(***********************************************************************

                    Mathematica-Compatible Notebook

This notebook can be used on any computer system with Mathematica 4.0,
MathReader 4.0, or any compatible application. The data for the notebook 
starts with the line containing stars above.

To get the notebook into a Mathematica-compatible application, do one of 
the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing the 
word CacheID, otherwise Mathematica-compatible applications may try to 
use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
***********************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[     44883,       1285]*)
(*NotebookOutlinePosition[     45796,       1314]*)
(*  CellTagsIndexPosition[     45752,       1310]*)
(*WindowFrame->Normal*)



Notebook[{
Cell[BoxData[
    \(\(BeginPackage["\<Genealogies`Continua`\>", \
{"\<Statistics`ContinuousDistributions`\>", \n\t\t\t\
"\<Statistics`DiscreteDistributions`\>", "\<Statistics`DataManipulation`\>", \
"\<Utilities`RandomNumbers`\>", "\<Genealogies`Genealogies`\>"}];\)\)], \
"Input",
  PageWidth->PaperWidth,
  InitializationCell->True,
  AspectRatioFixed->False],

Cell[BoxData[
    \(\(\( (*\ For\ obscure\ reasons, \ 
      it\ is\ necessary\ to\ load\ Statistics`ContinuousDistributions`\  - \ 
        even\ though\ BeginPackage[]\ should\ achieve\ that\ *) \)\(\ \
\)\)\)], "Input"],

Cell[BoxData[
    \(\(<< Statistics`ContinuousDistributions`;\)\)], "Input",
  InitializationCell->True],

Cell[CellGroupData[{

Cell[" Usage statements", "Section",
  Evaluatable->False,
  InitializationCell->True,
  AspectRatioFixed->False],

Cell[CellGroupData[{

Cell["Simulating", "Subsection"],

Cell[CellGroupData[{

Cell["ContinuumVariables", "Subsubsection"],

Cell[BoxData[
    \(\(ContinuumVariables::usage = "\<ContinuumVariables lists all the \
variables that define the simulation results. Save['file',ContinuumVariables] \
saves the results in a large file.  These are GlobalContinuumVariables, \
IndividualContinuumVariables, and Individuals (which has arguments pop, box).\
\>";\)\)], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(\(GlobalContinuumVariables::usage = "\<GlobalContinuumVariables lists \
the global variables, which have the form NumberOfIndividuals[pop]\>";\)\)], \
"Input",
  InitializationCell->True],

Cell[BoxData[
    \(\(IndividualContinuumVariables::usage = "\<GlobalContinuumVariables \
lists the individual variables, which have the form \
NumberOfIndividuals[pop]\>";\)\)], "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{

Cell["Genotype", "Subsubsection"],

Cell[BoxData[
    \(\(Genotype::usage = "\<Genotype[pop,ind] specifies the genotype of the \
individual.  Genotype\[Rule]f is an option for InitialiseContinuum which \
specifies the initial genotype,f[ind].\>";\)\)], "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    \(TextForm
    \`Location[popln, i]\ gives\ the\ locations\ of\ individual\ \(i . \)\)], 
  "Subsubsection",
  InitializationCell->True],

Cell[BoxData[
    \(\(Location::usage = "\<Location[popln,i] gives the locations of \
individual i.\>";\)\)], "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    \(TextForm
    \`Density[popln, i]\ lists\ the\ perceived\ density\ around\ individual\ 
      \(i . \)\)], "Subsubsection",
  InitializationCell->True],

Cell[BoxData[
    \(\(Density::usage = "\<Density[popln,i] lists the perceived density \
around individual i.\>";\)\)], "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{

Cell["Fecundity[popln,i] gives the fecundity of each individual.", 
  "Subsubsection"],

Cell[BoxData[
    \(\(Fecundity::usage = "\<Fecundity[popln,i] gives the fecundity of each \
individual.\>";\)\)], "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{

Cell["Mortality[popln,i] gives the mortality of each individual.", 
  "Subsubsection"],

Cell[BoxData[
    \(\(Mortality::usage = "\<Mortality[popln,i] gives the mortality of each \
individual.\>";\)\)], "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    \(TextForm
    \`BirthTime[popln, i]\ lists\ the\ birth\ time\ of\ individual\ 
      \(i . \)\)], "Subsubsection",
  InitializationCell->True],

Cell[BoxData[
    \(\(BirthTime::usage = "\<BirthTime[popln,i] lists the birth time of \
individual i.\>";\)\)], "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    \(TextForm\`DeathTime[popln, 
        i]\ lists\ the\ death\ time\ of\ individual\ i . \ \ If\ an\ \
individual\ is\ still\ alive, \ 
    DeathTime[popln, i]\ is\ \(\(undefined\)\(.\)\)\)], "Subsubsection",
  InitializationCell->True],

Cell[BoxData[
    \(\(DeathTime::usage = "\<DeathTime[popln,i] lists the death time of \
individual i.  If an individual is still alive, DeathTime[popln,i] is \
\[Infinity].\>";\)\)], "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{

Cell["\<\
Ancestry[popln,i] lists the ancestry of each individual.  For the \
first  individuals, Ancestry[] is set to {}.\
\>", "Subsubsection"],

Cell[BoxData[
    \(\(Ancestry::usage = "\<Ancestry[popln,i] lists the ancestry of each \
individual.  For the first individuals, Ancestry[] is set to {}.\>";\)\)], \
"Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{

Cell["Offspring[popln,i] gives the offspring of individual i", "Subsubsection"],

Cell[BoxData[
    \(\(Offspring::usage = "\<Offspring[popln,i] gives the offspring of \
individual i. \>";\)\)], "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{

Cell["\<\
NumberOfIndividuals[popln] is the number of extant \
individuals\
\>", "Subsubsection",
  InitializationCell->True],

Cell[BoxData[
    \(\(NumberOfIndividuals::usage = "\<NumberOfIndividuals[popln] is the \
number of extant individuals\>";\)\)], "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{

Cell["ExtantIndividuals[pop] lists the extant individuals", "Subsubsection",
  InitializationCell->True],

Cell[BoxData[
    \(\(ExtantIndividuals::usage = "\<ExtantIndividuals[pop] lists the extant \
individuals.  ExtantIndividuals[pop,t] lists those individuals extant at time \
t.\>";\)\)], "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{

Cell["T[popln] is the current time", "Subsubsection",
  InitializationCell->True],

Cell[BoxData[
    \(\(T::usage = "\<T[popln] is the current time\>";\)\)], "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{

Cell["NetFecundity[popln] is the net fecundity", "Subsubsection",
  InitializationCell->True],

Cell[BoxData[
    \(\(NetFecundity::usage = "\<NetFecundity[popln] is the net fecundity\>";\
\)\)], "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{

Cell["NetMortality[popln] is the net fecundity", "Subsubsection",
  InitializationCell->True],

Cell[BoxData[
    \(\(NetMortality::usage = "\<NetMortality[popln] is the net mortality\>";\
\)\)], "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{

Cell["\<\
TotalNumber[popln] gives the largest code used so far to identify \
individuals\
\>", "Subsubsection",
  InitializationCell->True],

Cell[BoxData[
    \(\(TotalNumber::usage = "\<TotalNumber[popln] gives the total number of \
individuals who have ever lived.\>";\)\)], "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{

Cell["\<\
Individuals[popln,X] lists the codes of the extant individuals in \
box X\
\>", "Subsubsection",
  InitializationCell->True],

Cell[BoxData[
    \(\(Individuals::usage = "\<Individuals[popln,X] lists the codes of the \
extant individuals in box X\>";\)\)], "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData[
"Box[x,\[CapitalDelta]] gives the box in which x is found.   Boxes are of \
size \[CapitalDelta]. "], "Subsubsection",
  InitializationCell->True],

Cell[BoxData[
    \(\(Box::usage = "\<Box[x,\[CapitalDelta]] gives the box in which x is \
found.  Boxes are of size \[CapitalDelta], and are numbered from {0,0} to \
{nboxes-1,nboxes-1} in two dimensions; similarly in other dimensions. \
\>";\)\)], "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData[
"Boxes[popln,i] lists the box in which individual i is found.  Boxes are of \
size \[CapitalDelta]."], "Subsubsection"],

Cell[BoxData[
    \(\(Boxes::usage = "\<Boxes[popln,i] lists the box in which individual i \
is found.  Boxes are of size \[CapitalDelta]. \>";\)\)], "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{

Cell["\<\
DistanceSquared[x,y,R] gives the distance between x and y, on a \
torus of size R.\
\>", "Subsubsection"],

Cell[BoxData[
    \(\(DistanceSquared::usage = "\<DistanceSquared[x,y,R] gives the square \
of the distance between x and y, on a torus of size R. \>";\)\)], "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    \(TextForm
    \`MakeDistances[y, {x\_1, \[Ellipsis]}, R, \[CapitalDelta]\^2]\ lists\ the
      \ squared\ distances\ from\ y\ to\ each\ of\ the\ neighbours\ at\ 
      \({x\_1, \[Ellipsis]} . \)\)], "Subsubsection"],

Cell[BoxData[
    \(\(MakeDistances::usage = \
\*"\"\<MakeDistances[y,{\!\(x\_1\),\[Ellipsis]},R,\!\(\[CapitalDelta]\^2\)] \
lists the squared distances from y to each of the neighbours at {\!\(x\_1\),\
\[Ellipsis]}.\>\"";\)\)], "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    \(TextForm
    \`MakeDistanceList[popln, R, \[CapitalDelta]]\ generates\ a\ list\ of\ all
      \ the\ distances\ between\ pairs\ of\ neighbouring\ extant\ 
      individuals . \ Each\ distance\ appears\ only\ \(once . \)\)], 
  "Subsubsection"],

Cell[BoxData[
    \(\(MakeDistanceList::usage = \
"\<MakeDistanceList[popln,R,\[CapitalDelta]] generates a list of all the \
distances between pairs of neighbouring extant individuals. Each distance \
appears only once. \>";\)\)], "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    \(TextForm\`InitialiseContinuum[popln, n, R, \[CapitalDelta], d, U, M, 
        F]\ sets\ up\ a\ population, \ 
    with\ uniformly\ distributed\ locations\ for\ n\ individuals\ in\ d\ \
dimensions, \ 
    on\ a\ range\ R . \ \ Box\ size\ is\ \[CapitalDelta] . \ \ \ U[
          z\^2]\ is\ a\ function\ giving\ the\ density\ due\ to\ an\ \
individual\ a\ distance\ z\ away, \ 
    M[d, x]\ is\ a\ function\ giving\ the\ mortality\ as\ a\ function\ of\ \
the\ density\ and\ location, \ 
    and\ F[d, 
        x]\ is\ a\ function\ giving\ the\ fecundity\ as\ a\ function\ of\ \
density\ and\ location . \ 
        Returns\ the\ net\ rate\ of\ \(\(events\)\(.\)\)\)], "Subsubsection"],

Cell[BoxData[
    \(\(InitialiseContinuum::usage = "\<InitialiseContinuum[popln,n,R,\
\[CapitalDelta],d,U,M,F] sets up a population, with uniformly distributed \
locations for n individuals in d dimensions, on a range R.  Box size is \
\[CapitalDelta].   U[x,x*,g,g*] is a function giving the 'density' at x due \
to an individual at x*, with genotypes g, g*, M[d,x,g] is a function giving \
the mortality as a function of the density, location and genotype, and \
F[d,x,g] is a function giving the fecundity as a function of density, \
location and genotype. Returns the net mortality and fecundity.  \
Genotype->f[ind,x] specifies the genotype; default is 0&.\>";\)\)], "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    \(TextForm\`IterateContinuum[popln, R, \[CapitalDelta], U, M, F, 
      D]\)], "Subsubsection"],

Cell[BoxData[
    \(\(IterateContinuum::usage = \
"\<IterateContinuum[popln,R,\[CapitalDelta],U,M,F,D] iterates a population on \
a range R; the number of the individual who is born or dies is returned \
(negative if dead).  Box size is \[CapitalDelta]. The dispersal distribution \
is a random number generated by D[d,x,g], g being the genotype and d the \
local density.  U[x,x*,g,g*] is a function giving the 'density' at x due to \
an individual at x*, with genotypes g, g*,. M[d,x,g] is a function giving the \
mortality as a function of the density, location and genotype. F[d,x,g] does \
the same for fecundity. \>";\)\)], "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData[
"Birth[pop,U,M,F,\[Sigma]][R,\[CapitalDelta]] adds a random newborn \
individual."], "Subsubsection"],

Cell[BoxData[
    \(\(Birth::usage = "\<Birth[pop,U,M,F,D][R,\[CapitalDelta]] adds a random \
newborn individual; returns the number of the new individual.\>";\)\)], \
"Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData[
"Death[pop,U,M,F][R,\[CapitalDelta]] deletes a random individual."], 
  "Subsubsection"],

Cell[BoxData[
    \(\(Death::usage = "\<Death[pop,U,M,F][R,\[CapitalDelta]] deletes a \
random individual; returns minus the number of that individual..\>";\)\)], \
"Input",
  InitializationCell->True]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
ExtractExtant[f,popln] extracts a list of f [popln,i] for those \
individuals who are still alive\
\>", "Subsubsection"],

Cell[BoxData[
    \(\(ExtractExtant::usage = "\<ExtractExtant[f,popln] extracts a list of \
f[popln,i] for those individuals who are still alive. \
ExtractExtant[f,popln,t] extracts a list of f[popln,i] for those individuals \
who are alive at time t\>";\)\)], "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{

Cell["\<\
FindPosition[popln, i] finds the position of this individual in the \
list of extant individuals\
\>", "Subsubsection"],

Cell[BoxData[
    \(\(FindPosition::usage = "\<FindPosition[popln,i] finds the position of \
this individual in the list of extant individuals\>";\)\)], "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    \(TextForm
    \`Neighbours[popln, Box[], nboxes]\ lists\ those\ extant\ individuals\ in
      \ boxes\ of\ size\ \[CapitalDelta]\ which\ neighbour\ the\ given\ 
      box . \ These\ neighbours\ can\ be\ no\ more\ than\ 2 \(\@ d\) 
      \[CapitalDelta]\ \(away . \)\)], "Subsubsection",
  InitializationCell->True],

Cell[BoxData[
    \(\(Neighbours::usage = \*"\"\<Neighbours[popln,Box[],nboxes] lists those \
extant individuals in boxes of size \[CapitalDelta] which neighbour the given \
box. These neighbours can be no more than 2\!\(\@d\)\[CapitalDelta] away.  \
Includes the target individual at x.\>\"";\)\)], "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{

Cell["\<\
NeighbourArray[2] gives the array of displacements  \
{{-1,-1},{-1,0},{-1,1},{0,-1},{0,0},{0,1},{1,-1},{1,0},{1,1}}; similarly in \
other dimensions.\
\>", "Subsubsection",
  InitializationCell->True],

Cell[BoxData[
    \(\(NeighbourArray::usage = "\<NeighbourArray[2] gives the array of \
displacements {{-1,-1},{-1,0},{-1,1},{0,-1},{0,0},{0,1},{1,-1},{1,0},{1,1}}; \
similarly in other dimensions.\>";\)\)], "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{

Cell["\<\
SampleCovariance[popln,R,{Dmax,\[Delta]D}] uses MakeDistanceList[] \
to find the distances between pairs of individuals; returns the number of \
distances in bins of size \[Delta]D\
\>", "Subsubsection"],

Cell[BoxData[
    \(\(SampleCovariance::usage = \
"\<SampleCovariance[popln,R,{Dmax,\[Delta]D}] uses MakeDistanceList[] to find \
the distances between pairs of individuals; returns the number of distances \
in bins of size \[Delta]D. \>";\)\)], "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{

Cell["\<\
InitialiseCovariance[{Dmax,\[Delta]D}] returns an empty array \
suitable for accumulating covariances\
\>", "Subsubsection"],

Cell[BoxData[
    \(\(InitialiseCovariance::usage = \
"\<InitialiseCovariance[{Dmax,\[Delta]D}] returns an empty array suitable for \
accumulating covariances. \>";\)\)], "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{

Cell["\<\
CovarianceMidPoints[{Dmax,\[Delta]D}] gives a list of the midpoints \
of the distance bins.\
\>", "Subsubsection"],

Cell[BoxData[
    \(\(CovarianceMidPoints::usage = "\<CovarianceMidPoints[{Dmax,\[Delta]D}] \
gives a list of the midpoints of the distance bins.\>";\)\)], "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    \(TextForm
    \`SpatialCovariance[hist, nbar, R, {D\_max, \[Delta]D}, dims]\ gives\ a\ 
      list\ of\ the\ covariance\ in\ density\ as\ a\ function\ of\ 
      distance . \ \ hist\ gives\ the\ distribution\ of\ distances, \ 
    in\ bins\ of\ size\ \[Delta]D, \ and\ nbar\ the\ mean\ \(density . \)\)], 
  "Subsubsection"],

Cell[BoxData[
    \(\(SpatialCovariance::usage = \
\*"\"\<SpatialCovariance[hist,nbar,R,{\!\(D\_max\),\[Delta]D},dims] gives a \
list of the covariance in density as a function of distance.  hist gives the \
distribution of distances, in bins of size \[Delta]D, and nbar the mean \
density.\>\"";\)\)], "Input",
  InitializationCell->True]
}, Closed]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Extracting the genealogy", "Subsection"],

Cell[CellGroupData[{

Cell["\<\
MostRecentCommonAncestor[pop,i,j] gives the most recent common \
ancestor of individuals i, j\
\>", "Subsubsection"],

Cell[BoxData[
    \(\(MostRecentCommonAncestor::usage = \((MostRecentCommonAncestor::usage)\
\) <> "\<Applies to a continuum simulation as well as to a rooted \
genealogy.\>";\)\)], "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    \(TextForm
    \`Ancestors[p, {i\_1, i\_2, \[Ellipsis]}]\ lists\ the\ ancestors\ of\ 
      individuals\ \({i\_1, i\_2, \[Ellipsis]} . \)\)], "Subsubsection"],

Cell[BoxData[
    \(\(Ancestors::usage = \((Ancestors::usage)\) <> \
\*"\"\<Ancestors[p,{\!\(i\_1\),\!\(i\_2\),\[Ellipsis]}] lists the ancestors \
of individuals {\!\(i\_1\),\!\(i\_2\),\[Ellipsis]}. Ancestors[p,i] gives the \
ancestor of individual i.\>\"";\)\)], "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{

Cell["\<\
Descendants[p,i,s] gives the descendants of individual i who are \
members of the set s.\
\>", "Subsubsection"],

Cell[BoxData[
    \(\(Descendants::usage = \((Descendants::usage)\) <> \
"\<Descendants[p,i,s] gives the descendants of individual i who are members \
of the set s.\>";\)\)], "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    \(TextForm
    \`MakeGenealogy[popln, {i\_1, i\_2, \[Ellipsis]}]\ constructs\ the\ 
        genealogy\ which\ relates\ individuals
        \ {i\_1, i\_2, \[Ellipsis]} . \ \ NodeFunction \[Rule] 
      f\ inserts\ information\ f[j]\ at\ each\ node, \ j; \ 
    this\ must\ return\ a\ \(list . \)\)], "Subsubsection"],

Cell[BoxData[
    \(\(MakeGenealogy::usage = \
\*"\"\<MakeGenealogy[popln,{\!\(i\_1\),\!\(i\_2\),\[Ellipsis]}] constructs \
the genealogy which relates individuals {\!\(i\_1\),\!\(i\_2\),\[Ellipsis]}.  \
NodeFunction\[Rule]f inserts information f[j,x,g] at each node, j; this must \
return a list.(x is the location, and g the genotype)\>\"";\)\)], "Input",
  InitializationCell->True]
}, Closed]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Sampling individuals", "Subsection"],

Cell[CellGroupData[{

Cell[BoxData[
    \(TextForm
    \`SampleIndividuals[popln, {x\_1, \[Ellipsis]}, n, \[Sigma]\^2, R, 
        \[CapitalDelta]]\ samples\ n\ individuals, \ without\ replacement, \ 
    from\ around\ each\ of\ the\ locations\ \ x\_i . \ \ The\ probability\ of
      \ sampling\ falls\ as\ a\ Gaussian\ around\ x, \ 
    with\ variance\ \[Sigma]\^2 . \ \ If\ \[Sigma]\^2\ is\ set\ to\ zero, \ 
    the\ nearest\ n\ individuals\ are\ sampled . \ \ To\ save\ time, \ 
    only\ those\ individuals\ within\ \[CapitalDelta]\ of\ the\ target\ point
      \ are\ \(counted : \ if\ there\ are\ too\ few\ in\ this\ region\), \ 
    a\ smaller\ sample\ is\ returned . \ \ Must\ choose\ \[CapitalDelta] > 
      3  \[Sigma], \ \(say . \)\)], "Subsubsection"],

Cell[BoxData[
    \(\(SampleIndividuals::usage = \
\*"\"\<SampleIndividuals[popln,{\!\(x\_1\),\[Ellipsis]},n,\!\(\[Sigma]\^2\),R,\
\[CapitalDelta]] samples n individuals, without replacement, from around each \
of the locations  \!\(x\_i\).  The probability of sampling falls as a \
Gaussian around x, with variance \!\(\[Sigma]\^2\).  If \!\(\[Sigma]\^2\) is \
set to zero, the nearest n individuals are sampled.  To save time, only those \
individuals within \[CapitalDelta] of the target point are counted: if there \
are too few in this region, a smaller sample is returned.  Must choose \
\[CapitalDelta]>3\[Sigma], say.\>\"";\)\)], "Input",
  InitializationCell->True]
}, Closed]]
}, Closed]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Private parts", "Section"],

Cell[BoxData[
    \(\(Begin["\<Genealogies`Continua`Private`\>"];\)\)], "Input",
  InitializationCell->True],

Cell[CellGroupData[{

Cell["Simulating continua", "Subsection"],

Cell[CellGroupData[{

Cell["ContinuumVariables", "Subsubsection"],

Cell[BoxData[
    \(\(GlobalContinuumVariables = {NumberOfIndividuals, ExtantIndividuals, 
          T, NetFecundity, NetMortality, TotalNumber};\)\)], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(\(IndividualContinuumVariables = {Location, Density, Fecundity, 
          Mortality, BirthTime, DeathTime, Ancestry, Offspring, Boxes, 
          Genotype};\)\)], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(\(ContinuumVariables = 
        Join[GlobalContinuumVariables, 
          IndividualContinuumVariables, {Individuals}];\)\)], "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{

Cell["\<\
Box[x,\[CapitalDelta]] gives the box in which x is found.   Boxes \
are of size \[CapitalDelta]. \
\>", "Subsubsection",
  InitializationCell->True],

Cell[BoxData[
    \(\(Box[x_, \[CapitalDelta]_] := \(Quotient[#, \[CapitalDelta]] &\) /@ 
          x;\)\)], "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{

Cell["\<\
DistanceSquared[x,y,R] gives the distance between x and y, on a \
torus of size R.\
\>", "Subsubsection"],

Cell[BoxData[
    \(\(DistanceSquared[x_, y_, R_] := 
        Plus @@ \(\((Mod[x - y + R/2, R] - R/2)\)\^2\);\)\)], "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    \(TextForm\`MakeDistances[y, {x\_1, \[Ellipsis]}, 
        R, \[CapitalDelta]\^2]\ lists\ the\ squared\ distances\ from\ y\ to\ \
each\ of\ the\ neighbours\ at\ \(\({x\_1, \[Ellipsis]}\)\(.\)\)\)], \
"Subsubsection"],

Cell[BoxData[
    \(\(MakeDistances[xx_, nx_, R_, \[CapitalDelta]\[CapitalDelta]_] := \n\t
        Select[\(DistanceSquared[#, xx, R] &\) /@ 
            nx, \((# < \[CapitalDelta]\[CapitalDelta])\) &];\)\)], "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    \(TextForm\`\(\(MakeDistanceList[popln, 
        R, \[CapitalDelta]]\)\(\ \)\(generates\)\(\ \)\(a\)\(\ \)\(list\)\(\ \
\)\(of\)\(\ \)\(all\)\(\ \)\(the\)\(\ \)\(distances\)\(\ \)\(between\)\(\ \
\)\(pairs\)\(\ \)\(of\)\(\ \)\(neighbouring\)\(\ \)\(extant\)\(\ \
\)\(individuals . \ 
        Each\)\(\ \)\(distance\)\(\ \)\(appears\)\(\ \)\(only\)\(\ \)\(\(once\
\)\(.\)\)\(\ \ \)\)\)], "Subsubsection"],

Cell[BoxData[
    \(\(MakeDistanceList[pop_, R_, \[CapitalDelta]_] := \n\t
        Module[{bx, i, locs = ExtractExtant[Location, pop], inds, nx, 
            n = NumberOfIndividuals[
                pop], \[CapitalDelta]\[CapitalDelta] = \[CapitalDelta]\^2, 
            nb = Quotient[R, \[CapitalDelta]], done = {}, 
            dims}, \n\t\t\ \ dims = 
            Length[First[
                locs]]; \n\t\t\ \ bx = \(Box[#, \[CapitalDelta]] &\) /@ locs; 
          inds[_] := {}; \n\t\t\ \ Do[
            AppendTo[inds[bx\[LeftDoubleBracket]i\[RightDoubleBracket]], 
              i], {i, n}]; \n\t\t\ \ Table[AppendTo[done, i]; 
            nx = Complement[
                Flatten[\(inds[
                        Mod[bx\[LeftDoubleBracket]i\[RightDoubleBracket] + #, 
                          nb]] &\) /@ NeighbourArray[dims]], 
                done]; \n\t\t\t\@MakeDistances[locs\[LeftDoubleBracket]i\
\[RightDoubleBracket], locs\[LeftDoubleBracket]nx\[RightDoubleBracket], R, \
\[CapitalDelta]\[CapitalDelta]], {i, n}]];\)\)], "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    \(TextForm\`\(\(InitialiseContinuum[popln, n, R, \[CapitalDelta], d, U, 
      M, F]\)\(\ \)\)\)], "Subsubsection"],

Cell[BoxData[
    \(\(Options[
          InitialiseContinuum] = {Genotype \[Rule] \((0 &)\)};\)\)], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(\(InitialiseContinuum[p_, n_Integer, R_, \[CapitalDelta]_, d_Integer, 
          U_, M_, F_, opts___Rule] := \n\t
        Module[{nb = Quotient[R, \[CapitalDelta]], i, xi, 
            nx, \[CapitalDelta]\[CapitalDelta] = \[CapitalDelta]\^2, dens, 
            nl, \[IndentingNewLine]ff = \(Genotype /. {opts}\) /. 
                Options[InitialiseContinuum]}, \[IndentingNewLine]Individuals[
              p, _] := {}; NumberOfIndividuals[p] = n; TotalNumber[p] = n; 
          T[p] = 0; 
          Do[Location[p, i] = Table[Random[Real, R], {d}], {i, 
              n}]; \ \[IndentingNewLine]ExtantIndividuals[p] = 
            Range[n]; \[IndentingNewLine]Do[\[IndentingNewLine]BirthTime[p, 
                i] = 0; 
            DeathTime[p, i] = \[Infinity]; \[IndentingNewLine]Ancestry[p, 
                i] = {}; 
            Offspring[p, i] = {}; \[IndentingNewLine]Genotype[p, i] = 
              ff[i, Location[p, i]]; \[IndentingNewLine]Boxes[p, i] = 
              Box[Location[p, 
                  i], \[CapitalDelta]]; \[IndentingNewLine]AppendTo[
              Individuals[p, Boxes[p, i]], i];, \[IndentingNewLine]{i, 
              n}]; \ \[IndentingNewLine]Do[\[IndentingNewLine]nl = 
              DeleteCases[Neighbours[p, Boxes[p, i], nb], 
                i]; \[IndentingNewLine]\ 
            dens = \(Density[p, i] = 
                Plus @@ MapThread[
                    U[Location[p, i], #1, 
                        Genotype[p, i], #2] &, {\(Location[p, #] &\) /@ 
                        nl, \(Genotype[p, #] &\) /@ 
                        nl}]\); \[IndentingNewLine]Fecundity[p, i] = 
              F[dens, Location[p, i], 
                Genotype[p, i]]; \[IndentingNewLine]Mortality[p, i] = 
              M[dens, Location[p, i], Genotype[p, i]];, {i, 
              n}]; \[IndentingNewLine]NetFecundity[p] = 
            Sum[Fecundity[p, i], {i, n}]; \ \[IndentingNewLine]NetMortality[
              p] = Sum[Mortality[p, i], {i, n}]; \[IndentingNewLine]{\ 
            NetMortality[p], NetFecundity[p]}];\)\)], "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    \(TextForm\`\(\(IterateContinuum[popln, R, \[CapitalDelta], U, M, 
      F, \[Sigma]]\)\(\ \)\)\)], "Subsubsection"],

Cell[BoxData[
    \(\(IterateContinuum[p_, R_, \[CapitalDelta]_, U_, M_, F_, 
          D_] := \n\t\((T[p] += 
            Random[ExponentialDistribution[
                NetMortality[p] + NetFecundity[p]]]; \n\t
          If[Random[] > 
              NetMortality[p]\/\(NetMortality[p] + NetFecundity[p]\), \n\t\
\(Birth[p, U, M, F, D]\)[R, \[CapitalDelta]], \(Death[p, U, M, F]\)[
              R, \[CapitalDelta]]])\);\)\)], "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{

Cell["\<\
Birth[pop,U,M,F,\[Sigma]][R,\[CapitalDelta]] adds a random newborn \
individual.\
\>", "Subsubsection"],

Cell[BoxData[
    \(\(\(Birth[p_, U_, M_, F_, Disp_]\)[
          R_, \[CapitalDelta]_] := \[IndentingNewLine]Module[{i, j, k, xi, 
            yi, gi, bx, 
            nb = Quotient[
                R, \[CapitalDelta]], \[CapitalDelta]\[CapitalDelta] = \
\[CapitalDelta]\^2, nx, nn, dens, d, dd, yt = {}, gt = {}, 
            ng}, \ \[IndentingNewLine]NumberOfIndividuals[p] += 1; 
          TotalNumber[p] += 1; nn = TotalNumber[p]; 
          k = RandomListCompiled[
                1, \(Fecundity[p, #] &\) /@ \
ExtantIndividuals[p]\/NetFecundity[p]] // 
              First; \[IndentingNewLine]i = \(ExtantIndividuals[
                p]\)\[LeftDoubleBracket]
              k\[RightDoubleBracket]; \[IndentingNewLine]BirthTime[p, nn] = 
            T[p]; DeathTime[p, nn] = \[Infinity]; 
          ng = \(Genotype[p, nn] = Genotype[p, i]\); \[IndentingNewLine]xi = 
            Location[p, i]; d = Length[xi]; 
          xi += Disp[Density[p, i], xi, ng]; xi = \(Mod[#, R] &\) /@ xi; 
          bx = \(Boxes[p, nn] = Box[xi, \[CapitalDelta]]\); 
          nx = Neighbours[p, bx, nb]; 
          AppendTo[Individuals[p, bx], nn]; \ \ Location[p, nn] = xi; \ 
          Scan[\((yi = Location[p, #]; dd = DistanceSquared[xi, yi, R]; 
                If[dd < \[CapitalDelta]\[CapitalDelta], \
\[IndentingNewLine]AppendTo[yt, yi]; gi = Genotype[p, #]; 
                  AppendTo[gt, gi]; \[IndentingNewLine]Density[p, #] += 
                    U[yi, xi, gi, ng]; NetMortality[p] -= Mortality[p, #]; 
                  NetFecundity[p] -= 
                    Fecundity[p, #]; \ \ NetMortality[
                      p] += \((Mortality[p, #] = 
                        M[Density[p, #], yi, gi])\); \ \ NetFecundity[
                      p] += \((Fecundity[p, #] = 
                        F[Density[p, #], yi, 
                          gi])\)];)\) &, \[IndentingNewLine]nx]; \
\[IndentingNewLine]Density[p, nn] = \(dens = 
              Plus @@ MapThread[
                  U[xi, #1, ng, #2] &, {yt, 
                    gt}]\); \[IndentingNewLine]NetFecundity[
              p] += \((Fecundity[p, nn] = 
                F[dens, xi, ng])\); \[IndentingNewLine]NetMortality[
              p] += \((Mortality[p, nn] = 
                M[dens, xi, ng])\); \[IndentingNewLine]AppendTo[
            ExtantIndividuals[p], 
            TotalNumber[p]]; \[IndentingNewLine]Ancestry[p, nn] = 
            Prepend[Ancestry[p, i], i]; \[IndentingNewLine]AppendTo[
            Offspring[p, i], 
            TotalNumber[p]]; \[IndentingNewLine]Offspring[p, 
              nn] = {}; \[IndentingNewLine]\(+nn\)];\)\)], "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{

Cell["\<\
Death[pop,U,M,F][R,\[CapitalDelta]] deletes a random \
individual.\
\>", "Subsubsection"],

Cell[BoxData[
    \(\(\(Death[p_, U_, M_, F_]\)[
          R_, \[CapitalDelta]_] := \[IndentingNewLine]Module[{i, j, k, xi, 
            yi, bx, nb = 
              Quotient[
                R, \[CapitalDelta]], \[CapitalDelta]\[CapitalDelta] = \
\[CapitalDelta]\^2, nx, gi, gx}, \[IndentingNewLine]NumberOfIndividuals[p] -= 
            1; \[IndentingNewLine]k = 
            RandomListCompiled[
                1, \(Mortality[p, #] &\) /@ \
ExtantIndividuals[p]\/NetMortality[p]] // 
              First; \[IndentingNewLine]i = \(ExtantIndividuals[
                p]\)\[LeftDoubleBracket]k\[RightDoubleBracket]; 
          xi = Location[p, i]; \[IndentingNewLine]DeathTime[p, i] = 
            T[p]; \[IndentingNewLine]bx = 
            Box[xi, \[CapitalDelta]]; \[IndentingNewLine]Individuals[p, bx] = 
            DeleteCases[Individuals[p, bx], i]; \[IndentingNewLine]nx = 
            DeleteCases[Neighbours[p, bx, nb], i]; \[IndentingNewLine]gx = 
            Genotype[p, 
              i]; \[IndentingNewLine]Scan[\[IndentingNewLine]\((yi = 
                  Location[p, #]; 
                dd = DistanceSquared[xi, yi, R]; \[IndentingNewLine]If[
                  dd < \[CapitalDelta]\[CapitalDelta], \[IndentingNewLine]gi \
= Genotype[p, #]; 
                  Density[p, #] -= 
                    U[yi, xi, gi, gx]; \[IndentingNewLine]NetMortality[p] -= 
                    Mortality[p, #]; 
                  NetFecundity[p] -= 
                    Fecundity[p, #]; \[IndentingNewLine]NetMortality[
                      p] += \((Mortality[p, #] = 
                        M[Density[p, #], yi, 
                          gi])\); \[IndentingNewLine]NetFecundity[
                      p] += \((Fecundity[p, #] = 
                        F[Density[p, #], yi, 
                          gi])\)];)\) &, \[IndentingNewLine]nx]; \n\t
          ExtantIndividuals[p] = Delete[ExtantIndividuals[p], k]; \n\t
          NetMortality[p] -= Mortality[p, i]; 
          NetFecundity[p] -= 
            Fecundity[p, i]; \[IndentingNewLine]\(-i\)];\)\)], "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{

Cell["\<\
ExtractExtant[f,popln] extracts a list of f [popln,i] for those \
individuals who are still alive\
\>", "Subsubsection"],

Cell[BoxData[{
    \(\(ExtractExtant[f_, pop_] := \(f[pop, #] &\) /@ 
          ExtantIndividuals[pop];\)\), "\[IndentingNewLine]", 
    \(ExtractExtant[f_, pop_, t_] := \(f[pop, #] &\) /@ 
        ExtantIndividuals[pop, t]\)}], "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{

Cell["ExtantIndividuals[pop] lists the extant individuals", "Subsubsection",
  InitializationCell->True],

Cell[BoxData[
    \(\(ExtantIndividuals[pop_, t_] := \[IndentingNewLine]Select[
          Range[TotalNumber[pop]], 
          BirthTime[pop, #] \[LessEqual] t < 
              DeathTime[pop, #] &];\)\)], "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{

Cell["\<\
FindPosition[popln, i] finds the position of this individual in the \
list of extant individuals\
\>", "Subsubsection"],

Cell[BoxData[
    \(\(FindPosition[pop_, 
          i_Integer] := \(Position[ExtantIndividuals[pop], 
            i]\)\[LeftDoubleBracket]1, 1\[RightDoubleBracket];\)\)], "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    \(TextForm\`Neighbours[popln, Box[], 
        nboxes]\ lists\ those\ extant\ individuals\ in\ boxes\ of\ size\ \
\[CapitalDelta]\ which\ neighbour\ the\ given\ box . \ 
        These\ neighbours\ can\ be\ no\ more\ than\ 2 \(\@ 
          d\) \[CapitalDelta]\ \(\(away\)\(.\)\)\)], "Subsubsection",
  InitializationCell->True],

Cell[BoxData[
    \(\(Neighbours[pop_, bx_, 
          nb_] := \n\t\tFlatten[\(Individuals[pop, Mod[bx + #, nb]] &\) /@ 
            NeighbourArray[Length[bx]]];\)\)], "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{

Cell["\<\
NeighbourArray[2] gives the array of displacements  \
{{-1,-1},{-1,0},{-1,1},{0,-1},{0,0},{0,1},{1,-1},{1,0},{1,1}}; similarly in \
other dimensions.\
\>", "Subsubsection",
  InitializationCell->True],

Cell[BoxData[{
    \(\(NeighbourArray[0] = {{}};\)\), "\n", 
    \(\(NeighbourArray[d_Integer] := \(NeighbourArray[d] = 
          Module[{i}, \n\t\t\tFlatten[
              Table[\(Append[#, i] &\) /@ NeighbourArray[d - 1], {i, \(-1\), 
                  1}], 1]]\);\)\)}], "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{

Cell["\<\
SampleCovariance[popln,R,{Dmax,\[Delta]D}] uses MakeDistanceList[] \
to find the distances between pairs of individuals; returns the number of \
distances in bins of size \[Delta]D\
\>", "Subsubsection"],

Cell[BoxData[
    \(\(SampleCovariance[p_, R_, {dm_, \[Delta]d_}]\  := \n\t\tBinCounts[
          Flatten[MakeDistanceList[p, R, dm]], {0, 
            dm, \[Delta]d}];\)\)], "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{

Cell["\<\
InitialiseCovariance[{Dmax,\[Delta]D}] returns an empty array \
suitable for accumulating covariances\
\>", "Subsubsection"],

Cell[BoxData[
    \(\(InitialiseCovariance[{dm_, \[Delta]d_}]\  := \n\t
        Array[0 &, Round[dm/\[Delta]d]];\)\)], "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{

Cell["\<\
CovarianceMidPoints[{Dmax,\[Delta]D}] gives a list of the midpoints \
of the distance bins.\
\>", "Subsubsection"],

Cell[BoxData[
    \(\(CovarianceMidPoints[{Dmax_, \[Delta]D_}] := 
        Module[{z}, 
          Table[z, {z, \[Delta]D\/2, 
              Dmax - \[Delta]D\/2, \[Delta]D}]];\)\)], "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    \(TextForm\`SpatialCovariance[hist, nbar, R, {D\_max, \[Delta]D}, 
        dims]\ gives\ a\ list\ of\ the\ covariance\ in\ density\ as\ a\ \
function\ of\ distance . \ \ hist\ gives\ the\ distribution\ of\ distances, \ 
    in\ bins\ of\ size\ \[Delta]D, \ 
    and\ nbar\ the\ mean\ \(\(density\)\(.\)\)\)], "Subsubsection"],

Cell[BoxData[
    \(\(SpatialCovariance::badDimensions = "\<SpatialCovariance is not \
defined for more than 2 dimensions\>";\)\)], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(\(SpatialCovariance[h_, nb_, R_, {dm_, \[Delta]D_}, d_] := 
        Module[{ne}, \[IndentingNewLine]ne = 
            Switch[d, \[IndentingNewLine]1, \[IndentingNewLine]\(2  h\)\/\(nb\
\ \(R\^2\) \[Delta]D\), \[IndentingNewLine]2, \[IndentingNewLine]\(\(2  
                      h\)\/\(nb\ \(R\^2\) \[Delta]D\)\) 
                1\/\(2  \[Pi]\ \[Delta]D\ CovarianceMidPoints[{dm, \
\[Delta]D}]\), \[IndentingNewLine]_, \[IndentingNewLine]Message[
                SpatialCovariance::badDimensions]]; \[IndentingNewLine]nb \
\((ne - nb)\)];\)\)], "Input",
  InitializationCell->True]
}, Closed]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Extracting the genealogy", "Subsection"],

Cell[CellGroupData[{

Cell["\<\
MostRecentCommonAncestor[pop,i,j] gives the most recent common \
ancestor of individuals i, j\
\>", "Subsubsection"],

Cell[BoxData[
    \(\(MostRecentCommonAncestor[p_, i_, j_] := \n\t
        Last[Prepend[Intersection[Ancestry[p, i], Ancestry[p, j]], 
            0]];\)\)], "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    \(TextForm
    \`Ancestors[p, {i\_1, i\_2, \[Ellipsis]}]\ lists\ the\ ancestors\ of\ 
      individuals\ \({i\_1, i\_2, \[Ellipsis]} . \)\)], "Subsubsection"],

Cell[BoxData[{
    \(\(Ancestors[p_, i_Integer] := Last[Ancestry[p, i]];\)\), "\n", 
    \(\(Ancestors[p_, s_List] := 
        Union[\(Ancestors[p, #] &\) /@ s];\)\)}], "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{

Cell["\<\
Descendants[p,i,s] gives the descendants of individual i who are \
members of the set s.\
\>", "Subsubsection"],

Cell[BoxData[
    \(\(Descendants[p_, i_, s_List] := 
        Select[s, MemberQ[Ancestry[p, #], i] &];\)\)], "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    \(TextForm\`MakeGenealogy[
          popln, {i\_1, 
            i\_2, \[Ellipsis]}]\ constructs\ the\ genealogy\ which\ relates\ \
individuals\ {i\_1, i\_2, \[Ellipsis]} . \ \ NodeFunction \[Rule] 
      f\ inserts\ information\ f[j, x, g]\ at\ each\ node, \ j; \ 
    this\ must\ return\ a\ \(\(list\)\(.\)\)\)], "Subsubsection"],

Cell[BoxData[
    \(\(Options[
          MakeGenealogy] = {NodeFunction \[Rule] \(({} &)\)};\)\)], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(\(MakeGenealogy[p_, {i_Integer}, opts___Rule] := \n\t
        Module[{nf = \(NodeFunction /. {opts}\) /. Options[MakeGenealogy], 
            aa = Ancestors[p, i]}, \n\t\t\tNode\ [aa, 
            nf[aa], {Node[i, 
                nf[i, Location[p, i], Genotype[p, i]], {}]}]];\)\)], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(\(MakeGenealogy[p_, {s__Integer, i_Integer}, opts___Rule] := \n\t
        Module[{tr = MakeGenealogy[p, {s}, opts], nodes, leaves, mrca, nn, 
            pn, nf = \(NodeFunction /. {opts}\) /. 
                Options[MakeGenealogy]}, \n\t\tIf[
            First[tr] != 
              Ancestors[p, 
                i], \n\t\ttr\[LeftDoubleBracket]1\[RightDoubleBracket] = 
              0]; \n\t\t\ \ nodes = CollapseGenealogy[tr]; \n\t\t\ \ leaves = 
            Flatten[CollapseGenealogy[tr, 
                Node -> False]]; \n\t\t\ \ mrca = \(MostRecentCommonAncestor[
                  p, i, #] &\) /@ leaves; 
          nn = Max[mrca]; \n\t\t\ \ If[
            MemberQ[Flatten[nodes], nn], \n\t\t\t\t (*\ 
              add\ to\ an\ existing\ node*) \n\t\t\t\tAddGenealogy[tr, 
              Node[i, nf[i, Location[p, i], Genotype[p, i]], {}], nn, 
              nn, {}], \n\t\t\t\t (*\ 
              insert\ a\ new\ bifurcating\ node\ *) \n\t\t\t\tpn = \(Extract[
                  leaves, 
                  Position[mrca, 
                    nn]]\)\[LeftDoubleBracket]1\[RightDoubleBracket]; \n\t\t\t\
\tAddGenealogy[tr, Node[i, nf[i, Location[p, i], Genotype[p, i]], {}], pn, 
              nn, nf[nn]]]];\)\)], "Input",
  InitializationCell->True]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["Sampling individuals", "Subsection"],

Cell[CellGroupData[{

Cell[BoxData[
    \(TextForm
    \`SampleIndividuals[popln, {x\_1, \[Ellipsis]}, n, \[Sigma]\^2, R, 
        \[CapitalDelta]]\ samples\ n\ individuals, \ without\ replacement, \ 
    from\ around\ each\ of\ the\ locations\ \ x\_i . \ \ The\ probability\ of
      \ sampling\ falls\ as\ a\ Gaussian\ around\ x, \ 
    with\ variance\ \[Sigma]\^2 . \ \ If\ \[Sigma]\^2\ is\ set\ to\ zero, \ 
    the\ nearest\ n\ individuals\ are\ sampled . \ \ To\ save\ time, \ 
    only\ those\ individuals\ within\ \[CapitalDelta]\ of\ the\ target\ point
      \ are\ \(counted : \ if\ there\ are\ too\ few\ in\ this\ region\), \ 
    a\ smaller\ sample . \ \ Must\ choose\ \[CapitalDelta] > 3  \[Sigma], \ 
    \(say . \)\)], "Subsubsection"],

Cell["\<\
There is a difficulty in using boxes to sample individuals \
efficiently.  One would like to sample from regions which are potentially \
larger than the existing box size, which is determined by the distance over \
which crowding occurs.  Therefore, boxes must be constructed afresh with each \
sampling.  This carries an overhead, so it is best to sample from a set of \
points simultaneously.  Note that while each sample is a list of distinct \
individuals, the same individual may appear in different samples.\
\>", "Text"],

Cell[TextData[
"- bx is a list of the boxes in which each extant individual is found\n- \
inds[box] is the individuals in that box\n- nx is a list of the individuals \
near to xl\[LeftDoubleBracket]j\[RightDoubleBracket]"], "Text"],

Cell[BoxData[
    \(\(SampleIndividuals[pop_, xl_List, n_Integer, v_, 
          R_, \[CapitalDelta]_] := \n\t
        Module[{bx, i, j, inds, 
            nx, \[CapitalDelta]\[CapitalDelta] = \[CapitalDelta]\^2, 
            nb = Quotient[R, \[CapitalDelta]], 
            na = NeighbourArray[Length[First[xl]]], wl, ns, ps, 
            locs = ExtractExtant[Location, 
                pop]}, \n\t\tbx = \(Box[#, \[CapitalDelta]] &\) /@ locs; 
          inds[_] := {}; \n\t\tDo[
            AppendTo[inds[bx\[LeftDoubleBracket]i\[RightDoubleBracket]], 
              i], {i, NumberOfIndividuals[pop]}]; \n\t\tTable[\n\t\t\tnx = 
              Flatten[\(inds[
                      Mod[Box[
                            xl\[LeftDoubleBracket]
                              j\[RightDoubleBracket], \[CapitalDelta]] + #, 
                        nb]] &\) /@ 
                  na]; \n\t\t\twl = \(DistanceSquared[#, 
                    xl\[LeftDoubleBracket]j\[RightDoubleBracket], R] &\) /@ 
                locs\[LeftDoubleBracket]nx\[RightDoubleBracket]; \n\t\t\tns = 
              Min[Length[wl], n]; \n\t\t\tps = 
              If[v > 0, \n\t\t\t\tRandomList[ns, Exp[\(-\(wl\/\(2  v\)\)\)], 
                  Replace \[Rule] False, Compiled \[Rule] True], 
                Take[\(\(Position[wl, #]\)\[LeftDoubleBracket]1, 
                        1\[RightDoubleBracket] &\) /@ Sort[wl], 
                  ns]]; \n\t\t\(ExtantIndividuals[pop]\)\[LeftDoubleBracket]
              nx\[LeftDoubleBracket]
                ps\[RightDoubleBracket]\[RightDoubleBracket], {j, 
              Length[xl]}]];\)\)], "Input",
  InitializationCell->True]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["Ending", "Subsection"],

Cell[BoxData[{
    \(\(End[];\)\), "\n", 
    \(\(EndPackage[];\)\)}], "Input",
  InitializationCell->True]
}, Closed]]
}, Open  ]]
},
FrontEndVersion->"4.0 for Macintosh",
ScreenRectangle->{{0, 1152}, {0, 748}},
AutoGeneratedPackage->Automatic,
WindowSize->{1002, 658},
WindowMargins->{{28, Automatic}, {Automatic, 22}},
StyleDefinitions -> "Default.nb",
MacintoshSystemPageSetup->"\<\
00<0001804P000000`d26_oRon@3:`8f0dL5N`?N0080001804P000000`d26P01
0000I00000400@410?l00BL?00400@00000000000000000201T1T0000000@000
00000000004000000000000000010000\>"
]


(***********************************************************************
Cached data follows.  If you edit this Notebook file directly, not using
Mathematica, you must remove the line containing CacheID at the top of 
the file.  The cache data will then be recreated when you save this file 
from within Mathematica.
***********************************************************************)

(*CellTagsOutline
CellTagsIndex->{}
*)

(*CellTagsIndex
CellTagsIndex->{}
*)

(*NotebookFileOutline
Notebook[{
Cell[1717, 49, 361, 8, 107, "Input",
  InitializationCell->True],
Cell[2081, 59, 222, 4, 43, "Input"],
Cell[2306, 65, 104, 2, 27, "Input",
  InitializationCell->True],

Cell[CellGroupData[{
Cell[2435, 71, 113, 3, 50, "Section",
  Evaluatable->False,
  InitializationCell->True],

Cell[CellGroupData[{
Cell[2573, 78, 32, 0, 46, "Subsection"],

Cell[CellGroupData[{
Cell[2630, 82, 43, 0, 42, "Subsubsection"],
Cell[2676, 84, 368, 6, 75, "Input",
  InitializationCell->True],
Cell[3047, 92, 207, 4, 43, "Input",
  InitializationCell->True],
Cell[3257, 98, 215, 4, 43, "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{
Cell[3509, 107, 33, 0, 28, "Subsubsection"],
Cell[3545, 109, 253, 4, 59, "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{
Cell[3835, 118, 154, 4, 28, "Subsubsection",
  InitializationCell->True],
Cell[3992, 124, 146, 3, 27, "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{
Cell[4175, 132, 170, 4, 28, "Subsubsection",
  InitializationCell->True],
Cell[4348, 138, 156, 3, 27, "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{
Cell[4541, 146, 86, 1, 28, "Subsubsection"],
Cell[4630, 149, 151, 3, 27, "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{
Cell[4818, 157, 86, 1, 28, "Subsubsection"],
Cell[4907, 160, 151, 3, 27, "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{
Cell[5095, 168, 161, 4, 28, "Subsubsection",
  InitializationCell->True],
Cell[5259, 174, 149, 3, 27, "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{
Cell[5445, 182, 252, 5, 28, "Subsubsection",
  InitializationCell->True],
Cell[5700, 189, 220, 4, 59, "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{
Cell[5957, 198, 145, 3, 28, "Subsubsection"],
Cell[6105, 203, 203, 4, 59, "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{
Cell[6345, 212, 79, 0, 28, "Subsubsection"],
Cell[6427, 214, 149, 3, 43, "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{
Cell[6613, 222, 125, 4, 28, "Subsubsection",
  InitializationCell->True],
Cell[6741, 228, 165, 3, 43, "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{
Cell[6943, 236, 104, 1, 28, "Subsubsection",
  InitializationCell->True],
Cell[7050, 239, 223, 4, 75, "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{
Cell[7310, 248, 81, 1, 28, "Subsubsection",
  InitializationCell->True],
Cell[7394, 251, 111, 2, 27, "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{
Cell[7542, 258, 93, 1, 28, "Subsubsection",
  InitializationCell->True],
Cell[7638, 261, 136, 3, 27, "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{
Cell[7811, 269, 93, 1, 28, "Subsubsection",
  InitializationCell->True],
Cell[7907, 272, 136, 3, 27, "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{
Cell[8080, 280, 140, 4, 28, "Subsubsection",
  InitializationCell->True],
Cell[8223, 286, 172, 3, 59, "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{
Cell[8432, 294, 134, 4, 28, "Subsubsection",
  InitializationCell->True],
Cell[8569, 300, 166, 3, 27, "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{
Cell[8772, 308, 161, 3, 28, "Subsubsection",
  InitializationCell->True],
Cell[8936, 313, 286, 5, 75, "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{
Cell[9259, 323, 134, 2, 28, "Subsubsection"],
Cell[9396, 327, 186, 3, 59, "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{
Cell[9619, 335, 115, 3, 28, "Subsubsection"],
Cell[9737, 340, 194, 3, 59, "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{
Cell[9968, 348, 234, 4, 29, "Subsubsection"],
Cell[10205, 354, 265, 5, 61, "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{
Cell[10507, 364, 263, 5, 28, "Subsubsection"],
Cell[10773, 371, 267, 5, 59, "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{
Cell[11077, 381, 701, 13, 73, "Subsubsection"],
Cell[11781, 396, 708, 10, 139, "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{
Cell[12526, 411, 113, 2, 28, "Subsubsection"],
Cell[12642, 415, 666, 10, 123, "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{
Cell[13345, 430, 116, 2, 28, "Subsubsection"],
Cell[13464, 434, 204, 4, 43, "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{
Cell[13705, 443, 103, 2, 28, "Subsubsection"],
Cell[13811, 447, 201, 4, 43, "Input",
  InitializationCell->True]
}, Open  ]],

Cell[CellGroupData[{
Cell[14049, 456, 130, 3, 42, "Subsubsection"],
Cell[14182, 461, 297, 5, 75, "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{
Cell[14516, 471, 129, 3, 28, "Subsubsection"],
Cell[14648, 476, 189, 3, 59, "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{
Cell[14874, 484, 333, 6, 30, "Subsubsection",
  InitializationCell->True],
Cell[15210, 492, 336, 5, 79, "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{
Cell[15583, 502, 210, 5, 28, "Subsubsection",
  InitializationCell->True],
Cell[15796, 509, 244, 4, 59, "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{
Cell[16077, 518, 213, 4, 28, "Subsubsection"],
Cell[16293, 524, 282, 5, 75, "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{
Cell[16612, 534, 134, 3, 28, "Subsubsection"],
Cell[16749, 539, 207, 4, 59, "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{
Cell[16993, 548, 124, 3, 28, "Subsubsection"],
Cell[17120, 553, 192, 3, 59, "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{
Cell[17349, 561, 343, 6, 43, "Subsubsection"],
Cell[17695, 569, 339, 6, 91, "Input",
  InitializationCell->True]
}, Closed]]
}, Open  ]],

Cell[CellGroupData[{
Cell[18083, 581, 46, 0, 46, "Subsection"],

Cell[CellGroupData[{
Cell[18154, 585, 126, 3, 42, "Subsubsection"],
Cell[18283, 590, 218, 4, 75, "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{
Cell[18538, 599, 176, 3, 28, "Subsubsection"],
Cell[18717, 604, 300, 5, 75, "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{
Cell[19054, 614, 121, 3, 28, "Subsubsection"],
Cell[19178, 619, 211, 4, 75, "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{
Cell[19426, 628, 333, 6, 43, "Subsubsection"],
Cell[19762, 636, 385, 6, 75, "Input",
  InitializationCell->True]
}, Closed]]
}, Open  ]],

Cell[CellGroupData[{
Cell[20196, 648, 42, 0, 46, "Subsection"],

Cell[CellGroupData[{
Cell[20263, 652, 744, 11, 88, "Subsubsection"],
Cell[21010, 665, 674, 10, 159, "Input",
  InitializationCell->True]
}, Closed]]
}, Closed]]
}, Open  ]],

Cell[CellGroupData[{
Cell[21745, 682, 32, 0, 50, "Section"],
Cell[21780, 684, 108, 2, 27, "Input",
  InitializationCell->True],

Cell[CellGroupData[{
Cell[21913, 690, 41, 0, 46, "Subsection"],

Cell[CellGroupData[{
Cell[21979, 694, 43, 0, 42, "Subsubsection"],
Cell[22025, 696, 188, 3, 27, "Input",
  InitializationCell->True],
Cell[22216, 701, 220, 4, 43, "Input",
  InitializationCell->True],
Cell[22439, 707, 182, 4, 27, "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{
Cell[22658, 716, 158, 4, 28, "Subsubsection",
  InitializationCell->True],
Cell[22819, 722, 145, 3, 27, "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{
Cell[23001, 730, 115, 3, 28, "Subsubsection"],
Cell[23119, 735, 152, 3, 29, "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{
Cell[23308, 743, 234, 4, 29, "Subsubsection"],
Cell[23545, 749, 245, 4, 43, "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{
Cell[23827, 758, 421, 7, 28, "Subsubsection"],
Cell[24251, 767, 1074, 19, 173, "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{
Cell[25362, 791, 133, 2, 28, "Subsubsection"],
Cell[25498, 795, 136, 3, 27, "Input",
  InitializationCell->True],
Cell[25637, 800, 2105, 36, 374, "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{
Cell[27779, 841, 134, 2, 28, "Subsubsection"],
Cell[27916, 845, 464, 9, 130, "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{
Cell[28417, 859, 113, 3, 28, "Subsubsection"],
Cell[28533, 864, 2643, 48, 424, "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{
Cell[31213, 917, 99, 3, 28, "Subsubsection"],
Cell[31315, 922, 2092, 39, 376, "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{
Cell[33444, 966, 130, 3, 28, "Subsubsection"],
Cell[33577, 971, 265, 5, 43, "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{
Cell[33879, 981, 104, 1, 28, "Subsubsection",
  InitializationCell->True],
Cell[33986, 984, 240, 5, 43, "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{
Cell[34263, 994, 129, 3, 28, "Subsubsection"],
Cell[34395, 999, 207, 4, 27, "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{
Cell[34639, 1008, 344, 6, 30, "Subsubsection",
  InitializationCell->True],
Cell[34986, 1016, 204, 4, 43, "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{
Cell[35227, 1025, 210, 5, 28, "Subsubsection",
  InitializationCell->True],
Cell[35440, 1032, 311, 6, 59, "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{
Cell[35788, 1043, 213, 4, 28, "Subsubsection"],
Cell[36004, 1049, 211, 4, 43, "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{
Cell[36252, 1058, 134, 3, 28, "Subsubsection"],
Cell[36389, 1063, 155, 3, 43, "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{
Cell[36581, 1071, 124, 3, 28, "Subsubsection"],
Cell[36708, 1076, 217, 5, 42, "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{
Cell[36962, 1086, 343, 5, 43, "Subsubsection"],
Cell[37308, 1093, 168, 3, 43, "Input",
  InitializationCell->True],
Cell[37479, 1098, 603, 10, 207, "Input",
  InitializationCell->True]
}, Closed]]
}, Open  ]],

Cell[CellGroupData[{
Cell[38131, 1114, 46, 0, 46, "Subsection"],

Cell[CellGroupData[{
Cell[38202, 1118, 126, 3, 42, "Subsubsection"],
Cell[38331, 1123, 194, 4, 43, "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{
Cell[38562, 1132, 176, 3, 28, "Subsubsection"],
Cell[38741, 1137, 205, 4, 43, "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{
Cell[38983, 1146, 121, 3, 28, "Subsubsection"],
Cell[39107, 1151, 145, 3, 27, "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{
Cell[39289, 1159, 348, 6, 43, "Subsubsection"],
Cell[39640, 1167, 135, 3, 27, "Input",
  InitializationCell->True],
Cell[39778, 1172, 340, 6, 59, "Input",
  InitializationCell->True],
Cell[40121, 1180, 1281, 23, 235, "Input",
  InitializationCell->True]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[41451, 1209, 42, 0, 30, "Subsection"],

Cell[CellGroupData[{
Cell[41518, 1213, 728, 11, 88, "Subsubsection"],
Cell[42249, 1226, 537, 8, 78, "Text"],
Cell[42789, 1236, 231, 3, 62, "Text"],
Cell[43023, 1241, 1645, 29, 275, "Input",
  InitializationCell->True]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[44717, 1276, 28, 0, 30, "Subsection"],
Cell[44748, 1278, 107, 3, 43, "Input",
  InitializationCell->True]
}, Closed]]
}, Open  ]]
}
]
*)




(***********************************************************************
End of Mathematica Notebook file.
***********************************************************************)

