(***********************************************************************

                    Mathematica-Compatible Notebook

This notebook can be used on any computer system with Mathematica 4.0,
MathReader 4.0, or any compatible application. The data for the notebook 
starts with the line containing stars above.

To get the notebook into a Mathematica-compatible application, do one of 
the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing the 
word CacheID, otherwise Mathematica-compatible applications may try to 
use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
***********************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[      8786,        289]*)
(*NotebookOutlinePosition[     10900,        351]*)
(*  CellTagsIndexPosition[     10602,        338]*)
(*WindowFrame->Normal*)



Notebook[{

Cell[CellGroupData[{
Cell["An example of an ancestral graph", "SubsubsectionIcon"],

Cell["\<\
This is an example of an ancestral graph consisting of seven \
lineages, arbitrarily labelled {a,b, 3,4, 5,6,7}\
\>", "MathCaption"],

Cell[BoxData[
    \(\(ag = {\[IndentingNewLine]AncestralLineage[
            a, {0, 2}, {{a}}, {R}, {}], \[IndentingNewLine]AncestralLineage[
            b, {0, 2}, {{b}}, {R}, {}], \[IndentingNewLine]AncestralLineage[
            3, {2, 4}, {{a, 
                b}}, {R}, {}], \[IndentingNewLine]AncestralLineage[
            4, {4, 10}, {{a, b}, {}}, {r1, 
              R}, {}], \[IndentingNewLine]AncestralLineage[
            5, {4, 6}, {{}, {a, b}}, {r1, 
              R}, {}], \[IndentingNewLine]AncestralLineage[
            6, {6, 10}, {{}, {a, b}, {}}, {r1, r2, 
              R}, {}], \[IndentingNewLine]AncestralLineage[
            7, {6, 10}, {{}, {a, b}}, {r2, R}, {}]};\)\)], "Input",
  CellLabel->"In[2]:=  (21:09:46 on 5/9/02)"],

Cell["\<\
There is a coalescence between a and b at t=2; a recombination \
event at map position r1, time t=4; and a recombination at map position r2>r1 \
at t=6.\
\>", "Text"]
}, Closed]],

Cell[CellGroupData[{

Cell["Descendants, Ancestors", "SubsubsectionIcon",
  CellTags->{"Descendants", "Ancestors"}],

Cell[TextData[Cell[BoxData[
    FormBox[GridBox[{
          {\(Descendants[{AncestralLineage[\[Ellipsis]] \[Ellipsis]}, 
              l]\), \(lists\ the\ immediate\ descendants\ from\ lineage\ \
l\)},
          {\(Ancestors[{AncestralLineage[\[Ellipsis]] \[Ellipsis]}, 
              l]\), \(lists\ the\ immediate\ ancestors\ of\ lineage\ l\)}
          }], TraditionalForm]]]], "DefinitionBox"],

Cell["\<\
The root lineage 7 has lineage 5 as a descendant, via a \
recombination event:\
\>", "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[
    \(Descendants[ag, 7]\)], "Input",
  CellLabel->"In[113]:=  (21:22:14 on 5/11/02)"],

Cell[BoxData[
    \({5}\)], "Output",
  CellLabel->"Out[113]=  (21:22:14 on 5/11/02)"]
}, Open  ]],

Cell["\<\
Lineage 3 has lineages a, b as descendants, via a coalescence \
event:\
\>", "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[
    \(Descendants[ag, 3]\)], "Input",
  CellLabel->"In[114]:=  (21:22:51 on 5/11/02)"],

Cell[BoxData[
    \({a, b}\)], "Output",
  CellLabel->"Out[114]=  (21:22:51 on 5/11/02)"]
}, Open  ]],

Cell["Lineage 3 has two ancestors, via a recombination event:", "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[
    \(Ancestors[ag, 3]\)], "Input",
  CellLabel->"In[122]:=  (21:31:38 on 5/11/02)"],

Cell[BoxData[
    \({4, 5}\)], "Output",
  CellLabel->"Out[122]=  (21:31:38 on 5/11/02)"]
}, Open  ]],

Cell[TextData[Cell[BoxData[
    FormBox[GridBox[{
          {\(DescendantList \[Rule] All\), \(lists\ all\ descendants\)},
          {\(DescendantList \[Rule] 
              Leaves\), \(\(lists\)\(\ \)\(the\)\(\ \)\(descendant\)\(\ \
\)\(leaves\)\(\ \)\)},
          {\(MapPosition \[Rule] 
              x\), \(restricts\ descendants\ to\ thoise\ at\ map\ position\ x\
\)}
          }], TraditionalForm]]]], "DefinitionBox",
  CellTags->{"DescendantList", "MapPositionD"}],

Cell["These are the descendants from lineage 7:", "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[
    \(Descendants[ag, 7, DescendantList \[Rule] All]\)], "Input",
  CellLabel->"In[115]:=  (21:24:01 on 5/11/02)"],

Cell[BoxData[
    \({7, {{5, {{3, {{a, {}}, {b, {}}}}}}}}\)], "Output",
  CellLabel->"Out[115]=  (21:24:01 on 5/11/02)"]
}, Open  ]],

Cell["\<\
The nested list structure allows for the possibility that a lineage \
may have several descendants.\
\>", "Text"],

Cell["\<\
These are the leaves which ultimately descend from lineage 7:\
\>", \
"MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[
    \(Descendants[ag, 7, DescendantList \[Rule] Leaves]\)], "Input",
  CellLabel->"In[116]:=  (21:25:53 on 5/11/02)"],

Cell[BoxData[
    \({{{a, b}}}\)], "Output",
  CellLabel->"Out[116]=  (21:25:53 on 5/11/02)"]
}, Open  ]],

Cell["Lineage 7 has no descendants left of junction r2=0.6:", "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[
    \(Descendants[ag /. {r1 -> 0.3, r2 -> 0.6, R -> 1}, 7, 
      MapPosition -> 0.4]\)], "Input",
  CellLabel->"In[118]:=  (21:28:35 on 5/11/02)"],

Cell[BoxData[
    \({}\)], "Output",
  CellLabel->"Out[118]=  (21:28:35 on 5/11/02)"]
}, Open  ]],

Cell[TextData[{
  StyleBox["Note: ",
    FontWeight->"Bold"],
  "The junctions must be specified numerically, so that it can be determined \
whether or not map position x is in the relevant segment."
}], "Text"],

Cell[TextData[Cell[BoxData[
    FormBox[GridBox[{
          {\(AncestorList \[Rule] All\), \(lists\ all\ ancestors\)},
          {\(AncestorList \[Rule] 
              Roots\), \(\(lists\)\(\ \)\(the\)\(\ \)\(ancestral\)\(\ \
\)\(roots\)\(\ \)\)},
          {\(MapPosition \[Rule] 
              x\), \(restricts\ ancestors\ to\ those\ at\ map\ position\ x\)}
          }], TraditionalForm]]]], "DefinitionBox",
  CellTags->{"AncestorList", "MapPositionA"}],

Cell["These are the all the ancestors of lineage 3:", "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[
    \(Ancestors[ag, 3, AncestorList \[Rule] All]\)], "Input",
  CellLabel->"In[124]:=  (21:33:44 on 5/11/02)"],

Cell[BoxData[
    \({3, {{4, {}}, {5, {{6, {}}, {7, {}}}}}}\)], "Output",
  CellLabel->"Out[124]=  (21:33:44 on 5/11/02)"]
}, Open  ]],

Cell["\<\
The nested list structure allows for the possibility that a lineage \
may have several ancestors.\
\>", "Text"],

Cell["These are the roots which ultimately lead to lineage 3:", "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[
    \(Ancestors[ag, a, AncestorList \[Rule] Roots]\)], "Input",
  CellLabel->"In[127]:=  (21:34:25 on 5/11/02)"],

Cell[BoxData[
    \(4\)], "Output",
  CellLabel->"Out[127]=  (21:34:25 on 5/11/02)"]
}, Open  ]],

Cell["Lineage 3 has only one ancestor left of junction r2=0.6:", "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[
    \(Ancestors[ag /. {r1 -> 0.3, r2 -> 0.6, R -> 1}, 3, 
      MapPosition -> 0.4]\)], "Input",
  CellLabel->"In[129]:=  (21:35:03 on 5/11/02)"],

Cell[BoxData[
    \({5}\)], "Output",
  CellLabel->"Out[129]=  (21:35:03 on 5/11/02)"]
}, Open  ]],

Cell[TextData[{
  StyleBox["Note: ",
    FontWeight->"Bold"],
  "The junctions must be specified numerically, so that it can be determined \
whether or not map position x is in the relevant segment."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["AddDescendants, AddAncestors", "SubsubsectionIcon"],

Cell[TextData[Cell[BoxData[
    FormBox[GridBox[{
          {\(AddDescendants[{AncestralLineage[\[Ellipsis]] \[Ellipsis]}, 
              l]\), \(returns\ {l, \ Descendants[\[Ellipsis] . l]}\)},
          {\(AddAncestors[{AncestralLineage[\[Ellipsis]] \[Ellipsis]}, 
              l]\), \(returns\ {l, \ Ancestors[\[Ellipsis] . l]}\)}
          }], TraditionalForm]]]], "DefinitionBox",
  CellTags->{"AddDescendants", "AddAncestors"}],

Cell["\<\
These simple modifications of Descendants[], Ancestors[] are used \
internally.\
\>", "Text"]
}, Closed]]
},
FrontEndVersion->"4.0 for Macintosh",
ScreenRectangle->{{0, 1024}, {0, 748}},
WindowSize->{520, 626},
WindowMargins->{{137, Automatic}, {Automatic, 21}},
StyleDefinitions -> "HelpBrowser.nb",
MacintoshSystemPageSetup->"\<\
00h0001804P000000b02<?oaonl3>@91H`85N0?N0@00005X0FP000003j0:l001
0@00I00100000@0200000BL?00400000000000000000010000000000000@0?ne
oj/@7@]500P1000000000000000001T1\>"
]


(***********************************************************************
Cached data follows.  If you edit this Notebook file directly, not using
Mathematica, you must remove the line containing CacheID at the top of 
the file.  The cache data will then be recreated when you save this file 
from within Mathematica.
***********************************************************************)

(*CellTagsOutline
CellTagsIndex->{
  "Descendants"->{
    Cell[2912, 82, 93, 1, 20, "SubsubsectionIcon",
      CellTags->{"Descendants", "Ancestors"}]},
  "Ancestors"->{
    Cell[2912, 82, 93, 1, 20, "SubsubsectionIcon",
      CellTags->{"Descendants", "Ancestors"}]},
  "DescendantList"->{
    Cell[4386, 139, 473, 10, 74, "DefinitionBox",
      CellTags->{"DescendantList", "MapPositionD"}]},
  "MapPositionD"->{
    Cell[4386, 139, 473, 10, 74, "DefinitionBox",
      CellTags->{"DescendantList", "MapPositionD"}]},
  "AncestorList"->{
    Cell[6283, 206, 457, 9, 74, "DefinitionBox",
      CellTags->{"AncestorList", "MapPositionA"}]},
  "MapPositionA"->{
    Cell[6283, 206, 457, 9, 74, "DefinitionBox",
      CellTags->{"AncestorList", "MapPositionA"}]},
  "AddDescendants"->{
    Cell[8230, 274, 434, 7, 54, "DefinitionBox",
      CellTags->{"AddDescendants", "AddAncestors"}]},
  "AddAncestors"->{
    Cell[8230, 274, 434, 7, 54, "DefinitionBox",
      CellTags->{"AddDescendants", "AddAncestors"}]}
  }
*)

(*CellTagsIndex
CellTagsIndex->{
  {"Descendants", 9622, 310},
  {"Ancestors", 9738, 313},
  {"DescendantList", 9859, 316},
  {"MapPositionD", 9983, 319},
  {"AncestorList", 10107, 322},
  {"MapPositionA", 10228, 325},
  {"AddDescendants", 10351, 328},
  {"AddAncestors", 10474, 331}
  }
*)

(*NotebookFileOutline
Notebook[{

Cell[CellGroupData[{
Cell[1739, 51, 61, 0, 24, "SubsubsectionIcon"],
Cell[1803, 53, 142, 3, 28, "MathCaption"],
Cell[1948, 58, 748, 13, 132, "Input"],
Cell[2699, 73, 176, 4, 22, "Text"]
}, Closed]],

Cell[CellGroupData[{
Cell[2912, 82, 93, 1, 20, "SubsubsectionIcon",
  CellTags->{"Descendants", "Ancestors"}],
Cell[3008, 85, 396, 7, 84, "DefinitionBox"],
Cell[3407, 94, 109, 3, 28, "MathCaption"],

Cell[CellGroupData[{
Cell[3541, 101, 100, 2, 27, "Input"],
Cell[3644, 105, 86, 2, 20, "Output"]
}, Open  ]],
Cell[3745, 110, 101, 3, 28, "MathCaption"],

Cell[CellGroupData[{
Cell[3871, 117, 100, 2, 27, "Input"],
Cell[3974, 121, 89, 2, 20, "Output"]
}, Open  ]],
Cell[4078, 126, 78, 0, 28, "MathCaption"],

Cell[CellGroupData[{
Cell[4181, 130, 98, 2, 27, "Input"],
Cell[4282, 134, 89, 2, 20, "Output"]
}, Open  ]],
Cell[4386, 139, 473, 10, 74, "DefinitionBox",
  CellTags->{"DescendantList", "MapPositionD"}],
Cell[4862, 151, 64, 0, 28, "MathCaption"],

Cell[CellGroupData[{
Cell[4951, 155, 128, 2, 27, "Input"],
Cell[5082, 159, 120, 2, 20, "Output"]
}, Open  ]],
Cell[5217, 164, 123, 3, 22, "Text"],
Cell[5343, 169, 94, 3, 28, "MathCaption"],

Cell[CellGroupData[{
Cell[5462, 176, 131, 2, 27, "Input"],
Cell[5596, 180, 93, 2, 20, "Output"]
}, Open  ]],
Cell[5704, 185, 76, 0, 28, "MathCaption"],

Cell[CellGroupData[{
Cell[5805, 189, 161, 3, 27, "Input"],
Cell[5969, 194, 85, 2, 20, "Output"]
}, Open  ]],
Cell[6069, 199, 211, 5, 38, "Text"],
Cell[6283, 206, 457, 9, 74, "DefinitionBox",
  CellTags->{"AncestorList", "MapPositionA"}],
Cell[6743, 217, 68, 0, 28, "MathCaption"],

Cell[CellGroupData[{
Cell[6836, 221, 124, 2, 27, "Input"],
Cell[6963, 225, 122, 2, 20, "Output"]
}, Open  ]],
Cell[7100, 230, 121, 3, 22, "Text"],
Cell[7224, 235, 78, 0, 28, "MathCaption"],

Cell[CellGroupData[{
Cell[7327, 239, 126, 2, 27, "Input"],
Cell[7456, 243, 84, 2, 20, "Output"]
}, Open  ]],
Cell[7555, 248, 79, 0, 28, "MathCaption"],

Cell[CellGroupData[{
Cell[7659, 252, 159, 3, 27, "Input"],
Cell[7821, 257, 86, 2, 20, "Output"]
}, Open  ]],
Cell[7922, 262, 211, 5, 38, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[8170, 272, 57, 0, 24, "SubsubsectionIcon"],
Cell[8230, 274, 434, 7, 54, "DefinitionBox",
  CellTags->{"AddDescendants", "AddAncestors"}],
Cell[8667, 283, 103, 3, 22, "Text"]
}, Closed]]
}
]
*)




(***********************************************************************
End of Mathematica Notebook file.
***********************************************************************)

