(***********************************************************************

                    Mathematica-Compatible Notebook

This notebook can be used on any computer system with Mathematica 4.0,
MathReader 4.0, or any compatible application. The data for the notebook 
starts with the line containing stars above.

To get the notebook into a Mathematica-compatible application, do one of 
the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing the 
word CacheID, otherwise Mathematica-compatible applications may try to 
use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
***********************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[     19940,        573]*)
(*NotebookOutlinePosition[     22188,        634]*)
(*  CellTagsIndexPosition[     21870,        622]*)
(*WindowFrame->Normal*)



Notebook[{

Cell[CellGroupData[{
Cell["An example of an ancestral graph", "SubsubsectionIcon"],

Cell["\<\
This is an example of an ancestral graph consisting of seven \
lineages, arbitrarily labelled {a,b, 3,4, 5,6,7}\
\>", "MathCaption"],

Cell[BoxData[
    \(\(ag = {\[IndentingNewLine]AncestralLineage[
            a, {0, 2}, {{a}}, {R}, {}], \[IndentingNewLine]AncestralLineage[
            b, {0, 2}, {{b}}, {R}, {}], \[IndentingNewLine]AncestralLineage[
            3, {2, 4}, {{a, 
                b}}, {R}, {}], \[IndentingNewLine]AncestralLineage[
            4, {4, 10}, {{a, b}, {}}, {r1, 
              R}, {}], \[IndentingNewLine]AncestralLineage[
            5, {4, 6}, {{}, {a, b}}, {r1, 
              R}, {}], \[IndentingNewLine]AncestralLineage[
            6, {6, 10}, {{}, {a, b}, {}}, {r1, r2, 
              R}, {}], \[IndentingNewLine]AncestralLineage[
            7, {6, 10}, {{}, {a, b}}, {r2, R}, {}]};\)\)], "Input",
  CellLabel->"In[2]:=  (21:09:46 on 5/9/02)"],

Cell["\<\
There is a coalescence between a and b at t=2; a recombination \
event at map position r1, time t=4; and a recombination at map position r2>r1 \
at t=6.\
\>", "Text"]
}, Closed]],

Cell[CellGroupData[{

Cell["CoalesceLineages, AddCoalescentLineage", "SubsubsectionIcon"],

Cell[TextData[Cell[BoxData[
    FormBox[GridBox[{
          {
            RowBox[{
              RowBox[{
                RowBox[{
                  
                  FormBox[\(\(CoalesceLineages\)\([\)\(\(AncestralLineage[
                        l\_1, \[Ellipsis]]\)\(,\)\)\),
                    "TraditionalForm"], 
                  FormBox[\(\(AncestralLineage[l\_1, \[Ellipsis]]\)\(,\)\),
                    "TraditionalForm"], \(l\_12\)}], ",", "t"}], 
              "]"}], \(gives\ a\ lineage\ \(l\_12\) 
              which\ is\ ancestral\ to\ l\_1, \ l\_2, \ 
            generated\ by\ a\ coalescence\ event\ at\ time\ \
\(\(t\)\(.\)\)\)},
          {\(InformationFunction \[Rule] 
              f\), \(generates\ a\ new\ information\ list\ f[info\_1, 
                info\_2]\)}
          }], TraditionalForm]]]], "DefinitionBox",
  CellTags->{
  "CoalesceLineages", "AddCoalescentLineage", "InformationFunctionC"}],

Cell["This generates a lineage ancestral to l1 and l2: ", "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[
    \(CoalesceLineages[AncestralLineage[l1, {2, 10}, {{a}}, {R}, {}], 
      AncestralLineage[l2, {2, 10}, {{b}}, {R}, {}], l12, 4]\)], "Input",
  CellLabel->"In[155]:=  (7:47:33 on 5/12/02)"],

Cell[BoxData[
    RowBox[{"AncestralLineage", "[", 
      RowBox[{"l12", ",", 
        RowBox[{"{", 
          RowBox[{"4", ",", 
            InterpretationBox["\[Infinity]",
              DirectedInfinity[ 1]]}], "}"}], ",", \({{a, b}}\), ",", \({R}\),
         ",", \({}\)}], "]"}]], "Output",
  CellLabel->"Out[155]=  (7:47:33 on 5/12/02)"]
}, Open  ]],

Cell["\<\
The coalescence occurs at time t=4; the ancestral lineage is taken \
to trace back indefinitely, to a root at t=\[Infinity].  The new lineage is \
ancestral to both {a} and {b}.\
\>", "Text"],

Cell["\<\
Here, the two descendant lineages carried several segments, with \
junctions at 0.2, 0.3, 0.6:\
\>", "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[
    \(CoalesceLineages[
      AncestralLineage[l1, {2, 10}, {{a}, {b}}, {0.5, 1}, {}], 
      AncestralLineage[l2, {2, 10}, {{c}, {}, {d, e}}, {0.3, 0.6, 1}, {}], 
      l12, 4]\)], "Input",
  CellLabel->"In[160]:=  (7:51:06 on 5/12/02)"],

Cell[BoxData[
    RowBox[{"AncestralLineage", "[", 
      RowBox[{"l12", ",", 
        RowBox[{"{", 
          RowBox[{"4", ",", 
            InterpretationBox["\[Infinity]",
              DirectedInfinity[ 1]]}], "}"}], 
        ",", \({{a, c}, {a}, {b}, {b, d, e}}\), 
        ",", \({0.3`, 0.5`, 0.6`, 1}\), ",", \({}\)}], "]"}]], "Output",
  CellLabel->"Out[160]=  (7:51:06 on 5/12/02)"]
}, Open  ]],

Cell["\<\
The new lineage carries the junctions present in both descendant \
lineages.\
\>", "Text"],

Cell[TextData[{
  "Note: ",
  StyleBox[" The junctions must be given numerical values, so that the \
junctions of the new lineage can be correctly ordered.",
    FontWeight->"Plain"]
}], "Text",
  FontWeight->"Bold"],

Cell["\<\
By default, information from the two lineages is combined as a set \
of sets:\
\>", "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[
    \(CoalesceLineages[
      AncestralLineage[l1, {2, 10}, {{a}}, {R}, {{I11}, {I12}}], 
      AncestralLineage[l2, {2, 10}, {{b}}, {R}, {{I21}, {I22}}], l12, 
      4]\)], "Input",
  CellLabel->"In[161]:=  (7:53:45 on 5/12/02)"],

Cell[BoxData[
    RowBox[{"AncestralLineage", "[", 
      RowBox[{"l12", ",", 
        RowBox[{"{", 
          RowBox[{"4", ",", 
            InterpretationBox["\[Infinity]",
              DirectedInfinity[ 1]]}], "}"}], ",", \({{a, b}}\), ",", \({R}\),
         ",", \({{{I11}, {I21}}, {{I12}, {I22}}}\)}], "]"}]], "Output",
  CellLabel->"Out[161]=  (7:53:45 on 5/12/02)"]
}, Open  ]],

Cell["An arbitrary  InformationFunction can be supplied:", "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[
    \(CoalesceLineages[
      AncestralLineage[l1, {2, 10}, {{a}}, {R}, {{I11}, {I12}}], 
      AncestralLineage[l2, {2, 10}, {{b}}, {R}, {{I21}, {I22}}], l12, 4, 
      InformationFunction -> f]\)], "Input",
  CellLabel->"In[163]:=  (7:55:10 on 5/12/02)"],

Cell[BoxData[
    RowBox[{"AncestralLineage", "[", 
      RowBox[{"l12", ",", 
        RowBox[{"{", 
          RowBox[{"4", ",", 
            InterpretationBox["\[Infinity]",
              DirectedInfinity[ 1]]}], "}"}], ",", \({{a, b}}\), ",", \({R}\),
         ",", \(f[{{I11}, {I12}}, {{I21}, {I22}}]\)}], "]"}]], "Output",
  CellLabel->"Out[163]=  (7:55:10 on 5/12/02)"]
}, Open  ]],

Cell["The information lists must have the same length:", "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[
    \(CoalesceLineages[AncestralLineage[l1, {2, 10}, {{a}}, {R}, {{I11}}], 
      AncestralLineage[l2, {2, 10}, {{b}}, {R}, {{I21}, {I22}}], l12, 
      4]\)], "Input",
  CellLabel->"In[162]:=  (7:54:37 on 5/12/02)"],

Cell[BoxData[
    \(CoalesceLineages::"badInfoLists" \(\(:\)\(\ \)\) 
      "The information lists associated with the two lineages have different \
lengths."\)], "Message",
  CellLabel->"From In[162]:=  (7:54:37 on 5/12/02)"],

Cell[BoxData[
    \($Failed\)], "Output",
  CellLabel->"Out[162]=  (7:54:40 on 5/12/02)"]
}, Open  ]],

Cell[TextData[Cell[BoxData[
    FormBox[GridBox[{
          {\(AddCoalescentLineage[{AncestralLineage[\[Ellipsis]], \
\[Ellipsis]}, {l\_1, \ l\_2}, l\_12, 
              t]\), \(terminates\ lineages\ {l\_1, \ l\_2}\ at\ time\ t, \ 
            and\ adds\ a 
              "coalescent lineage \!\(l\_12\) to the ancestral graph."\)},
          {\(InformationFunction -> f\), 
            RowBox[{
            "generates", " ", "a", " ", "new", " ", "information", " ", 
              "list", " ", 
              RowBox[{"f", "[", 
                RowBox[{
                  SubscriptBox[
                    StyleBox["info",
                      FontSlant->"Italic"], "1"], ",", 
                  SubscriptBox[
                    StyleBox["info",
                      FontSlant->"Italic"], "2"]}], "]"}]}]}
          }], TraditionalForm]]]], "DefinitionBox"],

Cell["\<\
This adds a new lineage 8, generated by coalescence between \
lineages 4 and 7 at t=9: \
\>", "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[
    \(AddCoalescentLineage[ag, {4, 7}, 8, 9]\)], "Input",
  CellLabel->"In[193]:=  (10:02:46 on 5/12/02)"],

Cell[BoxData[
    RowBox[{"{", 
      RowBox[{\(AncestralLineage[a, {0, 2}, {{a}}, {R}, {}]\), 
        ",", \(AncestralLineage[b, {0, 2}, {{b}}, {R}, {}]\), 
        ",", \(AncestralLineage[3, {2, 4}, {{a, b}}, {R}, {}]\), 
        ",", \(AncestralLineage[4, {4, 9}, {{a, b}, {}}, {r1, R}, {}]\), 
        ",", \(AncestralLineage[5, {4, 6}, {{}, {a, b}}, {r1, R}, {}]\), 
        ",", \(AncestralLineage[
          6, {6, 10}, {{}, {a, b}, {}}, {r1, r2, R}, {}]\), 
        ",", \(AncestralLineage[7, {6, 9}, {{}, {a, b}}, {r2, R}, {}]\), ",", 
        
        RowBox[{"AncestralLineage", "[", 
          RowBox[{"8", ",", 
            RowBox[{"{", 
              RowBox[{"9", ",", 
                InterpretationBox["\[Infinity]",
                  DirectedInfinity[ 1]]}], "}"}], ",", \({{a, b}}\), 
            ",", \({r1}\), ",", \({}\)}], "]"}]}], "}"}]], "Output",
  CellLabel->"Out[193]=  (10:02:46 on 5/12/02)"]
}, Open  ]],

Cell["\<\
The new lineage 8  traces back indefinitely,  to \
t=\[Infinity].\
\>", "Text"],

Cell["\<\
InfomationFunction\[Rule]f has the same effect as in \
CoalesceLineages (see above).\
\>", "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["RecombineLineage, AddRecombinantLineages", "SubsubsectionIcon"],

Cell[TextData[Cell[BoxData[
    FormBox[GridBox[{
          {\(RecombineLineage[AncestralLineage[l, \[Ellipsis]], {lL, lR}, x, 
              t]\), \(generates\ two\ recombinant\ lineages, \ 
            with\ breakpoint\ at\ map\ position\ x, \ and\ labelled\ lL, \ 
            lR\)},
          {\(InformationFunction \[Rule] {fL, 
                fR}\), \(generates\ a\ pair\ of\ information\ lists\ {fL[
                  info], \ fR[info]}\)}
          }], TraditionalForm]]]], "DefinitionBox",
  CellTags->{"RecombineLineage", "InformationFunctionR"}],

Cell["\<\
This gives the two recombinant lineages that are generated by a \
recombination event at t=3, map position x=0.3:\
\>", "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[
    \(RecombineLineage[
      AncestralLineage[l, {0, 10}, {{a}, {b}}, {0.5, 1}, {}], {lL, lR}, 0.3, 
      3]\)], "Input",
  CellLabel->"In[169]:=  (8:00:59 on 5/12/02)"],

Cell[BoxData[
    RowBox[{"{", 
      RowBox[{
        RowBox[{"AncestralLineage", "[", 
          RowBox[{"lL", ",", 
            RowBox[{"{", 
              RowBox[{"3", ",", 
                InterpretationBox["\[Infinity]",
                  DirectedInfinity[ 1]]}], "}"}], ",", \({{a}, {}}\), 
            ",", \({0.3`, 1}\), ",", \({}\)}], "]"}], ",", 
        RowBox[{"AncestralLineage", "[", 
          RowBox[{"lR", ",", 
            RowBox[{"{", 
              RowBox[{"3", ",", 
                InterpretationBox["\[Infinity]",
                  DirectedInfinity[ 1]]}], "}"}], ",", \({{}, {a}, {b}}\), 
            ",", \({0.3`, 0.5`, 1}\), ",", \({}\)}], "]"}]}], "}"}]], "Output",\

  CellLabel->"Out[169]=  (8:00:59 on 5/12/02)"]
}, Open  ]],

Cell["\<\
The new lineages trace back indefinitely,  to t=\[Infinity].\
\>", \
"Text"],

Cell[TextData[{
  "Note: ",
  StyleBox[" The map position and junctions must be given numerical values.",
    FontWeight->"Plain"]
}], "Text",
  FontWeight->"Bold"],

Cell["By default, information lists are duplicated:", "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[
    \(RecombineLineage[
      AncestralLineage[l, {0, 10}, {{a}, {b}}, {0.5, 1}, {{I1}, {I2}}], {lL, 
        lR}, 0.3, 3]\)], "Input",
  CellLabel->"In[170]:=  (8:01:36 on 5/12/02)"],

Cell[BoxData[
    RowBox[{"{", 
      RowBox[{
        RowBox[{"AncestralLineage", "[", 
          RowBox[{"lL", ",", 
            RowBox[{"{", 
              RowBox[{"3", ",", 
                InterpretationBox["\[Infinity]",
                  DirectedInfinity[ 1]]}], "}"}], ",", \({{a}, {}}\), 
            ",", \({0.3`, 1}\), ",", \({{I1}, {I2}}\)}], "]"}], ",", 
        RowBox[{"AncestralLineage", "[", 
          RowBox[{"lR", ",", 
            RowBox[{"{", 
              RowBox[{"3", ",", 
                InterpretationBox["\[Infinity]",
                  DirectedInfinity[ 1]]}], "}"}], ",", \({{}, {a}, {b}}\), 
            ",", \({0.3`, 0.5`, 1}\), ",", \({{I1}, {I2}}\)}], "]"}]}], 
      "}"}]], "Output",
  CellLabel->"Out[170]=  (8:01:36 on 5/12/02)"]
}, Open  ]],

Cell["An arbitrary pair of information functions can be supplied:", \
"MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[
    \(RecombineLineage[
      AncestralLineage[l, {0, 10}, {{a}, {b}}, {0.5, 1}, {{I1}, {I2}}], {lL, 
        lR}, 0.3, 3, InformationFunction -> {fL, fR}]\)], "Input",
  CellLabel->"In[171]:=  (8:02:15 on 5/12/02)"],

Cell[BoxData[
    RowBox[{"{", 
      RowBox[{
        RowBox[{"AncestralLineage", "[", 
          RowBox[{"lL", ",", 
            RowBox[{"{", 
              RowBox[{"3", ",", 
                InterpretationBox["\[Infinity]",
                  DirectedInfinity[ 1]]}], "}"}], ",", \({{a}, {}}\), 
            ",", \({0.3`, 1}\), ",", \(fL[{{I1}, {I2}}]\)}], "]"}], ",", 
        RowBox[{"AncestralLineage", "[", 
          RowBox[{"lR", ",", 
            RowBox[{"{", 
              RowBox[{"3", ",", 
                InterpretationBox["\[Infinity]",
                  DirectedInfinity[ 1]]}], "}"}], ",", \({{}, {a}, {b}}\), 
            ",", \({0.3`, 0.5`, 1}\), ",", \(fR[{{I1}, {I2}}]\)}], "]"}]}], 
      "}"}]], "Output",
  CellLabel->"Out[171]=  (8:02:15 on 5/12/02)"]
}, Open  ]],

Cell[TextData[Cell[BoxData[
    FormBox[GridBox[{
          {\(AddRecombinantLineages[{AncestralLineage[\[Ellipsis]], \
\[Ellipsis]}, l, {lL, lR}, x, t]\), \(terminates\ lineage\ l\ at\ time\ t, \ 
            and\ adds\ two\ recombinant\ lineages\ {lL, \ 
                lR}\ to\ the\ list\)},
          {"\<\"DeleteNullLineages->True\"\>", "\<\"ignores null \
recombination events\"\>"},
          {\(InformationFunction -> {fL, fR}\), 
            RowBox[{
              RowBox[{
              "generates", " ", "new", " ", "information", " ", "lists", " ", 
                
                RowBox[{"fL", "[", 
                  StyleBox["info",
                    FontSlant->"Italic"], "]"}]}], ",", " ", 
              RowBox[{"fR", "[", 
                StyleBox["info",
                  FontSlant->"Italic"], "]"}]}]}
          }], TraditionalForm]]]], "DefinitionBox",
  CellTags->{"AddRecombinantLineages", "DeleteNullLineages"}],

Cell["\<\
This adds two recombinant lineages, generated by an event in \
lineage 7 at t=8: \
\>", "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[
    \(AddRecombinantLineages[ag /. {r1 -> 0.3, r2 -> 0.5, R -> 1}, 7, {8, 9}, 
      0.8, 8]\)], "Input",
  CellLabel->"In[188]:=  (10:01:56 on 5/12/02)"],

Cell[BoxData[
    RowBox[{"{", 
      RowBox[{\(AncestralLineage[a, {0, 2}, {{a}}, {1}, {}]\), 
        ",", \(AncestralLineage[b, {0, 2}, {{b}}, {1}, {}]\), 
        ",", \(AncestralLineage[3, {2, 4}, {{a, b}}, {1}, {}]\), 
        ",", \(AncestralLineage[4, {4, 10}, {{a, b}, {}}, {0.3`, 1}, {}]\), 
        ",", \(AncestralLineage[5, {4, 6}, {{}, {a, b}}, {0.3`, 1}, {}]\), 
        ",", \(AncestralLineage[
          6, {6, 10}, {{}, {a, b}, {}}, {0.3`, 0.5`, 1}, {}]\), 
        ",", \(AncestralLineage[7, {6, 8}, {{}, {a, b}}, {0.5`, 1}, {}]\), 
        ",", 
        RowBox[{"AncestralLineage", "[", 
          RowBox[{"8", ",", 
            RowBox[{"{", 
              RowBox[{"8", ",", 
                InterpretationBox["\[Infinity]",
                  DirectedInfinity[ 1]]}], "}"}], ",", \({{}, {a, b}, {}}\), 
            ",", \({0.5`, 0.8`, 1}\), ",", \({}\)}], "]"}], ",", 
        RowBox[{"AncestralLineage", "[", 
          RowBox[{"9", ",", 
            RowBox[{"{", 
              RowBox[{"8", ",", 
                InterpretationBox["\[Infinity]",
                  DirectedInfinity[ 1]]}], "}"}], ",", \({{}, {a, b}}\), 
            ",", \({0.8`, 1}\), ",", \({}\)}], "]"}]}], "}"}]], "Output",
  CellLabel->"Out[188]=  (10:01:56 on 5/12/02)"]
}, Open  ]],

Cell["\<\
The new lineages trace back indefinitely,  to t=\[Infinity].\
\>", \
"Text"],

Cell[TextData[{
  "Note: ",
  StyleBox[" The map position and junctions must be given numerical values.",
    FontWeight->"Plain"]
}], "Text",
  FontWeight->"Bold"],

Cell["\<\
In this example, one of the new lineages carries no ancestral \
material:\
\>", "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[
    \(AddRecombinantLineages[ag /. {r1 -> 0.3, r2 -> 0.5, R -> 1}, 7, {8, 9}, 
      0.1, 8]\)], "Input",
  CellLabel->"In[189]:=  (10:02:01 on 5/12/02)"],

Cell[BoxData[
    RowBox[{"{", 
      RowBox[{\(AncestralLineage[a, {0, 2}, {{a}}, {1}, {}]\), 
        ",", \(AncestralLineage[b, {0, 2}, {{b}}, {1}, {}]\), 
        ",", \(AncestralLineage[3, {2, 4}, {{a, b}}, {1}, {}]\), 
        ",", \(AncestralLineage[4, {4, 10}, {{a, b}, {}}, {0.3`, 1}, {}]\), 
        ",", \(AncestralLineage[5, {4, 6}, {{}, {a, b}}, {0.3`, 1}, {}]\), 
        ",", \(AncestralLineage[
          6, {6, 10}, {{}, {a, b}, {}}, {0.3`, 0.5`, 1}, {}]\), 
        ",", \(AncestralLineage[7, {6, 8}, {{}, {a, b}}, {0.5`, 1}, {}]\), 
        ",", 
        RowBox[{"AncestralLineage", "[", 
          RowBox[{"8", ",", 
            RowBox[{"{", 
              RowBox[{"8", ",", 
                InterpretationBox["\[Infinity]",
                  DirectedInfinity[ 1]]}], "}"}], ",", \({{}}\), ",", \({1}\),
             ",", \({}\)}], "]"}], ",", 
        RowBox[{"AncestralLineage", "[", 
          RowBox[{"9", ",", 
            RowBox[{"{", 
              RowBox[{"8", ",", 
                InterpretationBox["\[Infinity]",
                  DirectedInfinity[ 1]]}], "}"}], ",", \({{}, {a, b}}\), 
            ",", \({0.5`, 1}\), ",", \({}\)}], "]"}]}], "}"}]], "Output",
  CellLabel->"Out[189]=  (10:02:01 on 5/12/02)"]
}, Open  ]],

Cell["\<\
Setting DeleteNullLineages\[Rule]True ignores such null \
events:\
\>", "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[
    \(AddRecombinantLineages[ag /. {r1 -> 0.3, r2 -> 0.5, R -> 1}, 7, {8, 9}, 
      0.1, 8, DeleteNullLineages -> True]\)], "Input",
  CellLabel->"In[190]:=  (10:02:05 on 5/12/02)"],

Cell[BoxData[
    \({AncestralLineage[a, {0, 2}, {{a}}, {1}, {}], 
      AncestralLineage[b, {0, 2}, {{b}}, {1}, {}], 
      AncestralLineage[3, {2, 4}, {{a, b}}, {1}, {}], 
      AncestralLineage[4, {4, 10}, {{a, b}, {}}, {0.3`, 1}, {}], 
      AncestralLineage[5, {4, 6}, {{}, {a, b}}, {0.3`, 1}, {}], 
      AncestralLineage[6, {6, 10}, {{}, {a, b}, {}}, {0.3`, 0.5`, 1}, {}], 
      AncestralLineage[7, {6, 10}, {{}, {a, b}}, {0.5`, 1}, {}]}\)], "Output",\

  CellLabel->"Out[190]=  (10:02:05 on 5/12/02)"]
}, Open  ]],

Cell["\<\
InfomationFunction\[Rule]{fL,FR} has the same effect as in \
RecombineLineage (see above).\
\>", "Text"]
}, Open  ]]
},
FrontEndVersion->"4.0 for Macintosh",
ScreenRectangle->{{0, 1024}, {0, 748}},
WindowSize->{520, 626},
WindowMargins->{{153, Automatic}, {32, Automatic}},
StyleDefinitions -> "HelpBrowser.nb",
MacintoshSystemPageSetup->"\<\
00h0001804P000000b02<?oaonl3>@91H`85N0?N0@00005X0FP000003j0:l001
0@00I00100000@0200000BL?00400000000000000000010000000000000@0?ne
oj/@7@]500P1000000000000000001T1\>"
]


(***********************************************************************
Cached data follows.  If you edit this Notebook file directly, not using
Mathematica, you must remove the line containing CacheID at the top of 
the file.  The cache data will then be recreated when you save this file 
from within Mathematica.
***********************************************************************)

(*CellTagsOutline
CellTagsIndex->{
  "CoalesceLineages"->{
    Cell[2982, 84, 931, 21, 82, "DefinitionBox",
      CellTags->{
      "CoalesceLineages", "AddCoalescentLineage", "InformationFunctionC"}]},
  "AddCoalescentLineage"->{
    Cell[2982, 84, 931, 21, 82, "DefinitionBox",
      CellTags->{
      "CoalesceLineages", "AddCoalescentLineage", "InformationFunctionC"}]},
  "InformationFunctionC"->{
    Cell[2982, 84, 931, 21, 82, "DefinitionBox",
      CellTags->{
      "CoalesceLineages", "AddCoalescentLineage", "InformationFunctionC"}]},
  "RecombineLineage"->{
    Cell[10482, 308, 557, 10, 70, "DefinitionBox",
      CellTags->{"RecombineLineage", "InformationFunctionR"}]},
  "InformationFunctionR"->{
    Cell[10482, 308, 557, 10, 70, "DefinitionBox",
      CellTags->{"RecombineLineage", "InformationFunctionR"}]},
  "AddRecombinantLineages"->{
    Cell[14622, 429, 942, 20, 90, "DefinitionBox",
      CellTags->{"AddRecombinantLineages", "DeleteNullLineages"}]},
  "DeleteNullLineages"->{
    Cell[14622, 429, 942, 20, 90, "DefinitionBox",
      CellTags->{"AddRecombinantLineages", "DeleteNullLineages"}]}
  }
*)

(*CellTagsIndex
CellTagsIndex->{
  {"CoalesceLineages", 20781, 594},
  {"AddCoalescentLineage", 20953, 598},
  {"InformationFunctionC", 21125, 602},
  {"RecombineLineage", 21293, 606},
  {"InformationFunctionR", 21436, 609},
  {"AddRecombinantLineages", 21581, 612},
  {"DeleteNullLineages", 21726, 615}
  }
*)

(*NotebookFileOutline
Notebook[{

Cell[CellGroupData[{
Cell[1739, 51, 61, 0, 24, "SubsubsectionIcon"],
Cell[1803, 53, 142, 3, 28, "MathCaption"],
Cell[1948, 58, 748, 13, 132, "Input"],
Cell[2699, 73, 176, 4, 22, "Text"]
}, Closed]],

Cell[CellGroupData[{
Cell[2912, 82, 67, 0, 20, "SubsubsectionIcon"],
Cell[2982, 84, 931, 21, 82, "DefinitionBox",
  CellTags->{
  "CoalesceLineages", "AddCoalescentLineage", "InformationFunctionC"}],
Cell[3916, 107, 72, 0, 28, "MathCaption"],

Cell[CellGroupData[{
Cell[4013, 111, 206, 3, 42, "Input"],
Cell[4222, 116, 343, 8, 20, "Output"]
}, Open  ]],
Cell[4580, 127, 201, 4, 36, "Text"],
Cell[4784, 133, 125, 3, 42, "MathCaption"],

Cell[CellGroupData[{
Cell[4934, 140, 252, 5, 42, "Input"],
Cell[5189, 147, 391, 9, 20, "Output"]
}, Open  ]],
Cell[5595, 159, 100, 3, 22, "Text"],
Cell[5698, 164, 216, 6, 38, "Text"],
Cell[5917, 172, 108, 3, 28, "MathCaption"],

Cell[CellGroupData[{
Cell[6050, 179, 244, 5, 42, "Input"],
Cell[6297, 186, 373, 8, 20, "Output"]
}, Open  ]],
Cell[6685, 197, 73, 0, 28, "MathCaption"],

Cell[CellGroupData[{
Cell[6783, 201, 270, 5, 57, "Input"],
Cell[7056, 208, 374, 8, 20, "Output"]
}, Open  ]],
Cell[7445, 219, 71, 0, 28, "MathCaption"],

Cell[CellGroupData[{
Cell[7541, 223, 230, 4, 42, "Input"],
Cell[7774, 229, 226, 4, 33, "Message"],
Cell[8003, 235, 89, 2, 20, "Output"]
}, Open  ]],
Cell[8107, 240, 861, 19, 86, "DefinitionBox"],
Cell[8971, 261, 118, 3, 28, "MathCaption"],

Cell[CellGroupData[{
Cell[9114, 268, 120, 2, 27, "Input"],
Cell[9237, 272, 921, 18, 98, "Output"]
}, Open  ]],
Cell[10173, 293, 89, 3, 22, "Text"],
Cell[10265, 298, 108, 3, 22, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[10410, 306, 69, 0, 24, "SubsubsectionIcon"],
Cell[10482, 308, 557, 10, 70, "DefinitionBox",
  CellTags->{"RecombineLineage", "InformationFunctionR"}],
Cell[11042, 320, 144, 3, 42, "MathCaption"],

Cell[CellGroupData[{
Cell[11211, 327, 185, 4, 27, "Input"],
Cell[11399, 333, 743, 18, 20, "Output"]
}, Open  ]],
Cell[12157, 354, 86, 3, 22, "Text"],
Cell[12246, 359, 164, 5, 24, "Text"],
Cell[12413, 366, 68, 0, 28, "MathCaption"],

Cell[CellGroupData[{
Cell[12506, 370, 197, 4, 27, "Input"],
Cell[12706, 376, 768, 18, 20, "Output"]
}, Open  ]],
Cell[13489, 397, 84, 1, 28, "MathCaption"],

Cell[CellGroupData[{
Cell[13598, 402, 230, 4, 27, "Input"],
Cell[13831, 408, 776, 18, 20, "Output"]
}, Open  ]],
Cell[14622, 429, 942, 20, 90, "DefinitionBox",
  CellTags->{"AddRecombinantLineages", "DeleteNullLineages"}],
Cell[15567, 451, 112, 3, 28, "MathCaption"],

Cell[CellGroupData[{
Cell[15704, 458, 168, 3, 27, "Input"],
Cell[15875, 463, 1264, 25, 59, "Output"]
}, Open  ]],
Cell[17154, 491, 86, 3, 22, "Text"],
Cell[17243, 496, 164, 5, 24, "Text"],
Cell[17410, 503, 104, 3, 28, "MathCaption"],

Cell[CellGroupData[{
Cell[17539, 510, 168, 3, 27, "Input"],
Cell[17710, 515, 1240, 25, 59, "Output"]
}, Open  ]],
Cell[18965, 543, 96, 3, 28, "MathCaption"],

Cell[CellGroupData[{
Cell[19086, 550, 196, 3, 27, "Input"],
Cell[19285, 555, 510, 9, 46, "Output"]
}, Open  ]],
Cell[19810, 567, 114, 3, 22, "Text"]
}, Open  ]]
}
]
*)




(***********************************************************************
End of Mathematica Notebook file.
***********************************************************************)

