(***********************************************************************

                    Mathematica-Compatible Notebook

This notebook can be used on any computer system with Mathematica 4.0,
MathReader 4.0, or any compatible application. The data for the notebook 
starts with the line containing stars above.

To get the notebook into a Mathematica-compatible application, do one of 
the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing the 
word CacheID, otherwise Mathematica-compatible applications may try to 
use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
***********************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[     19554,        672]*)
(*NotebookOutlinePosition[     96824,       3379]*)
(*  CellTagsIndexPosition[     95992,       3352]*)
(*WindowFrame->Normal*)



Notebook[{
Cell["This loads the package:", "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(<< Genealogies`Genealogies`;\)\)], "Input",
  CellLabel->"In[1]:=  (18:47:16 on 5/12/02)"],

Cell[BoxData[
    \(Ordering::"shdw" \(\(:\)\(\ \)\) 
      "Symbol \!\(\"Ordering\"\) appears in multiple contexts \
\!\({\"DiscreteMath`Permutations`\", \"Statistics`DataManipulation`\"}\); \
definitions in context \!\(\"DiscreteMath`Permutations`\"\) may shadow or be \
shadowed by other definitions."\)], "Message",
  CellLabel->"From In[1]:=  (18:47:24 on 5/12/02)"]
}, Open  ]],

Cell[TextData[{
  ButtonBox["Note: ",
    ButtonData:>{"Bugs", "Clashes between packages"},
    ButtonStyle->"AddOnsLink"],
  "The error message Ordering::shdw can be ignored - it arises because the ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " packages DiscreteMath`Permutations`, Statistics`DataManipulation` use the \
same term."
}], "Text"],

Cell[CellGroupData[{

Cell["An example of an ancestral graph", "SubsubsectionIcon"],

Cell["\<\
This is an example of an ancestral graph consisting of seven \
lineages, arbitrarily labelled {a,b, 3,4, 5,6,7}\
\>", "MathCaption"],

Cell[BoxData[
    \(\(ag = {\[IndentingNewLine]AncestralLineage[
            a, {0, 2}, {{a}}, {R}, {}], \[IndentingNewLine]AncestralLineage[
            b, {0, 2}, {{b}}, {R}, {}], \[IndentingNewLine]AncestralLineage[
            3, {2, 4}, {{a, 
                b}}, {R}, {}], \[IndentingNewLine]AncestralLineage[
            4, {4, 10}, {{a, b}, {}}, {r1, 
              R}, {}], \[IndentingNewLine]AncestralLineage[
            5, {4, 6}, {{}, {a, b}}, {r1, 
              R}, {}], \[IndentingNewLine]AncestralLineage[
            6, {6, 10}, {{}, {a, b}, {}}, {r1, r2, 
              R}, {}], \[IndentingNewLine]AncestralLineage[
            7, {6, 10}, {{}, {a, b}}, {r2, R}, {}]};\)\)], "Input",
  CellLabel->"In[2]:=  (21:09:46 on 5/9/02)"],

Cell["\<\
There is a coalescence between a and b at t=2; a recombination \
event at map position r1, time t=4; and a recombination at map position r2>r1 \
at t=6.\
\>", "Text"]
}, Closed]],

Cell[CellGroupData[{

Cell["Junctions, MapLength, Segments", "SubsubsectionIcon"],

Cell[TextData[{
  Cell[BoxData[
      FormBox[GridBox[{
            {\(MapLength[
                AncestralLineage[\[Ellipsis]]]\), \(gives\ the\ map\ length, \
\ R\)}
            }], TraditionalForm]]],
  Cell[BoxData[
      FormBox[GridBox[{
            {\(Junctions[
                AncestralLineage[\[Ellipsis]]]\), \(lists\ the\ junctions\ \
present\ in\ the\ lineage\)},
            {\(Junctions[{AncestralLineage[\[Ellipsis]], \[Ellipsis]}]\), \
\(lists\ all\ the\ junctions\ present\ in\ the\ ancestral\ graph\)}
            }], TraditionalForm]]]
}], "DefinitionBox",
  CellTags->{"Junctions", "MapLength"}],

Cell["These are the junctions:", "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[
    \(Junctions[ag]\)], "Input",
  CellLabel->"In[16]:=  (18:42:11 on 5/9/02)"],

Cell[BoxData[
    \({r1, r2}\)], "Output",
  CellLabel->"Out[16]=  (18:42:11 on 5/9/02)"]
}, Open  ]],

Cell["This is the map length:", "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[
    \(MapLength[ag]\)], "Input",
  CellLabel->"In[20]:=  (18:43:54 on 5/9/02)"],

Cell[BoxData[
    \(R\)], "Output",
  CellLabel->"Out[20]=  (18:43:54 on 5/9/02)"]
}, Open  ]],

Cell["\<\
An error message is given if map lengths are inconsistent across \
lineages:\
\>", "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[
    \(MapLength[{AncestralLineage[
          a, {0, 2}, {{a}}, {2  R}, {}], \[IndentingNewLine]AncestralLineage[
          b, {0, 2}, {{b}}, {R}, {}]}]\)], "Input",
  CellLabel->"In[21]:=  (18:44:39 on 5/9/02)"],

Cell[BoxData[
    \(MapLength::"mixedLengths" \(\(:\)\(\ \)\) 
      "The map lengths \!\({R, \(\(2\\ R\)\)}\) differ among lineages"\)], \
"Message",
  CellLabel->"From In[21]:=  (18:44:39 on 5/9/02)"],

Cell[BoxData[
    \(R\)], "Output",
  CellLabel->"Out[21]=  (18:44:39 on 5/9/02)"]
}, Open  ]],

Cell[TextData[Cell[BoxData[
    FormBox[GridBox[{
          {\(Segments[
              AncestralLineage[\[Ellipsis]]]\), \(gives\ blocks\ ancestral\ \
to\ l\ which\ are\ present\ within\ the\ lineage\)},
          {\(Segments[{AncestralLineage[\[Ellipsis]] \[Ellipsis]}]\), \
\(applies\ to\ several\ lineages\)}
          }], TraditionalForm]]]], "DefinitionBox",
  CellTags->"Segments"],

Cell["\<\
This lineage carries a block {r2,R} which is ancestral to lineage \
a:\
\>", "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[
    \(Segments[AncestralLineage[7, {6, 10}, {{}, {a, b}}, {r2, R}, {}], 
      a]\)], "Input",
  CellLabel->"In[243]:=  (10:40:46 on 5/12/02)"],

Cell[BoxData[
    \({{r2, R}}\)], "Output",
  CellLabel->"Out[243]=  (10:40:47 on 5/12/02)"]
}, Open  ]],

Cell["\<\
This lists all those blocks which are ancestral to lineage a:\
\>", \
"MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[
    \(Segments[ag, a]\)], "Input",
  CellLabel->"In[244]:=  (10:41:57 on 5/12/02)"],

Cell[BoxData[
    \({{{0, R}}, {}, {{0, R}}, {{0, r1}}, {{r1, R}}, {{r1, r2}}, {{r2, 
          R}}}\)], "Output",
  CellLabel->"Out[244]=  (10:41:57 on 5/12/02)"]
}, Open  ]],

Cell["\<\
Each element corresponds to a lineage ({a, b. 2, 3, 4, 5, 6, 7}).  \
All lineages except b carry some material ancestral to leaf a.\
\>", "Text"]
}, Closed]],

Cell[CellGroupData[{

Cell["\<\
TimesOfEvents, AllEvents, CoalescenceEvents, RecombinationEvents, \
NullRecombinationEvents, LeafEvents, RootEvents\
\>", "SubsubsectionIcon",
  InitializationCell->True],

Cell[TextData[{
  " ",
  Cell[BoxData[
      FormBox[GridBox[{
            {\(TimesOfEvents[{AncestralLineage[], \[Ellipsis]}]\), "\<\" \
lists all the times at which lineages begin or end.\"\>"}
            }], TraditionalForm]]]
}], "DefinitionBox",
  CellTags->"TimesOfEvents"],

Cell["These are the times of the various events:", "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[
    \(TimesOfEvents[ag]\)], "Input",
  CellLabel->"In[25]:=  (21:27:46 on 5/9/02)"],

Cell[BoxData[
    \({0, 2, 4, 6, 10}\)], "Output",
  CellLabel->"Out[25]=  (21:27:46 on 5/9/02)"]
}, Open  ]],

Cell[TextData[{
  "Note: ",
  StyleBox[" Each coalescence or recombination event must occur at a unique \
time.  Leaves are usually all at time zero; roots may be at any time.",
    FontWeight->"Plain"]
}], "Text",
  FontWeight->"Bold"],

Cell[TextData[Cell[BoxData[
    FormBox[GridBox[{
          {\(AllEvents[{AncestralLineage[\[Ellipsis]] \[Ellipsis]}]\), \
\(lists\ all\ events, \ 
            in\ the\ form\ {time, descendants, \ ancestors, \ 
                  map\ position} . \ \ The\ last\ element\ is\ set\ if\ there\
\ has\ been\ a\ recombination\ event; \ otherwise\ it\ is\ None\)},
          {\(LeafEvents[{AncestralLineage[\[Ellipsis]] \[Ellipsis]}]\), \
\(gives\ the\ events\ at\ which\ leaves\ are\ found\ \((usually, \ 
                set\ at\ time\ t = 0)\)\)},
          {\(RootEvents[{AncestralLineage[\[Ellipsis]] \[Ellipsis]}]\), \
\(gives\ the\ events\ at\ which\ the\ graph\ is\ \(\(rooted\)\(.\)\)\)},
          {\(CoalescenceEvents[{AncestralLineage[\[Ellipsis]] \
\[Ellipsis]}]\), \(gives\ the\ coalescence\ events\)},
          {\(RecombinationEvents[{AncestralLineage[\[Ellipsis]] \[Ellipsis]}]\
\), \(gives\ the\ recombination\ events\)},
          {\(NullRecombinationEvents[{AncestralLineage[\[Ellipsis]] \
\[Ellipsis]}]\), \(identifies\ recombinations\ which\ generate\ a\ lineage\ \
with\ no\ ancestral\ material\)}
          }], TraditionalForm]]]], "DefinitionBox",
  CellTags->{
  "AllEvents", "CoalescenceEvents", "RecombinationEvents", 
    "NullRecombinationEvents", "LeafEvents", "AllEvents", "CoalescenceEvents",
     "RecombinationEvents", "RootEvents"}],

Cell[CellGroupData[{

Cell[BoxData[
    \(AllEvents[ag]\)], "Input",
  CellLabel->"In[29]:=  (21:32:30 on 5/9/02)"],

Cell[BoxData[
    \({{0, {}, {a, b}, None}, {2, {a, b}, {3}, None}, {4, {3}, {4, 5}, 
        r1}, {6, {5}, {6, 7}, r2}, {10, {4, 6, 7}, {}, None}}\)], "Output",
  CellLabel->"Out[29]=  (21:32:30 on 5/9/02)"]
}, Open  ]],

Cell["\<\
At time zero, the leaves {a,b} begin.  At time 2, there is a \
coalescence; at times 4, 6 there are recombinations; and at time 10, the \
roots occur.\
\>", "Text"],

Cell["This is the single coalescence event:", "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[
    \(CoalescenceEvents[ag]\)], "Input",
  CellLabel->"In[31]:=  (21:34:19 on 5/9/02)"],

Cell[BoxData[
    \({{2, {a, b}, {3}, None}}\)], "Output",
  CellLabel->"Out[31]=  (21:34:19 on 5/9/02)"]
}, Open  ]],

Cell["\<\
These are the two recombination events, which occur at r1, \
r2:\
\>", "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[
    \(RecombinationEvents[ag]\)], "Input",
  CellLabel->"In[32]:=  (21:35:14 on 5/9/02)"],

Cell[BoxData[
    \({{4, {3}, {4, 5}, r1}, {6, {5}, {6, 7}, r2}}\)], "Output",
  CellLabel->"Out[32]=  (21:35:14 on 5/9/02)"]
}, Open  ]],

Cell["This is the event at which the roots enter:", "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[
    \(RootEvents[ag]\)], "Input",
  CellLabel->"In[36]:=  (21:36:28 on 5/9/02)"],

Cell[BoxData[
    \({{10, {4, 6, 7}, {}, None}}\)], "Output",
  CellLabel->"Out[36]=  (21:36:28 on 5/9/02)"]
}, Open  ]],

Cell["This is the event at which the leaves are found:", "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[
    \(LeafEvents[ag]\)], "Input",
  CellLabel->"In[48]:=  (21:41:02 on 5/9/02)"],

Cell[BoxData[
    \({{0, {}, {a, b}, None}}\)], "Output",
  CellLabel->"Out[48]=  (21:41:02 on 5/9/02)"]
}, Open  ]],

Cell["\<\
There are no recombination events which generate lineages without \
ancestral material:\
\>", "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[
    \(NullRecombinationEvents[ag]\)], "Input",
  CellLabel->"In[53]:=  (21:45:00 on 5/9/02)"],

Cell[BoxData[
    \({}\)], "Output",
  CellLabel->"Out[53]=  (21:45:00 on 5/9/02)"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["\<\
LineagesPresent, Leaves, RootLineages, RecombinantLineages, \
CoalescentLineages, NullLineages\
\>", "SubsubsectionIcon",
  CellTags->{
  "LineagesPresent", "Leaves", "RootLineages", "RecombinantLineages", 
    "CoalescentLineages", "NullLineages"}],

Cell[TextData[Cell[BoxData[
    FormBox[GridBox[{
          {\(LineagesPresent[{AncestralLineage[\[Ellipsis]], \[Ellipsis]}, 
              t]\), \(gives\ the\ set\ of\ lineages\ present\ at\ time\ t\)},
          {\(LineagesPresent[{AncestralLineage[\[Ellipsis]], \[Ellipsis]}]\), \
\(lists\ all\ lineages\)},
          {\(Leaves[{AncestralLineage[\[Ellipsis]], \[Ellipsis]}]\), \(gives\ \
the\ leaves\)},
          {\(RootLineages[{AncestralLineage[\[Ellipsis]], \[Ellipsis]}]\), \
\(gives\ the\ roots\)},
          {\(RecombinantLineages[{AncestralLineage[\[Ellipsis]], \
\[Ellipsis]}]\), \(gives\ "lineages which are generated by recombination"\)},
          {\(CoalescentLineages[{AncestralLineage[\[Ellipsis]], \[Ellipsis]}]\
\), \(gives\ "lineages which are generated by coalescence"\)},
          {\(NullLineages[{AncestralLineage[\[Ellipsis]], \[Ellipsis]}]\), \
\(gives\ any\ lineages\ which\ carry\ no\ ancestral\ material\)}
          }], TraditionalForm]]]], "DefinitionBox"],

Cell["These are the leaves:", "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[
    \(Leaves[ag]\)], "Input",
  CellLabel->"In[49]:=  (21:41:47 on 5/9/02)"],

Cell[BoxData[
    \({a, b}\)], "Output",
  CellLabel->"Out[49]=  (21:41:47 on 5/9/02)"]
}, Open  ]],

Cell["These are the roots:", "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[
    \(RootLineages[ag]\)], "Input",
  CellLabel->"In[52]:=  (21:42:29 on 5/9/02)"],

Cell[BoxData[
    \({4, 6, 7}\)], "Output",
  CellLabel->"Out[52]=  (21:42:29 on 5/9/02)"]
}, Open  ]],

Cell["These are all the lineages in the ancestral graph:", "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[
    \(LineagesPresent[ag]\)], "Input",
  CellLabel->"In[24]:=  (18:47:02 on 5/9/02)"],

Cell[BoxData[
    \({a, b, 3, 4, 5, 6, 7}\)], "Output",
  CellLabel->"Out[24]=  (18:47:02 on 5/9/02)"]
}, Open  ]],

Cell["At time t=7, three lineages are present:", "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[
    \(LineagesPresent[ag, 7]\)], "Input",
  CellLabel->"In[26]:=  (18:47:12 on 5/9/02)"],

Cell[BoxData[
    \({4, 6, 7}\)], "Output",
  CellLabel->"Out[26]=  (18:47:12 on 5/9/02)"]
}, Open  ]],

Cell["\<\
These lineages were generated by the two recombination events at \
times t=4 and t=6\
\>", "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[
    \(RecombinantLineages[ag]\)], "Input",
  CellLabel->"In[63]:=  (18:41:08 on 5/11/02)"],

Cell[BoxData[
    \({4, 5, 6, 7}\)], "Output",
  CellLabel->"Out[63]=  (18:41:08 on 5/11/02)"]
}, Open  ]],

Cell["This lineages was generated by the coalescent event at t=2", \
"MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[
    \(CoalescentLineages[ag]\)], "Input",
  CellLabel->"In[68]:=  (18:49:00 on 5/11/02)"],

Cell[BoxData[
    \({3}\)], "Output",
  CellLabel->"Out[68]=  (18:49:00 on 5/11/02)"]
}, Open  ]],

Cell["There are no null lineages in this graph:", "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[
    \(NullLineages[ag]\)], "Input",
  CellLabel->"In[71]:=  (18:50:34 on 5/11/02)"],

Cell[BoxData[
    \({}\)], "Output",
  CellLabel->"Out[71]=  (18:50:34 on 5/11/02)"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["TimespanOfLineage,TimespanOfJunction", "SubsubsectionIcon"],

Cell[TextData[{
  Cell[BoxData[
      FormBox[GridBox[{
            {\(TimespanOfLineage[{AncestralLineage[\[Ellipsis]], \
\[Ellipsis]}, l]\), \(gives\ the\ timespan\ of\ lineage\ l\)}
            }], TraditionalForm]]],
  " ",
  Cell[BoxData[
      FormBox[GridBox[{
            {\(TimespanOfJunction[{AncestralLineage[\[Ellipsis]], \
\[Ellipsis]}, 
                j]\), \(gives\ the\ time\ for\ which\ junction\ j\ is\ \
present\)}
            }], TraditionalForm]]]
}], "DefinitionBox",
  CellTags->{"TimespanOfLineage", "TimespanOfJunction"}],

Cell["Lineage 3 spans t=2 to t=4:", "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[
    \(TimespanOfLineage[ag, 3]\)], "Input",
  CellLabel->"In[73]:=  (18:51:36 on 5/11/02)"],

Cell[BoxData[
    \({2, 4}\)], "Output",
  CellLabel->"Out[73]=  (18:51:36 on 5/11/02)"]
}, Open  ]],

Cell["The pair of junctions at r1 persists from t=4 to t=10:", "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[
    \(TimespanOfJunction[ag, r1]\)], "Input",
  CellLabel->"In[74]:=  (18:51:56 on 5/11/02)"],

Cell[BoxData[
    \({4, 10}\)], "Output",
  CellLabel->"Out[74]=  (18:51:56 on 5/11/02)"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["ExtractLabel, ExtractInformation", "SubsubsectionIcon"],

Cell[TextData[Cell[BoxData[
    FormBox[GridBox[{
          {
            "ExtractLabel", "\<\"is a rule which \
replaces\:f39fAncestralLineage[l,\[Ellipsis]] by its label, l.\"\>"},
          {\(ExtractInformation[{AncestralLineage[\[Ellipsis]], \[Ellipsis]}, 
              l]\), \(gives\ the\ information\ associated\ with\ lineage\ \
l\)},
          {\(ExtractInformation[{AncestralLineage[\[Ellipsis]], \[Ellipsis]}, \
{l\_1, \[Ellipsis]}]\), \(gives\ a\ list\ of\ such\ information\)}
          }], TraditionalForm]]]], "DefinitionBox",
  CellTags->{"ExtractLabel", "ExtractInformation"}],

Cell["This reduces the graph to a list of labels:", "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[
    \(ag /. ExtractLabel\)], "Input",
  CellLabel->"In[15]:=  (18:42:01 on 5/9/02)"],

Cell[BoxData[
    \({a, b, 3, 4, 5, 6, 7}\)], "Output",
  CellLabel->"Out[15]=  (18:42:01 on 5/9/02)"]
}, Open  ]],

Cell["The rule can be applied to a single lineage:", "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[
    \(ag\[LeftDoubleBracket]2\[RightDoubleBracket] /. ExtractLabel\)], "Input",\

  CellLabel->"In[12]:=  (18:37:58 on 5/9/02)"],

Cell[BoxData[
    \(b\)], "Output",
  CellLabel->"Out[12]=  (18:37:58 on 5/9/02)"]
}, Open  ]],

Cell["No information has been defined for lineage 3:", "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[
    \(ExtractInformation[ag, 3]\)], "Input",
  CellLabel->"In[76]:=  (19:19:59 on 5/11/02)"],

Cell[BoxData[
    \({}\)], "Output",
  CellLabel->"Out[76]=  (19:19:59 on 5/11/02)"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["ExtractLineagesStartingAtT, ExtractLineagesEndingAtT", \
"SubsubsectionIcon"],

Cell[TextData[{
  Cell[BoxData[
      FormBox[GridBox[{
            {\(ExtractLineagesStartingAtT[{AncestralLineage[\[Ellipsis]], \
\[Ellipsis]}, 
                t]\), \(gives\ those\ lineages\ which\ start\ at\ time\ t . \ \
\ These\ are\ either\ leaves, \ 
              or\ are\ generated\ by\ a\ coalescence\ or\ \(\(recombination\)\
\(.\)\)\)}
            }], TraditionalForm]]],
  " ",
  Cell[BoxData[
      FormBox[GridBox[{
            {\(ExtractLineagesEndingAtT[{AncestralLineage[\[Ellipsis]], \
\[Ellipsis]}, 
                t]\), \(gives\ those\ lineages\ which\ end\ at\ time\ t . \ \ \
These\ are\ either\ roots, \ 
              or\ are\ generated\ by\ a\ coalescence\ or\ \(\(recombination\)\
\(.\)\)\)}
            }], TraditionalForm]]]
}], "DefinitionBox",
  CellTags->{"ExtractLineagesStartingAtT", "ExtractLineagesEndingAtT"}],

Cell["\<\
These two lineages start at t=4, as a result of a recombination \
event:\
\>", "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[
    \(ExtractLineagesStartingAtT[ag, 4]\)], "Input",
  CellLabel->"In[79]:=  (19:23:07 on 5/11/02)"],

Cell[BoxData[
    \({4, 5}\)], "Output",
  CellLabel->"Out[79]=  (19:23:07 on 5/11/02)"]
}, Open  ]],

Cell["They were generated from lineage 3:", "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[
    \(ExtractLineagesEndingAtT[ag, 4]\)], "Input",
  CellLabel->"In[80]:=  (19:23:47 on 5/11/02)"],

Cell[BoxData[
    \({3}\)], "Output",
  CellLabel->"Out[80]=  (19:23:47 on 5/11/02)"]
}, Open  ]]
}, Closed]]
},
FrontEndVersion->"4.0 for Macintosh",
ScreenRectangle->{{0, 1024}, {0, 748}},
AutoGeneratedPackage->None,
WindowSize->{628, 593},
WindowMargins->{{24, Automatic}, {Automatic, 4}},
Visible->True,
InputAliases->{"notation"->RowBox[ {"Notation", "[", 
        RowBox[ {
          TagBox[ 
          "\[Placeholder]", NotationBoxTag, TagStyle -> 
            "NotationTemplateStyle"], " ", "\[DoubleLongLeftRightArrow]", " ",
           
          TagBox[ 
          "\[Placeholder]", NotationBoxTag, TagStyle -> 
            "NotationTemplateStyle"]}], "]"}], 
    "notation>"->RowBox[ {"Notation", "[", 
        RowBox[ {
          TagBox[ 
          "\[Placeholder]", NotationBoxTag, TagStyle -> 
            "NotationTemplateStyle"], " ", "\[DoubleLongRightArrow]", " ", 
          TagBox[ 
          "\[Placeholder]", NotationBoxTag, TagStyle -> 
            "NotationTemplateStyle"]}], "]"}], 
    "notation<"->RowBox[ {"Notation", "[", 
        RowBox[ {
          TagBox[ 
          "\[Placeholder]", NotationBoxTag, TagStyle -> 
            "NotationTemplateStyle"], " ", "\[DoubleLongLeftArrow]", " ", 
          TagBox[ 
          "\[Placeholder]", NotationBoxTag, TagStyle -> 
            "NotationTemplateStyle"]}], "]"}], 
    "symb"->RowBox[ {"Symbolize", "[", 
        TagBox[ 
        "\[Placeholder]", NotationBoxTag, TagStyle -> 
          "NotationTemplateStyle"], "]"}], 
    "infixnotation"->RowBox[ {"InfixNotation", "[", 
        RowBox[ {
          TagBox[ 
          "\[Placeholder]", NotationBoxTag, TagStyle -> 
            "NotationTemplateStyle"], ",", "\[Placeholder]"}], "]"}], 
    "addia"->RowBox[ {"AddInputAlias", "[", 
        RowBox[ {
          TagBox[ 
          "\[Placeholder]", NotationBoxTag, TagStyle -> 
            "NotationTemplateStyle"], ",", "\[Placeholder]"}], "]"}], 
    "pattwraper"->TagBox[ 
      "\[Placeholder]", NotationPatternTag, TagStyle -> 
        "NotationPatternWrapperStyle"], 
    "madeboxeswraper"->TagBox[ 
      "\[Placeholder]", NotationMadeBoxesTag, TagStyle -> 
        "NotationMadeBoxesWrapperStyle"]},
StyleDefinitions -> Notebook[{
  
  Cell[CellGroupData[{
  Cell["Style Definitions for On-line Help", "Subtitle"],
  
  Cell["\<\
These styles are carefully tuned for all aspects of the online \
help. It's recommended that they remain unchanged.\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell["Style Environment Names", "Subsubsection"],
  
  Cell[StyleData[All, "Working"],
    PageWidth->WindowWidth,
    ShowCellBracket->False,
    ShowAutoStyles->False,
    ScriptMinSize->9],
  
  Cell[StyleData[All, "Brackets"],
    PageWidth->WindowWidth,
    ShowAutoStyles->False,
    ScriptMinSize->9],
  
  Cell[StyleData[All, "Printout"],
    PageWidth->PaperWidth,
    ShowAutoStyles->False,
    ScriptMinSize->5,
    PrivateFontOptions->{"FontType"->"Outline"}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Notebook Options", "Subsubsection"],
  
  Cell["\<\
  The options defined for the style below will be used at the \
Notebook level.  \
\>", "Text"],
  
  Cell[StyleData["Notebook"],
    PageHeaders->{{Cell[ 
            TextData[ {
              CounterBox[ "Page"]}], "PageNumber"], None, Cell[ 
            TextData[ {"Printed from the ", 
              StyleBox[ "Mathematica", FontSlant -> "Italic"], 
              " Help Browser"}], "PageHeader"]}, {Cell[ 
            TextData[ {"Printed from the ", 
              StyleBox[ "Mathematica", FontSlant -> "Italic"], 
              " Help Browser"}], "PageHeader"], None, Cell[ 
            TextData[ {
              CounterBox[ "Page"]}], "PageNumber"]}},
    PageFooters->{{None, Cell[ 
            
            TextData[ {
              "\[Copyright]1999 Wolfram Research, Inc. All rights \
reserved."}], "PageFooter"], None}, {None, Cell[ 
            
            TextData[ {
              "\[Copyright]1999 Wolfram Research, Inc. All rights \
reserved."}], "PageFooter"], None}},
    PageHeaderLines->{True, True},
    PageFooterLines->{True, True},
    PrintingOptions->{"FacingPages"->True},
    CellLabelAutoDelete->False,
    StyleMenuListing->None]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Headings", "Subsubsection"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Chapter"],
    CellMargins->{{10, 4}, {4, 24}},
    ConversionRules:>{"HTML" -> {
      "<FONT SIZE=\"+3\" FACE=\"Helvetica, Arial\"><P><B>", 
      "</B></P></FONT>\n"}},
    InputAutoReplacements->{"TeX"->StyleBox[ 
            RowBox[ {"T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.074999999999999997, \
-0.085000000000000006}, {0, 0}}, BoxBaselineShift -> 0.5], "X"}]], 
        "LaTeX"->StyleBox[ 
            RowBox[ {"L", 
              StyleBox[ 
                AdjustmentBox[ 
                "A", BoxMargins -> {{-0.35999999999999999, \
-0.10000000000000001}, {0, 0}}, BoxBaselineShift -> -0.20000000000000001], 
                FontSize -> Smaller], "T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.074999999999999997, \
-0.085000000000000006}, {0, 0}}, BoxBaselineShift -> 0.5], "X"}]], 
        "mma"->"Mathematica", "Mma"->"Mathematica", "MMA"->"Mathematica"},
    FontFamily->"Helvetica",
    FontSize->24,
    FontWeight->"Bold"],
  
  Cell[StyleData["Chapter", "Printout"],
    CellMargins->{{2, 0}, {0, 18}},
    PageBreakBelow->False,
    FontSize->22]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Section"],
    CellMargins->{{10, 4}, {12, 18}},
    ConversionRules:>{"HTML" -> {
      "<FONT SIZE=\"+2\" FACE=\"Helvetica, Arial\"><P><B>", 
      "</B></P></FONT>\n"}},
    InputAutoReplacements->{"TeX"->StyleBox[ 
            RowBox[ {"T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.074999999999999997, \
-0.085000000000000006}, {0, 0}}, BoxBaselineShift -> 0.5], "X"}]], 
        "LaTeX"->StyleBox[ 
            RowBox[ {"L", 
              StyleBox[ 
                AdjustmentBox[ 
                "A", BoxMargins -> {{-0.35999999999999999, \
-0.10000000000000001}, {0, 0}}, BoxBaselineShift -> -0.20000000000000001], 
                FontSize -> Smaller], "T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.074999999999999997, \
-0.085000000000000006}, {0, 0}}, BoxBaselineShift -> 0.5], "X"}]], 
        "mma"->"Mathematica", "Mma"->"Mathematica", "MMA"->"Mathematica"},
    FontFamily->"Helvetica",
    FontSize->20,
    FontWeight->"Bold"],
  
  Cell[StyleData["Section", "Printout"],
    CellMargins->{{2, 0}, {0, 18}},
    PageBreakBelow->False,
    FontSize->18]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Subsection"],
    CellDingbat->"\[FilledSquare]",
    CellMargins->{{24, 4}, {0, 18}},
    CellElementSpacings->{"ClosedGroupTopMargin"->18},
    ConversionRules:>{"HTML" -> {
      "<LI TYPE=\"SQUARE\"><FONT SIZE=\"+1\" FACE=\"Helvetica, \
Arial\"><P><B>", "</B></P></FONT>\n"}},
    CellFrameLabelMargins->6,
    InputAutoReplacements->{"TeX"->StyleBox[ 
            RowBox[ {"T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.074999999999999997, \
-0.085000000000000006}, {0, 0}}, BoxBaselineShift -> 0.5], "X"}]], 
        "LaTeX"->StyleBox[ 
            RowBox[ {"L", 
              StyleBox[ 
                AdjustmentBox[ 
                "A", BoxMargins -> {{-0.35999999999999999, \
-0.10000000000000001}, {0, 0}}, BoxBaselineShift -> -0.20000000000000001], 
                FontSize -> Smaller], "T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.074999999999999997, \
-0.085000000000000006}, {0, 0}}, BoxBaselineShift -> 0.5], "X"}]], 
        "mma"->"Mathematica", "Mma"->"Mathematica", "MMA"->"Mathematica"},
    FontFamily->"Helvetica",
    FontSize->16,
    FontWeight->"Bold"],
  
  Cell[StyleData["Subsection", "Printout"],
    CellMargins->{{16, 0}, {0, 18}},
    PageBreakBelow->False,
    FontSize->14]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Subsubsection"],
    CellMargins->{{10, 4}, {0, 18}},
    CellElementSpacings->{"ClosedGroupTopMargin"->18},
    ConversionRules:>{"HTML" -> {"<FONT FACE=\"Helvetica, Arial\"><P><B>", 
      "</B></P></FONT>\n"}},
    InputAutoReplacements->{"TeX"->StyleBox[ 
            RowBox[ {"T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.074999999999999997, \
-0.085000000000000006}, {0, 0}}, BoxBaselineShift -> 0.5], "X"}]], 
        "LaTeX"->StyleBox[ 
            RowBox[ {"L", 
              StyleBox[ 
                AdjustmentBox[ 
                "A", BoxMargins -> {{-0.35999999999999999, \
-0.10000000000000001}, {0, 0}}, BoxBaselineShift -> -0.20000000000000001], 
                FontSize -> Smaller], "T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.074999999999999997, \
-0.085000000000000006}, {0, 0}}, BoxBaselineShift -> 0.5], "X"}]], 
        "mma"->"Mathematica", "Mma"->"Mathematica", "MMA"->"Mathematica"},
    FontFamily->"Helvetica",
    FontSize->12,
    FontWeight->"Bold"],
  
  Cell[StyleData["Subsubsection", "Printout"],
    CellMargins->{{2, 0}, {0, 18}},
    PageBreakBelow->False,
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["SubsubsectionColor"],
    CellMargins->{{10, 4}, {0, 18}},
    CellElementSpacings->{"ClosedGroupTopMargin"->18},
    ConversionRules:>{"HTML" -> {
      "<FONT FACE=\"Helvetica, Arial\" COLOR=\"660099\"><P><B>", 
      "</B></P></FONT>\n"}},
    InputAutoReplacements->{"TeX"->StyleBox[ 
            RowBox[ {"T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.074999999999999997, \
-0.085000000000000006}, {0, 0}}, BoxBaselineShift -> 0.5], "X"}]], 
        "LaTeX"->StyleBox[ 
            RowBox[ {"L", 
              StyleBox[ 
                AdjustmentBox[ 
                "A", BoxMargins -> {{-0.35999999999999999, \
-0.10000000000000001}, {0, 0}}, BoxBaselineShift -> -0.20000000000000001], 
                FontSize -> Smaller], "T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.074999999999999997, \
-0.085000000000000006}, {0, 0}}, BoxBaselineShift -> 0.5], "X"}]], 
        "mma"->"Mathematica", "Mma"->"Mathematica", "MMA"->"Mathematica"},
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->12,
    FontWeight->"Bold",
    FontColor->RGBColor[0.297993, 0, 0.454994]],
  
  Cell[StyleData["SubsubsectionColor", "Printout"],
    CellMargins->{{2, 0}, {0, 18}},
    PageBreakBelow->False,
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["SubsectionIcon"],
    ShowGroupOpenCloseIcon->True,
    CellMargins->{{24, 4}, {0, 18}},
    CellElementSpacings->{"ClosedGroupTopMargin"->8},
    CellGroupingRules->{"SectionGrouping", 50},
    ConversionRules:>{"HTML" -> {
      "<LI TYPE=\"SQUARE\"><FONT FACE=\"Helvetica, Arial\"><P><B>", 
      "</B></P></FONT>\n"}},
    InputAutoReplacements->{"TeX"->StyleBox[ 
            RowBox[ {"T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.074999999999999997, \
-0.085000000000000006}, {0, 0}}, BoxBaselineShift -> 0.5], "X"}]], 
        "LaTeX"->StyleBox[ 
            RowBox[ {"L", 
              StyleBox[ 
                AdjustmentBox[ 
                "A", BoxMargins -> {{-0.35999999999999999, \
-0.10000000000000001}, {0, 0}}, BoxBaselineShift -> -0.20000000000000001], 
                FontSize -> Smaller], "T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.074999999999999997, \
-0.085000000000000006}, {0, 0}}, BoxBaselineShift -> 0.5], "X"}]], 
        "mma"->"Mathematica", "Mma"->"Mathematica", "MMA"->"Mathematica"},
    CounterIncrements->"Section",
    FontFamily->"Helvetica",
    FontSize->16,
    FontWeight->"Bold"],
  
  Cell[StyleData["SubsectionIcon", "Printout"],
    CellDingbat->"\[FilledSquare]",
    ShowGroupOpenCloseIcon->False,
    CellMargins->{{16, 0}, {0, 18}},
    PageBreakBelow->False,
    FontSize->14]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["SubsubsectionIcon"],
    ShowGroupOpenCloseIcon->True,
    CellMargins->{{24, 4}, {0, 8}},
    CellElementSpacings->{"ClosedGroupTopMargin"->4},
    CellGroupingRules->{"SectionGrouping", 60},
    ConversionRules:>{"HTML" -> {
      "<LI TYPE=\"SQUARE\"><FONT FACE=\"Helvetica, Arial\"><P><B>", 
      "</B></P></FONT>\n"}},
    InputAutoReplacements->{"TeX"->StyleBox[ 
            RowBox[ {"T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.074999999999999997, \
-0.085000000000000006}, {0, 0}}, BoxBaselineShift -> 0.5], "X"}]], 
        "LaTeX"->StyleBox[ 
            RowBox[ {"L", 
              StyleBox[ 
                AdjustmentBox[ 
                "A", BoxMargins -> {{-0.35999999999999999, \
-0.10000000000000001}, {0, 0}}, BoxBaselineShift -> -0.20000000000000001], 
                FontSize -> Smaller], "T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.074999999999999997, \
-0.085000000000000006}, {0, 0}}, BoxBaselineShift -> 0.5], "X"}]], 
        "mma"->"Mathematica", "Mma"->"Mathematica", "MMA"->"Mathematica"},
    CounterIncrements->"Subsection",
    CounterAssignments->{{"Subsubection", 0}},
    FontFamily->"Helvetica",
    FontSize->12,
    FontWeight->"Bold"],
  
  Cell[StyleData["SubsubsectionIcon", "Printout"],
    ShowGroupOpenCloseIcon->False,
    CellMargins->{{2, 0}, {0, 18}},
    PageBreakBelow->False,
    FontSize->10]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Text", "Subsubsection"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Text"],
    CellMargins->{{10, 4}, {0, 8}},
    ConversionRules:>{"HTML" -> {"<P>", "</P>"}},
    CellHorizontalScrolling->True,
    InputAutoReplacements->{"TeX"->StyleBox[ 
            RowBox[ {"T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.074999999999999997, \
-0.085000000000000006}, {0, 0}}, BoxBaselineShift -> 0.5], "X"}]], 
        "LaTeX"->StyleBox[ 
            RowBox[ {"L", 
              StyleBox[ 
                AdjustmentBox[ 
                "A", BoxMargins -> {{-0.35999999999999999, \
-0.10000000000000001}, {0, 0}}, BoxBaselineShift -> -0.20000000000000001], 
                FontSize -> Smaller], "T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.074999999999999997, \
-0.085000000000000006}, {0, 0}}, BoxBaselineShift -> 0.5], "X"}]], 
        "mma"->"Mathematica", "Mma"->"Mathematica", "MMA"->"Mathematica"},
    Hyphenation->True,
    ParagraphSpacing->{0, 8}],
  
  Cell[StyleData["Text", "Printout"],
    CellMargins->{{2, 0}, {0, 8}},
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["CompactText"],
    CellMargins->{{10, 4}, {0, 8}},
    ConversionRules:>{"HTML" -> {"<FONT SIZE=\"-1\">", "</FONT>\n"}},
    Hyphenation->True,
    ParagraphSpacing->{0, 0},
    StyleMenuListing->None,
    FontSize->10],
  
  Cell[StyleData["CompactText", "Printout"],
    CellMargins->{{2, 0}, {0, 8}},
    FontSize->8]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Compact12Text"],
    CellMargins->{{10, 4}, {0, 8}},
    ConversionRules:>{"HTML" -> {"<P>", "</P>"}},
    Hyphenation->True,
    ParagraphSpacing->{0, 0},
    StyleMenuListing->None],
  
  Cell[StyleData["Compact12Text", "Printout"],
    CellMargins->{{2, 0}, {0, 8}},
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["TextSans"],
    CellMargins->{{10, 4}, {0, 8}},
    ConversionRules:>{"HTML" -> {
      "<FONT SIZE=\"-1\" FACE=\"Helvetica, Arial\">", "</FONT>\n"}},
    CellHorizontalScrolling->True,
    Hyphenation->True,
    ParagraphSpacing->{0, 8},
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->10],
  
  Cell[StyleData["TextSans", "Printout"],
    CellMargins->{{2, 0}, {0, 8}},
    FontSize->8]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["ItemizedText"],
    CellMargins->{{20, 4}, {0, 8}},
    ConversionRules:>{"HTML" -> {"<BLOCKQUOTE>", "</BLOCKQUOTE>"}},
    Hyphenation->True,
    ParagraphSpacing->{0, 8},
    ParagraphIndent->-15,
    StyleMenuListing->None],
  
  Cell[StyleData["ItemizedText", "Printout"],
    CellMargins->{{12, 0}, {0, 8}},
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["ItemizedTextNote"],
    CellMargins->{{35, 4}, {0, 4}},
    ConversionRules:>{"HTML" -> {"<BLOCKQUOTE>", "</BLOCKQUOTE>"}},
    Hyphenation->True,
    ParagraphSpacing->{0, 8},
    StyleMenuListing->None],
  
  Cell[StyleData["ItemizedTextNote", "Printout"],
    CellMargins->{{27, 0}, {0, 4}},
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["IndentedText"],
    CellMargins->{{20, 4}, {0, 6}},
    ConversionRules:>{"HTML" -> {"<BLOCKQUOTE>", "</BLOCKQUOTE>"}},
    Hyphenation->True,
    ParagraphSpacing->{0, 8},
    StyleMenuListing->None],
  
  Cell[StyleData["IndentedText", "Printout"],
    CellMargins->{{12, 0}, {0, 6}},
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["MathCaption"],
    CellDingbat->"\[FilledSmallSquare]",
    CellMargins->{{19, 62}, {0, 14}},
    ConversionRules:>{"HTML" -> {
      "<LI TYPE=\"SQUARE\"><P><FONT COLOR=\"000066\">", "</FONT></P></LI>"}},
    PageBreakBelow->False,
    CellFrameLabelMargins->4,
    Hyphenation->True,
    LineSpacing->{1, 1},
    ParagraphSpacing->{0, 8},
    FontColor->RGBColor[0, 0, 0.4]],
  
  Cell[StyleData["MathCaption", "Printout"],
    CellMargins->{{9, 0}, {0, 14}},
    FontSize->9,
    FontColor->GrayLevel[0]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["SmallText"],
    CellMargins->{{10, 4}, {0, 8}},
    ConversionRules:>{"HTML" -> {"<FONT SIZE=\"1\"><P>", "</P></FONT>"}},
    Hyphenation->True,
    LineSpacing->{1, 3},
    ParagraphSpacing->{0.7, 0},
    CounterIncrements->"SmallText",
    FontSize->9],
  
  Cell[StyleData["SmallText", "Printout"],
    CellMargins->{{2, 0}, {0, 8}},
    TextJustification->1,
    FontSize->7]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Input/Output", "Subsubsection"],
  
  Cell["\<\
The cells in this section define styles used for input and output \
to the kernel.  Be careful when modifying, renaming, or removing these \
styles, because the front end associates special meanings with these style \
names.    \
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Input"],
    ShowCellBracket->True,
    CellMargins->{{46, 4}, {3, 8}},
    Evaluatable->True,
    CellGroupingRules->"InputGrouping",
    PageBreakWithin->False,
    GroupPageBreakWithin->False,
    CellLabelAutoDelete->False,
    CellLabelMargins->{{14, Inherited}, {Inherited, Inherited}},
    DefaultFormatType->DefaultInputFormatType,
    ShowSpecialCharacters->Automatic,
    HyphenationOptions->{"HyphenationCharacter"->"\[Continuation]"},
    LanguageCategory->"Formula",
    FormatType->StandardForm,
    ShowStringCharacters->True,
    NumberMarks->True,
    FontWeight->"Bold"],
  
  Cell[StyleData["Input", "Printout"],
    FontSize->9]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Output"],
    ShowCellBracket->True,
    CellMargins->{{47, 4}, {4, 2}},
    CellEditDuplicate->True,
    CellGroupingRules->"OutputGrouping",
    CellHorizontalScrolling->True,
    PageBreakWithin->False,
    GroupPageBreakWithin->False,
    GeneratedCell->True,
    CellAutoOverwrite->True,
    CellLabelAutoDelete->False,
    CellLabelMargins->{{14, Inherited}, {Inherited, Inherited}},
    DefaultFormatType->DefaultOutputFormatType,
    HyphenationOptions->{"HyphenationCharacter"->"\[Continuation]"},
    LanguageCategory->"Formula",
    FormatType->StandardForm],
  
  Cell[StyleData["Output", "Printout"],
    FontSize->9]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Message"],
    ShowCellBracket->True,
    CellMargins->{{47, 4}, {4, 2}},
    CellGroupingRules->"OutputGrouping",
    PageBreakWithin->False,
    GroupPageBreakWithin->False,
    GeneratedCell->True,
    CellAutoOverwrite->True,
    ShowCellLabel->False,
    CellLabelMargins->{{14, Inherited}, {Inherited, Inherited}},
    DefaultFormatType->DefaultOutputFormatType,
    HyphenationOptions->{"HyphenationCharacter"->"\[Continuation]"},
    FormatType->InputForm,
    StyleMenuListing->None,
    FontColor->RGBColor[0, 0, 1]],
  
  Cell[StyleData["Message", "Printout"],
    FontSize->9,
    FontColor->GrayLevel[0]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Print"],
    ShowCellBracket->True,
    CellMargins->{{47, 4}, {4, 2}},
    CellGroupingRules->"OutputGrouping",
    PageBreakWithin->False,
    GroupPageBreakWithin->False,
    GeneratedCell->True,
    CellAutoOverwrite->True,
    ShowCellLabel->False,
    CellLabelMargins->{{14, Inherited}, {Inherited, Inherited}},
    DefaultFormatType->DefaultOutputFormatType,
    HyphenationOptions->{"HyphenationCharacter"->"\[Continuation]"},
    FormatType->InputForm,
    StyleMenuListing->None],
  
  Cell[StyleData["Print", "Printout"],
    FontSize->9]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Graphics"],
    ShowCellBracket->True,
    CellMargins->{{47, 4}, {4, 2}},
    CellGroupingRules->"GraphicsGrouping",
    PageBreakWithin->False,
    GeneratedCell->True,
    CellAutoOverwrite->True,
    ShowCellLabel->False,
    DefaultFormatType->DefaultFormatTypeForOutput,
    FormatType->InputForm,
    StyleMenuListing->None,
    FontWeight->"Plain"],
  
  Cell[StyleData["Graphics", "Printout"],
    FontSize->9]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["CellLabel"],
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->9,
    FontWeight->"Plain",
    FontColor->RGBColor[0, 0, 1]],
  
  Cell[StyleData["CellLabel", "Printout"],
    FontFamily->"Courier",
    FontSize->7,
    FontSlant->"Italic",
    FontColor->GrayLevel[0]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Name"],
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->9,
    FontWeight->"Plain",
    FontSlant->"Italic",
    FontColor->RGBColor[0, 0, 1]],
  
  Cell[StyleData["Name", "Printout"],
    FontSize->7,
    FontColor->GrayLevel[0]]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Hyperlinks", "Subsubsection"],
  
  Cell["\<\
The cells below define styles useful for making hypertext \
ButtonBoxes.  The \"Hyperlink\" style is for links within the same Notebook, \
or between Notebooks. The others point to the various sections of the help \
browser. These styles will modify individual words or letters in a cell \
exclusive of the cell tag.\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Hyperlink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontColor->RGBColor[0, 0, 1],
    FontVariations->{"Underline"->True},
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`NotebookLocate[ #2]}]&),
    Active->True,
    ButtonFrame->"None",
    ButtonNote->ButtonData}],
  
  Cell[StyleData["Hyperlink", "Printout"],
    FontSize->10,
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["MainBookLink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontColor->RGBColor[0, 0, 1],
    FontVariations->{"Underline"->True},
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`HelpBrowserLookup[ "MainBook", #]}]&),
    Active->True,
    ButtonFrame->"None"}],
  
  Cell[StyleData["MainBookLink", "Printout"],
    FontSize->10,
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["MainBookLinkMR"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontFamily->"Courier",
    FontColor->RGBColor[0, 0, 1],
    FontVariations->{"Underline"->True},
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`HelpBrowserLookup[ "MainBook", #]}]&),
    Active->True,
    ButtonFrame->"None"}],
  
  Cell[StyleData["MainBookLinkMR", "Printout"],
    FontSize->10,
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["AddOnsLink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontFamily->"Courier",
    FontColor->RGBColor[0, 0, 1],
    FontVariations->{"Underline"->True},
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`HelpBrowserLookup[ "AddOns", #]}]&),
    Active->True,
    ButtonFrame->"None"}],
  
  Cell[StyleData["AddOnLink", "Printout"],
    FontSize->10,
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["RefGuideLink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontFamily->"Courier",
    FontColor->RGBColor[0, 0, 1],
    FontVariations->{"Underline"->True},
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`HelpBrowserLookup[ "RefGuideLink", #]}]&),
    Active->True,
    ButtonFrame->"None"}],
  
  Cell[StyleData["RefGuideLink", "Printout"],
    FontSize->10,
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["GettingStartedLink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontColor->RGBColor[0, 0, 1],
    FontVariations->{"Underline"->True},
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`HelpBrowserLookup[ "GettingStarted", #]}]&),
    Active->True,
    ButtonFrame->"None"}],
  
  Cell[StyleData["GettingStartedLink", "Printout"],
    FontSize->10,
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["OtherInformationLink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontColor->RGBColor[0, 0, 1],
    FontVariations->{"Underline"->True},
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`HelpBrowserLookup[ "OtherInformation", #]}]&),
    Active->True,
    ButtonFrame->"None"}],
  
  Cell[StyleData["OtherInformationLink", "Printout"],
    FontSize->10,
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["OtherInformationLinkMR"],
    StyleMenuListing->None,
    FontFamily->"Courier",
    FontColor->RGBColor[0, 0, 1],
    FontVariations->{"Underline"->True},
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`HelpBrowserLookup[ "OtherInformation", #]}]&),
    Active->True,
    ButtonFrame->"None"}],
  
  Cell[StyleData["OtherInformationLinkMR", "Printout"],
    FontSize->10,
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Palette Styles", "Subsubsection"],
  
  Cell["\<\
The cells below define styles that define standard \
ButtonFunctions, for use in palette buttons.\
\>", "Text"],
  
  Cell[StyleData["Paste"],
    StyleMenuListing->Automatic,
    ButtonStyleMenuListing->Automatic,
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`NotebookApply[ 
          FrontEnd`InputNotebook[ ], #, After]}]&)}],
  
  Cell[StyleData["Evaluate"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`NotebookApply[ 
          FrontEnd`InputNotebook[ ], #, All], 
        SelectionEvaluate[ 
          FrontEnd`InputNotebook[ ], All]}]&)}],
  
  Cell[StyleData["EvaluateCell"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`NotebookApply[ 
          FrontEnd`InputNotebook[ ], #, All], 
        FrontEnd`SelectionMove[ 
          FrontEnd`InputNotebook[ ], All, Cell, 1], 
        FrontEnd`SelectionEvaluateCreateCell[ 
          FrontEnd`InputNotebook[ ], All]}]&)}],
  
  Cell[StyleData["CopyEvaluate"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`SelectionCreateCell[ 
          FrontEnd`InputNotebook[ ], All], 
        FrontEnd`NotebookApply[ 
          FrontEnd`InputNotebook[ ], #, All], 
        FrontEnd`SelectionEvaluate[ 
          FrontEnd`InputNotebook[ ], All]}]&)}],
  
  Cell[StyleData["CopyEvaluateCell"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`SelectionCreateCell[ 
          FrontEnd`InputNotebook[ ], All], 
        FrontEnd`NotebookApply[ 
          FrontEnd`InputNotebook[ ], #, All], 
        FrontEnd`SelectionEvaluateCreateCell[ 
          FrontEnd`InputNotebook[ ], All]}]&)}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Inline Formatting", "Subsubsection"],
  
  Cell["\<\
These styles are for modifying individual words or letters in a \
cell exclusive of the cell tag.\
\>", "Text"],
  
  Cell[StyleData["JT"],
    StyleMenuListing->None,
    FontFamily->"JFontText"],
  
  Cell[StyleData["JS"],
    StyleMenuListing->None,
    FontFamily->"JFontSans"],
  
  Cell[StyleData["JSB"],
    StyleMenuListing->None,
    FontFamily->"JFontSansBold"],
  
  Cell[StyleData["RM"],
    StyleMenuListing->None,
    FontWeight->"Plain",
    FontSlant->"Plain"],
  
  Cell[StyleData["BF"],
    StyleMenuListing->None,
    FontWeight->"Bold"],
  
  Cell[StyleData["IT"],
    StyleMenuListing->None,
    FontSlant->"Italic"],
  
  Cell[StyleData["TR"],
    StyleMenuListing->None,
    FontFamily->"Times",
    FontWeight->"Plain",
    FontSlant->"Plain"],
  
  Cell[StyleData["TI"],
    StyleMenuListing->None,
    FontFamily->"Times",
    FontWeight->"Plain",
    FontSlant->"Italic"],
  
  Cell[StyleData["TB"],
    StyleMenuListing->None,
    FontFamily->"Times",
    FontWeight->"Bold",
    FontSlant->"Plain"],
  
  Cell[StyleData["TBI"],
    StyleMenuListing->None,
    FontFamily->"Times",
    FontWeight->"Bold",
    FontSlant->"Italic"],
  
  Cell[StyleData["MR"],
    StyleMenuListing->None,
    FontFamily->"Courier",
    FontWeight->"Plain",
    FontSlant->"Plain"],
  
  Cell[StyleData["MO"],
    StyleMenuListing->None,
    FontFamily->"Courier",
    FontWeight->"Plain",
    FontSlant->"Italic"],
  
  Cell[StyleData["MB"],
    StyleMenuListing->None,
    FontFamily->"Courier",
    FontWeight->"Bold",
    FontSlant->"Plain"],
  
  Cell[StyleData["MBO"],
    StyleMenuListing->None,
    FontFamily->"Courier",
    FontWeight->"Bold",
    FontSlant->"Italic"],
  
  Cell[StyleData["SR"],
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontWeight->"Plain",
    FontSlant->"Plain"],
  
  Cell[StyleData["SO"],
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontWeight->"Plain",
    FontSlant->"Italic"],
  
  Cell[StyleData["SB"],
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontWeight->"Bold",
    FontSlant->"Plain"],
  
  Cell[StyleData["SBO"],
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontWeight->"Bold",
    FontSlant->"Italic"],
  
  Cell[StyleData["M4"],
    ShowCellBracket->True,
    StyleMenuListing->None,
    FontFamily->"Math4",
    CharacterEncoding->"Math4"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["SO10"],
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->10,
    FontWeight->"Plain",
    FontSlant->"Italic"],
  
  Cell[StyleData["SO10", "Printout"],
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->7,
    FontWeight->"Plain",
    FontSlant->"Italic"]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["C1"],
    StyleMenuListing->None,
    FontColor->RGBColor[0.4, 0, 1]],
  
  Cell[StyleData["C1", "Printout"],
    FontColor->GrayLevel[0]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["C1MR"],
    StyleMenuListing->None,
    FontFamily->"Courier",
    FontColor->RGBColor[0.4, 0, 1]],
  
  Cell[StyleData["C1MR", "Printout"],
    FontColor->GrayLevel[0]]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Emphasis Boxes and Pictures", "Subsubsection"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Box"],
    CellMargins->{{10, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    StyleMenuListing->None,
    Background->RGBColor[1, 0.6, 0.6],
    FrameBoxOptions->{BoxMargins->{{1, 1}, {1.5, 1.5}}},
    GridBoxOptions->{ColumnSpacings->1}],
  
  Cell[StyleData["Box", "Printout"],
    CellMargins->{{2, 0}, {0, 8}},
    FontSize->10,
    Background->GrayLevel[0.900008]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["DoubleBox"],
    CellMargins->{{10, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    StyleMenuListing->None,
    Background->RGBColor[1, 0.6, 0.6],
    FrameBoxOptions->{BoxMargins->{{1, 1}, {1.5, 1.5}}},
    GridBoxOptions->{ColumnSpacings->2,
    RowAlignments->Top}],
  
  Cell[StyleData["DoubleBox", "Printout"],
    CellMargins->{{2, 0}, {0, 8}},
    FontSize->10,
    Background->GrayLevel[0.900008]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["1ColumnBox"],
    CellMargins->{{10, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    LineIndent->0,
    StyleMenuListing->None,
    Background->RGBColor[1, 0.6, 0.6],
    FrameBoxOptions->{BoxMargins->{{1, 1}, {1.5, 1.5}}},
    GridBoxOptions->{ColumnSpacings->1}],
  
  Cell[StyleData["1ColumnBox", "Printout"],
    CellMargins->{{2, 0}, {0, 8}},
    FontSize->10,
    Background->GrayLevel[0.900008]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["2ColumnBox"],
    CellMargins->{{10, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    LineIndent->0,
    StyleMenuListing->None,
    Background->RGBColor[1, 0.6, 0.6],
    FrameBoxOptions->{BoxMargins->{{1, 1}, {1.5, 1.5}}},
    GridBoxOptions->{ColumnWidths->{0.31, 0.62}}],
  
  Cell[StyleData["2ColumnBox", "Printout"],
    CellMargins->{{2, 0}, {0, 8}},
    FontSize->10,
    Background->GrayLevel[0.900008]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["2ColumnEvenBox"],
    CellMargins->{{10, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    LineIndent->0,
    StyleMenuListing->None,
    Background->RGBColor[1, 0.6, 0.6],
    FrameBoxOptions->{BoxMargins->{{1, 1}, {1.5, 1.5}}},
    GridBoxOptions->{ColumnWidths->0.46}],
  
  Cell[StyleData["2ColumnEvenBox", "Printout"],
    CellMargins->{{2, 0}, {0, 8}},
    FontSize->10,
    Background->GrayLevel[0.900008]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["2ColumnSmallBox"],
    CellMargins->{{10, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    LineIndent->0,
    StyleMenuListing->None,
    Background->RGBColor[1, 0.6, 0.6],
    FrameBoxOptions->{BoxMargins->{{1, 1}, {1.5, 1.5}}},
    GridBoxOptions->{ColumnSpacings->1.5,
    ColumnWidths->0.35,
    ColumnAlignments->{Right, Left}}],
  
  Cell[StyleData["2ColumnSmallBox", "Printout"],
    CellMargins->{{2, 0}, {0, 8}},
    FontSize->10,
    Background->GrayLevel[0.900008]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["3ColumnBox"],
    CellMargins->{{10, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    LineIndent->0,
    StyleMenuListing->None,
    Background->RGBColor[1, 0.6, 0.6],
    FrameBoxOptions->{BoxMargins->{{1, 1}, {1.5, 1.5}}},
    GridBoxOptions->{ColumnWidths->0.31}],
  
  Cell[StyleData["3ColumnBox", "Printout"],
    CellMargins->{{2, 0}, {0, 8}},
    FontSize->10,
    Background->GrayLevel[0.900008]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["3ColumnSmallBox"],
    CellMargins->{{10, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    LineIndent->0,
    StyleMenuListing->None,
    Background->RGBColor[1, 0.6, 0.6],
    FrameBoxOptions->{BoxMargins->{{1, 1}, {1.5, 1.5}}},
    GridBoxOptions->{ColumnSpacings->1.5,
    ColumnWidths->0.24,
    ColumnAlignments->{Right, Center, Left}}],
  
  Cell[StyleData["3ColumnSmallBox", "Printout"],
    CellMargins->{{2, 0}, {0, 8}},
    FontSize->10,
    Background->GrayLevel[0.900008]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["4ColumnBox"],
    CellMargins->{{10, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    LineIndent->0,
    StyleMenuListing->None,
    Background->RGBColor[1, 0.6, 0.6],
    FrameBoxOptions->{BoxMargins->{{1, 1}, {1.5, 1.5}}},
    GridBoxOptions->{ColumnWidths->{0.13, 0.33, 0.13, 0.33}}],
  
  Cell[StyleData["4ColumnBox", "Printout"],
    CellMargins->{{2, 0}, {0, 8}},
    FontSize->10,
    Background->GrayLevel[0.900008]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["5ColumnBox"],
    CellMargins->{{10, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    LineIndent->0,
    StyleMenuListing->None,
    Background->RGBColor[1, 0.6, 0.6],
    FrameBoxOptions->{BoxMargins->{{1, 1}, {1.5, 1.5}}},
    GridBoxOptions->{ColumnWidths->0.194}],
  
  Cell[StyleData["5ColumnBox", "Printout"],
    CellMargins->{{2, 0}, {0, 8}},
    FontSize->10,
    Background->GrayLevel[0.900008]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["6ColumnBox"],
    CellMargins->{{10, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    LineIndent->0,
    StyleMenuListing->None,
    Background->RGBColor[1, 0.6, 0.6],
    FrameBoxOptions->{BoxMargins->{{1, 1}, {1.5, 1.5}}},
    GridBoxOptions->{ColumnWidths->{0.12, 0.22, 0.12, 0.12, 0.22, 0.12}}],
  
  Cell[StyleData["6ColumnBox", "Printout"],
    CellMargins->{{2, 0}, {0, 8}},
    FontSize->10,
    Background->GrayLevel[0.900008]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["ItemizedNoteBox"],
    CellFrame->0.5,
    CellMargins->{{37, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    LineIndent->0,
    StyleMenuListing->None,
    Background->RGBColor[1, 0.6, 0.6],
    FrameBoxOptions->{BoxMargins->{{1, 1}, {1.5, 1.5}}},
    GridBoxOptions->{ColumnSpacings->1}],
  
  Cell[StyleData["ItemizedNoteBox", "Printout"],
    FontSize->10,
    Background->GrayLevel[0.900008]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["DefinitionBox"],
    CellFrame->0.5,
    CellMargins->{{10, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    AutoIndent->False,
    AutoSpacing->False,
    LineIndent->0,
    FontWeight->"Plain",
    Background->RGBColor[1, 0.6, 0.6],
    GridBoxOptions->{RowSpacings->1.5,
    ColumnSpacings->1,
    ColumnWidths->{0.4, 0.6},
    ColumnAlignments->{Left}}],
  
  Cell[StyleData["DefinitionBox", "Printout"],
    CellMargins->{{2, 4}, {0, 8}},
    FontSize->10,
    Background->GrayLevel[0.900008]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["DefinitionBox3Col"],
    CellFrame->0.5,
    CellMargins->{{10, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    AutoIndent->False,
    AutoSpacing->False,
    LineIndent->0,
    FontWeight->"Plain",
    Background->RGBColor[1, 0.6, 0.6],
    GridBoxOptions->{RowSpacings->1.5,
    ColumnSpacings->1,
    ColumnWidths->{0.35, 0.2, 0.45},
    ColumnAlignments->{Left}}],
  
  Cell[StyleData["DefinitionBox3Col", "Printout"],
    CellMargins->{{2, 4}, {0, 8}},
    FontSize->10,
    Background->GrayLevel[0.900008]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["DefinitionBox4Col"],
    CellFrame->0.5,
    CellMargins->{{10, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    AutoIndent->False,
    AutoSpacing->False,
    LineIndent->0,
    FontWeight->"Plain",
    Background->RGBColor[1, 0.6, 0.6],
    GridBoxOptions->{RowSpacings->1.5,
    ColumnSpacings->1,
    ColumnWidths->{0.15, 0.35, 0.15, 0.35},
    ColumnAlignments->{Left}}],
  
  Cell[StyleData["DefinitionBox4Col", "Printout"],
    CellMargins->{{2, 4}, {0, 8}},
    FontSize->10,
    Background->GrayLevel[0.900008]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["DefinitionBox5Col"],
    CellFrame->0.5,
    CellMargins->{{10, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    AutoIndent->False,
    AutoSpacing->False,
    LineIndent->0,
    FontWeight->"Plain",
    Background->RGBColor[1, 0.6, 0.6],
    GridBoxOptions->{RowSpacings->1.5,
    ColumnSpacings->1,
    ColumnWidths->0.2,
    ColumnAlignments->{Left}}],
  
  Cell[StyleData["DefinitionBox5Col", "Printout"],
    CellMargins->{{2, 4}, {0, 8}},
    FontSize->10,
    Background->GrayLevel[0.900008]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["DefinitionBox6Col"],
    CellFrame->0.5,
    CellMargins->{{10, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    AutoIndent->False,
    AutoSpacing->False,
    LineIndent->0,
    FontWeight->"Plain",
    Background->RGBColor[1, 0.6, 0.6],
    GridBoxOptions->{RowSpacings->1.5,
    ColumnSpacings->1,
    ColumnWidths->{0.13, 0.24, 0.13, 0.13, 0.24, 0.13},
    ColumnAlignments->{Left}}],
  
  Cell[StyleData["DefinitionBox6Col", "Printout"],
    CellMargins->{{2, 4}, {0, 8}},
    FontSize->10,
    Background->GrayLevel[0.900008]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["TopBox"],
    CellFrame->{{0.5, 0.5}, {0, 0.5}},
    CellMargins->{{11, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    PageBreakBelow->False,
    AutoIndent->False,
    AutoSpacing->False,
    LineIndent->0,
    StyleMenuListing->None,
    FontWeight->"Plain",
    Background->RGBColor[1, 0.6, 0.6],
    GridBoxOptions->{RowSpacings->1.5,
    ColumnSpacings->1,
    ColumnWidths->{0.31, 0.62},
    ColumnAlignments->{Left}}],
  
  Cell[StyleData["TopBox", "Printout"],
    CellMargins->{{2, 0}, {0, 8}},
    FontSize->10,
    Background->GrayLevel[0.900008]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["MiddleBox"],
    CellFrame->{{0.5, 0.5}, {0, 0}},
    CellMargins->{{11, 4}, {0, -7}},
    CellHorizontalScrolling->True,
    PageBreakBelow->False,
    AutoIndent->False,
    AutoSpacing->False,
    LineIndent->0,
    StyleMenuListing->None,
    FontWeight->"Plain",
    Background->RGBColor[1, 0.6, 0.6],
    GridBoxOptions->{RowSpacings->1.5,
    ColumnSpacings->1,
    ColumnWidths->{0.31, 0.62},
    ColumnAlignments->{Left}}],
  
  Cell[StyleData["MiddleBox", "Printout"],
    CellMargins->{{2, 0}, {0, 0}},
    FontSize->10,
    Background->GrayLevel[0.900008]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["BottomBox"],
    CellFrame->{{0.5, 0.5}, {0.5, 0}},
    CellMargins->{{11, 4}, {0, -7}},
    CellHorizontalScrolling->True,
    PageBreakBelow->False,
    AutoIndent->False,
    AutoSpacing->False,
    LineIndent->0,
    StyleMenuListing->None,
    FontWeight->"Plain",
    Background->RGBColor[1, 0.6, 0.6],
    GridBoxOptions->{RowSpacings->1.5,
    ColumnSpacings->1,
    ColumnWidths->{0.31, 0.62},
    ColumnAlignments->{Left}}],
  
  Cell[StyleData["BottomBox", "Printout"],
    CellMargins->{{2, 4}, {0, 0}},
    FontSize->10,
    Background->GrayLevel[0.900008]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["TopSpanBox"],
    CellFrame->{{0.5, 0.5}, {0, 0.5}},
    CellMargins->{{11, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    PageBreakBelow->False,
    AutoIndent->False,
    AutoSpacing->False,
    LineIndent->0,
    StyleMenuListing->None,
    FontWeight->"Plain",
    Background->RGBColor[1, 0.6, 0.6],
    GridBoxOptions->{RowSpacings->1.5,
    ColumnSpacings->1,
    ColumnWidths->{0.9, 0.03},
    ColumnAlignments->{Left}}],
  
  Cell[StyleData["TopSpanBox", "Printout"],
    CellMargins->{{2, 0}, {0, 8}},
    FontSize->10,
    Background->GrayLevel[0.900008]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["MiddleSpanBox"],
    CellFrame->{{0.5, 0.5}, {0, 0}},
    CellMargins->{{11, 4}, {0, 0}},
    CellHorizontalScrolling->True,
    PageBreakBelow->False,
    AutoIndent->False,
    AutoSpacing->False,
    LineIndent->0,
    StyleMenuListing->None,
    FontWeight->"Plain",
    Background->RGBColor[1, 0.6, 0.6],
    GridBoxOptions->{RowSpacings->1.5,
    ColumnSpacings->1,
    ColumnWidths->{0.9, 0.03},
    ColumnAlignments->{Left}}],
  
  Cell[StyleData["MiddleSpanBox", "Printout"],
    CellMargins->{{2, 4}, {0, 8}},
    FontSize->10,
    Background->GrayLevel[0.900008]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Picture"],
    CellMargins->{{10, Inherited}, {0, 8}},
    CellHorizontalScrolling->True,
    StyleMenuListing->None],
  
  Cell[StyleData["Picture", "Printout"],
    CellMargins->{{2, 0}, {0, 8}}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["ItemizedPicture"],
    CellMargins->{{35, 4}, {0, 4}},
    CellGroupingRules->"GraphicsGrouping",
    CellHorizontalScrolling->True,
    StyleMenuListing->None],
  
  Cell[StyleData["ItemizedPicture", "Printout"],
    CellMargins->{{27, 0}, {0, 4}},
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["PictureGroup"],
    CellMargins->{{10, Inherited}, {0, 8}},
    CellGroupingRules->"GraphicsGrouping",
    CellHorizontalScrolling->True,
    StyleMenuListing->None],
  
  Cell[StyleData["PictureGroup", "Printout"],
    CellMargins->{{2, 0}, {0, 8}},
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Sound"],
    ShowCellBracket->True,
    CellMargins->{{10, Inherited}, {0, 8}},
    StyleMenuListing->None],
  
  Cell[StyleData["Sound", "Printout"],
    CellMargins->{{2, 0}, {0, 8}},
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Caption"],
    CellMargins->{{10, 4}, {0, 3}},
    PageBreakAbove->False,
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->9],
  
  Cell[StyleData["Caption", "Printout"],
    CellMargins->{{2, 0}, {0, 3}},
    FontSize->7]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Tables", "Subsubsection"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["2ColumnTable"],
    CellMargins->{{10, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    LineIndent->0,
    StyleMenuListing->None,
    GridBoxOptions->{ColumnWidths->{0.34, 0.64},
    ColumnAlignments->{Left}}],
  
  Cell[StyleData["2ColumnTable", "Printout"],
    CellMargins->{{2, 0}, {0, 8}},
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["2ColumnEvenTable"],
    CellMargins->{{10, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    LineIndent->0,
    StyleMenuListing->None,
    GridBoxOptions->{ColumnWidths->0.49,
    ColumnAlignments->{Left}}],
  
  Cell[StyleData["2ColumnEvenTable", "Printout"],
    CellMargins->{{2, 0}, {0, 8}},
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["3ColumnTable"],
    CellMargins->{{10, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    LineIndent->0,
    StyleMenuListing->None,
    GridBoxOptions->{ColumnWidths->{0.28, 0.28, 0.43},
    ColumnAlignments->{Left}}],
  
  Cell[StyleData["3ColumnTable", "Printout"],
    CellMargins->{{2, 0}, {0, 8}},
    FontSize->10]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Formulas and Programming", "Subsubsection"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["InlineFormula"],
    CellMargins->{{10, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    HyphenationOptions->{"HyphenationCharacter"->"\[Continuation]"},
    ScriptLevel->1,
    SingleLetterItalics->True,
    SpanMaxSize->Infinity,
    StyleMenuListing->None,
    GridBoxOptions->{ColumnWidths->Automatic}],
  
  Cell[StyleData["InlineFormula", "Printout"],
    CellMargins->{{2, 0}, {0, 8}},
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["InlineOutput"],
    CellMargins->{{10, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    HyphenationOptions->{"HyphenationCharacter"->"\[Continuation]"},
    StyleMenuListing->None,
    FontFamily->"Courier"],
  
  Cell[StyleData["InlineOutput", "Printout"],
    CellMargins->{{2, 0}, {0, 8}},
    FontSize->9.5]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["DisplayFormula"],
    CellMargins->{{42, Inherited}, {Inherited, 10}},
    CellHorizontalScrolling->True,
    HyphenationOptions->{"HyphenationCharacter"->"\[Continuation]"},
    LanguageCategory->"Formula",
    ScriptLevel->0,
    SingleLetterItalics->True,
    SpanMaxSize->Infinity,
    StyleMenuListing->None,
    UnderoverscriptBoxOptions->{LimitsPositioning->True},
    GridBoxOptions->{ColumnWidths->Automatic}],
  
  Cell[StyleData["DisplayFormula", "Printout"],
    CellMargins->{{34, Inherited}, {Inherited, 10}},
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["DisplayMath"],
    CellMargins->{{42, 10}, {7, 7}},
    Evaluatable->False,
    CellGroupingRules->"InputGrouping",
    CellHorizontalScrolling->True,
    PageBreakWithin->False,
    GroupPageBreakWithin->False,
    DefaultFormatType->DefaultInputFormatType,
    HyphenationOptions->{"HyphenationCharacter"->"\[Continuation]"},
    AutoItalicWords->{},
    LanguageCategory->"Formula",
    FormatType->InputForm,
    ShowStringCharacters->True,
    NumberMarks->True,
    CounterIncrements->"Input"],
  
  Cell[StyleData["DisplayMath", "Printout"],
    CellMargins->{{39, 0}, {6, 6}},
    FontSize->9]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["NumberedEquation"],
    CellMargins->{{42, 10}, {7, 7}},
    CellFrameLabels->{{None, Cell[ 
            TextData[ {"(", 
              CounterBox[ "NumberedEquation"], ")"}]]}, {None, None}},
    DefaultFormatType->DefaultInputFormatType,
    HyphenationOptions->{"HyphenationCharacter"->"\[Continuation]"},
    LanguageCategory->"Formula",
    CounterIncrements->"NumberedEquation",
    FormatTypeAutoConvert->False],
  
  Cell[StyleData["NumberedEquation", "Printout"],
    CellMargins->{{34, 55}, {0, 10}},
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["EquationNumber"],
    LineSpacing->{1.83, 0},
    LanguageCategory->"Formula"],
  
  Cell[StyleData["EquationNumber", "Printout"],
    LineSpacing->{1.7, 0},
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Program"],
    CellMargins->{{16, Inherited}, {Inherited, 10}},
    CellHorizontalScrolling->True,
    LanguageCategory->"Formula",
    StyleMenuListing->None,
    FontFamily->"Courier"],
  
  Cell[StyleData["Program", "Printout"],
    CellMargins->{{8, Inherited}, {Inherited, 10}},
    FontSize->9.5]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Unique Help Browser Styles", "Subsubsection"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["InspectorLevel1"],
    ShowGroupOpenCloseIcon->True,
    CellMargins->{{12, 10}, {2, 7}},
    CellGroupingRules->{"SectionGrouping", 60},
    ParagraphIndent->-38,
    FontFamily->"Helvetica",
    FontSize->16,
    FontWeight->"Bold"],
  
  Cell[StyleData["InspectorLevel1", "Brackets"]],
  
  Cell[StyleData["InspectorLevel1", "Printout"],
    FontSize->14]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["InspectorLevel2"],
    ShowGroupOpenCloseIcon->True,
    CellMargins->{{10, 4}, {0, 14}},
    FontFamily->"Helvetica",
    FontSize->14,
    FontWeight->"Bold"],
  
  Cell[StyleData["InspectorLevel2", "Brackets"],
    ShowGroupOpenCloseIcon->True,
    CellMargins->{{48, 10}, {2, 12}},
    CellGroupingRules->{"SectionGrouping", 70},
    ParagraphIndent->-27,
    FontFamily->"Helvetica",
    FontSize->14,
    FontWeight->"Bold"],
  
  Cell[StyleData["InspectorLevel2", "Printout"],
    FontSize->12]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["ObjectName"],
    CellMargins->{{10, 4}, {1, 10}},
    FontFamily->"Courier",
    FontSize->16,
    FontWeight->"Bold"],
  
  Cell[StyleData["ObjectName", "Brackets"],
    CellMargins->{{72, 4}, {1, 14}},
    CellGroupingRules->{"SectionGrouping", 90},
    StyleMenuListing->None,
    FontFamily->"Courier",
    FontSize->12,
    FontWeight->"Bold"],
  
  Cell[StyleData["ObjectName", "Printout"],
    CellMargins->{{2, 0}, {1, 10}},
    FontSize->12]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["SubObjectNameClosed"],
    ShowGroupOpenCloseIcon->True,
    CellMargins->{{10, 4}, {1, 10}},
    PrivateCellOptions->{"DefaultCellGroupOpen"->False},
    CellGroupingRules->{"SectionGrouping", 90},
    FontFamily->"Courier",
    FontSize->14,
    FontWeight->"Bold"],
  
  Cell[StyleData["SubObjectNameClosed", "Brackets"],
    CellMargins->{{72, 4}, {1, 14}},
    StyleMenuListing->None,
    FontFamily->"Courier",
    FontSize->12,
    FontWeight->"Bold"],
  
  Cell[StyleData["SubObjectNameClosed", "Printout"],
    CellMargins->{{2, 0}, {1, 10}},
    FontSize->12]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["SubObjectName"],
    ShowGroupOpenCloseIcon->True,
    CellMargins->{{24, 4}, {1, 10}},
    FontFamily->"Courier",
    FontSize->16,
    FontWeight->"Bold"],
  
  Cell[StyleData["SubObjectName", "Brackets"],
    ShowGroupOpenCloseIcon->True,
    CellMargins->{{90, 4}, {1, 14}},
    FontFamily->"Courier",
    FontSize->12],
  
  Cell[StyleData["SubObjectName", "Printout"],
    CellMargins->{{2, 0}, {1, 10}},
    FontFamily->"Courier",
    FontSize->12]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["GroupObjectName"],
    ShowGroupOpenCloseIcon->True,
    CellMargins->{{10, 4}, {0, 14}},
    FontFamily->"Courier",
    FontSize->16,
    FontWeight->"Bold"],
  
  Cell[StyleData["GroupObjectName", "Brackets"],
    ShowGroupOpenCloseIcon->True,
    CellMargins->{{72, 10}, {2, 12}},
    CellGroupingRules->{"SectionGrouping", 70},
    ParagraphIndent->-27,
    CounterIncrements->"Outline2",
    FontFamily->"Courier",
    FontSize->12,
    FontWeight->"Bold"],
  
  Cell[StyleData["GroupObjectName", "Printout"],
    FontSize->14]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["GroupObjectNameClosed"],
    ShowGroupOpenCloseIcon->True,
    CellMargins->{{10, 4}, {0, 14}},
    PrivateCellOptions->{"DefaultCellGroupOpen"->False},
    CellGroupingRules->{"SectionGrouping", 80},
    FontFamily->"Courier",
    FontSize->16,
    FontWeight->"Bold"],
  
  Cell[StyleData["GroupObjectNameClosed", "Brackets"],
    ShowGroupOpenCloseIcon->True,
    CellMargins->{{72, 10}, {2, 12}},
    CellGroupingRules->{"SectionGrouping", 70},
    ParagraphIndent->-27,
    CounterIncrements->"Outline2",
    FontFamily->"Courier",
    FontSize->12,
    FontWeight->"Bold"],
  
  Cell[StyleData["GroupObjectNameClosed", "Printout"],
    FontSize->14]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["ObjectNameWarningMessages"],
    CellMargins->{{10, 4}, {1, 10}},
    CellGroupingRules->{"SectionGrouping", 65},
    FontFamily->"Courier",
    FontSize->16,
    FontWeight->"Bold"],
  
  Cell[StyleData["ObjectNameWarningMessages", "Brackets"],
    CellMargins->{{10, 4}, {1, 10}},
    CellGroupingRules->{"SectionGrouping", 65},
    FontFamily->"Courier",
    FontSize->16,
    FontWeight->"Bold"],
  
  Cell[StyleData["ObjectNameWarningMessages", "Printout"],
    CellMargins->{{2, 0}, {1, 10}},
    FontSize->12]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Command"],
    CellMargins->{{10, 4}, {0, 14}},
    CounterIncrements->"Section",
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->16,
    FontWeight->"Bold"],
  
  Cell[StyleData["Command", "Printout"],
    CellMargins->{{2, 0}, {0, 14}},
    PageBreakBelow->False,
    FontSize->14]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["CharacterName"],
    CellFrame->{{0, 0}, {0.5, 0.5}},
    CellMargins->{{10, 4}, {0, 4}},
    CellFrameMargins->4,
    StyleMenuListing->None],
  
  Cell[StyleData["CharacterName", "Brackets"],
    CellMargins->{{72, 4}, {1, 14}},
    CellGroupingRules->{"SectionGrouping", 90},
    StyleMenuListing->None,
    FontFamily->"Courier",
    FontSize->12,
    FontWeight->"Bold"],
  
  Cell[StyleData["CharacterName", "Printout"],
    CellMargins->{{2, 0}, {0, 4}},
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Usage"],
    CellFrame->{{0, 0}, {0.5, 0.5}},
    CellMargins->{{10, 4}, {0, 4}},
    CellFrameMargins->5,
    Hyphenation->True,
    ParagraphSpacing->{0, 6},
    ParagraphIndent->-10,
    StyleMenuListing->None],
  
  Cell[StyleData["Usage", "Brackets"],
    CellFrame->{{0, 0}, {0.5, 0.5}},
    CellMargins->{{72, 4}, {0, 4}},
    CellFrameMargins->5,
    ParagraphSpacing->{0, 6},
    ParagraphIndent->-10,
    StyleMenuListing->None],
  
  Cell[StyleData["Usage", "Printout"],
    CellMargins->{{2, 0}, {0, 4}},
    FontSize->10,
    FontWeight->"Plain"]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["ErrorMessage"],
    CellFrame->{{0, 0}, {0.5, 0.5}},
    ShowCellBracket->True,
    CellMargins->{{10, 4}, {0, 4}},
    CellGroupingRules->"OutputGrouping",
    PageBreakWithin->False,
    GroupPageBreakWithin->False,
    GeneratedCell->True,
    CellAutoOverwrite->True,
    ShowCellLabel->False,
    CellLabelMargins->{{14, Inherited}, {Inherited, Inherited}},
    CellFrameMargins->5,
    DefaultFormatType->DefaultOutputFormatType,
    FormatType->InputForm,
    StyleMenuListing->None,
    FontColor->RGBColor[0, 0, 1]],
  
  Cell[StyleData["ErrorMessage", "Brackets"],
    CellMargins->{{72, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    StyleMenuListing->None],
  
  Cell[StyleData["ErrorMessage", "Printout"],
    FontSize->9,
    FontColor->GrayLevel[0]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Notes"],
    CellMargins->{{10, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    Hyphenation->True,
    ParagraphSpacing->{0, 6},
    ParagraphIndent->-10,
    StyleMenuListing->None,
    FontFamily->"Times"],
  
  Cell[StyleData["Notes", "Brackets"],
    CellMargins->{{72, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    ParagraphSpacing->{0, 6},
    ParagraphIndent->-10,
    StyleMenuListing->None,
    FontFamily->"Times"],
  
  Cell[StyleData["Notes", "Printout"],
    CellMargins->{{2, 0}, {0, 8}},
    FontSize->9]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["NotesList"],
    CellMargins->{{20, 4}, {2, 8}},
    CellHorizontalScrolling->True,
    Hyphenation->True,
    ScriptLevel->1,
    SingleLetterItalics->True,
    StyleMenuListing->None,
    FontFamily->"Times"],
  
  Cell[StyleData["NotesList", "Brackets"],
    CellMargins->{{82, 4}, {2, 8}},
    CellHorizontalScrolling->True,
    ScriptLevel->1,
    SingleLetterItalics->True,
    StyleMenuListing->None,
    FontFamily->"Times"],
  
  Cell[StyleData["NotesList", "Printout"],
    CellMargins->{{12, 0}, {2, 8}},
    FontSize->9]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["ExampleSection"],
    CellFrame->{{0, 0}, {0, 0.5}},
    ShowGroupOpenCloseIcon->True,
    CellMargins->{{11, 4}, {0, 10}},
    CellGroupingRules->{"SectionGrouping", 70},
    CellFrameMargins->12,
    StyleMenuListing->None,
    FontSize->13,
    FontWeight->"Bold",
    FontSlant->"Italic",
    FontColor->RGBColor[0, 0, 0.4]],
  
  Cell[StyleData["ExampleSection", "Printout"],
    CellMargins->{{3, 0}, {0, 10}},
    PageBreakBelow->False,
    FontSize->9,
    FontColor->GrayLevel[0]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["ExampleText"],
    CellMargins->{{20, 40}, {0, 18}},
    Hyphenation->True,
    ParagraphSpacing->{0, 6},
    StyleMenuListing->None,
    FontColor->RGBColor[0, 0, 0.4]],
  
  Cell[StyleData["ExampleText", "Printout"],
    CellMargins->{{2, 80}, {0, 8}},
    PageBreakBelow->False,
    FontSize->8,
    FontColor->GrayLevel[0]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["ExampleSubsection"],
    ShowCellBracket->True,
    CellMargins->{{20, 4}, {0, 16}},
    CellGroupingRules->{"SectionGrouping", 80},
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->10,
    FontWeight->"Bold"],
  
  Cell[StyleData["ExampleSubsection", "Printout"],
    CellMargins->{{12, 0}, {0, 16}},
    PageBreakBelow->False,
    FontSize->7]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["LineHead"],
    CellFrame->{{0, 0}, {0.5, 0}},
    CellMargins->{{10, 4}, {8, 18}},
    CounterIncrements->"Subsection",
    CounterAssignments->{{"Subsubection", 0}},
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->12,
    FontWeight->"Bold"],
  
  Cell[StyleData["LineHead", "Printout"],
    CellMargins->{{2, 0}, {8, 18}},
    PageBreakBelow->False,
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["FlushInput"],
    CellMargins->{{10, 4}, {1, 4}},
    Evaluatable->True,
    CellGroupingRules->"InputGrouping",
    CellHorizontalScrolling->True,
    PageBreakWithin->False,
    GroupPageBreakWithin->False,
    CellLabelAutoDelete->False,
    CellLabelMargins->{{23, Inherited}, {Inherited, Inherited}},
    DefaultFormatType->DefaultInputFormatType,
    ShowSpecialCharacters->Automatic,
    FormatType->StandardForm,
    ShowStringCharacters->True,
    NumberMarks->True,
    StyleMenuListing->None,
    FontWeight->"Bold"],
  
  Cell[StyleData["FlushInput", "Printout"],
    CellMargins->{{2, 0}, {1, 4}},
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["FlushOutput"],
    CellMargins->{{10, Inherited}, {Inherited, Inherited}},
    CellEditDuplicate->True,
    CellGroupingRules->"OutputGrouping",
    CellHorizontalScrolling->True,
    PageBreakWithin->False,
    GroupPageBreakWithin->False,
    GeneratedCell->True,
    CellAutoOverwrite->True,
    CellLabelAutoDelete->False,
    CellLabelMargins->{{23, Inherited}, {Inherited, Inherited}},
    DefaultFormatType->DefaultOutputFormatType,
    FormatType->StandardForm,
    StyleMenuListing->None],
  
  Cell[StyleData["FlushOutput", "Printout"],
    CellMargins->{{2, Inherited}, {Inherited, Inherited}},
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["DialogItem"],
    CellDingbat->"\[EmptyDiamond]",
    CellMargins->{{20, 4}, {0, 12}},
    CellGroupingRules->{"SectionGrouping", 70},
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->10,
    FontWeight->"Bold"],
  
  Cell[StyleData["DialogItem", "Printout"],
    CellMargins->{{12, 0}, {0, 12}},
    PageBreakBelow->False,
    FontSize->8]
  }, Closed]],
  
  Cell[StyleData["GroupDivider"],
    CellMargins->{{10, Inherited}, {Inherited, Inherited}},
    CellEditDuplicate->True,
    CellGroupingRules->{"TitleGrouping", 0},
    StyleMenuListing->None],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Highlight"],
    CellMargins->{{10, 4}, {0, 18}},
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->12,
    Background->GrayLevel[0.900008]],
  
  Cell[StyleData["Highlight", "Printout"],
    CellMargins->{{2, 0}, {0, 18}},
    LineSpacing->{1, 3}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["UserNotes"],
    CellFrame->{{2, 0}, {0, 0.25}},
    CellMargins->{{10, 4}, {0, 4}},
    Hyphenation->True,
    ParagraphIndent->-7,
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->10],
  
  Cell[StyleData["UserNotes", "Printout"],
    CellMargins->{{2, 0}, {0, 4}},
    LineSpacing->{1, 3},
    FontSize->8]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["MoreInfo"],
    CellMargins->{{10, 4}, {0, 4}},
    Hyphenation->True,
    ParagraphIndent->-7,
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->10,
    FontColor->GrayLevel[1],
    Background->RGBColor[0.700008, 0.4, 0.100008]],
  
  Cell[StyleData["MoreInfo", "Printout"],
    CellMargins->{{2, 0}, {0, 4}},
    LineSpacing->{1, 3},
    FontSize->8]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["UserTips"],
    CellFrame->{{2, 0}, {0, 0.25}},
    CellMargins->{{10, 4}, {0, 4}},
    Hyphenation->True,
    ParagraphIndent->-7,
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->10,
    FontColor->GrayLevel[1],
    Background->RGBColor[0.2, 0.500008, 0.700008]],
  
  Cell[StyleData["UserTips", "Printout"],
    CellMargins->{{2, 0}, {0, 4}},
    LineSpacing->{1, 3},
    FontSize->8,
    Background->GrayLevel[0.700008]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Theorem"],
    CellFrame->{{4, 0}, {0, 0}},
    CellMargins->{{12, 62}, {0, 14}},
    CellFrameMargins->4,
    CellFrameColor->RGBColor[0, 0, 0.8],
    LineSpacing->{1, 1},
    ParagraphSpacing->{0, 8}],
  
  Cell[StyleData["Theorem", "Printout"],
    CellMargins->{{2, 0}, {0, 14}},
    CellFrameMargins->3,
    CellFrameColor->GrayLevel[0.8],
    FontSize->9,
    FontColor->GrayLevel[0]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Commentary"],
    CellFrame->{{2, 0}, {0, 0}},
    CellMargins->{{36, 10}, {7, 7}},
    PageBreakBelow->False,
    CellFrameMargins->8,
    CellFrameColor->RGBColor[0, 0.2, 1],
    Hyphenation->True,
    LineSpacing->{1, 3},
    ParagraphSpacing->{0, 8},
    FontSlant->"Italic"],
  
  Cell[StyleData["Commentary", "Printout"],
    CellMargins->{{32, 0}, {6, 6}},
    CellFrameColor->GrayLevel[0.8],
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Level1Icon"],
    ShowGroupOpenCloseIcon->True,
    CellMargins->{{10, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    ParagraphSpacing->{0, 8},
    StyleMenuListing->None],
  
  Cell[StyleData["Level1Icon", "Printout"],
    CellMargins->{{2, 0}, {0, 8}},
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Level2Icon"],
    ShowGroupOpenCloseIcon->True,
    CellMargins->{{10, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    ParagraphSpacing->{0, 8},
    StyleMenuListing->None],
  
  Cell[StyleData["Level2Icon", "Printout"],
    CellMargins->{{2, 0}, {0, 8}},
    FontSize->10]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Contents and Index", "Subsubsection"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["ContentsTitle"],
    CellMargins->{{10, 4}, {0, 18}},
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->18,
    FontWeight->"Bold"],
  
  Cell[StyleData["ContentsTitle", "Printout"],
    CellMargins->{{2, 0}, {0, 18}},
    PageBreakBelow->False,
    FontSize->18]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["ContentsSection"],
    CellDingbat->"\[FilledSquare]",
    CellMargins->{{20, 4}, {3, 18}},
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->12,
    FontWeight->"Bold"],
  
  Cell[StyleData["ContentsSection", "Printout"],
    CellMargins->{{12, 0}, {3, 18}},
    PageBreakBelow->False]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["IndexSection"],
    CellDingbat->"\[FilledSquare]",
    CellMargins->{{20, 4}, {5, 20}},
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->12,
    FontWeight->"Bold"],
  
  Cell[StyleData["IndexSection", "Printout"],
    CellMargins->{{12, 0}, {5, 20}},
    PageBreakBelow->False,
    FontSize->12]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Contents"],
    CellMargins->{{21, 4}, {0, 8}},
    StyleMenuListing->None],
  
  Cell[StyleData["Contents", "Printout"],
    CellMargins->{{13, 0}, {0, 8}},
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Index"],
    CellMargins->{{21, 4}, {0, 0}},
    ParagraphIndent->-48,
    StyleMenuListing->None],
  
  Cell[StyleData["Index", "Printout"],
    CellMargins->{{13, 0}, {0, 0}},
    FontSize->9]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["IndexSubentry"],
    CellMargins->{{36, 4}, {0, 0}},
    ParagraphIndent->-48,
    StyleMenuListing->None],
  
  Cell[StyleData["IndexSubentry", "Printout"],
    CellMargins->{{24, 0}, {0, 0}},
    FontSize->9]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Horizontal Lines", "Subsubsection"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Line1"],
    CellFrame->{{0, 0}, {0, 0.5}},
    CellMargins->{{10, 4}, {-16, 9}},
    StyleMenuListing->None,
    FontSize->2],
  
  Cell[StyleData["Line1", "Printout"],
    CellMargins->{{2, 0}, {-16, 9}}]
  }, Closed]],
  
  Cell["\<\

The item above is horizontal 0.5 pt line\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["ProgramTop"],
    CellFrame->{{0.5, 0.5}, {0, 0.5}},
    CellMargins->{{10, 4}, {-18, 18}},
    LineSpacing->{1, -4},
    StyleMenuListing->None,
    FontSize->4],
  
  Cell[StyleData["ProgramTop", "Printout"],
    CellMargins->{{2, 0}, {-18, 18}}]
  }, Closed]],
  
  Cell["\<\

The item above is a ProgramTop line
\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["ProgramBottom"],
    CellFrame->{{0.5, 0.5}, {0.5, 0}},
    CellMargins->{{10, 4}, {-10, -2}},
    LineSpacing->{1, -4},
    StyleMenuListing->None,
    FontSize->4],
  
  Cell[StyleData["ProgramBottom", "Printout"],
    CellMargins->{{2, 0}, {-10, -2}}]
  }, Closed]],
  
  Cell["\<\

The item above is a ProgramBottom line
\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["SessionLabel"],
    CellFrame->{{0.5, 0}, {0, 0.5}},
    CellMargins->{{10, 4}, {-4, 18}},
    LineSpacing->{1, -3},
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->9],
  
  Cell[StyleData["SessionLabel", "Printout"],
    CellMargins->{{2, 0}, {-4, 18}},
    FontSize->7]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Page Headers and Footers", "Subsubsection"],
  
  Cell[StyleData["PageHeader"],
    CellMargins->{{0, 0}, {2, 0}},
    StyleMenuListing->None,
    FontSize->8,
    FontSlant->"Italic"],
  
  Cell[StyleData["PageNumber"],
    CellMargins->{{0, 0}, {2, 0}},
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->8,
    FontWeight->"Bold"],
  
  Cell[StyleData["PageFooter"],
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->6]
  }, Closed]]
  }, Open  ]],
  
  Cell[CellGroupData[{
  
  Cell["Notation Package Styles", "Section",
    GeneratedCell->True,
    CellTags->"NotationPackage"],
  
  Cell["\<\
The cells below define certain styles needed by the Notation \
package. These styles serve to make visible otherwise invisible \
tagboxes.\
\>", "Text",
    GeneratedCell->True,
    CellTags->"NotationPackage"],
  
  Cell[StyleData["NotationTemplateStyle"],
    GeneratedCell->True,
    StyleMenuListing->None,
    Background->RGBColor[1, 1, 0.850004],
    TagBoxOptions->{SyntaxForm->"symbol"},
    CellTags->"NotationPackage"],
  
  Cell[StyleData["NotationPatternWrapperStyle"],
    GeneratedCell->True,
    StyleMenuListing->None,
    Background->RGBColor[1, 0.900008, 0.979995],
    TagBoxOptions->{SyntaxForm->"symbol"},
    CellTags->"NotationPackage"],
  
  Cell[StyleData["NotationMadeBoxesWrapperStyle"],
    GeneratedCell->True,
    StyleMenuListing->None,
    Background->RGBColor[0.900008, 0.889998, 1],
    TagBoxOptions->{SyntaxForm->"symbol"},
    CellTags->"NotationPackage"]
  }, Closed]]
  }],
MacintoshSystemPageSetup->"\<\
00h0001804P000000b02<?oaonl3>@91H`85N0?N0@00005X0FP000003j0:l001
0@00I00100000@0200000BL?00400000000000000000010000000000000@0?ne
oj/@7@]500P1000000000000000001T1\>"
]


(***********************************************************************
Cached data follows.  If you edit this Notebook file directly, not using
Mathematica, you must remove the line containing CacheID at the top of 
the file.  The cache data will then be recreated when you save this file 
from within Mathematica.
***********************************************************************)

(*CellTagsOutline
CellTagsIndex->{
  "Junctions"->{
    Cell[3906, 112, 616, 16, 83, "DefinitionBox",
      CellTags->{"Junctions", "MapLength"}]},
  "MapLength"->{
    Cell[3906, 112, 616, 16, 83, "DefinitionBox",
      CellTags->{"Junctions", "MapLength"}]},
  "Segments"->{
    Cell[5723, 180, 387, 8, 54, "DefinitionBox",
      CellTags->"Segments"]},
  "TimesOfEvents"->{
    Cell[7278, 238, 280, 8, 39, "DefinitionBox",
      CellTags->"TimesOfEvents"]},
  "AllEvents"->{
    Cell[8102, 269, 1361, 23, 146, "DefinitionBox",
      CellTags->{
      "AllEvents", "CoalescenceEvents", "RecombinationEvents", 
        "NullRecombinationEvents", "LeafEvents", "AllEvents", 
        "CoalescenceEvents", "RecombinationEvents", "RootEvents"}],
    Cell[8102, 269, 1361, 23, 146, "DefinitionBox",
      CellTags->{
      "AllEvents", "CoalescenceEvents", "RecombinationEvents", 
        "NullRecombinationEvents", "LeafEvents", "AllEvents", 
        "CoalescenceEvents", "RecombinationEvents", "RootEvents"}]},
  "CoalescenceEvents"->{
    Cell[8102, 269, 1361, 23, 146, "DefinitionBox",
      CellTags->{
      "AllEvents", "CoalescenceEvents", "RecombinationEvents", 
        "NullRecombinationEvents", "LeafEvents", "AllEvents", 
        "CoalescenceEvents", "RecombinationEvents", "RootEvents"}],
    Cell[8102, 269, 1361, 23, 146, "DefinitionBox",
      CellTags->{
      "AllEvents", "CoalescenceEvents", "RecombinationEvents", 
        "NullRecombinationEvents", "LeafEvents", "AllEvents", 
        "CoalescenceEvents", "RecombinationEvents", "RootEvents"}]},
  "RecombinationEvents"->{
    Cell[8102, 269, 1361, 23, 146, "DefinitionBox",
      CellTags->{
      "AllEvents", "CoalescenceEvents", "RecombinationEvents", 
        "NullRecombinationEvents", "LeafEvents", "AllEvents", 
        "CoalescenceEvents", "RecombinationEvents", "RootEvents"}],
    Cell[8102, 269, 1361, 23, 146, "DefinitionBox",
      CellTags->{
      "AllEvents", "CoalescenceEvents", "RecombinationEvents", 
        "NullRecombinationEvents", "LeafEvents", "AllEvents", 
        "CoalescenceEvents", "RecombinationEvents", "RootEvents"}]},
  "NullRecombinationEvents"->{
    Cell[8102, 269, 1361, 23, 146, "DefinitionBox",
      CellTags->{
      "AllEvents", "CoalescenceEvents", "RecombinationEvents", 
        "NullRecombinationEvents", "LeafEvents", "AllEvents", 
        "CoalescenceEvents", "RecombinationEvents", "RootEvents"}]},
  "LeafEvents"->{
    Cell[8102, 269, 1361, 23, 146, "DefinitionBox",
      CellTags->{
      "AllEvents", "CoalescenceEvents", "RecombinationEvents", 
        "NullRecombinationEvents", "LeafEvents", "AllEvents", 
        "CoalescenceEvents", "RecombinationEvents", "RootEvents"}]},
  "RootEvents"->{
    Cell[8102, 269, 1361, 23, 146, "DefinitionBox",
      CellTags->{
      "AllEvents", "CoalescenceEvents", "RecombinationEvents", 
        "NullRecombinationEvents", "LeafEvents", "AllEvents", 
        "CoalescenceEvents", "RecombinationEvents", "RootEvents"}]},
  "LineagesPresent"->{
    Cell[11667, 386, 259, 6, 20, "SubsubsectionIcon",
      CellTags->{
      "LineagesPresent", "Leaves", "RootLineages", "RecombinantLineages", 
        "CoalescentLineages", "NullLineages"}]},
  "Leaves"->{
    Cell[11667, 386, 259, 6, 20, "SubsubsectionIcon",
      CellTags->{
      "LineagesPresent", "Leaves", "RootLineages", "RecombinantLineages", 
        "CoalescentLineages", "NullLineages"}]},
  "RootLineages"->{
    Cell[11667, 386, 259, 6, 20, "SubsubsectionIcon",
      CellTags->{
      "LineagesPresent", "Leaves", "RootLineages", "RecombinantLineages", 
        "CoalescentLineages", "NullLineages"}]},
  "RecombinantLineages"->{
    Cell[11667, 386, 259, 6, 20, "SubsubsectionIcon",
      CellTags->{
      "LineagesPresent", "Leaves", "RootLineages", "RecombinantLineages", 
        "CoalescentLineages", "NullLineages"}]},
  "CoalescentLineages"->{
    Cell[11667, 386, 259, 6, 20, "SubsubsectionIcon",
      CellTags->{
      "LineagesPresent", "Leaves", "RootLineages", "RecombinantLineages", 
        "CoalescentLineages", "NullLineages"}]},
  "NullLineages"->{
    Cell[11667, 386, 259, 6, 20, "SubsubsectionIcon",
      CellTags->{
      "LineagesPresent", "Leaves", "RootLineages", "RecombinantLineages", 
        "CoalescentLineages", "NullLineages"}]},
  "TimespanOfLineage"->{
    Cell[15131, 512, 547, 15, 51, "DefinitionBox",
      CellTags->{"TimespanOfLineage", "TimespanOfJunction"}]},
  "TimespanOfJunction"->{
    Cell[15131, 512, 547, 15, 51, "DefinitionBox",
      CellTags->{"TimespanOfLineage", "TimespanOfJunction"}]},
  "ExtractLabel"->{
    Cell[16381, 560, 594, 11, 74, "DefinitionBox",
      CellTags->{"ExtractLabel", "ExtractInformation"}]},
  "ExtractInformation"->{
    Cell[16381, 560, 594, 11, 74, "DefinitionBox",
      CellTags->{"ExtractLabel", "ExtractInformation"}]},
  "ExtractLineagesStartingAtT"->{
    Cell[18043, 619, 849, 21, 75, "DefinitionBox",
      CellTags->{"ExtractLineagesStartingAtT", "ExtractLineagesEndingAtT"}]},
  "ExtractLineagesEndingAtT"->{
    Cell[18043, 619, 849, 21, 75, "DefinitionBox",
      CellTags->{"ExtractLineagesStartingAtT", "ExtractLineagesEndingAtT"}]}
  }
*)

(*CellTagsIndex
CellTagsIndex->{
  {"Junctions", 90858, 3237},
  {"MapLength", 90971, 3240},
  {"Segments", 91083, 3243},
  {"TimesOfEvents", 91183, 3246},
  {"AllEvents", 91284, 3249},
  {"CoalescenceEvents", 91840, 3260},
  {"RecombinationEvents", 92398, 3271},
  {"NullRecombinationEvents", 92960, 3282},
  {"LeafEvents", 93244, 3288},
  {"RootEvents", 93528, 3294},
  {"LineagesPresent", 93817, 3300},
  {"Leaves", 94027, 3305},
  {"RootLineages", 94243, 3310},
  {"RecombinantLineages", 94466, 3315},
  {"CoalescentLineages", 94688, 3320},
  {"NullLineages", 94904, 3325},
  {"TimespanOfLineage", 95125, 3330},
  {"TimespanOfJunction", 95265, 3333},
  {"ExtractLabel", 95399, 3336},
  {"ExtractInformation", 95534, 3339},
  {"ExtractLineagesStartingAtT", 95677, 3342},
  {"ExtractLineagesEndingAtT", 95838, 3345}
  }
*)

(*NotebookFileOutline
Notebook[{
Cell[1717, 49, 46, 0, 28, "MathCaption"],

Cell[CellGroupData[{
Cell[1788, 53, 112, 2, 27, "Input"],
Cell[1903, 57, 371, 6, 46, "Message"]
}, Open  ]],
Cell[2289, 66, 357, 9, 38, "Text"],

Cell[CellGroupData[{
Cell[2671, 79, 61, 0, 24, "SubsubsectionIcon"],
Cell[2735, 81, 142, 3, 28, "MathCaption"],
Cell[2880, 86, 748, 13, 132, "Input"],
Cell[3631, 101, 176, 4, 22, "Text"]
}, Closed]],

Cell[CellGroupData[{
Cell[3844, 110, 59, 0, 20, "SubsubsectionIcon"],
Cell[3906, 112, 616, 16, 83, "DefinitionBox",
  CellTags->{"Junctions", "MapLength"}],
Cell[4525, 130, 47, 0, 28, "MathCaption"],

Cell[CellGroupData[{
Cell[4597, 134, 93, 2, 27, "Input"],
Cell[4693, 138, 89, 2, 20, "Output"]
}, Open  ]],
Cell[4797, 143, 46, 0, 28, "MathCaption"],

Cell[CellGroupData[{
Cell[4868, 147, 93, 2, 27, "Input"],
Cell[4964, 151, 82, 2, 20, "Output"]
}, Open  ]],
Cell[5061, 156, 107, 3, 28, "MathCaption"],

Cell[CellGroupData[{
Cell[5193, 163, 225, 4, 42, "Input"],
Cell[5421, 169, 202, 4, 20, "Message"],
Cell[5626, 175, 82, 2, 20, "Output"]
}, Open  ]],
Cell[5723, 180, 387, 8, 54, "DefinitionBox",
  CellTags->"Segments"],
Cell[6113, 190, 101, 3, 28, "MathCaption"],

Cell[CellGroupData[{
Cell[6239, 197, 157, 3, 27, "Input"],
Cell[6399, 202, 92, 2, 20, "Output"]
}, Open  ]],
Cell[6506, 207, 94, 3, 28, "MathCaption"],

Cell[CellGroupData[{
Cell[6625, 214, 97, 2, 27, "Input"],
Cell[6725, 218, 163, 3, 20, "Output"]
}, Open  ]],
Cell[6903, 224, 155, 3, 22, "Text"]
}, Closed]],

Cell[CellGroupData[{
Cell[7095, 232, 180, 4, 36, "SubsubsectionIcon",
  InitializationCell->True],
Cell[7278, 238, 280, 8, 39, "DefinitionBox",
  CellTags->"TimesOfEvents"],
Cell[7561, 248, 65, 0, 28, "MathCaption"],

Cell[CellGroupData[{
Cell[7651, 252, 97, 2, 27, "Input"],
Cell[7751, 256, 97, 2, 20, "Output"]
}, Open  ]],
Cell[7863, 261, 236, 6, 24, "Text"],
Cell[8102, 269, 1361, 23, 146, "DefinitionBox",
  CellTags->{
  "AllEvents", "CoalescenceEvents", "RecombinationEvents", 
    "NullRecombinationEvents", "LeafEvents", "AllEvents", "CoalescenceEvents",
     "RecombinationEvents", "RootEvents"}],

Cell[CellGroupData[{
Cell[9488, 296, 93, 2, 27, "Input"],
Cell[9584, 300, 208, 3, 20, "Output"]
}, Open  ]],
Cell[9807, 306, 174, 4, 22, "Text"],
Cell[9984, 312, 60, 0, 28, "MathCaption"],

Cell[CellGroupData[{
Cell[10069, 316, 101, 2, 27, "Input"],
Cell[10173, 320, 105, 2, 20, "Output"]
}, Open  ]],
Cell[10293, 325, 95, 3, 28, "MathCaption"],

Cell[CellGroupData[{
Cell[10413, 332, 103, 2, 27, "Input"],
Cell[10519, 336, 125, 2, 20, "Output"]
}, Open  ]],
Cell[10659, 341, 66, 0, 28, "MathCaption"],

Cell[CellGroupData[{
Cell[10750, 345, 94, 2, 27, "Input"],
Cell[10847, 349, 108, 2, 20, "Output"]
}, Open  ]],
Cell[10970, 354, 71, 0, 28, "MathCaption"],

Cell[CellGroupData[{
Cell[11066, 358, 94, 2, 27, "Input"],
Cell[11163, 362, 104, 2, 20, "Output"]
}, Open  ]],
Cell[11282, 367, 118, 3, 28, "MathCaption"],

Cell[CellGroupData[{
Cell[11425, 374, 107, 2, 27, "Input"],
Cell[11535, 378, 83, 2, 20, "Output"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{
Cell[11667, 386, 259, 6, 20, "SubsubsectionIcon",
  CellTags->{
  "LineagesPresent", "Leaves", "RootLineages", "RecombinantLineages", 
    "CoalescentLineages", "NullLineages"}],
Cell[11929, 394, 988, 16, 150, "DefinitionBox"],
Cell[12920, 412, 44, 0, 28, "MathCaption"],

Cell[CellGroupData[{
Cell[12989, 416, 90, 2, 27, "Input"],
Cell[13082, 420, 87, 2, 20, "Output"]
}, Open  ]],
Cell[13184, 425, 43, 0, 28, "MathCaption"],

Cell[CellGroupData[{
Cell[13252, 429, 96, 2, 27, "Input"],
Cell[13351, 433, 90, 2, 20, "Output"]
}, Open  ]],
Cell[13456, 438, 73, 0, 28, "MathCaption"],

Cell[CellGroupData[{
Cell[13554, 442, 99, 2, 27, "Input"],
Cell[13656, 446, 102, 2, 20, "Output"]
}, Open  ]],
Cell[13773, 451, 63, 0, 28, "MathCaption"],

Cell[CellGroupData[{
Cell[13861, 455, 102, 2, 27, "Input"],
Cell[13966, 459, 90, 2, 20, "Output"]
}, Open  ]],
Cell[14071, 464, 115, 3, 28, "MathCaption"],

Cell[CellGroupData[{
Cell[14211, 471, 104, 2, 27, "Input"],
Cell[14318, 475, 94, 2, 20, "Output"]
}, Open  ]],
Cell[14427, 480, 83, 1, 28, "MathCaption"],

Cell[CellGroupData[{
Cell[14535, 485, 103, 2, 27, "Input"],
Cell[14641, 489, 85, 2, 20, "Output"]
}, Open  ]],
Cell[14741, 494, 64, 0, 28, "MathCaption"],

Cell[CellGroupData[{
Cell[14830, 498, 97, 2, 27, "Input"],
Cell[14930, 502, 84, 2, 20, "Output"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{
Cell[15063, 510, 65, 0, 20, "SubsubsectionIcon"],
Cell[15131, 512, 547, 15, 51, "DefinitionBox",
  CellTags->{"TimespanOfLineage", "TimespanOfJunction"}],
Cell[15681, 529, 50, 0, 28, "MathCaption"],

Cell[CellGroupData[{
Cell[15756, 533, 105, 2, 27, "Input"],
Cell[15864, 537, 88, 2, 20, "Output"]
}, Open  ]],
Cell[15967, 542, 77, 0, 28, "MathCaption"],

Cell[CellGroupData[{
Cell[16069, 546, 107, 2, 27, "Input"],
Cell[16179, 550, 89, 2, 20, "Output"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{
Cell[16317, 558, 61, 0, 20, "SubsubsectionIcon"],
Cell[16381, 560, 594, 11, 74, "DefinitionBox",
  CellTags->{"ExtractLabel", "ExtractInformation"}],
Cell[16978, 573, 66, 0, 28, "MathCaption"],

Cell[CellGroupData[{
Cell[17069, 577, 98, 2, 27, "Input"],
Cell[17170, 581, 102, 2, 20, "Output"]
}, Open  ]],
Cell[17287, 586, 67, 0, 28, "MathCaption"],

Cell[CellGroupData[{
Cell[17379, 590, 142, 3, 27, "Input"],
Cell[17524, 595, 82, 2, 20, "Output"]
}, Open  ]],
Cell[17621, 600, 69, 0, 28, "MathCaption"],

Cell[CellGroupData[{
Cell[17715, 604, 106, 2, 27, "Input"],
Cell[17824, 608, 84, 2, 20, "Output"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{
Cell[17957, 616, 83, 1, 20, "SubsubsectionIcon"],
Cell[18043, 619, 849, 21, 75, "DefinitionBox",
  CellTags->{"ExtractLineagesStartingAtT", "ExtractLineagesEndingAtT"}],
Cell[18895, 642, 103, 3, 28, "MathCaption"],

Cell[CellGroupData[{
Cell[19023, 649, 114, 2, 27, "Input"],
Cell[19140, 653, 88, 2, 20, "Output"]
}, Open  ]],
Cell[19243, 658, 58, 0, 28, "MathCaption"],

Cell[CellGroupData[{
Cell[19326, 662, 112, 2, 27, "Input"],
Cell[19441, 666, 85, 2, 20, "Output"]
}, Open  ]]
}, Closed]]
}
]
*)




(***********************************************************************
End of Mathematica Notebook file.
***********************************************************************)

