(***********************************************************************

                    Mathematica-Compatible Notebook

This notebook can be used on any computer system with Mathematica 4.0,
MathReader 4.0, or any compatible application. The data for the notebook 
starts with the line containing stars above.

To get the notebook into a Mathematica-compatible application, do one of 
the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing the 
word CacheID, otherwise Mathematica-compatible applications may try to 
use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
***********************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[     15503,        558]*)
(*NotebookOutlinePosition[     16387,        586]*)
(*  CellTagsIndexPosition[     16343,        582]*)
(*WindowFrame->Normal*)



Notebook[{

Cell[CellGroupData[{
Cell["An example of an ancestral graph", "SubsubsectionIcon"],

Cell["\<\
This is an example of an ancestral graph consisting of seven \
lineages, arbitrarily labelled {a,b, 3,4, 5,6,7}\
\>", "MathCaption"],

Cell[BoxData[
    \(\(ag = {\[IndentingNewLine]AncestralLineage[
            a, {0, 2}, {{a}}, {R}, {}], \[IndentingNewLine]AncestralLineage[
            b, {0, 2}, {{b}}, {R}, {}], \[IndentingNewLine]AncestralLineage[
            3, {2, 4}, {{a, 
                b}}, {R}, {}], \[IndentingNewLine]AncestralLineage[
            4, {4, 10}, {{a, b}, {}}, {r1, 
              R}, {}], \[IndentingNewLine]AncestralLineage[
            5, {4, 6}, {{}, {a, b}}, {r1, 
              R}, {}], \[IndentingNewLine]AncestralLineage[
            6, {6, 10}, {{}, {a, b}, {}}, {r1, r2, 
              R}, {}], \[IndentingNewLine]AncestralLineage[
            7, {6, 10}, {{}, {a, b}}, {r2, R}, {}]};\)\)], "Input",
  CellLabel->"In[2]:=  (21:09:46 on 5/9/02)"],

Cell["\<\
There is a coalescence between a and b at t=2; a recombination \
event at map position r1, time t=4; and a recombination at map position r2>r1 \
at t=6.\
\>", "Text"]
}, Closed]],

Cell[CellGroupData[{

Cell["ExtractGenealogy", "SubsubsectionIcon"],

Cell[TextData[Cell[BoxData[
    FormBox[GridBox[{
          {\(ExtractGenealogy[{AncestralLineage[\[Ellipsis]], \[Ellipsis]}, 
              x]\), \(generates\ the\ genealogy\ corresponding\ to\ map\ \
position\ x\)},
          {\(InformationFunction \[Rule] 
              f\), \(generates\ an\ information\ list\ f[i, 
                x]\ for\ node\ i\)},
          {\("ExtractGenealogy[{AncestralLineage[\[Ellipsis]]\[Ellipsis]}]."\)\
, \("generates the set of genealogies, applying to segments demarcated by \
Junctions[g]."\)}
          }], TraditionalForm]],
  CellTags->{"ExtractGenealogy", "InformationFunction"}]], "DefinitionBox"],

Cell[TextData[{
  StyleBox["Note: ",
    FontWeight->"Bold"],
  "All segments of the genome must have a single common ancestor."
}], "Text"],

Cell[TextData[{
  StyleBox["Note: ",
    FontWeight->"Bold"],
  " ExtractGenealogy[] requires that the junctions take numerical values, so \
that it can be decided where the map position lies.  In the example, \
therefore, r1, r2, R are replaced by numbers:"
}], "Text"],

Cell["This is the genealogy of the locus at map position 0.1:", "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[
    \(ExtractGenealogy[ag /. {r1 -> 0.3, r2 -> 0.6, R -> 1}, 0.1]\)], "Input",\

  CellLabel->"In[96]:=  (19:35:01 on 5/11/02)"],

Cell[BoxData[
    \(Node[
      4, {4}, {Node[
          3, {2}, {Node[a, {0}, {}], Node[b, {0}, {}]}]}]\)], "Output",
  CellLabel->"Out[96]=  (19:35:01 on 5/11/02)"]
}, Open  ]],

Cell["\<\
This lists the three genealogies associated with the three segments \
(0\[LessEqual]x<0.3, 0.3\[LessEqual]x<0.6, 0.6\[LessEqual]x<1):\
\>", \
"MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[
    \(gl = ExtractGenealogy[ag /. {r1 -> 0.3, r2 -> 0.6, R -> 1}]\)], "Input",\

  CellLabel->"In[100]:=  (19:37:34 on 5/11/02)"],

Cell[BoxData[
    \({Node[4, {4}, {Node[3, {2}, {Node[a, {0}, {}], Node[b, {0}, {}]}]}], 
      Node[6, {6}, {Node[
            5, {4}, {Node[3, {2}, {Node[a, {0}, {}], Node[b, {0}, {}]}]}]}], 
      Node[7, {6}, {Node[
            5, {4}, {Node[
                3, {2}, {Node[a, {0}, {}], 
                  Node[b, {0}, {}]}]}]}]}\)], "Output",
  CellLabel->"Out[100]=  (19:37:35 on 5/11/02)"]
}, Open  ]],

Cell["\<\
The genealogies all have the same structure in this simple example, \
but trace back through different ancestral lineages:\
\>", "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(Show[GraphicsArray[\(PlotGenealogy[#] &\) /@ gl]];\)\)], "Input",
  CellLabel->"In[97]:=  (19:35:35 on 5/11/02)"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .19314 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.31746 0.00459847 0.31746 [
[ 0 0 0 0 ]
[ 1 .19314 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .19314 L
0 .19314 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.00459847 0.321429 0.188537 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.333333 0.333333 0.154508 0.154508 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
0 g
.5 Mabswid
[ ] 0 setdash
.5 .30902 m
.33333 .15451 L
s
.5 .30902 m
.66667 .15451 L
s
.5 .46353 m
.5 .30902 L
s
[(3)] .43333 .33992 0 0 Mshowa
[(4)] .43333 .49443 0 0 Mshowa
gsave
.33333 .12361 -66 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(a) show
1.000 setlinewidth
grestore
gsave
.66667 .12361 -66 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(b) show
1.000 setlinewidth
grestore
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.35119 0.00459847 0.64881 0.188537 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.333333 0.333333 0.123607 0.123607 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
0 g
.5 Mabswid
[ ] 0 setdash
.5 .24721 m
.33333 .12361 L
s
.5 .24721 m
.66667 .12361 L
s
.5 .37082 m
.5 .24721 L
s
.5 .49443 m
.5 .37082 L
s
[(3)] .43333 .27193 0 0 Mshowa
[(5)] .43333 .39554 0 0 Mshowa
[(6)] .43333 .51915 0 0 Mshowa
gsave
.33333 .09889 -66 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(a) show
1.000 setlinewidth
grestore
gsave
.66667 .09889 -66 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(b) show
1.000 setlinewidth
grestore
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.678571 0.00459847 0.97619 0.188537 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.333333 0.333333 0.123607 0.123607 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
0 g
.5 Mabswid
[ ] 0 setdash
.5 .24721 m
.33333 .12361 L
s
.5 .24721 m
.66667 .12361 L
s
.5 .37082 m
.5 .24721 L
s
.5 .49443 m
.5 .37082 L
s
[(3)] .43333 .27193 0 0 Mshowa
[(5)] .43333 .39554 0 0 Mshowa
[(7)] .43333 .51915 0 0 Mshowa
gsave
.33333 .09889 -66 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(a) show
1.000 setlinewidth
grestore
gsave
.66667 .09889 -66 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(b) show
1.000 setlinewidth
grestore
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[99]:=  (19:36:20 on 5/11/02)",
  ImageSize->{288, 55.5625},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000=a000`40O003h00Oogoo8Goo003oOolQ
Ool00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol007moo`@001Mo
o`@003eoo`@001Moo`@002Ioo`00OWoo00@007ooOol001Uoo`04001oogoo000kOol01000Oomoo`00
6Goo00@007ooOol002Eoo`008goo10005goo1000?Goo0`006Goo00@007ooOol003aoo`<001Uoo`04
001oogoo000UOol0029oo`04001oogoo000IOol01000Oomoo`00>goo00@007ooOol001Uoo`04001o
ogoo000kOol01000Oomoo`006Goo00@007ooOol002Eoo`008goo0`006Goo00@007ooOol003aoo`@0
01Qoo`<003eoo`@001Qoo`<002Ioo`008Woo00@007ooOol001Uoo`04001oogoo0010Ool00`00Oomo
o`0EOol00`00Oomoo`11Ool00`00Oomoo`0EOol00`00Oomoo`0VOol002=oo`<001Uoo`<0049oo`80
01=oo`<004Aoo`8001=oo`<002Qoo`009Woo00<007ooOol05Goo0P00AWoo00<007ooOol03goo00<0
07ooOol0Agoo00<007ooOol03goo00<007ooOol0:Goo000WOol00`00Oomoo`0COol30017Ool00`00
Oomoo`0=Ool00`00Oomoo`19Ool00`00Oomoo`0=Ool00`00Oomoo`0ZOol002Qoo`03001oogoo015o
o`03001oogoo04Uoo`8000]oo`8004eoo`8000]oo`8002eoo`00:Goo00<007ooOol03goo00<007oo
Ool0C7oo00<007ooOol01goo00<007ooOol0Cgoo00<007ooOol01goo00<007ooOol0;Goo000ZOol0
0`00Oomoo`0=Ool00`00Oomoo`1>Ool20005Ool2001COol20005Ool2000`Ool002]oo`03001oogoo
00]oo`03001oogoo055oo`05001oogooOol0001GOol01@00Oomoogoo0000<Woo000/Ool00`00Oomo
o`09Ool00`00Oomoo`1COol00`00Ool0001IOol00`00Ool0000cOol002eoo`03001oogoo00Moo`03
001oogoo04eoo`<000Eoo`03001oogoo059oo`<000Aoo`03001oogoo039oo`00;Woo00<007ooOol0
1Goo00<007ooOol0CGoo00D007ooOomoo`0000Aoo`03001oogoo055oo`05001oogooOol00003Ool0
0`00Oomoo`0bOol002moo`03001oogoo00=oo`03001oogoo059oo`03001oogoo009oo`03001oogoo
05Eoo`05001oogooOol0000dOol0031oo`05001oogooOol0001COol20005Ool00`00Oomoo`1COol2
0004Ool00`00Oomoo`0bOol0035oo`03001oo`0005Ioo`03001oogoo009oo`03001oogoo05Eoo`05
001oogooOol0000dOol002]oo`<000Aoo`03001oogoo055oo`05001oogooOol00004Ool00`00Oomo
o`1AOol01@00Oomoogoo00000goo00<007ooOol0<Woo000ZOol01@00Oomoogoo00000goo00<007oo
Ool0DWoo0`001Goo00<007ooOol0DWoo0`0017oo00<007ooOol0<Woo000^Ool01@00Oomoogoo0000
G7oo00<007ooOol0FGoo00<007ooOol0<Woo000/Ool20004Ool00`00Oomoo`1JOol00`00Oomoo`1I
Ool00`00Oomoo`0bOol002ioo`05001oogooOol0001LOol00`00Oomoo`1IOol00`00Oomoo`0bOol0
02Yoo`05001oogooOol00003Ool00`00Oomoo`1BOol30005Ool00`00Oomoo`1BOol30004Ool00`00
Oomoo`0bOol002]oo`<000Aoo`03001oogoo055oo`05001oogooOol00004Ool00`00Oomoo`1AOol0
1@00Oomoogoo00000goo00<007ooOol0<Woo000bOol00`00Oomoo`1EOol00`00Oomoo`02Ool00`00
Oomoo`1EOol01@00Oomoogoo0000=7oo000bOol00`00Oomoo`1EOol00`00Oomoo`02Ool00`00Oomo
o`1EOol01@00Oomoogoo0000=7oo000bOol00`00Oomoo`1AOol40005Ool00`00Oomoo`1AOol40004
Ool00`00Oomoo`0bOol0039oo`03001oogoo055oo`03001oogoo00Ioo`03001oogoo055oo`03001o
ogoo00Eoo`03001oogoo039oo`00<Woo00<007ooOol0DGoo1@0017oo00<007ooOol0DGoo1@000goo
00<007ooOol0<Woo000bOol00`00Oomoo`1JOol00`00Oomoo`1IOol00`00Oomoo`0bOol002aoo`<0
00=oo`03001oogoo05Yoo`03001oogoo05Uoo`03001oogoo039oo`00;Goo00<007ooOol0Ggoo00<0
07ooOol0FGoo00<007ooOol0<Woo000ZOol5001HOol30005Ool00`00Oomoo`1COol00`00Oomoo`03
Ool00`00Oomoo`0bOol002Yoo`04001oogoo001HOol01@00Oomoogoo000017oo00<007ooOol0Dgoo
00<007ooOol00goo00<007ooOol0<Woo000[Ool00`00Ool0001HOol01@00Oomoogoo0000Fgoo00<0
07ooOol0=goo000/Ool2001HOol4001LOol00`00Oomoo`0gOol002eoo`03001oogoo05Ioo`03001o
ogoo05ioo`03001oogoo03Ioo`00Qgoo00<007ooOol0FGoo00D007ooOomoo`0003Qoo`00R7oo0P00
FGoo1@00>7oo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo0000
\
\>"],
  ImageRangeCache->{{{0, 287}, {54.5625, 0}} -> {-0.100091, -0.0144882, \
0.0111505, 0.0111505}, {{8.9375, 93}, {53.25, 1.25}} -> {-1.31898, -1.10288, \
0.0356881, 0.076993}, {{101.438, 185.5}, {53.25, 1.25}} -> {-4.62013, \
-1.1286, 0.0356881, 0.0962407}, {{193.938, 278}, {53.25, 1.25}} -> {-7.92128, \
-1.1286, 0.0356881, 0.0962407}}]
}, Open  ]]
}, Closed]]
},
FrontEndVersion->"4.0 for Macintosh",
ScreenRectangle->{{0, 1024}, {0, 748}},
WindowSize->{520, 626},
WindowMargins->{{145, Automatic}, {Automatic, 41}},
StyleDefinitions -> "HelpBrowser.nb",
MacintoshSystemPageSetup->"\<\
00h0001804P000000b02<?oaonl3>@91H`85N0?N0@00005X0FP000003j0:l001
0@00I00100000@0200000BL?00400000000000000000010000000000000@0?ne
oj/@7@]500P1000000000000000001T1\>"
]


(***********************************************************************
Cached data follows.  If you edit this Notebook file directly, not using
Mathematica, you must remove the line containing CacheID at the top of 
the file.  The cache data will then be recreated when you save this file 
from within Mathematica.
***********************************************************************)

(*CellTagsOutline
CellTagsIndex->{}
*)

(*CellTagsIndex
CellTagsIndex->{}
*)

(*NotebookFileOutline
Notebook[{

Cell[CellGroupData[{
Cell[1739, 51, 61, 0, 24, "SubsubsectionIcon"],
Cell[1803, 53, 142, 3, 28, "MathCaption"],
Cell[1948, 58, 748, 13, 132, "Input"],
Cell[2699, 73, 176, 4, 22, "Text"]
}, Closed]],

Cell[CellGroupData[{
Cell[2912, 82, 45, 0, 20, "SubsubsectionIcon"],
Cell[2960, 84, 640, 12, 74, "DefinitionBox"],
Cell[3603, 98, 140, 4, 24, "Text"],
Cell[3746, 104, 270, 6, 38, "Text"],
Cell[4019, 112, 78, 0, 28, "MathCaption"],

Cell[CellGroupData[{
Cell[4122, 116, 142, 3, 27, "Input"],
Cell[4267, 121, 166, 4, 20, "Output"]
}, Open  ]],
Cell[4448, 128, 166, 4, 28, "MathCaption"],

Cell[CellGroupData[{
Cell[4639, 136, 143, 3, 27, "Input"],
Cell[4785, 141, 395, 8, 33, "Output"]
}, Open  ]],
Cell[5195, 152, 153, 3, 28, "MathCaption"],

Cell[CellGroupData[{
Cell[5373, 159, 135, 2, 27, "Input"],
Cell[5511, 163, 9964, 391, 62, 6106, 338, "GraphicsData", "PostScript", \
"Graphics"]
}, Open  ]]
}, Closed]]
}
]
*)




(***********************************************************************
End of Mathematica Notebook file.
***********************************************************************)

