(***********************************************************************

                    Mathematica-Compatible Notebook

This notebook can be used on any computer system with Mathematica 4.0,
MathReader 4.0, or any compatible application. The data for the notebook 
starts with the line containing stars above.

To get the notebook into a Mathematica-compatible application, do one of 
the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing the 
word CacheID, otherwise Mathematica-compatible applications may try to 
use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
***********************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[   2829720,      79681]*)
(*NotebookOutlinePosition[   2901124,      82254]*)
(*  CellTagsIndexPosition[   2901080,      82250]*)
(*WindowFrame->Normal*)



Notebook[{

Cell[CellGroupData[{
Cell["Introduction", "SubsubsectionIcon"],

Cell[TextData[{
  "The ancestry of a section of genome can be represented by an ",
  StyleBox["ancestral graph",
    FontSlant->"Italic"],
  ".  As one traces back in time, lineages may coalesce (reflecting the \
action of random drift) or split (reflecting recombination).  If the genetic \
map is taken to be a continuous, then each recombination occurs at a unique \
point.  One can regard the complete graph as a set of genealogies, each \
applying to some short segment of genome, and each obeying the coalescent \
process.  Adjacent genealogies differ by a single recombination event, which \
changes the ancestry of part of the genealogy."
}], "Text"],

Cell[TextData[{
  "Scaling time relative to 2N generations, the rate of coalescence between \
any pair of lineages is 1, and the net rate among ",
  Cell[BoxData[
      \(TraditionalForm\`k\)]],
  " lineages is ",
  Cell[BoxData[
      \(TraditionalForm\`\(k(k - 1)\)\/2\)]],
  ".  The rate of recombination in a section of genome of map length ",
  Cell[BoxData[
      \(TraditionalForm\`2  N\[VeryThinSpace]r = R\)]],
  " is just ",
  Cell[BoxData[
      \(TraditionalForm\`k\[VeryThinSpace]R\)]],
  ".  The number of lineages therefore follows a simple branching process.   \
It will eventually reach 1; that is, eventually a single genome will be the \
ancestor of the entire sample, at all loci.  However, tracing further back, \
this single lineage will descend from many ancestors: the 'typical/' ancestry \
of a sample will be to descend from a fluctuating # of ancestral genomic \
segments, each being the single common ancestor of some part of the genome of \
the sample."
}], "Text"],

Cell["\<\
The abcestral graph can be constructed by tracing the whole genome \
back in time, and allowing both coalescence and recombination.   This was the \
algorithm given by Hudson (1990).  Alternatively, one can start at an \
arbitrary point in the genome, and then work along, until the first \
recombination event occurs; this determines a new genealogy, differing by a \
single event.  Wiuf and Hein (1999) describe this method, which is somewhat \
more cumbersome.\
\>", "Text"]
}, Closed]],

Cell[CellGroupData[{

Cell["Representing an ancestral graph", "SubsubsectionIcon"],

Cell[TextData[Cell[BoxData[
    FormBox[GridBox[{
          {
            FormBox[
              RowBox[{
                RowBox[{
                  RowBox[{
                    FormBox[
                      RowBox[{
                        
                        FormBox[\(\(AncestralLineage\)\([\)\(l, {t\_0, 
                              t\_1}, {{a, b}, {}, {c, d}, {c}}\)\),
                          "TraditionalForm"], ",", \({r\_1, r\_2, r\_3, R\)}],
                      
                      "TraditionalForm"], "}"}], ",", 
                  StyleBox["info",
                    FontSlant->"Italic"]}], "]"}],
              "TraditionalForm"], 
            
            RowBox[{\(represents\ a\ lineage\ l\ which\ persists\ from\ \
\(t\_0\) to\ \(t\_1\) back\ into\ the\ past\), ",", " ", 
              
              RowBox[{\(and\ which\ consists\ of\ 4\ distinct\ segments . \ \ \
{{a, b}, {}, {c, 
                        d}, {c}}\ lists\ the\ leaves\ which\ descend\ from\ \
each\ segment\), ";", 
                " ", \({r\_1, r\_2, r\_3, 
                    R}\ lists\ the\ rightmost\ end\ of\ each\ segment\ \
\((starting\ at\ 0\ and\ ending\ at\ R)\)\), ";", " ", 
                RowBox[{
                  StyleBox["info",
                    FontSlant->"Italic"], " ", "is", " ", "a", " ", "list", 
                  " ", "of", "  ", "information", " ", "about", " ", "the", 
                  " ", "lineage", 
                  " ", \(\((e . g . \ where\ it\ is, \ 
                      what\ mutations\ it\ carries)\)\(.\)\)}]}]}]},
          {\({AncestralLineage[l\_1, {t\_0, t\_1}, \[Ellipsis]], 
              AncestralLineage[
                  l\_2, {t\_0, 
                    t\_1}, \[Ellipsis]] \[Ellipsis]}\), \(represents\ the\ \
complete\ graph\ as\ a\ list\ of\ \(\(lineages\)\(.\)\)\)}
          }], TraditionalForm]]]], "DefinitionBox"],

Cell[TextData[{
  "Each lineage is represented as spanning a certain time interval ",
  Cell[BoxData[
      \(TraditionalForm\`{t\_0, t\_1}\)]],
  ", and consisting of segments that are ancestral to various sets of \
descendants - for example, ",
  Cell[BoxData[
      \(TraditionalForm\`{{a, b}, {}, {c, d}, {c}}\)]],
  ".  The genome spans {0,R}, and the segments are separated by ",
  StyleBox["junctions",
    FontSlant->"Italic"],
  " at ",
  Cell[BoxData[
      \(TraditionalForm\`{r\_1, \ r\_2, r\_3}\)]],
  ".  (It is convenient to add ",
  Cell[BoxData[
      \(TraditionalForm\`R\)]],
  " as the last element of the list of junctions).  Information about the \
lineage as a whole, and about each segment, can be supplied as subsequent \
lists.  Lineages are given an arbitrary ",
  Cell[BoxData[
      \(TraditionalForm\`label\)]],
  " ",
  Cell[BoxData[
      \(TraditionalForm\`l\_i\)]],
  "."
}], "Text"],

Cell["\<\
This representation is closest to that of an unrooted genealogy, \
except that lineages are listed, rather than nodes.  In contrast, rooted \
genealogies are represented as nested structures, and the nesting contains \
information about the topology of the tree.  This kind of representation \
cannot be used for an ancestral graph, since it does not have a nested \
structure.\
\>", "Text"],

Cell[TextData[{
  "Note that the representation is relative to a set of ",
  StyleBox["leaves",
    FontSlant->"Italic"],
  ", ",
  Cell[BoxData[
      \(TraditionalForm\`{a, b, c\[VeryThinSpace]\[Ellipsis]}\)]],
  ". Thus, information about sections of genome which are not ancestral to \
the sample (\"",
  StyleBox["trapped material",
    FontSlant->"Italic"],
  "\"; Wiuf and Hein, 1999) is lost.  That is more or less inevitable, since \
the total number of number of descendants (",
  StyleBox["cousins",
    FontSlant->"Italic"],
  " of the leaves)",
  " may be extremely large."
}], "Text"],

Cell["\<\
A coalescence of two lineages preserves all the junctions, unless \
complementary junctions annihilate.  The lists of descendants in each segment \
are simply combined.  \
\>", "Text"],

Cell[TextData[{
  "A recombination splits the lineage into two at some randompoint; one \
lineage carries the material to the left, and non-anestralmaterial to the \
right, while the second carries the material to the left.  A pair of \
junctions is generated, which will annihilate when two lineages which carry \
them coalesce.  One should be able to work out the lifetimes of junctions \
using properties of the standard coalescent, since they are point objects: \
they will persist for an exponentially distributed time, with scaled mean 1 \
unit.   The rate of generationof junctions is harder to calculate, because \
they are generated only when there is a recombination event within material \
ancestral to the sample.  Recombinations within ",
  StyleBox["trapped material",
    FontSlant->"Italic"],
  " may still have an effect, even if they do not generate a pair of \
junctions, however.  This difficulty might be resolved if material not \
ancestralto the sample were nevertheless tracked: one then needs to find what \
fraction of descendants of given genomes lead down to the sample, by pruning \
out \"cousins\"."
}], "Text"]
}, Closed]],

Cell[CellGroupData[{

Cell["Definitions", "SubsectionIcon",
  InitializationCell->True],

Cell[CellGroupData[{

Cell["Notes", "SubsubsectionIcon",
  InitializationCell->True],

Cell[TextData[{
  "The ancestral graph can be represented either as a list of lineages, or as \
a list of events.  The latter is generated from the former by ",
  Cell[BoxData[
      \(TraditionalForm\`AllEvents[g]\)]],
  ";  a rather cumbersome procedure.  "
}], "Text",
  InitializationCell->True],

Cell["\<\
Events are labelled by times, which must (apart from roots and \
leaves) be unique numbers.  This is somewhat restrictive.\
\>", "Text",
  InitializationCell->True],

Cell["\<\
The list of ancestry is almost never used - only to decide whether \
a recombinant lineage arose from a left- or right- break.  One might perhaps \
use negative junction labels to deal with this???\
\>", "Text",
  InitializationCell->True],

Cell["\<\
I had begun by setting up a list of event times, and then applying \
it to construct a genealogy.  However, this is extremely inefficient, because \
most lineages ultimately carry no material ancestral to the sample.  \
However,if one discards the null recombination events that generate such \
nulllineages, then the event times can no longer be separated from the \
genealogy.  (However, with a long genome, almost all ancestors will carry \
some ancestral material)\
\>", "Text"]
}, Closed]],

Cell[CellGroupData[{

Cell["Load packages", "SubsubsectionIcon",
  InitializationCell->True],

Cell[BoxData[
    \(\(<< Genealogies`Genealogies`;\)\)], "Input",
  CellLabel->"In[1]:=",
  InitializationCell->True],

Cell[BoxData[
    \(<< Statistics`; << Graphics`;\)], "Input",
  CellLabel->"In[2]:=",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{

Cell["AncestralGraphPattern", "SubsubsectionIcon",
  InitializationCell->True],

Cell[BoxData[
    \(\(AncestralGraphPattern::usage = "\<AncestralGraphPattern is matched by \
a list {AncestralLineage[\[Ellipsis]]...}, representing an ancestral graph. \
No detailed checks aremade that this is a valid graph, however.\>";\)\)], \
"Input",
  CellLabel->"In[3]:=",
  InitializationCell->True],

Cell[BoxData[
    \(\(AncestralGraphPattern = {AncestralLineagePattern ... };\)\)], "Input",\

  CellLabel->"In[4]:=",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{

Cell["AncestralLineagePattern", "SubsubsectionIcon",
  InitializationCell->True],

Cell[BoxData[
    \(\(AncestralLineagePattern::usage = "\<AncestralLineagePattern is \
matched by an AncestralLineage[\[Ellipsis]]\>";\)\)], "Input",
  CellLabel->"In[5]:=",
  InitializationCell->True],

Cell[BoxData[
    \(\(AncestralLineagePattern = 
        AncestralLineage[_, {_, _}, _List, _List, _List];\)\)], "Input",
  CellLabel->"In[6]:=",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{

Cell["RandomCoalescenceTimes", "SubsubsectionIcon",
  InitializationCell->True],

Cell[BoxData[
    \(\("\<RandomCoalescenceTimes[n,k,R] generates a sequence of n \
coalescences and recombinations, starting with k lineages at t=0. The output \
is a list of n items of the form {t,k,j}, where t is the time of the event;k \
is the number of lineages after the event; and j is the location of the \
recombination event in the interval {0,R}. j=None indicates a coalescence.  \
RandomCoalescenceTimes[k,R] generates a single item, with rate k(k-1)/2 of \
coalescence and k R of recombination.\>";\)\)], "Input",
  CellLabel->"In[7]:=",
  InitializationCell->True],

Cell[BoxData[
    \(\(RandomCoalescenceTimes[k_Integer, R_] := 
        Module[{t, \[Lambda] = \(k \((k - 1)\)\)\/2 + 
                k\ R}, \[IndentingNewLine]t = 
            Random[ExponentialDistribution[\[Lambda]]]; \[IndentingNewLine]If[
            Random[] < k\ R/\[Lambda], \[IndentingNewLine]{t, k + 1, 
              Random[UniformDistribution[0, \ R]]}, \[IndentingNewLine]{t, 
              k - 1, None}]];\)\)], "Input",
  CellLabel->"In[8]:=",
  InitializationCell->True],

Cell[BoxData[
    \(\(RandomCoalescenceTimes[n_Integer, k_Integer, R_] := 
        Drop[FoldList[#2 + {#1\[LeftDoubleBracket]1\[RightDoubleBracket], 0, 
                  0} &, {0, 0, 0}, \[IndentingNewLine]Drop[
              NestList[
                RandomCoalescenceTimes[#\[LeftDoubleBracket]2\
\[RightDoubleBracket], R] &, {0, k, 0}, n], 1]], 1];\)\)], "Input",
  CellLabel->"In[9]:=",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{

Cell["ExtractLabel", "SubsubsectionIcon",
  InitializationCell->True],

Cell[BoxData[
    \(\(ExtractLabel::usage = "\<ExtractLabel is a rule which replaces \
AncestralLineage[l,\[Ellipsis]] by its label, l.\>";\)\)], "Input",
  CellLabel->"In[10]:=",
  InitializationCell->True],

Cell[BoxData[
    \(\(ExtractLabel = {AncestralLineage[
              l_, {_, _}, _List, _List, _List] \[RuleDelayed] 
            l};\)\)], "Input",
  CellLabel->"In[11]:=",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{

Cell["CoalesceLineages", "SubsubsectionIcon",
  InitializationCell->True],

Cell[BoxData[
    \(\(CoalesceLineages::usage = \
\*"\"\<CoalesceLineages[AncestralLineage[l1,\[Ellipsis]],AncestralLineage[l2,\
\[Ellipsis]],l12,t] gives a lineage l12 which is ancestral to l1, l2, \
generated by a coalescence event at time t.  By default, corresponding \
elements of information lists are put into a set; InformationFunction\[Rule]f \
generates a new information list f[\!\(i\_1\),\!\(i\_2\)]\>\"";\)\)], "Input",\

  CellLabel->"In[12]:=",
  InitializationCell->True],

Cell[BoxData[
    \(\(Options[
          CoalesceLineages] = {InformationFunction \[Rule] \((Transpose[{##}] \
&)\)};\)\)], "Input",
  CellLabel->"In[13]:=",
  InitializationCell->True],

Cell[BoxData[
    \(\(CoalesceLineages::badInfoLists = "\<The information lists associated \
with the two lineages have different lengths.\>";\)\)], "Input",
  CellLabel->"In[14]:=",
  InitializationCell->True],

Cell[BoxData[
    \(\(CoalesceLineages[\[IndentingNewLine]AncestralLineage[_, {_, _}, 
            s1_List, j1_List, i1 : {___List}], 
          AncestralLineage[_, {_, _}, s2_List, j2_List, i2 : {___List}], 
          l12_, t12_, 
          opts___Rule] := \[IndentingNewLine]Module[{if = \
\(InformationFunction /. {opts}\) /. Options[CoalesceLineages], 
            jsl}, \[IndentingNewLine]If[
            Length[i1] \[NotEqual] Length[i2], \[IndentingNewLine]Message[
              CoalesceLineages::badInfoLists, i1, 
              i2]; $Failed, \[IndentingNewLine]jsl = 
              Transpose[
                Sort[Join[
                    Replace[
                      Transpose[{j1, s1}], {j_, s_} \[RuleDelayed] {j, s, 
                          Null}, 1], 
                    Replace[
                      Transpose[{j2, s2}], {j_, s_} \[RuleDelayed] {j, Null, 
                          s}, 1]]]]; \[IndentingNewLine]jsl = 
              Drop[Transpose[
                  jsl //. {a___, Null, x_?\((Not[# === Null] &)\), 
                        b___} \[RuleDelayed] {a, x, x, 
                        b}], \(-1\)]; \[IndentingNewLine]jsl = 
              Replace[jsl, {j_, ss1_, ss2_} \[RuleDelayed] {j, 
                    Union[ss1\[Vee]ss2]}, 1]; \[IndentingNewLine]jsl = 
              jsl //. {a___, {j_?\((Not[ListQ[#]] &)\), 
                      s__}, {j_?\((Not[ListQ[#]] &)\), __}, 
                    b___} \[RuleDelayed] {a, {j, s}, 
                    b}; \[IndentingNewLine]jsl = 
              jsl //. {a___, {_?\((Not[ListQ[#]] &)\), 
                      s__}, {jj2_?\((Not[ListQ[#]] &)\), s__}, 
                    b___} \[RuleDelayed] {a, {jj2, s}, 
                    b}; \[IndentingNewLine]jsl = 
              Transpose[jsl]; \[IndentingNewLine]AncestralLineage[
              l12, {t12, \[Infinity]}, 
              jsl\[LeftDoubleBracket]2\[RightDoubleBracket], 
              jsl\[LeftDoubleBracket]1\[RightDoubleBracket], 
              if[i1, i2]]]];\)\)], "Input",
  CellLabel->"In[15]:=",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{

Cell["InformationFunction", "SubsubsectionIcon",
  InitializationCell->True],

Cell[BoxData[
    \(\(InformationFunction::usage = "\<InformationFunction->f is an option \
for functions dealing with ancestral graphs, which specifies how the \
information associated with each lineage should be handled.\>";\)\)], "Input",\

  CellLabel->"In[16]:=",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{

Cell["RecombineLineage", "SubsubsectionIcon",
  InitializationCell->True],

Cell[BoxData[
    \(\(RecombineLineage::usage = "\<RecombineLineage[AncestralLineage[l,\
\[Ellipsis]],{lL,lR},x,t] generates two recombinant lineages, with breakpoint \
at map position x, and labelled lL, lR. By default, the information lists are \
duplicated; InformationFunction\[Rule]{fL,fR} generates a pair of information \
lists {fL[i],fR[i]}.\>";\)\)], "Input",
  CellLabel->"In[17]:=",
  InitializationCell->True],

Cell[BoxData[
    \(\(Options[
          RecombineLineage] = {InformationFunction \[Rule] {Identity, 
              Identity}};\)\)], "Input",
  CellLabel->"In[18]:=",
  InitializationCell->True],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(RecombineLineage[
          AncestralLineage[_, {_, _}, s_List, j_List, i_List], {lL_, lR_}, 
          x_, t_, opts___Rule] := \[IndentingNewLine]Module[{if = \
\(InformationFunction /. {opts}\) /. Options[RecombineLineage], jsl, jsL, 
            jsR, jsRR}, \[IndentingNewLine]jsl = 
            Transpose[{j, s}]; \[IndentingNewLine]jsRR = 
            Select[jsl, \((#\[LeftDoubleBracket]1\[RightDoubleBracket] > 
                    x)\) &]; \[IndentingNewLine]If[
            jsRR\[LeftDoubleBracket]1, 
                2\[RightDoubleBracket] === {}, \[IndentingNewLine]jsR = 
              Transpose[jsRR]; \[IndentingNewLine]jsL = 
              Transpose[
                Join[Select[
                    jsl, \((#\[LeftDoubleBracket]1\[RightDoubleBracket] \
\[LessEqual] 
                          x)\) &], {{jsR\[LeftDoubleBracket]1, \(-1\)\
\[RightDoubleBracket], {}}}]], \[IndentingNewLine]jsR = 
              Transpose[Prepend[jsRR, {x, {}}]]; \[IndentingNewLine]jsL = 
              Transpose[
                Join[Select[
                    jsl, \((#\[LeftDoubleBracket]1\[RightDoubleBracket] \
\[LessEqual] x)\) &], {{x, 
                      jsR\[LeftDoubleBracket]2, 
                        2\[RightDoubleBracket]}, {jsR\[LeftDoubleBracket]1, \
\(-1\)\[RightDoubleBracket], {}}}]]]; \[IndentingNewLine]{AncestralLineage[
              lL, {t, \[Infinity]}, 
              jsL\[LeftDoubleBracket]2\[RightDoubleBracket], 
              jsL\[LeftDoubleBracket]1\[RightDoubleBracket], \(if\
\[LeftDoubleBracket]1\[RightDoubleBracket]\)[
                i]], \[IndentingNewLine]AncestralLineage[
              lR, {t, \[Infinity]}, 
              jsR\[LeftDoubleBracket]2\[RightDoubleBracket], 
              jsR\[LeftDoubleBracket]1\[RightDoubleBracket], \(if\
\[LeftDoubleBracket]2\[RightDoubleBracket]\)[i]]}];\)\)], "Input",
  CellLabel->"In[19]:=",
  InitializationCell->True],

Cell[BoxData[
    \(General::"spell1" \(\(:\)\(\ \)\) 
      "Possible spelling error: new symbol name \"\!\(jsL\)\" is similar to \
existing symbol \"\!\(jsl\)\"."\)], "Message",
  CellLabel->"From In[19]:="],

Cell[BoxData[
    \(General::"spell1" \(\(:\)\(\ \)\) 
      "Possible spelling error: new symbol name \"\!\(jsRR\)\" is similar to \
existing symbol \"\!\(jsR\)\"."\)], "Message",
  CellLabel->"From In[19]:="]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["Junctions", "SubsubsectionIcon",
  InitializationCell->True],

Cell[BoxData[
    \(\(Junctions::usage = "\<Junctions[AncestralLineage[\[Ellipsis]]] lists \
the junctions present in the lineage.  \
Junctions[{AncestralLineage[\[Ellipsis]]\[Ellipsis]}] lists all the junctions \
present in the ancestral graph. \>";\)\)], "Input",
  CellLabel->"In[20]:=",
  InitializationCell->True],

Cell[BoxData[{
    \(\(Junctions[AncestralLineage[_, {_, _}, _List, j_List, _List]] := 
        Drop[j, \(-1\)];\)\), "\[IndentingNewLine]", 
    \(\(Junctions[g : AncestralGraphPattern] := 
        Union[Flatten[Junctions /@ g]];\)\)}], "Input",
  CellLabel->"In[21]:=",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{

Cell["MapLength", "SubsubsectionIcon",
  InitializationCell->True],

Cell[BoxData[
    \(\(MapLength::usage = "\<MapLength[AncestralLineage[\[Ellipsis]]] or \
MapLength[{AncestralLineage[\[Ellipsis]]\[Ellipsis]}] gives the map length, \
R. \>";\)\)], "Input",
  CellLabel->"In[23]:=",
  InitializationCell->True],

Cell[BoxData[
    \(\(MapLength::mixedLengths = "\<The map lengths `1` differ among \
lineages\>";\)\)], "Input",
  CellLabel->"In[24]:=",
  InitializationCell->True],

Cell[BoxData[{
    \(\(MapLength[AncestralLineage[_, {_, _}, _List, j_List, _List]] := 
        Last[j];\)\), "\[IndentingNewLine]", 
    \(\(MapLength[
          g : AncestralGraphPattern] := \[IndentingNewLine]Module[{ml = 
              Union[MapLength /@ g]}, \[IndentingNewLine]If[
            Length[ml] > 1, \[IndentingNewLine]Message[
              MapLength::mixedLengths, 
              ml]]; \[IndentingNewLine]ml\[LeftDoubleBracket]1\
\[RightDoubleBracket]];\)\)}], "Input",
  CellLabel->"In[25]:=",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{

Cell["LineagesPresent", "SubsubsectionIcon",
  InitializationCell->True],

Cell[BoxData[
    \(\(LineagesPresent::usage = "\<LineagesPresent[{AncestralLineage[\
\[Ellipsis]],\[Ellipsis]},t] gives the set of lineages present at time t. \
LineagesPresent[{AncestralLineage[\[Ellipsis]],\[Ellipsis]}] lists all \
lineages\>";\)\)], "Input",
  CellLabel->"In[27]:=",
  InitializationCell->True],

Cell[BoxData[{
    \(\(LineagesPresent[g : AncestralGraphPattern, 
          t_] := \[IndentingNewLine]Select[
            g, \((#\[LeftDoubleBracket]2, 1\[RightDoubleBracket] \[LessEqual] 
                  t < #\[LeftDoubleBracket]2, 2\[RightDoubleBracket])\) &] /. 
          ExtractLabel;\)\), "\[IndentingNewLine]", 
    \(\(LineagesPresent[g : AncestralGraphPattern] := \[IndentingNewLine]g /. 
          ExtractLabel;\)\)}], "Input",
  CellLabel->"In[28]:=",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{

Cell["Leaves", "SubsubsectionIcon",
  InitializationCell->True],

Cell[CellGroupData[{

Cell[BoxData[
    \("\<Leaves[{AncestralLineage[\[Ellipsis]]\[Ellipsis]}] gives those \
lineages which start at times when no other lineages end\>"\)], "Input",
  CellLabel->"In[30]:=",
  InitializationCell->True],

Cell[BoxData[
    \("Leaves[{AncestralLineage[\[Ellipsis]]\[Ellipsis]}] gives those \
lineages which start at times when no other lineages end"\)], "Output",
  CellLabel->"Out[30]="]
}, Open  ]],

Cell[BoxData[
    \(\(\(Leaves::multipleLineages = "\<Some leaves share the same label: `1`\
\>";\)\(\ \)\)\)], "Input",
  CellLabel->"In[31]:=",
  InitializationCell->True],

Cell[BoxData[
    \(\(Leaves[
          g : AncestralGraphPattern] := \[IndentingNewLine]Module[{ss = 
              Flatten[\(#\[LeftDoubleBracket]3\[RightDoubleBracket] &\) /@ 
                  LeafEvents[g]], uss}, \[IndentingNewLine]uss = 
            Union[ss]; \[IndentingNewLine]If[Not[ss\[Backslash]uss === {}], 
            Message[Leaves::multipleLineages, 
              g]]; \[IndentingNewLine]uss];\)\)], "Input",
  CellLabel->"In[32]:=",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{

Cell["RecombinantLineages", "SubsubsectionIcon",
  InitializationCell->True],

Cell[BoxData[
    \(\(RecombinantLineages::usage = \
"\<RecombinantLineages[{AncestralLineage[\[Ellipsis]]\[Ellipsis]}] gives \
lineages which start at the same time as a sister lineage\>";\)\)], "Input",
  CellLabel->"In[33]:=",
  InitializationCell->True],

Cell[BoxData[
    \(\(\(RecombinantLineages::multipleLineages = "\<Some recombinant \
lineages share the same label: `1`\>";\)\(\ \)\)\)], "Input",
  CellLabel->"In[34]:=",
  InitializationCell->True],

Cell[BoxData[
    \(\(RecombinantLineages[
          g : AncestralGraphPattern] := \[IndentingNewLine]Module[{ss = 
              Flatten[\(#\[LeftDoubleBracket]3\[RightDoubleBracket] &\) /@ 
                  RecombinationEvents[g]], uss}, \[IndentingNewLine]uss = 
            Union[ss]; \[IndentingNewLine]If[Not[ss\[Backslash]uss === {}], 
            Message[RecombinantLineages::multipleLineages, 
              g]]; \[IndentingNewLine]uss];\)\)], "Input",
  CellLabel->"In[35]:=",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{

Cell["CoalescentLineages", "SubsubsectionIcon",
  InitializationCell->True],

Cell[BoxData[
    \(\(CoalescentLineages::usage = "\<CoalescentLineages[{AncestralLineage[\
\[Ellipsis]]\[Ellipsis]}] gives lineages which start at the same time as two \
other lineages end\>";\)\)], "Input",
  CellLabel->"In[36]:=",
  InitializationCell->True],

Cell[BoxData[
    \(\(\(CoalescentLineages::multipleLineages = "\<Some coalescent lineages \
share the same label: `1`\>";\)\(\ \)\)\)], "Input",
  CellLabel->"In[37]:=",
  InitializationCell->True],

Cell[BoxData[
    \(\(CoalescentLineages[
          g : AncestralGraphPattern] := \[IndentingNewLine]Module[{ss = 
              Flatten[\(#\[LeftDoubleBracket]3\[RightDoubleBracket] &\) /@ 
                  CoalescenceEvents[g]], uss}, \[IndentingNewLine]uss = 
            Union[ss]; \[IndentingNewLine]If[Not[ss\[Backslash]uss === {}], 
            Message[CoalescentLineages::multipleLineages, 
              g]]; \[IndentingNewLine]uss];\)\)], "Input",
  CellLabel->"In[38]:=",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{

Cell["RootLineages", "SubsubsectionIcon",
  InitializationCell->True],

Cell[BoxData[
    \(\(RootLineages::usage = "\<RootLineages[{AncestralLineage[\[Ellipsis]]\
\[Ellipsis]}] gives lineages which end when no other lineages \
begin.\>";\)\)], "Input",
  CellLabel->"In[39]:=",
  InitializationCell->True],

Cell[BoxData[
    \(\(\(RootLineages::multipleLineages = "\<Some root lineages share the \
same label: `1`\>";\)\(\ \)\)\)], "Input",
  CellLabel->"In[40]:=",
  InitializationCell->True],

Cell[BoxData[
    \(\(RootLineages[
          g : AncestralGraphPattern] := \[IndentingNewLine]Module[{ss = 
              Flatten[\(\((#\[LeftDoubleBracket]2\[RightDoubleBracket])\) &\) \
/@ RootEvents[g]], uss}, \[IndentingNewLine]uss = 
            Union[ss]; \[IndentingNewLine]If[Not[ss\[Backslash]uss === {}], 
            Message[RootLineages::multipleLineages, 
              g]]; \[IndentingNewLine]uss];\)\)], "Input",
  CellLabel->"In[41]:=",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{

Cell["ExtractInformation", "SubsubsectionIcon",
  InitializationCell->True],

Cell[BoxData[
    \(\(ExtractInformation[g : AncestralGraphPattern, l_] := 
        Last[ExtractLineage[g, l]];\)\)], "Input",
  CellLabel->"In[42]:=",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{

Cell["ExtractLineage", "SubsubsectionIcon",
  InitializationCell->True],

Cell[BoxData[
    \(\(ExtractLineage::usage = \*"\"\<ExtractLineage[{AncestralLineage[\
\[Ellipsis]]\[Ellipsis]},l] extracts the lineage labelled by l.  \
ExtractLineage[{AncestralLineage[\[Ellipsis]]\[Ellipsis]},{\!\(l\_1\),\
\[Ellipsis]}] extracts a list of lineages. Checks that there is only one such \
lineage.\>\"";\)\)], "Input",
  CellLabel->"In[43]:=",
  InitializationCell->True],

Cell[BoxData[
    \(\(ExtractLineage::notPresent = "\<Lineage `1` is not present in the \
graph `2`\>";\)\)], "Input",
  CellLabel->"In[44]:=",
  InitializationCell->True],

Cell[BoxData[
    \(\(ExtractLineage::multipleLineages = "\<Lineage `1` occurs more than \
once in the graph `2`\>";\)\)], "Input",
  CellLabel->"In[45]:=",
  InitializationCell->True],

Cell[BoxData[
    \(\(ExtractLineage[g : AncestralGraphPattern, l_List] := 
        Map[ExtractLineage[g, #] &, l, 1];\)\)], "Input",
  CellLabel->"In[46]:=",
  InitializationCell->True],

Cell[BoxData[
    \(\(ExtractLineage[g : AncestralGraphPattern, l_?\((Not[ListQ[#]] &)\)] := 
        Module[{cs}, \[IndentingNewLine]cs = 
            Cases[g, 
              AncestralLineage[
                l, {_, _}, _List, _List, _List]]; \[IndentingNewLine]Switch[
            Length[cs], \[IndentingNewLine]0, 
            Message[ExtractLineage::notPresent, l, 
              g]; {}, \[IndentingNewLine]1, 
            cs\[LeftDoubleBracket]1\[RightDoubleBracket], \
\[IndentingNewLine]_, Message[ExtractLineage::multipleLineages, l, g]; 
            cs]];\)\)], "Input",
  CellLabel->"In[47]:=",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{

Cell["ExtractLineagesEndingAtT", "SubsubsectionIcon",
  InitializationCell->True],

Cell[BoxData[
    \(\(ExtractLineagesEndingAtT::usage = \
"\<ExtractLineagesEndingAtT[{AncestralLineage[\[Ellipsis]]\[Ellipsis]},t] \
extracts those lineages which end at time t.  These are either root lineages, \
with no ancestors, or are generated by a coalescence or recombination.  \
Checks that these are present in the appropriate numbers.\>";\)\)], "Input",
  CellLabel->"In[48]:=",
  InitializationCell->True],

Cell[BoxData[
    \(\(ExtractLineagesEndingAtT[g : AncestralGraphPattern, t_] := 
        Module[{cs}, \[IndentingNewLine]cs = 
            Cases[g, AncestralLineage[_, {_, t}, _List, _List, _List]] /. 
              ExtractLabel];\)\)], "Input",
  CellLabel->"In[49]:=",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{

Cell["ExtractLineagesStartingAtT", "SubsubsectionIcon",
  InitializationCell->True],

Cell[BoxData[
    \(\(ExtractLineagesStartingAtT::usage = \
"\<ExtractLineagesStartingAtT[{AncestralLineage[\[Ellipsis]]\[Ellipsis]},t] \
extracts those lineages which start at time t.  These are either leaves, with \
no descendants, or are generated by a coalescence or recombination.  Checks \
that these are present in the appropriate numbers.\>";\)\)], "Input",
  CellLabel->"In[50]:=",
  InitializationCell->True],

Cell[BoxData[
    \(\(ExtractLineagesStartingAtT[g : AncestralGraphPattern, t_] := 
        Module[{cs}, \[IndentingNewLine]cs = 
            Cases[g, AncestralLineage[_, {t, _}, _List, _List, _List]] /. 
              ExtractLabel];\)\)], "Input",
  CellLabel->"In[51]:=",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{

Cell["TimesOfEvents", "SubsubsectionIcon",
  InitializationCell->True],

Cell[BoxData[
    \(\(TimesOfEvents::usage = \
"\<TimesOfEvents[{AncestralLineage[\[Ellipsis]]\[Ellipsis]}] lists all the \
times at which lineages begin or end.\>";\)\)], "Input",
  CellLabel->"In[52]:=",
  InitializationCell->True],

Cell[BoxData[
    \(\(TimesOfEvents[g : AncestralGraphPattern] := 
        Union[Flatten[
            g /. AncestralLineage[_, {t0_, 
                    t1_}, _List, _List, _List] \[RuleDelayed] {t0, 
                  t1}]];\)\)], "Input",
  CellLabel->"In[53]:=",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{

Cell["AllEvents", "SubsubsectionIcon",
  InitializationCell->True],

Cell[BoxData[
    \(\(AllEvents::usage = "\<AllEvents[{AncestralLineage[\[Ellipsis]]\
\[Ellipsis]}] lists all events at which lineages begin or end, in the form \
{t,descendants,ancestors,map position}. (The last element is set if there has \
been a recombination event; otherwise it is None).\>";\)\)], "Input",
  CellLabel->"In[54]:=",
  InitializationCell->True],

Cell[BoxData[
    \(\(AllEvents::badJunctions = "\<The junctions at the recombination event \
at t=`1` in graph `2` do not change by 1.\>";\)\)], "Input",
  CellLabel->"In[55]:=",
  InitializationCell->True],

Cell[BoxData[
    \(\(AllEvents::badRelationship = "\<The event at t=`1` in graph `2` does \
not have the right form.\>";\)\)], "Input",
  CellLabel->"In[56]:=",
  InitializationCell->True],

Cell[BoxData[
    \(\(AllEvents[g : AncestralGraphPattern] := \(AllEvents[g] = 
          Module[{cs, ce, 
              jj}, \[IndentingNewLine]\(\((cs = 
                    Cases[g, 
                      AncestralLineage[_, {#, _}, _List, _List, _List]]; \
\[IndentingNewLine]ce = 
                    Cases[g, 
                      AncestralLineage[_, {_, #}, _List, _List, _List]]; \
\[IndentingNewLine]Switch[
                    Length /@ {ce, cs}, \[IndentingNewLine]{0, _} | {_, 
                        0} | {2, 1}, \[IndentingNewLine]{#, 
                      ce /. ExtractLabel, cs /. ExtractLabel, 
                      None}, \[IndentingNewLine]{1, 
                      2}, \[IndentingNewLine]jj = \((cs\[LeftDoubleBracket]1, 
                              4\[RightDoubleBracket]\[Vee]cs\
\[LeftDoubleBracket]2, 4\[RightDoubleBracket])\)\[Backslash]
                        ce\[LeftDoubleBracket]1, 
                          4\[RightDoubleBracket]; \[IndentingNewLine] (*If[\
\[InvisibleSpace]\(! \((MatchQ[jj, {x_, x_, 
                                  1}] || \((Sort[{cs\[LeftDoubleBracket]1, 
                                        3\[RightDoubleBracket], 
                                      cs\[LeftDoubleBracket]2, 
                                        3\[RightDoubleBracket]}] === 
                                  Sort[{{{}}, 
                                      ce\[LeftDoubleBracket]1, 
                                        3\[RightDoubleBracket]}])\))\)\), 
                        Message[AllEvents::"\<badJunctions\>", #1, g]]*)  (*\ 
                      too\ hard\ to\ do\ *) \[IndentingNewLine]If[
                      Not[{} === \(Cases[
                              Transpose[{cs\[LeftDoubleBracket]2, 
                                    4\[RightDoubleBracket], 
                                  cs\[LeftDoubleBracket]2, 
                                    3\[RightDoubleBracket]}], {jj\
\[LeftDoubleBracket]1\[RightDoubleBracket], _}]\)\[LeftDoubleBracket]1, 
                            2\[RightDoubleBracket]], \[IndentingNewLine]cs = 
                        Reverse[cs]]; \[IndentingNewLine]{#, 
                      ce /. ExtractLabel, cs /. ExtractLabel, 
                      jj\[LeftDoubleBracket]1\[RightDoubleBracket]}, \
\[IndentingNewLine]_, \[IndentingNewLine]Message[
                      AllEvents::badRelationship, #, 
                      g]; \[IndentingNewLine]{#, ce /. ExtractLabel, 
                      cs /. ExtractLabel, None}])\) &\) /@ 
              TimesOfEvents[g]]\);\)\)], "Input",
  CellLabel->"In[57]:=",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{

Cell["CoalescenceEvents", "SubsubsectionIcon",
  InitializationCell->True],

Cell[BoxData[
    \(\(CoalescenceEvents::usage = \
\*"\"\<CoalescenceEvents[{AncestralLineage[\[Ellipsis]]\[Ellipsis]}] lists \
events at which lineages {\!\(l\_1\),\[Ellipsis]} coalesce into lineage \!\(l\
\_p\), in the form {t,{\!\(l\_1\),\!\(l\_2\)},\!\(l\_P\)}.\>\"";\)\)], "Input",\

  CellLabel->"In[58]:=",
  InitializationCell->True],

Cell[BoxData[
    \(\(CoalescenceEvents[g : AncestralGraphPattern] := 
        Cases[AllEvents[g], {_, {_, _}, {_}, _}];\)\)], "Input",
  CellLabel->"In[59]:=",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{

Cell["NullLineages", "SubsubsectionIcon"],

Cell[BoxData[
    \(\(NullLineages::usage = "\<NullLineages[g] lists those lineages which \
contain no material ancestral to the sample.\>";\)\)], "Input",
  CellLabel->"In[60]:=",
  InitializationCell->True],

Cell[BoxData[
    \(\(NullLineages[g : AncestralGraphPattern] := \(NullLineages[g] = 
          Cases[g, 
            AncestralLineage[_, {_, _}, {{}}, {MapLength[
                  g]}, _List]]\);\)\)], "Input",
  CellLabel->"In[61]:=",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{

Cell["RecombinationEvents", "SubsubsectionIcon",
  InitializationCell->True],

Cell[BoxData[
    \(\(RecombinationEvents::usage = \
\*"\"\<RecombinationEvents[{AncestralLineage[\[Ellipsis]]\[Ellipsis]}] lists \
events at which a lineages \!\(l\_1\) splits into two lineage {\!\(l\_L\), \!\
\(l\_R\)} in the form {t,{\!\(l\_p\)},{\!\(l\_L\),\!\(l\_R\)},r}.\>\"";\)\)], \
"Input",
  CellLabel->"In[62]:=",
  InitializationCell->True],

Cell[BoxData[
    \(\(RecombinationEvents[
          g : AncestralGraphPattern] := \(RecombinationEvents[g] = 
          Cases[AllEvents[g], {_, {_}, {_, _}, _}]\);\)\)], "Input",
  CellLabel->"In[63]:=",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{

Cell["NullRecombinationEvents", "SubsubsectionIcon",
  InitializationCell->True],

Cell[BoxData[
    \(\(NullRecombinationEvents::usage = \
\*"\"\<NullRecombinationEvents[{AncestralLineage[\[Ellipsis]]\[Ellipsis]}] \
lists events at which a lineages \!\(l\_1\) splits into two lineages \
{\!\(l\_L\), \!\(l\_R\)}, but where one of these is null.  These have the \
form {t,{\!\(l\_p\)},{\!\(l\_L\),\!\(l\_R\)},R}.\>\"";\)\)], "Input",
  CellLabel->"In[64]:=",
  InitializationCell->True],

Cell[BoxData[
    \(\(NullRecombinationEvents[
          g : AncestralGraphPattern] := \(NullRecombinationEvents[g] = 
          Cases[AllEvents[g], {_, {_}, {_, _}, MapLength[g]}]\);\)\)], "Input",\

  CellLabel->"In[65]:=",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{

Cell["LeafEvents", "SubsubsectionIcon",
  InitializationCell->True],

Cell[BoxData[
    \(\(LeafEvents::usage = "\<LeafEvents[{AncestralLineage[\[Ellipsis]]\
\[Ellipsis]}] lists events at which a lineages becomes extinct.\>";\)\)], \
"Input",
  CellLabel->"In[66]:=",
  InitializationCell->True],

Cell[BoxData[
    \(\(LeafEvents[g : AncestralGraphPattern] := \(LeafEvents[g] = 
          Cases[AllEvents[g], {_, {}, {__}, _}]\);\)\)], "Input",
  CellLabel->"In[67]:=",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{

Cell["RootEvents", "SubsubsectionIcon",
  InitializationCell->True],

Cell[BoxData[
    \(\(RootEvents::usage = "\<RootEvents[{AncestralLineage[\[Ellipsis]]\
\[Ellipsis]}] lists events at which an ancestral lineage begins.\>";\)\)], \
"Input",
  CellLabel->"In[68]:=",
  InitializationCell->True],

Cell[BoxData[
    \(\(RootEvents[g : AncestralGraphPattern] := \(RootEvents[g] = 
          Cases[AllEvents[g], {_, {__}, {}, _}]\);\)\)], "Input",
  CellLabel->"In[69]:=",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{

Cell["TimespanOfLineage", "SubsubsectionIcon",
  InitializationCell->True],

Cell[BoxData[
    \(\(TimespanOfLineage::usage = "\<TimespanOfLineage[{AncestralLineage[\
\[Ellipsis]]\[Ellipsis]},l] gives the start and end times,{t0,t1}, of lineage \
l.\>";\)\)], "Input",
  CellLabel->"In[70]:=",
  InitializationCell->True],

Cell[BoxData[
    \(\(TimespanOfLineage[g : AncestralGraphPattern, 
          l_] := \(ExtractLineage[g, 
            l]\)\[LeftDoubleBracket]2\[RightDoubleBracket];\)\)], "Input",
  CellLabel->"In[71]:=",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{

Cell["MapPosition", "SubsubsectionIcon",
  InitializationCell->True],

Cell[BoxData[
    \(\(MapPosition::usage = "\<MapPosition\[Rule]x is an option for \
Descendants which specifies that only descendants at map position x are \
counted.\>";\)\)], "Input",
  CellLabel->"In[72]:=",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{

Cell["Descendants", "SubsubsectionIcon",
  InitializationCell->True],

Cell[BoxData[
    \(\(\*"\"\<Descendants[{AncestralLineage[\[Ellipsis]],\[Ellipsis]},l] \
lists the immediate descendants from lineage l.  MapPosition\[Rule]x \
restricts the list to descendants at map position x.  \
DescendantList\[Rule]All gives a list of all descendants, in  the form {\!\(l\
\_1\),{{\!\(d\_1\),{\[Ellipsis]}},{\!\(d\_2\),{\[Ellipsis]}}}}. \
DescendantList\[Rule]Leaves gives only the descendant leaves.\>\"";\)\)], \
"Input",
  CellLabel->"In[73]:=",
  InitializationCell->True],

Cell[BoxData[
    \(\(Options[Descendants] = {DescendantList \[Rule] Next, 
          MapPosition \[Rule] None};\)\)], "Input",
  CellLabel->"In[74]:=",
  InitializationCell->True],

Cell[BoxData[
    \(\(Descendants::multipleLineages = "\<Several events occur at `1`; \
`2`\>";\)\)], "Input",
  CellLabel->"In[75]:=",
  InitializationCell->True],

Cell[BoxData[
    \(\(Descendants[g : AncestralGraphPattern, l_, 
          opts___Rule] := \[IndentingNewLine]Module[{t0, desc, f, 
            dl = \(DescendantList /. {opts}\) /. Options[Descendants], mp, 
            cs, re}, \[IndentingNewLine]Switch[
            dl, \[IndentingNewLine]Next, \[IndentingNewLine]mp = \
\(MapPosition /. {opts}\) /. Options[Descendants]; \[IndentingNewLine]t0 = 
              TimespanOfLineage[g, l] // First; \[IndentingNewLine]cs = 
              Cases[g, AncestralLineage[_, {_, t0}, _List, _List, _List]] /. 
                ExtractLabel; \[IndentingNewLine]If[
              mp === None, \[IndentingNewLine]cs, \[IndentingNewLine]re = 
                Cases[AllEvents[g], {t0, _, _, _}]; \[IndentingNewLine]If[
                Length[re] \[NotEqual] 1, 
                Message[Descendants::multipleLineages, t0, 
                  g]]; \[IndentingNewLine]If[
                re\[LeftDoubleBracket]1, \(-1\)\[RightDoubleBracket] === 
                  None, \[IndentingNewLine]cs, \[IndentingNewLine]If[\((mp < 
                          re\[LeftDoubleBracket]1, \
\(-1\)\[RightDoubleBracket] && 
                        re\[LeftDoubleBracket]1, 3, 1\[RightDoubleBracket] === 
                          l)\) || \((mp \[GreaterEqual] 
                          re\[LeftDoubleBracket]1, \
\(-1\)\[RightDoubleBracket] && 
                        re\[LeftDoubleBracket]1, 3, 2\[RightDoubleBracket] === 
                          l)\), \[IndentingNewLine]cs, {}]]], \
\[IndentingNewLine]All, \[IndentingNewLine]First[
              FixedPoint[
                Map[AddDescendants[g, #, 
                        opts] &, #, {\(-2\)}] &, \ {l}]], \
\[IndentingNewLine]Leaves, \[IndentingNewLine]First[{l} //. {{x__?\((Not[
                              ListQ[#]] &)\)} \[RuleDelayed] \((\(\((dd = 
                              Descendants[g, #, DescendantList \[Rule] Next, 
                                opts]; 
                            If[dd === {}, #, 
                              dd])\) &\) /@ {x})\)}]]];\)\)], "Input",
  CellLabel->"In[76]:=",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{

Cell["AddDescendants", "SubsubsectionIcon",
  InitializationCell->True],

Cell[BoxData[
    \(\(AddDescendants::usage = "\<AddDescendants[g,{l}] returns \
{l,Descendants[g,l]}.\>";\)\)], "Input",
  CellLabel->"In[77]:=",
  InitializationCell->True],

Cell[BoxData[{
    \(\(AddDescendants[
          g : AncestralGraphPattern, {}, ___Rule] := {};\)\), "\
\[IndentingNewLine]", 
    \(\(AddDescendants[
          g : AncestralGraphPattern, {x__?\((Not[ListQ[#]] &)\)}, 
          opts___Rule] := \[IndentingNewLine]\({#, 
              Descendants[g, #, DescendantList \[Rule] Next, 
                opts]} &\) /@ {x};\)\)}], "Input",
  CellLabel->"In[78]:=",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{

Cell["AncestorList", "SubsubsectionIcon",
  InitializationCell->True],

Cell[BoxData[
    \(\(AncestorList::usage = "\<AncestorList is an option for Ancestors; it \
may be set to Previous, All or Roots\>";\)\)], "Input",
  CellLabel->"In[80]:=",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{

Cell["Ancestors", "SubsubsectionIcon",
  InitializationCell->True],

Cell[BoxData[
    \(\(\*"\"\<Ancestors[{AncestralLineage[\[Ellipsis]],\[Ellipsis]},l] lists \
the immediate ancestors of lineage l.  MapPosition\[Rule]x restricts the list \
to ancestors at map position x.  AncestorList\[Rule]All gives a list of all \
ancestors, in  the form {\!\(l\_1\),{{\!\(d\_1\),{\[Ellipsis]}},{\!\(d\_2\),{\
\[Ellipsis]}}}}.  AncestorList\[Rule]Roots gives only the root \
ancestors.\>\"";\)\)], "Input",
  CellLabel->"In[81]:=",
  InitializationCell->True],

Cell[BoxData[
    \(\(Options[Ancestors] = {AncestorList \[Rule] Previous, 
          MapPosition \[Rule] None};\)\)], "Input",
  CellLabel->"In[82]:=",
  InitializationCell->True],

Cell[BoxData[
    \(\(Ancestors::multipleLineages = "\<Several events occur at `1`; `2`\>";\
\)\)], "Input",
  CellLabel->"In[83]:=",
  InitializationCell->True],

Cell[BoxData[
    \(\(Ancestors[g : AncestralGraphPattern, l_, 
          opts___Rule] := \[IndentingNewLine]Module[{t0, anc, f, 
            al = \(AncestorList /. {opts}\) /. Options[Ancestors], mp, cs, 
            re}, \[IndentingNewLine]Switch[
            al, \[IndentingNewLine]Previous, \[IndentingNewLine]mp = \
\(MapPosition /. {opts}\) /. Options[Ancestors]; \[IndentingNewLine]t0 = 
              TimespanOfLineage[g, l] // Last; \[IndentingNewLine]cs = 
              Cases[g, AncestralLineage[_, {t0, _}, _List, _List, _List]] /. 
                ExtractLabel; \[IndentingNewLine]If[
              mp === None, \[IndentingNewLine]cs, \[IndentingNewLine]re = 
                Cases[AllEvents[g], {t0, _, _, _}]; \[IndentingNewLine]If[
                Length[re] \[NotEqual] 1, 
                Message[Ancestors::multipleLineages, t0, 
                  g]]; \[IndentingNewLine]If[
                re\[LeftDoubleBracket]1, \(-1\)\[RightDoubleBracket] === 
                  None, \[IndentingNewLine]cs, \[IndentingNewLine]If[
                  mp < re\[LeftDoubleBracket]1, \(-1\)\[RightDoubleBracket], \
{re\[LeftDoubleBracket]1, 3, 
                      1\[RightDoubleBracket]}, {re\[LeftDoubleBracket]1, 3, 
                      2\[RightDoubleBracket]}]]], \[IndentingNewLine]All, \
\[IndentingNewLine]First[
              FixedPoint[
                Map[AddAncestors[g, #, 
                        opts] &, #, {\(-2\)}] &, \ {l}]], \
\[IndentingNewLine]Roots, \[IndentingNewLine]First[{l} //. {{x__?\((Not[
                              ListQ[#]] &)\)} \[RuleDelayed] \((y = 
                        Union[Flatten[\((\(\((dd = 
                                      Ancestors[g, #, 
                                        AncestorList \[Rule] Previous, opts]; 
                                    If[dd === {}, #, 
                                      dd])\) &\) /@ {x})\)]];  (*\(Print[
                            y];\)*) y)\)}]]];\)\)], "Input",
  CellLabel->"In[84]:=",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{

Cell["Problem with Ancestors", "SubsubsectionIcon"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(NestList[\((# /. {{x__?\((Not[
                            ListQ[#]] &)\)} \[RuleDelayed] \((\(\((dd = 
                            Ancestors[ng2, #]; 
                          If[dd === {}, #, dd])\) &\) /@ {x})\)})\) &, {a}, 
        20]\)\[LeftDoubleBracket]{\(-2\), \(-1\)}\[RightDoubleBracket]\)], \
"Input",
  CellLabel->"In[404]:="],

Cell[BoxData[
    \({{{{{{{{{{{{{{{{{{{{{33, 34}}}, {{{33, 
                                        34}}}}, {{{{44}}, {{44}, {43}}}}}}, \
{{{{{{33, 34}}}, {{{33, 34}}}}, {{{{44}}, {{44}, {43}}}}}}}}, {{{{{{{{33, 
                                        34}}}, {{{33, 
                                        34}}}}, {{{{44}}, {{44}, {43}}}}}}, \
{{{{{{33, 34}}}, {{{33, 34}}}}, {{{{44}}, {{44}, {43}}}}}}}}}}, {{{{{{{{{{33, 
                                        34}}}, {{{33, 
                                        34}}}}, {{{{44}}, {{44}, {43}}}}}}, \
{{{{{{33, 34}}}, {{{33, 34}}}}, {{{{44}}, {{44}, {43}}}}}}}}, {{{{{{{{33, 
                                        34}}}, {{{33, 
                                        34}}}}, {{{{44}}, {{44}, {43}}}}}}, \
{{{{{{33, 34}}}, {{{33, 
                                        34}}}}, {{{{44}}, {{44}, \
{43}}}}}}}}}}}}, {{{{{{{{{{{{33, 34}}}, {{{33, 
                                        34}}}}, {{{{44}}, {{44}, {43}}}}}}, \
{{{{{{33, 34}}}, {{{33, 34}}}}, {{{{44}}, {{44}, {43}}}}}}}}, {{{{{{{{33, 
                                        34}}}, {{{33, 
                                        34}}}}, {{{{44}}, {{44}, {43}}}}}}, \
{{{{{{33, 34}}}, {{{33, 34}}}}, {{{{44}}, {{44}, {43}}}}}}}}}}, {{{{{{{{{{33, 
                                        34}}}, {{{33, 
                                        34}}}}, {{{{44}}, {{44}, {43}}}}}}, \
{{{{{{33, 34}}}, {{{33, 34}}}}, {{{{44}}, {{44}, {43}}}}}}}}, {{{{{{{{33, 
                                        34}}}, {{{33, 
                                        34}}}}, {{{{44}}, {{44}, {43}}}}}}, \
{{{{{{33, 34}}}, {{{33, 
                                        34}}}}, {{{{44}}, {{44}, \
{43}}}}}}}}}}}}}}, {{{{{{{{{{{{48, 49}, 47}}}}, {{{{{48, 49}, 
                                        47}}}, {{{{{48, 49}, 
                                        47}}}}}}}}, {{{{48, 49}, 
                                47}}, {{{{{{{{48, 49}, 47}}}}, {{{{{48, 49}, 
                                        47}}}, {{{{{48, 49}, 
                                        47}}}}}}}}}}}}, {{{{{{{{{{{48, 49}, 
                                        47}}}}, {{{{{48, 49}, 
                                        47}}}, {{{{{48, 49}, 
                                        47}}}}}}}}, {{{{48, 49}, 
                                47}}, {{{{{{{{48, 49}, 47}}}}, {{{{{48, 49}, 
                                        47}}}, {{{{{48, 49}, 
                                        47}}}}}}}}}}}}}}}, \
{{{{{{{{{{{{{{{{33, 34}}}, {{{33, 
                                        34}}}}, {{{{44}}, {{44}, {43}}}}}}, \
{{{{{{33, 34}}}, {{{33, 34}}}}, {{{{44}}, {{44}, {43}}}}}}}}, {{{{{{{{33, 
                                        34}}}, {{{33, 
                                        34}}}}, {{{{44}}, {{44}, {43}}}}}}, \
{{{{{{33, 34}}}, {{{33, 34}}}}, {{{{44}}, {{44}, {43}}}}}}}}}}, {{{{{{{{{{33, 
                                        34}}}, {{{33, 
                                        34}}}}, {{{{44}}, {{44}, {43}}}}}}, \
{{{{{{33, 34}}}, {{{33, 34}}}}, {{{{44}}, {{44}, {43}}}}}}}}, {{{{{{{{33, 
                                        34}}}, {{{33, 
                                        34}}}}, {{{{44}}, {{44}, {43}}}}}}, \
{{{{{{33, 34}}}, {{{33, 
                                        34}}}}, {{{{44}}, {{44}, \
{43}}}}}}}}}}}}, {{{{{{{{{{{{33, 34}}}, {{{33, 
                                        34}}}}, {{{{44}}, {{44}, {43}}}}}}, \
{{{{{{33, 34}}}, {{{33, 34}}}}, {{{{44}}, {{44}, {43}}}}}}}}, {{{{{{{{33, 
                                        34}}}, {{{33, 
                                        34}}}}, {{{{44}}, {{44}, {43}}}}}}, \
{{{{{{33, 34}}}, {{{33, 34}}}}, {{{{44}}, {{44}, {43}}}}}}}}}}, {{{{{{{{{{33, 
                                        34}}}, {{{33, 
                                        34}}}}, {{{{44}}, {{44}, {43}}}}}}, \
{{{{{{33, 34}}}, {{{33, 34}}}}, {{{{44}}, {{44}, {43}}}}}}}}, {{{{{{{{33, 
                                        34}}}, {{{33, 
                                        34}}}}, {{{{44}}, {{44}, {43}}}}}}, \
{{{{{{33, 34}}}, {{{33, 
                                        34}}}}, {{{{44}}, {{44}, \
{43}}}}}}}}}}}}}}, {{{{{{{{{{{{48, 49}, 47}}}}, {{{{{48, 49}, 
                                        47}}}, {{{{{48, 49}, 
                                        47}}}}}}}}, {{{{48, 49}, 
                                47}}, {{{{{{{{48, 49}, 47}}}}, {{{{{48, 49}, 
                                        47}}}, {{{{{48, 49}, 
                                        47}}}}}}}}}}}}, {{{{{{{{{{{48, 49}, 
                                        47}}}}, {{{{{48, 49}, 
                                        47}}}, {{{{{48, 49}, 
                                        47}}}}}}}}, {{{{48, 49}, 
                                47}}, {{{{{{{{48, 49}, 47}}}}, {{{{{48, 49}, 
                                        47}}}, {{{{{48, 49}, 
                                        47}}}}}}}}}}}}}}}}}}}, \
{{{{{{{{{{{{{{{{{{{{{37}, {35, 36}}}}, {{{{37}, {35, 
                                        36}}}}}, {{{{{45}}}, {{{45}}, \
{{44}}}}}}}, {{{{{{{37}, {35, 36}}}}, {{{{37}, {35, 
                                        36}}}}}, {{{{{45}}}, {{{45}}, \
{{44}}}}}}}}}, {{{{{{{{{37}, {35, 36}}}}, {{{{37}, {35, 
                                        36}}}}}, {{{{{45}}}, {{{45}}, \
{{44}}}}}}}, {{{{{{{37}, {35, 36}}}}, {{{{37}, {35, 
                                        36}}}}}, {{{{{45}}}, {{{45}}, \
{{44}}}}}}}}}}}, {{{{{{{{{{{37}, {35, 36}}}}, {{{{37}, {35, 
                                        36}}}}}, {{{{{45}}}, {{{45}}, \
{{44}}}}}}}, {{{{{{{37}, {35, 36}}}}, {{{{37}, {35, 
                                        36}}}}}, {{{{{45}}}, {{{45}}, \
{{44}}}}}}}}}, {{{{{{{{{37}, {35, 36}}}}, {{{{37}, {35, 
                                        36}}}}}, {{{{{45}}}, {{{45}}, \
{{44}}}}}}}, {{{{{{{37}, {35, 36}}}}, {{{{37}, {35, 
                                        36}}}}}, {{{{{45}}}, {{{45}}, \
{{44}}}}}}}}}}}}}, {{{{{{{{{{{{{37}, {35, 36}}}}, {{{{37}, {35, 
                                        36}}}}}, {{{{{45}}}, {{{45}}, \
{{44}}}}}}}, {{{{{{{37}, {35, 36}}}}, {{{{37}, {35, 
                                        36}}}}}, {{{{{45}}}, {{{45}}, \
{{44}}}}}}}}}, {{{{{{{{{37}, {35, 36}}}}, {{{{37}, {35, 
                                        36}}}}}, {{{{{45}}}, {{{45}}, \
{{44}}}}}}}, {{{{{{{37}, {35, 36}}}}, {{{{37}, {35, 
                                        36}}}}}, {{{{{45}}}, {{{45}}, \
{{44}}}}}}}}}}}, {{{{{{{{{{{37}, {35, 36}}}}, {{{{37}, {35, 
                                        36}}}}}, {{{{{45}}}, {{{45}}, \
{{44}}}}}}}, {{{{{{{37}, {35, 36}}}}, {{{{37}, {35, 
                                        36}}}}}, {{{{{45}}}, {{{45}}, \
{{44}}}}}}}}}, {{{{{{{{{37}, {35, 36}}}}, {{{{37}, {35, 
                                        36}}}}}, {{{{{45}}}, {{{45}}, \
{{44}}}}}}}, {{{{{{{37}, {35, 36}}}}, {{{{37}, {35, 
                                        36}}}}}, {{{{{45}}}, {{{45}}, \
{{44}}}}}}}}}}}}}}}, {{{{{{{{{{{{48, 49}, 47}}}}, {{{{{48, 49}, 
                                        47}}}, {{{{{48, 49}, 
                                        47}}}}}}}}, {{{{48, 49}, 
                                47}}, {{{{{{{{48, 49}, 47}}}}, {{{{{48, 49}, 
                                        47}}}, {{{{{48, 49}, 
                                        47}}}}}}}}}}}}, {{{{{{{{{{{48, 49}, 
                                        47}}}}, {{{{{48, 49}, 
                                        47}}}, {{{{{48, 49}, 
                                        47}}}}}}}}, {{{{48, 49}, 
                                47}}, {{{{{{{{48, 49}, 47}}}}, {{{{{48, 49}, 
                                        47}}}, {{{{{48, 49}, 
                                        47}}}}}}}}}}}}}}}, \
{{{{{{{{{{{{{{{{{37}, {35, 36}}}}, {{{{37}, {35, 
                                        36}}}}}, {{{{{45}}}, {{{45}}, \
{{44}}}}}}}, {{{{{{{37}, {35, 36}}}}, {{{{37}, {35, 
                                        36}}}}}, {{{{{45}}}, {{{45}}, \
{{44}}}}}}}}}, {{{{{{{{{37}, {35, 36}}}}, {{{{37}, {35, 
                                        36}}}}}, {{{{{45}}}, {{{45}}, \
{{44}}}}}}}, {{{{{{{37}, {35, 36}}}}, {{{{37}, {35, 
                                        36}}}}}, {{{{{45}}}, {{{45}}, \
{{44}}}}}}}}}}}, {{{{{{{{{{{37}, {35, 36}}}}, {{{{37}, {35, 
                                        36}}}}}, {{{{{45}}}, {{{45}}, \
{{44}}}}}}}, {{{{{{{37}, {35, 36}}}}, {{{{37}, {35, 
                                        36}}}}}, {{{{{45}}}, {{{45}}, \
{{44}}}}}}}}}, {{{{{{{{{37}, {35, 36}}}}, {{{{37}, {35, 
                                        36}}}}}, {{{{{45}}}, {{{45}}, \
{{44}}}}}}}, {{{{{{{37}, {35, 36}}}}, {{{{37}, {35, 
                                        36}}}}}, {{{{{45}}}, {{{45}}, \
{{44}}}}}}}}}}}}}, {{{{{{{{{{{{{37}, {35, 36}}}}, {{{{37}, {35, 
                                        36}}}}}, {{{{{45}}}, {{{45}}, \
{{44}}}}}}}, {{{{{{{37}, {35, 36}}}}, {{{{37}, {35, 
                                        36}}}}}, {{{{{45}}}, {{{45}}, \
{{44}}}}}}}}}, {{{{{{{{{37}, {35, 36}}}}, {{{{37}, {35, 
                                        36}}}}}, {{{{{45}}}, {{{45}}, \
{{44}}}}}}}, {{{{{{{37}, {35, 36}}}}, {{{{37}, {35, 
                                        36}}}}}, {{{{{45}}}, {{{45}}, \
{{44}}}}}}}}}}}, {{{{{{{{{{{37}, {35, 36}}}}, {{{{37}, {35, 
                                        36}}}}}, {{{{{45}}}, {{{45}}, \
{{44}}}}}}}, {{{{{{{37}, {35, 36}}}}, {{{{37}, {35, 
                                        36}}}}}, {{{{{45}}}, {{{45}}, \
{{44}}}}}}}}}, {{{{{{{{{37}, {35, 36}}}}, {{{{37}, {35, 
                                        36}}}}}, {{{{{45}}}, {{{45}}, \
{{44}}}}}}}, {{{{{{{37}, {35, 36}}}}, {{{{37}, {35, 
                                        36}}}}}, {{{{{45}}}, {{{45}}, \
{{44}}}}}}}}}}}}}}}, {{{{{{{{{{{{48, 49}, 47}}}}, {{{{{48, 49}, 
                                        47}}}, {{{{{48, 49}, 
                                        47}}}}}}}}, {{{{48, 49}, 
                                47}}, {{{{{{{{48, 49}, 47}}}}, {{{{{48, 49}, 
                                        47}}}, {{{{{48, 49}, 
                                        47}}}}}}}}}}}}, {{{{{{{{{{{48, 49}, 
                                        47}}}}, {{{{{48, 49}, 
                                        47}}}, {{{{{48, 49}, 
                                        47}}}}}}}}, {{{{48, 49}, 
                                47}}, {{{{{{{{48, 49}, 47}}}}, {{{{{48, 49}, 
                                        47}}}, {{{{{48, 49}, 
                                        47}}}}}}}}}}}}}}}}}}}}\)], "Output",
  CellLabel->"Out[404]="]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    \({a} /. {{x__?\((Not[ListQ[#]] &)\)} \[RuleDelayed] \((\(\((dd = 
                    Ancestors[ng2, #, MapPosition \[Rule] 0.2]; 
                  If[dd === {}, #, dd])\) &\) /@ {x})\)}\)], "Input",
  CellLabel->"In[409]:="],

Cell[BoxData[
    \({{4}}\)], "Output",
  CellLabel->"Out[409]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \({a} //. {{x__?\((Not[ListQ[#]] &)\)} \[RuleDelayed] 
          Flatten[\((\(\((dd = Ancestors[ng2, #, MapPosition \[Rule] 0.2]; 
                    If[dd === {}, #, dd])\) &\) /@ {x})\)]}\)], "Input",
  CellLabel->"In[440]:="],

Cell[BoxData[
    \({48}\)], "Output",
  CellLabel->"Out[440]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(Ancestors[ng2, a, AncestorList \[Rule] Roots]\)], "Input",
  CellLabel->"In[453]:="],

Cell[BoxData[
    \({4}\)], "Print",
  CellLabel->"From In[453]:="],

Cell[BoxData[
    \({5}\)], "Print",
  CellLabel->"From In[453]:="],

Cell[BoxData[
    \({6, 7}\)], "Print",
  CellLabel->"From In[453]:="],

Cell[BoxData[
    \({8}\)], "Print",
  CellLabel->"From In[453]:="],

Cell[BoxData[
    \({9, 10}\)], "Print",
  CellLabel->"From In[453]:="],

Cell[BoxData[
    \({11, 28, 29}\)], "Print",
  CellLabel->"From In[453]:="],

Cell[BoxData[
    \({12, 13, 30, 31}\)], "Print",
  CellLabel->"From In[453]:="],

Cell[BoxData[
    \({14, 32}\)], "Print",
  CellLabel->"From In[453]:="],

Cell[BoxData[
    \({15, 16, 33, 34}\)], "Print",
  CellLabel->"From In[453]:="],

Cell[BoxData[
    \({17, 35, 36, 37}\)], "Print",
  CellLabel->"From In[453]:="],

Cell[BoxData[
    \({18, 19, 37, 38, 45}\)], "Print",
  CellLabel->"From In[453]:="],

Cell[BoxData[
    \({20, 38, 39, 40, 46, 47}\)], "Print",
  CellLabel->"From In[453]:="],

Cell[BoxData[
    \({21, 22, 39, 40, 41, 42, 43, 47, 48, 49}\)], "Print",
  CellLabel->"From In[453]:="],

Cell[BoxData[
    \({23, 41, 42, 43, 44, 47, 48, 49}\)], "Print",
  CellLabel->"From In[453]:="],

Cell[BoxData[
    \({24, 25, 43, 44, 45, 47, 48, 49}\)], "Print",
  CellLabel->"From In[453]:="],

Cell[BoxData[
    \({26, 27, 38, 44, 45, 46, 47, 48, 49}\)], "Print",
  CellLabel->"From In[453]:="],

Cell[BoxData[
    \({30, 31, 39, 40, 45, 46, 47, 48, 49}\)], "Print",
  CellLabel->"From In[453]:="],

Cell[BoxData[
    \({32, 41, 42, 43, 46, 47, 48, 49}\)], "Print",
  CellLabel->"From In[453]:="],

Cell[BoxData[
    \({33, 34, 43, 44, 47, 48, 49}\)], "Print",
  CellLabel->"From In[453]:="],

Cell[BoxData[
    \({35, 36, 37, 44, 45, 47, 48, 49}\)], "Print",
  CellLabel->"From In[453]:="],

Cell[BoxData[
    \({37, 38, 45, 46, 47, 48, 49}\)], "Print",
  CellLabel->"From In[453]:="],

Cell[BoxData[
    \({38, 39, 40, 46, 47, 48, 49}\)], "Print",
  CellLabel->"From In[453]:="],

Cell[BoxData[
    \({39, 40, 41, 42, 43, 47, 48, 49}\)], "Print",
  CellLabel->"From In[453]:="],

Cell[BoxData[
    \({41, 42, 43, 44, 47, 48, 49}\)], "Print",
  CellLabel->"From In[453]:="],

Cell[BoxData[
    \({43, 44, 45, 47, 48, 49}\)], "Print",
  CellLabel->"From In[453]:="],

Cell[BoxData[
    \({44, 45, 46, 47, 48, 49}\)], "Print",
  CellLabel->"From In[453]:="],

Cell[BoxData[
    \({45, 46, 47, 48, 49}\)], "Print",
  CellLabel->"From In[453]:="],

Cell[BoxData[
    \({46, 47, 48, 49}\)], "Print",
  CellLabel->"From In[453]:="],

Cell[BoxData[
    \({47, 48, 49}\)], "Print",
  CellLabel->"From In[453]:="],

Cell[BoxData[
    \({47, 48, 49}\)], "Print",
  CellLabel->"From In[453]:="],

Cell[BoxData[
    \(47\)], "Output",
  CellLabel->"Out[453]="]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["AddAncestors", "SubsubsectionIcon",
  InitializationCell->True],

Cell[BoxData[
    \(\(AddAncestors::usage = "\<AddAncestors[g,{l}] returns \
{l,Ancestors[g,l]}.\>";\)\)], "Input",
  CellLabel->"In[85]:=",
  InitializationCell->True],

Cell[BoxData[{
    \(\(AddAncestors[
          g : AncestralGraphPattern, {}, ___Rule] := {};\)\), "\
\[IndentingNewLine]", 
    \(\(AddAncestors[g : AncestralGraphPattern, {x__?\((Not[ListQ[#]] &)\)}, 
          opts___Rule] := \[IndentingNewLine]\({#, 
              Ancestors[g, #, AncestorList \[Rule] Previous, 
                opts]} &\) /@ {x};\)\)}], "Input",
  CellLabel->"In[86]:=",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{

Cell["ExtractGenealogy", "SubsubsectionIcon",
  InitializationCell->True],

Cell[BoxData[
    \(\(ExtractGenealogy::usage = "\<ExtractGenealogy[{AncestralLineage[\
\[Ellipsis]]\[Ellipsis]},x] generates the genealogy corresponding to map \
position x. InformationFunction->f generates an information list f[i,x]. \
ExtractGenealogy[{AncestralLineage[\[Ellipsis]]\[Ellipsis]}] generates the \
set of genealogies, applying to segments demarcated by Junctions[g].  All \
parts of the genome must have a single common ancestor.\>";\)\)], "Input",
  CellLabel->"In[88]:=",
  InitializationCell->True],

Cell[BoxData[
    \(\(ExtractGenealogy::multipleRoots = "\<Some of the leaves `1` have more \
than one ancestral lineage at map position `3`: `2`\>";\)\)], "Input",
  CellLabel->"In[89]:=",
  InitializationCell->True],

Cell[BoxData[
    \(\(ExtractGenealogy[g : AncestralGraphPattern, 
          x_] := \[IndentingNewLine]Module[{ng = g, ds, ll = Leaves[g], 
            rl}, \[IndentingNewLine]rl = 
            Union[\(Ancestors[g, #, AncestorList \[Rule] Roots, 
                    MapPosition \[Rule] x] &\) /@ 
                ll]; \[IndentingNewLine]Print[rl]; \[IndentingNewLine]If[
            Length[rl] \[Equal] 1, \[IndentingNewLine]ds = 
              Descendants[g, rl\[LeftDoubleBracket]1\[RightDoubleBracket], 
                MapPosition \[Rule] x, 
                DescendantList \[Rule] All]; \[IndentingNewLine]ds = 
              ds //. {a___, {l_?\((Not[MemberQ[ll, \ #]] &)\), {}}, 
                    b___} \[RuleDelayed] {a, 
                    b}; \[IndentingNewLine]ListToGenealogy[
              ds, \[IndentingNewLine]NodeFunction \[Rule] \(({First[
                        TimespanOfLineage[
                          g, #]]} &)\)], \[IndentingNewLine]Message[
              ExtractGenealogy::multipleRoots, ll, rl, 
              x]; $Failed]];\)\)], "Input",
  CellLabel->"In[90]:=",
  InitializationCell->True],

Cell[BoxData[
    \(\(\( (*\ 
      This\ is\ an\ old\ piece\ of\ code\ which\ is\ in\ some\ ways\ more\ \
efficient*) \)\(\[IndentingNewLine]\)\( \
(*\[IndentingNewLine]\(ExtractGenealogy[g : AncestralGraphPattern, 
            x_] := \[IndentingNewLine]Module[{ng = g, ds, ll = Leaves[g], 
              rl}, \[IndentingNewLine]rl = \(Union[
                    Flatten[
                      Ancestors[g, #, AncestorList \[Rule] Roots]]] &\) /@ 
                ll; \[IndentingNewLine]If[
              And @@ \((\(Length[#] \[Equal] 1 &\) /@ 
                    rl)\), \[IndentingNewLine]ds = 
                RecombinationEvents[
                    g] /. {_, _, {aL_, aR_}, j_} \[RuleDelayed] 
                    If[x < j, aR, aL]; \[IndentingNewLine]\(\((ng = 
                      DeleteCases[ng, 
                        AncestralLineage[#, {_, _}, _List, _List, _List]])\) \
&\) /@ ds; \[IndentingNewLine]ng, \[IndentingNewLine]Message[
                ExtractGenealogy::multipleRoots, ll, 
                rl]; $Failed]];\)\[IndentingNewLine]*) \)\)\)], "Input",
  CellLabel->"In[91]:=",
  InitializationCell->True],

Cell[BoxData[
    \(\(ExtractGenealogy[g : AncestralGraphPattern] := 
        Module[{js = 
              Junctions[g]}, \[IndentingNewLine]\(ExtractGenealogy[
                g, #] &\) /@ \(\(Prepend[js, 0] + 
                  Append[js, 1]\)\/2\)];\)\)], "Input",
  CellLabel->"In[92]:=",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{

Cell["DeleteNullLineages", "SubsubsectionIcon"],

Cell[BoxData[
    \(\(DeleteNullLineages::usage = "\<DeleteNullLineages is an option for \
AddRecombinantLineages which specifies whether lineages carrying no material \
ancestral to thhe sample are to be included.\>";\)\)], "Input",
  CellLabel->"In[93]:=",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{

Cell["AddRecombinantLineages", "SubsubsectionIcon",
  InitializationCell->True],

Cell[BoxData[
    \(\(AddRecombinantLineages::usage = \
"\<AddRecombinantLineages[g,l,{lL,lR},x,t] terminates lineage l, and adds two \
recombinant lineages {lL,lR} to the list g. DeleteNullLineages->True ignores \
null recombination events.\>";\)\)], "Input",
  CellLabel->"In[94]:=",
  InitializationCell->True],

Cell[BoxData[
    \(\(Options[
          AddRecombinantLineages] = {DeleteNullLineages \[Rule] 
            False};\)\)], "Input",
  CellLabel->"In[95]:=",
  InitializationCell->True],

Cell[BoxData[
    \(\(AddRecombinantLineages[g : AncestralGraphPattern, l_, {lL_, lR_}, x_, 
          t_, opts___Rule] := \[IndentingNewLine]Module[{rl = 
              RecombineLineage[ExtractLineage[g, l], {lL, lR}, x, 
                t]}, \[IndentingNewLine]If[\((\(DeleteNullLineages /. \
{opts}\) /. Options[
                    AddRecombinantLineages])\) && \((rl\[LeftDoubleBracket]1, 
                      3\[RightDoubleBracket] === {{}} || 
                  rl\[LeftDoubleBracket]2, 
                      3\[RightDoubleBracket] === {{}})\), \
\[IndentingNewLine]g, \[IndentingNewLine]Join[
              g /. AncestralLineage[l, {t0_, \[Infinity]}, s_, j_, 
                    i_] \[RuleDelayed] AncestralLineage[l, {t0, t}, s, j, i], 
              rl]]];\)\)], "Input",
  CellLabel->"In[96]:=",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{

Cell["AddCoalescentLineage", "SubsubsectionIcon",
  InitializationCell->True],

Cell[BoxData[
    \(\(AddCoalescentLineage::usage = "\<AddCoalescentLineage[g,{l1,l2},lC,t] \
terminates lineages {l1,l2} at t, and adds a coalescent lineages lC to the \
list g.\>";\)\)], "Input",
  CellLabel->"In[97]:=",
  InitializationCell->True],

Cell[BoxData[
    \(\(AddCoalescentLineage[g : AncestralGraphPattern, {l1_, l2_}, lC_, t_] := 
        Module[{cl = 
              CoalesceLineages[ExtractLineage[g, l1], ExtractLineage[g, l2], 
                lC, t]}, 
          Append[g /. 
              AncestralLineage[ll : l1 | l2, {t0_, \[Infinity]}, s_, j_, 
                  i_] \[RuleDelayed] AncestralLineage[ll, {t0, t}, s, j, i], 
            cl]];\)\)], "Input",
  CellLabel->"In[98]:=",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{

Cell["PrintDetails", "SubsubsectionIcon"],

Cell[BoxData[
    \(\(PrintDetails::usage = "\<PrintDetails is an option for \
RandomGenealogy\>";\)\)], "Input",
  CellLabel->"In[99]:=",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{

Cell["RandomGenealogy", "SubsubsectionIcon",
  InitializationCell->True],

Cell[BoxData[
    \(\(\*"\"\<RandomGenealogy[{\!\(leaf\_1\),\!\(leaf\_2\)\[Ellipsis]},n,R] \
gives a random realisation of the coalescent process with recombination; \
there are n events. \
RandomGenealogy[{\!\(leaf\_1\),\!\(leaf\_2\)\[Ellipsis]},{{\!\(t\_1\),\!\(k\_\
1\),\!\(x\_1\)}\[Ellipsis]},R] gives a random realisation for a specific \
sequence of events, generated by RandomCoalescenceTimes[n,k,R]; this \
preserves null lineages, however.  DeletNullLineages->True ignores null \
events; can only be used with the first form.\>\"";\)\)], "Input",
  CellLabel->"In[191]:=",
  InitializationCell->True],

Cell[BoxData[
    \(\(Options[RandomGenealogy] = {NodeLabels \[Rule] None, 
          MutationRate \[Rule] None, 
          PrintDetails \[Rule] False};\)\)], "Input",
  CellLabel->"In[192]:=",
  InitializationCell->True],

Cell[BoxData[{
    \(\(RandomGenealogy::badRec = "\<Attempt to add recombinant lineages \
derived from `1` to `2` failed.\>";\)\), "\[IndentingNewLine]", 
    \(\(RandomGenealogy::oneRec = "\<Only one recombinant lineages derived \
from `1` added to `2`: error.\>";\)\)}], "Input",
  CellLabel->"In[193]:=",
  InitializationCell->True],

Cell[BoxData[
    \(\(RandomGenealogy[ll_List, n_Integer, R_, 
          opts___Rule] := \[IndentingNewLine]Module[{rct, g1, 
            g0 = \(AncestralLineage[#, {0, \[Infinity]}, {{#}}, {R}, {}] &\) /@ 
                ll, k = 0, lvs = ll, nl, t = 0, 
            pd = \(PrintDetails /. {opts}\) /. 
                Options[RandomGenealogy]}, \[IndentingNewLine]Do[\((rct = 
                RandomCoalescenceTimes[Length[lvs], R]; 
              t += rct\[LeftDoubleBracket]1\[RightDoubleBracket]; \
\[IndentingNewLine]If[pd, Print[rct]]; \[IndentingNewLine]If[
                Last[rct] === None, \[IndentingNewLine]nl = 
                  RandomSet[2, lvs]; \[IndentingNewLine]If[pd, 
                  Print["\<Coalescing \>", nl, "\<; current lineages \>", 
                    lvs]]; \[IndentingNewLine]g1 = 
                  AddCoalescentLineage[g0, nl, k + 1, 
                    t]; \[IndentingNewLine]lvs = 
                  Append[lvs\[Backslash]nl, k + 1]; 
                k += 1, \[IndentingNewLine]nl = \(RandomSet[1, 
                      lvs]\)\[LeftDoubleBracket]1\[RightDoubleBracket]; \
\[IndentingNewLine]If[pd, 
                  Print["\<Recombining \>", nl, "\<; current lineages \>", 
                    lvs]]; \[IndentingNewLine]g1 = 
                  AddRecombinantLineages[g0, nl, {k + 1, k + 2}, 
                    rct\[LeftDoubleBracket]3\[RightDoubleBracket], t, 
                    opts]; \[IndentingNewLine]Switch[
                  Length[g1] - Length[g0], \[IndentingNewLine]0, 
                  Null, \[IndentingNewLine]1, 
                  Message[RandomGenealogy::oneRec, nl, 
                    g1]; \[IndentingNewLine]lvs = 
                    Join[lvs\[Backslash]{nl}, {k + 1}]; 
                  k += 1, \[IndentingNewLine]2, 
                  lvs = Join[lvs\[Backslash]{nl}, {k + 1, k + 2}]; 
                  k += 2, \[IndentingNewLine]_, 
                  Message[RandomGenealogy::badRec, nl, 
                    g1]]]; \[IndentingNewLine]If[pd, Print["\<G=\>", g1]]; 
              g0 = g1)\), {n}]; \[IndentingNewLine]g1];\)\)], "Input",
  CellLabel->"In[195]:=",
  InitializationCell->True],

Cell[BoxData[
    \(\(RandomGenealogy[ll_List, rct : {{_, _Integer, _} ... }, R_, 
          opts___Rule] := \[IndentingNewLine]Module[{g1, 
            g0 = \(AncestralLineage[#, {0, \[Infinity]}, {{#}}, {R}, {}] &\) /@ 
                ll, k = 0, lvs = ll, nl, 
            pd = \(PrintDetails /. {opts}\) /. 
                Options[
                  RandomGenealogy]}, \[IndentingNewLine]\(\((Print[#]; \
\[IndentingNewLine]If[
                  Last[#] === None, \[IndentingNewLine]nl = 
                    RandomSet[2, lvs]; \[IndentingNewLine]If[pd, 
                    Print["\<Coalescing \>", nl, "\<; current lineages \>", 
                      lvs]]; \[IndentingNewLine]g1 = 
                    AddCoalescentLineage[g0, nl, 
                      k + 1, #\[LeftDoubleBracket]1\[RightDoubleBracket]]; \
\[IndentingNewLine]lvs = Append[lvs\[Backslash]nl, k + 1]; 
                  k += 1, \[IndentingNewLine]nl = \(RandomSet[1, 
                        lvs]\)\[LeftDoubleBracket]1\[RightDoubleBracket]; \
\[IndentingNewLine]If[pd, 
                    Print["\<Recombining \>", nl, "\<; current lineages \>", 
                      lvs]]; \[IndentingNewLine]g1 = 
                    AddRecombinantLineages[g0, 
                      nl, {k + 1, 
                        k + 2}, #\[LeftDoubleBracket]3\[RightDoubleBracket], \
#\[LeftDoubleBracket]1\[RightDoubleBracket]]; \[IndentingNewLine]Switch[
                    Length[g1] - Length[g0], \[IndentingNewLine]1, 
                    lvs = Join[lvs\[Backslash]{nl}, {k + 1}]; 
                    k += 1, \[IndentingNewLine]2, 
                    lvs = Join[lvs\[Backslash]{nl}, {k + 1, k + 2}]; 
                    k += 2, \[IndentingNewLine]_, 
                    Message[RandomGenealogy::badRec, nl, 
                      g1]]]; \[IndentingNewLine]If[pd, Print["\<G=\>", g1]]; 
                g0 = g1)\) &\) /@ rct; \[IndentingNewLine]g1];\)\)], "Input",
  CellLabel->"In[196]:=",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{

Cell["Segments", "SubsubsectionIcon"],

Cell[BoxData[
    \(\(Segments::usage = "\<Segments[AncestralLineage[\[Ellipsis]],l] gives \
the blocks ancestral to l present within the lineage.  \
Segments[{AncestralLineage[\[Ellipsis]]\[Ellipsis]},l] Applies to several \
lineages\>";\)\)], "Input",
  CellLabel->"In[105]:=",
  InitializationCell->True],

Cell[BoxData[
    \(\(Segments[al : AncestralLineagePattern, l_] := 
        Module[{xx = al /. AncestralLineage[_, {_, _}, s_, j_, _] :> {s, j}, 
            yy}, \[IndentingNewLine]yy = 
            Replace[Transpose[
                  xx], {{___?\((FreeQ[#, 
                              l] &)\)} \[RuleDelayed] {}, {___?\((FreeQ[#, 
                              l] &)\), 
                      l, ___?\((FreeQ[#, 
                              l] &)\)} \[RuleDelayed] {l}}, {2}] //. {a___, \
{s_List, x0_}, {s_List, x1_}, b___} \[RuleDelayed] {a, {s, x1}, 
                  b}; \[IndentingNewLine]yy = \((yy \
//. \[IndentingNewLine]{{b___, {{}, x0_}, \[IndentingNewLine]{{___, l, ___}, 
                        x1_}, c___} \[RuleDelayed] {b, {x0, x1}, 
                      c}, \[IndentingNewLine]{b___, {{}, _}} \[RuleDelayed] \
{b}, \[IndentingNewLine]{{{___, l, ___}, x0_}, b___} \[RuleDelayed] {{0, x0}, 
                      b}})\)];\)\)], "Input",
  CellLabel->"In[106]:=",
  InitializationCell->True],

Cell[BoxData[
    \(\(Segments[al : AncestralGraphPattern, l_] := \(Segments[#, l] &\) /@ 
          al;\)\)], "Input",
  CellLabel->"In[107]:=",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{

Cell["PlotSegments", "SubsubsectionIcon"],

Cell[BoxData[
    \(\(PlotSegments::usage = \
"\<PlotSegments[AncestralLineage[\[Ellipsis]],leaf,y] gives a Graphics[] \
object depicting the segments ancestral to the leaf; drawn at height y.  \
SegmentStyle\[Rule]{Blue,\[Ellipsis]} and BackgroundStyle\[Rule]{Yellow,\
\[Ellipsis]} set the style of the lines.  PlotSegments[{AncestralLineage[\
\[Ellipsis]]\[Ellipsis]},leaf,{y0,y1}] plots a series of lineages spanning \
{y0,y1}; JunctionStyle specifies vertical lines depicting the junctions. \>";\
\)\)], "Input",
  CellLabel->"In[108]:=",
  InitializationCell->True],

Cell[BoxData[
    \(\(BackgroundStyle::usage = "\<BackgroundStyle is an option for \
PlotSegments which sets the style of non-ancestral parts of the chromosome; \
default {Yellow}\>";\)\)], "Input",
  CellLabel->"In[109]:=",
  InitializationCell->True],

Cell[BoxData[
    \(\(SegmentStyle::usage = "\<SegmentStyle is an option for PlotSegments \
which sets the style of ancestral parts of the chromosome; default {Blue}\>";\
\)\)], "Input",
  CellLabel->"In[110]:=",
  InitializationCell->True],

Cell[BoxData[
    \(\(JunctionStyle::usage = "\<JunctionStyle is an option for PlotSegments \
which sets the style of vertical lines depicting junctions; default \
{Black}\>";\)\)], "Input",
  CellLabel->"In[111]:=",
  InitializationCell->True],

Cell[BoxData[
    \(\(Options[PlotSegments] = {JunctionStyle \[Rule] {Black}, 
          SegmentStyle \[Rule] {Blue}, 
          BackgroundStyle \[Rule] {Yellow}};\)\)], "Input",
  CellLabel->"In[112]:=",
  InitializationCell->True],

Cell[BoxData[
    \(\(PlotSegments[al : AncestralLineagePattern, l_, y_, 
          opts___Rule] := \[IndentingNewLine]Module[{segs = Segments[al, l], 
            yy, \[IndentingNewLine]bs = \(BackgroundStyle /. {opts}\) /. 
                Options[
                  PlotSegments], \[IndentingNewLine]ss = \(SegmentStyle /. \
{opts}\) /. Options[PlotSegments]}, \[IndentingNewLine]yy = 
            bs\[Vee]{Line[{{0, y}, {MapLength[al], 
                      y}}]}\[Vee]ss\[Vee]\[IndentingNewLine]{Replace[
                  segs, {x0_, x1_} \[RuleDelayed] Line[{{x0, y}, {x1, y}}], 
                  1]}; \[IndentingNewLine]Graphics[yy]];\)\)], "Input",
  CellLabel->"In[113]:=",
  InitializationCell->True],

Cell[BoxData[
    \(\(PlotSegments[al : AncestralGraphPattern, l_, {y0_, y1_}, 
          opts___Rule] := \[IndentingNewLine]Module[{segs = Segments[al, l], 
            yy, \[IndentingNewLine]jj = Junctions[al], y, k, 
            nl = Length[
                al], \[IndentingNewLine]bs = \(BackgroundStyle /. {opts}\) /. 
                Options[
                  PlotSegments], \[IndentingNewLine]js = \(JunctionStyle /. \
{opts}\) /. Options[
                  PlotSegments], \[IndentingNewLine]ss = \(SegmentStyle /. \
{opts}\) /. Options[PlotSegments]}, \[IndentingNewLine]yy = 
            js\[Vee]Replace[jj, x_ \[RuleDelayed] Line[{{x, y0}, {x, y1}}], 
                1]\[Vee]bs\[Vee]Table[
                Line[{{0, y}, {MapLength[al], y}}], {y, y0, 
                  y1, \(y1 - y0\)\/Max[1, nl - 1]}]\[Vee]Table[
                ss\[Vee]Replace[
                    segs[\([k]\)], {x0_, 
                        x1_} \[RuleDelayed] {Line[{{x0, \(y0 \((nl - k)\) + \
y1 \((k - 1)\)\)\/Max[1, nl - 1]}, {x1, \(y0 \((nl - k)\) + y1 \((k - \
1)\)\)\/Max[1, nl - 1]}}]}, 1], {k, nl}]; \[IndentingNewLine]Graphics[
            yy]];\)\)], "Input",
  CellLabel->"In[114]:=",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{

Cell["TimeSpanOfJunctions", "SubsubsectionIcon"],

Cell[BoxData[
    \(\(TimespanOfJunction::usage = "\<TimespanOfJunction[{AncestralLineage[\
\[Ellipsis]]\[Ellipsis]},j] finds the first and last occurrence of j. \
\>";\)\)], "Input",
  CellLabel->"In[118]:=",
  InitializationCell->True],

Cell[BoxData[
    \(\(TimespanOfJunction[ag : AncestralGraphPattern, j_] := 
        Module[{cc}, \[IndentingNewLine]cc = 
            Cases[ag, 
              AncestralLineage[_, {_, _}, _, {___, 
                  j, ___}, _]]; \[IndentingNewLine]{First[
              Sort[cc /. 
                  AncestralLineage[_, {t0_, _}, _, _, _] \[RuleDelayed] t0]], 
            Last[Sort[
                cc /. AncestralLineage[_, {_, t1_}, _, _, _] \[RuleDelayed] 
                    t1]]}];\)\)], "Input",
  CellLabel->"In[130]:=",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{

Cell["ConfigurationSet", "SubsubsectionIcon"],

Cell[BoxData[
    \(\(ConfigurationSet::usage = "\<ConfigurationSet[{n1,n2\[Ellipsis]},k] \
lists all distinct ways of combining the {n1,n2\[Ellipsis]} objects into k \
sets. ConfigurationSet[{n1,n2\[Ellipsis]}]  lists all configurations from k=1 \
up.  ConfigurationSet[{{a1,b1\[Ellipsis]},{a2,b2\[Ellipsis]}\[Ellipsis]},k] \
does the same for definite sets {a1,b1\[Ellipsis]}\>";\)\)], "Input",
  CellLabel->"In[7]:="],

Cell["\<\
It would be far more efficient to derive the set version from \
permutations of the integer version.\
\>", "Text"],

Cell[BoxData[
    \(\(ConfigurationSet[n : {_Integer ... }, k_Integer] := 
        Module[{cl}, \[IndentingNewLine]cl = 
            Sequence @@ \((\(Compositions[#, k] &\) /@ 
                  n)\); \[IndentingNewLine]DeleteCases[
            Union[Flatten[Outer[Sort[Transpose[{##}]] &, cl, 1], 
                Length[n] - 1]], {___, {0\  .. }, ___}]];\)\)], "Input",
  CellLabel->"In[8]:="],

Cell[BoxData[
    \(\(ConfigurationSet[s : {_List ... }, k_Integer] := 
        Module[{cl}, \[IndentingNewLine]cl = 
            Sequence @@ \((\(\((Union[\((\(PartitionSet[
                                Join[#, Array[\[EmptySet] &, k]], k, 
                                Permutations \[Rule] 
                                  True] /. {\[EmptySet] .. } \[RuleDelayed] \
{}\) //. {{x___, \[EmptySet], y___} \[RuleDelayed] {x, y}})\)])\) &\) /@ 
                  s)\); \[IndentingNewLine]DeleteCases[
            Union[Flatten[Outer[Sort[Transpose[{##}]] &, cl, 1], 
                Length[s] - 1]], {___, {{} .. }, ___}]];\)\)], "Input",
  CellLabel->"In[9]:="],

Cell[BoxData[
    \(\(ConfigurationSet[s : {_List ... }] := 
        Flatten[\(ConfigurationSet[s, #] &\) /@ Range[Length[Flatten[s, 1]]], 
          1];\)\)], "Input",
  CellLabel->"In[10]:="],

Cell[BoxData[
    \(\(ConfigurationSet[n : {_Integer ... }] := 
        Flatten[\(ConfigurationSet[n, #] &\) /@ Range[Plus @@ n], 
          1];\)\)], "Input",
  CellLabel->"In[11]:="]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["Working", "SubsectionIcon"],

Cell[CellGroupData[{

Cell["Example: including null lineages", "SubsubsectionIcon"],

Cell[CellGroupData[{

Cell[BoxData[
    \(rct = RandomCoalescenceTimes[40, 4, 1]\)], "Input",
  CellLabel->"In[838]:="],

Cell[BoxData[
    \({{0.019383015546365092`, 3, None}, {0.20791089748782055`, 4, 
        0.8682725819511856`}, {0.6701914002606539`, 5, 
        0.8416252091318484`}, {0.6809139945533447`, 4, 
        None}, {0.8082611553180112`, 3, None}, {0.819438989971345`, 2, 
        None}, {0.8532272029274215`, 3, 
        0.77204269549965`}, {0.9279236226802318`, 4, 
        0.7137649700782009`}, {0.9921844303687049`, 5, 
        0.8303584183033372`}, {1.1278074171478605`, 4, 
        None}, {1.1796998716660128`, 3, None}, {1.2127910732239224`, 2, 
        None}, {1.3913146795063875`, 3, 
        0.9782958527565554`}, {1.3942708432872513`, 2, 
        None}, {1.9881613076170042`, 3, 
        0.04728685373971567`}, {2.0398261971895755`, 4, 
        0.2943410593396193`}, {2.1688358698969656`, 5, 
        0.20847892402288237`}, {2.2050848306335045`, 4, 
        None}, {2.220838271348572`, 5, 
        0.4498099570700569`}, {2.4243900830757257`, 6, 
        0.8704184898080483`}, {2.446400170314001`, 7, 
        0.6737520745164615`}, {2.477195442951188`, 6, 
        None}, {2.5469866218260546`, 5, None}, {2.6383881736223116`, 6, 
        0.1836491247260541`}, {2.7119488157401745`, 5, 
        None}, {2.7145172050283635`, 4, None}, {2.9276361251875103`, 3, 
        None}, {3.088186417628635`, 4, 
        0.26444863546691216`}, {3.179193776770838`, 3, 
        None}, {3.5442547240301896`, 4, 
        0.5320761129854872`}, {3.6640101023588074`, 3, 
        None}, {3.8479763477999405`, 4, 
        0.6503388577071584`}, {3.88838528108767`, 5, 
        0.856025449412`}, {3.950514286232974`, 4, None}, {4.126869835943969`, 
        3, None}, {4.2669186444455605`, 2, None}, {5.2477237924398885`, 3, 
        0.049953362692804426`}, {5.393721703646322`, 2, 
        None}, {5.5204077235498685`, 3, 
        0.30457475527869593`}, {5.561193466228457`, 4, 
        0.8162006672466392`}}\)], "Output",
  CellLabel->"Out[838]="]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(ListPlot[rct /. {t_, k_, _} \[RuleDelayed] {t, k}, 
        PlotJoined \[Rule] True, 
        PlotRange \[Rule] {{0, 6}, {0, 10}}];\)\)], "Input",
  CellLabel->"In[841]:="],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
2.77556e-17 0.166667 0 0.0618034 [
[.16667 -0.0125 -3 -9 ]
[.16667 -0.0125 3 0 ]
[.33333 -0.0125 -3 -9 ]
[.33333 -0.0125 3 0 ]
[.5 -0.0125 -3 -9 ]
[.5 -0.0125 3 0 ]
[.66667 -0.0125 -3 -9 ]
[.66667 -0.0125 3 0 ]
[.83333 -0.0125 -3 -9 ]
[.83333 -0.0125 3 0 ]
[1 -0.0125 -3 -9 ]
[1 -0.0125 3 0 ]
[-0.0125 .12361 -6 -4.5 ]
[-0.0125 .12361 0 4.5 ]
[-0.0125 .24721 -6 -4.5 ]
[-0.0125 .24721 0 4.5 ]
[-0.0125 .37082 -6 -4.5 ]
[-0.0125 .37082 0 4.5 ]
[-0.0125 .49443 -6 -4.5 ]
[-0.0125 .49443 0 4.5 ]
[-0.0125 .61803 -12 -4.5 ]
[-0.0125 .61803 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.16667 0 m
.16667 .00625 L
s
[(1)] .16667 -0.0125 0 1 Mshowa
.33333 0 m
.33333 .00625 L
s
[(2)] .33333 -0.0125 0 1 Mshowa
.5 0 m
.5 .00625 L
s
[(3)] .5 -0.0125 0 1 Mshowa
.66667 0 m
.66667 .00625 L
s
[(4)] .66667 -0.0125 0 1 Mshowa
.83333 0 m
.83333 .00625 L
s
[(5)] .83333 -0.0125 0 1 Mshowa
1 0 m
1 .00625 L
s
[(6)] 1 -0.0125 0 1 Mshowa
.125 Mabswid
.03333 0 m
.03333 .00375 L
s
.06667 0 m
.06667 .00375 L
s
.1 0 m
.1 .00375 L
s
.13333 0 m
.13333 .00375 L
s
.2 0 m
.2 .00375 L
s
.23333 0 m
.23333 .00375 L
s
.26667 0 m
.26667 .00375 L
s
.3 0 m
.3 .00375 L
s
.36667 0 m
.36667 .00375 L
s
.4 0 m
.4 .00375 L
s
.43333 0 m
.43333 .00375 L
s
.46667 0 m
.46667 .00375 L
s
.53333 0 m
.53333 .00375 L
s
.56667 0 m
.56667 .00375 L
s
.6 0 m
.6 .00375 L
s
.63333 0 m
.63333 .00375 L
s
.7 0 m
.7 .00375 L
s
.73333 0 m
.73333 .00375 L
s
.76667 0 m
.76667 .00375 L
s
.8 0 m
.8 .00375 L
s
.86667 0 m
.86667 .00375 L
s
.9 0 m
.9 .00375 L
s
.93333 0 m
.93333 .00375 L
s
.96667 0 m
.96667 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .12361 m
.00625 .12361 L
s
[(2)] -0.0125 .12361 1 0 Mshowa
0 .24721 m
.00625 .24721 L
s
[(4)] -0.0125 .24721 1 0 Mshowa
0 .37082 m
.00625 .37082 L
s
[(6)] -0.0125 .37082 1 0 Mshowa
0 .49443 m
.00625 .49443 L
s
[(8)] -0.0125 .49443 1 0 Mshowa
0 .61803 m
.00625 .61803 L
s
[(10)] -0.0125 .61803 1 0 Mshowa
.125 Mabswid
0 .0309 m
.00375 .0309 L
s
0 .0618 m
.00375 .0618 L
s
0 .09271 m
.00375 .09271 L
s
0 .15451 m
.00375 .15451 L
s
0 .18541 m
.00375 .18541 L
s
0 .21631 m
.00375 .21631 L
s
0 .27812 m
.00375 .27812 L
s
0 .30902 m
.00375 .30902 L
s
0 .33992 m
.00375 .33992 L
s
0 .40172 m
.00375 .40172 L
s
0 .43262 m
.00375 .43262 L
s
0 .46353 m
.00375 .46353 L
s
0 .52533 m
.00375 .52533 L
s
0 .55623 m
.00375 .55623 L
s
0 .58713 m
.00375 .58713 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.00323 .18541 m
.03465 .24721 L
.1117 .30902 L
.11349 .24721 L
.13471 .18541 L
.13657 .12361 L
.1422 .18541 L
.15465 .24721 L
.16536 .30902 L
.18797 .24721 L
.19662 .18541 L
.20213 .12361 L
.23189 .18541 L
.23238 .12361 L
.33136 .18541 L
.33997 .24721 L
.36147 .30902 L
.36751 .24721 L
.37014 .30902 L
.40407 .37082 L
.40773 .43262 L
.41287 .37082 L
.4245 .30902 L
.43973 .37082 L
.45199 .30902 L
.45242 .24721 L
.48794 .18541 L
.5147 .24721 L
.52987 .18541 L
.59071 .24721 L
.61067 .18541 L
.64133 .24721 L
.64806 .30902 L
.65842 .24721 L
.68781 .18541 L
.71115 .12361 L
.87462 .18541 L
.89895 .12361 L
.92007 .18541 L
.92687 .24721 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[841]:=",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/B000`400?l00000o`00003oo`3ooolQ
0?ooo`00?@3oool3000002L0oooo1@00000W0?ooo`<00000:@3oool3000002P0oooo0`00000X0?oo
o`<00000203oool003h0oooo00<000000?ooo`3oool09`3oool010000000oooo0?ooo`00000V0?oo
o`050000003oool0oooo0?ooo`000000:@3oool00`000000oooo0?ooo`0V0?ooo`050000003oool0
oooo0?ooo`0000009P3oool01@000000oooo0?ooo`3oool0000000L0oooo000n0?ooo`030000003o
ool0oooo02P0oooo00<000000?ooo`3oool0:P3oool00`000000oooo0?ooo`0T0?ooo`D00000:`3o
ool00`000000oooo0?ooo`0T0?ooo`050000003oool0oooo0?ooo`0000001`3oool003h0oooo00<0
00000?ooo`3oool0:@3oool00`000000oooo0?ooo`0W0?ooo`8000009`3oool010000000oooo0?oo
o`00000/0?ooo`030000003oool0oooo02@0oooo100000080?ooo`00?P3oool00`000000oooo0?oo
o`0V0?ooo`050000003oool0oooo0?ooo`000000:P3oool00`000000oooo0?ooo`0U0?ooo`030000
003oool0000002P0oooo1000000W0?ooo`030000003oool0oooo00T0oooo000m0?ooo`800000:03o
ool01@000000oooo0?ooo`3oool0000002H0oooo00D000000?ooo`3oool0oooo0000000X0?ooo`80
0000:03oool00`000000oooo0?ooo`0Y0?ooo`030000003oool0oooo00P0oooo000n0?ooo`030000
003oool0oooo02L0oooo0`00000X0?ooo`<00000:P3oool00`000000oooo0?ooo`0V0?ooo`D00000
:03oool2000000P0oooo003o0?ooob40oooo003o0?ooob40oooo003o0?ooob40oooo003o0?ooob40
oooo000D0?ooool000001@0000080?ooo`00503oool00`000000oooo0?ooo`050?ooo`030000003o
ool0oooo00H0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`060?ooo`030000003o
ool0oooo00H0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`060?ooo`030000003o
ool0oooo00H0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`060?ooo`030000003o
ool0oooo00H0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`060?ooo`030000003o
ool0oooo00D0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`060?ooo`030000003o
ool0oooo00D0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`060?ooo`030000003o
ool0oooo00D0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`060?ooo`030000003o
ool0oooo00D0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`060?ooo`030000003o
ool0oooo00D0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`050?ooo`030000003o
ool0oooo00H0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`060?ooo`00503oool0
0`000000oooo0?ooo`3o0?ooo`X0oooo000D0?ooo`030000003oool0oooo0?l0oooo2P3oool001@0
oooo00<000000?ooo`3oool0o`3oool:0?ooo`00503oool00`000000oooo0?ooo`3o0?ooo`X0oooo
000D0?ooo`030000003oool0oooo0?l0oooo2P3oool001@0oooo00<000000?ooo`3oool0o`3oool:
0?ooo`00503oool00`000000oooo0?ooo`3o0?ooo`X0oooo000D0?ooo`030000003oool0oooo0?l0
oooo2P3oool001@0oooo00<000000?ooo`3oool0o`3oool:0?ooo`00503oool00`000000oooo0?oo
o`3o0?ooo`X0oooo000D0?ooo`030000003oool0oooo0?l0oooo2P3oool001@0oooo00<000000?oo
o`3oool0o`3oool:0?ooo`00503oool00`000000oooo0?ooo`3o0?ooo`X0oooo000D0?ooo`030000
003oool0oooo0?l0oooo2P3oool001@0oooo00<000000?ooo`3oool0o`3oool:0?ooo`00503oool0
0`000000oooo0?ooo`3o0?ooo`X0oooo000D0?ooo`030000003oool0oooo0?l0oooo2P3oool001@0
oooo00<000000?ooo`3oool0o`3oool:0?ooo`00503oool00`000000oooo0?ooo`3o0?ooo`X0oooo
000D0?ooo`030000003oool0oooo0?l0oooo2P3oool001@0oooo00<000000?ooo`3oool0o`3oool:
0?ooo`00503oool00`000000oooo0?ooo`3o0?ooo`X0oooo000D0?ooo`030000003oool0oooo0?l0
oooo2P3oool001@0oooo00<000000?ooo`3oool0o`3oool:0?ooo`00503oool00`000000oooo0?oo
o`3o0?ooo`X0oooo000D0?ooo`030000003oool0oooo0?l0oooo2P3oool001@0oooo00<000000?oo
o`3oool0o`3oool:0?ooo`002P3oool5000000D0oooo00<000000?ooo`3oool0o`3oool:0?ooo`00
2`3oool010000000oooo0?ooo`0000050?ooo`030000003oool0oooo0?l0oooo2P3oool000`0oooo
00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`3o0?ooo`X0oooo000=0?ooo`030000003o
ool0oooo00@0oooo0P00000Q0?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3oool01@3o
ool2000007X0oooo0P00000_0?ooo`030000003oool0oooo0200oooo000:0?ooo`050000003oool0
oooo0?ooo`0000001@3oool00`000000oooo0?ooo`0P0?ooo`030000003oool0oooo00h0oooo00<0
00000?ooo`3oool01@3oool00`000000oooo0000001i0?ooo`030000003oool0000000800000;03o
ool00`000000oooo0?ooo`0P0?ooo`002P3oool01@000000oooo0?ooo`3oool0000000D0oooo00<0
00000?ooo`3oool0803oool00`000000oooo0?ooo`0>0?ooo`8000001P3oool00`000000oooo0?oo
o`02000007H0oooo00<000000?ooo`3oool00`3oool3000002P0oooo0P00000R0?ooo`002`3oool3
000000H0oooo00<000000?ooo`3oool0803oool00`000000oooo0?ooo`0>0?ooo`8000001P3oool0
0`000000oooo0?ooo`020?ooo`030000003oool0oooo07<0oooo00<000000?ooo`3oool01P3oool2
000002H0oooo00<000000?ooo`0000008@3oool001@0oooo00<000000?ooo`3oool0803oool00`00
0000oooo0?ooo`0>0?ooo`030000003oool0000000D0oooo00<000000?ooo`3oool00`3oool20000
07<0oooo00<000000?ooo`3oool0203oool300000280oooo00@000000?ooo`3oool000008@3oool0
01@0oooo00<000000?ooo`3oool0803oool00`000000oooo0?ooo`0=0?ooo`040000003oool0oooo
000000D0oooo00<000000?ooo`3oool01@3oool200000700oooo00<000000?ooo`3oool0303oool2
00000200oooo00@000000?ooo`3oool000008@3oool001@0oooo00<000000?ooo`3oool0803oool0
0`000000oooo0?ooo`0=0?ooo`050000003oool0oooo0?ooo`000000103oool00`000000oooo0?oo
o`070?ooo`030000003oool0oooo06d0oooo00<000000?ooo`3oool03P3oool3000001d0oooo00D0
00000?ooo`3oool0oooo0000000P0?ooo`00503oool00`000000oooo0?ooo`0P0?ooo`030000003o
ool0oooo00d0oooo00D000000?ooo`3oool0oooo000000040?ooo`030000003oool0oooo00P0oooo
0P00001]0?ooo`030000003oool0oooo0140oooo0`00000I0?ooo`030000003oool0oooo0080oooo
00<000000?ooo`3oool07P3oool001@0oooo00<000000?ooo`3oool0803oool00`000000oooo0?oo
o`0=0?ooo`030000003oool0oooo0080oooo00D000000?ooo`3oool0oooo0000000<0?ooo`030000
003oool0oooo06T0oooo00<000000?ooo`3oool05@3oool2000001L0oooo00<000000?ooo`3oool0
0P3oool00`000000oooo0?ooo`0N0?ooo`00503oool00`000000oooo0?ooo`0O0?ooo`030000003o
ool0000000h0oooo00<000000?ooo`3oool00P3oool01@000000oooo0?ooo`3oool0000000d0oooo
0P00001Y0?ooo`030000003oool0oooo01L0oooo0`00000C0?ooo`030000003oool0oooo00@0oooo
00<000000?ooo`3oool07@3oool001@0oooo00<000000?ooo`3oool07`3oool00`000000oooo0000
000>0?ooo`030000003oool0oooo00<0oooo00@000000?ooo`3oool000003`3oool00`000000oooo
0?ooo`1U0?ooo`030000003oool0oooo01/0oooo0`00000@0?ooo`030000003oool0oooo00@0oooo
00<000000?ooo`3oool07@3oool001@0oooo00<000000?ooo`3oool07`3oool00`000000oooo0000
000>0?ooo`030000003oool0oooo00<0oooo00@000000?ooo`3oool00000403oool2000006D0oooo
00<000000?ooo`3oool07P3oool2000000d0oooo00<000000?ooo`3oool01@3oool00`000000oooo
0?ooo`0M0?ooo`00503oool00`000000oooo0?ooo`0O0?ooo`030000003oool0000000h0oooo00<0
00000?ooo`3oool0103oool00`000000oooo0000000B0?ooo`800000H`3oool00`000000oooo0?oo
o`0P0?ooo`<000002P3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo01`0oooo000D
0?ooo`030000003oool0oooo01l0oooo00<000000?ooo`0000003@3oool00`000000oooo0?ooo`05
0?ooo`030000003oool0000001@0oooo00<000000?ooo`3oool0G`3oool00`000000oooo0?ooo`0T
0?ooo`800000203oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo01`0oooo000D0?oo
o`030000003oool0oooo01l0oooo00<000000?ooo`0000003@3oool00`000000oooo0?ooo`060?oo
o`8000005@3oool2000005l0oooo00<000000?ooo`3oool09P3oool3000000@0oooo00<000000?oo
o`3oool01`3oool00`000000oooo0?ooo`0L0?ooo`00503oool00`000000oooo0?ooo`0O0?ooo`03
0000003oool0000000d0oooo00<000000?ooo`3oool01P3oool2000001L0oooo00<000000?ooo`3o
ool0G03oool00`000000oooo0?ooo`0Y0?ooo`<0000000<0oooo0000003oool02@3oool00`000000
oooo0?ooo`0K0?ooo`00503oool00`000000oooo0?ooo`0O0?ooo`030000003oool0000000d0oooo
00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`0F0?ooo`030000003oool0oooo02H0oooo
00<000000?ooo`3oool0203oool00`000000oooo0?ooo`0B0?ooo`030000003oool0oooo0140oooo
00<000000?ooo`3oool0;@3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo01/0oooo
000D0?ooo`030000003oool0oooo01l0oooo00<000000?ooo`0000003@3oool00`000000oooo0?oo
o`0P0?ooo`030000003oool0oooo02H0oooo00<000000?ooo`3oool0203oool2000001<0oooo00<0
00000?ooo`3oool04@3oool00`000000oooo0?ooo`0i0?ooo`030000003oool0oooo01/0oooo000D
0?ooo`800000803oool00`000000oooo0000000=0?ooo`030000003oool0oooo0200oooo00<00000
0?ooo`3oool09@3oool00`000000oooo000000090?ooo`030000003oool000000180oooo0P00000A
0?ooo`030000003oool0oooo03X0oooo00<000000?ooo`3oool06`3oool001@0oooo0P00000O0?oo
o`050000003oool0oooo0?ooo`000000303oool00`000000oooo0?ooo`0P0?ooo`030000003oool0
oooo02D0oooo00<000000?ooo`000000203oool01@000000oooo0?ooo`3oool000000100oooo00<0
00000?ooo`0000004@3oool00`000000oooo0?ooo`0j0?ooo`030000003oool0oooo01/0oooo000D
0?ooo`030000003oool0000001h0oooo00D000000?ooo`3oool0oooo0000000<0?ooo`030000003o
ool0oooo0240oooo00<000000?ooo`3oool08`3oool01@000000oooo0?ooo`3oool0000000L0oooo
00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0=0?ooo`040000003oool0oooo000000l0
oooo00<000000?ooo`3oool0>`3oool00`000000oooo0?ooo`0K0?ooo`00503oool010000000oooo
0?ooo`00000M0?ooo`050000003oool0oooo0?ooo`0000002`3oool00`000000oooo0?ooo`0R0?oo
o`030000003oool0oooo0280oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`050?oo
o`030000003oool0oooo00<0oooo00<000000?ooo`3oool0303oool010000000oooo0?ooo`00000?
0?ooo`030000003oool0oooo03`0oooo00<000000?ooo`3oool06P3oool001@0oooo00@000000?oo
o`3oool00000703oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00T0oooo00<00000
0?ooo`3oool08P3oool00`000000oooo0?ooo`0R0?ooo`030000003oool0oooo0080oooo00<00000
0?ooo`3oool01@3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00X0oooo00<00000
0?ooo`3oool00P3oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo03d0oooo00<00000
0?ooo`3oool06P3oool001@0oooo00D000000?ooo`3oool0oooo0000000K0?ooo`030000003oool0
oooo00<0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`0R0?ooo`030000003oool0
oooo0240oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`030?ooo`030000003oool0
oooo00H0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`020?ooo`030000003oool0
oooo00/0oooo00<000000?ooo`3oool0?@3oool00`000000oooo0?ooo`0J0?ooo`00503oool01@00
0000oooo0?ooo`3oool0000001/0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`08
0?ooo`030000003oool0oooo0280oooo00<000000?ooo`3oool08@3oool00`000000oooo0?ooo`04
0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`08
0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`0n
0?ooo`030000003oool0oooo01X0oooo000D0?ooo`030000003oool0oooo0080oooo00<000000?oo
o`3oool05`3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00P0oooo00<000000?oo
o`3oool08`3oool00`000000oooo0?ooo`0O0?ooo`030000003oool0oooo00H0oooo00<000000?oo
o`3oool00P3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo00H0oooo00<000000?oo
o`3oool0103oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo03h0oooo00<000000?oo
o`3oool06P3oool001@0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0G0?ooo`03
0000003oool0oooo00@0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`0S0?ooo`03
0000003oool0oooo01l0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`020?ooo`03
0000003oool0oooo00T0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`050?ooo`03
0000003oool0oooo00L0oooo00<000000?ooo`3oool0?`3oool00`000000oooo0?ooo`0J0?ooo`00
503oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo01H0oooo00<000000?ooo`3oool0
1@3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo02<0oooo00<000000?ooo`3oool0
7P3oool00`000000oooo0?ooo`080?ooo`040000003oool0oooo000000d0oooo00<000000?ooo`3o
ool0103oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3o
ool0?`3oool00`000000oooo0?ooo`0J0?ooo`00503oool00`000000oooo0?ooo`030?ooo`030000
003oool0oooo01D0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`070?ooo`030000
003oool0oooo02<0oooo00<000000?ooo`3oool07P3oool00`000000oooo0?ooo`080?ooo`040000
003oool0oooo000000h0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`070?ooo`03
0000003oool0oooo00D0oooo00<000000?ooo`3oool0@03oool00`000000oooo0?ooo`0J0?ooo`00
303oool3000000D0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`0D0?ooo`030000
003oool0oooo00H0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`0T0?ooo`030000
003oool0oooo01d0oooo00<000000?ooo`3oool02@3oool010000000oooo0?ooo`00000?0?ooo`05
0000003oool0oooo0?ooo`0000002@3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo
0440oooo00<000000?ooo`3oool06@3oool000d0oooo00<000000?ooo`3oool0103oool00`000000
oooo0?ooo`050?ooo`030000003oool0oooo01<0oooo00<000000?ooo`3oool01P3oool00`000000
oooo0?ooo`060?ooo`030000003oool0oooo02D0oooo00<000000?ooo`3oool06`3oool00`000000
oooo0?ooo`0;0?ooo`030000003oool000000100oooo00@000000?ooo`3oool000002P3oool00`00
0000oooo0?ooo`030?ooo`030000003oool0oooo0480oooo00<000000?ooo`3oool06@3oool000X0
oooo1@0000050?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool04P3oool00`000000
oooo0?ooo`080?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool09@3oool00`000000
oooo0?ooo`0K0?ooo`030000003oool0oooo00/0oooo0P00000B0?ooo`8000002`3oool00`000000
oooo0?ooo`030?ooo`030000003oool0oooo0480oooo00<000000?ooo`3oool06@3oool000X0oooo
00@000000?ooo`3oool000001P3oool2000000L0oooo0P00000B0?ooo`030000003oool0oooo00P0
oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`0U0?ooo`030000003oool0oooo00@0
oooo00<000000?ooo`3oool04`3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo0140
oooo00<000000?ooo`3oool02P3oool01@000000oooo0?ooo`3oool0000004D0oooo00<000000?oo
o`3oool06@3oool000/0oooo00<000000?ooo`0000001P3oool00`000000oooo0?ooo`080?ooo`03
0000003oool0oooo00l0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`050?ooo`03
0000003oool0oooo02D0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`0C0?ooo`03
0000003oool0oooo02h0oooo00D000000?ooo`3oool0oooo0000001Q0?ooo`00303oool2000000H0
oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo00P0
oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`0V0?ooo`030000003oool0oooo00@0
oooo00<000000?ooo`3oool04`3oool00`000000oooo0?ooo`0^0?ooo`050000003oool0oooo0?oo
o`000000H@3oool000d0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`0:0?ooo`03
0000003oool0oooo00d0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`040?ooo`03
0000003oool0oooo02L0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`0C0?ooo`03
0000003oool0oooo02h0oooo00D000000?ooo`3oool0oooo0000001Q0?ooo`00503oool00`000000
oooo0?ooo`0;0?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool0203oool00`000000
oooo0?ooo`040?ooo`030000003oool0oooo02L0oooo00<000000?ooo`3oool00`3oool00`000000
oooo0?ooo`0C0?ooo`030000003oool0oooo02h0oooo00@000000?ooo`3oool00000HP3oool001@0
oooo00<000000?ooo`3oool0303oool2000000`0oooo00<000000?ooo`3oool02@3oool00`000000
oooo0?ooo`020?ooo`030000003oool0oooo02P0oooo00<000000?ooo`3oool00P3oool2000001D0
oooo00<000000?ooo`3oool0;P3oool010000000oooo0?ooo`00001R0?ooo`00503oool00`000000
oooo0?ooo`0>0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool02@3oool00`000000
oooo0?ooo`020?ooo`030000003oool0oooo02T0oooo00@000000?ooo`3oool0oooo0P00000E0?oo
o`030000003oool0oooo02h0oooo00@000000?ooo`3oool00000HP3oool001@0oooo00<000000?oo
o`3oool03`3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo00T0oooo00<000000?oo
o`3oool00P3oool00`000000oooo0?ooo`0Y0?ooo`040000003oool0oooo0?ooo`8000005@3oool0
0`000000oooo0?ooo`0^0?ooo`040000003oool0oooo00000680oooo000D0?ooo`030000003oool0
oooo0100oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`090?ooo`050000003oool0
oooo0?ooo`000000;03oool010000000oooo0?ooo`3oool2000001D0oooo00<000000?ooo`3oool0
;P3oool010000000oooo0?ooo`00001R0?ooo`00503oool00`000000oooo0?ooo`0A0?ooo`030000
003oool0oooo00D0oooo00<000000?ooo`3oool02P3oool01@000000oooo0?ooo`3oool0000002d0
oooo00<000000?ooo`3oool00P00000E0?ooo`030000003oool0oooo02l0oooo0P00001S0?ooo`00
503oool00`000000oooo0?ooo`0B0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0
2P3oool010000000oooo0?ooo`00000^0?ooo`030000003oool0oooo008000005@3oool00`000000
oooo0?ooo`0_0?ooo`800000H`3oool001@0oooo00<000000?ooo`3oool04`3oool2000000@0oooo
00<000000?ooo`3oool02P3oool010000000oooo0?ooo`00000^0?ooo`030000003oool0oooo0080
00005@3oool00`000000oooo0?ooo`0_0?ooo`800000H`3oool001@0oooo00<000000?ooo`3oool0
5@3oool01@000000oooo0?ooo`3oool0000000`0oooo00@000000?ooo`3oool00000;`3oool01000
0000oooo00000000000E0?ooo`030000003oool0oooo02l0oooo0P00001S0?ooo`00503oool00`00
0000oooo0?ooo`0F0?ooo`040000003oool0oooo000000d0oooo0P00000`0?ooo`80000000<0oooo
0000003oool0503oool00`000000oooo0?ooo`0_0?ooo`800000H`3oool001@0oooo00<000000?oo
o`3oool05`3oool00`000000oooo0000000=0?ooo`800000<03oool2000000030?ooo`000000oooo
01@0oooo00<000000?ooo`3oool0;`3oool00`000000oooo0?ooo`1R0?ooo`00503oool00`000000
oooo0?ooo`0H0?ooo`8000003@3oool200000340oooo00<000000?ooo`0000005@3oool00`000000
oooo0?ooo`0_0?ooo`030000003oool0oooo0680oooo000D0?ooo`030000003oool0oooo01T0oooo
00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`0`0?ooo`030000003oool0000000h0oooo
00<000000?ooo`3oool0103oool00`000000oooo0?ooo`0_0?ooo`030000003oool0oooo0680oooo
000D0?ooo`030000003oool0oooo05`0oooo00<000000?ooo`3oool0303oool00`000000oooo0?oo
o`040?ooo`030000003oool0oooo09@0oooo000D0?ooo`030000003oool0oooo05d0oooo00<00000
0?ooo`3oool02`3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo09@0oooo000D0?oo
o`030000003oool0oooo05d0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`030?oo
o`030000003oool0oooo09D0oooo000D0?ooo`030000003oool0oooo05h0oooo00<000000?ooo`3o
ool02@3oool00`000000oooo000000040?ooo`030000003oool0oooo09D0oooo000D0?ooo`030000
003oool0oooo05l0oooo00<000000?ooo`3oool0203oool00`000000oooo000000040?ooo`030000
003oool0oooo09D0oooo000D0?ooo`030000003oool0oooo05l0oooo00<000000?ooo`3oool0203o
ool00`000000oooo000000040?ooo`030000003oool0oooo09D0oooo000D0?ooo`030000003oool0
oooo0600oooo00<000000?ooo`3oool01`3oool00`000000oooo000000030?ooo`030000003oool0
oooo09H0oooo000D0?ooo`030000003oool0oooo0600oooo00<000000?ooo`3oool01`3oool00`00
0000oooo000000030?ooo`030000003oool0oooo09H0oooo000D0?ooo`030000003oool0oooo0640
oooo00<000000?ooo`3oool01@3oool01@000000oooo0?ooo`3oool000000080oooo00<000000?oo
o`3oool0UP3oool001@0oooo00<000000?ooo`3oool0H@3oool00`000000oooo0?ooo`050?ooo`05
0000003oool0oooo0?ooo`0000000P3oool00`000000oooo0?ooo`2F0?ooo`00503oool00`000000
oooo0?ooo`1R0?ooo`030000003oool0oooo00@0oooo00L000000?ooo`3oool0oooo0000003oool0
000009T0oooo000D0?ooo`030000003oool0oooo0680oooo00<000000?ooo`3oool0103oool01`00
0000oooo0?ooo`3oool000000?ooo`000000V@3oool000/0oooo0`0000060?ooo`030000003oool0
oooo06<0oooo00<000000?ooo`3oool00`3oool01`000000oooo0?ooo`3oool000000?ooo`000000
V@3oool000X0oooo00D000000?ooo`3oool0oooo000000050?ooo`030000003oool0oooo06@0oooo
00D000000?ooo`3oool0oooo000000050?ooo`800000V@3oool000X0oooo00D000000?ooo`3oool0
oooo000000050?ooo`030000003oool0oooo06@0oooo00D000000?ooo`3oool0oooo000000050?oo
o`030000003oool0oooo09P0oooo000:0?ooo`@000001P3oool2000006H0oooo00@000000?ooo`3o
ool000001@3oool00`000000oooo0?ooo`2H0?ooo`002P3oool00`000000oooo0?ooo`070?ooo`03
0000003oool0oooo06D0oooo00@000000?ooo`3oool00000X03oool000/0oooo00<000000?ooo`3o
ool01P3oool00`000000oooo0?ooo`1U0?ooo`040000003oool0oooo00000:00oooo000<0?ooo`80
00001P3oool00`000000oooo0?ooo`1U0?ooo`040000003oool0oooo00000:00oooo000D0?ooo`03
0000003oool0oooo06D0oooo00@000000?ooo`3oool00000X03oool001@0oooo00<000000?ooo`3o
ool0I@3oool00`000000oooo0000002Q0?ooo`00503oool00`000000oooo0?ooo`1U0?ooo`030000
003oool000000:40oooo000D0?ooo`030000003oool0oooo06D0oooo00<000000?ooo`000000X@3o
ool001@0oooo00<000000?ooo`3oool0I@3oool00`000000oooo0000002Q0?ooo`00503oool00`00
0000oooo0?ooo`1V0?ooo`800000X@3oool001@0oooo00<000000?ooo`3oool0IP3oool200000:40
oooo000D0?ooo`030000003oool0oooo06H0oooo0P00002Q0?ooo`00503oool00`000000oooo0?oo
o`1V0?ooo`800000X@3oool001@0oooo00<000000?ooo`3oool0IP3oool00`000000oooo0?ooo`2P
0?ooo`00503oool00`000000oooo0?ooo`1V0?ooo`030000003oool0oooo0:00oooo000D0?ooo`03
0000003oool0oooo06H0oooo00<000000?ooo`3oool0X03oool001@0oooo00<000000?ooo`3oool0
IP3oool00`000000oooo0?ooo`2P0?ooo`00503oool00`000000oooo0?ooo`3o0?ooo`X0oooo000D
0?ooo`030000003oool0oooo0?l0oooo2P3oool001@0oooo00<000000?ooo`3oool0o`3oool:0?oo
o`00503oool00`000000oooo0?ooo`3o0?ooo`X0oooo000D0?ooo`030000003oool0oooo0?l0oooo
2P3oool001@0oooo00<000000?ooo`3oool0o`3oool:0?ooo`00503oool00`000000oooo0?ooo`3o
0?ooo`X0oooo000D0?ooo`030000003oool0oooo0?l0oooo2P3oool001@0oooo00<000000?ooo`3o
ool0o`3oool:0?ooo`00503oool00`000000oooo0?ooo`3o0?ooo`X0oooo000D0?ooo`030000003o
ool0oooo0?l0oooo2P3oool001@0oooo00<000000?ooo`3oool0o`3oool:0?ooo`002`3oool30000
00H0oooo00<000000?ooo`3oool0o`3oool:0?ooo`002P3oool01@000000oooo0?ooo`3oool00000
00D0oooo00<000000?ooo`3oool0o`3oool:0?ooo`002P3oool01@000000oooo0?ooo`3oool00000
00D0oooo00<000000?ooo`3oool0o`3oool:0?ooo`002`3oool3000000H0oooo0P00003o0?ooo`/0
oooo000:0?ooo`050000003oool0oooo0?ooo`0000001@3oool00`000000oooo0?ooo`3o0?ooo`X0
oooo000:0?ooo`050000003oool0oooo0?ooo`0000001@3oool00`000000oooo0?ooo`3o0?ooo`X0
oooo000;0?ooo`<000001P3oool00`000000oooo0?ooo`3o0?ooo`X0oooo000D0?ooo`030000003o
ool0oooo0?l0oooo2P3oool001@0oooo00<000000?ooo`3oool0o`3oool:0?ooo`00503oool00`00
0000oooo0?ooo`3o0?ooo`X0oooo000D0?ooo`030000003oool0oooo0?l0oooo2P3oool001@0oooo
00<000000?ooo`3oool0o`3oool:0?ooo`00503oool00`000000oooo0?ooo`3o0?ooo`X0oooo000D
0?ooo`030000003oool0oooo0?l0oooo2P3oool001@0oooo00<000000?ooo`3oool0o`3oool:0?oo
o`00503oool00`000000oooo0?ooo`3o0?ooo`X0oooo000D0?ooo`030000003oool0oooo0?l0oooo
2P3oool001@0oooo00<000000?ooo`3oool0o`3oool:0?ooo`00503oool00`000000oooo0?ooo`3o
0?ooo`X0oooo000D0?ooo`030000003oool0oooo0?l0oooo2P3oool001@0oooo00<000000?ooo`3o
ool0o`3oool:0?ooo`00503oool00`000000oooo0?ooo`3o0?ooo`X0oooo000D0?ooo`030000003o
ool0oooo0?l0oooo2P3oool001@0oooo00<000000?ooo`3oool0o`3oool:0?ooo`00503oool00`00
0000oooo0?ooo`3o0?ooo`X0oooo000D0?ooo`030000003oool0oooo0?l0oooo2P3oool001@0oooo
00<000000?ooo`3oool0o`3oool:0?ooo`00503oool00`000000oooo0?ooo`3o0?ooo`X0oooo000D
0?ooo`030000003oool0oooo0?l0oooo2P3oool001@0oooo00<000000?ooo`3oool0o`3oool:0?oo
o`00503oool00`000000oooo0?ooo`3o0?ooo`X0oooo000D0?ooo`030000003oool0oooo0?l0oooo
2P3oool000D0oooo0`0000040?ooo`8000001P3oool00`000000oooo0?ooo`3o0?ooo`X0oooo0006
0?ooo`030000003oool0oooo0080oooo00@000000?ooo`3oool000001@3oool00`000000oooo0?oo
o`3o0?ooo`X0oooo00060?ooo`030000003oool0oooo0080oooo00@000000?ooo`3oool000001@3o
ool00`000000oooo0?ooo`3o0?ooo`X0oooo00060?ooo`030000003oool0oooo0080oooo00@00000
0?ooo`3oool000001@3oool200000?l0oooo2`3oool000H0oooo00<000000?ooo`3oool00P3oool0
10000000oooo0?ooo`00003o0?oooa80oooo00050?ooo`800000103oool010000000oooo0?ooo`00
003o0?oooa80oooo00060?ooo`030000003oool0oooo00<0oooo0P00003o0?oooa<0oooo003o0?oo
ob40oooo0000\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.463373, -0.764114, \
0.0231477, 0.0624232}}]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    \(ng = RandomGenealogy[{a, b, c, d}, rct, 1]\)], "Input",
  CellLabel->"In[122]:="],

Cell[BoxData[
    \({0.027696065882077705`, 3, None}\)], "Print",
  CellLabel->"From In[122]:="],

Cell[BoxData[
    InterpretationBox[\("Coalescing "\[InvisibleSpace]{b, 
          d}\[InvisibleSpace]"; current lineages "\[InvisibleSpace]{a, b, c, 
          d}\),
      SequenceForm[ 
      "Coalescing ", {b, d}, "; current lineages ", {a, b, c, d}],
      Editable->False]], "Print",
  CellLabel->"From In[122]:="],

Cell[BoxData[
    InterpretationBox[
      RowBox[{"\<\"G=\"\>", "\[InvisibleSpace]", 
        RowBox[{"{", 
          RowBox[{
            RowBox[{"AncestralLineage", "[", 
              RowBox[{"a", ",", 
                RowBox[{"{", 
                  RowBox[{"0", ",", 
                    InterpretationBox["\[Infinity]",
                      DirectedInfinity[ 1]]}], "}"}], ",", \({{a}}\), 
                ",", \({1}\), ",", \({}\)}], "]"}], 
            ",", \(AncestralLineage[
              b, {0, 0.027696065882077705`}, {{b}}, {1}, {}]\), ",", 
            RowBox[{"AncestralLineage", "[", 
              RowBox[{"c", ",", 
                RowBox[{"{", 
                  RowBox[{"0", ",", 
                    InterpretationBox["\[Infinity]",
                      DirectedInfinity[ 1]]}], "}"}], ",", \({{c}}\), 
                ",", \({1}\), ",", \({}\)}], "]"}], 
            ",", \(AncestralLineage[
              d, {0, 0.027696065882077705`}, {{d}}, {1}, {}]\), ",", 
            RowBox[{"AncestralLineage", "[", 
              RowBox[{"1", ",", 
                RowBox[{"{", 
                  RowBox[{"0.027696065882077705`", ",", 
                    InterpretationBox["\[Infinity]",
                      DirectedInfinity[ 1]]}], "}"}], ",", \({{b, d}}\), 
                ",", \({1}\), ",", \({}\)}], "]"}]}], "}"}]}],
      SequenceForm[ "G=", {
        AncestralLineage[ a, {0, 
          DirectedInfinity[ 1]}, {{a}}, {1}, {}], 
        AncestralLineage[ b, {0, 0.027696065882077705}, {{b}}, {1}, {}], 
        AncestralLineage[ c, {0, 
          DirectedInfinity[ 1]}, {{c}}, {1}, {}], 
        AncestralLineage[ d, {0, 0.027696065882077705}, {{d}}, {1}, {}], 
        AncestralLineage[ 1, {0.027696065882077705, 
          DirectedInfinity[ 1]}, {{b, d}}, {1}, {}]}],
      Editable->False]], "Print",
  CellLabel->"From In[122]:="],

Cell[BoxData[
    \({0.05710778878192141`, 2, None}\)], "Print",
  CellLabel->"From In[122]:="],

Cell[BoxData[
    InterpretationBox[\("Coalescing "\[InvisibleSpace]{a, 
          1}\[InvisibleSpace]"; current lineages "\[InvisibleSpace]{a, c, 
          1}\),
      SequenceForm[ "Coalescing ", {a, 1}, "; current lineages ", {a, c, 1}],
      Editable->False]], "Print",
  CellLabel->"From In[122]:="],

Cell[BoxData[
    InterpretationBox[
      RowBox[{"\<\"G=\"\>", "\[InvisibleSpace]", 
        RowBox[{"{", 
          
          RowBox[{\(AncestralLineage[
              a, {0, 0.05710778878192141`}, {{a}}, {1}, {}]\), 
            ",", \(AncestralLineage[
              b, {0, 0.027696065882077705`}, {{b}}, {1}, {}]\), ",", 
            RowBox[{"AncestralLineage", "[", 
              RowBox[{"c", ",", 
                RowBox[{"{", 
                  RowBox[{"0", ",", 
                    InterpretationBox["\[Infinity]",
                      DirectedInfinity[ 1]]}], "}"}], ",", \({{c}}\), 
                ",", \({1}\), ",", \({}\)}], "]"}], 
            ",", \(AncestralLineage[
              d, {0, 0.027696065882077705`}, {{d}}, {1}, {}]\), 
            ",", \(AncestralLineage[
              1, {0.027696065882077705`, 
                0.05710778878192141`}, {{b, d}}, {1}, {}]\), ",", 
            RowBox[{"AncestralLineage", "[", 
              RowBox[{"2", ",", 
                RowBox[{"{", 
                  RowBox[{"0.05710778878192141`", ",", 
                    InterpretationBox["\[Infinity]",
                      DirectedInfinity[ 1]]}], "}"}], ",", \({{a, b, d}}\), 
                ",", \({1}\), ",", \({}\)}], "]"}]}], "}"}]}],
      SequenceForm[ "G=", {
        AncestralLineage[ a, {0, 0.057107788781921409}, {{a}}, {1}, {}], 
        AncestralLineage[ b, {0, 0.027696065882077705}, {{b}}, {1}, {}], 
        AncestralLineage[ c, {0, 
          DirectedInfinity[ 1]}, {{c}}, {1}, {}], 
        AncestralLineage[ d, {0, 0.027696065882077705}, {{d}}, {1}, {}], 
        AncestralLineage[ 
        1, {0.027696065882077705, 0.057107788781921409}, {{b, d}}, {1}, {}], 
        AncestralLineage[ 2, {0.057107788781921409, 
          DirectedInfinity[ 1]}, {{a, b, d}}, {1}, {}]}],
      Editable->False]], "Print",
  CellLabel->"From In[122]:="],

Cell[BoxData[
    \({0.27049717829601805`, 3, 0.01899643970468609`}\)], "Print",
  CellLabel->"From In[122]:="],

Cell[BoxData[
    InterpretationBox[\("Recombining "\[InvisibleSpace]2\[InvisibleSpace]"; \
current lineages "\[InvisibleSpace]{c, 2}\),
      SequenceForm[ "Recombining ", 2, "; current lineages ", {c, 2}],
      Editable->False]], "Print",
  CellLabel->"From In[122]:="],

Cell[BoxData[
    InterpretationBox[
      RowBox[{"\<\"G=\"\>", "\[InvisibleSpace]", 
        RowBox[{"{", 
          
          RowBox[{\(AncestralLineage[
              a, {0, 0.05710778878192141`}, {{a}}, {1}, {}]\), 
            ",", \(AncestralLineage[
              b, {0, 0.027696065882077705`}, {{b}}, {1}, {}]\), ",", 
            RowBox[{"AncestralLineage", "[", 
              RowBox[{"c", ",", 
                RowBox[{"{", 
                  RowBox[{"0", ",", 
                    InterpretationBox["\[Infinity]",
                      DirectedInfinity[ 1]]}], "}"}], ",", \({{c}}\), 
                ",", \({1}\), ",", \({}\)}], "]"}], 
            ",", \(AncestralLineage[
              d, {0, 0.027696065882077705`}, {{d}}, {1}, {}]\), 
            ",", \(AncestralLineage[
              1, {0.027696065882077705`, 
                0.05710778878192141`}, {{b, d}}, {1}, {}]\), 
            ",", \(AncestralLineage[
              2, {0.05710778878192141`, 
                0.27049717829601805`}, {{a, b, d}}, {1}, {}]\), ",", 
            RowBox[{"AncestralLineage", "[", 
              RowBox[{"3", ",", 
                RowBox[{"{", 
                  RowBox[{"0.27049717829601805`", ",", 
                    InterpretationBox["\[Infinity]",
                      DirectedInfinity[ 1]]}], "}"}], 
                ",", \({{a, b, d}, {}}\), ",", \({0.01899643970468609`, 1}\), 
                ",", \({}\)}], "]"}], ",", 
            RowBox[{"AncestralLineage", "[", 
              RowBox[{"4", ",", 
                RowBox[{"{", 
                  RowBox[{"0.27049717829601805`", ",", 
                    InterpretationBox["\[Infinity]",
                      DirectedInfinity[ 1]]}], "}"}], 
                ",", \({{}, {a, b, d}}\), ",", \({0.01899643970468609`, 1}\), 
                ",", \({}\)}], "]"}]}], "}"}]}],
      SequenceForm[ "G=", {
        AncestralLineage[ a, {0, 0.057107788781921409}, {{a}}, {1}, {}], 
        AncestralLineage[ b, {0, 0.027696065882077705}, {{b}}, {1}, {}], 
        AncestralLineage[ c, {0, 
          DirectedInfinity[ 1]}, {{c}}, {1}, {}], 
        AncestralLineage[ d, {0, 0.027696065882077705}, {{d}}, {1}, {}], 
        AncestralLineage[ 
        1, {0.027696065882077705, 0.057107788781921409}, {{b, d}}, {1}, {}], 
        AncestralLineage[ 
        2, {0.057107788781921409, 0.27049717829601805}, {{a, b, d}}, {1}, {}],
         
        AncestralLineage[ 3, {0.27049717829601805, 
          DirectedInfinity[ 1]}, {{a, b, d}, {}}, {0.018996439704686091, 
          1}, {}], 
        AncestralLineage[ 4, {0.27049717829601805, 
          DirectedInfinity[ 1]}, {{}, {a, b, d}}, {0.018996439704686091, 
          1}, {}]}],
      Editable->False]], "Print",
  CellLabel->"From In[122]:="],

Cell[BoxData[
    \({0.4292570949591068`, 4, 0.3890465100002953`}\)], "Print",
  CellLabel->"From In[122]:="],

Cell[BoxData[
    InterpretationBox[\("Recombining "\[InvisibleSpace]3\[InvisibleSpace]"; \
current lineages "\[InvisibleSpace]{c, 3, 4}\),
      SequenceForm[ "Recombining ", 3, "; current lineages ", {c, 3, 4}],
      Editable->False]], "Print",
  CellLabel->"From In[122]:="],

Cell[BoxData[
    InterpretationBox[
      RowBox[{"\<\"G=\"\>", "\[InvisibleSpace]", 
        RowBox[{"{", 
          
          RowBox[{\(AncestralLineage[
              a, {0, 0.05710778878192141`}, {{a}}, {1}, {}]\), 
            ",", \(AncestralLineage[
              b, {0, 0.027696065882077705`}, {{b}}, {1}, {}]\), ",", 
            RowBox[{"AncestralLineage", "[", 
              RowBox[{"c", ",", 
                RowBox[{"{", 
                  RowBox[{"0", ",", 
                    InterpretationBox["\[Infinity]",
                      DirectedInfinity[ 1]]}], "}"}], ",", \({{c}}\), 
                ",", \({1}\), ",", \({}\)}], "]"}], 
            ",", \(AncestralLineage[
              d, {0, 0.027696065882077705`}, {{d}}, {1}, {}]\), 
            ",", \(AncestralLineage[
              1, {0.027696065882077705`, 
                0.05710778878192141`}, {{b, d}}, {1}, {}]\), 
            ",", \(AncestralLineage[
              2, {0.05710778878192141`, 
                0.27049717829601805`}, {{a, b, d}}, {1}, {}]\), 
            ",", \(AncestralLineage[
              3, {0.27049717829601805`, 
                0.4292570949591068`}, {{a, b, d}, {}}, {0.01899643970468609`, 
                1}, {}]\), ",", 
            RowBox[{"AncestralLineage", "[", 
              RowBox[{"4", ",", 
                RowBox[{"{", 
                  RowBox[{"0.27049717829601805`", ",", 
                    InterpretationBox["\[Infinity]",
                      DirectedInfinity[ 1]]}], "}"}], 
                ",", \({{}, {a, b, d}}\), ",", \({0.01899643970468609`, 1}\), 
                ",", \({}\)}], "]"}], ",", 
            RowBox[{"AncestralLineage", "[", 
              RowBox[{"5", ",", 
                RowBox[{"{", 
                  RowBox[{"0.4292570949591068`", ",", 
                    InterpretationBox["\[Infinity]",
                      DirectedInfinity[ 1]]}], "}"}], 
                ",", \({{a, b, d}, {}}\), ",", \({0.01899643970468609`, 1}\), 
                ",", \({}\)}], "]"}], ",", 
            RowBox[{"AncestralLineage", "[", 
              RowBox[{"6", ",", 
                RowBox[{"{", 
                  RowBox[{"0.4292570949591068`", ",", 
                    InterpretationBox["\[Infinity]",
                      DirectedInfinity[ 1]]}], "}"}], ",", \({{}}\), 
                ",", \({1}\), ",", \({}\)}], "]"}]}], "}"}]}],
      SequenceForm[ "G=", {
        AncestralLineage[ a, {0, 0.057107788781921409}, {{a}}, {1}, {}], 
        AncestralLineage[ b, {0, 0.027696065882077705}, {{b}}, {1}, {}], 
        AncestralLineage[ c, {0, 
          DirectedInfinity[ 1]}, {{c}}, {1}, {}], 
        AncestralLineage[ d, {0, 0.027696065882077705}, {{d}}, {1}, {}], 
        AncestralLineage[ 
        1, {0.027696065882077705, 0.057107788781921409}, {{b, d}}, {1}, {}], 
        AncestralLineage[ 
        2, {0.057107788781921409, 0.27049717829601805}, {{a, b, d}}, {1}, {}],
         
        AncestralLineage[ 
        3, {0.27049717829601805, 0.4292570949591068}, {{a, b, d}, {}}, {
          0.018996439704686091, 1}, {}], 
        AncestralLineage[ 4, {0.27049717829601805, 
          DirectedInfinity[ 1]}, {{}, {a, b, d}}, {0.018996439704686091, 
          1}, {}], 
        AncestralLineage[ 5, {0.4292570949591068, 
          DirectedInfinity[ 1]}, {{a, b, d}, {}}, {0.018996439704686091, 
          1}, {}], 
        AncestralLineage[ 6, {0.4292570949591068, 
          DirectedInfinity[ 1]}, {{}}, {1}, {}]}],
      Editable->False]], "Print",
  CellLabel->"From In[122]:="],

Cell[BoxData[
    \({0.45951657742311824`, 3, None}\)], "Print",
  CellLabel->"From In[122]:="],

Cell[BoxData[
    InterpretationBox[\("Coalescing "\[InvisibleSpace]{5, 
          6}\[InvisibleSpace]"; current lineages "\[InvisibleSpace]{c, 4, 5, 
          6}\),
      SequenceForm[ 
      "Coalescing ", {5, 6}, "; current lineages ", {c, 4, 5, 6}],
      Editable->False]], "Print",
  CellLabel->"From In[122]:="],

Cell[BoxData[
    InterpretationBox[
      RowBox[{"\<\"G=\"\>", "\[InvisibleSpace]", 
        RowBox[{"{", 
          
          RowBox[{\(AncestralLineage[
              a, {0, 0.05710778878192141`}, {{a}}, {1}, {}]\), 
            ",", \(AncestralLineage[
              b, {0, 0.027696065882077705`}, {{b}}, {1}, {}]\), ",", 
            RowBox[{"AncestralLineage", "[", 
              RowBox[{"c", ",", 
                RowBox[{"{", 
                  RowBox[{"0", ",", 
                    InterpretationBox["\[Infinity]",
                      DirectedInfinity[ 1]]}], "}"}], ",", \({{c}}\), 
                ",", \({1}\), ",", \({}\)}], "]"}], 
            ",", \(AncestralLineage[
              d, {0, 0.027696065882077705`}, {{d}}, {1}, {}]\), 
            ",", \(AncestralLineage[
              1, {0.027696065882077705`, 
                0.05710778878192141`}, {{b, d}}, {1}, {}]\), 
            ",", \(AncestralLineage[
              2, {0.05710778878192141`, 
                0.27049717829601805`}, {{a, b, d}}, {1}, {}]\), 
            ",", \(AncestralLineage[
              3, {0.27049717829601805`, 
                0.4292570949591068`}, {{a, b, d}, {}}, {0.01899643970468609`, 
                1}, {}]\), ",", 
            RowBox[{"AncestralLineage", "[", 
              RowBox[{"4", ",", 
                RowBox[{"{", 
                  RowBox[{"0.27049717829601805`", ",", 
                    InterpretationBox["\[Infinity]",
                      DirectedInfinity[ 1]]}], "}"}], 
                ",", \({{}, {a, b, d}}\), ",", \({0.01899643970468609`, 1}\), 
                ",", \({}\)}], "]"}], 
            ",", \(AncestralLineage[
              5, {0.4292570949591068`, 
                0.45951657742311824`}, {{a, b, 
                  d}, {}}, {0.01899643970468609`, 1}, {}]\), 
            ",", \(AncestralLineage[
              6, {0.4292570949591068`, 
                0.45951657742311824`}, {{}}, {1}, {}]\), ",", 
            RowBox[{"AncestralLineage", "[", 
              RowBox[{"7", ",", 
                RowBox[{"{", 
                  RowBox[{"0.45951657742311824`", ",", 
                    InterpretationBox["\[Infinity]",
                      DirectedInfinity[ 1]]}], "}"}], 
                ",", \({{a, b, d}, {}}\), ",", \({0.01899643970468609`, 1}\), 
                ",", \({}\)}], "]"}]}], "}"}]}],
      SequenceForm[ "G=", {
        AncestralLineage[ a, {0, 0.057107788781921409}, {{a}}, {1}, {}], 
        AncestralLineage[ b, {0, 0.027696065882077705}, {{b}}, {1}, {}], 
        AncestralLineage[ c, {0, 
          DirectedInfinity[ 1]}, {{c}}, {1}, {}], 
        AncestralLineage[ d, {0, 0.027696065882077705}, {{d}}, {1}, {}], 
        AncestralLineage[ 
        1, {0.027696065882077705, 0.057107788781921409}, {{b, d}}, {1}, {}], 
        AncestralLineage[ 
        2, {0.057107788781921409, 0.27049717829601805}, {{a, b, d}}, {1}, {}],
         
        AncestralLineage[ 
        3, {0.27049717829601805, 0.4292570949591068}, {{a, b, d}, {}}, {
          0.018996439704686091, 1}, {}], 
        AncestralLineage[ 4, {0.27049717829601805, 
          DirectedInfinity[ 1]}, {{}, {a, b, d}}, {0.018996439704686091, 
          1}, {}], 
        AncestralLineage[ 
        5, {0.4292570949591068, 0.45951657742311824}, {{a, b, d}, {}}, {
          0.018996439704686091, 1}, {}], 
        AncestralLineage[ 
        6, {0.4292570949591068, 0.45951657742311824}, {{}}, {1}, {}], 
        AncestralLineage[ 7, {0.45951657742311824, 
          DirectedInfinity[ 1]}, {{a, b, d}, {}}, {0.018996439704686091, 
          1}, {}]}],
      Editable->False]], "Print",
  CellLabel->"From In[122]:="],

Cell[BoxData[
    \({0.6214825149645679`, 2, None}\)], "Print",
  CellLabel->"From In[122]:="],

Cell[BoxData[
    InterpretationBox[\("Coalescing "\[InvisibleSpace]{c, 
          4}\[InvisibleSpace]"; current lineages "\[InvisibleSpace]{c, 4, 
          7}\),
      SequenceForm[ "Coalescing ", {c, 4}, "; current lineages ", {c, 4, 7}],
      Editable->False]], "Print",
  CellLabel->"From In[122]:="],

Cell[BoxData[
    InterpretationBox[
      RowBox[{"\<\"G=\"\>", "\[InvisibleSpace]", 
        RowBox[{"{", 
          
          RowBox[{\(AncestralLineage[
              a, {0, 0.05710778878192141`}, {{a}}, {1}, {}]\), 
            ",", \(AncestralLineage[
              b, {0, 0.027696065882077705`}, {{b}}, {1}, {}]\), 
            ",", \(AncestralLineage[
              c, {0, 0.6214825149645679`}, {{c}}, {1}, {}]\), 
            ",", \(AncestralLineage[
              d, {0, 0.027696065882077705`}, {{d}}, {1}, {}]\), 
            ",", \(AncestralLineage[
              1, {0.027696065882077705`, 
                0.05710778878192141`}, {{b, d}}, {1}, {}]\), 
            ",", \(AncestralLineage[
              2, {0.05710778878192141`, 
                0.27049717829601805`}, {{a, b, d}}, {1}, {}]\), 
            ",", \(AncestralLineage[
              3, {0.27049717829601805`, 
                0.4292570949591068`}, {{a, b, d}, {}}, {0.01899643970468609`, 
                1}, {}]\), 
            ",", \(AncestralLineage[
              4, {0.27049717829601805`, 
                0.6214825149645679`}, {{}, {a, b, d}}, {0.01899643970468609`, 
                1}, {}]\), 
            ",", \(AncestralLineage[
              5, {0.4292570949591068`, 
                0.45951657742311824`}, {{a, b, 
                  d}, {}}, {0.01899643970468609`, 1}, {}]\), 
            ",", \(AncestralLineage[
              6, {0.4292570949591068`, 
                0.45951657742311824`}, {{}}, {1}, {}]\), ",", 
            RowBox[{"AncestralLineage", "[", 
              RowBox[{"7", ",", 
                RowBox[{"{", 
                  RowBox[{"0.45951657742311824`", ",", 
                    InterpretationBox["\[Infinity]",
                      DirectedInfinity[ 1]]}], "}"}], 
                ",", \({{a, b, d}, {}}\), ",", \({0.01899643970468609`, 1}\), 
                ",", \({}\)}], "]"}], ",", 
            RowBox[{"AncestralLineage", "[", 
              RowBox[{"8", ",", 
                RowBox[{"{", 
                  RowBox[{"0.6214825149645679`", ",", 
                    InterpretationBox["\[Infinity]",
                      DirectedInfinity[ 1]]}], "}"}], 
                ",", \({{c}, {a, b, c, d}}\), 
                ",", \({0.01899643970468609`, 1}\), ",", \({}\)}], "]"}]}], 
          "}"}]}],
      SequenceForm[ "G=", {
        AncestralLineage[ a, {0, 0.057107788781921409}, {{a}}, {1}, {}], 
        AncestralLineage[ b, {0, 0.027696065882077705}, {{b}}, {1}, {}], 
        AncestralLineage[ c, {0, 0.62148251496456786}, {{c}}, {1}, {}], 
        AncestralLineage[ d, {0, 0.027696065882077705}, {{d}}, {1}, {}], 
        AncestralLineage[ 
        1, {0.027696065882077705, 0.057107788781921409}, {{b, d}}, {1}, {}], 
        AncestralLineage[ 
        2, {0.057107788781921409, 0.27049717829601805}, {{a, b, d}}, {1}, {}],
         
        AncestralLineage[ 
        3, {0.27049717829601805, 0.4292570949591068}, {{a, b, d}, {}}, {
          0.018996439704686091, 1}, {}], 
        AncestralLineage[ 
        4, {0.27049717829601805, 0.62148251496456786}, {{}, {a, b, d}}, {
          0.018996439704686091, 1}, {}], 
        AncestralLineage[ 
        5, {0.4292570949591068, 0.45951657742311824}, {{a, b, d}, {}}, {
          0.018996439704686091, 1}, {}], 
        AncestralLineage[ 
        6, {0.4292570949591068, 0.45951657742311824}, {{}}, {1}, {}], 
        AncestralLineage[ 7, {0.45951657742311824, 
          DirectedInfinity[ 1]}, {{a, b, d}, {}}, {0.018996439704686091, 
          1}, {}], 
        AncestralLineage[ 8, {0.62148251496456786, 
          DirectedInfinity[ 1]}, {{c}, {a, b, c, d}}, {0.018996439704686091, 
          1}, {}]}],
      Editable->False]], "Print",
  CellLabel->"From In[122]:="],

Cell[BoxData[
    \({0.6452036798471656`, 1, None}\)], "Print",
  CellLabel->"From In[122]:="],

Cell[BoxData[
    InterpretationBox[\("Coalescing "\[InvisibleSpace]{7, 
          8}\[InvisibleSpace]"; current lineages "\[InvisibleSpace]{7, 8}\),
      SequenceForm[ "Coalescing ", {7, 8}, "; current lineages ", {7, 8}],
      Editable->False]], "Print",
  CellLabel->"From In[122]:="],

Cell[BoxData[
    InterpretationBox[
      RowBox[{"\<\"G=\"\>", "\[InvisibleSpace]", 
        RowBox[{"{", 
          
          RowBox[{\(AncestralLineage[
              a, {0, 0.05710778878192141`}, {{a}}, {1}, {}]\), 
            ",", \(AncestralLineage[
              b, {0, 0.027696065882077705`}, {{b}}, {1}, {}]\), 
            ",", \(AncestralLineage[
              c, {0, 0.6214825149645679`}, {{c}}, {1}, {}]\), 
            ",", \(AncestralLineage[
              d, {0, 0.027696065882077705`}, {{d}}, {1}, {}]\), 
            ",", \(AncestralLineage[
              1, {0.027696065882077705`, 
                0.05710778878192141`}, {{b, d}}, {1}, {}]\), 
            ",", \(AncestralLineage[
              2, {0.05710778878192141`, 
                0.27049717829601805`}, {{a, b, d}}, {1}, {}]\), 
            ",", \(AncestralLineage[
              3, {0.27049717829601805`, 
                0.4292570949591068`}, {{a, b, d}, {}}, {0.01899643970468609`, 
                1}, {}]\), 
            ",", \(AncestralLineage[
              4, {0.27049717829601805`, 
                0.6214825149645679`}, {{}, {a, b, d}}, {0.01899643970468609`, 
                1}, {}]\), 
            ",", \(AncestralLineage[
              5, {0.4292570949591068`, 
                0.45951657742311824`}, {{a, b, 
                  d}, {}}, {0.01899643970468609`, 1}, {}]\), 
            ",", \(AncestralLineage[
              6, {0.4292570949591068`, 
                0.45951657742311824`}, {{}}, {1}, {}]\), 
            ",", \(AncestralLineage[
              7, {0.45951657742311824`, 
                0.6452036798471656`}, {{a, b, d}, {}}, {0.01899643970468609`, 
                1}, {}]\), 
            ",", \(AncestralLineage[
              8, {0.6214825149645679`, 
                0.6452036798471656`}, {{c}, {a, b, c, 
                  d}}, {0.01899643970468609`, 1}, {}]\), ",", 
            RowBox[{"AncestralLineage", "[", 
              RowBox[{"9", ",", 
                RowBox[{"{", 
                  RowBox[{"0.6452036798471656`", ",", 
                    InterpretationBox["\[Infinity]",
                      DirectedInfinity[ 1]]}], "}"}], ",", \({{a, b, c, d}}\),
                 ",", \({1}\), ",", \({}\)}], "]"}]}], "}"}]}],
      SequenceForm[ "G=", {
        AncestralLineage[ a, {0, 0.057107788781921409}, {{a}}, {1}, {}], 
        AncestralLineage[ b, {0, 0.027696065882077705}, {{b}}, {1}, {}], 
        AncestralLineage[ c, {0, 0.62148251496456786}, {{c}}, {1}, {}], 
        AncestralLineage[ d, {0, 0.027696065882077705}, {{d}}, {1}, {}], 
        AncestralLineage[ 
        1, {0.027696065882077705, 0.057107788781921409}, {{b, d}}, {1}, {}], 
        AncestralLineage[ 
        2, {0.057107788781921409, 0.27049717829601805}, {{a, b, d}}, {1}, {}],
         
        AncestralLineage[ 
        3, {0.27049717829601805, 0.4292570949591068}, {{a, b, d}, {}}, {
          0.018996439704686091, 1}, {}], 
        AncestralLineage[ 
        4, {0.27049717829601805, 0.62148251496456786}, {{}, {a, b, d}}, {
          0.018996439704686091, 1}, {}], 
        AncestralLineage[ 
        5, {0.4292570949591068, 0.45951657742311824}, {{a, b, d}, {}}, {
          0.018996439704686091, 1}, {}], 
        AncestralLineage[ 
        6, {0.4292570949591068, 0.45951657742311824}, {{}}, {1}, {}], 
        AncestralLineage[ 
        7, {0.45951657742311824, 0.64520367984716565}, {{a, b, d}, {}}, {
          0.018996439704686091, 1}, {}], 
        AncestralLineage[ 
        8, {0.62148251496456786, 0.64520367984716565}, {{c}, {a, b, c, d}}, {
          0.018996439704686091, 1}, {}], 
        AncestralLineage[ 9, {0.64520367984716565, 
          DirectedInfinity[ 1]}, {{a, b, c, d}}, {1}, {}]}],
      Editable->False]], "Print",
  CellLabel->"From In[122]:="],

Cell[BoxData[
    \({1.9706637158007017`, 2, 0.9371981015363346`}\)], "Print",
  CellLabel->"From In[122]:="],

Cell[BoxData[
    InterpretationBox[\("Recombining "\[InvisibleSpace]9\[InvisibleSpace]"; \
current lineages "\[InvisibleSpace]{9}\),
      SequenceForm[ "Recombining ", 9, "; current lineages ", {9}],
      Editable->False]], "Print",
  CellLabel->"From In[122]:="],

Cell[BoxData[
    InterpretationBox[
      RowBox[{"\<\"G=\"\>", "\[InvisibleSpace]", 
        RowBox[{"{", 
          
          RowBox[{\(AncestralLineage[
              a, {0, 0.05710778878192141`}, {{a}}, {1}, {}]\), 
            ",", \(AncestralLineage[
              b, {0, 0.027696065882077705`}, {{b}}, {1}, {}]\), 
            ",", \(AncestralLineage[
              c, {0, 0.6214825149645679`}, {{c}}, {1}, {}]\), 
            ",", \(AncestralLineage[
              d, {0, 0.027696065882077705`}, {{d}}, {1}, {}]\), 
            ",", \(AncestralLineage[
              1, {0.027696065882077705`, 
                0.05710778878192141`}, {{b, d}}, {1}, {}]\), 
            ",", \(AncestralLineage[
              2, {0.05710778878192141`, 
                0.27049717829601805`}, {{a, b, d}}, {1}, {}]\), 
            ",", \(AncestralLineage[
              3, {0.27049717829601805`, 
                0.4292570949591068`}, {{a, b, d}, {}}, {0.01899643970468609`, 
                1}, {}]\), 
            ",", \(AncestralLineage[
              4, {0.27049717829601805`, 
                0.6214825149645679`}, {{}, {a, b, d}}, {0.01899643970468609`, 
                1}, {}]\), 
            ",", \(AncestralLineage[
              5, {0.4292570949591068`, 
                0.45951657742311824`}, {{a, b, 
                  d}, {}}, {0.01899643970468609`, 1}, {}]\), 
            ",", \(AncestralLineage[
              6, {0.4292570949591068`, 
                0.45951657742311824`}, {{}}, {1}, {}]\), 
            ",", \(AncestralLineage[
              7, {0.45951657742311824`, 
                0.6452036798471656`}, {{a, b, d}, {}}, {0.01899643970468609`, 
                1}, {}]\), 
            ",", \(AncestralLineage[
              8, {0.6214825149645679`, 
                0.6452036798471656`}, {{c}, {a, b, c, 
                  d}}, {0.01899643970468609`, 1}, {}]\), 
            ",", \(AncestralLineage[
              9, {0.6452036798471656`, 
                1.9706637158007017`}, {{a, b, c, d}}, {1}, {}]\), ",", 
            RowBox[{"AncestralLineage", "[", 
              RowBox[{"10", ",", 
                RowBox[{"{", 
                  RowBox[{"1.9706637158007017`", ",", 
                    InterpretationBox["\[Infinity]",
                      DirectedInfinity[ 1]]}], "}"}], 
                ",", \({{a, b, c, d}, {}}\), 
                ",", \({0.9371981015363346`, 1}\), ",", \({}\)}], "]"}], ",", 
            
            RowBox[{"AncestralLineage", "[", 
              RowBox[{"11", ",", 
                RowBox[{"{", 
                  RowBox[{"1.9706637158007017`", ",", 
                    InterpretationBox["\[Infinity]",
                      DirectedInfinity[ 1]]}], "}"}], 
                ",", \({{}, {a, b, c, d}}\), 
                ",", \({0.9371981015363346`, 1}\), ",", \({}\)}], "]"}]}], 
          "}"}]}],
      SequenceForm[ "G=", {
        AncestralLineage[ a, {0, 0.057107788781921409}, {{a}}, {1}, {}], 
        AncestralLineage[ b, {0, 0.027696065882077705}, {{b}}, {1}, {}], 
        AncestralLineage[ c, {0, 0.62148251496456786}, {{c}}, {1}, {}], 
        AncestralLineage[ d, {0, 0.027696065882077705}, {{d}}, {1}, {}], 
        AncestralLineage[ 
        1, {0.027696065882077705, 0.057107788781921409}, {{b, d}}, {1}, {}], 
        AncestralLineage[ 
        2, {0.057107788781921409, 0.27049717829601805}, {{a, b, d}}, {1}, {}],
         
        AncestralLineage[ 
        3, {0.27049717829601805, 0.4292570949591068}, {{a, b, d}, {}}, {
          0.018996439704686091, 1}, {}], 
        AncestralLineage[ 
        4, {0.27049717829601805, 0.62148251496456786}, {{}, {a, b, d}}, {
          0.018996439704686091, 1}, {}], 
        AncestralLineage[ 
        5, {0.4292570949591068, 0.45951657742311824}, {{a, b, d}, {}}, {
          0.018996439704686091, 1}, {}], 
        AncestralLineage[ 
        6, {0.4292570949591068, 0.45951657742311824}, {{}}, {1}, {}], 
        AncestralLineage[ 
        7, {0.45951657742311824, 0.64520367984716565}, {{a, b, d}, {}}, {
          0.018996439704686091, 1}, {}], 
        AncestralLineage[ 
        8, {0.62148251496456786, 0.64520367984716565}, {{c}, {a, b, c, d}}, {
          0.018996439704686091, 1}, {}], 
        AncestralLineage[ 
        9, {0.64520367984716565, 1.9706637158007017}, {{a, b, c, d}}, {
          1}, {}], 
        AncestralLineage[ 10, {1.9706637158007017, 
          DirectedInfinity[ 1]}, {{a, b, c, d}, {}}, {0.93719810153633465, 
          1}, {}], 
        AncestralLineage[ 11, {1.9706637158007017, 
          DirectedInfinity[ 1]}, {{}, {a, b, c, d}}, {0.93719810153633465, 
          1}, {}]}],
      Editable->False]], "Print",
  CellLabel->"From In[122]:="],

Cell[BoxData[
    \({2.118015261702507`, 3, 0.47831059952724087`}\)], "Print",
  CellLabel->"From In[122]:="],

Cell[BoxData[
    InterpretationBox[\("Recombining "\[InvisibleSpace]11\[InvisibleSpace]"; \
current lineages "\[InvisibleSpace]{10, 11}\),
      SequenceForm[ "Recombining ", 11, "; current lineages ", {10, 11}],
      Editable->False]], "Print",
  CellLabel->"From In[122]:="],

Cell[BoxData[
    InterpretationBox[
      RowBox[{"\<\"G=\"\>", "\[InvisibleSpace]", 
        RowBox[{"{", 
          
          RowBox[{\(AncestralLineage[
              a, {0, 0.05710778878192141`}, {{a}}, {1}, {}]\), 
            ",", \(AncestralLineage[
              b, {0, 0.027696065882077705`}, {{b}}, {1}, {}]\), 
            ",", \(AncestralLineage[
              c, {0, 0.6214825149645679`}, {{c}}, {1}, {}]\), 
            ",", \(AncestralLineage[
              d, {0, 0.027696065882077705`}, {{d}}, {1}, {}]\), 
            ",", \(AncestralLineage[
              1, {0.027696065882077705`, 
                0.05710778878192141`}, {{b, d}}, {1}, {}]\), 
            ",", \(AncestralLineage[
              2, {0.05710778878192141`, 
                0.27049717829601805`}, {{a, b, d}}, {1}, {}]\), 
            ",", \(AncestralLineage[
              3, {0.27049717829601805`, 
                0.4292570949591068`}, {{a, b, d}, {}}, {0.01899643970468609`, 
                1}, {}]\), 
            ",", \(AncestralLineage[
              4, {0.27049717829601805`, 
                0.6214825149645679`}, {{}, {a, b, d}}, {0.01899643970468609`, 
                1}, {}]\), 
            ",", \(AncestralLineage[
              5, {0.4292570949591068`, 
                0.45951657742311824`}, {{a, b, 
                  d}, {}}, {0.01899643970468609`, 1}, {}]\), 
            ",", \(AncestralLineage[
              6, {0.4292570949591068`, 
                0.45951657742311824`}, {{}}, {1}, {}]\), 
            ",", \(AncestralLineage[
              7, {0.45951657742311824`, 
                0.6452036798471656`}, {{a, b, d}, {}}, {0.01899643970468609`, 
                1}, {}]\), 
            ",", \(AncestralLineage[
              8, {0.6214825149645679`, 
                0.6452036798471656`}, {{c}, {a, b, c, 
                  d}}, {0.01899643970468609`, 1}, {}]\), 
            ",", \(AncestralLineage[
              9, {0.6452036798471656`, 
                1.9706637158007017`}, {{a, b, c, d}}, {1}, {}]\), ",", 
            RowBox[{"AncestralLineage", "[", 
              RowBox[{"10", ",", 
                RowBox[{"{", 
                  RowBox[{"1.9706637158007017`", ",", 
                    InterpretationBox["\[Infinity]",
                      DirectedInfinity[ 1]]}], "}"}], 
                ",", \({{a, b, c, d}, {}}\), 
                ",", \({0.9371981015363346`, 1}\), ",", \({}\)}], "]"}], 
            ",", \(AncestralLineage[
              11, {1.9706637158007017`, 
                2.118015261702507`}, {{}, {a, b, c, 
                  d}}, {0.9371981015363346`, 1}, {}]\), ",", 
            RowBox[{"AncestralLineage", "[", 
              RowBox[{"12", ",", 
                RowBox[{"{", 
                  RowBox[{"2.118015261702507`", ",", 
                    InterpretationBox["\[Infinity]",
                      DirectedInfinity[ 1]]}], "}"}], ",", \({{}}\), 
                ",", \({1}\), ",", \({}\)}], "]"}], ",", 
            RowBox[{"AncestralLineage", "[", 
              RowBox[{"13", ",", 
                RowBox[{"{", 
                  RowBox[{"2.118015261702507`", ",", 
                    InterpretationBox["\[Infinity]",
                      DirectedInfinity[ 1]]}], "}"}], 
                ",", \({{}, {a, b, c, d}}\), 
                ",", \({0.9371981015363346`, 1}\), ",", \({}\)}], "]"}]}], 
          "}"}]}],
      SequenceForm[ "G=", {
        AncestralLineage[ a, {0, 0.057107788781921409}, {{a}}, {1}, {}], 
        AncestralLineage[ b, {0, 0.027696065882077705}, {{b}}, {1}, {}], 
        AncestralLineage[ c, {0, 0.62148251496456786}, {{c}}, {1}, {}], 
        AncestralLineage[ d, {0, 0.027696065882077705}, {{d}}, {1}, {}], 
        AncestralLineage[ 
        1, {0.027696065882077705, 0.057107788781921409}, {{b, d}}, {1}, {}], 
        AncestralLineage[ 
        2, {0.057107788781921409, 0.27049717829601805}, {{a, b, d}}, {1}, {}],
         
        AncestralLineage[ 
        3, {0.27049717829601805, 0.4292570949591068}, {{a, b, d}, {}}, {
          0.018996439704686091, 1}, {}], 
        AncestralLineage[ 
        4, {0.27049717829601805, 0.62148251496456786}, {{}, {a, b, d}}, {
          0.018996439704686091, 1}, {}], 
        AncestralLineage[ 
        5, {0.4292570949591068, 0.45951657742311824}, {{a, b, d}, {}}, {
          0.018996439704686091, 1}, {}], 
        AncestralLineage[ 
        6, {0.4292570949591068, 0.45951657742311824}, {{}}, {1}, {}], 
        AncestralLineage[ 
        7, {0.45951657742311824, 0.64520367984716565}, {{a, b, d}, {}}, {
          0.018996439704686091, 1}, {}], 
        AncestralLineage[ 
        8, {0.62148251496456786, 0.64520367984716565}, {{c}, {a, b, c, d}}, {
          0.018996439704686091, 1}, {}], 
        AncestralLineage[ 
        9, {0.64520367984716565, 1.9706637158007017}, {{a, b, c, d}}, {
          1}, {}], 
        AncestralLineage[ 10, {1.9706637158007017, 
          DirectedInfinity[ 1]}, {{a, b, c, d}, {}}, {0.93719810153633465, 
          1}, {}], 
        AncestralLineage[ 
        11, {1.9706637158007017, 2.118015261702507}, {{}, {a, b, c, d}}, {
          0.93719810153633465, 1}, {}], 
        AncestralLineage[ 12, {2.118015261702507, 
          DirectedInfinity[ 1]}, {{}}, {1}, {}], 
        AncestralLineage[ 13, {2.118015261702507, 
          DirectedInfinity[ 1]}, {{}, {a, b, c, d}}, {0.93719810153633465, 
          1}, {}]}],
      Editable->False]], "Print",
  CellLabel->"From In[122]:="],

Cell[BoxData[
    \({2.228204237719424`, 4, 0.42408428200619824`}\)], "Print",
  CellLabel->"From In[122]:="],

Cell[BoxData[
    InterpretationBox[\("Recombining "\[InvisibleSpace]13\[InvisibleSpace]"; \
current lineages "\[InvisibleSpace]{10, 12, 13}\),
      SequenceForm[ "Recombining ", 13, "; current lineages ", {10, 12, 13}],
      Editable->False]], "Print",
  CellLabel->"From In[122]:="],

Cell[BoxData[
    InterpretationBox[
      RowBox[{"\<\"G=\"\>", "\[InvisibleSpace]", 
        RowBox[{"{", 
          
          RowBox[{\(AncestralLineage[
              a, {0, 0.05710778878192141`}, {{a}}, {1}, {}]\), 
            ",", \(AncestralLineage[
              b, {0, 0.027696065882077705`}, {{b}}, {1}, {}]\), 
            ",", \(AncestralLineage[
              c, {0, 0.6214825149645679`}, {{c}}, {1}, {}]\), 
            ",", \(AncestralLineage[
              d, {0, 0.027696065882077705`}, {{d}}, {1}, {}]\), 
            ",", \(AncestralLineage[
              1, {0.027696065882077705`, 
                0.05710778878192141`}, {{b, d}}, {1}, {}]\), 
            ",", \(AncestralLineage[
              2, {0.05710778878192141`, 
                0.27049717829601805`}, {{a, b, d}}, {1}, {}]\), 
            ",", \(AncestralLineage[
              3, {0.27049717829601805`, 
                0.4292570949591068`}, {{a, b, d}, {}}, {0.01899643970468609`, 
                1}, {}]\), 
            ",", \(AncestralLineage[
              4, {0.27049717829601805`, 
                0.6214825149645679`}, {{}, {a, b, d}}, {0.01899643970468609`, 
                1}, {}]\), 
            ",", \(AncestralLineage[
              5, {0.4292570949591068`, 
                0.45951657742311824`}, {{a, b, 
                  d}, {}}, {0.01899643970468609`, 1}, {}]\), 
            ",", \(AncestralLineage[
              6, {0.4292570949591068`, 
                0.45951657742311824`}, {{}}, {1}, {}]\), 
            ",", \(AncestralLineage[
              7, {0.45951657742311824`, 
                0.6452036798471656`}, {{a, b, d}, {}}, {0.01899643970468609`, 
                1}, {}]\), 
            ",", \(AncestralLineage[
              8, {0.6214825149645679`, 
                0.6452036798471656`}, {{c}, {a, b, c, 
                  d}}, {0.01899643970468609`, 1}, {}]\), 
            ",", \(AncestralLineage[
              9, {0.6452036798471656`, 
                1.9706637158007017`}, {{a, b, c, d}}, {1}, {}]\), ",", 
            RowBox[{"AncestralLineage", "[", 
              RowBox[{"10", ",", 
                RowBox[{"{", 
                  RowBox[{"1.9706637158007017`", ",", 
                    InterpretationBox["\[Infinity]",
                      DirectedInfinity[ 1]]}], "}"}], 
                ",", \({{a, b, c, d}, {}}\), 
                ",", \({0.9371981015363346`, 1}\), ",", \({}\)}], "]"}], 
            ",", \(AncestralLineage[
              11, {1.9706637158007017`, 
                2.118015261702507`}, {{}, {a, b, c, 
                  d}}, {0.9371981015363346`, 1}, {}]\), ",", 
            RowBox[{"AncestralLineage", "[", 
              RowBox[{"12", ",", 
                RowBox[{"{", 
                  RowBox[{"2.118015261702507`", ",", 
                    InterpretationBox["\[Infinity]",
                      DirectedInfinity[ 1]]}], "}"}], ",", \({{}}\), 
                ",", \({1}\), ",", \({}\)}], "]"}], 
            ",", \(AncestralLineage[
              13, {2.118015261702507`, 
                2.228204237719424`}, {{}, {a, b, c, 
                  d}}, {0.9371981015363346`, 1}, {}]\), ",", 
            RowBox[{"AncestralLineage", "[", 
              RowBox[{"14", ",", 
                RowBox[{"{", 
                  RowBox[{"2.228204237719424`", ",", 
                    InterpretationBox["\[Infinity]",
                      DirectedInfinity[ 1]]}], "}"}], ",", \({{}}\), 
                ",", \({1}\), ",", \({}\)}], "]"}], ",", 
            RowBox[{"AncestralLineage", "[", 
              RowBox[{"15", ",", 
                RowBox[{"{", 
                  RowBox[{"2.228204237719424`", ",", 
                    InterpretationBox["\[Infinity]",
                      DirectedInfinity[ 1]]}], "}"}], 
                ",", \({{}, {a, b, c, d}}\), 
                ",", \({0.9371981015363346`, 1}\), ",", \({}\)}], "]"}]}], 
          "}"}]}],
      SequenceForm[ "G=", {
        AncestralLineage[ a, {0, 0.057107788781921409}, {{a}}, {1}, {}], 
        AncestralLineage[ b, {0, 0.027696065882077705}, {{b}}, {1}, {}], 
        AncestralLineage[ c, {0, 0.62148251496456786}, {{c}}, {1}, {}], 
        AncestralLineage[ d, {0, 0.027696065882077705}, {{d}}, {1}, {}], 
        AncestralLineage[ 
        1, {0.027696065882077705, 0.057107788781921409}, {{b, d}}, {1}, {}], 
        AncestralLineage[ 
        2, {0.057107788781921409, 0.27049717829601805}, {{a, b, d}}, {1}, {}],
         
        AncestralLineage[ 
        3, {0.27049717829601805, 0.4292570949591068}, {{a, b, d}, {}}, {
          0.018996439704686091, 1}, {}], 
        AncestralLineage[ 
        4, {0.27049717829601805, 0.62148251496456786}, {{}, {a, b, d}}, {
          0.018996439704686091, 1}, {}], 
        AncestralLineage[ 
        5, {0.4292570949591068, 0.45951657742311824}, {{a, b, d}, {}}, {
          0.018996439704686091, 1}, {}], 
        AncestralLineage[ 
        6, {0.4292570949591068, 0.45951657742311824}, {{}}, {1}, {}], 
        AncestralLineage[ 
        7, {0.45951657742311824, 0.64520367984716565}, {{a, b, d}, {}}, {
          0.018996439704686091, 1}, {}], 
        AncestralLineage[ 
        8, {0.62148251496456786, 0.64520367984716565}, {{c}, {a, b, c, d}}, {
          0.018996439704686091, 1}, {}], 
        AncestralLineage[ 
        9, {0.64520367984716565, 1.9706637158007017}, {{a, b, c, d}}, {
          1}, {}], 
        AncestralLineage[ 10, {1.9706637158007017, 
          DirectedInfinity[ 1]}, {{a, b, c, d}, {}}, {0.93719810153633465, 
          1}, {}], 
        AncestralLineage[ 
        11, {1.9706637158007017, 2.118015261702507}, {{}, {a, b, c, d}}, {
          0.93719810153633465, 1}, {}], 
        AncestralLineage[ 12, {2.118015261702507, 
          DirectedInfinity[ 1]}, {{}}, {1}, {}], 
        AncestralLineage[ 
        13, {2.118015261702507, 2.228204237719424}, {{}, {a, b, c, d}}, {
          0.93719810153633465, 1}, {}], 
        AncestralLineage[ 14, {2.228204237719424, 
          DirectedInfinity[ 1]}, {{}}, {1}, {}], 
        AncestralLineage[ 15, {2.228204237719424, 
          DirectedInfinity[ 1]}, {{}, {a, b, c, d}}, {0.93719810153633465, 
          1}, {}]}],
      Editable->False]], "Print",
  CellLabel->"From In[122]:="],

Cell[BoxData[
    \({2.2897969825533644`, 3, None}\)], "Print",
  CellLabel->"From In[122]:="],

Cell[BoxData[
    InterpretationBox[\("Coalescing "\[InvisibleSpace]{10, 
          14}\[InvisibleSpace]"; current lineages "\[InvisibleSpace]{10, 12, 
          14, 15}\),
      SequenceForm[ 
      "Coalescing ", {10, 14}, "; current lineages ", {10, 12, 14, 15}],
      Editable->False]], "Print",
  CellLabel->"From In[122]:="],

Cell[BoxData[
    InterpretationBox[
      RowBox[{"\<\"G=\"\>", "\[InvisibleSpace]", 
        RowBox[{"{", 
          
          RowBox[{\(AncestralLineage[
              a, {0, 0.05710778878192141`}, {{a}}, {1}, {}]\), 
            ",", \(AncestralLineage[
              b, {0, 0.027696065882077705`}, {{b}}, {1}, {}]\), 
            ",", \(AncestralLineage[
              c, {0, 0.6214825149645679`}, {{c}}, {1}, {}]\), 
            ",", \(AncestralLineage[
              d, {0, 0.027696065882077705`}, {{d}}, {1}, {}]\), 
            ",", \(AncestralLineage[
              1, {0.027696065882077705`, 
                0.05710778878192141`}, {{b, d}}, {1}, {}]\), 
            ",", \(AncestralLineage[
              2, {0.05710778878192141`, 
                0.27049717829601805`}, {{a, b, d}}, {1}, {}]\), 
            ",", \(AncestralLineage[
              3, {0.27049717829601805`, 
                0.4292570949591068`}, {{a, b, d}, {}}, {0.01899643970468609`, 
                1}, {}]\), 
            ",", \(AncestralLineage[
              4, {0.27049717829601805`, 
                0.6214825149645679`}, {{}, {a, b, d}}, {0.01899643970468609`, 
                1}, {}]\), 
            ",", \(AncestralLineage[
              5, {0.4292570949591068`, 
                0.45951657742311824`}, {{a, b, 
                  d}, {}}, {0.01899643970468609`, 1}, {}]\), 
            ",", \(AncestralLineage[
              6, {0.4292570949591068`, 
                0.45951657742311824`}, {{}}, {1}, {}]\), 
            ",", \(AncestralLineage[
              7, {0.45951657742311824`, 
                0.6452036798471656`}, {{a, b, d}, {}}, {0.01899643970468609`, 
                1}, {}]\), 
            ",", \(AncestralLineage[
              8, {0.6214825149645679`, 
                0.6452036798471656`}, {{c}, {a, b, c, 
                  d}}, {0.01899643970468609`, 1}, {}]\), 
            ",", \(AncestralLineage[
              9, {0.6452036798471656`, 
                1.9706637158007017`}, {{a, b, c, d}}, {1}, {}]\), 
            ",", \(AncestralLineage[
              10, {1.9706637158007017`, 
                2.2897969825533644`}, {{a, b, c, 
                  d}, {}}, {0.9371981015363346`, 1}, {}]\), 
            ",", \(AncestralLineage[
              11, {1.9706637158007017`, 
                2.118015261702507`}, {{}, {a, b, c, 
                  d}}, {0.9371981015363346`, 1}, {}]\), ",", 
            RowBox[{"AncestralLineage", "[", 
              RowBox[{"12", ",", 
                RowBox[{"{", 
                  RowBox[{"2.118015261702507`", ",", 
                    InterpretationBox["\[Infinity]",
                      DirectedInfinity[ 1]]}], "}"}], ",", \({{}}\), 
                ",", \({1}\), ",", \({}\)}], "]"}], 
            ",", \(AncestralLineage[
              13, {2.118015261702507`, 
                2.228204237719424`}, {{}, {a, b, c, 
                  d}}, {0.9371981015363346`, 1}, {}]\), 
            ",", \(AncestralLineage[
              14, {2.228204237719424`, 2.2897969825533644`}, {{}}, {1}, {}]\),
             ",", 
            RowBox[{"AncestralLineage", "[", 
              RowBox[{"15", ",", 
                RowBox[{"{", 
                  RowBox[{"2.228204237719424`", ",", 
                    InterpretationBox["\[Infinity]",
                      DirectedInfinity[ 1]]}], "}"}], 
                ",", \({{}, {a, b, c, d}}\), 
                ",", \({0.9371981015363346`, 1}\), ",", \({}\)}], "]"}], ",", 
            
            RowBox[{"AncestralLineage", "[", 
              RowBox[{"16", ",", 
                RowBox[{"{", 
                  RowBox[{"2.2897969825533644`", ",", 
                    InterpretationBox["\[Infinity]",
                      DirectedInfinity[ 1]]}], "}"}], 
                ",", \({{a, b, c, d}, {}}\), 
                ",", \({0.9371981015363346`, 1}\), ",", \({}\)}], "]"}]}], 
          "}"}]}],
      SequenceForm[ "G=", {
        AncestralLineage[ a, {0, 0.057107788781921409}, {{a}}, {1}, {}], 
        AncestralLineage[ b, {0, 0.027696065882077705}, {{b}}, {1}, {}], 
        AncestralLineage[ c, {0, 0.62148251496456786}, {{c}}, {1}, {}], 
        AncestralLineage[ d, {0, 0.027696065882077705}, {{d}}, {1}, {}], 
        AncestralLineage[ 
        1, {0.027696065882077705, 0.057107788781921409}, {{b, d}}, {1}, {}], 
        AncestralLineage[ 
        2, {0.057107788781921409, 0.27049717829601805}, {{a, b, d}}, {1}, {}],
         
        AncestralLineage[ 
        3, {0.27049717829601805, 0.4292570949591068}, {{a, b, d}, {}}, {
          0.018996439704686091, 1}, {}], 
        AncestralLineage[ 
        4, {0.27049717829601805, 0.62148251496456786}, {{}, {a, b, d}}, {
          0.018996439704686091, 1}, {}], 
        AncestralLineage[ 
        5, {0.4292570949591068, 0.45951657742311824}, {{a, b, d}, {}}, {
          0.018996439704686091, 1}, {}], 
        AncestralLineage[ 
        6, {0.4292570949591068, 0.45951657742311824}, {{}}, {1}, {}], 
        AncestralLineage[ 
        7, {0.45951657742311824, 0.64520367984716565}, {{a, b, d}, {}}, {
          0.018996439704686091, 1}, {}], 
        AncestralLineage[ 
        8, {0.62148251496456786, 0.64520367984716565}, {{c}, {a, b, c, d}}, {
          0.018996439704686091, 1}, {}], 
        AncestralLineage[ 
        9, {0.64520367984716565, 1.9706637158007017}, {{a, b, c, d}}, {
          1}, {}], 
        AncestralLineage[ 
        10, {1.9706637158007017, 2.2897969825533644}, {{a, b, c, d}, {}}, {
          0.93719810153633465, 1}, {}], 
        AncestralLineage[ 
        11, {1.9706637158007017, 2.118015261702507}, {{}, {a, b, c, d}}, {
          0.93719810153633465, 1}, {}], 
        AncestralLineage[ 12, {2.118015261702507, 
          DirectedInfinity[ 1]}, {{}}, {1}, {}], 
        AncestralLineage[ 
        13, {2.118015261702507, 2.228204237719424}, {{}, {a, b, c, d}}, {
          0.93719810153633465, 1}, {}], 
        AncestralLineage[ 
        14, {2.228204237719424, 2.2897969825533644}, {{}}, {1}, {}], 
        AncestralLineage[ 15, {2.228204237719424, 
          DirectedInfinity[ 1]}, {{}, {a, b, c, d}}, {0.93719810153633465, 
          1}, {}], 
        AncestralLineage[ 16, {2.2897969825533644, 
          DirectedInfinity[ 1]}, {{a, b, c, d}, {}}, {0.93719810153633465, 
          1}, {}]}],
      Editable->False]], "Print",
  CellLabel->"From In[122]:="],

Cell[BoxData[
    \({2.3639104415829926`, 2, None}\)], "Print",
  CellLabel->"From In[122]:="],

Cell[BoxData[
    InterpretationBox[\("Coalescing "\[InvisibleSpace]{15, 
          16}\[InvisibleSpace]"; current lineages "\[InvisibleSpace]{12, 15, 
          16}\),
      SequenceForm[ 
      "Coalescing ", {15, 16}, "; current lineages ", {12, 15, 16}],
      Editable->False]], "Print",
  CellLabel->"From In[122]:="],

Cell[BoxData[
    InterpretationBox[
      RowBox[{"\<\"G=\"\>", "\[InvisibleSpace]", 
        RowBox[{"{", 
          
          RowBox[{\(AncestralLineage[
              a, {0, 0.05710778878192141`}, {{a}}, {1}, {}]\), 
            ",", \(AncestralLineage[
              b, {0, 0.027696065882077705`}, {{b}}, {1}, {}]\), 
            ",", \(AncestralLineage[
              c, {0, 0.6214825149645679`}, {{c}}, {1}, {}]\), 
            ",", \(AncestralLineage[
              d, {0, 0.027696065882077705`}, {{d}}, {1}, {}]\), 
            ",", \(AncestralLineage[
              1, {0.027696065882077705`, 
                0.05710778878192141`}, {{b, d}}, {1}, {}]\), 
            ",", \(AncestralLineage[
              2, {0.05710778878192141`, 
                0.27049717829601805`}, {{a, b, d}}, {1}, {}]\), 
            ",", \(AncestralLineage[
              3, {0.27049717829601805`, 
                0.4292570949591068`}, {{a, b, d}, {}}, {0.01899643970468609`, 
                1}, {}]\), 
            ",", \(AncestralLineage[
              4, {0.27049717829601805`, 
                0.6214825149645679`}, {{}, {a, b, d}}, {0.01899643970468609`, 
                1}, {}]\), 
            ",", \(AncestralLineage[
              5, {0.4292570949591068`, 
                0.45951657742311824`}, {{a, b, 
                  d}, {}}, {0.01899643970468609`, 1}, {}]\), 
            ",", \(AncestralLineage[
              6, {0.4292570949591068`, 
                0.45951657742311824`}, {{}}, {1}, {}]\), 
            ",", \(AncestralLineage[
              7, {0.45951657742311824`, 
                0.6452036798471656`}, {{a, b, d}, {}}, {0.01899643970468609`, 
                1}, {}]\), 
            ",", \(AncestralLineage[
              8, {0.6214825149645679`, 
                0.6452036798471656`}, {{c}, {a, b, c, 
                  d}}, {0.01899643970468609`, 1}, {}]\), 
            ",", \(AncestralLineage[
              9, {0.6452036798471656`, 
                1.9706637158007017`}, {{a, b, c, d}}, {1}, {}]\), 
            ",", \(AncestralLineage[
              10, {1.9706637158007017`, 
                2.2897969825533644`}, {{a, b, c, 
                  d}, {}}, {0.9371981015363346`, 1}, {}]\), 
            ",", \(AncestralLineage[
              11, {1.9706637158007017`, 
                2.118015261702507`}, {{}, {a, b, c, 
                  d}}, {0.9371981015363346`, 1}, {}]\), ",", 
            RowBox[{"AncestralLineage", "[", 
              RowBox[{"12", ",", 
                RowBox[{"{", 
                  RowBox[{"2.118015261702507`", ",", 
                    InterpretationBox["\[Infinity]",
                      DirectedInfinity[ 1]]}], "}"}], ",", \({{}}\), 
                ",", \({1}\), ",", \({}\)}], "]"}], 
            ",", \(AncestralLineage[
              13, {2.118015261702507`, 
                2.228204237719424`}, {{}, {a, b, c, 
                  d}}, {0.9371981015363346`, 1}, {}]\), 
            ",", \(AncestralLineage[
              14, {2.228204237719424`, 2.2897969825533644`}, {{}}, {1}, {}]\),
             ",", \(AncestralLineage[
              15, {2.228204237719424`, 
                2.3639104415829926`}, {{}, {a, b, c, 
                  d}}, {0.9371981015363346`, 1}, {}]\), 
            ",", \(AncestralLineage[
              16, {2.2897969825533644`, 
                2.3639104415829926`}, {{a, b, c, 
                  d}, {}}, {0.9371981015363346`, 1}, {}]\), ",", 
            RowBox[{"AncestralLineage", "[", 
              RowBox[{"17", ",", 
                RowBox[{"{", 
                  RowBox[{"2.3639104415829926`", ",", 
                    InterpretationBox["\[Infinity]",
                      DirectedInfinity[ 1]]}], "}"}], ",", \({{a, b, c, d}}\),
                 ",", \({1}\), ",", \({}\)}], "]"}]}], "}"}]}],
      SequenceForm[ "G=", {
        AncestralLineage[ a, {0, 0.057107788781921409}, {{a}}, {1}, {}], 
        AncestralLineage[ b, {0, 0.027696065882077705}, {{b}}, {1}, {}], 
        AncestralLineage[ c, {0, 0.62148251496456786}, {{c}}, {1}, {}], 
        AncestralLineage[ d, {0, 0.027696065882077705}, {{d}}, {1}, {}], 
        AncestralLineage[ 
        1, {0.027696065882077705, 0.057107788781921409}, {{b, d}}, {1}, {}], 
        AncestralLineage[ 
        2, {0.057107788781921409, 0.27049717829601805}, {{a, b, d}}, {1}, {}],
         
        AncestralLineage[ 
        3, {0.27049717829601805, 0.4292570949591068}, {{a, b, d}, {}}, {
          0.018996439704686091, 1}, {}], 
        AncestralLineage[ 
        4, {0.27049717829601805, 0.62148251496456786}, {{}, {a, b, d}}, {
          0.018996439704686091, 1}, {}], 
        AncestralLineage[ 
        5, {0.4292570949591068, 0.45951657742311824}, {{a, b, d}, {}}, {
          0.018996439704686091, 1}, {}], 
        AncestralLineage[ 
        6, {0.4292570949591068, 0.45951657742311824}, {{}}, {1}, {}], 
        AncestralLineage[ 
        7, {0.45951657742311824, 0.64520367984716565}, {{a, b, d}, {}}, {
          0.018996439704686091, 1}, {}], 
        AncestralLineage[ 
        8, {0.62148251496456786, 0.64520367984716565}, {{c}, {a, b, c, d}}, {
          0.018996439704686091, 1}, {}], 
        AncestralLineage[ 
        9, {0.64520367984716565, 1.9706637158007017}, {{a, b, c, d}}, {
          1}, {}], 
        AncestralLineage[ 
        10, {1.9706637158007017, 2.2897969825533644}, {{a, b, c, d}, {}}, {
          0.93719810153633465, 1}, {}], 
        AncestralLineage[ 
        11, {1.9706637158007017, 2.118015261702507}, {{}, {a, b, c, d}}, {
          0.93719810153633465, 1}, {}], 
        AncestralLineage[ 12, {2.118015261702507, 
          DirectedInfinity[ 1]}, {{}}, {1}, {}], 
        AncestralLineage[ 
        13, {2.118015261702507, 2.228204237719424}, {{}, {a, b, c, d}}, {
          0.93719810153633465, 1}, {}], 
        AncestralLineage[ 
        14, {2.228204237719424, 2.2897969825533644}, {{}}, {1}, {}], 
        AncestralLineage[ 
        15, {2.228204237719424, 2.3639104415829926}, {{}, {a, b, c, d}}, {
          0.93719810153633465, 1}, {}], 
        AncestralLineage[ 
        16, {2.2897969825533644, 2.3639104415829926}, {{a, b, c, d}, {}}, {
          0.93719810153633465, 1}, {}], 
        AncestralLineage[ 17, {2.3639104415829926, 
          DirectedInfinity[ 1]}, {{a, b, c, d}}, {1}, {}]}],
      Editable->False]], "Print",
  CellLabel->"From In[122]:="],

Cell[BoxData[
    \({2.3758569290340006`, 3, 0.25527646365325707`}\)], "Print",
  CellLabel->"From In[122]:="],

Cell[BoxData[
    InterpretationBox[\("Recombining "\[InvisibleSpace]12\[InvisibleSpace]"; \
current lineages "\[InvisibleSpace]{12, 17}\),
      SequenceForm[ "Recombining ", 12, "; current lineages ", {12, 17}],
      Editable->False]], "Print",
  CellLabel->"From In[122]:="],

Cell[BoxData[
    InterpretationBox[
      RowBox[{"\<\"G=\"\>", "\[InvisibleSpace]", 
        RowBox[{"{", 
          
          RowBox[{\(AncestralLineage[
              a, {0, 0.05710778878192141`}, {{a}}, {1}, {}]\), 
            ",", \(AncestralLineage[
              b, {0, 0.027696065882077705`}, {{b}}, {1}, {}]\), 
            ",", \(AncestralLineage[
              c, {0, 0.6214825149645679`}, {{c}}, {1}, {}]\), 
            ",", \(AncestralLineage[
              d, {0, 0.027696065882077705`}, {{d}}, {1}, {}]\), 
            ",", \(AncestralLineage[
              1, {0.027696065882077705`, 
                0.05710778878192141`}, {{b, d}}, {1}, {}]\), 
            ",", \(AncestralLineage[
              2, {0.05710778878192141`, 
                0.27049717829601805`}, {{a, b, d}}, {1}, {}]\), 
            ",", \(AncestralLineage[
              3, {0.27049717829601805`, 
                0.4292570949591068`}, {{a, b, d}, {}}, {0.01899643970468609`, 
                1}, {}]\), 
            ",", \(AncestralLineage[
              4, {0.27049717829601805`, 
                0.6214825149645679`}, {{}, {a, b, d}}, {0.01899643970468609`, 
                1}, {}]\), 
            ",", \(AncestralLineage[
              5, {0.4292570949591068`, 
                0.45951657742311824`}, {{a, b, 
                  d}, {}}, {0.01899643970468609`, 1}, {}]\), 
            ",", \(AncestralLineage[
              6, {0.4292570949591068`, 
                0.45951657742311824`}, {{}}, {1}, {}]\), 
            ",", \(AncestralLineage[
              7, {0.45951657742311824`, 
                0.6452036798471656`}, {{a, b, d}, {}}, {0.01899643970468609`, 
                1}, {}]\), 
            ",", \(AncestralLineage[
              8, {0.6214825149645679`, 
                0.6452036798471656`}, {{c}, {a, b, c, 
                  d}}, {0.01899643970468609`, 1}, {}]\), 
            ",", \(AncestralLineage[
              9, {0.6452036798471656`, 
                1.9706637158007017`}, {{a, b, c, d}}, {1}, {}]\), 
            ",", \(AncestralLineage[
              10, {1.9706637158007017`, 
                2.2897969825533644`}, {{a, b, c, 
                  d}, {}}, {0.9371981015363346`, 1}, {}]\), 
            ",", \(AncestralLineage[
              11, {1.9706637158007017`, 
                2.118015261702507`}, {{}, {a, b, c, 
                  d}}, {0.9371981015363346`, 1}, {}]\), 
            ",", \(AncestralLineage[
              12, {2.118015261702507`, 2.3758569290340006`}, {{}}, {1}, {}]\),
             ",", \(AncestralLineage[
              13, {2.118015261702507`, 
                2.228204237719424`}, {{}, {a, b, c, 
                  d}}, {0.9371981015363346`, 1}, {}]\), 
            ",", \(AncestralLineage[
              14, {2.228204237719424`, 2.2897969825533644`}, {{}}, {1}, {}]\),
             ",", \(AncestralLineage[
              15, {2.228204237719424`, 
                2.3639104415829926`}, {{}, {a, b, c, 
                  d}}, {0.9371981015363346`, 1}, {}]\), 
            ",", \(AncestralLineage[
              16, {2.2897969825533644`, 
                2.3639104415829926`}, {{a, b, c, 
                  d}, {}}, {0.9371981015363346`, 1}, {}]\), ",", 
            RowBox[{"AncestralLineage", "[", 
              RowBox[{"17", ",", 
                RowBox[{"{", 
                  RowBox[{"2.3639104415829926`", ",", 
                    InterpretationBox["\[Infinity]",
                      DirectedInfinity[ 1]]}], "}"}], ",", \({{a, b, c, d}}\),
                 ",", \({1}\), ",", \({}\)}], "]"}], ",", 
            RowBox[{"AncestralLineage", "[", 
              RowBox[{"18", ",", 
                RowBox[{"{", 
                  RowBox[{"2.3758569290340006`", ",", 
                    InterpretationBox["\[Infinity]",
                      DirectedInfinity[ 1]]}], "}"}], ",", \({{}}\), 
                ",", \({1}\), ",", \({}\)}], "]"}], ",", 
            RowBox[{"AncestralLineage", "[", 
              RowBox[{"19", ",", 
                RowBox[{"{", 
                  RowBox[{"2.3758569290340006`", ",", 
                    InterpretationBox["\[Infinity]",
                      DirectedInfinity[ 1]]}], "}"}], ",", \({{}}\), 
                ",", \({1}\), ",", \({}\)}], "]"}]}], "}"}]}],
      SequenceForm[ "G=", {
        AncestralLineage[ a, {0, 0.057107788781921409}, {{a}}, {1}, {}], 
        AncestralLineage[ b, {0, 0.027696065882077705}, {{b}}, {1}, {}], 
        AncestralLineage[ c, {0, 0.62148251496456786}, {{c}}, {1}, {}], 
        AncestralLineage[ d, {0, 0.027696065882077705}, {{d}}, {1}, {}], 
        AncestralLineage[ 
        1, {0.027696065882077705, 0.057107788781921409}, {{b, d}}, {1}, {}], 
        AncestralLineage[ 
        2, {0.057107788781921409, 0.27049717829601805}, {{a, b, d}}, {1}, {}],
         
        AncestralLineage[ 
        3, {0.27049717829601805, 0.4292570949591068}, {{a, b, d}, {}}, {
          0.018996439704686091, 1}, {}], 
        AncestralLineage[ 
        4, {0.27049717829601805, 0.62148251496456786}, {{}, {a, b, d}}, {
          0.018996439704686091, 1}, {}], 
        AncestralLineage[ 
        5, {0.4292570949591068, 0.45951657742311824}, {{a, b, d}, {}}, {
          0.018996439704686091, 1}, {}], 
        AncestralLineage[ 
        6, {0.4292570949591068, 0.45951657742311824}, {{}}, {1}, {}], 
        AncestralLineage[ 
        7, {0.45951657742311824, 0.64520367984716565}, {{a, b, d}, {}}, {
          0.018996439704686091, 1}, {}], 
        AncestralLineage[ 
        8, {0.62148251496456786, 0.64520367984716565}, {{c}, {a, b, c, d}}, {
          0.018996439704686091, 1}, {}], 
        AncestralLineage[ 
        9, {0.64520367984716565, 1.9706637158007017}, {{a, b, c, d}}, {
          1}, {}], 
        AncestralLineage[ 
        10, {1.9706637158007017, 2.2897969825533644}, {{a, b, c, d}, {}}, {
          0.93719810153633465, 1}, {}], 
        AncestralLineage[ 
        11, {1.9706637158007017, 2.118015261702507}, {{}, {a, b, c, d}}, {
          0.93719810153633465, 1}, {}], 
        AncestralLineage[ 
        12, {2.118015261702507, 2.3758569290340006}, {{}}, {1}, {}], 
        AncestralLineage[ 
        13, {2.118015261702507, 2.228204237719424}, {{}, {a, b, c, d}}, {
          0.93719810153633465, 1}, {}], 
        AncestralLineage[ 
        14, {2.228204237719424, 2.2897969825533644}, {{}}, {1}, {}], 
        AncestralLineage[ 
        15, {2.228204237719424, 2.3639104415829926}, {{}, {a, b, c, d}}, {
          0.93719810153633465, 1}, {}], 
        AncestralLineage[ 
        16, {2.2897969825533644, 2.3639104415829926}, {{a, b, c, d}, {}}, {
          0.93719810153633465, 1}, {}], 
        AncestralLineage[ 17, {2.3639104415829926, 
          DirectedInfinity[ 1]}, {{a, b, c, d}}, {1}, {}], 
        AncestralLineage[ 18, {2.3758569290340006, 
          DirectedInfinity[ 1]}, {{}}, {1}, {}], 
        AncestralLineage[ 19, {2.3758569290340006, 
          DirectedInfinity[ 1]}, {{}}, {1}, {}]}],
      Editable->False]], "Print",
  CellLabel->"From In[122]:="],

Cell[BoxData[
    \({2.458462043572085`, 2, None}\)], "Print",
  CellLabel->"From In[122]:="],

Cell[BoxData[
    InterpretationBox[\("Coalescing "\[InvisibleSpace]{17, 
          18}\[InvisibleSpace]"; current lineages "\[InvisibleSpace]{17, 18, 
          19}\),
      SequenceForm[ 
      "Coalescing ", {17, 18}, "; current lineages ", {17, 18, 19}],
      Editable->False]], "Print",
  CellLabel->"From In[122]:="],

Cell[BoxData[
    InterpretationBox[
      RowBox[{"\<\"G=\"\>", "\[InvisibleSpace]", 
        RowBox[{"{", 
          
          RowBox[{\(AncestralLineage[
              a, {0, 0.05710778878192141`}, {{a}}, {1}, {}]\), 
            ",", \(AncestralLineage[
              b, {0, 0.027696065882077705`}, {{b}}, {1}, {}]\), 
            ",", \(AncestralLineage[
              c, {0, 0.6214825149645679`}, {{c}}, {1}, {}]\), 
            ",", \(AncestralLineage[
              d, {0, 0.027696065882077705`}, {{d}}, {1}, {}]\), 
            ",", \(AncestralLineage[
              1, {0.027696065882077705`, 
                0.05710778878192141`}, {{b, d}}, {1}, {}]\), 
            ",", \(AncestralLineage[
              2, {0.05710778878192141`, 
                0.27049717829601805`}, {{a, b, d}}, {1}, {}]\), 
            ",", \(AncestralLineage[
              3, {0.27049717829601805`, 
                0.4292570949591068`}, {{a, b, d}, {}}, {0.01899643970468609`, 
                1}, {}]\), 
            ",", \(AncestralLineage[
              4, {0.27049717829601805`, 
                0.6214825149645679`}, {{}, {a, b, d}}, {0.01899643970468609`, 
                1}, {}]\), 
            ",", \(AncestralLineage[
              5, {0.4292570949591068`, 
                0.45951657742311824`}, {{a, b, 
                  d}, {}}, {0.01899643970468609`, 1}, {}]\), 
            ",", \(AncestralLineage[
              6, {0.4292570949591068`, 
                0.45951657742311824`}, {{}}, {1}, {}]\), 
            ",", \(AncestralLineage[
              7, {0.45951657742311824`, 
                0.6452036798471656`}, {{a, b, d}, {}}, {0.01899643970468609`, 
                1}, {}]\), 
            ",", \(AncestralLineage[
              8, {0.6214825149645679`, 
                0.6452036798471656`}, {{c}, {a, b, c, 
                  d}}, {0.01899643970468609`, 1}, {}]\), 
            ",", \(AncestralLineage[
              9, {0.6452036798471656`, 
                1.9706637158007017`}, {{a, b, c, d}}, {1}, {}]\), 
            ",", \(AncestralLineage[
              10, {1.9706637158007017`, 
                2.2897969825533644`}, {{a, b, c, 
                  d}, {}}, {0.9371981015363346`, 1}, {}]\), 
            ",", \(AncestralLineage[
              11, {1.9706637158007017`, 
                2.118015261702507`}, {{}, {a, b, c, 
                  d}}, {0.9371981015363346`, 1}, {}]\), 
            ",", \(AncestralLineage[
              12, {2.118015261702507`, 2.3758569290340006`}, {{}}, {1}, {}]\),
             ",", \(AncestralLineage[
              13, {2.118015261702507`, 
                2.228204237719424`}, {{}, {a, b, c, 
                  d}}, {0.9371981015363346`, 1}, {}]\), 
            ",", \(AncestralLineage[
              14, {2.228204237719424`, 2.2897969825533644`}, {{}}, {1}, {}]\),
             ",", \(AncestralLineage[
              15, {2.228204237719424`, 
                2.3639104415829926`}, {{}, {a, b, c, 
                  d}}, {0.9371981015363346`, 1}, {}]\), 
            ",", \(AncestralLineage[
              16, {2.2897969825533644`, 
                2.3639104415829926`}, {{a, b, c, 
                  d}, {}}, {0.9371981015363346`, 1}, {}]\), 
            ",", \(AncestralLineage[
              17, {2.3639104415829926`, 
                2.458462043572085`}, {{a, b, c, d}}, {1}, {}]\), 
            ",", \(AncestralLineage[
              18, {2.3758569290340006`, 2.458462043572085`}, {{}}, {1}, {}]\),
             ",", 
            RowBox[{"AncestralLineage", "[", 
              RowBox[{"19", ",", 
                RowBox[{"{", 
                  RowBox[{"2.3758569290340006`", ",", 
                    InterpretationBox["\[Infinity]",
                      DirectedInfinity[ 1]]}], "}"}], ",", \({{}}\), 
                ",", \({1}\), ",", \({}\)}], "]"}], ",", 
            RowBox[{"AncestralLineage", "[", 
              RowBox[{"20", ",", 
                RowBox[{"{", 
                  RowBox[{"2.458462043572085`", ",", 
                    InterpretationBox["\[Infinity]",
                      DirectedInfinity[ 1]]}], "}"}], ",", \({{a, b, c, d}}\),
                 ",", \({1}\), ",", \({}\)}], "]"}]}], "}"}]}],
      SequenceForm[ "G=", {
        AncestralLineage[ a, {0, 0.057107788781921409}, {{a}}, {1}, {}], 
        AncestralLineage[ b, {0, 0.027696065882077705}, {{b}}, {1}, {}], 
        AncestralLineage[ c, {0, 0.62148251496456786}, {{c}}, {1}, {}], 
        AncestralLineage[ d, {0, 0.027696065882077705}, {{d}}, {1}, {}], 
        AncestralLineage[ 
        1, {0.027696065882077705, 0.057107788781921409}, {{b, d}}, {1}, {}], 
        AncestralLineage[ 
        2, {0.057107788781921409, 0.27049717829601805}, {{a, b, d}}, {1}, {}],
         
        AncestralLineage[ 
        3, {0.27049717829601805, 0.4292570949591068}, {{a, b, d}, {}}, {
          0.018996439704686091, 1}, {}], 
        AncestralLineage[ 
        4, {0.27049717829601805, 0.62148251496456786}, {{}, {a, b, d}}, {
          0.018996439704686091, 1}, {}], 
        AncestralLineage[ 
        5, {0.4292570949591068, 0.45951657742311824}, {{a, b, d}, {}}, {
          0.018996439704686091, 1}, {}], 
        AncestralLineage[ 
        6, {0.4292570949591068, 0.45951657742311824}, {{}}, {1}, {}], 
        AncestralLineage[ 
        7, {0.45951657742311824, 0.64520367984716565}, {{a, b, d}, {}}, {
          0.018996439704686091, 1}, {}], 
        AncestralLineage[ 
        8, {0.62148251496456786, 0.64520367984716565}, {{c}, {a, b, c, d}}, {
          0.018996439704686091, 1}, {}], 
        AncestralLineage[ 
        9, {0.64520367984716565, 1.9706637158007017}, {{a, b, c, d}}, {
          1}, {}], 
        AncestralLineage[ 
        10, {1.9706637158007017, 2.2897969825533644}, {{a, b, c, d}, {}}, {
          0.93719810153633465, 1}, {}], 
        AncestralLineage[ 
        11, {1.9706637158007017, 2.118015261702507}, {{}, {a, b, c, d}}, {
          0.93719810153633465, 1}, {}], 
        AncestralLineage[ 
        12, {2.118015261702507, 2.3758569290340006}, {{}}, {1}, {}], 
        AncestralLineage[ 
        13, {2.118015261702507, 2.228204237719424}, {{}, {a, b, c, d}}, {
          0.93719810153633465, 1}, {}], 
        AncestralLineage[ 
        14, {2.228204237719424, 2.2897969825533644}, {{}}, {1}, {}], 
        AncestralLineage[ 
        15, {2.228204237719424, 2.3639104415829926}, {{}, {a, b, c, d}}, {
          0.93719810153633465, 1}, {}], 
        AncestralLineage[ 
        16, {2.2897969825533644, 2.3639104415829926}, {{a, b, c, d}, {}}, {
          0.93719810153633465, 1}, {}], 
        AncestralLineage[ 
        17, {2.3639104415829926, 2.458462043572085}, {{a, b, c, d}}, {1}, {}],
         
        AncestralLineage[ 
        18, {2.3758569290340006, 2.458462043572085}, {{}}, {1}, {}], 
        AncestralLineage[ 19, {2.3758569290340006, 
          DirectedInfinity[ 1]}, {{}}, {1}, {}], 
        AncestralLineage[ 20, {2.458462043572085, 
          DirectedInfinity[ 1]}, {{a, b, c, d}}, {1}, {}]}],
      Editable->False]], "Print",
  CellLabel->"From In[122]:="],

Cell[BoxData[
    \({2.4862026095016123`, 1, None}\)], "Print",
  CellLabel->"From In[122]:="],

Cell[BoxData[
    InterpretationBox[\("Coalescing "\[InvisibleSpace]{19, 
          20}\[InvisibleSpace]"; current lineages "\[InvisibleSpace]{19, 
          20}\),
      SequenceForm[ "Coalescing ", {19, 20}, "; current lineages ", {19, 20}],
      
      Editable->False]], "Print",
  CellLabel->"From In[122]:="],

Cell[BoxData[
    InterpretationBox[
      RowBox[{"\<\"G=\"\>", "\[InvisibleSpace]", 
        RowBox[{"{", 
          
          RowBox[{\(AncestralLineage[
              a, {0, 0.05710778878192141`}, {{a}}, {1}, {}]\), 
            ",", \(AncestralLineage[
              b, {0, 0.027696065882077705`}, {{b}}, {1}, {}]\), 
            ",", \(AncestralLineage[
              c, {0, 0.6214825149645679`}, {{c}}, {1}, {}]\), 
            ",", \(AncestralLineage[
              d, {0, 0.027696065882077705`}, {{d}}, {1}, {}]\), 
            ",", \(AncestralLineage[
              1, {0.027696065882077705`, 
                0.05710778878192141`}, {{b, d}}, {1}, {}]\), 
            ",", \(AncestralLineage[
              2, {0.05710778878192141`, 
                0.27049717829601805`}, {{a, b, d}}, {1}, {}]\), 
            ",", \(AncestralLineage[
              3, {0.27049717829601805`, 
                0.4292570949591068`}, {{a, b, d}, {}}, {0.01899643970468609`, 
                1}, {}]\), 
            ",", \(AncestralLineage[
              4, {0.27049717829601805`, 
                0.6214825149645679`}, {{}, {a, b, d}}, {0.01899643970468609`, 
                1}, {}]\), 
            ",", \(AncestralLineage[
              5, {0.4292570949591068`, 
                0.45951657742311824`}, {{a, b, 
                  d}, {}}, {0.01899643970468609`, 1}, {}]\), 
            ",", \(AncestralLineage[
              6, {0.4292570949591068`, 
                0.45951657742311824`}, {{}}, {1}, {}]\), 
            ",", \(AncestralLineage[
              7, {0.45951657742311824`, 
                0.6452036798471656`}, {{a, b, d}, {}}, {0.01899643970468609`, 
                1}, {}]\), 
            ",", \(AncestralLineage[
              8, {0.6214825149645679`, 
                0.6452036798471656`}, {{c}, {a, b, c, 
                  d}}, {0.01899643970468609`, 1}, {}]\), 
            ",", \(AncestralLineage[
              9, {0.6452036798471656`, 
                1.9706637158007017`}, {{a, b, c, d}}, {1}, {}]\), 
            ",", \(AncestralLineage[
              10, {1.9706637158007017`, 
                2.2897969825533644`}, {{a, b, c, 
                  d}, {}}, {0.9371981015363346`, 1}, {}]\), 
            ",", \(AncestralLineage[
              11, {1.9706637158007017`, 
                2.118015261702507`}, {{}, {a, b, c, 
                  d}}, {0.9371981015363346`, 1}, {}]\), 
            ",", \(AncestralLineage[
              12, {2.118015261702507`, 2.3758569290340006`}, {{}}, {1}, {}]\),
             ",", \(AncestralLineage[
              13, {2.118015261702507`, 
                2.228204237719424`}, {{}, {a, b, c, 
                  d}}, {0.9371981015363346`, 1}, {}]\), 
            ",", \(AncestralLineage[
              14, {2.228204237719424`, 2.2897969825533644`}, {{}}, {1}, {}]\),
             ",", \(AncestralLineage[
              15, {2.228204237719424`, 
                2.3639104415829926`}, {{}, {a, b, c, 
                  d}}, {0.9371981015363346`, 1}, {}]\), 
            ",", \(AncestralLineage[
              16, {2.2897969825533644`, 
                2.3639104415829926`}, {{a, b, c, 
                  d}, {}}, {0.9371981015363346`, 1}, {}]\), 
            ",", \(AncestralLineage[
              17, {2.3639104415829926`, 
                2.458462043572085`}, {{a, b, c, d}}, {1}, {}]\), 
            ",", \(AncestralLineage[
              18, {2.3758569290340006`, 2.458462043572085`}, {{}}, {1}, {}]\),
             ",", \(AncestralLineage[
              19, {2.3758569290340006`, 
                2.4862026095016123`}, {{}}, {1}, {}]\), 
            ",", \(AncestralLineage[
              20, {2.458462043572085`, 
                2.4862026095016123`}, {{a, b, c, d}}, {1}, {}]\), ",", 
            RowBox[{"AncestralLineage", "[", 
              RowBox[{"21", ",", 
                RowBox[{"{", 
                  RowBox[{"2.4862026095016123`", ",", 
                    InterpretationBox["\[Infinity]",
                      DirectedInfinity[ 1]]}], "}"}], ",", \({{a, b, c, d}}\),
                 ",", \({1}\), ",", \({}\)}], "]"}]}], "}"}]}],
      SequenceForm[ "G=", {
        AncestralLineage[ a, {0, 0.057107788781921409}, {{a}}, {1}, {}], 
        AncestralLineage[ b, {0, 0.027696065882077705}, {{b}}, {1}, {}], 
        AncestralLineage[ c, {0, 0.62148251496456786}, {{c}}, {1}, {}], 
        AncestralLineage[ d, {0, 0.027696065882077705}, {{d}}, {1}, {}], 
        AncestralLineage[ 
        1, {0.027696065882077705, 0.057107788781921409}, {{b, d}}, {1}, {}], 
        AncestralLineage[ 
        2, {0.057107788781921409, 0.27049717829601805}, {{a, b, d}}, {1}, {}],
         
        AncestralLineage[ 
        3, {0.27049717829601805, 0.4292570949591068}, {{a, b, d}, {}}, {
          0.018996439704686091, 1}, {}], 
        AncestralLineage[ 
        4, {0.27049717829601805, 0.62148251496456786}, {{}, {a, b, d}}, {
          0.018996439704686091, 1}, {}], 
        AncestralLineage[ 
        5, {0.4292570949591068, 0.45951657742311824}, {{a, b, d}, {}}, {
          0.018996439704686091, 1}, {}], 
        AncestralLineage[ 
        6, {0.4292570949591068, 0.45951657742311824}, {{}}, {1}, {}], 
        AncestralLineage[ 
        7, {0.45951657742311824, 0.64520367984716565}, {{a, b, d}, {}}, {
          0.018996439704686091, 1}, {}], 
        AncestralLineage[ 
        8, {0.62148251496456786, 0.64520367984716565}, {{c}, {a, b, c, d}}, {
          0.018996439704686091, 1}, {}], 
        AncestralLineage[ 
        9, {0.64520367984716565, 1.9706637158007017}, {{a, b, c, d}}, {
          1}, {}], 
        AncestralLineage[ 
        10, {1.9706637158007017, 2.2897969825533644}, {{a, b, c, d}, {}}, {
          0.93719810153633465, 1}, {}], 
        AncestralLineage[ 
        11, {1.9706637158007017, 2.118015261702507}, {{}, {a, b, c, d}}, {
          0.93719810153633465, 1}, {}], 
        AncestralLineage[ 
        12, {2.118015261702507, 2.3758569290340006}, {{}}, {1}, {}], 
        AncestralLineage[ 
        13, {2.118015261702507, 2.228204237719424}, {{}, {a, b, c, d}}, {
          0.93719810153633465, 1}, {}], 
        AncestralLineage[ 
        14, {2.228204237719424, 2.2897969825533644}, {{}}, {1}, {}], 
        AncestralLineage[ 
        15, {2.228204237719424, 2.3639104415829926}, {{}, {a, b, c, d}}, {
          0.93719810153633465, 1}, {}], 
        AncestralLineage[ 
        16, {2.2897969825533644, 2.3639104415829926}, {{a, b, c, d}, {}}, {
          0.93719810153633465, 1}, {}], 
        AncestralLineage[ 
        17, {2.3639104415829926, 2.458462043572085}, {{a, b, c, d}}, {1}, {}],
         
        AncestralLineage[ 
        18, {2.3758569290340006, 2.458462043572085}, {{}}, {1}, {}], 
        AncestralLineage[ 
        19, {2.3758569290340006, 2.4862026095016123}, {{}}, {1}, {}], 
        AncestralLineage[ 
        20, {2.458462043572085, 2.4862026095016123}, {{a, b, c, d}}, {1}, {}],
         
        AncestralLineage[ 21, {2.4862026095016123, 
          DirectedInfinity[ 1]}, {{a, b, c, d}}, {1}, {}]}],
      Editable->False]], "Print",
  CellLabel->"From In[122]:="],

Cell[BoxData[
    \({3.9524773177113115`, 2, 0.9888375144798349`}\)], "Print",
  CellLabel->"From In[122]:="],

Cell[BoxData[
    InterpretationBox[\("Recombining "\[InvisibleSpace]21\[InvisibleSpace]"; \
current lineages "\[InvisibleSpace]{21}\),
      SequenceForm[ "Recombining ", 21, "; current lineages ", {21}],
      Editable->False]], "Print",
  CellLabel->"From In[122]:="],

Cell[BoxData[
    InterpretationBox[
      RowBox[{"\<\"G=\"\>", "\[InvisibleSpace]", 
        RowBox[{"{", 
          
          RowBox[{\(AncestralLineage[
              a, {0, 0.05710778878192141`}, {{a}}, {1}, {}]\), 
            ",", \(AncestralLineage[
              b, {0, 0.027696065882077705`}, {{b}}, {1}, {}]\), 
            ",", \(AncestralLineage[
              c, {0, 0.6214825149645679`}, {{c}}, {1}, {}]\), 
            ",", \(AncestralLineage[
              d, {0, 0.027696065882077705`}, {{d}}, {1}, {}]\), 
            ",", \(AncestralLineage[
              1, {0.027696065882077705`, 
                0.05710778878192141`}, {{b, d}}, {1}, {}]\), 
            ",", \(AncestralLineage[
              2, {0.05710778878192141`, 
                0.27049717829601805`}, {{a, b, d}}, {1}, {}]\), 
            ",", \(AncestralLineage[
              3, {0.27049717829601805`, 
                0.4292570949591068`}, {{a, b, d}, {}}, {0.01899643970468609`, 
                1}, {}]\), 
            ",", \(AncestralLineage[
              4, {0.27049717829601805`, 
                0.6214825149645679`}, {{}, {a, b, d}}, {0.01899643970468609`, 
                1}, {}]\), 
            ",", \(AncestralLineage[
              5, {0.4292570949591068`, 
                0.45951657742311824`}, {{a, b, 
                  d}, {}}, {0.01899643970468609`, 1}, {}]\), 
            ",", \(AncestralLineage[
              6, {0.4292570949591068`, 
                0.45951657742311824`}, {{}}, {1}, {}]\), 
            ",", \(AncestralLineage[
              7, {0.45951657742311824`, 
                0.6452036798471656`}, {{a, b, d}, {}}, {0.01899643970468609`, 
                1}, {}]\), 
            ",", \(AncestralLineage[
              8, {0.6214825149645679`, 
                0.6452036798471656`}, {{c}, {a, b, c, 
                  d}}, {0.01899643970468609`, 1}, {}]\), 
            ",", \(AncestralLineage[
              9, {0.6452036798471656`, 
                1.9706637158007017`}, {{a, b, c, d}}, {1}, {}]\), 
            ",", \(AncestralLineage[
              10, {1.9706637158007017`, 
                2.2897969825533644`}, {{a, b, c, 
                  d}, {}}, {0.9371981015363346`, 1}, {}]\), 
            ",", \(AncestralLineage[
              11, {1.9706637158007017`, 
                2.118015261702507`}, {{}, {a, b, c, 
                  d}}, {0.9371981015363346`, 1}, {}]\), 
            ",", \(AncestralLineage[
              12, {2.118015261702507`, 2.3758569290340006`}, {{}}, {1}, {}]\),
             ",", \(AncestralLineage[
              13, {2.118015261702507`, 
                2.228204237719424`}, {{}, {a, b, c, 
                  d}}, {0.9371981015363346`, 1}, {}]\), 
            ",", \(AncestralLineage[
              14, {2.228204237719424`, 2.2897969825533644`}, {{}}, {1}, {}]\),
             ",", \(AncestralLineage[
              15, {2.228204237719424`, 
                2.3639104415829926`}, {{}, {a, b, c, 
                  d}}, {0.9371981015363346`, 1}, {}]\), 
            ",", \(AncestralLineage[
              16, {2.2897969825533644`, 
                2.3639104415829926`}, {{a, b, c, 
                  d}, {}}, {0.9371981015363346`, 1}, {}]\), 
            ",", \(AncestralLineage[
              17, {2.3639104415829926`, 
                2.458462043572085`}, {{a, b, c, d}}, {1}, {}]\), 
            ",", \(AncestralLineage[
              18, {2.3758569290340006`, 2.458462043572085`}, {{}}, {1}, {}]\),
             ",", \(AncestralLineage[
              19, {2.3758569290340006`, 
                2.4862026095016123`}, {{}}, {1}, {}]\), 
            ",", \(AncestralLineage[
              20, {2.458462043572085`, 
                2.4862026095016123`}, {{a, b, c, d}}, {1}, {}]\), 
            ",", \(AncestralLineage[
              21, {2.4862026095016123`, 
                3.9524773177113115`}, {{a, b, c, d}}, {1}, {}]\), ",", 
            RowBox[{"AncestralLineage", "[", 
              RowBox[{"22", ",", 
                RowBox[{"{", 
                  RowBox[{"3.9524773177113115`", ",", 
                    InterpretationBox["\[Infinity]",
                      DirectedInfinity[ 1]]}], "}"}], 
                ",", \({{a, b, c, d}, {}}\), 
                ",", \({0.9888375144798349`, 1}\), ",", \({}\)}], "]"}], ",", 
            
            RowBox[{"AncestralLineage", "[", 
              RowBox[{"23", ",", 
                RowBox[{"{", 
                  RowBox[{"3.9524773177113115`", ",", 
                    InterpretationBox["\[Infinity]",
                      DirectedInfinity[ 1]]}], "}"}], 
                ",", \({{}, {a, b, c, d}}\), 
                ",", \({0.9888375144798349`, 1}\), ",", \({}\)}], "]"}]}], 
          "}"}]}],
      SequenceForm[ "G=", {
        AncestralLineage[ a, {0, 0.057107788781921409}, {{a}}, {1}, {}], 
        AncestralLineage[ b, {0, 0.027696065882077705}, {{b}}, {1}, {}], 
        AncestralLineage[ c, {0, 0.62148251496456786}, {{c}}, {1}, {}], 
        AncestralLineage[ d, {0, 0.027696065882077705}, {{d}}, {1}, {}], 
        AncestralLineage[ 
        1, {0.027696065882077705, 0.057107788781921409}, {{b, d}}, {1}, {}], 
        AncestralLineage[ 
        2, {0.057107788781921409, 0.27049717829601805}, {{a, b, d}}, {1}, {}],
         
        AncestralLineage[ 
        3, {0.27049717829601805, 0.4292570949591068}, {{a, b, d}, {}}, {
          0.018996439704686091, 1}, {}], 
        AncestralLineage[ 
        4, {0.27049717829601805, 0.62148251496456786}, {{}, {a, b, d}}, {
          0.018996439704686091, 1}, {}], 
        AncestralLineage[ 
        5, {0.4292570949591068, 0.45951657742311824}, {{a, b, d}, {}}, {
          0.018996439704686091, 1}, {}], 
        AncestralLineage[ 
        6, {0.4292570949591068, 0.45951657742311824}, {{}}, {1}, {}], 
        AncestralLineage[ 
        7, {0.45951657742311824, 0.64520367984716565}, {{a, b, d}, {}}, {
          0.018996439704686091, 1}, {}], 
        AncestralLineage[ 
        8, {0.62148251496456786, 0.64520367984716565}, {{c}, {a, b, c, d}}, {
          0.018996439704686091, 1}, {}], 
        AncestralLineage[ 
        9, {0.64520367984716565, 1.9706637158007017}, {{a, b, c, d}}, {
          1}, {}], 
        AncestralLineage[ 
        10, {1.9706637158007017, 2.2897969825533644}, {{a, b, c, d}, {}}, {
          0.93719810153633465, 1}, {}], 
        AncestralLineage[ 
        11, {1.9706637158007017, 2.118015261702507}, {{}, {a, b, c, d}}, {
          0.93719810153633465, 1}, {}], 
        AncestralLineage[ 
        12, {2.118015261702507, 2.3758569290340006}, {{}}, {1}, {}], 
        AncestralLineage[ 
        13, {2.118015261702507, 2.228204237719424}, {{}, {a, b, c, d}}, {
          0.93719810153633465, 1}, {}], 
        AncestralLineage[ 
        14, {2.228204237719424, 2.2897969825533644}, {{}}, {1}, {}], 
        AncestralLineage[ 
        15, {2.228204237719424, 2.3639104415829926}, {{}, {a, b, c, d}}, {
          0.93719810153633465, 1}, {}], 
        AncestralLineage[ 
        16, {2.2897969825533644, 2.3639104415829926}, {{a, b, c, d}, {}}, {
          0.93719810153633465, 1}, {}], 
        AncestralLineage[ 
        17, {2.3639104415829926, 2.458462043572085}, {{a, b, c, d}}, {1}, {}],
         
        AncestralLineage[ 
        18, {2.3758569290340006, 2.458462043572085}, {{}}, {1}, {}], 
        AncestralLineage[ 
        19, {2.3758569290340006, 2.4862026095016123}, {{}}, {1}, {}], 
        AncestralLineage[ 
        20, {2.458462043572085, 2.4862026095016123}, {{a, b, c, d}}, {1}, {}],
         
        AncestralLineage[ 
        21, {2.4862026095016123, 3.9524773177113115}, {{a, b, c, d}}, {
          1}, {}], 
        AncestralLineage[ 22, {3.9524773177113115, 
          DirectedInfinity[ 1]}, {{a, b, c, d}, {}}, {0.98883751447983492, 
          1}, {}], 
        AncestralLineage[ 23, {3.9524773177113115, 
          DirectedInfinity[ 1]}, {{}, {a, b, c, d}}, {0.98883751447983492, 
          1}, {}]}],
      Editable->False]], "Print",
  CellLabel->"From In[122]:="],

Cell[BoxData[
    \({4.0138506590066365`, 1, None}\)], "Print",
  CellLabel->"From In[122]:="],

Cell[BoxData[
    InterpretationBox[\("Coalescing "\[InvisibleSpace]{22, 
          23}\[InvisibleSpace]"; current lineages "\[InvisibleSpace]{22, 
          23}\),
      SequenceForm[ "Coalescing ", {22, 23}, "; current lineages ", {22, 23}],
      
      Editable->False]], "Print",
  CellLabel->"From In[122]:="],

Cell[BoxData[
    InterpretationBox[
      RowBox[{"\<\"G=\"\>", "\[InvisibleSpace]", 
        RowBox[{"{", 
          
          RowBox[{\(AncestralLineage[
              a, {0, 0.05710778878192141`}, {{a}}, {1}, {}]\), 
            ",", \(AncestralLineage[
              b, {0, 0.027696065882077705`}, {{b}}, {1}, {}]\), 
            ",", \(AncestralLineage[
              c, {0, 0.6214825149645679`}, {{c}}, {1}, {}]\), 
            ",", \(AncestralLineage[
              d, {0, 0.027696065882077705`}, {{d}}, {1}, {}]\), 
            ",", \(AncestralLineage[
              1, {0.027696065882077705`, 
                0.05710778878192141`}, {{b, d}}, {1}, {}]\), 
            ",", \(AncestralLineage[
              2, {0.05710778878192141`, 
                0.27049717829601805`}, {{a, b, d}}, {1}, {}]\), 
            ",", \(AncestralLineage[
              3, {0.27049717829601805`, 
                0.4292570949591068`}, {{a, b, d}, {}}, {0.01899643970468609`, 
                1}, {}]\), 
            ",", \(AncestralLineage[
              4, {0.27049717829601805`, 
                0.6214825149645679`}, {{}, {a, b, d}}, {0.01899643970468609`, 
                1}, {}]\), 
            ",", \(AncestralLineage[
              5, {0.4292570949591068`, 
                0.45951657742311824`}, {{a, b, 
                  d}, {}}, {0.01899643970468609`, 1}, {}]\), 
            ",", \(AncestralLineage[
              6, {0.4292570949591068`, 
                0.45951657742311824`}, {{}}, {1}, {}]\), 
            ",", \(AncestralLineage[
              7, {0.45951657742311824`, 
                0.6452036798471656`}, {{a, b, d}, {}}, {0.01899643970468609`, 
                1}, {}]\), 
            ",", \(AncestralLineage[
              8, {0.6214825149645679`, 
                0.6452036798471656`}, {{c}, {a, b, c, 
                  d}}, {0.01899643970468609`, 1}, {}]\), 
            ",", \(AncestralLineage[
              9, {0.6452036798471656`, 
                1.9706637158007017`}, {{a, b, c, d}}, {1}, {}]\), 
            ",", \(AncestralLineage[
              10, {1.9706637158007017`, 
                2.2897969825533644`}, {{a, b, c, 
                  d}, {}}, {0.9371981015363346`, 1}, {}]\), 
            ",", \(AncestralLineage[
              11, {1.9706637158007017`, 
                2.118015261702507`}, {{}, {a, b, c, 
                  d}}, {0.9371981015363346`, 1}, {}]\), 
            ",", \(AncestralLineage[
              12, {2.118015261702507`, 2.3758569290340006`}, {{}}, {1}, {}]\),
             ",", \(AncestralLineage[
              13, {2.118015261702507`, 
                2.228204237719424`}, {{}, {a, b, c, 
                  d}}, {0.9371981015363346`, 1}, {}]\), 
            ",", \(AncestralLineage[
              14, {2.228204237719424`, 2.2897969825533644`}, {{}}, {1}, {}]\),
             ",", \(AncestralLineage[
              15, {2.228204237719424`, 
                2.3639104415829926`}, {{}, {a, b, c, 
                  d}}, {0.9371981015363346`, 1}, {}]\), 
            ",", \(AncestralLineage[
              16, {2.2897969825533644`, 
                2.3639104415829926`}, {{a, b, c, 
                  d}, {}}, {0.9371981015363346`, 1}, {}]\), 
            ",", \(AncestralLineage[
              17, {2.3639104415829926`, 
                2.458462043572085`}, {{a, b, c, d}}, {1}, {}]\), 
            ",", \(AncestralLineage[
              18, {2.3758569290340006`, 2.458462043572085`}, {{}}, {1}, {}]\),
             ",", \(AncestralLineage[
              19, {2.3758569290340006`, 
                2.4862026095016123`}, {{}}, {1}, {}]\), 
            ",", \(AncestralLineage[
              20, {2.458462043572085`, 
                2.4862026095016123`}, {{a, b, c, d}}, {1}, {}]\), 
            ",", \(AncestralLineage[
              21, {2.4862026095016123`, 
                3.9524773177113115`}, {{a, b, c, d}}, {1}, {}]\), 
            ",", \(AncestralLineage[
              22, {3.9524773177113115`, 
                4.0138506590066365`}, {{a, b, c, 
                  d}, {}}, {0.9888375144798349`, 1}, {}]\), 
            ",", \(AncestralLineage[
              23, {3.9524773177113115`, 
                4.0138506590066365`}, {{}, {a, b, c, 
                  d}}, {0.9888375144798349`, 1}, {}]\), ",", 
            RowBox[{"AncestralLineage", "[", 
              RowBox[{"24", ",", 
                RowBox[{"{", 
                  RowBox[{"4.0138506590066365`", ",", 
                    InterpretationBox["\[Infinity]",
                      DirectedInfinity[ 1]]}], "}"}], ",", \({{a, b, c, d}}\),
                 ",", \({1}\), ",", \({}\)}], "]"}]}], "}"}]}],
      SequenceForm[ "G=", {
        AncestralLineage[ a, {0, 0.057107788781921409}, {{a}}, {1}, {}], 
        AncestralLineage[ b, {0, 0.027696065882077705}, {{b}}, {1}, {}], 
        AncestralLineage[ c, {0, 0.62148251496456786}, {{c}}, {1}, {}], 
        AncestralLineage[ d, {0, 0.027696065882077705}, {{d}}, {1}, {}], 
        AncestralLineage[ 
        1, {0.027696065882077705, 0.057107788781921409}, {{b, d}}, {1}, {}], 
        AncestralLineage[ 
        2, {0.057107788781921409, 0.27049717829601805}, {{a, b, d}}, {1}, {}],
         
        AncestralLineage[ 
        3, {0.27049717829601805, 0.4292570949591068}, {{a, b, d}, {}}, {
          0.018996439704686091, 1}, {}], 
        AncestralLineage[ 
        4, {0.27049717829601805, 0.62148251496456786}, {{}, {a, b, d}}, {
          0.018996439704686091, 1}, {}], 
        AncestralLineage[ 
        5, {0.4292570949591068, 0.45951657742311824}, {{a, b, d}, {}}, {
          0.018996439704686091, 1}, {}], 
        AncestralLineage[ 
        6, {0.4292570949591068, 0.45951657742311824}, {{}}, {1}, {}], 
        AncestralLineage[ 
        7, {0.45951657742311824, 0.64520367984716565}, {{a, b, d}, {}}, {
          0.018996439704686091, 1}, {}], 
        AncestralLineage[ 
        8, {0.62148251496456786, 0.64520367984716565}, {{c}, {a, b, c, d}}, {
          0.018996439704686091, 1}, {}], 
        AncestralLineage[ 
        9, {0.64520367984716565, 1.9706637158007017}, {{a, b, c, d}}, {
          1}, {}], 
        AncestralLineage[ 
        10, {1.9706637158007017, 2.2897969825533644}, {{a, b, c, d}, {}}, {
          0.93719810153633465, 1}, {}], 
        AncestralLineage[ 
        11, {1.9706637158007017, 2.118015261702507}, {{}, {a, b, c, d}}, {
          0.93719810153633465, 1}, {}], 
        AncestralLineage[ 
        12, {2.118015261702507, 2.3758569290340006}, {{}}, {1}, {}], 
        AncestralLineage[ 
        13, {2.118015261702507, 2.228204237719424}, {{}, {a, b, c, d}}, {
          0.93719810153633465, 1}, {}], 
        AncestralLineage[ 
        14, {2.228204237719424, 2.2897969825533644}, {{}}, {1}, {}], 
        AncestralLineage[ 
        15, {2.228204237719424, 2.3639104415829926}, {{}, {a, b, c, d}}, {
          0.93719810153633465, 1}, {}], 
        AncestralLineage[ 
        16, {2.2897969825533644, 2.3639104415829926}, {{a, b, c, d}, {}}, {
          0.93719810153633465, 1}, {}], 
        AncestralLineage[ 
        17, {2.3639104415829926, 2.458462043572085}, {{a, b, c, d}}, {1}, {}],
         
        AncestralLineage[ 
        18, {2.3758569290340006, 2.458462043572085}, {{}}, {1}, {}], 
        AncestralLineage[ 
        19, {2.3758569290340006, 2.4862026095016123}, {{}}, {1}, {}], 
        AncestralLineage[ 
        20, {2.458462043572085, 2.4862026095016123}, {{a, b, c, d}}, {1}, {}],
         
        AncestralLineage[ 
        21, {2.4862026095016123, 3.9524773177113115}, {{a, b, c, d}}, {
          1}, {}], 
        AncestralLineage[ 
        22, {3.9524773177113115, 4.0138506590066365}, {{a, b, c, d}, {}}, {
          0.98883751447983492, 1}, {}], 
        AncestralLineage[ 
        23, {3.9524773177113115, 4.0138506590066365}, {{}, {a, b, c, d}}, {
          0.98883751447983492, 1}, {}], 
        AncestralLineage[ 24, {4.0138506590066365, 
          DirectedInfinity[ 1]}, {{a, b, c, d}}, {1}, {}]}],
      Editable->False]], "Print",
  CellLabel->"From In[122]:="],

Cell[BoxData[
    \({5.754090480075275`, 2, 0.18912143960102942`}\)], "Print",
  CellLabel->"From In[122]:="],

Cell[BoxData[
    InterpretationBox[\("Recombining "\[InvisibleSpace]24\[InvisibleSpace]"; \
current lineages "\[InvisibleSpace]{24}\),
      SequenceForm[ "Recombining ", 24, "; current lineages ", {24}],
      Editable->False]], "Print",
  CellLabel->"From In[122]:="],

Cell[BoxData[
    InterpretationBox[
      RowBox[{"\<\"G=\"\>", "\[InvisibleSpace]", 
        RowBox[{"{", 
          
          RowBox[{\(AncestralLineage[
              a, {0, 0.05710778878192141`}, {{a}}, {1}, {}]\), 
            ",", \(AncestralLineage[
              b, {0, 0.027696065882077705`}, {{b}}, {1}, {}]\), 
            ",", \(AncestralLineage[
              c, {0, 0.6214825149645679`}, {{c}}, {1}, {}]\), 
            ",", \(AncestralLineage[
              d, {0, 0.027696065882077705`}, {{d}}, {1}, {}]\), 
            ",", \(AncestralLineage[
              1, {0.027696065882077705`, 
                0.05710778878192141`}, {{b, d}}, {1}, {}]\), 
            ",", \(AncestralLineage[
              2, {0.05710778878192141`, 
                0.27049717829601805`}, {{a, b, d}}, {1}, {}]\), 
            ",", \(AncestralLineage[
              3, {0.27049717829601805`, 
                0.4292570949591068`}, {{a, b, d}, {}}, {0.01899643970468609`, 
                1}, {}]\), 
            ",", \(AncestralLineage[
              4, {0.27049717829601805`, 
                0.6214825149645679`}, {{}, {a, b, d}}, {0.01899643970468609`, 
                1}, {}]\), 
            ",", \(AncestralLineage[
              5, {0.4292570949591068`, 
                0.45951657742311824`}, {{a, b, 
                  d}, {}}, {0.01899643970468609`, 1}, {}]\), 
            ",", \(AncestralLineage[
              6, {0.4292570949591068`, 
                0.45951657742311824`}, {{}}, {1}, {}]\), 
            ",", \(AncestralLineage[
              7, {0.45951657742311824`, 
                0.6452036798471656`}, {{a, b, d}, {}}, {0.01899643970468609`, 
                1}, {}]\), 
            ",", \(AncestralLineage[
              8, {0.6214825149645679`, 
                0.6452036798471656`}, {{c}, {a, b, c, 
                  d}}, {0.01899643970468609`, 1}, {}]\), 
            ",", \(AncestralLineage[
              9, {0.6452036798471656`, 
                1.9706637158007017`}, {{a, b, c, d}}, {1}, {}]\), 
            ",", \(AncestralLineage[
              10, {1.9706637158007017`, 
                2.2897969825533644`}, {{a, b, c, 
                  d}, {}}, {0.9371981015363346`, 1}, {}]\), 
            ",", \(AncestralLineage[
              11, {1.9706637158007017`, 
                2.118015261702507`}, {{}, {a, b, c, 
                  d}}, {0.9371981015363346`, 1}, {}]\), 
            ",", \(AncestralLineage[
              12, {2.118015261702507`, 2.3758569290340006`}, {{}}, {1}, {}]\),
             ",", \(AncestralLineage[
              13, {2.118015261702507`, 
                2.228204237719424`}, {{}, {a, b, c, 
                  d}}, {0.9371981015363346`, 1}, {}]\), 
            ",", \(AncestralLineage[
              14, {2.228204237719424`, 2.2897969825533644`}, {{}}, {1}, {}]\),
             ",", \(AncestralLineage[
              15, {2.228204237719424`, 
                2.3639104415829926`}, {{}, {a, b, c, 
                  d}}, {0.9371981015363346`, 1}, {}]\), 
            ",", \(AncestralLineage[
              16, {2.2897969825533644`, 
                2.3639104415829926`}, {{a, b, c, 
                  d}, {}}, {0.9371981015363346`, 1}, {}]\), 
            ",", \(AncestralLineage[
              17, {2.3639104415829926`, 
                2.458462043572085`}, {{a, b, c, d}}, {1}, {}]\), 
            ",", \(AncestralLineage[
              18, {2.3758569290340006`, 2.458462043572085`}, {{}}, {1}, {}]\),
             ",", \(AncestralLineage[
              19, {2.3758569290340006`, 
                2.4862026095016123`}, {{}}, {1}, {}]\), 
            ",", \(AncestralLineage[
              20, {2.458462043572085`, 
                2.4862026095016123`}, {{a, b, c, d}}, {1}, {}]\), 
            ",", \(AncestralLineage[
              21, {2.4862026095016123`, 
                3.9524773177113115`}, {{a, b, c, d}}, {1}, {}]\), 
            ",", \(AncestralLineage[
              22, {3.9524773177113115`, 
                4.0138506590066365`}, {{a, b, c, 
                  d}, {}}, {0.9888375144798349`, 1}, {}]\), 
            ",", \(AncestralLineage[
              23, {3.9524773177113115`, 
                4.0138506590066365`}, {{}, {a, b, c, 
                  d}}, {0.9888375144798349`, 1}, {}]\), 
            ",", \(AncestralLineage[
              24, {4.0138506590066365`, 
                5.754090480075275`}, {{a, b, c, d}}, {1}, {}]\), ",", 
            RowBox[{"AncestralLineage", "[", 
              RowBox[{"25", ",", 
                RowBox[{"{", 
                  RowBox[{"5.754090480075275`", ",", 
                    InterpretationBox["\[Infinity]",
                      DirectedInfinity[ 1]]}], "}"}], 
                ",", \({{a, b, c, d}, {}}\), 
                ",", \({0.18912143960102942`, 1}\), ",", \({}\)}], "]"}], ",",
             
            RowBox[{"AncestralLineage", "[", 
              RowBox[{"26", ",", 
                RowBox[{"{", 
                  RowBox[{"5.754090480075275`", ",", 
                    InterpretationBox["\[Infinity]",
                      DirectedInfinity[ 1]]}], "}"}], 
                ",", \({{}, {a, b, c, d}}\), 
                ",", \({0.18912143960102942`, 1}\), ",", \({}\)}], "]"}]}], 
          "}"}]}],
      SequenceForm[ "G=", {
        AncestralLineage[ a, {0, 0.057107788781921409}, {{a}}, {1}, {}], 
        AncestralLineage[ b, {0, 0.027696065882077705}, {{b}}, {1}, {}], 
        AncestralLineage[ c, {0, 0.62148251496456786}, {{c}}, {1}, {}], 
        AncestralLineage[ d, {0, 0.027696065882077705}, {{d}}, {1}, {}], 
        AncestralLineage[ 
        1, {0.027696065882077705, 0.057107788781921409}, {{b, d}}, {1}, {}], 
        AncestralLineage[ 
        2, {0.057107788781921409, 0.27049717829601805}, {{a, b, d}}, {1}, {}],
         
        AncestralLineage[ 
        3, {0.27049717829601805, 0.4292570949591068}, {{a, b, d}, {}}, {
          0.018996439704686091, 1}, {}], 
        AncestralLineage[ 
        4, {0.27049717829601805, 0.62148251496456786}, {{}, {a, b, d}}, {
          0.018996439704686091, 1}, {}], 
        AncestralLineage[ 
        5, {0.4292570949591068, 0.45951657742311824}, {{a, b, d}, {}}, {
          0.018996439704686091, 1}, {}], 
        AncestralLineage[ 
        6, {0.4292570949591068, 0.45951657742311824}, {{}}, {1}, {}], 
        AncestralLineage[ 
        7, {0.45951657742311824, 0.64520367984716565}, {{a, b, d}, {}}, {
          0.018996439704686091, 1}, {}], 
        AncestralLineage[ 
        8, {0.62148251496456786, 0.64520367984716565}, {{c}, {a, b, c, d}}, {
          0.018996439704686091, 1}, {}], 
        AncestralLineage[ 
        9, {0.64520367984716565, 1.9706637158007017}, {{a, b, c, d}}, {
          1}, {}], 
        AncestralLineage[ 
        10, {1.9706637158007017, 2.2897969825533644}, {{a, b, c, d}, {}}, {
          0.93719810153633465, 1}, {}], 
        AncestralLineage[ 
        11, {1.9706637158007017, 2.118015261702507}, {{}, {a, b, c, d}}, {
          0.93719810153633465, 1}, {}], 
        AncestralLineage[ 
        12, {2.118015261702507, 2.3758569290340006}, {{}}, {1}, {}], 
        AncestralLineage[ 
        13, {2.118015261702507, 2.228204237719424}, {{}, {a, b, c, d}}, {
          0.93719810153633465, 1}, {}], 
        AncestralLineage[ 
        14, {2.228204237719424, 2.2897969825533644}, {{}}, {1}, {}], 
        AncestralLineage[ 
        15, {2.228204237719424, 2.3639104415829926}, {{}, {a, b, c, d}}, {
          0.93719810153633465, 1}, {}], 
        AncestralLineage[ 
        16, {2.2897969825533644, 2.3639104415829926}, {{a, b, c, d}, {}}, {
          0.93719810153633465, 1}, {}], 
        AncestralLineage[ 
        17, {2.3639104415829926, 2.458462043572085}, {{a, b, c, d}}, {1}, {}],
         
        AncestralLineage[ 
        18, {2.3758569290340006, 2.458462043572085}, {{}}, {1}, {}], 
        AncestralLineage[ 
        19, {2.3758569290340006, 2.4862026095016123}, {{}}, {1}, {}], 
        AncestralLineage[ 
        20, {2.458462043572085, 2.4862026095016123}, {{a, b, c, d}}, {1}, {}],
         
        AncestralLineage[ 
        21, {2.4862026095016123, 3.9524773177113115}, {{a, b, c, d}}, {
          1}, {}], 
        AncestralLineage[ 
        22, {3.9524773177113115, 4.0138506590066365}, {{a, b, c, d}, {}}, {
          0.98883751447983492, 1}, {}], 
        AncestralLineage[ 
        23, {3.9524773177113115, 4.0138506590066365}, {{}, {a, b, c, d}}, {
          0.98883751447983492, 1}, {}], 
        AncestralLineage[ 
        24, {4.0138506590066365, 5.7540904800752752}, {{a, b, c, d}}, {
          1}, {}], 
        AncestralLineage[ 25, {5.7540904800752752, 
          DirectedInfinity[ 1]}, {{a, b, c, d}, {}}, {0.18912143960102942, 
          1}, {}], 
        AncestralLineage[ 26, {5.7540904800752752, 
          DirectedInfinity[ 1]}, {{}, {a, b, c, d}}, {0.18912143960102942, 
          1}, {}]}],
      Editable->False]], "Print",
  CellLabel->"From In[122]:="],

Cell[BoxData[
    \({5.835659306754844`, 1, None}\)], "Print",
  CellLabel->"From In[122]:="],

Cell[BoxData[
    InterpretationBox[\("Coalescing "\[InvisibleSpace]{25, 
          26}\[InvisibleSpace]"; current lineages "\[InvisibleSpace]{25, 
          26}\),
      SequenceForm[ "Coalescing ", {25, 26}, "; current lineages ", {25, 26}],
      
      Editable->False]], "Print",
  CellLabel->"From In[122]:="],

Cell[BoxData[
    InterpretationBox[
      RowBox[{"\<\"G=\"\>", "\[InvisibleSpace]", 
        RowBox[{"{", 
          
          RowBox[{\(AncestralLineage[
              a, {0, 0.05710778878192141`}, {{a}}, {1}, {}]\), 
            ",", \(AncestralLineage[
              b, {0, 0.027696065882077705`}, {{b}}, {1}, {}]\), 
            ",", \(AncestralLineage[
              c, {0, 0.6214825149645679`}, {{c}}, {1}, {}]\), 
            ",", \(AncestralLineage[
              d, {0, 0.027696065882077705`}, {{d}}, {1}, {}]\), 
            ",", \(AncestralLineage[
              1, {0.027696065882077705`, 
                0.05710778878192141`}, {{b, d}}, {1}, {}]\), 
            ",", \(AncestralLineage[
              2, {0.05710778878192141`, 
                0.27049717829601805`}, {{a, b, d}}, {1}, {}]\), 
            ",", \(AncestralLineage[
              3, {0.27049717829601805`, 
                0.4292570949591068`}, {{a, b, d}, {}}, {0.01899643970468609`, 
                1}, {}]\), 
            ",", \(AncestralLineage[
              4, {0.27049717829601805`, 
                0.6214825149645679`}, {{}, {a, b, d}}, {0.01899643970468609`, 
                1}, {}]\), 
            ",", \(AncestralLineage[
              5, {0.4292570949591068`, 
                0.45951657742311824`}, {{a, b, 
                  d}, {}}, {0.01899643970468609`, 1}, {}]\), 
            ",", \(AncestralLineage[
              6, {0.4292570949591068`, 
                0.45951657742311824`}, {{}}, {1}, {}]\), 
            ",", \(AncestralLineage[
              7, {0.45951657742311824`, 
                0.6452036798471656`}, {{a, b, d}, {}}, {0.01899643970468609`, 
                1}, {}]\), 
            ",", \(AncestralLineage[
              8, {0.6214825149645679`, 
                0.6452036798471656`}, {{c}, {a, b, c, 
                  d}}, {0.01899643970468609`, 1}, {}]\), 
            ",", \(AncestralLineage[
              9, {0.6452036798471656`, 
                1.9706637158007017`}, {{a, b, c, d}}, {1}, {}]\), 
            ",", \(AncestralLineage[
              10, {1.9706637158007017`, 
                2.2897969825533644`}, {{a, b, c, 
                  d}, {}}, {0.9371981015363346`, 1}, {}]\), 
            ",", \(AncestralLineage[
              11, {1.9706637158007017`, 
                2.118015261702507`}, {{}, {a, b, c, 
                  d}}, {0.9371981015363346`, 1}, {}]\), 
            ",", \(AncestralLineage[
              12, {2.118015261702507`, 2.3758569290340006`}, {{}}, {1}, {}]\),
             ",", \(AncestralLineage[
              13, {2.118015261702507`, 
                2.228204237719424`}, {{}, {a, b, c, 
                  d}}, {0.9371981015363346`, 1}, {}]\), 
            ",", \(AncestralLineage[
              14, {2.228204237719424`, 2.2897969825533644`}, {{}}, {1}, {}]\),
             ",", \(AncestralLineage[
              15, {2.228204237719424`, 
                2.3639104415829926`}, {{}, {a, b, c, 
                  d}}, {0.9371981015363346`, 1}, {}]\), 
            ",", \(AncestralLineage[
              16, {2.2897969825533644`, 
                2.3639104415829926`}, {{a, b, c, 
                  d}, {}}, {0.9371981015363346`, 1}, {}]\), 
            ",", \(AncestralLineage[
              17, {2.3639104415829926`, 
                2.458462043572085`}, {{a, b, c, d}}, {1}, {}]\), 
            ",", \(AncestralLineage[
              18, {2.3758569290340006`, 2.458462043572085`}, {{}}, {1}, {}]\),
             ",", \(AncestralLineage[
              19, {2.3758569290340006`, 
                2.4862026095016123`}, {{}}, {1}, {}]\), 
            ",", \(AncestralLineage[
              20, {2.458462043572085`, 
                2.4862026095016123`}, {{a, b, c, d}}, {1}, {}]\), 
            ",", \(AncestralLineage[
              21, {2.4862026095016123`, 
                3.9524773177113115`}, {{a, b, c, d}}, {1}, {}]\), 
            ",", \(AncestralLineage[
              22, {3.9524773177113115`, 
                4.0138506590066365`}, {{a, b, c, 
                  d}, {}}, {0.9888375144798349`, 1}, {}]\), 
            ",", \(AncestralLineage[
              23, {3.9524773177113115`, 
                4.0138506590066365`}, {{}, {a, b, c, 
                  d}}, {0.9888375144798349`, 1}, {}]\), 
            ",", \(AncestralLineage[
              24, {4.0138506590066365`, 
                5.754090480075275`}, {{a, b, c, d}}, {1}, {}]\), 
            ",", \(AncestralLineage[
              25, {5.754090480075275`, 
                5.835659306754844`}, {{a, b, c, 
                  d}, {}}, {0.18912143960102942`, 1}, {}]\), 
            ",", \(AncestralLineage[
              26, {5.754090480075275`, 
                5.835659306754844`}, {{}, {a, b, c, 
                  d}}, {0.18912143960102942`, 1}, {}]\), ",", 
            RowBox[{"AncestralLineage", "[", 
              RowBox[{"27", ",", 
                RowBox[{"{", 
                  RowBox[{"5.835659306754844`", ",", 
                    InterpretationBox["\[Infinity]",
                      DirectedInfinity[ 1]]}], "}"}], ",", \({{a, b, c, d}}\),
                 ",", \({1}\), ",", \({}\)}], "]"}]}], "}"}]}],
      SequenceForm[ "G=", {
        AncestralLineage[ a, {0, 0.057107788781921409}, {{a}}, {1}, {}], 
        AncestralLineage[ b, {0, 0.027696065882077705}, {{b}}, {1}, {}], 
        AncestralLineage[ c, {0, 0.62148251496456786}, {{c}}, {1}, {}], 
        AncestralLineage[ d, {0, 0.027696065882077705}, {{d}}, {1}, {}], 
        AncestralLineage[ 
        1, {0.027696065882077705, 0.057107788781921409}, {{b, d}}, {1}, {}], 
        AncestralLineage[ 
        2, {0.057107788781921409, 0.27049717829601805}, {{a, b, d}}, {1}, {}],
         
        AncestralLineage[ 
        3, {0.27049717829601805, 0.4292570949591068}, {{a, b, d}, {}}, {
          0.018996439704686091, 1}, {}], 
        AncestralLineage[ 
        4, {0.27049717829601805, 0.62148251496456786}, {{}, {a, b, d}}, {
          0.018996439704686091, 1}, {}], 
        AncestralLineage[ 
        5, {0.4292570949591068, 0.45951657742311824}, {{a, b, d}, {}}, {
          0.018996439704686091, 1}, {}], 
        AncestralLineage[ 
        6, {0.4292570949591068, 0.45951657742311824}, {{}}, {1}, {}], 
        AncestralLineage[ 
        7, {0.45951657742311824, 0.64520367984716565}, {{a, b, d}, {}}, {
          0.018996439704686091, 1}, {}], 
        AncestralLineage[ 
        8, {0.62148251496456786, 0.64520367984716565}, {{c}, {a, b, c, d}}, {
          0.018996439704686091, 1}, {}], 
        AncestralLineage[ 
        9, {0.64520367984716565, 1.9706637158007017}, {{a, b, c, d}}, {
          1}, {}], 
        AncestralLineage[ 
        10, {1.9706637158007017, 2.2897969825533644}, {{a, b, c, d}, {}}, {
          0.93719810153633465, 1}, {}], 
        AncestralLineage[ 
        11, {1.9706637158007017, 2.118015261702507}, {{}, {a, b, c, d}}, {
          0.93719810153633465, 1}, {}], 
        AncestralLineage[ 
        12, {2.118015261702507, 2.3758569290340006}, {{}}, {1}, {}], 
        AncestralLineage[ 
        13, {2.118015261702507, 2.228204237719424}, {{}, {a, b, c, d}}, {
          0.93719810153633465, 1}, {}], 
        AncestralLineage[ 
        14, {2.228204237719424, 2.2897969825533644}, {{}}, {1}, {}], 
        AncestralLineage[ 
        15, {2.228204237719424, 2.3639104415829926}, {{}, {a, b, c, d}}, {
          0.93719810153633465, 1}, {}], 
        AncestralLineage[ 
        16, {2.2897969825533644, 2.3639104415829926}, {{a, b, c, d}, {}}, {
          0.93719810153633465, 1}, {}], 
        AncestralLineage[ 
        17, {2.3639104415829926, 2.458462043572085}, {{a, b, c, d}}, {1}, {}],
         
        AncestralLineage[ 
        18, {2.3758569290340006, 2.458462043572085}, {{}}, {1}, {}], 
        AncestralLineage[ 
        19, {2.3758569290340006, 2.4862026095016123}, {{}}, {1}, {}], 
        AncestralLineage[ 
        20, {2.458462043572085, 2.4862026095016123}, {{a, b, c, d}}, {1}, {}],
         
        AncestralLineage[ 
        21, {2.4862026095016123, 3.9524773177113115}, {{a, b, c, d}}, {
          1}, {}], 
        AncestralLineage[ 
        22, {3.9524773177113115, 4.0138506590066365}, {{a, b, c, d}, {}}, {
          0.98883751447983492, 1}, {}], 
        AncestralLineage[ 
        23, {3.9524773177113115, 4.0138506590066365}, {{}, {a, b, c, d}}, {
          0.98883751447983492, 1}, {}], 
        AncestralLineage[ 
        24, {4.0138506590066365, 5.7540904800752752}, {{a, b, c, d}}, {
          1}, {}], 
        AncestralLineage[ 
        25, {5.7540904800752752, 5.8356593067548443}, {{a, b, c, d}, {}}, {
          0.18912143960102942, 1}, {}], 
        AncestralLineage[ 
        26, {5.7540904800752752, 5.8356593067548443}, {{}, {a, b, c, d}}, {
          0.18912143960102942, 1}, {}], 
        AncestralLineage[ 27, {5.8356593067548443, 
          DirectedInfinity[ 1]}, {{a, b, c, d}}, {1}, {}]}],
      Editable->False]], "Print",
  CellLabel->"From In[122]:="],

Cell[BoxData[
    \({6.460449426008908`, 2, 0.3588500293612883`}\)], "Print",
  CellLabel->"From In[122]:="],

Cell[BoxData[
    InterpretationBox[\("Recombining "\[InvisibleSpace]27\[InvisibleSpace]"; \
current lineages "\[InvisibleSpace]{27}\),
      SequenceForm[ "Recombining ", 27, "; current lineages ", {27}],
      Editable->False]], "Print",
  CellLabel->"From In[122]:="],

Cell[BoxData[
    InterpretationBox[
      RowBox[{"\<\"G=\"\>", "\[InvisibleSpace]", 
        RowBox[{"{", 
          
          RowBox[{\(AncestralLineage[
              a, {0, 0.05710778878192141`}, {{a}}, {1}, {}]\), 
            ",", \(AncestralLineage[
              b, {0, 0.027696065882077705`}, {{b}}, {1}, {}]\), 
            ",", \(AncestralLineage[
              c, {0, 0.6214825149645679`}, {{c}}, {1}, {}]\), 
            ",", \(AncestralLineage[
              d, {0, 0.027696065882077705`}, {{d}}, {1}, {}]\), 
            ",", \(AncestralLineage[
              1, {0.027696065882077705`, 
                0.05710778878192141`}, {{b, d}}, {1}, {}]\), 
            ",", \(AncestralLineage[
              2, {0.05710778878192141`, 
                0.27049717829601805`}, {{a, b, d}}, {1}, {}]\), 
            ",", \(AncestralLineage[
              3, {0.27049717829601805`, 
                0.4292570949591068`}, {{a, b, d}, {}}, {0.01899643970468609`, 
                1}, {}]\), 
            ",", \(AncestralLineage[
              4, {0.27049717829601805`, 
                0.6214825149645679`}, {{}, {a, b, d}}, {0.01899643970468609`, 
                1}, {}]\), 
            ",", \(AncestralLineage[
              5, {0.4292570949591068`, 
                0.45951657742311824`}, {{a, b, 
                  d}, {}}, {0.01899643970468609`, 1}, {}]\), 
            ",", \(AncestralLineage[
              6, {0.4292570949591068`, 
                0.45951657742311824`}, {{}}, {1}, {}]\), 
            ",", \(AncestralLineage[
              7, {0.45951657742311824`, 
                0.6452036798471656`}, {{a, b, d}, {}}, {0.01899643970468609`, 
                1}, {}]\), 
            ",", \(AncestralLineage[
              8, {0.6214825149645679`, 
                0.6452036798471656`}, {{c}, {a, b, c, 
                  d}}, {0.01899643970468609`, 1}, {}]\), 
            ",", \(AncestralLineage[
              9, {0.6452036798471656`, 
                1.9706637158007017`}, {{a, b, c, d}}, {1}, {}]\), 
            ",", \(AncestralLineage[
              10, {1.9706637158007017`, 
                2.2897969825533644`}, {{a, b, c, 
                  d}, {}}, {0.9371981015363346`, 1}, {}]\), 
            ",", \(AncestralLineage[
              11, {1.9706637158007017`, 
                2.118015261702507`}, {{}, {a, b, c, 
                  d}}, {0.9371981015363346`, 1}, {}]\), 
            ",", \(AncestralLineage[
              12, {2.118015261702507`, 2.3758569290340006`}, {{}}, {1}, {}]\),
             ",", \(AncestralLineage[
              13, {2.118015261702507`, 
                2.228204237719424`}, {{}, {a, b, c, 
                  d}}, {0.9371981015363346`, 1}, {}]\), 
            ",", \(AncestralLineage[
              14, {2.228204237719424`, 2.2897969825533644`}, {{}}, {1}, {}]\),
             ",", \(AncestralLineage[
              15, {2.228204237719424`, 
                2.3639104415829926`}, {{}, {a, b, c, 
                  d}}, {0.9371981015363346`, 1}, {}]\), 
            ",", \(AncestralLineage[
              16, {2.2897969825533644`, 
                2.3639104415829926`}, {{a, b, c, 
                  d}, {}}, {0.9371981015363346`, 1}, {}]\), 
            ",", \(AncestralLineage[
              17, {2.3639104415829926`, 
                2.458462043572085`}, {{a, b, c, d}}, {1}, {}]\), 
            ",", \(AncestralLineage[
              18, {2.3758569290340006`, 2.458462043572085`}, {{}}, {1}, {}]\),
             ",", \(AncestralLineage[
              19, {2.3758569290340006`, 
                2.4862026095016123`}, {{}}, {1}, {}]\), 
            ",", \(AncestralLineage[
              20, {2.458462043572085`, 
                2.4862026095016123`}, {{a, b, c, d}}, {1}, {}]\), 
            ",", \(AncestralLineage[
              21, {2.4862026095016123`, 
                3.9524773177113115`}, {{a, b, c, d}}, {1}, {}]\), 
            ",", \(AncestralLineage[
              22, {3.9524773177113115`, 
                4.0138506590066365`}, {{a, b, c, 
                  d}, {}}, {0.9888375144798349`, 1}, {}]\), 
            ",", \(AncestralLineage[
              23, {3.9524773177113115`, 
                4.0138506590066365`}, {{}, {a, b, c, 
                  d}}, {0.9888375144798349`, 1}, {}]\), 
            ",", \(AncestralLineage[
              24, {4.0138506590066365`, 
                5.754090480075275`}, {{a, b, c, d}}, {1}, {}]\), 
            ",", \(AncestralLineage[
              25, {5.754090480075275`, 
                5.835659306754844`}, {{a, b, c, 
                  d}, {}}, {0.18912143960102942`, 1}, {}]\), 
            ",", \(AncestralLineage[
              26, {5.754090480075275`, 
                5.835659306754844`}, {{}, {a, b, c, 
                  d}}, {0.18912143960102942`, 1}, {}]\), 
            ",", \(AncestralLineage[
              27, {5.835659306754844`, 
                6.460449426008908`}, {{a, b, c, d}}, {1}, {}]\), ",", 
            RowBox[{"AncestralLineage", "[", 
              RowBox[{"28", ",", 
                RowBox[{"{", 
                  RowBox[{"6.460449426008908`", ",", 
                    InterpretationBox["\[Infinity]",
                      DirectedInfinity[ 1]]}], "}"}], 
                ",", \({{a, b, c, d}, {}}\), 
                ",", \({0.3588500293612883`, 1}\), ",", \({}\)}], "]"}], ",", 
            
            RowBox[{"AncestralLineage", "[", 
              RowBox[{"29", ",", 
                RowBox[{"{", 
                  RowBox[{"6.460449426008908`", ",", 
                    InterpretationBox["\[Infinity]",
                      DirectedInfinity[ 1]]}], "}"}], 
                ",", \({{}, {a, b, c, d}}\), 
                ",", \({0.3588500293612883`, 1}\), ",", \({}\)}], "]"}]}], 
          "}"}]}],
      SequenceForm[ "G=", {
        AncestralLineage[ a, {0, 0.057107788781921409}, {{a}}, {1}, {}], 
        AncestralLineage[ b, {0, 0.027696065882077705}, {{b}}, {1}, {}], 
        AncestralLineage[ c, {0, 0.62148251496456786}, {{c}}, {1}, {}], 
        AncestralLineage[ d, {0, 0.027696065882077705}, {{d}}, {1}, {}], 
        AncestralLineage[ 
        1, {0.027696065882077705, 0.057107788781921409}, {{b, d}}, {1}, {}], 
        AncestralLineage[ 
        2, {0.057107788781921409, 0.27049717829601805}, {{a, b, d}}, {1}, {}],
         
        AncestralLineage[ 
        3, {0.27049717829601805, 0.4292570949591068}, {{a, b, d}, {}}, {
          0.018996439704686091, 1}, {}], 
        AncestralLineage[ 
        4, {0.27049717829601805, 0.62148251496456786}, {{}, {a, b, d}}, {
          0.018996439704686091, 1}, {}], 
        AncestralLineage[ 
        5, {0.4292570949591068, 0.45951657742311824}, {{a, b, d}, {}}, {
          0.018996439704686091, 1}, {}], 
        AncestralLineage[ 
        6, {0.4292570949591068, 0.45951657742311824}, {{}}, {1}, {}], 
        AncestralLineage[ 
        7, {0.45951657742311824, 0.64520367984716565}, {{a, b, d}, {}}, {
          0.018996439704686091, 1}, {}], 
        AncestralLineage[ 
        8, {0.62148251496456786, 0.64520367984716565}, {{c}, {a, b, c, d}}, {
          0.018996439704686091, 1}, {}], 
        AncestralLineage[ 
        9, {0.64520367984716565, 1.9706637158007017}, {{a, b, c, d}}, {
          1}, {}], 
        AncestralLineage[ 
        10, {1.9706637158007017, 2.2897969825533644}, {{a, b, c, d}, {}}, {
          0.93719810153633465, 1}, {}], 
        AncestralLineage[ 
        11, {1.9706637158007017, 2.118015261702507}, {{}, {a, b, c, d}}, {
          0.93719810153633465, 1}, {}], 
        AncestralLineage[ 
        12, {2.118015261702507, 2.3758569290340006}, {{}}, {1}, {}], 
        AncestralLineage[ 
        13, {2.118015261702507, 2.228204237719424}, {{}, {a, b, c, d}}, {
          0.93719810153633465, 1}, {}], 
        AncestralLineage[ 
        14, {2.228204237719424, 2.2897969825533644}, {{}}, {1}, {}], 
        AncestralLineage[ 
        15, {2.228204237719424, 2.3639104415829926}, {{}, {a, b, c, d}}, {
          0.93719810153633465, 1}, {}], 
        AncestralLineage[ 
        16, {2.2897969825533644, 2.3639104415829926}, {{a, b, c, d}, {}}, {
          0.93719810153633465, 1}, {}], 
        AncestralLineage[ 
        17, {2.3639104415829926, 2.458462043572085}, {{a, b, c, d}}, {1}, {}],
         
        AncestralLineage[ 
        18, {2.3758569290340006, 2.458462043572085}, {{}}, {1}, {}], 
        AncestralLineage[ 
        19, {2.3758569290340006, 2.4862026095016123}, {{}}, {1}, {}], 
        AncestralLineage[ 
        20, {2.458462043572085, 2.4862026095016123}, {{a, b, c, d}}, {1}, {}],
         
        AncestralLineage[ 
        21, {2.4862026095016123, 3.9524773177113115}, {{a, b, c, d}}, {
          1}, {}], 
        AncestralLineage[ 
        22, {3.9524773177113115, 4.0138506590066365}, {{a, b, c, d}, {}}, {
          0.98883751447983492, 1}, {}], 
        AncestralLineage[ 
        23, {3.9524773177113115, 4.0138506590066365}, {{}, {a, b, c, d}}, {
          0.98883751447983492, 1}, {}], 
        AncestralLineage[ 
        24, {4.0138506590066365, 5.7540904800752752}, {{a, b, c, d}}, {
          1}, {}], 
        AncestralLineage[ 
        25, {5.7540904800752752, 5.8356593067548443}, {{a, b, c, d}, {}}, {
          0.18912143960102942, 1}, {}], 
        AncestralLineage[ 
        26, {5.7540904800752752, 5.8356593067548443}, {{}, {a, b, c, d}}, {
          0.18912143960102942, 1}, {}], 
        AncestralLineage[ 
        27, {5.8356593067548443, 6.4604494260089078}, {{a, b, c, d}}, {
          1}, {}], 
        AncestralLineage[ 28, {6.4604494260089078, 
          DirectedInfinity[ 1]}, {{a, b, c, d}, {}}, {0.35885002936128829, 
          1}, {}], 
        AncestralLineage[ 29, {6.4604494260089078, 
          DirectedInfinity[ 1]}, {{}, {a, b, c, d}}, {0.35885002936128829, 
          1}, {}]}],
      Editable->False]], "Print",
  CellLabel->"From In[122]:="],

Cell[BoxData[
    \({7.077559804918352`, 1, None}\)], "Print",
  CellLabel->"From In[122]:="],

Cell[BoxData[
    InterpretationBox[\("Coalescing "\[InvisibleSpace]{28, 
          29}\[InvisibleSpace]"; current lineages "\[InvisibleSpace]{28, 
          29}\),
      SequenceForm[ "Coalescing ", {28, 29}, "; current lineages ", {28, 29}],
      
      Editable->False]], "Print",
  CellLabel->"From In[122]:="],

Cell[BoxData[
    InterpretationBox[
      RowBox[{"\<\"G=\"\>", "\[InvisibleSpace]", 
        RowBox[{"{", 
          
          RowBox[{\(AncestralLineage[
              a, {0, 0.05710778878192141`}, {{a}}, {1}, {}]\), 
            ",", \(AncestralLineage[
              b, {0, 0.027696065882077705`}, {{b}}, {1}, {}]\), 
            ",", \(AncestralLineage[
              c, {0, 0.6214825149645679`}, {{c}}, {1}, {}]\), 
            ",", \(AncestralLineage[
              d, {0, 0.027696065882077705`}, {{d}}, {1}, {}]\), 
            ",", \(AncestralLineage[
              1, {0.027696065882077705`, 
                0.05710778878192141`}, {{b, d}}, {1}, {}]\), 
            ",", \(AncestralLineage[
              2, {0.05710778878192141`, 
                0.27049717829601805`}, {{a, b, d}}, {1}, {}]\), 
            ",", \(AncestralLineage[
              3, {0.27049717829601805`, 
                0.4292570949591068`}, {{a, b, d}, {}}, {0.01899643970468609`, 
                1}, {}]\), 
            ",", \(AncestralLineage[
              4, {0.27049717829601805`, 
                0.6214825149645679`}, {{}, {a, b, d}}, {0.01899643970468609`, 
                1}, {}]\), 
            ",", \(AncestralLineage[
              5, {0.4292570949591068`, 
                0.45951657742311824`}, {{a, b, 
                  d}, {}}, {0.01899643970468609`, 1}, {}]\), 
            ",", \(AncestralLineage[
              6, {0.4292570949591068`, 
                0.45951657742311824`}, {{}}, {1}, {}]\), 
            ",", \(AncestralLineage[
              7, {0.45951657742311824`, 
                0.6452036798471656`}, {{a, b, d}, {}}, {0.01899643970468609`, 
                1}, {}]\), 
            ",", \(AncestralLineage[
              8, {0.6214825149645679`, 
                0.6452036798471656`}, {{c}, {a, b, c, 
                  d}}, {0.01899643970468609`, 1}, {}]\), 
            ",", \(AncestralLineage[
              9, {0.6452036798471656`, 
                1.9706637158007017`}, {{a, b, c, d}}, {1}, {}]\), 
            ",", \(AncestralLineage[
              10, {1.9706637158007017`, 
                2.2897969825533644`}, {{a, b, c, 
                  d}, {}}, {0.9371981015363346`, 1}, {}]\), 
            ",", \(AncestralLineage[
              11, {1.9706637158007017`, 
                2.118015261702507`}, {{}, {a, b, c, 
                  d}}, {0.9371981015363346`, 1}, {}]\), 
            ",", \(AncestralLineage[
              12, {2.118015261702507`, 2.3758569290340006`}, {{}}, {1}, {}]\),
             ",", \(AncestralLineage[
              13, {2.118015261702507`, 
                2.228204237719424`}, {{}, {a, b, c, 
                  d}}, {0.9371981015363346`, 1}, {}]\), 
            ",", \(AncestralLineage[
              14, {2.228204237719424`, 2.2897969825533644`}, {{}}, {1}, {}]\),
             ",", \(AncestralLineage[
              15, {2.228204237719424`, 
                2.3639104415829926`}, {{}, {a, b, c, 
                  d}}, {0.9371981015363346`, 1}, {}]\), 
            ",", \(AncestralLineage[
              16, {2.2897969825533644`, 
                2.3639104415829926`}, {{a, b, c, 
                  d}, {}}, {0.9371981015363346`, 1}, {}]\), 
            ",", \(AncestralLineage[
              17, {2.3639104415829926`, 
                2.458462043572085`}, {{a, b, c, d}}, {1}, {}]\), 
            ",", \(AncestralLineage[
              18, {2.3758569290340006`, 2.458462043572085`}, {{}}, {1}, {}]\),
             ",", \(AncestralLineage[
              19, {2.3758569290340006`, 
                2.4862026095016123`}, {{}}, {1}, {}]\), 
            ",", \(AncestralLineage[
              20, {2.458462043572085`, 
                2.4862026095016123`}, {{a, b, c, d}}, {1}, {}]\), 
            ",", \(AncestralLineage[
              21, {2.4862026095016123`, 
                3.9524773177113115`}, {{a, b, c, d}}, {1}, {}]\), 
            ",", \(AncestralLineage[
              22, {3.9524773177113115`, 
                4.0138506590066365`}, {{a, b, c, 
                  d}, {}}, {0.9888375144798349`, 1}, {}]\), 
            ",", \(AncestralLineage[
              23, {3.9524773177113115`, 
                4.0138506590066365`}, {{}, {a, b, c, 
                  d}}, {0.9888375144798349`, 1}, {}]\), 
            ",", \(AncestralLineage[
              24, {4.0138506590066365`, 
                5.754090480075275`}, {{a, b, c, d}}, {1}, {}]\), 
            ",", \(AncestralLineage[
              25, {5.754090480075275`, 
                5.835659306754844`}, {{a, b, c, 
                  d}, {}}, {0.18912143960102942`, 1}, {}]\), 
            ",", \(AncestralLineage[
              26, {5.754090480075275`, 
                5.835659306754844`}, {{}, {a, b, c, 
                  d}}, {0.18912143960102942`, 1}, {}]\), 
            ",", \(AncestralLineage[
              27, {5.835659306754844`, 
                6.460449426008908`}, {{a, b, c, d}}, {1}, {}]\), 
            ",", \(AncestralLineage[
              28, {6.460449426008908`, 
                7.077559804918352`}, {{a, b, c, 
                  d}, {}}, {0.3588500293612883`, 1}, {}]\), 
            ",", \(AncestralLineage[
              29, {6.460449426008908`, 
                7.077559804918352`}, {{}, {a, b, c, 
                  d}}, {0.3588500293612883`, 1}, {}]\), ",", 
            RowBox[{"AncestralLineage", "[", 
              RowBox[{"30", ",", 
                RowBox[{"{", 
                  RowBox[{"7.077559804918352`", ",", 
                    InterpretationBox["\[Infinity]",
                      DirectedInfinity[ 1]]}], "}"}], ",", \({{a, b, c, d}}\),
                 ",", \({1}\), ",", \({}\)}], "]"}]}], "}"}]}],
      SequenceForm[ "G=", {
        AncestralLineage[ a, {0, 0.057107788781921409}, {{a}}, {1}, {}], 
        AncestralLineage[ b, {0, 0.027696065882077705}, {{b}}, {1}, {}], 
        AncestralLineage[ c, {0, 0.62148251496456786}, {{c}}, {1}, {}], 
        AncestralLineage[ d, {0, 0.027696065882077705}, {{d}}, {1}, {}], 
        AncestralLineage[ 
        1, {0.027696065882077705, 0.057107788781921409}, {{b, d}}, {1}, {}], 
        AncestralLineage[ 
        2, {0.057107788781921409, 0.27049717829601805}, {{a, b, d}}, {1}, {}],
         
        AncestralLineage[ 
        3, {0.27049717829601805, 0.4292570949591068}, {{a, b, d}, {}}, {
          0.018996439704686091, 1}, {}], 
        AncestralLineage[ 
        4, {0.27049717829601805, 0.62148251496456786}, {{}, {a, b, d}}, {
          0.018996439704686091, 1}, {}], 
        AncestralLineage[ 
        5, {0.4292570949591068, 0.45951657742311824}, {{a, b, d}, {}}, {
          0.018996439704686091, 1}, {}], 
        AncestralLineage[ 
        6, {0.4292570949591068, 0.45951657742311824}, {{}}, {1}, {}], 
        AncestralLineage[ 
        7, {0.45951657742311824, 0.64520367984716565}, {{a, b, d}, {}}, {
          0.018996439704686091, 1}, {}], 
        AncestralLineage[ 
        8, {0.62148251496456786, 0.64520367984716565}, {{c}, {a, b, c, d}}, {
          0.018996439704686091, 1}, {}], 
        AncestralLineage[ 
        9, {0.64520367984716565, 1.9706637158007017}, {{a, b, c, d}}, {
          1}, {}], 
        AncestralLineage[ 
        10, {1.9706637158007017, 2.2897969825533644}, {{a, b, c, d}, {}}, {
          0.93719810153633465, 1}, {}], 
        AncestralLineage[ 
        11, {1.9706637158007017, 2.118015261702507}, {{}, {a, b, c, d}}, {
          0.93719810153633465, 1}, {}], 
        AncestralLineage[ 
        12, {2.118015261702507, 2.3758569290340006}, {{}}, {1}, {}], 
        AncestralLineage[ 
        13, {2.118015261702507, 2.228204237719424}, {{}, {a, b, c, d}}, {
          0.93719810153633465, 1}, {}], 
        AncestralLineage[ 
        14, {2.228204237719424, 2.2897969825533644}, {{}}, {1}, {}], 
        AncestralLineage[ 
        15, {2.228204237719424, 2.3639104415829926}, {{}, {a, b, c, d}}, {
          0.93719810153633465, 1}, {}], 
        AncestralLineage[ 
        16, {2.2897969825533644, 2.3639104415829926}, {{a, b, c, d}, {}}, {
          0.93719810153633465, 1}, {}], 
        AncestralLineage[ 
        17, {2.3639104415829926, 2.458462043572085}, {{a, b, c, d}}, {1}, {}],
         
        AncestralLineage[ 
        18, {2.3758569290340006, 2.458462043572085}, {{}}, {1}, {}], 
        AncestralLineage[ 
        19, {2.3758569290340006, 2.4862026095016123}, {{}}, {1}, {}], 
        AncestralLineage[ 
        20, {2.458462043572085, 2.4862026095016123}, {{a, b, c, d}}, {1}, {}],
         
        AncestralLineage[ 
        21, {2.4862026095016123, 3.9524773177113115}, {{a, b, c, d}}, {
          1}, {}], 
        AncestralLineage[ 
        22, {3.9524773177113115, 4.0138506590066365}, {{a, b, c, d}, {}}, {
          0.98883751447983492, 1}, {}], 
        AncestralLineage[ 
        23, {3.9524773177113115, 4.0138506590066365}, {{}, {a, b, c, d}}, {
          0.98883751447983492, 1}, {}], 
        AncestralLineage[ 
        24, {4.0138506590066365, 5.7540904800752752}, {{a, b, c, d}}, {
          1}, {}], 
        AncestralLineage[ 
        25, {5.7540904800752752, 5.8356593067548443}, {{a, b, c, d}, {}}, {
          0.18912143960102942, 1}, {}], 
        AncestralLineage[ 
        26, {5.7540904800752752, 5.8356593067548443}, {{}, {a, b, c, d}}, {
          0.18912143960102942, 1}, {}], 
        AncestralLineage[ 
        27, {5.8356593067548443, 6.4604494260089078}, {{a, b, c, d}}, {
          1}, {}], 
        AncestralLineage[ 
        28, {6.4604494260089078, 7.0775598049183523}, {{a, b, c, d}, {}}, {
          0.35885002936128829, 1}, {}], 
        AncestralLineage[ 
        29, {6.4604494260089078, 7.0775598049183523}, {{}, {a, b, c, d}}, {
          0.35885002936128829, 1}, {}], 
        AncestralLineage[ 30, {7.0775598049183523, 
          DirectedInfinity[ 1]}, {{a, b, c, d}}, {1}, {}]}],
      Editable->False]], "Print",
  CellLabel->"From In[122]:="],

Cell[BoxData[
    \({9.350056023799493`, 2, 0.1922328343937298`}\)], "Print",
  CellLabel->"From In[122]:="],

Cell[BoxData[
    InterpretationBox[\("Recombining "\[InvisibleSpace]30\[InvisibleSpace]"; \
current lineages "\[InvisibleSpace]{30}\),
      SequenceForm[ "Recombining ", 30, "; current lineages ", {30}],
      Editable->False]], "Print",
  CellLabel->"From In[122]:="],

Cell[BoxData[
    InterpretationBox[
      RowBox[{"\<\"G=\"\>", "\[InvisibleSpace]", 
        RowBox[{"{", 
          
          RowBox[{\(AncestralLineage[
              a, {0, 0.05710778878192141`}, {{a}}, {1}, {}]\), 
            ",", \(AncestralLineage[
              b, {0, 0.027696065882077705`}, {{b}}, {1}, {}]\), 
            ",", \(AncestralLineage[
              c, {0, 0.6214825149645679`}, {{c}}, {1}, {}]\), 
            ",", \(AncestralLineage[
              d, {0, 0.027696065882077705`}, {{d}}, {1}, {}]\), 
            ",", \(AncestralLineage[
              1, {0.027696065882077705`, 
                0.05710778878192141`}, {{b, d}}, {1}, {}]\), 
            ",", \(AncestralLineage[
              2, {0.05710778878192141`, 
                0.27049717829601805`}, {{a, b, d}}, {1}, {}]\), 
            ",", \(AncestralLineage[
              3, {0.27049717829601805`, 
                0.4292570949591068`}, {{a, b, d}, {}}, {0.01899643970468609`, 
                1}, {}]\), 
            ",", \(AncestralLineage[
              4, {0.27049717829601805`, 
                0.6214825149645679`}, {{}, {a, b, d}}, {0.01899643970468609`, 
                1}, {}]\), 
            ",", \(AncestralLineage[
              5, {0.4292570949591068`, 
                0.45951657742311824`}, {{a, b, 
                  d}, {}}, {0.01899643970468609`, 1}, {}]\), 
            ",", \(AncestralLineage[
              6, {0.4292570949591068`, 
                0.45951657742311824`}, {{}}, {1}, {}]\), 
            ",", \(AncestralLineage[
              7, {0.45951657742311824`, 
                0.6452036798471656`}, {{a, b, d}, {}}, {0.01899643970468609`, 
                1}, {}]\), 
            ",", \(AncestralLineage[
              8, {0.6214825149645679`, 
                0.6452036798471656`}, {{c}, {a, b, c, 
                  d}}, {0.01899643970468609`, 1}, {}]\), 
            ",", \(AncestralLineage[
              9, {0.6452036798471656`, 
                1.9706637158007017`}, {{a, b, c, d}}, {1}, {}]\), 
            ",", \(AncestralLineage[
              10, {1.9706637158007017`, 
                2.2897969825533644`}, {{a, b, c, 
                  d}, {}}, {0.9371981015363346`, 1}, {}]\), 
            ",", \(AncestralLineage[
              11, {1.9706637158007017`, 
                2.118015261702507`}, {{}, {a, b, c, 
                  d}}, {0.9371981015363346`, 1}, {}]\), 
            ",", \(AncestralLineage[
              12, {2.118015261702507`, 2.3758569290340006`}, {{}}, {1}, {}]\),
             ",", \(AncestralLineage[
              13, {2.118015261702507`, 
                2.228204237719424`}, {{}, {a, b, c, 
                  d}}, {0.9371981015363346`, 1}, {}]\), 
            ",", \(AncestralLineage[
              14, {2.228204237719424`, 2.2897969825533644`}, {{}}, {1}, {}]\),
             ",", \(AncestralLineage[
              15, {2.228204237719424`, 
                2.3639104415829926`}, {{}, {a, b, c, 
                  d}}, {0.9371981015363346`, 1}, {}]\), 
            ",", \(AncestralLineage[
              16, {2.2897969825533644`, 
                2.3639104415829926`}, {{a, b, c, 
                  d}, {}}, {0.9371981015363346`, 1}, {}]\), 
            ",", \(AncestralLineage[
              17, {2.3639104415829926`, 
                2.458462043572085`}, {{a, b, c, d}}, {1}, {}]\), 
            ",", \(AncestralLineage[
              18, {2.3758569290340006`, 2.458462043572085`}, {{}}, {1}, {}]\),
             ",", \(AncestralLineage[
              19, {2.3758569290340006`, 
                2.4862026095016123`}, {{}}, {1}, {}]\), 
            ",", \(AncestralLineage[
              20, {2.458462043572085`, 
                2.4862026095016123`}, {{a, b, c, d}}, {1}, {}]\), 
            ",", \(AncestralLineage[
              21, {2.4862026095016123`, 
                3.9524773177113115`}, {{a, b, c, d}}, {1}, {}]\), 
            ",", \(AncestralLineage[
              22, {3.9524773177113115`, 
                4.0138506590066365`}, {{a, b, c, 
                  d}, {}}, {0.9888375144798349`, 1}, {}]\), 
            ",", \(AncestralLineage[
              23, {3.9524773177113115`, 
                4.0138506590066365`}, {{}, {a, b, c, 
                  d}}, {0.9888375144798349`, 1}, {}]\), 
            ",", \(AncestralLineage[
              24, {4.0138506590066365`, 
                5.754090480075275`}, {{a, b, c, d}}, {1}, {}]\), 
            ",", \(AncestralLineage[
              25, {5.754090480075275`, 
                5.835659306754844`}, {{a, b, c, 
                  d}, {}}, {0.18912143960102942`, 1}, {}]\), 
            ",", \(AncestralLineage[
              26, {5.754090480075275`, 
                5.835659306754844`}, {{}, {a, b, c, 
                  d}}, {0.18912143960102942`, 1}, {}]\), 
            ",", \(AncestralLineage[
              27, {5.835659306754844`, 
                6.460449426008908`}, {{a, b, c, d}}, {1}, {}]\), 
            ",", \(AncestralLineage[
              28, {6.460449426008908`, 
                7.077559804918352`}, {{a, b, c, 
                  d}, {}}, {0.3588500293612883`, 1}, {}]\), 
            ",", \(AncestralLineage[
              29, {6.460449426008908`, 
                7.077559804918352`}, {{}, {a, b, c, 
                  d}}, {0.3588500293612883`, 1}, {}]\), 
            ",", \(AncestralLineage[
              30, {7.077559804918352`, 
                9.350056023799493`}, {{a, b, c, d}}, {1}, {}]\), ",", 
            RowBox[{"AncestralLineage", "[", 
              RowBox[{"31", ",", 
                RowBox[{"{", 
                  RowBox[{"9.350056023799493`", ",", 
                    InterpretationBox["\[Infinity]",
                      DirectedInfinity[ 1]]}], "}"}], 
                ",", \({{a, b, c, d}, {}}\), 
                ",", \({0.1922328343937298`, 1}\), ",", \({}\)}], "]"}], ",", 
            
            RowBox[{"AncestralLineage", "[", 
              RowBox[{"32", ",", 
                RowBox[{"{", 
                  RowBox[{"9.350056023799493`", ",", 
                    InterpretationBox["\[Infinity]",
                      DirectedInfinity[ 1]]}], "}"}], 
                ",", \({{}, {a, b, c, d}}\), 
                ",", \({0.1922328343937298`, 1}\), ",", \({}\)}], "]"}]}], 
          "}"}]}],
      SequenceForm[ "G=", {
        AncestralLineage[ a, {0, 0.057107788781921409}, {{a}}, {1}, {}], 
        AncestralLineage[ b, {0, 0.027696065882077705}, {{b}}, {1}, {}], 
        AncestralLineage[ c, {0, 0.62148251496456786}, {{c}}, {1}, {}], 
        AncestralLineage[ d, {0, 0.027696065882077705}, {{d}}, {1}, {}], 
        AncestralLineage[ 
        1, {0.027696065882077705, 0.057107788781921409}, {{b, d}}, {1}, {}], 
        AncestralLineage[ 
        2, {0.057107788781921409, 0.27049717829601805}, {{a, b, d}}, {1}, {}],
         
        AncestralLineage[ 
        3, {0.27049717829601805, 0.4292570949591068}, {{a, b, d}, {}}, {
          0.018996439704686091, 1}, {}], 
        AncestralLineage[ 
        4, {0.27049717829601805, 0.62148251496456786}, {{}, {a, b, d}}, {
          0.018996439704686091, 1}, {}], 
        AncestralLineage[ 
        5, {0.4292570949591068, 0.45951657742311824}, {{a, b, d}, {}}, {
          0.018996439704686091, 1}, {}], 
        AncestralLineage[ 
        6, {0.4292570949591068, 0.45951657742311824}, {{}}, {1}, {}], 
        AncestralLineage[ 
        7, {0.45951657742311824, 0.64520367984716565}, {{a, b, d}, {}}, {
          0.018996439704686091, 1}, {}], 
        AncestralLineage[ 
        8, {0.62148251496456786, 0.64520367984716565}, {{c}, {a, b, c, d}}, {
          0.018996439704686091, 1}, {}], 
        AncestralLineage[ 
        9, {0.64520367984716565, 1.9706637158007017}, {{a, b, c, d}}, {
          1}, {}], 
        AncestralLineage[ 
        10, {1.9706637158007017, 2.2897969825533644}, {{a, b, c, d}, {}}, {
          0.93719810153633465, 1}, {}], 
        AncestralLineage[ 
        11, {1.9706637158007017, 2.118015261702507}, {{}, {a, b, c, d}}, {
          0.93719810153633465, 1}, {}], 
        AncestralLineage[ 
        12, {2.118015261702507, 2.3758569290340006}, {{}}, {1}, {}], 
        AncestralLineage[ 
        13, {2.118015261702507, 2.228204237719424}, {{}, {a, b, c, d}}, {
          0.93719810153633465, 1}, {}], 
        AncestralLineage[ 
        14, {2.228204237719424, 2.2897969825533644}, {{}}, {1}, {}], 
        AncestralLineage[ 
        15, {2.228204237719424, 2.3639104415829926}, {{}, {a, b, c, d}}, {
          0.93719810153633465, 1}, {}], 
        AncestralLineage[ 
        16, {2.2897969825533644, 2.3639104415829926}, {{a, b, c, d}, {}}, {
          0.93719810153633465, 1}, {}], 
        AncestralLineage[ 
        17, {2.3639104415829926, 2.458462043572085}, {{a, b, c, d}}, {1}, {}],
         
        AncestralLineage[ 
        18, {2.3758569290340006, 2.458462043572085}, {{}}, {1}, {}], 
        AncestralLineage[ 
        19, {2.3758569290340006, 2.4862026095016123}, {{}}, {1}, {}], 
        AncestralLineage[ 
        20, {2.458462043572085, 2.4862026095016123}, {{a, b, c, d}}, {1}, {}],
         
        AncestralLineage[ 
        21, {2.4862026095016123, 3.9524773177113115}, {{a, b, c, d}}, {
          1}, {}], 
        AncestralLineage[ 
        22, {3.9524773177113115, 4.0138506590066365}, {{a, b, c, d}, {}}, {
          0.98883751447983492, 1}, {}], 
        AncestralLineage[ 
        23, {3.9524773177113115, 4.0138506590066365}, {{}, {a, b, c, d}}, {
          0.98883751447983492, 1}, {}], 
        AncestralLineage[ 
        24, {4.0138506590066365, 5.7540904800752752}, {{a, b, c, d}}, {
          1}, {}], 
        AncestralLineage[ 
        25, {5.7540904800752752, 5.8356593067548443}, {{a, b, c, d}, {}}, {
          0.18912143960102942, 1}, {}], 
        AncestralLineage[ 
        26, {5.7540904800752752, 5.8356593067548443}, {{}, {a, b, c, d}}, {
          0.18912143960102942, 1}, {}], 
        AncestralLineage[ 
        27, {5.8356593067548443, 6.4604494260089078}, {{a, b, c, d}}, {
          1}, {}], 
        AncestralLineage[ 
        28, {6.4604494260089078, 7.0775598049183523}, {{a, b, c, d}, {}}, {
          0.35885002936128829, 1}, {}], 
        AncestralLineage[ 
        29, {6.4604494260089078, 7.0775598049183523}, {{}, {a, b, c, d}}, {
          0.35885002936128829, 1}, {}], 
        AncestralLineage[ 
        30, {7.0775598049183523, 9.3500560237994925}, {{a, b, c, d}}, {
          1}, {}], 
        AncestralLineage[ 31, {9.3500560237994925, 
          DirectedInfinity[ 1]}, {{a, b, c, d}, {}}, {0.19223283439372979, 
          1}, {}], 
        AncestralLineage[ 32, {9.3500560237994925, 
          DirectedInfinity[ 1]}, {{}, {a, b, c, d}}, {0.19223283439372979, 
          1}, {}]}],
      Editable->False]], "Print",
  CellLabel->"From In[122]:="],

Cell[BoxData[
    \({9.889403896797967`, 1, None}\)], "Print",
  CellLabel->"From In[122]:="],

Cell[BoxData[
    InterpretationBox[\("Coalescing "\[InvisibleSpace]{31, 
          32}\[InvisibleSpace]"; current lineages "\[InvisibleSpace]{31, 
          32}\),
      SequenceForm[ "Coalescing ", {31, 32}, "; current lineages ", {31, 32}],
      
      Editable->False]], "Print",
  CellLabel->"From In[122]:="],

Cell[BoxData[
    InterpretationBox[
      RowBox[{"\<\"G=\"\>", "\[InvisibleSpace]", 
        RowBox[{"{", 
          
          RowBox[{\(AncestralLineage[
              a, {0, 0.05710778878192141`}, {{a}}, {1}, {}]\), 
            ",", \(AncestralLineage[
              b, {0, 0.027696065882077705`}, {{b}}, {1}, {}]\), 
            ",", \(AncestralLineage[
              c, {0, 0.6214825149645679`}, {{c}}, {1}, {}]\), 
            ",", \(AncestralLineage[
              d, {0, 0.027696065882077705`}, {{d}}, {1}, {}]\), 
            ",", \(AncestralLineage[
              1, {0.027696065882077705`, 
                0.05710778878192141`}, {{b, d}}, {1}, {}]\), 
            ",", \(AncestralLineage[
              2, {0.05710778878192141`, 
                0.27049717829601805`}, {{a, b, d}}, {1}, {}]\), 
            ",", \(AncestralLineage[
              3, {0.27049717829601805`, 
                0.4292570949591068`}, {{a, b, d}, {}}, {0.01899643970468609`, 
                1}, {}]\), 
            ",", \(AncestralLineage[
              4, {0.27049717829601805`, 
                0.6214825149645679`}, {{}, {a, b, d}}, {0.01899643970468609`, 
                1}, {}]\), 
            ",", \(AncestralLineage[
              5, {0.4292570949591068`, 
                0.45951657742311824`}, {{a, b, 
                  d}, {}}, {0.01899643970468609`, 1}, {}]\), 
            ",", \(AncestralLineage[
              6, {0.4292570949591068`, 
                0.45951657742311824`}, {{}}, {1}, {}]\), 
            ",", \(AncestralLineage[
              7, {0.45951657742311824`, 
                0.6452036798471656`}, {{a, b, d}, {}}, {0.01899643970468609`, 
                1}, {}]\), 
            ",", \(AncestralLineage[
              8, {0.6214825149645679`, 
                0.6452036798471656`}, {{c}, {a, b, c, 
                  d}}, {0.01899643970468609`, 1}, {}]\), 
            ",", \(AncestralLineage[
              9, {0.6452036798471656`, 
                1.9706637158007017`}, {{a, b, c, d}}, {1}, {}]\), 
            ",", \(AncestralLineage[
              10, {1.9706637158007017`, 
                2.2897969825533644`}, {{a, b, c, 
                  d}, {}}, {0.9371981015363346`, 1}, {}]\), 
            ",", \(AncestralLineage[
              11, {1.9706637158007017`, 
                2.118015261702507`}, {{}, {a, b, c, 
                  d}}, {0.9371981015363346`, 1}, {}]\), 
            ",", \(AncestralLineage[
              12, {2.118015261702507`, 2.3758569290340006`}, {{}}, {1}, {}]\),
             ",", \(AncestralLineage[
              13, {2.118015261702507`, 
                2.228204237719424`}, {{}, {a, b, c, 
                  d}}, {0.9371981015363346`, 1}, {}]\), 
            ",", \(AncestralLineage[
              14, {2.228204237719424`, 2.2897969825533644`}, {{}}, {1}, {}]\),
             ",", \(AncestralLineage[
              15, {2.228204237719424`, 
                2.3639104415829926`}, {{}, {a, b, c, 
                  d}}, {0.9371981015363346`, 1}, {}]\), 
            ",", \(AncestralLineage[
              16, {2.2897969825533644`, 
                2.3639104415829926`}, {{a, b, c, 
                  d}, {}}, {0.9371981015363346`, 1}, {}]\), 
            ",", \(AncestralLineage[
              17, {2.3639104415829926`, 
                2.458462043572085`}, {{a, b, c, d}}, {1}, {}]\), 
            ",", \(AncestralLineage[
              18, {2.3758569290340006`, 2.458462043572085`}, {{}}, {1}, {}]\),
             ",", \(AncestralLineage[
              19, {2.3758569290340006`, 
                2.4862026095016123`}, {{}}, {1}, {}]\), 
            ",", \(AncestralLineage[
              20, {2.458462043572085`, 
                2.4862026095016123`}, {{a, b, c, d}}, {1}, {}]\), 
            ",", \(AncestralLineage[
              21, {2.4862026095016123`, 
                3.9524773177113115`}, {{a, b, c, d}}, {1}, {}]\), 
            ",", \(AncestralLineage[
              22, {3.9524773177113115`, 
                4.0138506590066365`}, {{a, b, c, 
                  d}, {}}, {0.9888375144798349`, 1}, {}]\), 
            ",", \(AncestralLineage[
              23, {3.9524773177113115`, 
                4.0138506590066365`}, {{}, {a, b, c, 
                  d}}, {0.9888375144798349`, 1}, {}]\), 
            ",", \(AncestralLineage[
              24, {4.0138506590066365`, 
                5.754090480075275`}, {{a, b, c, d}}, {1}, {}]\), 
            ",", \(AncestralLineage[
              25, {5.754090480075275`, 
                5.835659306754844`}, {{a, b, c, 
                  d}, {}}, {0.18912143960102942`, 1}, {}]\), 
            ",", \(AncestralLineage[
              26, {5.754090480075275`, 
                5.835659306754844`}, {{}, {a, b, c, 
                  d}}, {0.18912143960102942`, 1}, {}]\), 
            ",", \(AncestralLineage[
              27, {5.835659306754844`, 
                6.460449426008908`}, {{a, b, c, d}}, {1}, {}]\), 
            ",", \(AncestralLineage[
              28, {6.460449426008908`, 
                7.077559804918352`}, {{a, b, c, 
                  d}, {}}, {0.3588500293612883`, 1}, {}]\), 
            ",", \(AncestralLineage[
              29, {6.460449426008908`, 
                7.077559804918352`}, {{}, {a, b, c, 
                  d}}, {0.3588500293612883`, 1}, {}]\), 
            ",", \(AncestralLineage[
              30, {7.077559804918352`, 
                9.350056023799493`}, {{a, b, c, d}}, {1}, {}]\), 
            ",", \(AncestralLineage[
              31, {9.350056023799493`, 
                9.889403896797967`}, {{a, b, c, 
                  d}, {}}, {0.1922328343937298`, 1}, {}]\), 
            ",", \(AncestralLineage[
              32, {9.350056023799493`, 
                9.889403896797967`}, {{}, {a, b, c, 
                  d}}, {0.1922328343937298`, 1}, {}]\), ",", 
            RowBox[{"AncestralLineage", "[", 
              RowBox[{"33", ",", 
                RowBox[{"{", 
                  RowBox[{"9.889403896797967`", ",", 
                    InterpretationBox["\[Infinity]",
                      DirectedInfinity[ 1]]}], "}"}], ",", \({{a, b, c, d}}\),
                 ",", \({1}\), ",", \({}\)}], "]"}]}], "}"}]}],
      SequenceForm[ "G=", {
        AncestralLineage[ a, {0, 0.057107788781921409}, {{a}}, {1}, {}], 
        AncestralLineage[ b, {0, 0.027696065882077705}, {{b}}, {1}, {}], 
        AncestralLineage[ c, {0, 0.62148251496456786}, {{c}}, {1}, {}], 
        AncestralLineage[ d, {0, 0.027696065882077705}, {{d}}, {1}, {}], 
        AncestralLineage[ 
        1, {0.027696065882077705, 0.057107788781921409}, {{b, d}}, {1}, {}], 
        AncestralLineage[ 
        2, {0.057107788781921409, 0.27049717829601805}, {{a, b, d}}, {1}, {}],
         
        AncestralLineage[ 
        3, {0.27049717829601805, 0.4292570949591068}, {{a, b, d}, {}}, {
          0.018996439704686091, 1}, {}], 
        AncestralLineage[ 
        4, {0.27049717829601805, 0.62148251496456786}, {{}, {a, b, d}}, {
          0.018996439704686091, 1}, {}], 
        AncestralLineage[ 
        5, {0.4292570949591068, 0.45951657742311824}, {{a, b, d}, {}}, {
          0.018996439704686091, 1}, {}], 
        AncestralLineage[ 
        6, {0.4292570949591068, 0.45951657742311824}, {{}}, {1}, {}], 
        AncestralLineage[ 
        7, {0.45951657742311824, 0.64520367984716565}, {{a, b, d}, {}}, {
          0.018996439704686091, 1}, {}], 
        AncestralLineage[ 
        8, {0.62148251496456786, 0.64520367984716565}, {{c}, {a, b, c, d}}, {
          0.018996439704686091, 1}, {}], 
        AncestralLineage[ 
        9, {0.64520367984716565, 1.9706637158007017}, {{a, b, c, d}}, {
          1}, {}], 
        AncestralLineage[ 
        10, {1.9706637158007017, 2.2897969825533644}, {{a, b, c, d}, {}}, {
          0.93719810153633465, 1}, {}], 
        AncestralLineage[ 
        11, {1.9706637158007017, 2.118015261702507}, {{}, {a, b, c, d}}, {
          0.93719810153633465, 1}, {}], 
        AncestralLineage[ 
        12, {2.118015261702507, 2.3758569290340006}, {{}}, {1}, {}], 
        AncestralLineage[ 
        13, {2.118015261702507, 2.228204237719424}, {{}, {a, b, c, d}}, {
          0.93719810153633465, 1}, {}], 
        AncestralLineage[ 
        14, {2.228204237719424, 2.2897969825533644}, {{}}, {1}, {}], 
        AncestralLineage[ 
        15, {2.228204237719424, 2.3639104415829926}, {{}, {a, b, c, d}}, {
          0.93719810153633465, 1}, {}], 
        AncestralLineage[ 
        16, {2.2897969825533644, 2.3639104415829926}, {{a, b, c, d}, {}}, {
          0.93719810153633465, 1}, {}], 
        AncestralLineage[ 
        17, {2.3639104415829926, 2.458462043572085}, {{a, b, c, d}}, {1}, {}],
         
        AncestralLineage[ 
        18, {2.3758569290340006, 2.458462043572085}, {{}}, {1}, {}], 
        AncestralLineage[ 
        19, {2.3758569290340006, 2.4862026095016123}, {{}}, {1}, {}], 
        AncestralLineage[ 
        20, {2.458462043572085, 2.4862026095016123}, {{a, b, c, d}}, {1}, {}],
         
        AncestralLineage[ 
        21, {2.4862026095016123, 3.9524773177113115}, {{a, b, c, d}}, {
          1}, {}], 
        AncestralLineage[ 
        22, {3.9524773177113115, 4.0138506590066365}, {{a, b, c, d}, {}}, {
          0.98883751447983492, 1}, {}], 
        AncestralLineage[ 
        23, {3.9524773177113115, 4.0138506590066365}, {{}, {a, b, c, d}}, {
          0.98883751447983492, 1}, {}], 
        AncestralLineage[ 
        24, {4.0138506590066365, 5.7540904800752752}, {{a, b, c, d}}, {
          1}, {}], 
        AncestralLineage[ 
        25, {5.7540904800752752, 5.8356593067548443}, {{a, b, c, d}, {}}, {
          0.18912143960102942, 1}, {}], 
        AncestralLineage[ 
        26, {5.7540904800752752, 5.8356593067548443}, {{}, {a, b, c, d}}, {
          0.18912143960102942, 1}, {}], 
        AncestralLineage[ 
        27, {5.8356593067548443, 6.4604494260089078}, {{a, b, c, d}}, {
          1}, {}], 
        AncestralLineage[ 
        28, {6.4604494260089078, 7.0775598049183523}, {{a, b, c, d}, {}}, {
          0.35885002936128829, 1}, {}], 
        AncestralLineage[ 
        29, {6.4604494260089078, 7.0775598049183523}, {{}, {a, b, c, d}}, {
          0.35885002936128829, 1}, {}], 
        AncestralLineage[ 
        30, {7.0775598049183523, 9.3500560237994925}, {{a, b, c, d}}, {
          1}, {}], 
        AncestralLineage[ 
        31, {9.3500560237994925, 9.8894038967979672}, {{a, b, c, d}, {}}, {
          0.19223283439372979, 1}, {}], 
        AncestralLineage[ 
        32, {9.3500560237994925, 9.8894038967979672}, {{}, {a, b, c, d}}, {
          0.19223283439372979, 1}, {}], 
        AncestralLineage[ 33, {9.8894038967979672, 
          DirectedInfinity[ 1]}, {{a, b, c, d}}, {1}, {}]}],
      Editable->False]], "Print",
  CellLabel->"From In[122]:="],

Cell[BoxData[
    \({10.04865414492197`, 2, 0.27813911328582047`}\)], "Print",
  CellLabel->"From In[122]:="],

Cell[BoxData[
    InterpretationBox[\("Recombining "\[InvisibleSpace]33\[InvisibleSpace]"; \
current lineages "\[InvisibleSpace]{33}\),
      SequenceForm[ "Recombining ", 33, "; current lineages ", {33}],
      Editable->False]], "Print",
  CellLabel->"From In[122]:="],

Cell[BoxData[
    InterpretationBox[
      RowBox[{"\<\"G=\"\>", "\[InvisibleSpace]", 
        RowBox[{"{", 
          
          RowBox[{\(AncestralLineage[
              a, {0, 0.05710778878192141`}, {{a}}, {1}, {}]\), 
            ",", \(AncestralLineage[
              b, {0, 0.027696065882077705`}, {{b}}, {1}, {}]\), 
            ",", \(AncestralLineage[
              c, {0, 0.6214825149645679`}, {{c}}, {1}, {}]\), 
            ",", \(AncestralLineage[
              d, {0, 0.027696065882077705`}, {{d}}, {1}, {}]\), 
            ",", \(AncestralLineage[
              1, {0.027696065882077705`, 
                0.05710778878192141`}, {{b, d}}, {1}, {}]\), 
            ",", \(AncestralLineage[
              2, {0.05710778878192141`, 
                0.27049717829601805`}, {{a, b, d}}, {1}, {}]\), 
            ",", \(AncestralLineage[
              3, {0.27049717829601805`, 
                0.4292570949591068`}, {{a, b, d}, {}}, {0.01899643970468609`, 
                1}, {}]\), 
            ",", \(AncestralLineage[
              4, {0.27049717829601805`, 
                0.6214825149645679`}, {{}, {a, b, d}}, {0.01899643970468609`, 
                1}, {}]\), 
            ",", \(AncestralLineage[
              5, {0.4292570949591068`, 
                0.45951657742311824`}, {{a, b, 
                  d}, {}}, {0.01899643970468609`, 1}, {}]\), 
            ",", \(AncestralLineage[
              6, {0.4292570949591068`, 
                0.45951657742311824`}, {{}}, {1}, {}]\), 
            ",", \(AncestralLineage[
              7, {0.45951657742311824`, 
                0.6452036798471656`}, {{a, b, d}, {}}, {0.01899643970468609`, 
                1}, {}]\), 
            ",", \(AncestralLineage[
              8, {0.6214825149645679`, 
                0.6452036798471656`}, {{c}, {a, b, c, 
                  d}}, {0.01899643970468609`, 1}, {}]\), 
            ",", \(AncestralLineage[
              9, {0.6452036798471656`, 
                1.9706637158007017`}, {{a, b, c, d}}, {1}, {}]\), 
            ",", \(AncestralLineage[
              10, {1.9706637158007017`, 
                2.2897969825533644`}, {{a, b, c, 
                  d}, {}}, {0.9371981015363346`, 1}, {}]\), 
            ",", \(AncestralLineage[
              11, {1.9706637158007017`, 
                2.118015261702507`}, {{}, {a, b, c, 
                  d}}, {0.9371981015363346`, 1}, {}]\), 
            ",", \(AncestralLineage[
              12, {2.118015261702507`, 2.3758569290340006`}, {{}}, {1}, {}]\),
             ",", \(AncestralLineage[
              13, {2.118015261702507`, 
                2.228204237719424`}, {{}, {a, b, c, 
                  d}}, {0.9371981015363346`, 1}, {}]\), 
            ",", \(AncestralLineage[
              14, {2.228204237719424`, 2.2897969825533644`}, {{}}, {1}, {}]\),
             ",", \(AncestralLineage[
              15, {2.228204237719424`, 
                2.3639104415829926`}, {{}, {a, b, c, 
                  d}}, {0.9371981015363346`, 1}, {}]\), 
            ",", \(AncestralLineage[
              16, {2.2897969825533644`, 
                2.3639104415829926`}, {{a, b, c, 
                  d}, {}}, {0.9371981015363346`, 1}, {}]\), 
            ",", \(AncestralLineage[
              17, {2.3639104415829926`, 
                2.458462043572085`}, {{a, b, c, d}}, {1}, {}]\), 
            ",", \(AncestralLineage[
              18, {2.3758569290340006`, 2.458462043572085`}, {{}}, {1}, {}]\),
             ",", \(AncestralLineage[
              19, {2.3758569290340006`, 
                2.4862026095016123`}, {{}}, {1}, {}]\), 
            ",", \(AncestralLineage[
              20, {2.458462043572085`, 
                2.4862026095016123`}, {{a, b, c, d}}, {1}, {}]\), 
            ",", \(AncestralLineage[
              21, {2.4862026095016123`, 
                3.9524773177113115`}, {{a, b, c, d}}, {1}, {}]\), 
            ",", \(AncestralLineage[
              22, {3.9524773177113115`, 
                4.0138506590066365`}, {{a, b, c, 
                  d}, {}}, {0.9888375144798349`, 1}, {}]\), 
            ",", \(AncestralLineage[
              23, {3.9524773177113115`, 
                4.0138506590066365`}, {{}, {a, b, c, 
                  d}}, {0.9888375144798349`, 1}, {}]\), 
            ",", \(AncestralLineage[
              24, {4.0138506590066365`, 
                5.754090480075275`}, {{a, b, c, d}}, {1}, {}]\), 
            ",", \(AncestralLineage[
              25, {5.754090480075275`, 
                5.835659306754844`}, {{a, b, c, 
                  d}, {}}, {0.18912143960102942`, 1}, {}]\), 
            ",", \(AncestralLineage[
              26, {5.754090480075275`, 
                5.835659306754844`}, {{}, {a, b, c, 
                  d}}, {0.18912143960102942`, 1}, {}]\), 
            ",", \(AncestralLineage[
              27, {5.835659306754844`, 
                6.460449426008908`}, {{a, b, c, d}}, {1}, {}]\), 
            ",", \(AncestralLineage[
              28, {6.460449426008908`, 
                7.077559804918352`}, {{a, b, c, 
                  d}, {}}, {0.3588500293612883`, 1}, {}]\), 
            ",", \(AncestralLineage[
              29, {6.460449426008908`, 
                7.077559804918352`}, {{}, {a, b, c, 
                  d}}, {0.3588500293612883`, 1}, {}]\), 
            ",", \(AncestralLineage[
              30, {7.077559804918352`, 
                9.350056023799493`}, {{a, b, c, d}}, {1}, {}]\), 
            ",", \(AncestralLineage[
              31, {9.350056023799493`, 
                9.889403896797967`}, {{a, b, c, 
                  d}, {}}, {0.1922328343937298`, 1}, {}]\), 
            ",", \(AncestralLineage[
              32, {9.350056023799493`, 
                9.889403896797967`}, {{}, {a, b, c, 
                  d}}, {0.1922328343937298`, 1}, {}]\), 
            ",", \(AncestralLineage[
              33, {9.889403896797967`, 
                10.04865414492197`}, {{a, b, c, d}}, {1}, {}]\), ",", 
            RowBox[{"AncestralLineage", "[", 
              RowBox[{"34", ",", 
                RowBox[{"{", 
                  RowBox[{"10.04865414492197`", ",", 
                    InterpretationBox["\[Infinity]",
                      DirectedInfinity[ 1]]}], "}"}], 
                ",", \({{a, b, c, d}, {}}\), 
                ",", \({0.27813911328582047`, 1}\), ",", \({}\)}], "]"}], ",",
             
            RowBox[{"AncestralLineage", "[", 
              RowBox[{"35", ",", 
                RowBox[{"{", 
                  RowBox[{"10.04865414492197`", ",", 
                    InterpretationBox["\[Infinity]",
                      DirectedInfinity[ 1]]}], "}"}], 
                ",", \({{}, {a, b, c, d}}\), 
                ",", \({0.27813911328582047`, 1}\), ",", \({}\)}], "]"}]}], 
          "}"}]}],
      SequenceForm[ "G=", {
        AncestralLineage[ a, {0, 0.057107788781921409}, {{a}}, {1}, {}], 
        AncestralLineage[ b, {0, 0.027696065882077705}, {{b}}, {1}, {}], 
        AncestralLineage[ c, {0, 0.62148251496456786}, {{c}}, {1}, {}], 
        AncestralLineage[ d, {0, 0.027696065882077705}, {{d}}, {1}, {}], 
        AncestralLineage[ 
        1, {0.027696065882077705, 0.057107788781921409}, {{b, d}}, {1}, {}], 
        AncestralLineage[ 
        2, {0.057107788781921409, 0.27049717829601805}, {{a, b, d}}, {1}, {}],
         
        AncestralLineage[ 
        3, {0.27049717829601805, 0.4292570949591068}, {{a, b, d}, {}}, {
          0.018996439704686091, 1}, {}], 
        AncestralLineage[ 
        4, {0.27049717829601805, 0.62148251496456786}, {{}, {a, b, d}}, {
          0.018996439704686091, 1}, {}], 
        AncestralLineage[ 
        5, {0.4292570949591068, 0.45951657742311824}, {{a, b, d}, {}}, {
          0.018996439704686091, 1}, {}], 
        AncestralLineage[ 
        6, {0.4292570949591068, 0.45951657742311824}, {{}}, {1}, {}], 
        AncestralLineage[ 
        7, {0.45951657742311824, 0.64520367984716565}, {{a, b, d}, {}}, {
          0.018996439704686091, 1}, {}], 
        AncestralLineage[ 
        8, {0.62148251496456786, 0.64520367984716565}, {{c}, {a, b, c, d}}, {
          0.018996439704686091, 1}, {}], 
        AncestralLineage[ 
        9, {0.64520367984716565, 1.9706637158007017}, {{a, b, c, d}}, {
          1}, {}], 
        AncestralLineage[ 
        10, {1.9706637158007017, 2.2897969825533644}, {{a, b, c, d}, {}}, {
          0.93719810153633465, 1}, {}], 
        AncestralLineage[ 
        11, {1.9706637158007017, 2.118015261702507}, {{}, {a, b, c, d}}, {
          0.93719810153633465, 1}, {}], 
        AncestralLineage[ 
        12, {2.118015261702507, 2.3758569290340006}, {{}}, {1}, {}], 
        AncestralLineage[ 
        13, {2.118015261702507, 2.228204237719424}, {{}, {a, b, c, d}}, {
          0.93719810153633465, 1}, {}], 
        AncestralLineage[ 
        14, {2.228204237719424, 2.2897969825533644}, {{}}, {1}, {}], 
        AncestralLineage[ 
        15, {2.228204237719424, 2.3639104415829926}, {{}, {a, b, c, d}}, {
          0.93719810153633465, 1}, {}], 
        AncestralLineage[ 
        16, {2.2897969825533644, 2.3639104415829926}, {{a, b, c, d}, {}}, {
          0.93719810153633465, 1}, {}], 
        AncestralLineage[ 
        17, {2.3639104415829926, 2.458462043572085}, {{a, b, c, d}}, {1}, {}],
         
        AncestralLineage[ 
        18, {2.3758569290340006, 2.458462043572085}, {{}}, {1}, {}], 
        AncestralLineage[ 
        19, {2.3758569290340006, 2.4862026095016123}, {{}}, {1}, {}], 
        AncestralLineage[ 
        20, {2.458462043572085, 2.4862026095016123}, {{a, b, c, d}}, {1}, {}],
         
        AncestralLineage[ 
        21, {2.4862026095016123, 3.9524773177113115}, {{a, b, c, d}}, {
          1}, {}], 
        AncestralLineage[ 
        22, {3.9524773177113115, 4.0138506590066365}, {{a, b, c, d}, {}}, {
          0.98883751447983492, 1}, {}], 
        AncestralLineage[ 
        23, {3.9524773177113115, 4.0138506590066365}, {{}, {a, b, c, d}}, {
          0.98883751447983492, 1}, {}], 
        AncestralLineage[ 
        24, {4.0138506590066365, 5.7540904800752752}, {{a, b, c, d}}, {
          1}, {}], 
        AncestralLineage[ 
        25, {5.7540904800752752, 5.8356593067548443}, {{a, b, c, d}, {}}, {
          0.18912143960102942, 1}, {}], 
        AncestralLineage[ 
        26, {5.7540904800752752, 5.8356593067548443}, {{}, {a, b, c, d}}, {
          0.18912143960102942, 1}, {}], 
        AncestralLineage[ 
        27, {5.8356593067548443, 6.4604494260089078}, {{a, b, c, d}}, {
          1}, {}], 
        AncestralLineage[ 
        28, {6.4604494260089078, 7.0775598049183523}, {{a, b, c, d}, {}}, {
          0.35885002936128829, 1}, {}], 
        AncestralLineage[ 
        29, {6.4604494260089078, 7.0775598049183523}, {{}, {a, b, c, d}}, {
          0.35885002936128829, 1}, {}], 
        AncestralLineage[ 
        30, {7.0775598049183523, 9.3500560237994925}, {{a, b, c, d}}, {
          1}, {}], 
        AncestralLineage[ 
        31, {9.3500560237994925, 9.8894038967979672}, {{a, b, c, d}, {}}, {
          0.19223283439372979, 1}, {}], 
        AncestralLineage[ 
        32, {9.3500560237994925, 9.8894038967979672}, {{}, {a, b, c, d}}, {
          0.19223283439372979, 1}, {}], 
        AncestralLineage[ 
        33, {9.8894038967979672, 10.04865414492197}, {{a, b, c, d}}, {1}, {}],
         
        AncestralLineage[ 34, {10.04865414492197, 
          DirectedInfinity[ 1]}, {{a, b, c, d}, {}}, {0.27813911328582047, 
          1}, {}], 
        AncestralLineage[ 35, {10.04865414492197, 
          DirectedInfinity[ 1]}, {{}, {a, b, c, d}}, {0.27813911328582047, 
          1}, {}]}],
      Editable->False]], "Print",
  CellLabel->"From In[122]:="],

Cell[BoxData[
    \({10.957847529079562`, 3, 0.8704634759549755`}\)], "Print",
  CellLabel->"From In[122]:="],

Cell[BoxData[
    InterpretationBox[\("Recombining "\[InvisibleSpace]34\[InvisibleSpace]"; \
current lineages "\[InvisibleSpace]{34, 35}\),
      SequenceForm[ "Recombining ", 34, "; current lineages ", {34, 35}],
      Editable->False]], "Print",
  CellLabel->"From In[122]:="],

Cell[BoxData[
    InterpretationBox[
      RowBox[{"\<\"G=\"\>", "\[InvisibleSpace]", 
        RowBox[{"{", 
          
          RowBox[{\(AncestralLineage[
              a, {0, 0.05710778878192141`}, {{a}}, {1}, {}]\), 
            ",", \(AncestralLineage[
              b, {0, 0.027696065882077705`}, {{b}}, {1}, {}]\), 
            ",", \(AncestralLineage[
              c, {0, 0.6214825149645679`}, {{c}}, {1}, {}]\), 
            ",", \(AncestralLineage[
              d, {0, 0.027696065882077705`}, {{d}}, {1}, {}]\), 
            ",", \(AncestralLineage[
              1, {0.027696065882077705`, 
                0.05710778878192141`}, {{b, d}}, {1}, {}]\), 
            ",", \(AncestralLineage[
              2, {0.05710778878192141`, 
                0.27049717829601805`}, {{a, b, d}}, {1}, {}]\), 
            ",", \(AncestralLineage[
              3, {0.27049717829601805`, 
                0.4292570949591068`}, {{a, b, d}, {}}, {0.01899643970468609`, 
                1}, {}]\), 
            ",", \(AncestralLineage[
              4, {0.27049717829601805`, 
                0.6214825149645679`}, {{}, {a, b, d}}, {0.01899643970468609`, 
                1}, {}]\), 
            ",", \(AncestralLineage[
              5, {0.4292570949591068`, 
                0.45951657742311824`}, {{a, b, 
                  d}, {}}, {0.01899643970468609`, 1}, {}]\), 
            ",", \(AncestralLineage[
              6, {0.4292570949591068`, 
                0.45951657742311824`}, {{}}, {1}, {}]\), 
            ",", \(AncestralLineage[
              7, {0.45951657742311824`, 
                0.6452036798471656`}, {{a, b, d}, {}}, {0.01899643970468609`, 
                1}, {}]\), 
            ",", \(AncestralLineage[
              8, {0.6214825149645679`, 
                0.6452036798471656`}, {{c}, {a, b, c, 
                  d}}, {0.01899643970468609`, 1}, {}]\), 
            ",", \(AncestralLineage[
              9, {0.6452036798471656`, 
                1.9706637158007017`}, {{a, b, c, d}}, {1}, {}]\), 
            ",", \(AncestralLineage[
              10, {1.9706637158007017`, 
                2.2897969825533644`}, {{a, b, c, 
                  d}, {}}, {0.9371981015363346`, 1}, {}]\), 
            ",", \(AncestralLineage[
              11, {1.9706637158007017`, 
                2.118015261702507`}, {{}, {a, b, c, 
                  d}}, {0.9371981015363346`, 1}, {}]\), 
            ",", \(AncestralLineage[
              12, {2.118015261702507`, 2.3758569290340006`}, {{}}, {1}, {}]\),
             ",", \(AncestralLineage[
              13, {2.118015261702507`, 
                2.228204237719424`}, {{}, {a, b, c, 
                  d}}, {0.9371981015363346`, 1}, {}]\), 
            ",", \(AncestralLineage[
              14, {2.228204237719424`, 2.2897969825533644`}, {{}}, {1}, {}]\),
             ",", \(AncestralLineage[
              15, {2.228204237719424`, 
                2.3639104415829926`}, {{}, {a, b, c, 
                  d}}, {0.9371981015363346`, 1}, {}]\), 
            ",", \(AncestralLineage[
              16, {2.2897969825533644`, 
                2.3639104415829926`}, {{a, b, c, 
                  d}, {}}, {0.9371981015363346`, 1}, {}]\), 
            ",", \(AncestralLineage[
              17, {2.3639104415829926`, 
                2.458462043572085`}, {{a, b, c, d}}, {1}, {}]\), 
            ",", \(AncestralLineage[
              18, {2.3758569290340006`, 2.458462043572085`}, {{}}, {1}, {}]\),
             ",", \(AncestralLineage[
              19, {2.3758569290340006`, 
                2.4862026095016123`}, {{}}, {1}, {}]\), 
            ",", \(AncestralLineage[
              20, {2.458462043572085`, 
                2.4862026095016123`}, {{a, b, c, d}}, {1}, {}]\), 
            ",", \(AncestralLineage[
              21, {2.4862026095016123`, 
                3.9524773177113115`}, {{a, b, c, d}}, {1}, {}]\), 
            ",", \(AncestralLineage[
              22, {3.9524773177113115`, 
                4.0138506590066365`}, {{a, b, c, 
                  d}, {}}, {0.9888375144798349`, 1}, {}]\), 
            ",", \(AncestralLineage[
              23, {3.9524773177113115`, 
                4.0138506590066365`}, {{}, {a, b, c, 
                  d}}, {0.9888375144798349`, 1}, {}]\), 
            ",", \(AncestralLineage[
              24, {4.0138506590066365`, 
                5.754090480075275`}, {{a, b, c, d}}, {1}, {}]\), 
            ",", \(AncestralLineage[
              25, {5.754090480075275`, 
                5.835659306754844`}, {{a, b, c, 
                  d}, {}}, {0.18912143960102942`, 1}, {}]\), 
            ",", \(AncestralLineage[
              26, {5.754090480075275`, 
                5.835659306754844`}, {{}, {a, b, c, 
                  d}}, {0.18912143960102942`, 1}, {}]\), 
            ",", \(AncestralLineage[
              27, {5.835659306754844`, 
                6.460449426008908`}, {{a, b, c, d}}, {1}, {}]\), 
            ",", \(AncestralLineage[
              28, {6.460449426008908`, 
                7.077559804918352`}, {{a, b, c, 
                  d}, {}}, {0.3588500293612883`, 1}, {}]\), 
            ",", \(AncestralLineage[
              29, {6.460449426008908`, 
                7.077559804918352`}, {{}, {a, b, c, 
                  d}}, {0.3588500293612883`, 1}, {}]\), 
            ",", \(AncestralLineage[
              30, {7.077559804918352`, 
                9.350056023799493`}, {{a, b, c, d}}, {1}, {}]\), 
            ",", \(AncestralLineage[
              31, {9.350056023799493`, 
                9.889403896797967`}, {{a, b, c, 
                  d}, {}}, {0.1922328343937298`, 1}, {}]\), 
            ",", \(AncestralLineage[
              32, {9.350056023799493`, 
                9.889403896797967`}, {{}, {a, b, c, 
                  d}}, {0.1922328343937298`, 1}, {}]\), 
            ",", \(AncestralLineage[
              33, {9.889403896797967`, 
                10.04865414492197`}, {{a, b, c, d}}, {1}, {}]\), 
            ",", \(AncestralLineage[
              34, {10.04865414492197`, 
                10.957847529079562`}, {{a, b, c, 
                  d}, {}}, {0.27813911328582047`, 1}, {}]\), ",", 
            RowBox[{"AncestralLineage", "[", 
              RowBox[{"35", ",", 
                RowBox[{"{", 
                  RowBox[{"10.04865414492197`", ",", 
                    InterpretationBox["\[Infinity]",
                      DirectedInfinity[ 1]]}], "}"}], 
                ",", \({{}, {a, b, c, d}}\), 
                ",", \({0.27813911328582047`, 1}\), ",", \({}\)}], "]"}], ",",
             
            RowBox[{"AncestralLineage", "[", 
              RowBox[{"36", ",", 
                RowBox[{"{", 
                  RowBox[{"10.957847529079562`", ",", 
                    InterpretationBox["\[Infinity]",
                      DirectedInfinity[ 1]]}], "}"}], 
                ",", \({{a, b, c, d}, {}}\), 
                ",", \({0.27813911328582047`, 1}\), ",", \({}\)}], "]"}], ",",
             
            RowBox[{"AncestralLineage", "[", 
              RowBox[{"37", ",", 
                RowBox[{"{", 
                  RowBox[{"10.957847529079562`", ",", 
                    InterpretationBox["\[Infinity]",
                      DirectedInfinity[ 1]]}], "}"}], ",", \({{}}\), 
                ",", \({1}\), ",", \({}\)}], "]"}]}], "}"}]}],
      SequenceForm[ "G=", {
        AncestralLineage[ a, {0, 0.057107788781921409}, {{a}}, {1}, {}], 
        AncestralLineage[ b, {0, 0.027696065882077705}, {{b}}, {1}, {}], 
        AncestralLineage[ c, {0, 0.62148251496456786}, {{c}}, {1}, {}], 
        AncestralLineage[ d, {0, 0.027696065882077705}, {{d}}, {1}, {}], 
        AncestralLineage[ 
        1, {0.027696065882077705, 0.057107788781921409}, {{b, d}}, {1}, {}], 
        AncestralLineage[ 
        2, {0.057107788781921409, 0.27049717829601805}, {{a, b, d}}, {1}, {}],
         
        AncestralLineage[ 
        3, {0.27049717829601805, 0.4292570949591068}, {{a, b, d}, {}}, {
          0.018996439704686091, 1}, {}], 
        AncestralLineage[ 
        4, {0.27049717829601805, 0.62148251496456786}, {{}, {a, b, d}}, {
          0.018996439704686091, 1}, {}], 
        AncestralLineage[ 
        5, {0.4292570949591068, 0.45951657742311824}, {{a, b, d}, {}}, {
          0.018996439704686091, 1}, {}], 
        AncestralLineage[ 
        6, {0.4292570949591068, 0.45951657742311824}, {{}}, {1}, {}], 
        AncestralLineage[ 
        7, {0.45951657742311824, 0.64520367984716565}, {{a, b, d}, {}}, {
          0.018996439704686091, 1}, {}], 
        AncestralLineage[ 
        8, {0.62148251496456786, 0.64520367984716565}, {{c}, {a, b, c, d}}, {
          0.018996439704686091, 1}, {}], 
        AncestralLineage[ 
        9, {0.64520367984716565, 1.9706637158007017}, {{a, b, c, d}}, {
          1}, {}], 
        AncestralLineage[ 
        10, {1.9706637158007017, 2.2897969825533644}, {{a, b, c, d}, {}}, {
          0.93719810153633465, 1}, {}], 
        AncestralLineage[ 
        11, {1.9706637158007017, 2.118015261702507}, {{}, {a, b, c, d}}, {
          0.93719810153633465, 1}, {}], 
        AncestralLineage[ 
        12, {2.118015261702507, 2.3758569290340006}, {{}}, {1}, {}], 
        AncestralLineage[ 
        13, {2.118015261702507, 2.228204237719424}, {{}, {a, b, c, d}}, {
          0.93719810153633465, 1}, {}], 
        AncestralLineage[ 
        14, {2.228204237719424, 2.2897969825533644}, {{}}, {1}, {}], 
        AncestralLineage[ 
        15, {2.228204237719424, 2.3639104415829926}, {{}, {a, b, c, d}}, {
          0.93719810153633465, 1}, {}], 
        AncestralLineage[ 
        16, {2.2897969825533644, 2.3639104415829926}, {{a, b, c, d}, {}}, {
          0.93719810153633465, 1}, {}], 
        AncestralLineage[ 
        17, {2.3639104415829926, 2.458462043572085}, {{a, b, c, d}}, {1}, {}],
         
        AncestralLineage[ 
        18, {2.3758569290340006, 2.458462043572085}, {{}}, {1}, {}], 
        AncestralLineage[ 
        19, {2.3758569290340006, 2.4862026095016123}, {{}}, {1}, {}], 
        AncestralLineage[ 
        20, {2.458462043572085, 2.4862026095016123}, {{a, b, c, d}}, {1}, {}],
         
        AncestralLineage[ 
        21, {2.4862026095016123, 3.9524773177113115}, {{a, b, c, d}}, {
          1}, {}], 
        AncestralLineage[ 
        22, {3.9524773177113115, 4.0138506590066365}, {{a, b, c, d}, {}}, {
          0.98883751447983492, 1}, {}], 
        AncestralLineage[ 
        23, {3.9524773177113115, 4.0138506590066365}, {{}, {a, b, c, d}}, {
          0.98883751447983492, 1}, {}], 
        AncestralLineage[ 
        24, {4.0138506590066365, 5.7540904800752752}, {{a, b, c, d}}, {
          1}, {}], 
        AncestralLineage[ 
        25, {5.7540904800752752, 5.8356593067548443}, {{a, b, c, d}, {}}, {
          0.18912143960102942, 1}, {}], 
        AncestralLineage[ 
        26, {5.7540904800752752, 5.8356593067548443}, {{}, {a, b, c, d}}, {
          0.18912143960102942, 1}, {}], 
        AncestralLineage[ 
        27, {5.8356593067548443, 6.4604494260089078}, {{a, b, c, d}}, {
          1}, {}], 
        AncestralLineage[ 
        28, {6.4604494260089078, 7.0775598049183523}, {{a, b, c, d}, {}}, {
          0.35885002936128829, 1}, {}], 
        AncestralLineage[ 
        29, {6.4604494260089078, 7.0775598049183523}, {{}, {a, b, c, d}}, {
          0.35885002936128829, 1}, {}], 
        AncestralLineage[ 
        30, {7.0775598049183523, 9.3500560237994925}, {{a, b, c, d}}, {
          1}, {}], 
        AncestralLineage[ 
        31, {9.3500560237994925, 9.8894038967979672}, {{a, b, c, d}, {}}, {
          0.19223283439372979, 1}, {}], 
        AncestralLineage[ 
        32, {9.3500560237994925, 9.8894038967979672}, {{}, {a, b, c, d}}, {
          0.19223283439372979, 1}, {}], 
        AncestralLineage[ 
        33, {9.8894038967979672, 10.04865414492197}, {{a, b, c, d}}, {1}, {}],
         
        AncestralLineage[ 
        34, {10.04865414492197, 10.957847529079562}, {{a, b, c, d}, {}}, {
          0.27813911328582047, 1}, {}], 
        AncestralLineage[ 35, {10.04865414492197, 
          DirectedInfinity[ 1]}, {{}, {a, b, c, d}}, {0.27813911328582047, 
          1}, {}], 
        AncestralLineage[ 36, {10.957847529079562, 
          DirectedInfinity[ 1]}, {{a, b, c, d}, {}}, {0.27813911328582047, 
          1}, {}], 
        AncestralLineage[ 37, {10.957847529079562, 
          DirectedInfinity[ 1]}, {{}}, {1}, {}]}],
      Editable->False]], "Print",
  CellLabel->"From In[122]:="],

Cell[BoxData[
    \({11.164561785838144`, 4, 0.6568963889868111`}\)], "Print",
  CellLabel->"From In[122]:="],

Cell[BoxData[
    InterpretationBox[\("Recombining "\[InvisibleSpace]36\[InvisibleSpace]"; \
current lineages "\[InvisibleSpace]{35, 36, 37}\),
      SequenceForm[ "Recombining ", 36, "; current lineages ", {35, 36, 37}],
      Editable->False]], "Print",
  CellLabel->"From In[122]:="],

Cell[BoxData[
    InterpretationBox[
      RowBox[{"\<\"G=\"\>", "\[InvisibleSpace]", 
        RowBox[{"{", 
          
          RowBox[{\(AncestralLineage[
              a, {0, 0.05710778878192141`}, {{a}}, {1}, {}]\), 
            ",", \(AncestralLineage[
              b, {0, 0.027696065882077705`}, {{b}}, {1}, {}]\), 
            ",", \(AncestralLineage[
              c, {0, 0.6214825149645679`}, {{c}}, {1}, {}]\), 
            ",", \(AncestralLineage[
              d, {0, 0.027696065882077705`}, {{d}}, {1}, {}]\), 
            ",", \(AncestralLineage[
              1, {0.027696065882077705`, 
                0.05710778878192141`}, {{b, d}}, {1}, {}]\), 
            ",", \(AncestralLineage[
              2, {0.05710778878192141`, 
                0.27049717829601805`}, {{a, b, d}}, {1}, {}]\), 
            ",", \(AncestralLineage[
              3, {0.27049717829601805`, 
                0.4292570949591068`}, {{a, b, d}, {}}, {0.01899643970468609`, 
                1}, {}]\), 
            ",", \(AncestralLineage[
              4, {0.27049717829601805`, 
                0.6214825149645679`}, {{}, {a, b, d}}, {0.01899643970468609`, 
                1}, {}]\), 
            ",", \(AncestralLineage[
              5, {0.4292570949591068`, 
                0.45951657742311824`}, {{a, b, 
                  d}, {}}, {0.01899643970468609`, 1}, {}]\), 
            ",", \(AncestralLineage[
              6, {0.4292570949591068`, 
                0.45951657742311824`}, {{}}, {1}, {}]\), 
            ",", \(AncestralLineage[
              7, {0.45951657742311824`, 
                0.6452036798471656`}, {{a, b, d}, {}}, {0.01899643970468609`, 
                1}, {}]\), 
            ",", \(AncestralLineage[
              8, {0.6214825149645679`, 
                0.6452036798471656`}, {{c}, {a, b, c, 
                  d}}, {0.01899643970468609`, 1}, {}]\), 
            ",", \(AncestralLineage[
              9, {0.6452036798471656`, 
                1.9706637158007017`}, {{a, b, c, d}}, {1}, {}]\), 
            ",", \(AncestralLineage[
              10, {1.9706637158007017`, 
                2.2897969825533644`}, {{a, b, c, 
                  d}, {}}, {0.9371981015363346`, 1}, {}]\), 
            ",", \(AncestralLineage[
              11, {1.9706637158007017`, 
                2.118015261702507`}, {{}, {a, b, c, 
                  d}}, {0.9371981015363346`, 1}, {}]\), 
            ",", \(AncestralLineage[
              12, {2.118015261702507`, 2.3758569290340006`}, {{}}, {1}, {}]\),
             ",", \(AncestralLineage[
              13, {2.118015261702507`, 
                2.228204237719424`}, {{}, {a, b, c, 
                  d}}, {0.9371981015363346`, 1}, {}]\), 
            ",", \(AncestralLineage[
              14, {2.228204237719424`, 2.2897969825533644`}, {{}}, {1}, {}]\),
             ",", \(AncestralLineage[
              15, {2.228204237719424`, 
                2.3639104415829926`}, {{}, {a, b, c, 
                  d}}, {0.9371981015363346`, 1}, {}]\), 
            ",", \(AncestralLineage[
              16, {2.2897969825533644`, 
                2.3639104415829926`}, {{a, b, c, 
                  d}, {}}, {0.9371981015363346`, 1}, {}]\), 
            ",", \(AncestralLineage[
              17, {2.3639104415829926`, 
                2.458462043572085`}, {{a, b, c, d}}, {1}, {}]\), 
            ",", \(AncestralLineage[
              18, {2.3758569290340006`, 2.458462043572085`}, {{}}, {1}, {}]\),
             ",", \(AncestralLineage[
              19, {2.3758569290340006`, 
                2.4862026095016123`}, {{}}, {1}, {}]\), 
            ",", \(AncestralLineage[
              20, {2.458462043572085`, 
                2.4862026095016123`}, {{a, b, c, d}}, {1}, {}]\), 
            ",", \(AncestralLineage[
              21, {2.4862026095016123`, 
                3.9524773177113115`}, {{a, b, c, d}}, {1}, {}]\), 
            ",", \(AncestralLineage[
              22, {3.9524773177113115`, 
                4.0138506590066365`}, {{a, b, c, 
                  d}, {}}, {0.9888375144798349`, 1}, {}]\), 
            ",", \(AncestralLineage[
              23, {3.9524773177113115`, 
                4.0138506590066365`}, {{}, {a, b, c, 
                  d}}, {0.9888375144798349`, 1}, {}]\), 
            ",", \(AncestralLineage[
              24, {4.0138506590066365`, 
                5.754090480075275`}, {{a, b, c, d}}, {1}, {}]\), 
            ",", \(AncestralLineage[
              25, {5.754090480075275`, 
                5.835659306754844`}, {{a, b, c, 
                  d}, {}}, {0.18912143960102942`, 1}, {}]\), 
            ",", \(AncestralLineage[
              26, {5.754090480075275`, 
                5.835659306754844`}, {{}, {a, b, c, 
                  d}}, {0.18912143960102942`, 1}, {}]\), 
            ",", \(AncestralLineage[
              27, {5.835659306754844`, 
                6.460449426008908`}, {{a, b, c, d}}, {1}, {}]\), 
            ",", \(AncestralLineage[
              28, {6.460449426008908`, 
                7.077559804918352`}, {{a, b, c, 
                  d}, {}}, {0.3588500293612883`, 1}, {}]\), 
            ",", \(AncestralLineage[
              29, {6.460449426008908`, 
                7.077559804918352`}, {{}, {a, b, c, 
                  d}}, {0.3588500293612883`, 1}, {}]\), 
            ",", \(AncestralLineage[
              30, {7.077559804918352`, 
                9.350056023799493`}, {{a, b, c, d}}, {1}, {}]\), 
            ",", \(AncestralLineage[
              31, {9.350056023799493`, 
                9.889403896797967`}, {{a, b, c, 
                  d}, {}}, {0.1922328343937298`, 1}, {}]\), 
            ",", \(AncestralLineage[
              32, {9.350056023799493`, 
                9.889403896797967`}, {{}, {a, b, c, 
                  d}}, {0.1922328343937298`, 1}, {}]\), 
            ",", \(AncestralLineage[
              33, {9.889403896797967`, 
                10.04865414492197`}, {{a, b, c, d}}, {1}, {}]\), 
            ",", \(AncestralLineage[
              34, {10.04865414492197`, 
                10.957847529079562`}, {{a, b, c, 
                  d}, {}}, {0.27813911328582047`, 1}, {}]\), ",", 
            RowBox[{"AncestralLineage", "[", 
              RowBox[{"35", ",", 
                RowBox[{"{", 
                  RowBox[{"10.04865414492197`", ",", 
                    InterpretationBox["\[Infinity]",
                      DirectedInfinity[ 1]]}], "}"}], 
                ",", \({{}, {a, b, c, d}}\), 
                ",", \({0.27813911328582047`, 1}\), ",", \({}\)}], "]"}], 
            ",", \(AncestralLineage[
              36, {10.957847529079562`, 
                11.164561785838144`}, {{a, b, c, 
                  d}, {}}, {0.27813911328582047`, 1}, {}]\), ",", 
            RowBox[{"AncestralLineage", "[", 
              RowBox[{"37", ",", 
                RowBox[{"{", 
                  RowBox[{"10.957847529079562`", ",", 
                    InterpretationBox["\[Infinity]",
                      DirectedInfinity[ 1]]}], "}"}], ",", \({{}}\), 
                ",", \({1}\), ",", \({}\)}], "]"}], ",", 
            RowBox[{"AncestralLineage", "[", 
              RowBox[{"38", ",", 
                RowBox[{"{", 
                  RowBox[{"11.164561785838144`", ",", 
                    InterpretationBox["\[Infinity]",
                      DirectedInfinity[ 1]]}], "}"}], 
                ",", \({{a, b, c, d}, {}}\), 
                ",", \({0.27813911328582047`, 1}\), ",", \({}\)}], "]"}], ",",
             
            RowBox[{"AncestralLineage", "[", 
              RowBox[{"39", ",", 
                RowBox[{"{", 
                  RowBox[{"11.164561785838144`", ",", 
                    InterpretationBox["\[Infinity]",
                      DirectedInfinity[ 1]]}], "}"}], ",", \({{}}\), 
                ",", \({1}\), ",", \({}\)}], "]"}]}], "}"}]}],
      SequenceForm[ "G=", {
        AncestralLineage[ a, {0, 0.057107788781921409}, {{a}}, {1}, {}], 
        AncestralLineage[ b, {0, 0.027696065882077705}, {{b}}, {1}, {}], 
        AncestralLineage[ c, {0, 0.62148251496456786}, {{c}}, {1}, {}], 
        AncestralLineage[ d, {0, 0.027696065882077705}, {{d}}, {1}, {}], 
        AncestralLineage[ 
        1, {0.027696065882077705, 0.057107788781921409}, {{b, d}}, {1}, {}], 
        AncestralLineage[ 
        2, {0.057107788781921409, 0.27049717829601805}, {{a, b, d}}, {1}, {}],
         
        AncestralLineage[ 
        3, {0.27049717829601805, 0.4292570949591068}, {{a, b, d}, {}}, {
          0.018996439704686091, 1}, {}], 
        AncestralLineage[ 
        4, {0.27049717829601805, 0.62148251496456786}, {{}, {a, b, d}}, {
          0.018996439704686091, 1}, {}], 
        AncestralLineage[ 
        5, {0.4292570949591068, 0.45951657742311824}, {{a, b, d}, {}}, {
          0.018996439704686091, 1}, {}], 
        AncestralLineage[ 
        6, {0.4292570949591068, 0.45951657742311824}, {{}}, {1}, {}], 
        AncestralLineage[ 
        7, {0.45951657742311824, 0.64520367984716565}, {{a, b, d}, {}}, {
          0.018996439704686091, 1}, {}], 
        AncestralLineage[ 
        8, {0.62148251496456786, 0.64520367984716565}, {{c}, {a, b, c, d}}, {
          0.018996439704686091, 1}, {}], 
        AncestralLineage[ 
        9, {0.64520367984716565, 1.9706637158007017}, {{a, b, c, d}}, {
          1}, {}], 
        AncestralLineage[ 
        10, {1.9706637158007017, 2.2897969825533644}, {{a, b, c, d}, {}}, {
          0.93719810153633465, 1}, {}], 
        AncestralLineage[ 
        11, {1.9706637158007017, 2.118015261702507}, {{}, {a, b, c, d}}, {
          0.93719810153633465, 1}, {}], 
        AncestralLineage[ 
        12, {2.118015261702507, 2.3758569290340006}, {{}}, {1}, {}], 
        AncestralLineage[ 
        13, {2.118015261702507, 2.228204237719424}, {{}, {a, b, c, d}}, {
          0.93719810153633465, 1}, {}], 
        AncestralLineage[ 
        14, {2.228204237719424, 2.2897969825533644}, {{}}, {1}, {}], 
        AncestralLineage[ 
        15, {2.228204237719424, 2.3639104415829926}, {{}, {a, b, c, d}}, {
          0.93719810153633465, 1}, {}], 
        AncestralLineage[ 
        16, {2.2897969825533644, 2.3639104415829926}, {{a, b, c, d}, {}}, {
          0.93719810153633465, 1}, {}], 
        AncestralLineage[ 
        17, {2.3639104415829926, 2.458462043572085}, {{a, b, c, d}}, {1}, {}],
         
        AncestralLineage[ 
        18, {2.3758569290340006, 2.458462043572085}, {{}}, {1}, {}], 
        AncestralLineage[ 
        19, {2.3758569290340006, 2.4862026095016123}, {{}}, {1}, {}], 
        AncestralLineage[ 
        20, {2.458462043572085, 2.4862026095016123}, {{a, b, c, d}}, {1}, {}],
         
        AncestralLineage[ 
        21, {2.4862026095016123, 3.9524773177113115}, {{a, b, c, d}}, {
          1}, {}], 
        AncestralLineage[ 
        22, {3.9524773177113115, 4.0138506590066365}, {{a, b, c, d}, {}}, {
          0.98883751447983492, 1}, {}], 
        AncestralLineage[ 
        23, {3.9524773177113115, 4.0138506590066365}, {{}, {a, b, c, d}}, {
          0.98883751447983492, 1}, {}], 
        AncestralLineage[ 
        24, {4.0138506590066365, 5.7540904800752752}, {{a, b, c, d}}, {
          1}, {}], 
        AncestralLineage[ 
        25, {5.7540904800752752, 5.8356593067548443}, {{a, b, c, d}, {}}, {
          0.18912143960102942, 1}, {}], 
        AncestralLineage[ 
        26, {5.7540904800752752, 5.8356593067548443}, {{}, {a, b, c, d}}, {
          0.18912143960102942, 1}, {}], 
        AncestralLineage[ 
        27, {5.8356593067548443, 6.4604494260089078}, {{a, b, c, d}}, {
          1}, {}], 
        AncestralLineage[ 
        28, {6.4604494260089078, 7.0775598049183523}, {{a, b, c, d}, {}}, {
          0.35885002936128829, 1}, {}], 
        AncestralLineage[ 
        29, {6.4604494260089078, 7.0775598049183523}, {{}, {a, b, c, d}}, {
          0.35885002936128829, 1}, {}], 
        AncestralLineage[ 
        30, {7.0775598049183523, 9.3500560237994925}, {{a, b, c, d}}, {
          1}, {}], 
        AncestralLineage[ 
        31, {9.3500560237994925, 9.8894038967979672}, {{a, b, c, d}, {}}, {
          0.19223283439372979, 1}, {}], 
        AncestralLineage[ 
        32, {9.3500560237994925, 9.8894038967979672}, {{}, {a, b, c, d}}, {
          0.19223283439372979, 1}, {}], 
        AncestralLineage[ 
        33, {9.8894038967979672, 10.04865414492197}, {{a, b, c, d}}, {1}, {}],
         
        AncestralLineage[ 
        34, {10.04865414492197, 10.957847529079562}, {{a, b, c, d}, {}}, {
          0.27813911328582047, 1}, {}], 
        AncestralLineage[ 35, {10.04865414492197, 
          DirectedInfinity[ 1]}, {{}, {a, b, c, d}}, {0.27813911328582047, 
          1}, {}], 
        AncestralLineage[ 
        36, {10.957847529079562, 11.164561785838144}, {{a, b, c, d}, {}}, {
          0.27813911328582047, 1}, {}], 
        AncestralLineage[ 37, {10.957847529079562, 
          DirectedInfinity[ 1]}, {{}}, {1}, {}], 
        AncestralLineage[ 38, {11.164561785838144, 
          DirectedInfinity[ 1]}, {{a, b, c, d}, {}}, {0.27813911328582047, 
          1}, {}], 
        AncestralLineage[ 39, {11.164561785838144, 
          DirectedInfinity[ 1]}, {{}}, {1}, {}]}],
      Editable->False]], "Print",
  CellLabel->"From In[122]:="],

Cell[BoxData[
    \({11.200948263910437`, 5, 0.044419904258408`}\)], "Print",
  CellLabel->"From In[122]:="],

Cell[BoxData[
    InterpretationBox[\("Recombining "\[InvisibleSpace]37\[InvisibleSpace]"; \
current lineages "\[InvisibleSpace]{35, 37, 38, 39}\),
      SequenceForm[ 
      "Recombining ", 37, "; current lineages ", {35, 37, 38, 39}],
      Editable->False]], "Print",
  CellLabel->"From In[122]:="],

Cell[BoxData[
    InterpretationBox[
      RowBox[{"\<\"G=\"\>", "\[InvisibleSpace]", 
        RowBox[{"{", 
          
          RowBox[{\(AncestralLineage[
              a, {0, 0.05710778878192141`}, {{a}}, {1}, {}]\), 
            ",", \(AncestralLineage[
              b, {0, 0.027696065882077705`}, {{b}}, {1}, {}]\), 
            ",", \(AncestralLineage[
              c, {0, 0.6214825149645679`}, {{c}}, {1}, {}]\), 
            ",", \(AncestralLineage[
              d, {0, 0.027696065882077705`}, {{d}}, {1}, {}]\), 
            ",", \(AncestralLineage[
              1, {0.027696065882077705`, 
                0.05710778878192141`}, {{b, d}}, {1}, {}]\), 
            ",", \(AncestralLineage[
              2, {0.05710778878192141`, 
                0.27049717829601805`}, {{a, b, d}}, {1}, {}]\), 
            ",", \(AncestralLineage[
              3, {0.27049717829601805`, 
                0.4292570949591068`}, {{a, b, d}, {}}, {0.01899643970468609`, 
                1}, {}]\), 
            ",", \(AncestralLineage[
              4, {0.27049717829601805`, 
                0.6214825149645679`}, {{}, {a, b, d}}, {0.01899643970468609`, 
                1}, {}]\), 
            ",", \(AncestralLineage[
              5, {0.4292570949591068`, 
                0.45951657742311824`}, {{a, b, 
                  d}, {}}, {0.01899643970468609`, 1}, {}]\), 
            ",", \(AncestralLineage[
              6, {0.4292570949591068`, 
                0.45951657742311824`}, {{}}, {1}, {}]\), 
            ",", \(AncestralLineage[
              7, {0.45951657742311824`, 
                0.6452036798471656`}, {{a, b, d}, {}}, {0.01899643970468609`, 
                1}, {}]\), 
            ",", \(AncestralLineage[
              8, {0.6214825149645679`, 
                0.6452036798471656`}, {{c}, {a, b, c, 
                  d}}, {0.01899643970468609`, 1}, {}]\), 
            ",", \(AncestralLineage[
              9, {0.6452036798471656`, 
                1.9706637158007017`}, {{a, b, c, d}}, {1}, {}]\), 
            ",", \(AncestralLineage[
              10, {1.9706637158007017`, 
                2.2897969825533644`}, {{a, b, c, 
                  d}, {}}, {0.9371981015363346`, 1}, {}]\), 
            ",", \(AncestralLineage[
              11, {1.9706637158007017`, 
                2.118015261702507`}, {{}, {a, b, c, 
                  d}}, {0.9371981015363346`, 1}, {}]\), 
            ",", \(AncestralLineage[
              12, {2.118015261702507`, 2.3758569290340006`}, {{}}, {1}, {}]\),
             ",", \(AncestralLineage[
              13, {2.118015261702507`, 
                2.228204237719424`}, {{}, {a, b, c, 
                  d}}, {0.9371981015363346`, 1}, {}]\), 
            ",", \(AncestralLineage[
              14, {2.228204237719424`, 2.2897969825533644`}, {{}}, {1}, {}]\),
             ",", \(AncestralLineage[
              15, {2.228204237719424`, 
                2.3639104415829926`}, {{}, {a, b, c, 
                  d}}, {0.9371981015363346`, 1}, {}]\), 
            ",", \(AncestralLineage[
              16, {2.2897969825533644`, 
                2.3639104415829926`}, {{a, b, c, 
                  d}, {}}, {0.9371981015363346`, 1}, {}]\), 
            ",", \(AncestralLineage[
              17, {2.3639104415829926`, 
                2.458462043572085`}, {{a, b, c, d}}, {1}, {}]\), 
            ",", \(AncestralLineage[
              18, {2.3758569290340006`, 2.458462043572085`}, {{}}, {1}, {}]\),
             ",", \(AncestralLineage[
              19, {2.3758569290340006`, 
                2.4862026095016123`}, {{}}, {1}, {}]\), 
            ",", \(AncestralLineage[
              20, {2.458462043572085`, 
                2.4862026095016123`}, {{a, b, c, d}}, {1}, {}]\), 
            ",", \(AncestralLineage[
              21, {2.4862026095016123`, 
                3.9524773177113115`}, {{a, b, c, d}}, {1}, {}]\), 
            ",", \(AncestralLineage[
              22, {3.9524773177113115`, 
                4.0138506590066365`}, {{a, b, c, 
                  d}, {}}, {0.9888375144798349`, 1}, {}]\), 
            ",", \(AncestralLineage[
              23, {3.9524773177113115`, 
                4.0138506590066365`}, {{}, {a, b, c, 
                  d}}, {0.9888375144798349`, 1}, {}]\), 
            ",", \(AncestralLineage[
              24, {4.0138506590066365`, 
                5.754090480075275`}, {{a, b, c, d}}, {1}, {}]\), 
            ",", \(AncestralLineage[
              25, {5.754090480075275`, 
                5.835659306754844`}, {{a, b, c, 
                  d}, {}}, {0.18912143960102942`, 1}, {}]\), 
            ",", \(AncestralLineage[
              26, {5.754090480075275`, 
                5.835659306754844`}, {{}, {a, b, c, 
                  d}}, {0.18912143960102942`, 1}, {}]\), 
            ",", \(AncestralLineage[
              27, {5.835659306754844`, 
                6.460449426008908`}, {{a, b, c, d}}, {1}, {}]\), 
            ",", \(AncestralLineage[
              28, {6.460449426008908`, 
                7.077559804918352`}, {{a, b, c, 
                  d}, {}}, {0.3588500293612883`, 1}, {}]\), 
            ",", \(AncestralLineage[
              29, {6.460449426008908`, 
                7.077559804918352`}, {{}, {a, b, c, 
                  d}}, {0.3588500293612883`, 1}, {}]\), 
            ",", \(AncestralLineage[
              30, {7.077559804918352`, 
                9.350056023799493`}, {{a, b, c, d}}, {1}, {}]\), 
            ",", \(AncestralLineage[
              31, {9.350056023799493`, 
                9.889403896797967`}, {{a, b, c, 
                  d}, {}}, {0.1922328343937298`, 1}, {}]\), 
            ",", \(AncestralLineage[
              32, {9.350056023799493`, 
                9.889403896797967`}, {{}, {a, b, c, 
                  d}}, {0.1922328343937298`, 1}, {}]\), 
            ",", \(AncestralLineage[
              33, {9.889403896797967`, 
                10.04865414492197`}, {{a, b, c, d}}, {1}, {}]\), 
            ",", \(AncestralLineage[
              34, {10.04865414492197`, 
                10.957847529079562`}, {{a, b, c, 
                  d}, {}}, {0.27813911328582047`, 1}, {}]\), ",", 
            RowBox[{"AncestralLineage", "[", 
              RowBox[{"35", ",", 
                RowBox[{"{", 
                  RowBox[{"10.04865414492197`", ",", 
                    InterpretationBox["\[Infinity]",
                      DirectedInfinity[ 1]]}], "}"}], 
                ",", \({{}, {a, b, c, d}}\), 
                ",", \({0.27813911328582047`, 1}\), ",", \({}\)}], "]"}], 
            ",", \(AncestralLineage[
              36, {10.957847529079562`, 
                11.164561785838144`}, {{a, b, c, 
                  d}, {}}, {0.27813911328582047`, 1}, {}]\), 
            ",", \(AncestralLineage[
              37, {10.957847529079562`, 
                11.200948263910437`}, {{}}, {1}, {}]\), ",", 
            RowBox[{"AncestralLineage", "[", 
              RowBox[{"38", ",", 
                RowBox[{"{", 
                  RowBox[{"11.164561785838144`", ",", 
                    InterpretationBox["\[Infinity]",
                      DirectedInfinity[ 1]]}], "}"}], 
                ",", \({{a, b, c, d}, {}}\), 
                ",", \({0.27813911328582047`, 1}\), ",", \({}\)}], "]"}], ",",
             
            RowBox[{"AncestralLineage", "[", 
              RowBox[{"39", ",", 
                RowBox[{"{", 
                  RowBox[{"11.164561785838144`", ",", 
                    InterpretationBox["\[Infinity]",
                      DirectedInfinity[ 1]]}], "}"}], ",", \({{}}\), 
                ",", \({1}\), ",", \({}\)}], "]"}], ",", 
            RowBox[{"AncestralLineage", "[", 
              RowBox[{"40", ",", 
                RowBox[{"{", 
                  RowBox[{"11.200948263910437`", ",", 
                    InterpretationBox["\[Infinity]",
                      DirectedInfinity[ 1]]}], "}"}], ",", \({{}}\), 
                ",", \({1}\), ",", \({}\)}], "]"}], ",", 
            RowBox[{"AncestralLineage", "[", 
              RowBox[{"41", ",", 
                RowBox[{"{", 
                  RowBox[{"11.200948263910437`", ",", 
                    InterpretationBox["\[Infinity]",
                      DirectedInfinity[ 1]]}], "}"}], ",", \({{}}\), 
                ",", \({1}\), ",", \({}\)}], "]"}]}], "}"}]}],
      SequenceForm[ "G=", {
        AncestralLineage[ a, {0, 0.057107788781921409}, {{a}}, {1}, {}], 
        AncestralLineage[ b, {0, 0.027696065882077705}, {{b}}, {1}, {}], 
        AncestralLineage[ c, {0, 0.62148251496456786}, {{c}}, {1}, {}], 
        AncestralLineage[ d, {0, 0.027696065882077705}, {{d}}, {1}, {}], 
        AncestralLineage[ 
        1, {0.027696065882077705, 0.057107788781921409}, {{b, d}}, {1}, {}], 
        AncestralLineage[ 
        2, {0.057107788781921409, 0.27049717829601805}, {{a, b, d}}, {1}, {}],
         
        AncestralLineage[ 
        3, {0.27049717829601805, 0.4292570949591068}, {{a, b, d}, {}}, {
          0.018996439704686091, 1}, {}], 
        AncestralLineage[ 
        4, {0.27049717829601805, 0.62148251496456786}, {{}, {a, b, d}}, {
          0.018996439704686091, 1}, {}], 
        AncestralLineage[ 
        5, {0.4292570949591068, 0.45951657742311824}, {{a, b, d}, {}}, {
          0.018996439704686091, 1}, {}], 
        AncestralLineage[ 
        6, {0.4292570949591068, 0.45951657742311824}, {{}}, {1}, {}], 
        AncestralLineage[ 
        7, {0.45951657742311824, 0.64520367984716565}, {{a, b, d}, {}}, {
          0.018996439704686091, 1}, {}], 
        AncestralLineage[ 
        8, {0.62148251496456786, 0.64520367984716565}, {{c}, {a, b, c, d}}, {
          0.018996439704686091, 1}, {}], 
        AncestralLineage[ 
        9, {0.64520367984716565, 1.9706637158007017}, {{a, b, c, d}}, {
          1}, {}], 
        AncestralLineage[ 
        10, {1.9706637158007017, 2.2897969825533644}, {{a, b, c, d}, {}}, {
          0.93719810153633465, 1}, {}], 
        AncestralLineage[ 
        11, {1.9706637158007017, 2.118015261702507}, {{}, {a, b, c, d}}, {
          0.93719810153633465, 1}, {}], 
        AncestralLineage[ 
        12, {2.118015261702507, 2.3758569290340006}, {{}}, {1}, {}], 
        AncestralLineage[ 
        13, {2.118015261702507, 2.228204237719424}, {{}, {a, b, c, d}}, {
          0.93719810153633465, 1}, {}], 
        AncestralLineage[ 
        14, {2.228204237719424, 2.2897969825533644}, {{}}, {1}, {}], 
        AncestralLineage[ 
        15, {2.228204237719424, 2.3639104415829926}, {{}, {a, b, c, d}}, {
          0.93719810153633465, 1}, {}], 
        AncestralLineage[ 
        16, {2.2897969825533644, 2.3639104415829926}, {{a, b, c, d}, {}}, {
          0.93719810153633465, 1}, {}], 
        AncestralLineage[ 
        17, {2.3639104415829926, 2.458462043572085}, {{a, b, c, d}}, {1}, {}],
         
        AncestralLineage[ 
        18, {2.3758569290340006, 2.458462043572085}, {{}}, {1}, {}], 
        AncestralLineage[ 
        19, {2.3758569290340006, 2.4862026095016123}, {{}}, {1}, {}], 
        AncestralLineage[ 
        20, {2.458462043572085, 2.4862026095016123}, {{a, b, c, d}}, {1}, {}],
         
        AncestralLineage[ 
        21, {2.4862026095016123, 3.9524773177113115}, {{a, b, c, d}}, {
          1}, {}], 
        AncestralLineage[ 
        22, {3.9524773177113115, 4.0138506590066365}, {{a, b, c, d}, {}}, {
          0.98883751447983492, 1}, {}], 
        AncestralLineage[ 
        23, {3.9524773177113115, 4.0138506590066365}, {{}, {a, b, c, d}}, {
          0.98883751447983492, 1}, {}], 
        AncestralLineage[ 
        24, {4.0138506590066365, 5.7540904800752752}, {{a, b, c, d}}, {
          1}, {}], 
        AncestralLineage[ 
        25, {5.7540904800752752, 5.8356593067548443}, {{a, b, c, d}, {}}, {
          0.18912143960102942, 1}, {}], 
        AncestralLineage[ 
        26, {5.7540904800752752, 5.8356593067548443}, {{}, {a, b, c, d}}, {
          0.18912143960102942, 1}, {}], 
        AncestralLineage[ 
        27, {5.8356593067548443, 6.4604494260089078}, {{a, b, c, d}}, {
          1}, {}], 
        AncestralLineage[ 
        28, {6.4604494260089078, 7.0775598049183523}, {{a, b, c, d}, {}}, {
          0.35885002936128829, 1}, {}], 
        AncestralLineage[ 
        29, {6.4604494260089078, 7.0775598049183523}, {{}, {a, b, c, d}}, {
          0.35885002936128829, 1}, {}], 
        AncestralLineage[ 
        30, {7.0775598049183523, 9.3500560237994925}, {{a, b, c, d}}, {
          1}, {}], 
        AncestralLineage[ 
        31, {9.3500560237994925, 9.8894038967979672}, {{a, b, c, d}, {}}, {
          0.19223283439372979, 1}, {}], 
        AncestralLineage[ 
        32, {9.3500560237994925, 9.8894038967979672}, {{}, {a, b, c, d}}, {
          0.19223283439372979, 1}, {}], 
        AncestralLineage[ 
        33, {9.8894038967979672, 10.04865414492197}, {{a, b, c, d}}, {1}, {}],
         
        AncestralLineage[ 
        34, {10.04865414492197, 10.957847529079562}, {{a, b, c, d}, {}}, {
          0.27813911328582047, 1}, {}], 
        AncestralLineage[ 35, {10.04865414492197, 
          DirectedInfinity[ 1]}, {{}, {a, b, c, d}}, {0.27813911328582047, 
          1}, {}], 
        AncestralLineage[ 
        36, {10.957847529079562, 11.164561785838144}, {{a, b, c, d}, {}}, {
          0.27813911328582047, 1}, {}], 
        AncestralLineage[ 
        37, {10.957847529079562, 11.200948263910437}, {{}}, {1}, {}], 
        AncestralLineage[ 38, {11.164561785838144, 
          DirectedInfinity[ 1]}, {{a, b, c, d}, {}}, {0.27813911328582047, 
          1}, {}], 
        AncestralLineage[ 39, {11.164561785838144, 
          DirectedInfinity[ 1]}, {{}}, {1}, {}], 
        AncestralLineage[ 40, {11.200948263910437, 
          DirectedInfinity[ 1]}, {{}}, {1}, {}], 
        AncestralLineage[ 41, {11.200948263910437, 
          DirectedInfinity[ 1]}, {{}}, {1}, {}]}],
      Editable->False]], "Print",
  CellLabel->"From In[122]:="],

Cell[BoxData[
    \({11.209929483491738`, 4, None}\)], "Print",
  CellLabel->"From In[122]:="],

Cell[BoxData[
    InterpretationBox[\("Coalescing "\[InvisibleSpace]{38, 
          40}\[InvisibleSpace]"; current lineages "\[InvisibleSpace]{35, 38, 
          39, 40, 41}\),
      SequenceForm[ 
      "Coalescing ", {38, 40}, "; current lineages ", {35, 38, 39, 40, 41}],
      Editable->False]], "Print",
  CellLabel->"From In[122]:="],

Cell[BoxData[
    InterpretationBox[
      RowBox[{"\<\"G=\"\>", "\[InvisibleSpace]", 
        RowBox[{"{", 
          
          RowBox[{\(AncestralLineage[
              a, {0, 0.05710778878192141`}, {{a}}, {1}, {}]\), 
            ",", \(AncestralLineage[
              b, {0, 0.027696065882077705`}, {{b}}, {1}, {}]\), 
            ",", \(AncestralLineage[
              c, {0, 0.6214825149645679`}, {{c}}, {1}, {}]\), 
            ",", \(AncestralLineage[
              d, {0, 0.027696065882077705`}, {{d}}, {1}, {}]\), 
            ",", \(AncestralLineage[
              1, {0.027696065882077705`, 
                0.05710778878192141`}, {{b, d}}, {1}, {}]\), 
            ",", \(AncestralLineage[
              2, {0.05710778878192141`, 
                0.27049717829601805`}, {{a, b, d}}, {1}, {}]\), 
            ",", \(AncestralLineage[
              3, {0.27049717829601805`, 
                0.4292570949591068`}, {{a, b, d}, {}}, {0.01899643970468609`, 
                1}, {}]\), 
            ",", \(AncestralLineage[
              4, {0.27049717829601805`, 
                0.6214825149645679`}, {{}, {a, b, d}}, {0.01899643970468609`, 
                1}, {}]\), 
            ",", \(AncestralLineage[
              5, {0.4292570949591068`, 
                0.45951657742311824`}, {{a, b, 
                  d}, {}}, {0.01899643970468609`, 1}, {}]\), 
            ",", \(AncestralLineage[
              6, {0.4292570949591068`, 
                0.45951657742311824`}, {{}}, {1}, {}]\), 
            ",", \(AncestralLineage[
              7, {0.45951657742311824`, 
                0.6452036798471656`}, {{a, b, d}, {}}, {0.01899643970468609`, 
                1}, {}]\), 
            ",", \(AncestralLineage[
              8, {0.6214825149645679`, 
                0.6452036798471656`}, {{c}, {a, b, c, 
                  d}}, {0.01899643970468609`, 1}, {}]\), 
            ",", \(AncestralLineage[
              9, {0.6452036798471656`, 
                1.9706637158007017`}, {{a, b, c, d}}, {1}, {}]\), 
            ",", \(AncestralLineage[
              10, {1.9706637158007017`, 
                2.2897969825533644`}, {{a, b, c, 
                  d}, {}}, {0.9371981015363346`, 1}, {}]\), 
            ",", \(AncestralLineage[
              11, {1.9706637158007017`, 
                2.118015261702507`}, {{}, {a, b, c, 
                  d}}, {0.9371981015363346`, 1}, {}]\), 
            ",", \(AncestralLineage[
              12, {2.118015261702507`, 2.3758569290340006`}, {{}}, {1}, {}]\),
             ",", \(AncestralLineage[
              13, {2.118015261702507`, 
                2.228204237719424`}, {{}, {a, b, c, 
                  d}}, {0.9371981015363346`, 1}, {}]\), 
            ",", \(AncestralLineage[
              14, {2.228204237719424`, 2.2897969825533644`}, {{}}, {1}, {}]\),
             ",", \(AncestralLineage[
              15, {2.228204237719424`, 
                2.3639104415829926`}, {{}, {a, b, c, 
                  d}}, {0.9371981015363346`, 1}, {}]\), 
            ",", \(AncestralLineage[
              16, {2.2897969825533644`, 
                2.3639104415829926`}, {{a, b, c, 
                  d}, {}}, {0.9371981015363346`, 1}, {}]\), 
            ",", \(AncestralLineage[
              17, {2.3639104415829926`, 
                2.458462043572085`}, {{a, b, c, d}}, {1}, {}]\), 
            ",", \(AncestralLineage[
              18, {2.3758569290340006`, 2.458462043572085`}, {{}}, {1}, {}]\),
             ",", \(AncestralLineage[
              19, {2.3758569290340006`, 
                2.4862026095016123`}, {{}}, {1}, {}]\), 
            ",", \(AncestralLineage[
              20, {2.458462043572085`, 
                2.4862026095016123`}, {{a, b, c, d}}, {1}, {}]\), 
            ",", \(AncestralLineage[
              21, {2.4862026095016123`, 
                3.9524773177113115`}, {{a, b, c, d}}, {1}, {}]\), 
            ",", \(AncestralLineage[
              22, {3.9524773177113115`, 
                4.0138506590066365`}, {{a, b, c, 
                  d}, {}}, {0.9888375144798349`, 1}, {}]\), 
            ",", \(AncestralLineage[
              23, {3.9524773177113115`, 
                4.0138506590066365`}, {{}, {a, b, c, 
                  d}}, {0.9888375144798349`, 1}, {}]\), 
            ",", \(AncestralLineage[
              24, {4.0138506590066365`, 
                5.754090480075275`}, {{a, b, c, d}}, {1}, {}]\), 
            ",", \(AncestralLineage[
              25, {5.754090480075275`, 
                5.835659306754844`}, {{a, b, c, 
                  d}, {}}, {0.18912143960102942`, 1}, {}]\), 
            ",", \(AncestralLineage[
              26, {5.754090480075275`, 
                5.835659306754844`}, {{}, {a, b, c, 
                  d}}, {0.18912143960102942`, 1}, {}]\), 
            ",", \(AncestralLineage[
              27, {5.835659306754844`, 
                6.460449426008908`}, {{a, b, c, d}}, {1}, {}]\), 
            ",", \(AncestralLineage[
              28, {6.460449426008908`, 
                7.077559804918352`}, {{a, b, c, 
                  d}, {}}, {0.3588500293612883`, 1}, {}]\), 
            ",", \(AncestralLineage[
              29, {6.460449426008908`, 
                7.077559804918352`}, {{}, {a, b, c, 
                  d}}, {0.3588500293612883`, 1}, {}]\), 
            ",", \(AncestralLineage[
              30, {7.077559804918352`, 
                9.350056023799493`}, {{a, b, c, d}}, {1}, {}]\), 
            ",", \(AncestralLineage[
              31, {9.350056023799493`, 
                9.889403896797967`}, {{a, b, c, 
                  d}, {}}, {0.1922328343937298`, 1}, {}]\), 
            ",", \(AncestralLineage[
              32, {9.350056023799493`, 
                9.889403896797967`}, {{}, {a, b, c, 
                  d}}, {0.1922328343937298`, 1}, {}]\), 
            ",", \(AncestralLineage[
              33, {9.889403896797967`, 
                10.04865414492197`}, {{a, b, c, d}}, {1}, {}]\), 
            ",", \(AncestralLineage[
              34, {10.04865414492197`, 
                10.957847529079562`}, {{a, b, c, 
                  d}, {}}, {0.27813911328582047`, 1}, {}]\), ",", 
            RowBox[{"AncestralLineage", "[", 
              RowBox[{"35", ",", 
                RowBox[{"{", 
                  RowBox[{"10.04865414492197`", ",", 
                    InterpretationBox["\[Infinity]",
                      DirectedInfinity[ 1]]}], "}"}], 
                ",", \({{}, {a, b, c, d}}\), 
                ",", \({0.27813911328582047`, 1}\), ",", \({}\)}], "]"}], 
            ",", \(AncestralLineage[
              36, {10.957847529079562`, 
                11.164561785838144`}, {{a, b, c, 
                  d}, {}}, {0.27813911328582047`, 1}, {}]\), 
            ",", \(AncestralLineage[
              37, {10.957847529079562`, 
                11.200948263910437`}, {{}}, {1}, {}]\), 
            ",", \(AncestralLineage[
              38, {11.164561785838144`, 
                11.209929483491738`}, {{a, b, c, 
                  d}, {}}, {0.27813911328582047`, 1}, {}]\), ",", 
            RowBox[{"AncestralLineage", "[", 
              RowBox[{"39", ",", 
                RowBox[{"{", 
                  RowBox[{"11.164561785838144`", ",", 
                    InterpretationBox["\[Infinity]",
                      DirectedInfinity[ 1]]}], "}"}], ",", \({{}}\), 
                ",", \({1}\), ",", \({}\)}], "]"}], 
            ",", \(AncestralLineage[
              40, {11.200948263910437`, 
                11.209929483491738`}, {{}}, {1}, {}]\), ",", 
            RowBox[{"AncestralLineage", "[", 
              RowBox[{"41", ",", 
                RowBox[{"{", 
                  RowBox[{"11.200948263910437`", ",", 
                    InterpretationBox["\[Infinity]",
                      DirectedInfinity[ 1]]}], "}"}], ",", \({{}}\), 
                ",", \({1}\), ",", \({}\)}], "]"}], ",", 
            RowBox[{"AncestralLineage", "[", 
              RowBox[{"42", ",", 
                RowBox[{"{", 
                  RowBox[{"11.209929483491738`", ",", 
                    InterpretationBox["\[Infinity]",
                      DirectedInfinity[ 1]]}], "}"}], 
                ",", \({{a, b, c, d}, {}}\), 
                ",", \({0.27813911328582047`, 1}\), ",", \({}\)}], "]"}]}], 
          "}"}]}],
      SequenceForm[ "G=", {
        AncestralLineage[ a, {0, 0.057107788781921409}, {{a}}, {1}, {}], 
        AncestralLineage[ b, {0, 0.027696065882077705}, {{b}}, {1}, {}], 
        AncestralLineage[ c, {0, 0.62148251496456786}, {{c}}, {1}, {}], 
        AncestralLineage[ d, {0, 0.027696065882077705}, {{d}}, {1}, {}], 
        AncestralLineage[ 
        1, {0.027696065882077705, 0.057107788781921409}, {{b, d}}, {1}, {}], 
        AncestralLineage[ 
        2, {0.057107788781921409, 0.27049717829601805}, {{a, b, d}}, {1}, {}],
         
        AncestralLineage[ 
        3, {0.27049717829601805, 0.4292570949591068}, {{a, b, d}, {}}, {
          0.018996439704686091, 1}, {}], 
        AncestralLineage[ 
        4, {0.27049717829601805, 0.62148251496456786}, {{}, {a, b, d}}, {
          0.018996439704686091, 1}, {}], 
        AncestralLineage[ 
        5, {0.4292570949591068, 0.45951657742311824}, {{a, b, d}, {}}, {
          0.018996439704686091, 1}, {}], 
        AncestralLineage[ 
        6, {0.4292570949591068, 0.45951657742311824}, {{}}, {1}, {}], 
        AncestralLineage[ 
        7, {0.45951657742311824, 0.64520367984716565}, {{a, b, d}, {}}, {
          0.018996439704686091, 1}, {}], 
        AncestralLineage[ 
        8, {0.62148251496456786, 0.64520367984716565}, {{c}, {a, b, c, d}}, {
          0.018996439704686091, 1}, {}], 
        AncestralLineage[ 
        9, {0.64520367984716565, 1.9706637158007017}, {{a, b, c, d}}, {
          1}, {}], 
        AncestralLineage[ 
        10, {1.9706637158007017, 2.2897969825533644}, {{a, b, c, d}, {}}, {
          0.93719810153633465, 1}, {}], 
        AncestralLineage[ 
        11, {1.9706637158007017, 2.118015261702507}, {{}, {a, b, c, d}}, {
          0.93719810153633465, 1}, {}], 
        AncestralLineage[ 
        12, {2.118015261702507, 2.3758569290340006}, {{}}, {1}, {}], 
        AncestralLineage[ 
        13, {2.118015261702507, 2.228204237719424}, {{}, {a, b, c, d}}, {
          0.93719810153633465, 1}, {}], 
        AncestralLineage[ 
        14, {2.228204237719424, 2.2897969825533644}, {{}}, {1}, {}], 
        AncestralLineage[ 
        15, {2.228204237719424, 2.3639104415829926}, {{}, {a, b, c, d}}, {
          0.93719810153633465, 1}, {}], 
        AncestralLineage[ 
        16, {2.2897969825533644, 2.3639104415829926}, {{a, b, c, d}, {}}, {
          0.93719810153633465, 1}, {}], 
        AncestralLineage[ 
        17, {2.3639104415829926, 2.458462043572085}, {{a, b, c, d}}, {1}, {}],
         
        AncestralLineage[ 
        18, {2.3758569290340006, 2.458462043572085}, {{}}, {1}, {}], 
        AncestralLineage[ 
        19, {2.3758569290340006, 2.4862026095016123}, {{}}, {1}, {}], 
        AncestralLineage[ 
        20, {2.458462043572085, 2.4862026095016123}, {{a, b, c, d}}, {1}, {}],
         
        AncestralLineage[ 
        21, {2.4862026095016123, 3.9524773177113115}, {{a, b, c, d}}, {
          1}, {}], 
        AncestralLineage[ 
        22, {3.9524773177113115, 4.0138506590066365}, {{a, b, c, d}, {}}, {
          0.98883751447983492, 1}, {}], 
        AncestralLineage[ 
        23, {3.9524773177113115, 4.0138506590066365}, {{}, {a, b, c, d}}, {
          0.98883751447983492, 1}, {}], 
        AncestralLineage[ 
        24, {4.0138506590066365, 5.7540904800752752}, {{a, b, c, d}}, {
          1}, {}], 
        AncestralLineage[ 
        25, {5.7540904800752752, 5.8356593067548443}, {{a, b, c, d}, {}}, {
          0.18912143960102942, 1}, {}], 
        AncestralLineage[ 
        26, {5.7540904800752752, 5.8356593067548443}, {{}, {a, b, c, d}}, {
          0.18912143960102942, 1}, {}], 
        AncestralLineage[ 
        27, {5.8356593067548443, 6.4604494260089078}, {{a, b, c, d}}, {
          1}, {}], 
        AncestralLineage[ 
        28, {6.4604494260089078, 7.0775598049183523}, {{a, b, c, d}, {}}, {
          0.35885002936128829, 1}, {}], 
        AncestralLineage[ 
        29, {6.4604494260089078, 7.0775598049183523}, {{}, {a, b, c, d}}, {
          0.35885002936128829, 1}, {}], 
        AncestralLineage[ 
        30, {7.0775598049183523, 9.3500560237994925}, {{a, b, c, d}}, {
          1}, {}], 
        AncestralLineage[ 
        31, {9.3500560237994925, 9.8894038967979672}, {{a, b, c, d}, {}}, {
          0.19223283439372979, 1}, {}], 
        AncestralLineage[ 
        32, {9.3500560237994925, 9.8894038967979672}, {{}, {a, b, c, d}}, {
          0.19223283439372979, 1}, {}], 
        AncestralLineage[ 
        33, {9.8894038967979672, 10.04865414492197}, {{a, b, c, d}}, {1}, {}],
         
        AncestralLineage[ 
        34, {10.04865414492197, 10.957847529079562}, {{a, b, c, d}, {}}, {
          0.27813911328582047, 1}, {}], 
        AncestralLineage[ 35, {10.04865414492197, 
          DirectedInfinity[ 1]}, {{}, {a, b, c, d}}, {0.27813911328582047, 
          1}, {}], 
        AncestralLineage[ 
        36, {10.957847529079562, 11.164561785838144}, {{a, b, c, d}, {}}, {
          0.27813911328582047, 1}, {}], 
        AncestralLineage[ 
        37, {10.957847529079562, 11.200948263910437}, {{}}, {1}, {}], 
        AncestralLineage[ 
        38, {11.164561785838144, 11.209929483491738}, {{a, b, c, d}, {}}, {
          0.27813911328582047, 1}, {}], 
        AncestralLineage[ 39, {11.164561785838144, 
          DirectedInfinity[ 1]}, {{}}, {1}, {}], 
        AncestralLineage[ 
        40, {11.200948263910437, 11.209929483491738}, {{}}, {1}, {}], 
        AncestralLineage[ 41, {11.200948263910437, 
          DirectedInfinity[ 1]}, {{}}, {1}, {}], 
        AncestralLineage[ 42, {11.209929483491738, 
          DirectedInfinity[ 1]}, {{a, b, c, d}, {}}, {0.27813911328582047, 
          1}, {}]}],
      Editable->False]], "Print",
  CellLabel->"From In[122]:="],

Cell[BoxData[
    \({11.245270596164165`, 5, 0.5151120482580364`}\)], "Print",
  CellLabel->"From In[122]:="],

Cell[BoxData[
    InterpretationBox[\("Recombining "\[InvisibleSpace]41\[InvisibleSpace]"; \
current lineages "\[InvisibleSpace]{35, 39, 41, 42}\),
      SequenceForm[ 
      "Recombining ", 41, "; current lineages ", {35, 39, 41, 42}],
      Editable->False]], "Print",
  CellLabel->"From In[122]:="],

Cell[BoxData[
    InterpretationBox[
      RowBox[{"\<\"G=\"\>", "\[InvisibleSpace]", 
        RowBox[{"{", 
          
          RowBox[{\(AncestralLineage[
              a, {0, 0.05710778878192141`}, {{a}}, {1}, {}]\), 
            ",", \(AncestralLineage[
              b, {0, 0.027696065882077705`}, {{b}}, {1}, {}]\), 
            ",", \(AncestralLineage[
              c, {0, 0.6214825149645679`}, {{c}}, {1}, {}]\), 
            ",", \(AncestralLineage[
              d, {0, 0.027696065882077705`}, {{d}}, {1}, {}]\), 
            ",", \(AncestralLineage[
              1, {0.027696065882077705`, 
                0.05710778878192141`}, {{b, d}}, {1}, {}]\), 
            ",", \(AncestralLineage[
              2, {0.05710778878192141`, 
                0.27049717829601805`}, {{a, b, d}}, {1}, {}]\), 
            ",", \(AncestralLineage[
              3, {0.27049717829601805`, 
                0.4292570949591068`}, {{a, b, d}, {}}, {0.01899643970468609`, 
                1}, {}]\), 
            ",", \(AncestralLineage[
              4, {0.27049717829601805`, 
                0.6214825149645679`}, {{}, {a, b, d}}, {0.01899643970468609`, 
                1}, {}]\), 
            ",", \(AncestralLineage[
              5, {0.4292570949591068`, 
                0.45951657742311824`}, {{a, b, 
                  d}, {}}, {0.01899643970468609`, 1}, {}]\), 
            ",", \(AncestralLineage[
              6, {0.4292570949591068`, 
                0.45951657742311824`}, {{}}, {1}, {}]\), 
            ",", \(AncestralLineage[
              7, {0.45951657742311824`, 
                0.6452036798471656`}, {{a, b, d}, {}}, {0.01899643970468609`, 
                1}, {}]\), 
            ",", \(AncestralLineage[
              8, {0.6214825149645679`, 
                0.6452036798471656`}, {{c}, {a, b, c, 
                  d}}, {0.01899643970468609`, 1}, {}]\), 
            ",", \(AncestralLineage[
              9, {0.6452036798471656`, 
                1.9706637158007017`}, {{a, b, c, d}}, {1}, {}]\), 
            ",", \(AncestralLineage[
              10, {1.9706637158007017`, 
                2.2897969825533644`}, {{a, b, c, 
                  d}, {}}, {0.9371981015363346`, 1}, {}]\), 
            ",", \(AncestralLineage[
              11, {1.9706637158007017`, 
                2.118015261702507`}, {{}, {a, b, c, 
                  d}}, {0.9371981015363346`, 1}, {}]\), 
            ",", \(AncestralLineage[
              12, {2.118015261702507`, 2.3758569290340006`}, {{}}, {1}, {}]\),
             ",", \(AncestralLineage[
              13, {2.118015261702507`, 
                2.228204237719424`}, {{}, {a, b, c, 
                  d}}, {0.9371981015363346`, 1}, {}]\), 
            ",", \(AncestralLineage[
              14, {2.228204237719424`, 2.2897969825533644`}, {{}}, {1}, {}]\),
             ",", \(AncestralLineage[
              15, {2.228204237719424`, 
                2.3639104415829926`}, {{}, {a, b, c, 
                  d}}, {0.9371981015363346`, 1}, {}]\), 
            ",", \(AncestralLineage[
              16, {2.2897969825533644`, 
                2.3639104415829926`}, {{a, b, c, 
                  d}, {}}, {0.9371981015363346`, 1}, {}]\), 
            ",", \(AncestralLineage[
              17, {2.3639104415829926`, 
                2.458462043572085`}, {{a, b, c, d}}, {1}, {}]\), 
            ",", \(AncestralLineage[
              18, {2.3758569290340006`, 2.458462043572085`}, {{}}, {1}, {}]\),
             ",", \(AncestralLineage[
              19, {2.3758569290340006`, 
                2.4862026095016123`}, {{}}, {1}, {}]\), 
            ",", \(AncestralLineage[
              20, {2.458462043572085`, 
                2.4862026095016123`}, {{a, b, c, d}}, {1}, {}]\), 
            ",", \(AncestralLineage[
              21, {2.4862026095016123`, 
                3.9524773177113115`}, {{a, b, c, d}}, {1}, {}]\), 
            ",", \(AncestralLineage[
              22, {3.9524773177113115`, 
                4.0138506590066365`}, {{a, b, c, 
                  d}, {}}, {0.9888375144798349`, 1}, {}]\), 
            ",", \(AncestralLineage[
              23, {3.9524773177113115`, 
                4.0138506590066365`}, {{}, {a, b, c, 
                  d}}, {0.9888375144798349`, 1}, {}]\), 
            ",", \(AncestralLineage[
              24, {4.0138506590066365`, 
                5.754090480075275`}, {{a, b, c, d}}, {1}, {}]\), 
            ",", \(AncestralLineage[
              25, {5.754090480075275`, 
                5.835659306754844`}, {{a, b, c, 
                  d}, {}}, {0.18912143960102942`, 1}, {}]\), 
            ",", \(AncestralLineage[
              26, {5.754090480075275`, 
                5.835659306754844`}, {{}, {a, b, c, 
                  d}}, {0.18912143960102942`, 1}, {}]\), 
            ",", \(AncestralLineage[
              27, {5.835659306754844`, 
                6.460449426008908`}, {{a, b, c, d}}, {1}, {}]\), 
            ",", \(AncestralLineage[
              28, {6.460449426008908`, 
                7.077559804918352`}, {{a, b, c, 
                  d}, {}}, {0.3588500293612883`, 1}, {}]\), 
            ",", \(AncestralLineage[
              29, {6.460449426008908`, 
                7.077559804918352`}, {{}, {a, b, c, 
                  d}}, {0.3588500293612883`, 1}, {}]\), 
            ",", \(AncestralLineage[
              30, {7.077559804918352`, 
                9.350056023799493`}, {{a, b, c, d}}, {1}, {}]\), 
            ",", \(AncestralLineage[
              31, {9.350056023799493`, 
                9.889403896797967`}, {{a, b, c, 
                  d}, {}}, {0.1922328343937298`, 1}, {}]\), 
            ",", \(AncestralLineage[
              32, {9.350056023799493`, 
                9.889403896797967`}, {{}, {a, b, c, 
                  d}}, {0.1922328343937298`, 1}, {}]\), 
            ",", \(AncestralLineage[
              33, {9.889403896797967`, 
                10.04865414492197`}, {{a, b, c, d}}, {1}, {}]\), 
            ",", \(AncestralLineage[
              34, {10.04865414492197`, 
                10.957847529079562`}, {{a, b, c, 
                  d}, {}}, {0.27813911328582047`, 1}, {}]\), ",", 
            RowBox[{"AncestralLineage", "[", 
              RowBox[{"35", ",", 
                RowBox[{"{", 
                  RowBox[{"10.04865414492197`", ",", 
                    InterpretationBox["\[Infinity]",
                      DirectedInfinity[ 1]]}], "}"}], 
                ",", \({{}, {a, b, c, d}}\), 
                ",", \({0.27813911328582047`, 1}\), ",", \({}\)}], "]"}], 
            ",", \(AncestralLineage[
              36, {10.957847529079562`, 
                11.164561785838144`}, {{a, b, c, 
                  d}, {}}, {0.27813911328582047`, 1}, {}]\), 
            ",", \(AncestralLineage[
              37, {10.957847529079562`, 
                11.200948263910437`}, {{}}, {1}, {}]\), 
            ",", \(AncestralLineage[
              38, {11.164561785838144`, 
                11.209929483491738`}, {{a, b, c, 
                  d}, {}}, {0.27813911328582047`, 1}, {}]\), ",", 
            RowBox[{"AncestralLineage", "[", 
              RowBox[{"39", ",", 
                RowBox[{"{", 
                  RowBox[{"11.164561785838144`", ",", 
                    InterpretationBox["\[Infinity]",
                      DirectedInfinity[ 1]]}], "}"}], ",", \({{}}\), 
                ",", \({1}\), ",", \({}\)}], "]"}], 
            ",", \(AncestralLineage[
              40, {11.200948263910437`, 
                11.209929483491738`}, {{}}, {1}, {}]\), 
            ",", \(AncestralLineage[
              41, {11.200948263910437`, 
                11.245270596164165`}, {{}}, {1}, {}]\), ",", 
            RowBox[{"AncestralLineage", "[", 
              RowBox[{"42", ",", 
                RowBox[{"{", 
                  RowBox[{"11.209929483491738`", ",", 
                    InterpretationBox["\[Infinity]",
                      DirectedInfinity[ 1]]}], "}"}], 
                ",", \({{a, b, c, d}, {}}\), 
                ",", \({0.27813911328582047`, 1}\), ",", \({}\)}], "]"}], ",",
             
            RowBox[{"AncestralLineage", "[", 
              RowBox[{"43", ",", 
                RowBox[{"{", 
                  RowBox[{"11.245270596164165`", ",", 
                    InterpretationBox["\[Infinity]",
                      DirectedInfinity[ 1]]}], "}"}], ",", \({{}}\), 
                ",", \({1}\), ",", \({}\)}], "]"}], ",", 
            RowBox[{"AncestralLineage", "[", 
              RowBox[{"44", ",", 
                RowBox[{"{", 
                  RowBox[{"11.245270596164165`", ",", 
                    InterpretationBox["\[Infinity]",
                      DirectedInfinity[ 1]]}], "}"}], ",", \({{}}\), 
                ",", \({1}\), ",", \({}\)}], "]"}]}], "}"}]}],
      SequenceForm[ "G=", {
        AncestralLineage[ a, {0, 0.057107788781921409}, {{a}}, {1}, {}], 
        AncestralLineage[ b, {0, 0.027696065882077705}, {{b}}, {1}, {}], 
        AncestralLineage[ c, {0, 0.62148251496456786}, {{c}}, {1}, {}], 
        AncestralLineage[ d, {0, 0.027696065882077705}, {{d}}, {1}, {}], 
        AncestralLineage[ 
        1, {0.027696065882077705, 0.057107788781921409}, {{b, d}}, {1}, {}], 
        AncestralLineage[ 
        2, {0.057107788781921409, 0.27049717829601805}, {{a, b, d}}, {1}, {}],
         
        AncestralLineage[ 
        3, {0.27049717829601805, 0.4292570949591068}, {{a, b, d}, {}}, {
          0.018996439704686091, 1}, {}], 
        AncestralLineage[ 
        4, {0.27049717829601805, 0.62148251496456786}, {{}, {a, b, d}}, {
          0.018996439704686091, 1}, {}], 
        AncestralLineage[ 
        5, {0.4292570949591068, 0.45951657742311824}, {{a, b, d}, {}}, {
          0.018996439704686091, 1}, {}], 
        AncestralLineage[ 
        6, {0.4292570949591068, 0.45951657742311824}, {{}}, {1}, {}], 
        AncestralLineage[ 
        7, {0.45951657742311824, 0.64520367984716565}, {{a, b, d}, {}}, {
          0.018996439704686091, 1}, {}], 
        AncestralLineage[ 
        8, {0.62148251496456786, 0.64520367984716565}, {{c}, {a, b, c, d}}, {
          0.018996439704686091, 1}, {}], 
        AncestralLineage[ 
        9, {0.64520367984716565, 1.9706637158007017}, {{a, b, c, d}}, {
          1}, {}], 
        AncestralLineage[ 
        10, {1.9706637158007017, 2.2897969825533644}, {{a, b, c, d}, {}}, {
          0.93719810153633465, 1}, {}], 
        AncestralLineage[ 
        11, {1.9706637158007017, 2.118015261702507}, {{}, {a, b, c, d}}, {
          0.93719810153633465, 1}, {}], 
        AncestralLineage[ 
        12, {2.118015261702507, 2.3758569290340006}, {{}}, {1}, {}], 
        AncestralLineage[ 
        13, {2.118015261702507, 2.228204237719424}, {{}, {a, b, c, d}}, {
          0.93719810153633465, 1}, {}], 
        AncestralLineage[ 
        14, {2.228204237719424, 2.2897969825533644}, {{}}, {1}, {}], 
        AncestralLineage[ 
        15, {2.228204237719424, 2.3639104415829926}, {{}, {a, b, c, d}}, {
          0.93719810153633465, 1}, {}], 
        AncestralLineage[ 
        16, {2.2897969825533644, 2.3639104415829926}, {{a, b, c, d}, {}}, {
          0.93719810153633465, 1}, {}], 
        AncestralLineage[ 
        17, {2.3639104415829926, 2.458462043572085}, {{a, b, c, d}}, {1}, {}],
         
        AncestralLineage[ 
        18, {2.3758569290340006, 2.458462043572085}, {{}}, {1}, {}], 
        AncestralLineage[ 
        19, {2.3758569290340006, 2.4862026095016123}, {{}}, {1}, {}], 
        AncestralLineage[ 
        20, {2.458462043572085, 2.4862026095016123}, {{a, b, c, d}}, {1}, {}],
         
        AncestralLineage[ 
        21, {2.4862026095016123, 3.9524773177113115}, {{a, b, c, d}}, {
          1}, {}], 
        AncestralLineage[ 
        22, {3.9524773177113115, 4.0138506590066365}, {{a, b, c, d}, {}}, {
          0.98883751447983492, 1}, {}], 
        AncestralLineage[ 
        23, {3.9524773177113115, 4.0138506590066365}, {{}, {a, b, c, d}}, {
          0.98883751447983492, 1}, {}], 
        AncestralLineage[ 
        24, {4.0138506590066365, 5.7540904800752752}, {{a, b, c, d}}, {
          1}, {}], 
        AncestralLineage[ 
        25, {5.7540904800752752, 5.8356593067548443}, {{a, b, c, d}, {}}, {
          0.18912143960102942, 1}, {}], 
        AncestralLineage[ 
        26, {5.7540904800752752, 5.8356593067548443}, {{}, {a, b, c, d}}, {
          0.18912143960102942, 1}, {}], 
        AncestralLineage[ 
        27, {5.8356593067548443, 6.4604494260089078}, {{a, b, c, d}}, {
          1}, {}], 
        AncestralLineage[ 
        28, {6.4604494260089078, 7.0775598049183523}, {{a, b, c, d}, {}}, {
          0.35885002936128829, 1}, {}], 
        AncestralLineage[ 
        29, {6.4604494260089078, 7.0775598049183523}, {{}, {a, b, c, d}}, {
          0.35885002936128829, 1}, {}], 
        AncestralLineage[ 
        30, {7.0775598049183523, 9.3500560237994925}, {{a, b, c, d}}, {
          1}, {}], 
        AncestralLineage[ 
        31, {9.3500560237994925, 9.8894038967979672}, {{a, b, c, d}, {}}, {
          0.19223283439372979, 1}, {}], 
        AncestralLineage[ 
        32, {9.3500560237994925, 9.8894038967979672}, {{}, {a, b, c, d}}, {
          0.19223283439372979, 1}, {}], 
        AncestralLineage[ 
        33, {9.8894038967979672, 10.04865414492197}, {{a, b, c, d}}, {1}, {}],
         
        AncestralLineage[ 
        34, {10.04865414492197, 10.957847529079562}, {{a, b, c, d}, {}}, {
          0.27813911328582047, 1}, {}], 
        AncestralLineage[ 35, {10.04865414492197, 
          DirectedInfinity[ 1]}, {{}, {a, b, c, d}}, {0.27813911328582047, 
          1}, {}], 
        AncestralLineage[ 
        36, {10.957847529079562, 11.164561785838144}, {{a, b, c, d}, {}}, {
          0.27813911328582047, 1}, {}], 
        AncestralLineage[ 
        37, {10.957847529079562, 11.200948263910437}, {{}}, {1}, {}], 
        AncestralLineage[ 
        38, {11.164561785838144, 11.209929483491738}, {{a, b, c, d}, {}}, {
          0.27813911328582047, 1}, {}], 
        AncestralLineage[ 39, {11.164561785838144, 
          DirectedInfinity[ 1]}, {{}}, {1}, {}], 
        AncestralLineage[ 
        40, {11.200948263910437, 11.209929483491738}, {{}}, {1}, {}], 
        AncestralLineage[ 
        41, {11.200948263910437, 11.245270596164165}, {{}}, {1}, {}], 
        AncestralLineage[ 42, {11.209929483491738, 
          DirectedInfinity[ 1]}, {{a, b, c, d}, {}}, {0.27813911328582047, 
          1}, {}], 
        AncestralLineage[ 43, {11.245270596164165, 
          DirectedInfinity[ 1]}, {{}}, {1}, {}], 
        AncestralLineage[ 44, {11.245270596164165, 
          DirectedInfinity[ 1]}, {{}}, {1}, {}]}],
      Editable->False]], "Print",
  CellLabel->"From In[122]:="],

Cell[BoxData[
    \({11.256831529989311`, 4, None}\)], "Print",
  CellLabel->"From In[122]:="],

Cell[BoxData[
    InterpretationBox[\("Coalescing "\[InvisibleSpace]{35, 
          42}\[InvisibleSpace]"; current lineages "\[InvisibleSpace]{35, 39, 
          42, 43, 44}\),
      SequenceForm[ 
      "Coalescing ", {35, 42}, "; current lineages ", {35, 39, 42, 43, 44}],
      Editable->False]], "Print",
  CellLabel->"From In[122]:="],

Cell[BoxData[
    InterpretationBox[
      RowBox[{"\<\"G=\"\>", "\[InvisibleSpace]", 
        RowBox[{"{", 
          
          RowBox[{\(AncestralLineage[
              a, {0, 0.05710778878192141`}, {{a}}, {1}, {}]\), 
            ",", \(AncestralLineage[
              b, {0, 0.027696065882077705`}, {{b}}, {1}, {}]\), 
            ",", \(AncestralLineage[
              c, {0, 0.6214825149645679`}, {{c}}, {1}, {}]\), 
            ",", \(AncestralLineage[
              d, {0, 0.027696065882077705`}, {{d}}, {1}, {}]\), 
            ",", \(AncestralLineage[
              1, {0.027696065882077705`, 
                0.05710778878192141`}, {{b, d}}, {1}, {}]\), 
            ",", \(AncestralLineage[
              2, {0.05710778878192141`, 
                0.27049717829601805`}, {{a, b, d}}, {1}, {}]\), 
            ",", \(AncestralLineage[
              3, {0.27049717829601805`, 
                0.4292570949591068`}, {{a, b, d}, {}}, {0.01899643970468609`, 
                1}, {}]\), 
            ",", \(AncestralLineage[
              4, {0.27049717829601805`, 
                0.6214825149645679`}, {{}, {a, b, d}}, {0.01899643970468609`, 
                1}, {}]\), 
            ",", \(AncestralLineage[
              5, {0.4292570949591068`, 
                0.45951657742311824`}, {{a, b, 
                  d}, {}}, {0.01899643970468609`, 1}, {}]\), 
            ",", \(AncestralLineage[
              6, {0.4292570949591068`, 
                0.45951657742311824`}, {{}}, {1}, {}]\), 
            ",", \(AncestralLineage[
              7, {0.45951657742311824`, 
                0.6452036798471656`}, {{a, b, d}, {}}, {0.01899643970468609`, 
                1}, {}]\), 
            ",", \(AncestralLineage[
              8, {0.6214825149645679`, 
                0.6452036798471656`}, {{c}, {a, b, c, 
                  d}}, {0.01899643970468609`, 1}, {}]\), 
            ",", \(AncestralLineage[
              9, {0.6452036798471656`, 
                1.9706637158007017`}, {{a, b, c, d}}, {1}, {}]\), 
            ",", \(AncestralLineage[
              10, {1.9706637158007017`, 
                2.2897969825533644`}, {{a, b, c, 
                  d}, {}}, {0.9371981015363346`, 1}, {}]\), 
            ",", \(AncestralLineage[
              11, {1.9706637158007017`, 
                2.118015261702507`}, {{}, {a, b, c, 
                  d}}, {0.9371981015363346`, 1}, {}]\), 
            ",", \(AncestralLineage[
              12, {2.118015261702507`, 2.3758569290340006`}, {{}}, {1}, {}]\),
             ",", \(AncestralLineage[
              13, {2.118015261702507`, 
                2.228204237719424`}, {{}, {a, b, c, 
                  d}}, {0.9371981015363346`, 1}, {}]\), 
            ",", \(AncestralLineage[
              14, {2.228204237719424`, 2.2897969825533644`}, {{}}, {1}, {}]\),
             ",", \(AncestralLineage[
              15, {2.228204237719424`, 
                2.3639104415829926`}, {{}, {a, b, c, 
                  d}}, {0.9371981015363346`, 1}, {}]\), 
            ",", \(AncestralLineage[
              16, {2.2897969825533644`, 
                2.3639104415829926`}, {{a, b, c, 
                  d}, {}}, {0.9371981015363346`, 1}, {}]\), 
            ",", \(AncestralLineage[
              17, {2.3639104415829926`, 
                2.458462043572085`}, {{a, b, c, d}}, {1}, {}]\), 
            ",", \(AncestralLineage[
              18, {2.3758569290340006`, 2.458462043572085`}, {{}}, {1}, {}]\),
             ",", \(AncestralLineage[
              19, {2.3758569290340006`, 
                2.4862026095016123`}, {{}}, {1}, {}]\), 
            ",", \(AncestralLineage[
              20, {2.458462043572085`, 
                2.4862026095016123`}, {{a, b, c, d}}, {1}, {}]\), 
            ",", \(AncestralLineage[
              21, {2.4862026095016123`, 
                3.9524773177113115`}, {{a, b, c, d}}, {1}, {}]\), 
            ",", \(AncestralLineage[
              22, {3.9524773177113115`, 
                4.0138506590066365`}, {{a, b, c, 
                  d}, {}}, {0.9888375144798349`, 1}, {}]\), 
            ",", \(AncestralLineage[
              23, {3.9524773177113115`, 
                4.0138506590066365`}, {{}, {a, b, c, 
                  d}}, {0.9888375144798349`, 1}, {}]\), 
            ",", \(AncestralLineage[
              24, {4.0138506590066365`, 
                5.754090480075275`}, {{a, b, c, d}}, {1}, {}]\), 
            ",", \(AncestralLineage[
              25, {5.754090480075275`, 
                5.835659306754844`}, {{a, b, c, 
                  d}, {}}, {0.18912143960102942`, 1}, {}]\), 
            ",", \(AncestralLineage[
              26, {5.754090480075275`, 
                5.835659306754844`}, {{}, {a, b, c, 
                  d}}, {0.18912143960102942`, 1}, {}]\), 
            ",", \(AncestralLineage[
              27, {5.835659306754844`, 
                6.460449426008908`}, {{a, b, c, d}}, {1}, {}]\), 
            ",", \(AncestralLineage[
              28, {6.460449426008908`, 
                7.077559804918352`}, {{a, b, c, 
                  d}, {}}, {0.3588500293612883`, 1}, {}]\), 
            ",", \(AncestralLineage[
              29, {6.460449426008908`, 
                7.077559804918352`}, {{}, {a, b, c, 
                  d}}, {0.3588500293612883`, 1}, {}]\), 
            ",", \(AncestralLineage[
              30, {7.077559804918352`, 
                9.350056023799493`}, {{a, b, c, d}}, {1}, {}]\), 
            ",", \(AncestralLineage[
              31, {9.350056023799493`, 
                9.889403896797967`}, {{a, b, c, 
                  d}, {}}, {0.1922328343937298`, 1}, {}]\), 
            ",", \(AncestralLineage[
              32, {9.350056023799493`, 
                9.889403896797967`}, {{}, {a, b, c, 
                  d}}, {0.1922328343937298`, 1}, {}]\), 
            ",", \(AncestralLineage[
              33, {9.889403896797967`, 
                10.04865414492197`}, {{a, b, c, d}}, {1}, {}]\), 
            ",", \(AncestralLineage[
              34, {10.04865414492197`, 
                10.957847529079562`}, {{a, b, c, 
                  d}, {}}, {0.27813911328582047`, 1}, {}]\), 
            ",", \(AncestralLineage[
              35, {10.04865414492197`, 
                11.256831529989311`}, {{}, {a, b, c, 
                  d}}, {0.27813911328582047`, 1}, {}]\), 
            ",", \(AncestralLineage[
              36, {10.957847529079562`, 
                11.164561785838144`}, {{a, b, c, 
                  d}, {}}, {0.27813911328582047`, 1}, {}]\), 
            ",", \(AncestralLineage[
              37, {10.957847529079562`, 
                11.200948263910437`}, {{}}, {1}, {}]\), 
            ",", \(AncestralLineage[
              38, {11.164561785838144`, 
                11.209929483491738`}, {{a, b, c, 
                  d}, {}}, {0.27813911328582047`, 1}, {}]\), ",", 
            RowBox[{"AncestralLineage", "[", 
              RowBox[{"39", ",", 
                RowBox[{"{", 
                  RowBox[{"11.164561785838144`", ",", 
                    InterpretationBox["\[Infinity]",
                      DirectedInfinity[ 1]]}], "}"}], ",", \({{}}\), 
                ",", \({1}\), ",", \({}\)}], "]"}], 
            ",", \(AncestralLineage[
              40, {11.200948263910437`, 
                11.209929483491738`}, {{}}, {1}, {}]\), 
            ",", \(AncestralLineage[
              41, {11.200948263910437`, 
                11.245270596164165`}, {{}}, {1}, {}]\), 
            ",", \(AncestralLineage[
              42, {11.209929483491738`, 
                11.256831529989311`}, {{a, b, c, 
                  d}, {}}, {0.27813911328582047`, 1}, {}]\), ",", 
            RowBox[{"AncestralLineage", "[", 
              RowBox[{"43", ",", 
                RowBox[{"{", 
                  RowBox[{"11.245270596164165`", ",", 
                    InterpretationBox["\[Infinity]",
                      DirectedInfinity[ 1]]}], "}"}], ",", \({{}}\), 
                ",", \({1}\), ",", \({}\)}], "]"}], ",", 
            RowBox[{"AncestralLineage", "[", 
              RowBox[{"44", ",", 
                RowBox[{"{", 
                  RowBox[{"11.245270596164165`", ",", 
                    InterpretationBox["\[Infinity]",
                      DirectedInfinity[ 1]]}], "}"}], ",", \({{}}\), 
                ",", \({1}\), ",", \({}\)}], "]"}], ",", 
            RowBox[{"AncestralLineage", "[", 
              RowBox[{"45", ",", 
                RowBox[{"{", 
                  RowBox[{"11.256831529989311`", ",", 
                    InterpretationBox["\[Infinity]",
                      DirectedInfinity[ 1]]}], "}"}], ",", \({{a, b, c, d}}\),
                 ",", \({1}\), ",", \({}\)}], "]"}]}], "}"}]}],
      SequenceForm[ "G=", {
        AncestralLineage[ a, {0, 0.057107788781921409}, {{a}}, {1}, {}], 
        AncestralLineage[ b, {0, 0.027696065882077705}, {{b}}, {1}, {}], 
        AncestralLineage[ c, {0, 0.62148251496456786}, {{c}}, {1}, {}], 
        AncestralLineage[ d, {0, 0.027696065882077705}, {{d}}, {1}, {}], 
        AncestralLineage[ 
        1, {0.027696065882077705, 0.057107788781921409}, {{b, d}}, {1}, {}], 
        AncestralLineage[ 
        2, {0.057107788781921409, 0.27049717829601805}, {{a, b, d}}, {1}, {}],
         
        AncestralLineage[ 
        3, {0.27049717829601805, 0.4292570949591068}, {{a, b, d}, {}}, {
          0.018996439704686091, 1}, {}], 
        AncestralLineage[ 
        4, {0.27049717829601805, 0.62148251496456786}, {{}, {a, b, d}}, {
          0.018996439704686091, 1}, {}], 
        AncestralLineage[ 
        5, {0.4292570949591068, 0.45951657742311824}, {{a, b, d}, {}}, {
          0.018996439704686091, 1}, {}], 
        AncestralLineage[ 
        6, {0.4292570949591068, 0.45951657742311824}, {{}}, {1}, {}], 
        AncestralLineage[ 
        7, {0.45951657742311824, 0.64520367984716565}, {{a, b, d}, {}}, {
          0.018996439704686091, 1}, {}], 
        AncestralLineage[ 
        8, {0.62148251496456786, 0.64520367984716565}, {{c}, {a, b, c, d}}, {
          0.018996439704686091, 1}, {}], 
        AncestralLineage[ 
        9, {0.64520367984716565, 1.9706637158007017}, {{a, b, c, d}}, {
          1}, {}], 
        AncestralLineage[ 
        10, {1.9706637158007017, 2.2897969825533644}, {{a, b, c, d}, {}}, {
          0.93719810153633465, 1}, {}], 
        AncestralLineage[ 
        11, {1.9706637158007017, 2.118015261702507}, {{}, {a, b, c, d}}, {
          0.93719810153633465, 1}, {}], 
        AncestralLineage[ 
        12, {2.118015261702507, 2.3758569290340006}, {{}}, {1}, {}], 
        AncestralLineage[ 
        13, {2.118015261702507, 2.228204237719424}, {{}, {a, b, c, d}}, {
          0.93719810153633465, 1}, {}], 
        AncestralLineage[ 
        14, {2.228204237719424, 2.2897969825533644}, {{}}, {1}, {}], 
        AncestralLineage[ 
        15, {2.228204237719424, 2.3639104415829926}, {{}, {a, b, c, d}}, {
          0.93719810153633465, 1}, {}], 
        AncestralLineage[ 
        16, {2.2897969825533644, 2.3639104415829926}, {{a, b, c, d}, {}}, {
          0.93719810153633465, 1}, {}], 
        AncestralLineage[ 
        17, {2.3639104415829926, 2.458462043572085}, {{a, b, c, d}}, {1}, {}],
         
        AncestralLineage[ 
        18, {2.3758569290340006, 2.458462043572085}, {{}}, {1}, {}], 
        AncestralLineage[ 
        19, {2.3758569290340006, 2.4862026095016123}, {{}}, {1}, {}], 
        AncestralLineage[ 
        20, {2.458462043572085, 2.4862026095016123}, {{a, b, c, d}}, {1}, {}],
         
        AncestralLineage[ 
        21, {2.4862026095016123, 3.9524773177113115}, {{a, b, c, d}}, {
          1}, {}], 
        AncestralLineage[ 
        22, {3.9524773177113115, 4.0138506590066365}, {{a, b, c, d}, {}}, {
          0.98883751447983492, 1}, {}], 
        AncestralLineage[ 
        23, {3.9524773177113115, 4.0138506590066365}, {{}, {a, b, c, d}}, {
          0.98883751447983492, 1}, {}], 
        AncestralLineage[ 
        24, {4.0138506590066365, 5.7540904800752752}, {{a, b, c, d}}, {
          1}, {}], 
        AncestralLineage[ 
        25, {5.7540904800752752, 5.8356593067548443}, {{a, b, c, d}, {}}, {
          0.18912143960102942, 1}, {}], 
        AncestralLineage[ 
        26, {5.7540904800752752, 5.8356593067548443}, {{}, {a, b, c, d}}, {
          0.18912143960102942, 1}, {}], 
        AncestralLineage[ 
        27, {5.8356593067548443, 6.4604494260089078}, {{a, b, c, d}}, {
          1}, {}], 
        AncestralLineage[ 
        28, {6.4604494260089078, 7.0775598049183523}, {{a, b, c, d}, {}}, {
          0.35885002936128829, 1}, {}], 
        AncestralLineage[ 
        29, {6.4604494260089078, 7.0775598049183523}, {{}, {a, b, c, d}}, {
          0.35885002936128829, 1}, {}], 
        AncestralLineage[ 
        30, {7.0775598049183523, 9.3500560237994925}, {{a, b, c, d}}, {
          1}, {}], 
        AncestralLineage[ 
        31, {9.3500560237994925, 9.8894038967979672}, {{a, b, c, d}, {}}, {
          0.19223283439372979, 1}, {}], 
        AncestralLineage[ 
        32, {9.3500560237994925, 9.8894038967979672}, {{}, {a, b, c, d}}, {
          0.19223283439372979, 1}, {}], 
        AncestralLineage[ 
        33, {9.8894038967979672, 10.04865414492197}, {{a, b, c, d}}, {1}, {}],
         
        AncestralLineage[ 
        34, {10.04865414492197, 10.957847529079562}, {{a, b, c, d}, {}}, {
          0.27813911328582047, 1}, {}], 
        AncestralLineage[ 
        35, {10.04865414492197, 11.256831529989311}, {{}, {a, b, c, d}}, {
          0.27813911328582047, 1}, {}], 
        AncestralLineage[ 
        36, {10.957847529079562, 11.164561785838144}, {{a, b, c, d}, {}}, {
          0.27813911328582047, 1}, {}], 
        AncestralLineage[ 
        37, {10.957847529079562, 11.200948263910437}, {{}}, {1}, {}], 
        AncestralLineage[ 
        38, {11.164561785838144, 11.209929483491738}, {{a, b, c, d}, {}}, {
          0.27813911328582047, 1}, {}], 
        AncestralLineage[ 39, {11.164561785838144, 
          DirectedInfinity[ 1]}, {{}}, {1}, {}], 
        AncestralLineage[ 
        40, {11.200948263910437, 11.209929483491738}, {{}}, {1}, {}], 
        AncestralLineage[ 
        41, {11.200948263910437, 11.245270596164165}, {{}}, {1}, {}], 
        AncestralLineage[ 
        42, {11.209929483491738, 11.256831529989311}, {{a, b, c, d}, {}}, {
          0.27813911328582047, 1}, {}], 
        AncestralLineage[ 43, {11.245270596164165, 
          DirectedInfinity[ 1]}, {{}}, {1}, {}], 
        AncestralLineage[ 44, {11.245270596164165, 
          DirectedInfinity[ 1]}, {{}}, {1}, {}], 
        AncestralLineage[ 45, {11.256831529989311, 
          DirectedInfinity[ 1]}, {{a, b, c, d}}, {1}, {}]}],
      Editable->False]], "Print",
  CellLabel->"From In[122]:="],

Cell[BoxData[
    \({11.419143745929558`, 5, 0.6485566153495527`}\)], "Print",
  CellLabel->"From In[122]:="],

Cell[BoxData[
    InterpretationBox[\("Recombining "\[InvisibleSpace]39\[InvisibleSpace]"; \
current lineages "\[InvisibleSpace]{39, 43, 44, 45}\),
      SequenceForm[ 
      "Recombining ", 39, "; current lineages ", {39, 43, 44, 45}],
      Editable->False]], "Print",
  CellLabel->"From In[122]:="],

Cell[BoxData[
    InterpretationBox[
      RowBox[{"\<\"G=\"\>", "\[InvisibleSpace]", 
        RowBox[{"{", 
          
          RowBox[{\(AncestralLineage[
              a, {0, 0.05710778878192141`}, {{a}}, {1}, {}]\), 
            ",", \(AncestralLineage[
              b, {0, 0.027696065882077705`}, {{b}}, {1}, {}]\), 
            ",", \(AncestralLineage[
              c, {0, 0.6214825149645679`}, {{c}}, {1}, {}]\), 
            ",", \(AncestralLineage[
              d, {0, 0.027696065882077705`}, {{d}}, {1}, {}]\), 
            ",", \(AncestralLineage[
              1, {0.027696065882077705`, 
                0.05710778878192141`}, {{b, d}}, {1}, {}]\), 
            ",", \(AncestralLineage[
              2, {0.05710778878192141`, 
                0.27049717829601805`}, {{a, b, d}}, {1}, {}]\), 
            ",", \(AncestralLineage[
              3, {0.27049717829601805`, 
                0.4292570949591068`}, {{a, b, d}, {}}, {0.01899643970468609`, 
                1}, {}]\), 
            ",", \(AncestralLineage[
              4, {0.27049717829601805`, 
                0.6214825149645679`}, {{}, {a, b, d}}, {0.01899643970468609`, 
                1}, {}]\), 
            ",", \(AncestralLineage[
              5, {0.4292570949591068`, 
                0.45951657742311824`}, {{a, b, 
                  d}, {}}, {0.01899643970468609`, 1}, {}]\), 
            ",", \(AncestralLineage[
              6, {0.4292570949591068`, 
                0.45951657742311824`}, {{}}, {1}, {}]\), 
            ",", \(AncestralLineage[
              7, {0.45951657742311824`, 
                0.6452036798471656`}, {{a, b, d}, {}}, {0.01899643970468609`, 
                1}, {}]\), 
            ",", \(AncestralLineage[
              8, {0.6214825149645679`, 
                0.6452036798471656`}, {{c}, {a, b, c, 
                  d}}, {0.01899643970468609`, 1}, {}]\), 
            ",", \(AncestralLineage[
              9, {0.6452036798471656`, 
                1.9706637158007017`}, {{a, b, c, d}}, {1}, {}]\), 
            ",", \(AncestralLineage[
              10, {1.9706637158007017`, 
                2.2897969825533644`}, {{a, b, c, 
                  d}, {}}, {0.9371981015363346`, 1}, {}]\), 
            ",", \(AncestralLineage[
              11, {1.9706637158007017`, 
                2.118015261702507`}, {{}, {a, b, c, 
                  d}}, {0.9371981015363346`, 1}, {}]\), 
            ",", \(AncestralLineage[
              12, {2.118015261702507`, 2.3758569290340006`}, {{}}, {1}, {}]\),
             ",", \(AncestralLineage[
              13, {2.118015261702507`, 
                2.228204237719424`}, {{}, {a, b, c, 
                  d}}, {0.9371981015363346`, 1}, {}]\), 
            ",", \(AncestralLineage[
              14, {2.228204237719424`, 2.2897969825533644`}, {{}}, {1}, {}]\),
             ",", \(AncestralLineage[
              15, {2.228204237719424`, 
                2.3639104415829926`}, {{}, {a, b, c, 
                  d}}, {0.9371981015363346`, 1}, {}]\), 
            ",", \(AncestralLineage[
              16, {2.2897969825533644`, 
                2.3639104415829926`}, {{a, b, c, 
                  d}, {}}, {0.9371981015363346`, 1}, {}]\), 
            ",", \(AncestralLineage[
              17, {2.3639104415829926`, 
                2.458462043572085`}, {{a, b, c, d}}, {1}, {}]\), 
            ",", \(AncestralLineage[
              18, {2.3758569290340006`, 2.458462043572085`}, {{}}, {1}, {}]\),
             ",", \(AncestralLineage[
              19, {2.3758569290340006`, 
                2.4862026095016123`}, {{}}, {1}, {}]\), 
            ",", \(AncestralLineage[
              20, {2.458462043572085`, 
                2.4862026095016123`}, {{a, b, c, d}}, {1}, {}]\), 
            ",", \(AncestralLineage[
              21, {2.4862026095016123`, 
                3.9524773177113115`}, {{a, b, c, d}}, {1}, {}]\), 
            ",", \(AncestralLineage[
              22, {3.9524773177113115`, 
                4.0138506590066365`}, {{a, b, c, 
                  d}, {}}, {0.9888375144798349`, 1}, {}]\), 
            ",", \(AncestralLineage[
              23, {3.9524773177113115`, 
                4.0138506590066365`}, {{}, {a, b, c, 
                  d}}, {0.9888375144798349`, 1}, {}]\), 
            ",", \(AncestralLineage[
              24, {4.0138506590066365`, 
                5.754090480075275`}, {{a, b, c, d}}, {1}, {}]\), 
            ",", \(AncestralLineage[
              25, {5.754090480075275`, 
                5.835659306754844`}, {{a, b, c, 
                  d}, {}}, {0.18912143960102942`, 1}, {}]\), 
            ",", \(AncestralLineage[
              26, {5.754090480075275`, 
                5.835659306754844`}, {{}, {a, b, c, 
                  d}}, {0.18912143960102942`, 1}, {}]\), 
            ",", \(AncestralLineage[
              27, {5.835659306754844`, 
                6.460449426008908`}, {{a, b, c, d}}, {1}, {}]\), 
            ",", \(AncestralLineage[
              28, {6.460449426008908`, 
                7.077559804918352`}, {{a, b, c, 
                  d}, {}}, {0.3588500293612883`, 1}, {}]\), 
            ",", \(AncestralLineage[
              29, {6.460449426008908`, 
                7.077559804918352`}, {{}, {a, b, c, 
                  d}}, {0.3588500293612883`, 1}, {}]\), 
            ",", \(AncestralLineage[
              30, {7.077559804918352`, 
                9.350056023799493`}, {{a, b, c, d}}, {1}, {}]\), 
            ",", \(AncestralLineage[
              31, {9.350056023799493`, 
                9.889403896797967`}, {{a, b, c, 
                  d}, {}}, {0.1922328343937298`, 1}, {}]\), 
            ",", \(AncestralLineage[
              32, {9.350056023799493`, 
                9.889403896797967`}, {{}, {a, b, c, 
                  d}}, {0.1922328343937298`, 1}, {}]\), 
            ",", \(AncestralLineage[
              33, {9.889403896797967`, 
                10.04865414492197`}, {{a, b, c, d}}, {1}, {}]\), 
            ",", \(AncestralLineage[
              34, {10.04865414492197`, 
                10.957847529079562`}, {{a, b, c, 
                  d}, {}}, {0.27813911328582047`, 1}, {}]\), 
            ",", \(AncestralLineage[
              35, {10.04865414492197`, 
                11.256831529989311`}, {{}, {a, b, c, 
                  d}}, {0.27813911328582047`, 1}, {}]\), 
            ",", \(AncestralLineage[
              36, {10.957847529079562`, 
                11.164561785838144`}, {{a, b, c, 
                  d}, {}}, {0.27813911328582047`, 1}, {}]\), 
            ",", \(AncestralLineage[
              37, {10.957847529079562`, 
                11.200948263910437`}, {{}}, {1}, {}]\), 
            ",", \(AncestralLineage[
              38, {11.164561785838144`, 
                11.209929483491738`}, {{a, b, c, 
                  d}, {}}, {0.27813911328582047`, 1}, {}]\), 
            ",", \(AncestralLineage[
              39, {11.164561785838144`, 
                11.419143745929558`}, {{}}, {1}, {}]\), 
            ",", \(AncestralLineage[
              40, {11.200948263910437`, 
                11.209929483491738`}, {{}}, {1}, {}]\), 
            ",", \(AncestralLineage[
              41, {11.200948263910437`, 
                11.245270596164165`}, {{}}, {1}, {}]\), 
            ",", \(AncestralLineage[
              42, {11.209929483491738`, 
                11.256831529989311`}, {{a, b, c, 
                  d}, {}}, {0.27813911328582047`, 1}, {}]\), ",", 
            RowBox[{"AncestralLineage", "[", 
              RowBox[{"43", ",", 
                RowBox[{"{", 
                  RowBox[{"11.245270596164165`", ",", 
                    InterpretationBox["\[Infinity]",
                      DirectedInfinity[ 1]]}], "}"}], ",", \({{}}\), 
                ",", \({1}\), ",", \({}\)}], "]"}], ",", 
            RowBox[{"AncestralLineage", "[", 
              RowBox[{"44", ",", 
                RowBox[{"{", 
                  RowBox[{"11.245270596164165`", ",", 
                    InterpretationBox["\[Infinity]",
                      DirectedInfinity[ 1]]}], "}"}], ",", \({{}}\), 
                ",", \({1}\), ",", \({}\)}], "]"}], ",", 
            RowBox[{"AncestralLineage", "[", 
              RowBox[{"45", ",", 
                RowBox[{"{", 
                  RowBox[{"11.256831529989311`", ",", 
                    InterpretationBox["\[Infinity]",
                      DirectedInfinity[ 1]]}], "}"}], ",", \({{a, b, c, d}}\),
                 ",", \({1}\), ",", \({}\)}], "]"}], ",", 
            RowBox[{"AncestralLineage", "[", 
              RowBox[{"46", ",", 
                RowBox[{"{", 
                  RowBox[{"11.419143745929558`", ",", 
                    InterpretationBox["\[Infinity]",
                      DirectedInfinity[ 1]]}], "}"}], ",", \({{}}\), 
                ",", \({1}\), ",", \({}\)}], "]"}], ",", 
            RowBox[{"AncestralLineage", "[", 
              RowBox[{"47", ",", 
                RowBox[{"{", 
                  RowBox[{"11.419143745929558`", ",", 
                    InterpretationBox["\[Infinity]",
                      DirectedInfinity[ 1]]}], "}"}], ",", \({{}}\), 
                ",", \({1}\), ",", \({}\)}], "]"}]}], "}"}]}],
      SequenceForm[ "G=", {
        AncestralLineage[ a, {0, 0.057107788781921409}, {{a}}, {1}, {}], 
        AncestralLineage[ b, {0, 0.027696065882077705}, {{b}}, {1}, {}], 
        AncestralLineage[ c, {0, 0.62148251496456786}, {{c}}, {1}, {}], 
        AncestralLineage[ d, {0, 0.027696065882077705}, {{d}}, {1}, {}], 
        AncestralLineage[ 
        1, {0.027696065882077705, 0.057107788781921409}, {{b, d}}, {1}, {}], 
        AncestralLineage[ 
        2, {0.057107788781921409, 0.27049717829601805}, {{a, b, d}}, {1}, {}],
         
        AncestralLineage[ 
        3, {0.27049717829601805, 0.4292570949591068}, {{a, b, d}, {}}, {
          0.018996439704686091, 1}, {}], 
        AncestralLineage[ 
        4, {0.27049717829601805, 0.62148251496456786}, {{}, {a, b, d}}, {
          0.018996439704686091, 1}, {}], 
        AncestralLineage[ 
        5, {0.4292570949591068, 0.45951657742311824}, {{a, b, d}, {}}, {
          0.018996439704686091, 1}, {}], 
        AncestralLineage[ 
        6, {0.4292570949591068, 0.45951657742311824}, {{}}, {1}, {}], 
        AncestralLineage[ 
        7, {0.45951657742311824, 0.64520367984716565}, {{a, b, d}, {}}, {
          0.018996439704686091, 1}, {}], 
        AncestralLineage[ 
        8, {0.62148251496456786, 0.64520367984716565}, {{c}, {a, b, c, d}}, {
          0.018996439704686091, 1}, {}], 
        AncestralLineage[ 
        9, {0.64520367984716565, 1.9706637158007017}, {{a, b, c, d}}, {
          1}, {}], 
        AncestralLineage[ 
        10, {1.9706637158007017, 2.2897969825533644}, {{a, b, c, d}, {}}, {
          0.93719810153633465, 1}, {}], 
        AncestralLineage[ 
        11, {1.9706637158007017, 2.118015261702507}, {{}, {a, b, c, d}}, {
          0.93719810153633465, 1}, {}], 
        AncestralLineage[ 
        12, {2.118015261702507, 2.3758569290340006}, {{}}, {1}, {}], 
        AncestralLineage[ 
        13, {2.118015261702507, 2.228204237719424}, {{}, {a, b, c, d}}, {
          0.93719810153633465, 1}, {}], 
        AncestralLineage[ 
        14, {2.228204237719424, 2.2897969825533644}, {{}}, {1}, {}], 
        AncestralLineage[ 
        15, {2.228204237719424, 2.3639104415829926}, {{}, {a, b, c, d}}, {
          0.93719810153633465, 1}, {}], 
        AncestralLineage[ 
        16, {2.2897969825533644, 2.3639104415829926}, {{a, b, c, d}, {}}, {
          0.93719810153633465, 1}, {}], 
        AncestralLineage[ 
        17, {2.3639104415829926, 2.458462043572085}, {{a, b, c, d}}, {1}, {}],
         
        AncestralLineage[ 
        18, {2.3758569290340006, 2.458462043572085}, {{}}, {1}, {}], 
        AncestralLineage[ 
        19, {2.3758569290340006, 2.4862026095016123}, {{}}, {1}, {}], 
        AncestralLineage[ 
        20, {2.458462043572085, 2.4862026095016123}, {{a, b, c, d}}, {1}, {}],
         
        AncestralLineage[ 
        21, {2.4862026095016123, 3.9524773177113115}, {{a, b, c, d}}, {
          1}, {}], 
        AncestralLineage[ 
        22, {3.9524773177113115, 4.0138506590066365}, {{a, b, c, d}, {}}, {
          0.98883751447983492, 1}, {}], 
        AncestralLineage[ 
        23, {3.9524773177113115, 4.0138506590066365}, {{}, {a, b, c, d}}, {
          0.98883751447983492, 1}, {}], 
        AncestralLineage[ 
        24, {4.0138506590066365, 5.7540904800752752}, {{a, b, c, d}}, {
          1}, {}], 
        AncestralLineage[ 
        25, {5.7540904800752752, 5.8356593067548443}, {{a, b, c, d}, {}}, {
          0.18912143960102942, 1}, {}], 
        AncestralLineage[ 
        26, {5.7540904800752752, 5.8356593067548443}, {{}, {a, b, c, d}}, {
          0.18912143960102942, 1}, {}], 
        AncestralLineage[ 
        27, {5.8356593067548443, 6.4604494260089078}, {{a, b, c, d}}, {
          1}, {}], 
        AncestralLineage[ 
        28, {6.4604494260089078, 7.0775598049183523}, {{a, b, c, d}, {}}, {
          0.35885002936128829, 1}, {}], 
        AncestralLineage[ 
        29, {6.4604494260089078, 7.0775598049183523}, {{}, {a, b, c, d}}, {
          0.35885002936128829, 1}, {}], 
        AncestralLineage[ 
        30, {7.0775598049183523, 9.3500560237994925}, {{a, b, c, d}}, {
          1}, {}], 
        AncestralLineage[ 
        31, {9.3500560237994925, 9.8894038967979672}, {{a, b, c, d}, {}}, {
          0.19223283439372979, 1}, {}], 
        AncestralLineage[ 
        32, {9.3500560237994925, 9.8894038967979672}, {{}, {a, b, c, d}}, {
          0.19223283439372979, 1}, {}], 
        AncestralLineage[ 
        33, {9.8894038967979672, 10.04865414492197}, {{a, b, c, d}}, {1}, {}],
         
        AncestralLineage[ 
        34, {10.04865414492197, 10.957847529079562}, {{a, b, c, d}, {}}, {
          0.27813911328582047, 1}, {}], 
        AncestralLineage[ 
        35, {10.04865414492197, 11.256831529989311}, {{}, {a, b, c, d}}, {
          0.27813911328582047, 1}, {}], 
        AncestralLineage[ 
        36, {10.957847529079562, 11.164561785838144}, {{a, b, c, d}, {}}, {
          0.27813911328582047, 1}, {}], 
        AncestralLineage[ 
        37, {10.957847529079562, 11.200948263910437}, {{}}, {1}, {}], 
        AncestralLineage[ 
        38, {11.164561785838144, 11.209929483491738}, {{a, b, c, d}, {}}, {
          0.27813911328582047, 1}, {}], 
        AncestralLineage[ 
        39, {11.164561785838144, 11.419143745929558}, {{}}, {1}, {}], 
        AncestralLineage[ 
        40, {11.200948263910437, 11.209929483491738}, {{}}, {1}, {}], 
        AncestralLineage[ 
        41, {11.200948263910437, 11.245270596164165}, {{}}, {1}, {}], 
        AncestralLineage[ 
        42, {11.209929483491738, 11.256831529989311}, {{a, b, c, d}, {}}, {
          0.27813911328582047, 1}, {}], 
        AncestralLineage[ 43, {11.245270596164165, 
          DirectedInfinity[ 1]}, {{}}, {1}, {}], 
        AncestralLineage[ 44, {11.245270596164165, 
          DirectedInfinity[ 1]}, {{}}, {1}, {}], 
        AncestralLineage[ 45, {11.256831529989311, 
          DirectedInfinity[ 1]}, {{a, b, c, d}}, {1}, {}], 
        AncestralLineage[ 46, {11.419143745929558, 
          DirectedInfinity[ 1]}, {{}}, {1}, {}], 
        AncestralLineage[ 47, {11.419143745929558, 
          DirectedInfinity[ 1]}, {{}}, {1}, {}]}],
      Editable->False]], "Print",
  CellLabel->"From In[122]:="],

Cell[BoxData[
    \({11.448204985318503`, 4, None}\)], "Print",
  CellLabel->"From In[122]:="],

Cell[BoxData[
    InterpretationBox[\("Coalescing "\[InvisibleSpace]{44, 
          45}\[InvisibleSpace]"; current lineages "\[InvisibleSpace]{43, 44, 
          45, 46, 47}\),
      SequenceForm[ 
      "Coalescing ", {44, 45}, "; current lineages ", {43, 44, 45, 46, 47}],
      Editable->False]], "Print",
  CellLabel->"From In[122]:="],

Cell[BoxData[
    InterpretationBox[
      RowBox[{"\<\"G=\"\>", "\[InvisibleSpace]", 
        RowBox[{"{", 
          
          RowBox[{\(AncestralLineage[
              a, {0, 0.05710778878192141`}, {{a}}, {1}, {}]\), 
            ",", \(AncestralLineage[
              b, {0, 0.027696065882077705`}, {{b}}, {1}, {}]\), 
            ",", \(AncestralLineage[
              c, {0, 0.6214825149645679`}, {{c}}, {1}, {}]\), 
            ",", \(AncestralLineage[
              d, {0, 0.027696065882077705`}, {{d}}, {1}, {}]\), 
            ",", \(AncestralLineage[
              1, {0.027696065882077705`, 
                0.05710778878192141`}, {{b, d}}, {1}, {}]\), 
            ",", \(AncestralLineage[
              2, {0.05710778878192141`, 
                0.27049717829601805`}, {{a, b, d}}, {1}, {}]\), 
            ",", \(AncestralLineage[
              3, {0.27049717829601805`, 
                0.4292570949591068`}, {{a, b, d}, {}}, {0.01899643970468609`, 
                1}, {}]\), 
            ",", \(AncestralLineage[
              4, {0.27049717829601805`, 
                0.6214825149645679`}, {{}, {a, b, d}}, {0.01899643970468609`, 
                1}, {}]\), 
            ",", \(AncestralLineage[
              5, {0.4292570949591068`, 
                0.45951657742311824`}, {{a, b, 
                  d}, {}}, {0.01899643970468609`, 1}, {}]\), 
            ",", \(AncestralLineage[
              6, {0.4292570949591068`, 
                0.45951657742311824`}, {{}}, {1}, {}]\), 
            ",", \(AncestralLineage[
              7, {0.45951657742311824`, 
                0.6452036798471656`}, {{a, b, d}, {}}, {0.01899643970468609`, 
                1}, {}]\), 
            ",", \(AncestralLineage[
              8, {0.6214825149645679`, 
                0.6452036798471656`}, {{c}, {a, b, c, 
                  d}}, {0.01899643970468609`, 1}, {}]\), 
            ",", \(AncestralLineage[
              9, {0.6452036798471656`, 
                1.9706637158007017`}, {{a, b, c, d}}, {1}, {}]\), 
            ",", \(AncestralLineage[
              10, {1.9706637158007017`, 
                2.2897969825533644`}, {{a, b, c, 
                  d}, {}}, {0.9371981015363346`, 1}, {}]\), 
            ",", \(AncestralLineage[
              11, {1.9706637158007017`, 
                2.118015261702507`}, {{}, {a, b, c, 
                  d}}, {0.9371981015363346`, 1}, {}]\), 
            ",", \(AncestralLineage[
              12, {2.118015261702507`, 2.3758569290340006`}, {{}}, {1}, {}]\),
             ",", \(AncestralLineage[
              13, {2.118015261702507`, 
                2.228204237719424`}, {{}, {a, b, c, 
                  d}}, {0.9371981015363346`, 1}, {}]\), 
            ",", \(AncestralLineage[
              14, {2.228204237719424`, 2.2897969825533644`}, {{}}, {1}, {}]\),
             ",", \(AncestralLineage[
              15, {2.228204237719424`, 
                2.3639104415829926`}, {{}, {a, b, c, 
                  d}}, {0.9371981015363346`, 1}, {}]\), 
            ",", \(AncestralLineage[
              16, {2.2897969825533644`, 
                2.3639104415829926`}, {{a, b, c, 
                  d}, {}}, {0.9371981015363346`, 1}, {}]\), 
            ",", \(AncestralLineage[
              17, {2.3639104415829926`, 
                2.458462043572085`}, {{a, b, c, d}}, {1}, {}]\), 
            ",", \(AncestralLineage[
              18, {2.3758569290340006`, 2.458462043572085`}, {{}}, {1}, {}]\),
             ",", \(AncestralLineage[
              19, {2.3758569290340006`, 
                2.4862026095016123`}, {{}}, {1}, {}]\), 
            ",", \(AncestralLineage[
              20, {2.458462043572085`, 
                2.4862026095016123`}, {{a, b, c, d}}, {1}, {}]\), 
            ",", \(AncestralLineage[
              21, {2.4862026095016123`, 
                3.9524773177113115`}, {{a, b, c, d}}, {1}, {}]\), 
            ",", \(AncestralLineage[
              22, {3.9524773177113115`, 
                4.0138506590066365`}, {{a, b, c, 
                  d}, {}}, {0.9888375144798349`, 1}, {}]\), 
            ",", \(AncestralLineage[
              23, {3.9524773177113115`, 
                4.0138506590066365`}, {{}, {a, b, c, 
                  d}}, {0.9888375144798349`, 1}, {}]\), 
            ",", \(AncestralLineage[
              24, {4.0138506590066365`, 
                5.754090480075275`}, {{a, b, c, d}}, {1}, {}]\), 
            ",", \(AncestralLineage[
              25, {5.754090480075275`, 
                5.835659306754844`}, {{a, b, c, 
                  d}, {}}, {0.18912143960102942`, 1}, {}]\), 
            ",", \(AncestralLineage[
              26, {5.754090480075275`, 
                5.835659306754844`}, {{}, {a, b, c, 
                  d}}, {0.18912143960102942`, 1}, {}]\), 
            ",", \(AncestralLineage[
              27, {5.835659306754844`, 
                6.460449426008908`}, {{a, b, c, d}}, {1}, {}]\), 
            ",", \(AncestralLineage[
              28, {6.460449426008908`, 
                7.077559804918352`}, {{a, b, c, 
                  d}, {}}, {0.3588500293612883`, 1}, {}]\), 
            ",", \(AncestralLineage[
              29, {6.460449426008908`, 
                7.077559804918352`}, {{}, {a, b, c, 
                  d}}, {0.3588500293612883`, 1}, {}]\), 
            ",", \(AncestralLineage[
              30, {7.077559804918352`, 
                9.350056023799493`}, {{a, b, c, d}}, {1}, {}]\), 
            ",", \(AncestralLineage[
              31, {9.350056023799493`, 
                9.889403896797967`}, {{a, b, c, 
                  d}, {}}, {0.1922328343937298`, 1}, {}]\), 
            ",", \(AncestralLineage[
              32, {9.350056023799493`, 
                9.889403896797967`}, {{}, {a, b, c, 
                  d}}, {0.1922328343937298`, 1}, {}]\), 
            ",", \(AncestralLineage[
              33, {9.889403896797967`, 
                10.04865414492197`}, {{a, b, c, d}}, {1}, {}]\), 
            ",", \(AncestralLineage[
              34, {10.04865414492197`, 
                10.957847529079562`}, {{a, b, c, 
                  d}, {}}, {0.27813911328582047`, 1}, {}]\), 
            ",", \(AncestralLineage[
              35, {10.04865414492197`, 
                11.256831529989311`}, {{}, {a, b, c, 
                  d}}, {0.27813911328582047`, 1}, {}]\), 
            ",", \(AncestralLineage[
              36, {10.957847529079562`, 
                11.164561785838144`}, {{a, b, c, 
                  d}, {}}, {0.27813911328582047`, 1}, {}]\), 
            ",", \(AncestralLineage[
              37, {10.957847529079562`, 
                11.200948263910437`}, {{}}, {1}, {}]\), 
            ",", \(AncestralLineage[
              38, {11.164561785838144`, 
                11.209929483491738`}, {{a, b, c, 
                  d}, {}}, {0.27813911328582047`, 1}, {}]\), 
            ",", \(AncestralLineage[
              39, {11.164561785838144`, 
                11.419143745929558`}, {{}}, {1}, {}]\), 
            ",", \(AncestralLineage[
              40, {11.200948263910437`, 
                11.209929483491738`}, {{}}, {1}, {}]\), 
            ",", \(AncestralLineage[
              41, {11.200948263910437`, 
                11.245270596164165`}, {{}}, {1}, {}]\), 
            ",", \(AncestralLineage[
              42, {11.209929483491738`, 
                11.256831529989311`}, {{a, b, c, 
                  d}, {}}, {0.27813911328582047`, 1}, {}]\), ",", 
            RowBox[{"AncestralLineage", "[", 
              RowBox[{"43", ",", 
                RowBox[{"{", 
                  RowBox[{"11.245270596164165`", ",", 
                    InterpretationBox["\[Infinity]",
                      DirectedInfinity[ 1]]}], "}"}], ",", \({{}}\), 
                ",", \({1}\), ",", \({}\)}], "]"}], 
            ",", \(AncestralLineage[
              44, {11.245270596164165`, 
                11.448204985318503`}, {{}}, {1}, {}]\), 
            ",", \(AncestralLineage[
              45, {11.256831529989311`, 
                11.448204985318503`}, {{a, b, c, d}}, {1}, {}]\), ",", 
            RowBox[{"AncestralLineage", "[", 
              RowBox[{"46", ",", 
                RowBox[{"{", 
                  RowBox[{"11.419143745929558`", ",", 
                    InterpretationBox["\[Infinity]",
                      DirectedInfinity[ 1]]}], "}"}], ",", \({{}}\), 
                ",", \({1}\), ",", \({}\)}], "]"}], ",", 
            RowBox[{"AncestralLineage", "[", 
              RowBox[{"47", ",", 
                RowBox[{"{", 
                  RowBox[{"11.419143745929558`", ",", 
                    InterpretationBox["\[Infinity]",
                      DirectedInfinity[ 1]]}], "}"}], ",", \({{}}\), 
                ",", \({1}\), ",", \({}\)}], "]"}], ",", 
            RowBox[{"AncestralLineage", "[", 
              RowBox[{"48", ",", 
                RowBox[{"{", 
                  RowBox[{"11.448204985318503`", ",", 
                    InterpretationBox["\[Infinity]",
                      DirectedInfinity[ 1]]}], "}"}], ",", \({{a, b, c, d}}\),
                 ",", \({1}\), ",", \({}\)}], "]"}]}], "}"}]}],
      SequenceForm[ "G=", {
        AncestralLineage[ a, {0, 0.057107788781921409}, {{a}}, {1}, {}], 
        AncestralLineage[ b, {0, 0.027696065882077705}, {{b}}, {1}, {}], 
        AncestralLineage[ c, {0, 0.62148251496456786}, {{c}}, {1}, {}], 
        AncestralLineage[ d, {0, 0.027696065882077705}, {{d}}, {1}, {}], 
        AncestralLineage[ 
        1, {0.027696065882077705, 0.057107788781921409}, {{b, d}}, {1}, {}], 
        AncestralLineage[ 
        2, {0.057107788781921409, 0.27049717829601805}, {{a, b, d}}, {1}, {}],
         
        AncestralLineage[ 
        3, {0.27049717829601805, 0.4292570949591068}, {{a, b, d}, {}}, {
          0.018996439704686091, 1}, {}], 
        AncestralLineage[ 
        4, {0.27049717829601805, 0.62148251496456786}, {{}, {a, b, d}}, {
          0.018996439704686091, 1}, {}], 
        AncestralLineage[ 
        5, {0.4292570949591068, 0.45951657742311824}, {{a, b, d}, {}}, {
          0.018996439704686091, 1}, {}], 
        AncestralLineage[ 
        6, {0.4292570949591068, 0.45951657742311824}, {{}}, {1}, {}], 
        AncestralLineage[ 
        7, {0.45951657742311824, 0.64520367984716565}, {{a, b, d}, {}}, {
          0.018996439704686091, 1}, {}], 
        AncestralLineage[ 
        8, {0.62148251496456786, 0.64520367984716565}, {{c}, {a, b, c, d}}, {
          0.018996439704686091, 1}, {}], 
        AncestralLineage[ 
        9, {0.64520367984716565, 1.9706637158007017}, {{a, b, c, d}}, {
          1}, {}], 
        AncestralLineage[ 
        10, {1.9706637158007017, 2.2897969825533644}, {{a, b, c, d}, {}}, {
          0.93719810153633465, 1}, {}], 
        AncestralLineage[ 
        11, {1.9706637158007017, 2.118015261702507}, {{}, {a, b, c, d}}, {
          0.93719810153633465, 1}, {}], 
        AncestralLineage[ 
        12, {2.118015261702507, 2.3758569290340006}, {{}}, {1}, {}], 
        AncestralLineage[ 
        13, {2.118015261702507, 2.228204237719424}, {{}, {a, b, c, d}}, {
          0.93719810153633465, 1}, {}], 
        AncestralLineage[ 
        14, {2.228204237719424, 2.2897969825533644}, {{}}, {1}, {}], 
        AncestralLineage[ 
        15, {2.228204237719424, 2.3639104415829926}, {{}, {a, b, c, d}}, {
          0.93719810153633465, 1}, {}], 
        AncestralLineage[ 
        16, {2.2897969825533644, 2.3639104415829926}, {{a, b, c, d}, {}}, {
          0.93719810153633465, 1}, {}], 
        AncestralLineage[ 
        17, {2.3639104415829926, 2.458462043572085}, {{a, b, c, d}}, {1}, {}],
         
        AncestralLineage[ 
        18, {2.3758569290340006, 2.458462043572085}, {{}}, {1}, {}], 
        AncestralLineage[ 
        19, {2.3758569290340006, 2.4862026095016123}, {{}}, {1}, {}], 
        AncestralLineage[ 
        20, {2.458462043572085, 2.4862026095016123}, {{a, b, c, d}}, {1}, {}],
         
        AncestralLineage[ 
        21, {2.4862026095016123, 3.9524773177113115}, {{a, b, c, d}}, {
          1}, {}], 
        AncestralLineage[ 
        22, {3.9524773177113115, 4.0138506590066365}, {{a, b, c, d}, {}}, {
          0.98883751447983492, 1}, {}], 
        AncestralLineage[ 
        23, {3.9524773177113115, 4.0138506590066365}, {{}, {a, b, c, d}}, {
          0.98883751447983492, 1}, {}], 
        AncestralLineage[ 
        24, {4.0138506590066365, 5.7540904800752752}, {{a, b, c, d}}, {
          1}, {}], 
        AncestralLineage[ 
        25, {5.7540904800752752, 5.8356593067548443}, {{a, b, c, d}, {}}, {
          0.18912143960102942, 1}, {}], 
        AncestralLineage[ 
        26, {5.7540904800752752, 5.8356593067548443}, {{}, {a, b, c, d}}, {
          0.18912143960102942, 1}, {}], 
        AncestralLineage[ 
        27, {5.8356593067548443, 6.4604494260089078}, {{a, b, c, d}}, {
          1}, {}], 
        AncestralLineage[ 
        28, {6.4604494260089078, 7.0775598049183523}, {{a, b, c, d}, {}}, {
          0.35885002936128829, 1}, {}], 
        AncestralLineage[ 
        29, {6.4604494260089078, 7.0775598049183523}, {{}, {a, b, c, d}}, {
          0.35885002936128829, 1}, {}], 
        AncestralLineage[ 
        30, {7.0775598049183523, 9.3500560237994925}, {{a, b, c, d}}, {
          1}, {}], 
        AncestralLineage[ 
        31, {9.3500560237994925, 9.8894038967979672}, {{a, b, c, d}, {}}, {
          0.19223283439372979, 1}, {}], 
        AncestralLineage[ 
        32, {9.3500560237994925, 9.8894038967979672}, {{}, {a, b, c, d}}, {
          0.19223283439372979, 1}, {}], 
        AncestralLineage[ 
        33, {9.8894038967979672, 10.04865414492197}, {{a, b, c, d}}, {1}, {}],
         
        AncestralLineage[ 
        34, {10.04865414492197, 10.957847529079562}, {{a, b, c, d}, {}}, {
          0.27813911328582047, 1}, {}], 
        AncestralLineage[ 
        35, {10.04865414492197, 11.256831529989311}, {{}, {a, b, c, d}}, {
          0.27813911328582047, 1}, {}], 
        AncestralLineage[ 
        36, {10.957847529079562, 11.164561785838144}, {{a, b, c, d}, {}}, {
          0.27813911328582047, 1}, {}], 
        AncestralLineage[ 
        37, {10.957847529079562, 11.200948263910437}, {{}}, {1}, {}], 
        AncestralLineage[ 
        38, {11.164561785838144, 11.209929483491738}, {{a, b, c, d}, {}}, {
          0.27813911328582047, 1}, {}], 
        AncestralLineage[ 
        39, {11.164561785838144, 11.419143745929558}, {{}}, {1}, {}], 
        AncestralLineage[ 
        40, {11.200948263910437, 11.209929483491738}, {{}}, {1}, {}], 
        AncestralLineage[ 
        41, {11.200948263910437, 11.245270596164165}, {{}}, {1}, {}], 
        AncestralLineage[ 
        42, {11.209929483491738, 11.256831529989311}, {{a, b, c, d}, {}}, {
          0.27813911328582047, 1}, {}], 
        AncestralLineage[ 43, {11.245270596164165, 
          DirectedInfinity[ 1]}, {{}}, {1}, {}], 
        AncestralLineage[ 
        44, {11.245270596164165, 11.448204985318503}, {{}}, {1}, {}], 
        AncestralLineage[ 
        45, {11.256831529989311, 11.448204985318503}, {{a, b, c, d}}, {
          1}, {}], 
        AncestralLineage[ 46, {11.419143745929558, 
          DirectedInfinity[ 1]}, {{}}, {1}, {}], 
        AncestralLineage[ 47, {11.419143745929558, 
          DirectedInfinity[ 1]}, {{}}, {1}, {}], 
        AncestralLineage[ 48, {11.448204985318503, 
          DirectedInfinity[ 1]}, {{a, b, c, d}}, {1}, {}]}],
      Editable->False]], "Print",
  CellLabel->"From In[122]:="],

Cell[BoxData[
    \({11.608969128792605`, 5, 0.3685312554020764`}\)], "Print",
  CellLabel->"From In[122]:="],

Cell[BoxData[
    InterpretationBox[\("Recombining "\[InvisibleSpace]48\[InvisibleSpace]"; \
current lineages "\[InvisibleSpace]{43, 46, 47, 48}\),
      SequenceForm[ 
      "Recombining ", 48, "; current lineages ", {43, 46, 47, 48}],
      Editable->False]], "Print",
  CellLabel->"From In[122]:="],

Cell[BoxData[
    InterpretationBox[
      RowBox[{"\<\"G=\"\>", "\[InvisibleSpace]", 
        RowBox[{"{", 
          
          RowBox[{\(AncestralLineage[
              a, {0, 0.05710778878192141`}, {{a}}, {1}, {}]\), 
            ",", \(AncestralLineage[
              b, {0, 0.027696065882077705`}, {{b}}, {1}, {}]\), 
            ",", \(AncestralLineage[
              c, {0, 0.6214825149645679`}, {{c}}, {1}, {}]\), 
            ",", \(AncestralLineage[
              d, {0, 0.027696065882077705`}, {{d}}, {1}, {}]\), 
            ",", \(AncestralLineage[
              1, {0.027696065882077705`, 
                0.05710778878192141`}, {{b, d}}, {1}, {}]\), 
            ",", \(AncestralLineage[
              2, {0.05710778878192141`, 
                0.27049717829601805`}, {{a, b, d}}, {1}, {}]\), 
            ",", \(AncestralLineage[
              3, {0.27049717829601805`, 
                0.4292570949591068`}, {{a, b, d}, {}}, {0.01899643970468609`, 
                1}, {}]\), 
            ",", \(AncestralLineage[
              4, {0.27049717829601805`, 
                0.6214825149645679`}, {{}, {a, b, d}}, {0.01899643970468609`, 
                1}, {}]\), 
            ",", \(AncestralLineage[
              5, {0.4292570949591068`, 
                0.45951657742311824`}, {{a, b, 
                  d}, {}}, {0.01899643970468609`, 1}, {}]\), 
            ",", \(AncestralLineage[
              6, {0.4292570949591068`, 
                0.45951657742311824`}, {{}}, {1}, {}]\), 
            ",", \(AncestralLineage[
              7, {0.45951657742311824`, 
                0.6452036798471656`}, {{a, b, d}, {}}, {0.01899643970468609`, 
                1}, {}]\), 
            ",", \(AncestralLineage[
              8, {0.6214825149645679`, 
                0.6452036798471656`}, {{c}, {a, b, c, 
                  d}}, {0.01899643970468609`, 1}, {}]\), 
            ",", \(AncestralLineage[
              9, {0.6452036798471656`, 
                1.9706637158007017`}, {{a, b, c, d}}, {1}, {}]\), 
            ",", \(AncestralLineage[
              10, {1.9706637158007017`, 
                2.2897969825533644`}, {{a, b, c, 
                  d}, {}}, {0.9371981015363346`, 1}, {}]\), 
            ",", \(AncestralLineage[
              11, {1.9706637158007017`, 
                2.118015261702507`}, {{}, {a, b, c, 
                  d}}, {0.9371981015363346`, 1}, {}]\), 
            ",", \(AncestralLineage[
              12, {2.118015261702507`, 2.3758569290340006`}, {{}}, {1}, {}]\),
             ",", \(AncestralLineage[
              13, {2.118015261702507`, 
                2.228204237719424`}, {{}, {a, b, c, 
                  d}}, {0.9371981015363346`, 1}, {}]\), 
            ",", \(AncestralLineage[
              14, {2.228204237719424`, 2.2897969825533644`}, {{}}, {1}, {}]\),
             ",", \(AncestralLineage[
              15, {2.228204237719424`, 
                2.3639104415829926`}, {{}, {a, b, c, 
                  d}}, {0.9371981015363346`, 1}, {}]\), 
            ",", \(AncestralLineage[
              16, {2.2897969825533644`, 
                2.3639104415829926`}, {{a, b, c, 
                  d}, {}}, {0.9371981015363346`, 1}, {}]\), 
            ",", \(AncestralLineage[
              17, {2.3639104415829926`, 
                2.458462043572085`}, {{a, b, c, d}}, {1}, {}]\), 
            ",", \(AncestralLineage[
              18, {2.3758569290340006`, 2.458462043572085`}, {{}}, {1}, {}]\),
             ",", \(AncestralLineage[
              19, {2.3758569290340006`, 
                2.4862026095016123`}, {{}}, {1}, {}]\), 
            ",", \(AncestralLineage[
              20, {2.458462043572085`, 
                2.4862026095016123`}, {{a, b, c, d}}, {1}, {}]\), 
            ",", \(AncestralLineage[
              21, {2.4862026095016123`, 
                3.9524773177113115`}, {{a, b, c, d}}, {1}, {}]\), 
            ",", \(AncestralLineage[
              22, {3.9524773177113115`, 
                4.0138506590066365`}, {{a, b, c, 
                  d}, {}}, {0.9888375144798349`, 1}, {}]\), 
            ",", \(AncestralLineage[
              23, {3.9524773177113115`, 
                4.0138506590066365`}, {{}, {a, b, c, 
                  d}}, {0.9888375144798349`, 1}, {}]\), 
            ",", \(AncestralLineage[
              24, {4.0138506590066365`, 
                5.754090480075275`}, {{a, b, c, d}}, {1}, {}]\), 
            ",", \(AncestralLineage[
              25, {5.754090480075275`, 
                5.835659306754844`}, {{a, b, c, 
                  d}, {}}, {0.18912143960102942`, 1}, {}]\), 
            ",", \(AncestralLineage[
              26, {5.754090480075275`, 
                5.835659306754844`}, {{}, {a, b, c, 
                  d}}, {0.18912143960102942`, 1}, {}]\), 
            ",", \(AncestralLineage[
              27, {5.835659306754844`, 
                6.460449426008908`}, {{a, b, c, d}}, {1}, {}]\), 
            ",", \(AncestralLineage[
              28, {6.460449426008908`, 
                7.077559804918352`}, {{a, b, c, 
                  d}, {}}, {0.3588500293612883`, 1}, {}]\), 
            ",", \(AncestralLineage[
              29, {6.460449426008908`, 
                7.077559804918352`}, {{}, {a, b, c, 
                  d}}, {0.3588500293612883`, 1}, {}]\), 
            ",", \(AncestralLineage[
              30, {7.077559804918352`, 
                9.350056023799493`}, {{a, b, c, d}}, {1}, {}]\), 
            ",", \(AncestralLineage[
              31, {9.350056023799493`, 
                9.889403896797967`}, {{a, b, c, 
                  d}, {}}, {0.1922328343937298`, 1}, {}]\), 
            ",", \(AncestralLineage[
              32, {9.350056023799493`, 
                9.889403896797967`}, {{}, {a, b, c, 
                  d}}, {0.1922328343937298`, 1}, {}]\), 
            ",", \(AncestralLineage[
              33, {9.889403896797967`, 
                10.04865414492197`}, {{a, b, c, d}}, {1}, {}]\), 
            ",", \(AncestralLineage[
              34, {10.04865414492197`, 
                10.957847529079562`}, {{a, b, c, 
                  d}, {}}, {0.27813911328582047`, 1}, {}]\), 
            ",", \(AncestralLineage[
              35, {10.04865414492197`, 
                11.256831529989311`}, {{}, {a, b, c, 
                  d}}, {0.27813911328582047`, 1}, {}]\), 
            ",", \(AncestralLineage[
              36, {10.957847529079562`, 
                11.164561785838144`}, {{a, b, c, 
                  d}, {}}, {0.27813911328582047`, 1}, {}]\), 
            ",", \(AncestralLineage[
              37, {10.957847529079562`, 
                11.200948263910437`}, {{}}, {1}, {}]\), 
            ",", \(AncestralLineage[
              38, {11.164561785838144`, 
                11.209929483491738`}, {{a, b, c, 
                  d}, {}}, {0.27813911328582047`, 1}, {}]\), 
            ",", \(AncestralLineage[
              39, {11.164561785838144`, 
                11.419143745929558`}, {{}}, {1}, {}]\), 
            ",", \(AncestralLineage[
              40, {11.200948263910437`, 
                11.209929483491738`}, {{}}, {1}, {}]\), 
            ",", \(AncestralLineage[
              41, {11.200948263910437`, 
                11.245270596164165`}, {{}}, {1}, {}]\), 
            ",", \(AncestralLineage[
              42, {11.209929483491738`, 
                11.256831529989311`}, {{a, b, c, 
                  d}, {}}, {0.27813911328582047`, 1}, {}]\), ",", 
            RowBox[{"AncestralLineage", "[", 
              RowBox[{"43", ",", 
                RowBox[{"{", 
                  RowBox[{"11.245270596164165`", ",", 
                    InterpretationBox["\[Infinity]",
                      DirectedInfinity[ 1]]}], "}"}], ",", \({{}}\), 
                ",", \({1}\), ",", \({}\)}], "]"}], 
            ",", \(AncestralLineage[
              44, {11.245270596164165`, 
                11.448204985318503`}, {{}}, {1}, {}]\), 
            ",", \(AncestralLineage[
              45, {11.256831529989311`, 
                11.448204985318503`}, {{a, b, c, d}}, {1}, {}]\), ",", 
            RowBox[{"AncestralLineage", "[", 
              RowBox[{"46", ",", 
                RowBox[{"{", 
                  RowBox[{"11.419143745929558`", ",", 
                    InterpretationBox["\[Infinity]",
                      DirectedInfinity[ 1]]}], "}"}], ",", \({{}}\), 
                ",", \({1}\), ",", \({}\)}], "]"}], ",", 
            RowBox[{"AncestralLineage", "[", 
              RowBox[{"47", ",", 
                RowBox[{"{", 
                  RowBox[{"11.419143745929558`", ",", 
                    InterpretationBox["\[Infinity]",
                      DirectedInfinity[ 1]]}], "}"}], ",", \({{}}\), 
                ",", \({1}\), ",", \({}\)}], "]"}], 
            ",", \(AncestralLineage[
              48, {11.448204985318503`, 
                11.608969128792605`}, {{a, b, c, d}}, {1}, {}]\), ",", 
            RowBox[{"AncestralLineage", "[", 
              RowBox[{"49", ",", 
                RowBox[{"{", 
                  RowBox[{"11.608969128792605`", ",", 
                    InterpretationBox["\[Infinity]",
                      DirectedInfinity[ 1]]}], "}"}], 
                ",", \({{a, b, c, d}, {}}\), 
                ",", \({0.3685312554020764`, 1}\), ",", \({}\)}], "]"}], ",", 
            
            RowBox[{"AncestralLineage", "[", 
              RowBox[{"50", ",", 
                RowBox[{"{", 
                  RowBox[{"11.608969128792605`", ",", 
                    InterpretationBox["\[Infinity]",
                      DirectedInfinity[ 1]]}], "}"}], 
                ",", \({{}, {a, b, c, d}}\), 
                ",", \({0.3685312554020764`, 1}\), ",", \({}\)}], "]"}]}], 
          "}"}]}],
      SequenceForm[ "G=", {
        AncestralLineage[ a, {0, 0.057107788781921409}, {{a}}, {1}, {}], 
        AncestralLineage[ b, {0, 0.027696065882077705}, {{b}}, {1}, {}], 
        AncestralLineage[ c, {0, 0.62148251496456786}, {{c}}, {1}, {}], 
        AncestralLineage[ d, {0, 0.027696065882077705}, {{d}}, {1}, {}], 
        AncestralLineage[ 
        1, {0.027696065882077705, 0.057107788781921409}, {{b, d}}, {1}, {}], 
        AncestralLineage[ 
        2, {0.057107788781921409, 0.27049717829601805}, {{a, b, d}}, {1}, {}],
         
        AncestralLineage[ 
        3, {0.27049717829601805, 0.4292570949591068}, {{a, b, d}, {}}, {
          0.018996439704686091, 1}, {}], 
        AncestralLineage[ 
        4, {0.27049717829601805, 0.62148251496456786}, {{}, {a, b, d}}, {
          0.018996439704686091, 1}, {}], 
        AncestralLineage[ 
        5, {0.4292570949591068, 0.45951657742311824}, {{a, b, d}, {}}, {
          0.018996439704686091, 1}, {}], 
        AncestralLineage[ 
        6, {0.4292570949591068, 0.45951657742311824}, {{}}, {1}, {}], 
        AncestralLineage[ 
        7, {0.45951657742311824, 0.64520367984716565}, {{a, b, d}, {}}, {
          0.018996439704686091, 1}, {}], 
        AncestralLineage[ 
        8, {0.62148251496456786, 0.64520367984716565}, {{c}, {a, b, c, d}}, {
          0.018996439704686091, 1}, {}], 
        AncestralLineage[ 
        9, {0.64520367984716565, 1.9706637158007017}, {{a, b, c, d}}, {
          1}, {}], 
        AncestralLineage[ 
        10, {1.9706637158007017, 2.2897969825533644}, {{a, b, c, d}, {}}, {
          0.93719810153633465, 1}, {}], 
        AncestralLineage[ 
        11, {1.9706637158007017, 2.118015261702507}, {{}, {a, b, c, d}}, {
          0.93719810153633465, 1}, {}], 
        AncestralLineage[ 
        12, {2.118015261702507, 2.3758569290340006}, {{}}, {1}, {}], 
        AncestralLineage[ 
        13, {2.118015261702507, 2.228204237719424}, {{}, {a, b, c, d}}, {
          0.93719810153633465, 1}, {}], 
        AncestralLineage[ 
        14, {2.228204237719424, 2.2897969825533644}, {{}}, {1}, {}], 
        AncestralLineage[ 
        15, {2.228204237719424, 2.3639104415829926}, {{}, {a, b, c, d}}, {
          0.93719810153633465, 1}, {}], 
        AncestralLineage[ 
        16, {2.2897969825533644, 2.3639104415829926}, {{a, b, c, d}, {}}, {
          0.93719810153633465, 1}, {}], 
        AncestralLineage[ 
        17, {2.3639104415829926, 2.458462043572085}, {{a, b, c, d}}, {1}, {}],
         
        AncestralLineage[ 
        18, {2.3758569290340006, 2.458462043572085}, {{}}, {1}, {}], 
        AncestralLineage[ 
        19, {2.3758569290340006, 2.4862026095016123}, {{}}, {1}, {}], 
        AncestralLineage[ 
        20, {2.458462043572085, 2.4862026095016123}, {{a, b, c, d}}, {1}, {}],
         
        AncestralLineage[ 
        21, {2.4862026095016123, 3.9524773177113115}, {{a, b, c, d}}, {
          1}, {}], 
        AncestralLineage[ 
        22, {3.9524773177113115, 4.0138506590066365}, {{a, b, c, d}, {}}, {
          0.98883751447983492, 1}, {}], 
        AncestralLineage[ 
        23, {3.9524773177113115, 4.0138506590066365}, {{}, {a, b, c, d}}, {
          0.98883751447983492, 1}, {}], 
        AncestralLineage[ 
        24, {4.0138506590066365, 5.7540904800752752}, {{a, b, c, d}}, {
          1}, {}], 
        AncestralLineage[ 
        25, {5.7540904800752752, 5.8356593067548443}, {{a, b, c, d}, {}}, {
          0.18912143960102942, 1}, {}], 
        AncestralLineage[ 
        26, {5.7540904800752752, 5.8356593067548443}, {{}, {a, b, c, d}}, {
          0.18912143960102942, 1}, {}], 
        AncestralLineage[ 
        27, {5.8356593067548443, 6.4604494260089078}, {{a, b, c, d}}, {
          1}, {}], 
        AncestralLineage[ 
        28, {6.4604494260089078, 7.0775598049183523}, {{a, b, c, d}, {}}, {
          0.35885002936128829, 1}, {}], 
        AncestralLineage[ 
        29, {6.4604494260089078, 7.0775598049183523}, {{}, {a, b, c, d}}, {
          0.35885002936128829, 1}, {}], 
        AncestralLineage[ 
        30, {7.0775598049183523, 9.3500560237994925}, {{a, b, c, d}}, {
          1}, {}], 
        AncestralLineage[ 
        31, {9.3500560237994925, 9.8894038967979672}, {{a, b, c, d}, {}}, {
          0.19223283439372979, 1}, {}], 
        AncestralLineage[ 
        32, {9.3500560237994925, 9.8894038967979672}, {{}, {a, b, c, d}}, {
          0.19223283439372979, 1}, {}], 
        AncestralLineage[ 
        33, {9.8894038967979672, 10.04865414492197}, {{a, b, c, d}}, {1}, {}],
         
        AncestralLineage[ 
        34, {10.04865414492197, 10.957847529079562}, {{a, b, c, d}, {}}, {
          0.27813911328582047, 1}, {}], 
        AncestralLineage[ 
        35, {10.04865414492197, 11.256831529989311}, {{}, {a, b, c, d}}, {
          0.27813911328582047, 1}, {}], 
        AncestralLineage[ 
        36, {10.957847529079562, 11.164561785838144}, {{a, b, c, d}, {}}, {
          0.27813911328582047, 1}, {}], 
        AncestralLineage[ 
        37, {10.957847529079562, 11.200948263910437}, {{}}, {1}, {}], 
        AncestralLineage[ 
        38, {11.164561785838144, 11.209929483491738}, {{a, b, c, d}, {}}, {
          0.27813911328582047, 1}, {}], 
        AncestralLineage[ 
        39, {11.164561785838144, 11.419143745929558}, {{}}, {1}, {}], 
        AncestralLineage[ 
        40, {11.200948263910437, 11.209929483491738}, {{}}, {1}, {}], 
        AncestralLineage[ 
        41, {11.200948263910437, 11.245270596164165}, {{}}, {1}, {}], 
        AncestralLineage[ 
        42, {11.209929483491738, 11.256831529989311}, {{a, b, c, d}, {}}, {
          0.27813911328582047, 1}, {}], 
        AncestralLineage[ 43, {11.245270596164165, 
          DirectedInfinity[ 1]}, {{}}, {1}, {}], 
        AncestralLineage[ 
        44, {11.245270596164165, 11.448204985318503}, {{}}, {1}, {}], 
        AncestralLineage[ 
        45, {11.256831529989311, 11.448204985318503}, {{a, b, c, d}}, {
          1}, {}], 
        AncestralLineage[ 46, {11.419143745929558, 
          DirectedInfinity[ 1]}, {{}}, {1}, {}], 
        AncestralLineage[ 47, {11.419143745929558, 
          DirectedInfinity[ 1]}, {{}}, {1}, {}], 
        AncestralLineage[ 
        48, {11.448204985318503, 11.608969128792605}, {{a, b, c, d}}, {
          1}, {}], 
        AncestralLineage[ 49, {11.608969128792605, 
          DirectedInfinity[ 1]}, {{a, b, c, d}, {}}, {0.36853125540207637, 
          1}, {}], 
        AncestralLineage[ 50, {11.608969128792605, 
          DirectedInfinity[ 1]}, {{}, {a, b, c, d}}, {0.36853125540207637, 
          1}, {}]}],
      Editable->False]], "Print",
  CellLabel->"From In[122]:="],

Cell[BoxData[
    \({11.692858213787188`, 4, None}\)], "Print",
  CellLabel->"From In[122]:="],

Cell[BoxData[
    InterpretationBox[\("Coalescing "\[InvisibleSpace]{43, 
          47}\[InvisibleSpace]"; current lineages "\[InvisibleSpace]{43, 46, 
          47, 49, 50}\),
      SequenceForm[ 
      "Coalescing ", {43, 47}, "; current lineages ", {43, 46, 47, 49, 50}],
      Editable->False]], "Print",
  CellLabel->"From In[122]:="],

Cell[BoxData[
    InterpretationBox[
      RowBox[{"\<\"G=\"\>", "\[InvisibleSpace]", 
        RowBox[{"{", 
          
          RowBox[{\(AncestralLineage[
              a, {0, 0.05710778878192141`}, {{a}}, {1}, {}]\), 
            ",", \(AncestralLineage[
              b, {0, 0.027696065882077705`}, {{b}}, {1}, {}]\), 
            ",", \(AncestralLineage[
              c, {0, 0.6214825149645679`}, {{c}}, {1}, {}]\), 
            ",", \(AncestralLineage[
              d, {0, 0.027696065882077705`}, {{d}}, {1}, {}]\), 
            ",", \(AncestralLineage[
              1, {0.027696065882077705`, 
                0.05710778878192141`}, {{b, d}}, {1}, {}]\), 
            ",", \(AncestralLineage[
              2, {0.05710778878192141`, 
                0.27049717829601805`}, {{a, b, d}}, {1}, {}]\), 
            ",", \(AncestralLineage[
              3, {0.27049717829601805`, 
                0.4292570949591068`}, {{a, b, d}, {}}, {0.01899643970468609`, 
                1}, {}]\), 
            ",", \(AncestralLineage[
              4, {0.27049717829601805`, 
                0.6214825149645679`}, {{}, {a, b, d}}, {0.01899643970468609`, 
                1}, {}]\), 
            ",", \(AncestralLineage[
              5, {0.4292570949591068`, 
                0.45951657742311824`}, {{a, b, 
                  d}, {}}, {0.01899643970468609`, 1}, {}]\), 
            ",", \(AncestralLineage[
              6, {0.4292570949591068`, 
                0.45951657742311824`}, {{}}, {1}, {}]\), 
            ",", \(AncestralLineage[
              7, {0.45951657742311824`, 
                0.6452036798471656`}, {{a, b, d}, {}}, {0.01899643970468609`, 
                1}, {}]\), 
            ",", \(AncestralLineage[
              8, {0.6214825149645679`, 
                0.6452036798471656`}, {{c}, {a, b, c, 
                  d}}, {0.01899643970468609`, 1}, {}]\), 
            ",", \(AncestralLineage[
              9, {0.6452036798471656`, 
                1.9706637158007017`}, {{a, b, c, d}}, {1}, {}]\), 
            ",", \(AncestralLineage[
              10, {1.9706637158007017`, 
                2.2897969825533644`}, {{a, b, c, 
                  d}, {}}, {0.9371981015363346`, 1}, {}]\), 
            ",", \(AncestralLineage[
              11, {1.9706637158007017`, 
                2.118015261702507`}, {{}, {a, b, c, 
                  d}}, {0.9371981015363346`, 1}, {}]\), 
            ",", \(AncestralLineage[
              12, {2.118015261702507`, 2.3758569290340006`}, {{}}, {1}, {}]\),
             ",", \(AncestralLineage[
              13, {2.118015261702507`, 
                2.228204237719424`}, {{}, {a, b, c, 
                  d}}, {0.9371981015363346`, 1}, {}]\), 
            ",", \(AncestralLineage[
              14, {2.228204237719424`, 2.2897969825533644`}, {{}}, {1}, {}]\),
             ",", \(AncestralLineage[
              15, {2.228204237719424`, 
                2.3639104415829926`}, {{}, {a, b, c, 
                  d}}, {0.9371981015363346`, 1}, {}]\), 
            ",", \(AncestralLineage[
              16, {2.2897969825533644`, 
                2.3639104415829926`}, {{a, b, c, 
                  d}, {}}, {0.9371981015363346`, 1}, {}]\), 
            ",", \(AncestralLineage[
              17, {2.3639104415829926`, 
                2.458462043572085`}, {{a, b, c, d}}, {1}, {}]\), 
            ",", \(AncestralLineage[
              18, {2.3758569290340006`, 2.458462043572085`}, {{}}, {1}, {}]\),
             ",", \(AncestralLineage[
              19, {2.3758569290340006`, 
                2.4862026095016123`}, {{}}, {1}, {}]\), 
            ",", \(AncestralLineage[
              20, {2.458462043572085`, 
                2.4862026095016123`}, {{a, b, c, d}}, {1}, {}]\), 
            ",", \(AncestralLineage[
              21, {2.4862026095016123`, 
                3.9524773177113115`}, {{a, b, c, d}}, {1}, {}]\), 
            ",", \(AncestralLineage[
              22, {3.9524773177113115`, 
                4.0138506590066365`}, {{a, b, c, 
                  d}, {}}, {0.9888375144798349`, 1}, {}]\), 
            ",", \(AncestralLineage[
              23, {3.9524773177113115`, 
                4.0138506590066365`}, {{}, {a, b, c, 
                  d}}, {0.9888375144798349`, 1}, {}]\), 
            ",", \(AncestralLineage[
              24, {4.0138506590066365`, 
                5.754090480075275`}, {{a, b, c, d}}, {1}, {}]\), 
            ",", \(AncestralLineage[
              25, {5.754090480075275`, 
                5.835659306754844`}, {{a, b, c, 
                  d}, {}}, {0.18912143960102942`, 1}, {}]\), 
            ",", \(AncestralLineage[
              26, {5.754090480075275`, 
                5.835659306754844`}, {{}, {a, b, c, 
                  d}}, {0.18912143960102942`, 1}, {}]\), 
            ",", \(AncestralLineage[
              27, {5.835659306754844`, 
                6.460449426008908`}, {{a, b, c, d}}, {1}, {}]\), 
            ",", \(AncestralLineage[
              28, {6.460449426008908`, 
                7.077559804918352`}, {{a, b, c, 
                  d}, {}}, {0.3588500293612883`, 1}, {}]\), 
            ",", \(AncestralLineage[
              29, {6.460449426008908`, 
                7.077559804918352`}, {{}, {a, b, c, 
                  d}}, {0.3588500293612883`, 1}, {}]\), 
            ",", \(AncestralLineage[
              30, {7.077559804918352`, 
                9.350056023799493`}, {{a, b, c, d}}, {1}, {}]\), 
            ",", \(AncestralLineage[
              31, {9.350056023799493`, 
                9.889403896797967`}, {{a, b, c, 
                  d}, {}}, {0.1922328343937298`, 1}, {}]\), 
            ",", \(AncestralLineage[
              32, {9.350056023799493`, 
                9.889403896797967`}, {{}, {a, b, c, 
                  d}}, {0.1922328343937298`, 1}, {}]\), 
            ",", \(AncestralLineage[
              33, {9.889403896797967`, 
                10.04865414492197`}, {{a, b, c, d}}, {1}, {}]\), 
            ",", \(AncestralLineage[
              34, {10.04865414492197`, 
                10.957847529079562`}, {{a, b, c, 
                  d}, {}}, {0.27813911328582047`, 1}, {}]\), 
            ",", \(AncestralLineage[
              35, {10.04865414492197`, 
                11.256831529989311`}, {{}, {a, b, c, 
                  d}}, {0.27813911328582047`, 1}, {}]\), 
            ",", \(AncestralLineage[
              36, {10.957847529079562`, 
                11.164561785838144`}, {{a, b, c, 
                  d}, {}}, {0.27813911328582047`, 1}, {}]\), 
            ",", \(AncestralLineage[
              37, {10.957847529079562`, 
                11.200948263910437`}, {{}}, {1}, {}]\), 
            ",", \(AncestralLineage[
              38, {11.164561785838144`, 
                11.209929483491738`}, {{a, b, c, 
                  d}, {}}, {0.27813911328582047`, 1}, {}]\), 
            ",", \(AncestralLineage[
              39, {11.164561785838144`, 
                11.419143745929558`}, {{}}, {1}, {}]\), 
            ",", \(AncestralLineage[
              40, {11.200948263910437`, 
                11.209929483491738`}, {{}}, {1}, {}]\), 
            ",", \(AncestralLineage[
              41, {11.200948263910437`, 
                11.245270596164165`}, {{}}, {1}, {}]\), 
            ",", \(AncestralLineage[
              42, {11.209929483491738`, 
                11.256831529989311`}, {{a, b, c, 
                  d}, {}}, {0.27813911328582047`, 1}, {}]\), 
            ",", \(AncestralLineage[
              43, {11.245270596164165`, 
                11.692858213787188`}, {{}}, {1}, {}]\), 
            ",", \(AncestralLineage[
              44, {11.245270596164165`, 
                11.448204985318503`}, {{}}, {1}, {}]\), 
            ",", \(AncestralLineage[
              45, {11.256831529989311`, 
                11.448204985318503`}, {{a, b, c, d}}, {1}, {}]\), ",", 
            RowBox[{"AncestralLineage", "[", 
              RowBox[{"46", ",", 
                RowBox[{"{", 
                  RowBox[{"11.419143745929558`", ",", 
                    InterpretationBox["\[Infinity]",
                      DirectedInfinity[ 1]]}], "}"}], ",", \({{}}\), 
                ",", \({1}\), ",", \({}\)}], "]"}], 
            ",", \(AncestralLineage[
              47, {11.419143745929558`, 
                11.692858213787188`}, {{}}, {1}, {}]\), 
            ",", \(AncestralLineage[
              48, {11.448204985318503`, 
                11.608969128792605`}, {{a, b, c, d}}, {1}, {}]\), ",", 
            RowBox[{"AncestralLineage", "[", 
              RowBox[{"49", ",", 
                RowBox[{"{", 
                  RowBox[{"11.608969128792605`", ",", 
                    InterpretationBox["\[Infinity]",
                      DirectedInfinity[ 1]]}], "}"}], 
                ",", \({{a, b, c, d}, {}}\), 
                ",", \({0.3685312554020764`, 1}\), ",", \({}\)}], "]"}], ",", 
            
            RowBox[{"AncestralLineage", "[", 
              RowBox[{"50", ",", 
                RowBox[{"{", 
                  RowBox[{"11.608969128792605`", ",", 
                    InterpretationBox["\[Infinity]",
                      DirectedInfinity[ 1]]}], "}"}], 
                ",", \({{}, {a, b, c, d}}\), 
                ",", \({0.3685312554020764`, 1}\), ",", \({}\)}], "]"}], ",", 
            
            RowBox[{"AncestralLineage", "[", 
              RowBox[{"51", ",", 
                RowBox[{"{", 
                  RowBox[{"11.692858213787188`", ",", 
                    InterpretationBox["\[Infinity]",
                      DirectedInfinity[ 1]]}], "}"}], ",", \({{}}\), 
                ",", \({1}\), ",", \({}\)}], "]"}]}], "}"}]}],
      SequenceForm[ "G=", {
        AncestralLineage[ a, {0, 0.057107788781921409}, {{a}}, {1}, {}], 
        AncestralLineage[ b, {0, 0.027696065882077705}, {{b}}, {1}, {}], 
        AncestralLineage[ c, {0, 0.62148251496456786}, {{c}}, {1}, {}], 
        AncestralLineage[ d, {0, 0.027696065882077705}, {{d}}, {1}, {}], 
        AncestralLineage[ 
        1, {0.027696065882077705, 0.057107788781921409}, {{b, d}}, {1}, {}], 
        AncestralLineage[ 
        2, {0.057107788781921409, 0.27049717829601805}, {{a, b, d}}, {1}, {}],
         
        AncestralLineage[ 
        3, {0.27049717829601805, 0.4292570949591068}, {{a, b, d}, {}}, {
          0.018996439704686091, 1}, {}], 
        AncestralLineage[ 
        4, {0.27049717829601805, 0.62148251496456786}, {{}, {a, b, d}}, {
          0.018996439704686091, 1}, {}], 
        AncestralLineage[ 
        5, {0.4292570949591068, 0.45951657742311824}, {{a, b, d}, {}}, {
          0.018996439704686091, 1}, {}], 
        AncestralLineage[ 
        6, {0.4292570949591068, 0.45951657742311824}, {{}}, {1}, {}], 
        AncestralLineage[ 
        7, {0.45951657742311824, 0.64520367984716565}, {{a, b, d}, {}}, {
          0.018996439704686091, 1}, {}], 
        AncestralLineage[ 
        8, {0.62148251496456786, 0.64520367984716565}, {{c}, {a, b, c, d}}, {
          0.018996439704686091, 1}, {}], 
        AncestralLineage[ 
        9, {0.64520367984716565, 1.9706637158007017}, {{a, b, c, d}}, {
          1}, {}], 
        AncestralLineage[ 
        10, {1.9706637158007017, 2.2897969825533644}, {{a, b, c, d}, {}}, {
          0.93719810153633465, 1}, {}], 
        AncestralLineage[ 
        11, {1.9706637158007017, 2.118015261702507}, {{}, {a, b, c, d}}, {
          0.93719810153633465, 1}, {}], 
        AncestralLineage[ 
        12, {2.118015261702507, 2.3758569290340006}, {{}}, {1}, {}], 
        AncestralLineage[ 
        13, {2.118015261702507, 2.228204237719424}, {{}, {a, b, c, d}}, {
          0.93719810153633465, 1}, {}], 
        AncestralLineage[ 
        14, {2.228204237719424, 2.2897969825533644}, {{}}, {1}, {}], 
        AncestralLineage[ 
        15, {2.228204237719424, 2.3639104415829926}, {{}, {a, b, c, d}}, {
          0.93719810153633465, 1}, {}], 
        AncestralLineage[ 
        16, {2.2897969825533644, 2.3639104415829926}, {{a, b, c, d}, {}}, {
          0.93719810153633465, 1}, {}], 
        AncestralLineage[ 
        17, {2.3639104415829926, 2.458462043572085}, {{a, b, c, d}}, {1}, {}],
         
        AncestralLineage[ 
        18, {2.3758569290340006, 2.458462043572085}, {{}}, {1}, {}], 
        AncestralLineage[ 
        19, {2.3758569290340006, 2.4862026095016123}, {{}}, {1}, {}], 
        AncestralLineage[ 
        20, {2.458462043572085, 2.4862026095016123}, {{a, b, c, d}}, {1}, {}],
         
        AncestralLineage[ 
        21, {2.4862026095016123, 3.9524773177113115}, {{a, b, c, d}}, {
          1}, {}], 
        AncestralLineage[ 
        22, {3.9524773177113115, 4.0138506590066365}, {{a, b, c, d}, {}}, {
          0.98883751447983492, 1}, {}], 
        AncestralLineage[ 
        23, {3.9524773177113115, 4.0138506590066365}, {{}, {a, b, c, d}}, {
          0.98883751447983492, 1}, {}], 
        AncestralLineage[ 
        24, {4.0138506590066365, 5.7540904800752752}, {{a, b, c, d}}, {
          1}, {}], 
        AncestralLineage[ 
        25, {5.7540904800752752, 5.8356593067548443}, {{a, b, c, d}, {}}, {
          0.18912143960102942, 1}, {}], 
        AncestralLineage[ 
        26, {5.7540904800752752, 5.8356593067548443}, {{}, {a, b, c, d}}, {
          0.18912143960102942, 1}, {}], 
        AncestralLineage[ 
        27, {5.8356593067548443, 6.4604494260089078}, {{a, b, c, d}}, {
          1}, {}], 
        AncestralLineage[ 
        28, {6.4604494260089078, 7.0775598049183523}, {{a, b, c, d}, {}}, {
          0.35885002936128829, 1}, {}], 
        AncestralLineage[ 
        29, {6.4604494260089078, 7.0775598049183523}, {{}, {a, b, c, d}}, {
          0.35885002936128829, 1}, {}], 
        AncestralLineage[ 
        30, {7.0775598049183523, 9.3500560237994925}, {{a, b, c, d}}, {
          1}, {}], 
        AncestralLineage[ 
        31, {9.3500560237994925, 9.8894038967979672}, {{a, b, c, d}, {}}, {
          0.19223283439372979, 1}, {}], 
        AncestralLineage[ 
        32, {9.3500560237994925, 9.8894038967979672}, {{}, {a, b, c, d}}, {
          0.19223283439372979, 1}, {}], 
        AncestralLineage[ 
        33, {9.8894038967979672, 10.04865414492197}, {{a, b, c, d}}, {1}, {}],
         
        AncestralLineage[ 
        34, {10.04865414492197, 10.957847529079562}, {{a, b, c, d}, {}}, {
          0.27813911328582047, 1}, {}], 
        AncestralLineage[ 
        35, {10.04865414492197, 11.256831529989311}, {{}, {a, b, c, d}}, {
          0.27813911328582047, 1}, {}], 
        AncestralLineage[ 
        36, {10.957847529079562, 11.164561785838144}, {{a, b, c, d}, {}}, {
          0.27813911328582047, 1}, {}], 
        AncestralLineage[ 
        37, {10.957847529079562, 11.200948263910437}, {{}}, {1}, {}], 
        AncestralLineage[ 
        38, {11.164561785838144, 11.209929483491738}, {{a, b, c, d}, {}}, {
          0.27813911328582047, 1}, {}], 
        AncestralLineage[ 
        39, {11.164561785838144, 11.419143745929558}, {{}}, {1}, {}], 
        AncestralLineage[ 
        40, {11.200948263910437, 11.209929483491738}, {{}}, {1}, {}], 
        AncestralLineage[ 
        41, {11.200948263910437, 11.245270596164165}, {{}}, {1}, {}], 
        AncestralLineage[ 
        42, {11.209929483491738, 11.256831529989311}, {{a, b, c, d}, {}}, {
          0.27813911328582047, 1}, {}], 
        AncestralLineage[ 
        43, {11.245270596164165, 11.692858213787188}, {{}}, {1}, {}], 
        AncestralLineage[ 
        44, {11.245270596164165, 11.448204985318503}, {{}}, {1}, {}], 
        AncestralLineage[ 
        45, {11.256831529989311, 11.448204985318503}, {{a, b, c, d}}, {
          1}, {}], 
        AncestralLineage[ 46, {11.419143745929558, 
          DirectedInfinity[ 1]}, {{}}, {1}, {}], 
        AncestralLineage[ 
        47, {11.419143745929558, 11.692858213787188}, {{}}, {1}, {}], 
        AncestralLineage[ 
        48, {11.448204985318503, 11.608969128792605}, {{a, b, c, d}}, {
          1}, {}], 
        AncestralLineage[ 49, {11.608969128792605, 
          DirectedInfinity[ 1]}, {{a, b, c, d}, {}}, {0.36853125540207637, 
          1}, {}], 
        AncestralLineage[ 50, {11.608969128792605, 
          DirectedInfinity[ 1]}, {{}, {a, b, c, d}}, {0.36853125540207637, 
          1}, {}], 
        AncestralLineage[ 51, {11.692858213787188, 
          DirectedInfinity[ 1]}, {{}}, {1}, {}]}],
      Editable->False]], "Print",
  CellLabel->"From In[122]:="],

Cell[BoxData[
    \({11.875115781439789`, 5, 0.05058499775091726`}\)], "Print",
  CellLabel->"From In[122]:="],

Cell[BoxData[
    InterpretationBox[\("Recombining "\[InvisibleSpace]46\[InvisibleSpace]"; \
current lineages "\[InvisibleSpace]{46, 49, 50, 51}\),
      SequenceForm[ 
      "Recombining ", 46, "; current lineages ", {46, 49, 50, 51}],
      Editable->False]], "Print",
  CellLabel->"From In[122]:="],

Cell[BoxData[
    InterpretationBox[
      RowBox[{"\<\"G=\"\>", "\[InvisibleSpace]", 
        RowBox[{"{", 
          
          RowBox[{\(AncestralLineage[
              a, {0, 0.05710778878192141`}, {{a}}, {1}, {}]\), 
            ",", \(AncestralLineage[
              b, {0, 0.027696065882077705`}, {{b}}, {1}, {}]\), 
            ",", \(AncestralLineage[
              c, {0, 0.6214825149645679`}, {{c}}, {1}, {}]\), 
            ",", \(AncestralLineage[
              d, {0, 0.027696065882077705`}, {{d}}, {1}, {}]\), 
            ",", \(AncestralLineage[
              1, {0.027696065882077705`, 
                0.05710778878192141`}, {{b, d}}, {1}, {}]\), 
            ",", \(AncestralLineage[
              2, {0.05710778878192141`, 
                0.27049717829601805`}, {{a, b, d}}, {1}, {}]\), 
            ",", \(AncestralLineage[
              3, {0.27049717829601805`, 
                0.4292570949591068`}, {{a, b, d}, {}}, {0.01899643970468609`, 
                1}, {}]\), 
            ",", \(AncestralLineage[
              4, {0.27049717829601805`, 
                0.6214825149645679`}, {{}, {a, b, d}}, {0.01899643970468609`, 
                1}, {}]\), 
            ",", \(AncestralLineage[
              5, {0.4292570949591068`, 
                0.45951657742311824`}, {{a, b, 
                  d}, {}}, {0.01899643970468609`, 1}, {}]\), 
            ",", \(AncestralLineage[
              6, {0.4292570949591068`, 
                0.45951657742311824`}, {{}}, {1}, {}]\), 
            ",", \(AncestralLineage[
              7, {0.45951657742311824`, 
                0.6452036798471656`}, {{a, b, d}, {}}, {0.01899643970468609`, 
                1}, {}]\), 
            ",", \(AncestralLineage[
              8, {0.6214825149645679`, 
                0.6452036798471656`}, {{c}, {a, b, c, 
                  d}}, {0.01899643970468609`, 1}, {}]\), 
            ",", \(AncestralLineage[
              9, {0.6452036798471656`, 
                1.9706637158007017`}, {{a, b, c, d}}, {1}, {}]\), 
            ",", \(AncestralLineage[
              10, {1.9706637158007017`, 
                2.2897969825533644`}, {{a, b, c, 
                  d}, {}}, {0.9371981015363346`, 1}, {}]\), 
            ",", \(AncestralLineage[
              11, {1.9706637158007017`, 
                2.118015261702507`}, {{}, {a, b, c, 
                  d}}, {0.9371981015363346`, 1}, {}]\), 
            ",", \(AncestralLineage[
              12, {2.118015261702507`, 2.3758569290340006`}, {{}}, {1}, {}]\),
             ",", \(AncestralLineage[
              13, {2.118015261702507`, 
                2.228204237719424`}, {{}, {a, b, c, 
                  d}}, {0.9371981015363346`, 1}, {}]\), 
            ",", \(AncestralLineage[
              14, {2.228204237719424`, 2.2897969825533644`}, {{}}, {1}, {}]\),
             ",", \(AncestralLineage[
              15, {2.228204237719424`, 
                2.3639104415829926`}, {{}, {a, b, c, 
                  d}}, {0.9371981015363346`, 1}, {}]\), 
            ",", \(AncestralLineage[
              16, {2.2897969825533644`, 
                2.3639104415829926`}, {{a, b, c, 
                  d}, {}}, {0.9371981015363346`, 1}, {}]\), 
            ",", \(AncestralLineage[
              17, {2.3639104415829926`, 
                2.458462043572085`}, {{a, b, c, d}}, {1}, {}]\), 
            ",", \(AncestralLineage[
              18, {2.3758569290340006`, 2.458462043572085`}, {{}}, {1}, {}]\),
             ",", \(AncestralLineage[
              19, {2.3758569290340006`, 
                2.4862026095016123`}, {{}}, {1}, {}]\), 
            ",", \(AncestralLineage[
              20, {2.458462043572085`, 
                2.4862026095016123`}, {{a, b, c, d}}, {1}, {}]\), 
            ",", \(AncestralLineage[
              21, {2.4862026095016123`, 
                3.9524773177113115`}, {{a, b, c, d}}, {1}, {}]\), 
            ",", \(AncestralLineage[
              22, {3.9524773177113115`, 
                4.0138506590066365`}, {{a, b, c, 
                  d}, {}}, {0.9888375144798349`, 1}, {}]\), 
            ",", \(AncestralLineage[
              23, {3.9524773177113115`, 
                4.0138506590066365`}, {{}, {a, b, c, 
                  d}}, {0.9888375144798349`, 1}, {}]\), 
            ",", \(AncestralLineage[
              24, {4.0138506590066365`, 
                5.754090480075275`}, {{a, b, c, d}}, {1}, {}]\), 
            ",", \(AncestralLineage[
              25, {5.754090480075275`, 
                5.835659306754844`}, {{a, b, c, 
                  d}, {}}, {0.18912143960102942`, 1}, {}]\), 
            ",", \(AncestralLineage[
              26, {5.754090480075275`, 
                5.835659306754844`}, {{}, {a, b, c, 
                  d}}, {0.18912143960102942`, 1}, {}]\), 
            ",", \(AncestralLineage[
              27, {5.835659306754844`, 
                6.460449426008908`}, {{a, b, c, d}}, {1}, {}]\), 
            ",", \(AncestralLineage[
              28, {6.460449426008908`, 
                7.077559804918352`}, {{a, b, c, 
                  d}, {}}, {0.3588500293612883`, 1}, {}]\), 
            ",", \(AncestralLineage[
              29, {6.460449426008908`, 
                7.077559804918352`}, {{}, {a, b, c, 
                  d}}, {0.3588500293612883`, 1}, {}]\), 
            ",", \(AncestralLineage[
              30, {7.077559804918352`, 
                9.350056023799493`}, {{a, b, c, d}}, {1}, {}]\), 
            ",", \(AncestralLineage[
              31, {9.350056023799493`, 
                9.889403896797967`}, {{a, b, c, 
                  d}, {}}, {0.1922328343937298`, 1}, {}]\), 
            ",", \(AncestralLineage[
              32, {9.350056023799493`, 
                9.889403896797967`}, {{}, {a, b, c, 
                  d}}, {0.1922328343937298`, 1}, {}]\), 
            ",", \(AncestralLineage[
              33, {9.889403896797967`, 
                10.04865414492197`}, {{a, b, c, d}}, {1}, {}]\), 
            ",", \(AncestralLineage[
              34, {10.04865414492197`, 
                10.957847529079562`}, {{a, b, c, 
                  d}, {}}, {0.27813911328582047`, 1}, {}]\), 
            ",", \(AncestralLineage[
              35, {10.04865414492197`, 
                11.256831529989311`}, {{}, {a, b, c, 
                  d}}, {0.27813911328582047`, 1}, {}]\), 
            ",", \(AncestralLineage[
              36, {10.957847529079562`, 
                11.164561785838144`}, {{a, b, c, 
                  d}, {}}, {0.27813911328582047`, 1}, {}]\), 
            ",", \(AncestralLineage[
              37, {10.957847529079562`, 
                11.200948263910437`}, {{}}, {1}, {}]\), 
            ",", \(AncestralLineage[
              38, {11.164561785838144`, 
                11.209929483491738`}, {{a, b, c, 
                  d}, {}}, {0.27813911328582047`, 1}, {}]\), 
            ",", \(AncestralLineage[
              39, {11.164561785838144`, 
                11.419143745929558`}, {{}}, {1}, {}]\), 
            ",", \(AncestralLineage[
              40, {11.200948263910437`, 
                11.209929483491738`}, {{}}, {1}, {}]\), 
            ",", \(AncestralLineage[
              41, {11.200948263910437`, 
                11.245270596164165`}, {{}}, {1}, {}]\), 
            ",", \(AncestralLineage[
              42, {11.209929483491738`, 
                11.256831529989311`}, {{a, b, c, 
                  d}, {}}, {0.27813911328582047`, 1}, {}]\), 
            ",", \(AncestralLineage[
              43, {11.245270596164165`, 
                11.692858213787188`}, {{}}, {1}, {}]\), 
            ",", \(AncestralLineage[
              44, {11.245270596164165`, 
                11.448204985318503`}, {{}}, {1}, {}]\), 
            ",", \(AncestralLineage[
              45, {11.256831529989311`, 
                11.448204985318503`}, {{a, b, c, d}}, {1}, {}]\), 
            ",", \(AncestralLineage[
              46, {11.419143745929558`, 
                11.875115781439789`}, {{}}, {1}, {}]\), 
            ",", \(AncestralLineage[
              47, {11.419143745929558`, 
                11.692858213787188`}, {{}}, {1}, {}]\), 
            ",", \(AncestralLineage[
              48, {11.448204985318503`, 
                11.608969128792605`}, {{a, b, c, d}}, {1}, {}]\), ",", 
            RowBox[{"AncestralLineage", "[", 
              RowBox[{"49", ",", 
                RowBox[{"{", 
                  RowBox[{"11.608969128792605`", ",", 
                    InterpretationBox["\[Infinity]",
                      DirectedInfinity[ 1]]}], "}"}], 
                ",", \({{a, b, c, d}, {}}\), 
                ",", \({0.3685312554020764`, 1}\), ",", \({}\)}], "]"}], ",", 
            
            RowBox[{"AncestralLineage", "[", 
              RowBox[{"50", ",", 
                RowBox[{"{", 
                  RowBox[{"11.608969128792605`", ",", 
                    InterpretationBox["\[Infinity]",
                      DirectedInfinity[ 1]]}], "}"}], 
                ",", \({{}, {a, b, c, d}}\), 
                ",", \({0.3685312554020764`, 1}\), ",", \({}\)}], "]"}], ",", 
            
            RowBox[{"AncestralLineage", "[", 
              RowBox[{"51", ",", 
                RowBox[{"{", 
                  RowBox[{"11.692858213787188`", ",", 
                    InterpretationBox["\[Infinity]",
                      DirectedInfinity[ 1]]}], "}"}], ",", \({{}}\), 
                ",", \({1}\), ",", \({}\)}], "]"}], ",", 
            RowBox[{"AncestralLineage", "[", 
              RowBox[{"52", ",", 
                RowBox[{"{", 
                  RowBox[{"11.875115781439789`", ",", 
                    InterpretationBox["\[Infinity]",
                      DirectedInfinity[ 1]]}], "}"}], ",", \({{}}\), 
                ",", \({1}\), ",", \({}\)}], "]"}], ",", 
            RowBox[{"AncestralLineage", "[", 
              RowBox[{"53", ",", 
                RowBox[{"{", 
                  RowBox[{"11.875115781439789`", ",", 
                    InterpretationBox["\[Infinity]",
                      DirectedInfinity[ 1]]}], "}"}], ",", \({{}}\), 
                ",", \({1}\), ",", \({}\)}], "]"}]}], "}"}]}],
      SequenceForm[ "G=", {
        AncestralLineage[ a, {0, 0.057107788781921409}, {{a}}, {1}, {}], 
        AncestralLineage[ b, {0, 0.027696065882077705}, {{b}}, {1}, {}], 
        AncestralLineage[ c, {0, 0.62148251496456786}, {{c}}, {1}, {}], 
        AncestralLineage[ d, {0, 0.027696065882077705}, {{d}}, {1}, {}], 
        AncestralLineage[ 
        1, {0.027696065882077705, 0.057107788781921409}, {{b, d}}, {1}, {}], 
        AncestralLineage[ 
        2, {0.057107788781921409, 0.27049717829601805}, {{a, b, d}}, {1}, {}],
         
        AncestralLineage[ 
        3, {0.27049717829601805, 0.4292570949591068}, {{a, b, d}, {}}, {
          0.018996439704686091, 1}, {}], 
        AncestralLineage[ 
        4, {0.27049717829601805, 0.62148251496456786}, {{}, {a, b, d}}, {
          0.018996439704686091, 1}, {}], 
        AncestralLineage[ 
        5, {0.4292570949591068, 0.45951657742311824}, {{a, b, d}, {}}, {
          0.018996439704686091, 1}, {}], 
        AncestralLineage[ 
        6, {0.4292570949591068, 0.45951657742311824}, {{}}, {1}, {}], 
        AncestralLineage[ 
        7, {0.45951657742311824, 0.64520367984716565}, {{a, b, d}, {}}, {
          0.018996439704686091, 1}, {}], 
        AncestralLineage[ 
        8, {0.62148251496456786, 0.64520367984716565}, {{c}, {a, b, c, d}}, {
          0.018996439704686091, 1}, {}], 
        AncestralLineage[ 
        9, {0.64520367984716565, 1.9706637158007017}, {{a, b, c, d}}, {
          1}, {}], 
        AncestralLineage[ 
        10, {1.9706637158007017, 2.2897969825533644}, {{a, b, c, d}, {}}, {
          0.93719810153633465, 1}, {}], 
        AncestralLineage[ 
        11, {1.9706637158007017, 2.118015261702507}, {{}, {a, b, c, d}}, {
          0.93719810153633465, 1}, {}], 
        AncestralLineage[ 
        12, {2.118015261702507, 2.3758569290340006}, {{}}, {1}, {}], 
        AncestralLineage[ 
        13, {2.118015261702507, 2.228204237719424}, {{}, {a, b, c, d}}, {
          0.93719810153633465, 1}, {}], 
        AncestralLineage[ 
        14, {2.228204237719424, 2.2897969825533644}, {{}}, {1}, {}], 
        AncestralLineage[ 
        15, {2.228204237719424, 2.3639104415829926}, {{}, {a, b, c, d}}, {
          0.93719810153633465, 1}, {}], 
        AncestralLineage[ 
        16, {2.2897969825533644, 2.3639104415829926}, {{a, b, c, d}, {}}, {
          0.93719810153633465, 1}, {}], 
        AncestralLineage[ 
        17, {2.3639104415829926, 2.458462043572085}, {{a, b, c, d}}, {1}, {}],
         
        AncestralLineage[ 
        18, {2.3758569290340006, 2.458462043572085}, {{}}, {1}, {}], 
        AncestralLineage[ 
        19, {2.3758569290340006, 2.4862026095016123}, {{}}, {1}, {}], 
        AncestralLineage[ 
        20, {2.458462043572085, 2.4862026095016123}, {{a, b, c, d}}, {1}, {}],
         
        AncestralLineage[ 
        21, {2.4862026095016123, 3.9524773177113115}, {{a, b, c, d}}, {
          1}, {}], 
        AncestralLineage[ 
        22, {3.9524773177113115, 4.0138506590066365}, {{a, b, c, d}, {}}, {
          0.98883751447983492, 1}, {}], 
        AncestralLineage[ 
        23, {3.9524773177113115, 4.0138506590066365}, {{}, {a, b, c, d}}, {
          0.98883751447983492, 1}, {}], 
        AncestralLineage[ 
        24, {4.0138506590066365, 5.7540904800752752}, {{a, b, c, d}}, {
          1}, {}], 
        AncestralLineage[ 
        25, {5.7540904800752752, 5.8356593067548443}, {{a, b, c, d}, {}}, {
          0.18912143960102942, 1}, {}], 
        AncestralLineage[ 
        26, {5.7540904800752752, 5.8356593067548443}, {{}, {a, b, c, d}}, {
          0.18912143960102942, 1}, {}], 
        AncestralLineage[ 
        27, {5.8356593067548443, 6.4604494260089078}, {{a, b, c, d}}, {
          1}, {}], 
        AncestralLineage[ 
        28, {6.4604494260089078, 7.0775598049183523}, {{a, b, c, d}, {}}, {
          0.35885002936128829, 1}, {}], 
        AncestralLineage[ 
        29, {6.4604494260089078, 7.0775598049183523}, {{}, {a, b, c, d}}, {
          0.35885002936128829, 1}, {}], 
        AncestralLineage[ 
        30, {7.0775598049183523, 9.3500560237994925}, {{a, b, c, d}}, {
          1}, {}], 
        AncestralLineage[ 
        31, {9.3500560237994925, 9.8894038967979672}, {{a, b, c, d}, {}}, {
          0.19223283439372979, 1}, {}], 
        AncestralLineage[ 
        32, {9.3500560237994925, 9.8894038967979672}, {{}, {a, b, c, d}}, {
          0.19223283439372979, 1}, {}], 
        AncestralLineage[ 
        33, {9.8894038967979672, 10.04865414492197}, {{a, b, c, d}}, {1}, {}],
         
        AncestralLineage[ 
        34, {10.04865414492197, 10.957847529079562}, {{a, b, c, d}, {}}, {
          0.27813911328582047, 1}, {}], 
        AncestralLineage[ 
        35, {10.04865414492197, 11.256831529989311}, {{}, {a, b, c, d}}, {
          0.27813911328582047, 1}, {}], 
        AncestralLineage[ 
        36, {10.957847529079562, 11.164561785838144}, {{a, b, c, d}, {}}, {
          0.27813911328582047, 1}, {}], 
        AncestralLineage[ 
        37, {10.957847529079562, 11.200948263910437}, {{}}, {1}, {}], 
        AncestralLineage[ 
        38, {11.164561785838144, 11.209929483491738}, {{a, b, c, d}, {}}, {
          0.27813911328582047, 1}, {}], 
        AncestralLineage[ 
        39, {11.164561785838144, 11.419143745929558}, {{}}, {1}, {}], 
        AncestralLineage[ 
        40, {11.200948263910437, 11.209929483491738}, {{}}, {1}, {}], 
        AncestralLineage[ 
        41, {11.200948263910437, 11.245270596164165}, {{}}, {1}, {}], 
        AncestralLineage[ 
        42, {11.209929483491738, 11.256831529989311}, {{a, b, c, d}, {}}, {
          0.27813911328582047, 1}, {}], 
        AncestralLineage[ 
        43, {11.245270596164165, 11.692858213787188}, {{}}, {1}, {}], 
        AncestralLineage[ 
        44, {11.245270596164165, 11.448204985318503}, {{}}, {1}, {}], 
        AncestralLineage[ 
        45, {11.256831529989311, 11.448204985318503}, {{a, b, c, d}}, {
          1}, {}], 
        AncestralLineage[ 
        46, {11.419143745929558, 11.875115781439789}, {{}}, {1}, {}], 
        AncestralLineage[ 
        47, {11.419143745929558, 11.692858213787188}, {{}}, {1}, {}], 
        AncestralLineage[ 
        48, {11.448204985318503, 11.608969128792605}, {{a, b, c, d}}, {
          1}, {}], 
        AncestralLineage[ 49, {11.608969128792605, 
          DirectedInfinity[ 1]}, {{a, b, c, d}, {}}, {0.36853125540207637, 
          1}, {}], 
        AncestralLineage[ 50, {11.608969128792605, 
          DirectedInfinity[ 1]}, {{}, {a, b, c, d}}, {0.36853125540207637, 
          1}, {}], 
        AncestralLineage[ 51, {11.692858213787188, 
          DirectedInfinity[ 1]}, {{}}, {1}, {}], 
        AncestralLineage[ 52, {11.875115781439789, 
          DirectedInfinity[ 1]}, {{}}, {1}, {}], 
        AncestralLineage[ 53, {11.875115781439789, 
          DirectedInfinity[ 1]}, {{}}, {1}, {}]}],
      Editable->False]], "Print",
  CellLabel->"From In[122]:="],

Cell[BoxData[
    \({11.880568558037256`, 4, None}\)], "Print",
  CellLabel->"From In[122]:="],

Cell[BoxData[
    InterpretationBox[\("Coalescing "\[InvisibleSpace]{52, 
          53}\[InvisibleSpace]"; current lineages "\[InvisibleSpace]{49, 50, 
          51, 52, 53}\),
      SequenceForm[ 
      "Coalescing ", {52, 53}, "; current lineages ", {49, 50, 51, 52, 53}],
      Editable->False]], "Print",
  CellLabel->"From In[122]:="],

Cell[BoxData[
    InterpretationBox[
      RowBox[{"\<\"G=\"\>", "\[InvisibleSpace]", 
        RowBox[{"{", 
          
          RowBox[{\(AncestralLineage[
              a, {0, 0.05710778878192141`}, {{a}}, {1}, {}]\), 
            ",", \(AncestralLineage[
              b, {0, 0.027696065882077705`}, {{b}}, {1}, {}]\), 
            ",", \(AncestralLineage[
              c, {0, 0.6214825149645679`}, {{c}}, {1}, {}]\), 
            ",", \(AncestralLineage[
              d, {0, 0.027696065882077705`}, {{d}}, {1}, {}]\), 
            ",", \(AncestralLineage[
              1, {0.027696065882077705`, 
                0.05710778878192141`}, {{b, d}}, {1}, {}]\), 
            ",", \(AncestralLineage[
              2, {0.05710778878192141`, 
                0.27049717829601805`}, {{a, b, d}}, {1}, {}]\), 
            ",", \(AncestralLineage[
              3, {0.27049717829601805`, 
                0.4292570949591068`}, {{a, b, d}, {}}, {0.01899643970468609`, 
                1}, {}]\), 
            ",", \(AncestralLineage[
              4, {0.27049717829601805`, 
                0.6214825149645679`}, {{}, {a, b, d}}, {0.01899643970468609`, 
                1}, {}]\), 
            ",", \(AncestralLineage[
              5, {0.4292570949591068`, 
                0.45951657742311824`}, {{a, b, 
                  d}, {}}, {0.01899643970468609`, 1}, {}]\), 
            ",", \(AncestralLineage[
              6, {0.4292570949591068`, 
                0.45951657742311824`}, {{}}, {1}, {}]\), 
            ",", \(AncestralLineage[
              7, {0.45951657742311824`, 
                0.6452036798471656`}, {{a, b, d}, {}}, {0.01899643970468609`, 
                1}, {}]\), 
            ",", \(AncestralLineage[
              8, {0.6214825149645679`, 
                0.6452036798471656`}, {{c}, {a, b, c, 
                  d}}, {0.01899643970468609`, 1}, {}]\), 
            ",", \(AncestralLineage[
              9, {0.6452036798471656`, 
                1.9706637158007017`}, {{a, b, c, d}}, {1}, {}]\), 
            ",", \(AncestralLineage[
              10, {1.9706637158007017`, 
                2.2897969825533644`}, {{a, b, c, 
                  d}, {}}, {0.9371981015363346`, 1}, {}]\), 
            ",", \(AncestralLineage[
              11, {1.9706637158007017`, 
                2.118015261702507`}, {{}, {a, b, c, 
                  d}}, {0.9371981015363346`, 1}, {}]\), 
            ",", \(AncestralLineage[
              12, {2.118015261702507`, 2.3758569290340006`}, {{}}, {1}, {}]\),
             ",", \(AncestralLineage[
              13, {2.118015261702507`, 
                2.228204237719424`}, {{}, {a, b, c, 
                  d}}, {0.9371981015363346`, 1}, {}]\), 
            ",", \(AncestralLineage[
              14, {2.228204237719424`, 2.2897969825533644`}, {{}}, {1}, {}]\),
             ",", \(AncestralLineage[
              15, {2.228204237719424`, 
                2.3639104415829926`}, {{}, {a, b, c, 
                  d}}, {0.9371981015363346`, 1}, {}]\), 
            ",", \(AncestralLineage[
              16, {2.2897969825533644`, 
                2.3639104415829926`}, {{a, b, c, 
                  d}, {}}, {0.9371981015363346`, 1}, {}]\), 
            ",", \(AncestralLineage[
              17, {2.3639104415829926`, 
                2.458462043572085`}, {{a, b, c, d}}, {1}, {}]\), 
            ",", \(AncestralLineage[
              18, {2.3758569290340006`, 2.458462043572085`}, {{}}, {1}, {}]\),
             ",", \(AncestralLineage[
              19, {2.3758569290340006`, 
                2.4862026095016123`}, {{}}, {1}, {}]\), 
            ",", \(AncestralLineage[
              20, {2.458462043572085`, 
                2.4862026095016123`}, {{a, b, c, d}}, {1}, {}]\), 
            ",", \(AncestralLineage[
              21, {2.4862026095016123`, 
                3.9524773177113115`}, {{a, b, c, d}}, {1}, {}]\), 
            ",", \(AncestralLineage[
              22, {3.9524773177113115`, 
                4.0138506590066365`}, {{a, b, c, 
                  d}, {}}, {0.9888375144798349`, 1}, {}]\), 
            ",", \(AncestralLineage[
              23, {3.9524773177113115`, 
                4.0138506590066365`}, {{}, {a, b, c, 
                  d}}, {0.9888375144798349`, 1}, {}]\), 
            ",", \(AncestralLineage[
              24, {4.0138506590066365`, 
                5.754090480075275`}, {{a, b, c, d}}, {1}, {}]\), 
            ",", \(AncestralLineage[
              25, {5.754090480075275`, 
                5.835659306754844`}, {{a, b, c, 
                  d}, {}}, {0.18912143960102942`, 1}, {}]\), 
            ",", \(AncestralLineage[
              26, {5.754090480075275`, 
                5.835659306754844`}, {{}, {a, b, c, 
                  d}}, {0.18912143960102942`, 1}, {}]\), 
            ",", \(AncestralLineage[
              27, {5.835659306754844`, 
                6.460449426008908`}, {{a, b, c, d}}, {1}, {}]\), 
            ",", \(AncestralLineage[
              28, {6.460449426008908`, 
                7.077559804918352`}, {{a, b, c, 
                  d}, {}}, {0.3588500293612883`, 1}, {}]\), 
            ",", \(AncestralLineage[
              29, {6.460449426008908`, 
                7.077559804918352`}, {{}, {a, b, c, 
                  d}}, {0.3588500293612883`, 1}, {}]\), 
            ",", \(AncestralLineage[
              30, {7.077559804918352`, 
                9.350056023799493`}, {{a, b, c, d}}, {1}, {}]\), 
            ",", \(AncestralLineage[
              31, {9.350056023799493`, 
                9.889403896797967`}, {{a, b, c, 
                  d}, {}}, {0.1922328343937298`, 1}, {}]\), 
            ",", \(AncestralLineage[
              32, {9.350056023799493`, 
                9.889403896797967`}, {{}, {a, b, c, 
                  d}}, {0.1922328343937298`, 1}, {}]\), 
            ",", \(AncestralLineage[
              33, {9.889403896797967`, 
                10.04865414492197`}, {{a, b, c, d}}, {1}, {}]\), 
            ",", \(AncestralLineage[
              34, {10.04865414492197`, 
                10.957847529079562`}, {{a, b, c, 
                  d}, {}}, {0.27813911328582047`, 1}, {}]\), 
            ",", \(AncestralLineage[
              35, {10.04865414492197`, 
                11.256831529989311`}, {{}, {a, b, c, 
                  d}}, {0.27813911328582047`, 1}, {}]\), 
            ",", \(AncestralLineage[
              36, {10.957847529079562`, 
                11.164561785838144`}, {{a, b, c, 
                  d}, {}}, {0.27813911328582047`, 1}, {}]\), 
            ",", \(AncestralLineage[
              37, {10.957847529079562`, 
                11.200948263910437`}, {{}}, {1}, {}]\), 
            ",", \(AncestralLineage[
              38, {11.164561785838144`, 
                11.209929483491738`}, {{a, b, c, 
                  d}, {}}, {0.27813911328582047`, 1}, {}]\), 
            ",", \(AncestralLineage[
              39, {11.164561785838144`, 
                11.419143745929558`}, {{}}, {1}, {}]\), 
            ",", \(AncestralLineage[
              40, {11.200948263910437`, 
                11.209929483491738`}, {{}}, {1}, {}]\), 
            ",", \(AncestralLineage[
              41, {11.200948263910437`, 
                11.245270596164165`}, {{}}, {1}, {}]\), 
            ",", \(AncestralLineage[
              42, {11.209929483491738`, 
                11.256831529989311`}, {{a, b, c, 
                  d}, {}}, {0.27813911328582047`, 1}, {}]\), 
            ",", \(AncestralLineage[
              43, {11.245270596164165`, 
                11.692858213787188`}, {{}}, {1}, {}]\), 
            ",", \(AncestralLineage[
              44, {11.245270596164165`, 
                11.448204985318503`}, {{}}, {1}, {}]\), 
            ",", \(AncestralLineage[
              45, {11.256831529989311`, 
                11.448204985318503`}, {{a, b, c, d}}, {1}, {}]\), 
            ",", \(AncestralLineage[
              46, {11.419143745929558`, 
                11.875115781439789`}, {{}}, {1}, {}]\), 
            ",", \(AncestralLineage[
              47, {11.419143745929558`, 
                11.692858213787188`}, {{}}, {1}, {}]\), 
            ",", \(AncestralLineage[
              48, {11.448204985318503`, 
                11.608969128792605`}, {{a, b, c, d}}, {1}, {}]\), ",", 
            RowBox[{"AncestralLineage", "[", 
              RowBox[{"49", ",", 
                RowBox[{"{", 
                  RowBox[{"11.608969128792605`", ",", 
                    InterpretationBox["\[Infinity]",
                      DirectedInfinity[ 1]]}], "}"}], 
                ",", \({{a, b, c, d}, {}}\), 
                ",", \({0.3685312554020764`, 1}\), ",", \({}\)}], "]"}], ",", 
            
            RowBox[{"AncestralLineage", "[", 
              RowBox[{"50", ",", 
                RowBox[{"{", 
                  RowBox[{"11.608969128792605`", ",", 
                    InterpretationBox["\[Infinity]",
                      DirectedInfinity[ 1]]}], "}"}], 
                ",", \({{}, {a, b, c, d}}\), 
                ",", \({0.3685312554020764`, 1}\), ",", \({}\)}], "]"}], ",", 
            
            RowBox[{"AncestralLineage", "[", 
              RowBox[{"51", ",", 
                RowBox[{"{", 
                  RowBox[{"11.692858213787188`", ",", 
                    InterpretationBox["\[Infinity]",
                      DirectedInfinity[ 1]]}], "}"}], ",", \({{}}\), 
                ",", \({1}\), ",", \({}\)}], "]"}], 
            ",", \(AncestralLineage[
              52, {11.875115781439789`, 
                11.880568558037256`}, {{}}, {1}, {}]\), 
            ",", \(AncestralLineage[
              53, {11.875115781439789`, 
                11.880568558037256`}, {{}}, {1}, {}]\), ",", 
            RowBox[{"AncestralLineage", "[", 
              RowBox[{"54", ",", 
                RowBox[{"{", 
                  RowBox[{"11.880568558037256`", ",", 
                    InterpretationBox["\[Infinity]",
                      DirectedInfinity[ 1]]}], "}"}], ",", \({{}}\), 
                ",", \({1}\), ",", \({}\)}], "]"}]}], "}"}]}],
      SequenceForm[ "G=", {
        AncestralLineage[ a, {0, 0.057107788781921409}, {{a}}, {1}, {}], 
        AncestralLineage[ b, {0, 0.027696065882077705}, {{b}}, {1}, {}], 
        AncestralLineage[ c, {0, 0.62148251496456786}, {{c}}, {1}, {}], 
        AncestralLineage[ d, {0, 0.027696065882077705}, {{d}}, {1}, {}], 
        AncestralLineage[ 
        1, {0.027696065882077705, 0.057107788781921409}, {{b, d}}, {1}, {}], 
        AncestralLineage[ 
        2, {0.057107788781921409, 0.27049717829601805}, {{a, b, d}}, {1}, {}],
         
        AncestralLineage[ 
        3, {0.27049717829601805, 0.4292570949591068}, {{a, b, d}, {}}, {
          0.018996439704686091, 1}, {}], 
        AncestralLineage[ 
        4, {0.27049717829601805, 0.62148251496456786}, {{}, {a, b, d}}, {
          0.018996439704686091, 1}, {}], 
        AncestralLineage[ 
        5, {0.4292570949591068, 0.45951657742311824}, {{a, b, d}, {}}, {
          0.018996439704686091, 1}, {}], 
        AncestralLineage[ 
        6, {0.4292570949591068, 0.45951657742311824}, {{}}, {1}, {}], 
        AncestralLineage[ 
        7, {0.45951657742311824, 0.64520367984716565}, {{a, b, d}, {}}, {
          0.018996439704686091, 1}, {}], 
        AncestralLineage[ 
        8, {0.62148251496456786, 0.64520367984716565}, {{c}, {a, b, c, d}}, {
          0.018996439704686091, 1}, {}], 
        AncestralLineage[ 
        9, {0.64520367984716565, 1.9706637158007017}, {{a, b, c, d}}, {
          1}, {}], 
        AncestralLineage[ 
        10, {1.9706637158007017, 2.2897969825533644}, {{a, b, c, d}, {}}, {
          0.93719810153633465, 1}, {}], 
        AncestralLineage[ 
        11, {1.9706637158007017, 2.118015261702507}, {{}, {a, b, c, d}}, {
          0.93719810153633465, 1}, {}], 
        AncestralLineage[ 
        12, {2.118015261702507, 2.3758569290340006}, {{}}, {1}, {}], 
        AncestralLineage[ 
        13, {2.118015261702507, 2.228204237719424}, {{}, {a, b, c, d}}, {
          0.93719810153633465, 1}, {}], 
        AncestralLineage[ 
        14, {2.228204237719424, 2.2897969825533644}, {{}}, {1}, {}], 
        AncestralLineage[ 
        15, {2.228204237719424, 2.3639104415829926}, {{}, {a, b, c, d}}, {
          0.93719810153633465, 1}, {}], 
        AncestralLineage[ 
        16, {2.2897969825533644, 2.3639104415829926}, {{a, b, c, d}, {}}, {
          0.93719810153633465, 1}, {}], 
        AncestralLineage[ 
        17, {2.3639104415829926, 2.458462043572085}, {{a, b, c, d}}, {1}, {}],
         
        AncestralLineage[ 
        18, {2.3758569290340006, 2.458462043572085}, {{}}, {1}, {}], 
        AncestralLineage[ 
        19, {2.3758569290340006, 2.4862026095016123}, {{}}, {1}, {}], 
        AncestralLineage[ 
        20, {2.458462043572085, 2.4862026095016123}, {{a, b, c, d}}, {1}, {}],
         
        AncestralLineage[ 
        21, {2.4862026095016123, 3.9524773177113115}, {{a, b, c, d}}, {
          1}, {}], 
        AncestralLineage[ 
        22, {3.9524773177113115, 4.0138506590066365}, {{a, b, c, d}, {}}, {
          0.98883751447983492, 1}, {}], 
        AncestralLineage[ 
        23, {3.9524773177113115, 4.0138506590066365}, {{}, {a, b, c, d}}, {
          0.98883751447983492, 1}, {}], 
        AncestralLineage[ 
        24, {4.0138506590066365, 5.7540904800752752}, {{a, b, c, d}}, {
          1}, {}], 
        AncestralLineage[ 
        25, {5.7540904800752752, 5.8356593067548443}, {{a, b, c, d}, {}}, {
          0.18912143960102942, 1}, {}], 
        AncestralLineage[ 
        26, {5.7540904800752752, 5.8356593067548443}, {{}, {a, b, c, d}}, {
          0.18912143960102942, 1}, {}], 
        AncestralLineage[ 
        27, {5.8356593067548443, 6.4604494260089078}, {{a, b, c, d}}, {
          1}, {}], 
        AncestralLineage[ 
        28, {6.4604494260089078, 7.0775598049183523}, {{a, b, c, d}, {}}, {
          0.35885002936128829, 1}, {}], 
        AncestralLineage[ 
        29, {6.4604494260089078, 7.0775598049183523}, {{}, {a, b, c, d}}, {
          0.35885002936128829, 1}, {}], 
        AncestralLineage[ 
        30, {7.0775598049183523, 9.3500560237994925}, {{a, b, c, d}}, {
          1}, {}], 
        AncestralLineage[ 
        31, {9.3500560237994925, 9.8894038967979672}, {{a, b, c, d}, {}}, {
          0.19223283439372979, 1}, {}], 
        AncestralLineage[ 
        32, {9.3500560237994925, 9.8894038967979672}, {{}, {a, b, c, d}}, {
          0.19223283439372979, 1}, {}], 
        AncestralLineage[ 
        33, {9.8894038967979672, 10.04865414492197}, {{a, b, c, d}}, {1}, {}],
         
        AncestralLineage[ 
        34, {10.04865414492197, 10.957847529079562}, {{a, b, c, d}, {}}, {
          0.27813911328582047, 1}, {}], 
        AncestralLineage[ 
        35, {10.04865414492197, 11.256831529989311}, {{}, {a, b, c, d}}, {
          0.27813911328582047, 1}, {}], 
        AncestralLineage[ 
        36, {10.957847529079562, 11.164561785838144}, {{a, b, c, d}, {}}, {
          0.27813911328582047, 1}, {}], 
        AncestralLineage[ 
        37, {10.957847529079562, 11.200948263910437}, {{}}, {1}, {}], 
        AncestralLineage[ 
        38, {11.164561785838144, 11.209929483491738}, {{a, b, c, d}, {}}, {
          0.27813911328582047, 1}, {}], 
        AncestralLineage[ 
        39, {11.164561785838144, 11.419143745929558}, {{}}, {1}, {}], 
        AncestralLineage[ 
        40, {11.200948263910437, 11.209929483491738}, {{}}, {1}, {}], 
        AncestralLineage[ 
        41, {11.200948263910437, 11.245270596164165}, {{}}, {1}, {}], 
        AncestralLineage[ 
        42, {11.209929483491738, 11.256831529989311}, {{a, b, c, d}, {}}, {
          0.27813911328582047, 1}, {}], 
        AncestralLineage[ 
        43, {11.245270596164165, 11.692858213787188}, {{}}, {1}, {}], 
        AncestralLineage[ 
        44, {11.245270596164165, 11.448204985318503}, {{}}, {1}, {}], 
        AncestralLineage[ 
        45, {11.256831529989311, 11.448204985318503}, {{a, b, c, d}}, {
          1}, {}], 
        AncestralLineage[ 
        46, {11.419143745929558, 11.875115781439789}, {{}}, {1}, {}], 
        AncestralLineage[ 
        47, {11.419143745929558, 11.692858213787188}, {{}}, {1}, {}], 
        AncestralLineage[ 
        48, {11.448204985318503, 11.608969128792605}, {{a, b, c, d}}, {
          1}, {}], 
        AncestralLineage[ 49, {11.608969128792605, 
          DirectedInfinity[ 1]}, {{a, b, c, d}, {}}, {0.36853125540207637, 
          1}, {}], 
        AncestralLineage[ 50, {11.608969128792605, 
          DirectedInfinity[ 1]}, {{}, {a, b, c, d}}, {0.36853125540207637, 
          1}, {}], 
        AncestralLineage[ 51, {11.692858213787188, 
          DirectedInfinity[ 1]}, {{}}, {1}, {}], 
        AncestralLineage[ 
        52, {11.875115781439789, 11.880568558037256}, {{}}, {1}, {}], 
        AncestralLineage[ 
        53, {11.875115781439789, 11.880568558037256}, {{}}, {1}, {}], 
        AncestralLineage[ 54, {11.880568558037256, 
          DirectedInfinity[ 1]}, {{}}, {1}, {}]}],
      Editable->False]], "Print",
  CellLabel->"From In[122]:="],

Cell[BoxData[
    \({11.89781746698131`, 5, 0.04750184904356386`}\)], "Print",
  CellLabel->"From In[122]:="],

Cell[BoxData[
    InterpretationBox[\("Recombining "\[InvisibleSpace]54\[InvisibleSpace]"; \
current lineages "\[InvisibleSpace]{49, 50, 51, 54}\),
      SequenceForm[ 
      "Recombining ", 54, "; current lineages ", {49, 50, 51, 54}],
      Editable->False]], "Print",
  CellLabel->"From In[122]:="],

Cell[BoxData[
    InterpretationBox[
      RowBox[{"\<\"G=\"\>", "\[InvisibleSpace]", 
        RowBox[{"{", 
          
          RowBox[{\(AncestralLineage[
              a, {0, 0.05710778878192141`}, {{a}}, {1}, {}]\), 
            ",", \(AncestralLineage[
              b, {0, 0.027696065882077705`}, {{b}}, {1}, {}]\), 
            ",", \(AncestralLineage[
              c, {0, 0.6214825149645679`}, {{c}}, {1}, {}]\), 
            ",", \(AncestralLineage[
              d, {0, 0.027696065882077705`}, {{d}}, {1}, {}]\), 
            ",", \(AncestralLineage[
              1, {0.027696065882077705`, 
                0.05710778878192141`}, {{b, d}}, {1}, {}]\), 
            ",", \(AncestralLineage[
              2, {0.05710778878192141`, 
                0.27049717829601805`}, {{a, b, d}}, {1}, {}]\), 
            ",", \(AncestralLineage[
              3, {0.27049717829601805`, 
                0.4292570949591068`}, {{a, b, d}, {}}, {0.01899643970468609`, 
                1}, {}]\), 
            ",", \(AncestralLineage[
              4, {0.27049717829601805`, 
                0.6214825149645679`}, {{}, {a, b, d}}, {0.01899643970468609`, 
                1}, {}]\), 
            ",", \(AncestralLineage[
              5, {0.4292570949591068`, 
                0.45951657742311824`}, {{a, b, 
                  d}, {}}, {0.01899643970468609`, 1}, {}]\), 
            ",", \(AncestralLineage[
              6, {0.4292570949591068`, 
                0.45951657742311824`}, {{}}, {1}, {}]\), 
            ",", \(AncestralLineage[
              7, {0.45951657742311824`, 
                0.6452036798471656`}, {{a, b, d}, {}}, {0.01899643970468609`, 
                1}, {}]\), 
            ",", \(AncestralLineage[
              8, {0.6214825149645679`, 
                0.6452036798471656`}, {{c}, {a, b, c, 
                  d}}, {0.01899643970468609`, 1}, {}]\), 
            ",", \(AncestralLineage[
              9, {0.6452036798471656`, 
                1.9706637158007017`}, {{a, b, c, d}}, {1}, {}]\), 
            ",", \(AncestralLineage[
              10, {1.9706637158007017`, 
                2.2897969825533644`}, {{a, b, c, 
                  d}, {}}, {0.9371981015363346`, 1}, {}]\), 
            ",", \(AncestralLineage[
              11, {1.9706637158007017`, 
                2.118015261702507`}, {{}, {a, b, c, 
                  d}}, {0.9371981015363346`, 1}, {}]\), 
            ",", \(AncestralLineage[
              12, {2.118015261702507`, 2.3758569290340006`}, {{}}, {1}, {}]\),
             ",", \(AncestralLineage[
              13, {2.118015261702507`, 
                2.228204237719424`}, {{}, {a, b, c, 
                  d}}, {0.9371981015363346`, 1}, {}]\), 
            ",", \(AncestralLineage[
              14, {2.228204237719424`, 2.2897969825533644`}, {{}}, {1}, {}]\),
             ",", \(AncestralLineage[
              15, {2.228204237719424`, 
                2.3639104415829926`}, {{}, {a, b, c, 
                  d}}, {0.9371981015363346`, 1}, {}]\), 
            ",", \(AncestralLineage[
              16, {2.2897969825533644`, 
                2.3639104415829926`}, {{a, b, c, 
                  d}, {}}, {0.9371981015363346`, 1}, {}]\), 
            ",", \(AncestralLineage[
              17, {2.3639104415829926`, 
                2.458462043572085`}, {{a, b, c, d}}, {1}, {}]\), 
            ",", \(AncestralLineage[
              18, {2.3758569290340006`, 2.458462043572085`}, {{}}, {1}, {}]\),
             ",", \(AncestralLineage[
              19, {2.3758569290340006`, 
                2.4862026095016123`}, {{}}, {1}, {}]\), 
            ",", \(AncestralLineage[
              20, {2.458462043572085`, 
                2.4862026095016123`}, {{a, b, c, d}}, {1}, {}]\), 
            ",", \(AncestralLineage[
              21, {2.4862026095016123`, 
                3.9524773177113115`}, {{a, b, c, d}}, {1}, {}]\), 
            ",", \(AncestralLineage[
              22, {3.9524773177113115`, 
                4.0138506590066365`}, {{a, b, c, 
                  d}, {}}, {0.9888375144798349`, 1}, {}]\), 
            ",", \(AncestralLineage[
              23, {3.9524773177113115`, 
                4.0138506590066365`}, {{}, {a, b, c, 
                  d}}, {0.9888375144798349`, 1}, {}]\), 
            ",", \(AncestralLineage[
              24, {4.0138506590066365`, 
                5.754090480075275`}, {{a, b, c, d}}, {1}, {}]\), 
            ",", \(AncestralLineage[
              25, {5.754090480075275`, 
                5.835659306754844`}, {{a, b, c, 
                  d}, {}}, {0.18912143960102942`, 1}, {}]\), 
            ",", \(AncestralLineage[
              26, {5.754090480075275`, 
                5.835659306754844`}, {{}, {a, b, c, 
                  d}}, {0.18912143960102942`, 1}, {}]\), 
            ",", \(AncestralLineage[
              27, {5.835659306754844`, 
                6.460449426008908`}, {{a, b, c, d}}, {1}, {}]\), 
            ",", \(AncestralLineage[
              28, {6.460449426008908`, 
                7.077559804918352`}, {{a, b, c, 
                  d}, {}}, {0.3588500293612883`, 1}, {}]\), 
            ",", \(AncestralLineage[
              29, {6.460449426008908`, 
                7.077559804918352`}, {{}, {a, b, c, 
                  d}}, {0.3588500293612883`, 1}, {}]\), 
            ",", \(AncestralLineage[
              30, {7.077559804918352`, 
                9.350056023799493`}, {{a, b, c, d}}, {1}, {}]\), 
            ",", \(AncestralLineage[
              31, {9.350056023799493`, 
                9.889403896797967`}, {{a, b, c, 
                  d}, {}}, {0.1922328343937298`, 1}, {}]\), 
            ",", \(AncestralLineage[
              32, {9.350056023799493`, 
                9.889403896797967`}, {{}, {a, b, c, 
                  d}}, {0.1922328343937298`, 1}, {}]\), 
            ",", \(AncestralLineage[
              33, {9.889403896797967`, 
                10.04865414492197`}, {{a, b, c, d}}, {1}, {}]\), 
            ",", \(AncestralLineage[
              34, {10.04865414492197`, 
                10.957847529079562`}, {{a, b, c, 
                  d}, {}}, {0.27813911328582047`, 1}, {}]\), 
            ",", \(AncestralLineage[
              35, {10.04865414492197`, 
                11.256831529989311`}, {{}, {a, b, c, 
                  d}}, {0.27813911328582047`, 1}, {}]\), 
            ",", \(AncestralLineage[
              36, {10.957847529079562`, 
                11.164561785838144`}, {{a, b, c, 
                  d}, {}}, {0.27813911328582047`, 1}, {}]\), 
            ",", \(AncestralLineage[
              37, {10.957847529079562`, 
                11.200948263910437`}, {{}}, {1}, {}]\), 
            ",", \(AncestralLineage[
              38, {11.164561785838144`, 
                11.209929483491738`}, {{a, b, c, 
                  d}, {}}, {0.27813911328582047`, 1}, {}]\), 
            ",", \(AncestralLineage[
              39, {11.164561785838144`, 
                11.419143745929558`}, {{}}, {1}, {}]\), 
            ",", \(AncestralLineage[
              40, {11.200948263910437`, 
                11.209929483491738`}, {{}}, {1}, {}]\), 
            ",", \(AncestralLineage[
              41, {11.200948263910437`, 
                11.245270596164165`}, {{}}, {1}, {}]\), 
            ",", \(AncestralLineage[
              42, {11.209929483491738`, 
                11.256831529989311`}, {{a, b, c, 
                  d}, {}}, {0.27813911328582047`, 1}, {}]\), 
            ",", \(AncestralLineage[
              43, {11.245270596164165`, 
                11.692858213787188`}, {{}}, {1}, {}]\), 
            ",", \(AncestralLineage[
              44, {11.245270596164165`, 
                11.448204985318503`}, {{}}, {1}, {}]\), 
            ",", \(AncestralLineage[
              45, {11.256831529989311`, 
                11.448204985318503`}, {{a, b, c, d}}, {1}, {}]\), 
            ",", \(AncestralLineage[
              46, {11.419143745929558`, 
                11.875115781439789`}, {{}}, {1}, {}]\), 
            ",", \(AncestralLineage[
              47, {11.419143745929558`, 
                11.692858213787188`}, {{}}, {1}, {}]\), 
            ",", \(AncestralLineage[
              48, {11.448204985318503`, 
                11.608969128792605`}, {{a, b, c, d}}, {1}, {}]\), ",", 
            RowBox[{"AncestralLineage", "[", 
              RowBox[{"49", ",", 
                RowBox[{"{", 
                  RowBox[{"11.608969128792605`", ",", 
                    InterpretationBox["\[Infinity]",
                      DirectedInfinity[ 1]]}], "}"}], 
                ",", \({{a, b, c, d}, {}}\), 
                ",", \({0.3685312554020764`, 1}\), ",", \({}\)}], "]"}], ",", 
            
            RowBox[{"AncestralLineage", "[", 
              RowBox[{"50", ",", 
                RowBox[{"{", 
                  RowBox[{"11.608969128792605`", ",", 
                    InterpretationBox["\[Infinity]",
                      DirectedInfinity[ 1]]}], "}"}], 
                ",", \({{}, {a, b, c, d}}\), 
                ",", \({0.3685312554020764`, 1}\), ",", \({}\)}], "]"}], ",", 
            
            RowBox[{"AncestralLineage", "[", 
              RowBox[{"51", ",", 
                RowBox[{"{", 
                  RowBox[{"11.692858213787188`", ",", 
                    InterpretationBox["\[Infinity]",
                      DirectedInfinity[ 1]]}], "}"}], ",", \({{}}\), 
                ",", \({1}\), ",", \({}\)}], "]"}], 
            ",", \(AncestralLineage[
              52, {11.875115781439789`, 
                11.880568558037256`}, {{}}, {1}, {}]\), 
            ",", \(AncestralLineage[
              53, {11.875115781439789`, 
                11.880568558037256`}, {{}}, {1}, {}]\), 
            ",", \(AncestralLineage[
              54, {11.880568558037256`, 11.89781746698131`}, {{}}, {1}, {}]\),
             ",", 
            RowBox[{"AncestralLineage", "[", 
              RowBox[{"55", ",", 
                RowBox[{"{", 
                  RowBox[{"11.89781746698131`", ",", 
                    InterpretationBox["\[Infinity]",
                      DirectedInfinity[ 1]]}], "}"}], ",", \({{}}\), 
                ",", \({1}\), ",", \({}\)}], "]"}], ",", 
            RowBox[{"AncestralLineage", "[", 
              RowBox[{"56", ",", 
                RowBox[{"{", 
                  RowBox[{"11.89781746698131`", ",", 
                    InterpretationBox["\[Infinity]",
                      DirectedInfinity[ 1]]}], "}"}], ",", \({{}}\), 
                ",", \({1}\), ",", \({}\)}], "]"}]}], "}"}]}],
      SequenceForm[ "G=", {
        AncestralLineage[ a, {0, 0.057107788781921409}, {{a}}, {1}, {}], 
        AncestralLineage[ b, {0, 0.027696065882077705}, {{b}}, {1}, {}], 
        AncestralLineage[ c, {0, 0.62148251496456786}, {{c}}, {1}, {}], 
        AncestralLineage[ d, {0, 0.027696065882077705}, {{d}}, {1}, {}], 
        AncestralLineage[ 
        1, {0.027696065882077705, 0.057107788781921409}, {{b, d}}, {1}, {}], 
        AncestralLineage[ 
        2, {0.057107788781921409, 0.27049717829601805}, {{a, b, d}}, {1}, {}],
         
        AncestralLineage[ 
        3, {0.27049717829601805, 0.4292570949591068}, {{a, b, d}, {}}, {
          0.018996439704686091, 1}, {}], 
        AncestralLineage[ 
        4, {0.27049717829601805, 0.62148251496456786}, {{}, {a, b, d}}, {
          0.018996439704686091, 1}, {}], 
        AncestralLineage[ 
        5, {0.4292570949591068, 0.45951657742311824}, {{a, b, d}, {}}, {
          0.018996439704686091, 1}, {}], 
        AncestralLineage[ 
        6, {0.4292570949591068, 0.45951657742311824}, {{}}, {1}, {}], 
        AncestralLineage[ 
        7, {0.45951657742311824, 0.64520367984716565}, {{a, b, d}, {}}, {
          0.018996439704686091, 1}, {}], 
        AncestralLineage[ 
        8, {0.62148251496456786, 0.64520367984716565}, {{c}, {a, b, c, d}}, {
          0.018996439704686091, 1}, {}], 
        AncestralLineage[ 
        9, {0.64520367984716565, 1.9706637158007017}, {{a, b, c, d}}, {
          1}, {}], 
        AncestralLineage[ 
        10, {1.9706637158007017, 2.2897969825533644}, {{a, b, c, d}, {}}, {
          0.93719810153633465, 1}, {}], 
        AncestralLineage[ 
        11, {1.9706637158007017, 2.118015261702507}, {{}, {a, b, c, d}}, {
          0.93719810153633465, 1}, {}], 
        AncestralLineage[ 
        12, {2.118015261702507, 2.3758569290340006}, {{}}, {1}, {}], 
        AncestralLineage[ 
        13, {2.118015261702507, 2.228204237719424}, {{}, {a, b, c, d}}, {
          0.93719810153633465, 1}, {}], 
        AncestralLineage[ 
        14, {2.228204237719424, 2.2897969825533644}, {{}}, {1}, {}], 
        AncestralLineage[ 
        15, {2.228204237719424, 2.3639104415829926}, {{}, {a, b, c, d}}, {
          0.93719810153633465, 1}, {}], 
        AncestralLineage[ 
        16, {2.2897969825533644, 2.3639104415829926}, {{a, b, c, d}, {}}, {
          0.93719810153633465, 1}, {}], 
        AncestralLineage[ 
        17, {2.3639104415829926, 2.458462043572085}, {{a, b, c, d}}, {1}, {}],
         
        AncestralLineage[ 
        18, {2.3758569290340006, 2.458462043572085}, {{}}, {1}, {}], 
        AncestralLineage[ 
        19, {2.3758569290340006, 2.4862026095016123}, {{}}, {1}, {}], 
        AncestralLineage[ 
        20, {2.458462043572085, 2.4862026095016123}, {{a, b, c, d}}, {1}, {}],
         
        AncestralLineage[ 
        21, {2.4862026095016123, 3.9524773177113115}, {{a, b, c, d}}, {
          1}, {}], 
        AncestralLineage[ 
        22, {3.9524773177113115, 4.0138506590066365}, {{a, b, c, d}, {}}, {
          0.98883751447983492, 1}, {}], 
        AncestralLineage[ 
        23, {3.9524773177113115, 4.0138506590066365}, {{}, {a, b, c, d}}, {
          0.98883751447983492, 1}, {}], 
        AncestralLineage[ 
        24, {4.0138506590066365, 5.7540904800752752}, {{a, b, c, d}}, {
          1}, {}], 
        AncestralLineage[ 
        25, {5.7540904800752752, 5.8356593067548443}, {{a, b, c, d}, {}}, {
          0.18912143960102942, 1}, {}], 
        AncestralLineage[ 
        26, {5.7540904800752752, 5.8356593067548443}, {{}, {a, b, c, d}}, {
          0.18912143960102942, 1}, {}], 
        AncestralLineage[ 
        27, {5.8356593067548443, 6.4604494260089078}, {{a, b, c, d}}, {
          1}, {}], 
        AncestralLineage[ 
        28, {6.4604494260089078, 7.0775598049183523}, {{a, b, c, d}, {}}, {
          0.35885002936128829, 1}, {}], 
        AncestralLineage[ 
        29, {6.4604494260089078, 7.0775598049183523}, {{}, {a, b, c, d}}, {
          0.35885002936128829, 1}, {}], 
        AncestralLineage[ 
        30, {7.0775598049183523, 9.3500560237994925}, {{a, b, c, d}}, {
          1}, {}], 
        AncestralLineage[ 
        31, {9.3500560237994925, 9.8894038967979672}, {{a, b, c, d}, {}}, {
          0.19223283439372979, 1}, {}], 
        AncestralLineage[ 
        32, {9.3500560237994925, 9.8894038967979672}, {{}, {a, b, c, d}}, {
          0.19223283439372979, 1}, {}], 
        AncestralLineage[ 
        33, {9.8894038967979672, 10.04865414492197}, {{a, b, c, d}}, {1}, {}],
         
        AncestralLineage[ 
        34, {10.04865414492197, 10.957847529079562}, {{a, b, c, d}, {}}, {
          0.27813911328582047, 1}, {}], 
        AncestralLineage[ 
        35, {10.04865414492197, 11.256831529989311}, {{}, {a, b, c, d}}, {
          0.27813911328582047, 1}, {}], 
        AncestralLineage[ 
        36, {10.957847529079562, 11.164561785838144}, {{a, b, c, d}, {}}, {
          0.27813911328582047, 1}, {}], 
        AncestralLineage[ 
        37, {10.957847529079562, 11.200948263910437}, {{}}, {1}, {}], 
        AncestralLineage[ 
        38, {11.164561785838144, 11.209929483491738}, {{a, b, c, d}, {}}, {
          0.27813911328582047, 1}, {}], 
        AncestralLineage[ 
        39, {11.164561785838144, 11.419143745929558}, {{}}, {1}, {}], 
        AncestralLineage[ 
        40, {11.200948263910437, 11.209929483491738}, {{}}, {1}, {}], 
        AncestralLineage[ 
        41, {11.200948263910437, 11.245270596164165}, {{}}, {1}, {}], 
        AncestralLineage[ 
        42, {11.209929483491738, 11.256831529989311}, {{a, b, c, d}, {}}, {
          0.27813911328582047, 1}, {}], 
        AncestralLineage[ 
        43, {11.245270596164165, 11.692858213787188}, {{}}, {1}, {}], 
        AncestralLineage[ 
        44, {11.245270596164165, 11.448204985318503}, {{}}, {1}, {}], 
        AncestralLineage[ 
        45, {11.256831529989311, 11.448204985318503}, {{a, b, c, d}}, {
          1}, {}], 
        AncestralLineage[ 
        46, {11.419143745929558, 11.875115781439789}, {{}}, {1}, {}], 
        AncestralLineage[ 
        47, {11.419143745929558, 11.692858213787188}, {{}}, {1}, {}], 
        AncestralLineage[ 
        48, {11.448204985318503, 11.608969128792605}, {{a, b, c, d}}, {
          1}, {}], 
        AncestralLineage[ 49, {11.608969128792605, 
          DirectedInfinity[ 1]}, {{a, b, c, d}, {}}, {0.36853125540207637, 
          1}, {}], 
        AncestralLineage[ 50, {11.608969128792605, 
          DirectedInfinity[ 1]}, {{}, {a, b, c, d}}, {0.36853125540207637, 
          1}, {}], 
        AncestralLineage[ 51, {11.692858213787188, 
          DirectedInfinity[ 1]}, {{}}, {1}, {}], 
        AncestralLineage[ 
        52, {11.875115781439789, 11.880568558037256}, {{}}, {1}, {}], 
        AncestralLineage[ 
        53, {11.875115781439789, 11.880568558037256}, {{}}, {1}, {}], 
        AncestralLineage[ 
        54, {11.880568558037256, 11.89781746698131}, {{}}, {1}, {}], 
        AncestralLineage[ 55, {11.89781746698131, 
          DirectedInfinity[ 1]}, {{}}, {1}, {}], 
        AncestralLineage[ 56, {11.89781746698131, 
          DirectedInfinity[ 1]}, {{}}, {1}, {}]}],
      Editable->False]], "Print",
  CellLabel->"From In[122]:="],

Cell[BoxData[
    \({11.9483218337688`, 6, 0.7058286902741139`}\)], "Print",
  CellLabel->"From In[122]:="],

Cell[BoxData[
    InterpretationBox[\("Recombining "\[InvisibleSpace]56\[InvisibleSpace]"; \
current lineages "\[InvisibleSpace]{49, 50, 51, 55, 56}\),
      SequenceForm[ 
      "Recombining ", 56, "; current lineages ", {49, 50, 51, 55, 56}],
      Editable->False]], "Print",
  CellLabel->"From In[122]:="],

Cell[BoxData[
    InterpretationBox[
      RowBox[{"\<\"G=\"\>", "\[InvisibleSpace]", 
        RowBox[{"{", 
          
          RowBox[{\(AncestralLineage[
              a, {0, 0.05710778878192141`}, {{a}}, {1}, {}]\), 
            ",", \(AncestralLineage[
              b, {0, 0.027696065882077705`}, {{b}}, {1}, {}]\), 
            ",", \(AncestralLineage[
              c, {0, 0.6214825149645679`}, {{c}}, {1}, {}]\), 
            ",", \(AncestralLineage[
              d, {0, 0.027696065882077705`}, {{d}}, {1}, {}]\), 
            ",", \(AncestralLineage[
              1, {0.027696065882077705`, 
                0.05710778878192141`}, {{b, d}}, {1}, {}]\), 
            ",", \(AncestralLineage[
              2, {0.05710778878192141`, 
                0.27049717829601805`}, {{a, b, d}}, {1}, {}]\), 
            ",", \(AncestralLineage[
              3, {0.27049717829601805`, 
                0.4292570949591068`}, {{a, b, d}, {}}, {0.01899643970468609`, 
                1}, {}]\), 
            ",", \(AncestralLineage[
              4, {0.27049717829601805`, 
                0.6214825149645679`}, {{}, {a, b, d}}, {0.01899643970468609`, 
                1}, {}]\), 
            ",", \(AncestralLineage[
              5, {0.4292570949591068`, 
                0.45951657742311824`}, {{a, b, 
                  d}, {}}, {0.01899643970468609`, 1}, {}]\), 
            ",", \(AncestralLineage[
              6, {0.4292570949591068`, 
                0.45951657742311824`}, {{}}, {1}, {}]\), 
            ",", \(AncestralLineage[
              7, {0.45951657742311824`, 
                0.6452036798471656`}, {{a, b, d}, {}}, {0.01899643970468609`, 
                1}, {}]\), 
            ",", \(AncestralLineage[
              8, {0.6214825149645679`, 
                0.6452036798471656`}, {{c}, {a, b, c, 
                  d}}, {0.01899643970468609`, 1}, {}]\), 
            ",", \(AncestralLineage[
              9, {0.6452036798471656`, 
                1.9706637158007017`}, {{a, b, c, d}}, {1}, {}]\), 
            ",", \(AncestralLineage[
              10, {1.9706637158007017`, 
                2.2897969825533644`}, {{a, b, c, 
                  d}, {}}, {0.9371981015363346`, 1}, {}]\), 
            ",", \(AncestralLineage[
              11, {1.9706637158007017`, 
                2.118015261702507`}, {{}, {a, b, c, 
                  d}}, {0.9371981015363346`, 1}, {}]\), 
            ",", \(AncestralLineage[
              12, {2.118015261702507`, 2.3758569290340006`}, {{}}, {1}, {}]\),
             ",", \(AncestralLineage[
              13, {2.118015261702507`, 
                2.228204237719424`}, {{}, {a, b, c, 
                  d}}, {0.9371981015363346`, 1}, {}]\), 
            ",", \(AncestralLineage[
              14, {2.228204237719424`, 2.2897969825533644`}, {{}}, {1}, {}]\),
             ",", \(AncestralLineage[
              15, {2.228204237719424`, 
                2.3639104415829926`}, {{}, {a, b, c, 
                  d}}, {0.9371981015363346`, 1}, {}]\), 
            ",", \(AncestralLineage[
              16, {2.2897969825533644`, 
                2.3639104415829926`}, {{a, b, c, 
                  d}, {}}, {0.9371981015363346`, 1}, {}]\), 
            ",", \(AncestralLineage[
              17, {2.3639104415829926`, 
                2.458462043572085`}, {{a, b, c, d}}, {1}, {}]\), 
            ",", \(AncestralLineage[
              18, {2.3758569290340006`, 2.458462043572085`}, {{}}, {1}, {}]\),
             ",", \(AncestralLineage[
              19, {2.3758569290340006`, 
                2.4862026095016123`}, {{}}, {1}, {}]\), 
            ",", \(AncestralLineage[
              20, {2.458462043572085`, 
                2.4862026095016123`}, {{a, b, c, d}}, {1}, {}]\), 
            ",", \(AncestralLineage[
              21, {2.4862026095016123`, 
                3.9524773177113115`}, {{a, b, c, d}}, {1}, {}]\), 
            ",", \(AncestralLineage[
              22, {3.9524773177113115`, 
                4.0138506590066365`}, {{a, b, c, 
                  d}, {}}, {0.9888375144798349`, 1}, {}]\), 
            ",", \(AncestralLineage[
              23, {3.9524773177113115`, 
                4.0138506590066365`}, {{}, {a, b, c, 
                  d}}, {0.9888375144798349`, 1}, {}]\), 
            ",", \(AncestralLineage[
              24, {4.0138506590066365`, 
                5.754090480075275`}, {{a, b, c, d}}, {1}, {}]\), 
            ",", \(AncestralLineage[
              25, {5.754090480075275`, 
                5.835659306754844`}, {{a, b, c, 
                  d}, {}}, {0.18912143960102942`, 1}, {}]\), 
            ",", \(AncestralLineage[
              26, {5.754090480075275`, 
                5.835659306754844`}, {{}, {a, b, c, 
                  d}}, {0.18912143960102942`, 1}, {}]\), 
            ",", \(AncestralLineage[
              27, {5.835659306754844`, 
                6.460449426008908`}, {{a, b, c, d}}, {1}, {}]\), 
            ",", \(AncestralLineage[
              28, {6.460449426008908`, 
                7.077559804918352`}, {{a, b, c, 
                  d}, {}}, {0.3588500293612883`, 1}, {}]\), 
            ",", \(AncestralLineage[
              29, {6.460449426008908`, 
                7.077559804918352`}, {{}, {a, b, c, 
                  d}}, {0.3588500293612883`, 1}, {}]\), 
            ",", \(AncestralLineage[
              30, {7.077559804918352`, 
                9.350056023799493`}, {{a, b, c, d}}, {1}, {}]\), 
            ",", \(AncestralLineage[
              31, {9.350056023799493`, 
                9.889403896797967`}, {{a, b, c, 
                  d}, {}}, {0.1922328343937298`, 1}, {}]\), 
            ",", \(AncestralLineage[
              32, {9.350056023799493`, 
                9.889403896797967`}, {{}, {a, b, c, 
                  d}}, {0.1922328343937298`, 1}, {}]\), 
            ",", \(AncestralLineage[
              33, {9.889403896797967`, 
                10.04865414492197`}, {{a, b, c, d}}, {1}, {}]\), 
            ",", \(AncestralLineage[
              34, {10.04865414492197`, 
                10.957847529079562`}, {{a, b, c, 
                  d}, {}}, {0.27813911328582047`, 1}, {}]\), 
            ",", \(AncestralLineage[
              35, {10.04865414492197`, 
                11.256831529989311`}, {{}, {a, b, c, 
                  d}}, {0.27813911328582047`, 1}, {}]\), 
            ",", \(AncestralLineage[
              36, {10.957847529079562`, 
                11.164561785838144`}, {{a, b, c, 
                  d}, {}}, {0.27813911328582047`, 1}, {}]\), 
            ",", \(AncestralLineage[
              37, {10.957847529079562`, 
                11.200948263910437`}, {{}}, {1}, {}]\), 
            ",", \(AncestralLineage[
              38, {11.164561785838144`, 
                11.209929483491738`}, {{a, b, c, 
                  d}, {}}, {0.27813911328582047`, 1}, {}]\), 
            ",", \(AncestralLineage[
              39, {11.164561785838144`, 
                11.419143745929558`}, {{}}, {1}, {}]\), 
            ",", \(AncestralLineage[
              40, {11.200948263910437`, 
                11.209929483491738`}, {{}}, {1}, {}]\), 
            ",", \(AncestralLineage[
              41, {11.200948263910437`, 
                11.245270596164165`}, {{}}, {1}, {}]\), 
            ",", \(AncestralLineage[
              42, {11.209929483491738`, 
                11.256831529989311`}, {{a, b, c, 
                  d}, {}}, {0.27813911328582047`, 1}, {}]\), 
            ",", \(AncestralLineage[
              43, {11.245270596164165`, 
                11.692858213787188`}, {{}}, {1}, {}]\), 
            ",", \(AncestralLineage[
              44, {11.245270596164165`, 
                11.448204985318503`}, {{}}, {1}, {}]\), 
            ",", \(AncestralLineage[
              45, {11.256831529989311`, 
                11.448204985318503`}, {{a, b, c, d}}, {1}, {}]\), 
            ",", \(AncestralLineage[
              46, {11.419143745929558`, 
                11.875115781439789`}, {{}}, {1}, {}]\), 
            ",", \(AncestralLineage[
              47, {11.419143745929558`, 
                11.692858213787188`}, {{}}, {1}, {}]\), 
            ",", \(AncestralLineage[
              48, {11.448204985318503`, 
                11.608969128792605`}, {{a, b, c, d}}, {1}, {}]\), ",", 
            RowBox[{"AncestralLineage", "[", 
              RowBox[{"49", ",", 
                RowBox[{"{", 
                  RowBox[{"11.608969128792605`", ",", 
                    InterpretationBox["\[Infinity]",
                      DirectedInfinity[ 1]]}], "}"}], 
                ",", \({{a, b, c, d}, {}}\), 
                ",", \({0.3685312554020764`, 1}\), ",", \({}\)}], "]"}], ",", 
            
            RowBox[{"AncestralLineage", "[", 
              RowBox[{"50", ",", 
                RowBox[{"{", 
                  RowBox[{"11.608969128792605`", ",", 
                    InterpretationBox["\[Infinity]",
                      DirectedInfinity[ 1]]}], "}"}], 
                ",", \({{}, {a, b, c, d}}\), 
                ",", \({0.3685312554020764`, 1}\), ",", \({}\)}], "]"}], ",", 
            
            RowBox[{"AncestralLineage", "[", 
              RowBox[{"51", ",", 
                RowBox[{"{", 
                  RowBox[{"11.692858213787188`", ",", 
                    InterpretationBox["\[Infinity]",
                      DirectedInfinity[ 1]]}], "}"}], ",", \({{}}\), 
                ",", \({1}\), ",", \({}\)}], "]"}], 
            ",", \(AncestralLineage[
              52, {11.875115781439789`, 
                11.880568558037256`}, {{}}, {1}, {}]\), 
            ",", \(AncestralLineage[
              53, {11.875115781439789`, 
                11.880568558037256`}, {{}}, {1}, {}]\), 
            ",", \(AncestralLineage[
              54, {11.880568558037256`, 11.89781746698131`}, {{}}, {1}, {}]\),
             ",", 
            RowBox[{"AncestralLineage", "[", 
              RowBox[{"55", ",", 
                RowBox[{"{", 
                  RowBox[{"11.89781746698131`", ",", 
                    InterpretationBox["\[Infinity]",
                      DirectedInfinity[ 1]]}], "}"}], ",", \({{}}\), 
                ",", \({1}\), ",", \({}\)}], "]"}], 
            ",", \(AncestralLineage[
              56, {11.89781746698131`, 11.9483218337688`}, {{}}, {1}, {}]\), 
            ",", 
            RowBox[{"AncestralLineage", "[", 
              RowBox[{"57", ",", 
                RowBox[{"{", 
                  RowBox[{"11.9483218337688`", ",", 
                    InterpretationBox["\[Infinity]",
                      DirectedInfinity[ 1]]}], "}"}], ",", \({{}}\), 
                ",", \({1}\), ",", \({}\)}], "]"}], ",", 
            RowBox[{"AncestralLineage", "[", 
              RowBox[{"58", ",", 
                RowBox[{"{", 
                  RowBox[{"11.9483218337688`", ",", 
                    InterpretationBox["\[Infinity]",
                      DirectedInfinity[ 1]]}], "}"}], ",", \({{}}\), 
                ",", \({1}\), ",", \({}\)}], "]"}]}], "}"}]}],
      SequenceForm[ "G=", {
        AncestralLineage[ a, {0, 0.057107788781921409}, {{a}}, {1}, {}], 
        AncestralLineage[ b, {0, 0.027696065882077705}, {{b}}, {1}, {}], 
        AncestralLineage[ c, {0, 0.62148251496456786}, {{c}}, {1}, {}], 
        AncestralLineage[ d, {0, 0.027696065882077705}, {{d}}, {1}, {}], 
        AncestralLineage[ 
        1, {0.027696065882077705, 0.057107788781921409}, {{b, d}}, {1}, {}], 
        AncestralLineage[ 
        2, {0.057107788781921409, 0.27049717829601805}, {{a, b, d}}, {1}, {}],
         
        AncestralLineage[ 
        3, {0.27049717829601805, 0.4292570949591068}, {{a, b, d}, {}}, {
          0.018996439704686091, 1}, {}], 
        AncestralLineage[ 
        4, {0.27049717829601805, 0.62148251496456786}, {{}, {a, b, d}}, {
          0.018996439704686091, 1}, {}], 
        AncestralLineage[ 
        5, {0.4292570949591068, 0.45951657742311824}, {{a, b, d}, {}}, {
          0.018996439704686091, 1}, {}], 
        AncestralLineage[ 
        6, {0.4292570949591068, 0.45951657742311824}, {{}}, {1}, {}], 
        AncestralLineage[ 
        7, {0.45951657742311824, 0.64520367984716565}, {{a, b, d}, {}}, {
          0.018996439704686091, 1}, {}], 
        AncestralLineage[ 
        8, {0.62148251496456786, 0.64520367984716565}, {{c}, {a, b, c, d}}, {
          0.018996439704686091, 1}, {}], 
        AncestralLineage[ 
        9, {0.64520367984716565, 1.9706637158007017}, {{a, b, c, d}}, {
          1}, {}], 
        AncestralLineage[ 
        10, {1.9706637158007017, 2.2897969825533644}, {{a, b, c, d}, {}}, {
          0.93719810153633465, 1}, {}], 
        AncestralLineage[ 
        11, {1.9706637158007017, 2.118015261702507}, {{}, {a, b, c, d}}, {
          0.93719810153633465, 1}, {}], 
        AncestralLineage[ 
        12, {2.118015261702507, 2.3758569290340006}, {{}}, {1}, {}], 
        AncestralLineage[ 
        13, {2.118015261702507, 2.228204237719424}, {{}, {a, b, c, d}}, {
          0.93719810153633465, 1}, {}], 
        AncestralLineage[ 
        14, {2.228204237719424, 2.2897969825533644}, {{}}, {1}, {}], 
        AncestralLineage[ 
        15, {2.228204237719424, 2.3639104415829926}, {{}, {a, b, c, d}}, {
          0.93719810153633465, 1}, {}], 
        AncestralLineage[ 
        16, {2.2897969825533644, 2.3639104415829926}, {{a, b, c, d}, {}}, {
          0.93719810153633465, 1}, {}], 
        AncestralLineage[ 
        17, {2.3639104415829926, 2.458462043572085}, {{a, b, c, d}}, {1}, {}],
         
        AncestralLineage[ 
        18, {2.3758569290340006, 2.458462043572085}, {{}}, {1}, {}], 
        AncestralLineage[ 
        19, {2.3758569290340006, 2.4862026095016123}, {{}}, {1}, {}], 
        AncestralLineage[ 
        20, {2.458462043572085, 2.4862026095016123}, {{a, b, c, d}}, {1}, {}],
         
        AncestralLineage[ 
        21, {2.4862026095016123, 3.9524773177113115}, {{a, b, c, d}}, {
          1}, {}], 
        AncestralLineage[ 
        22, {3.9524773177113115, 4.0138506590066365}, {{a, b, c, d}, {}}, {
          0.98883751447983492, 1}, {}], 
        AncestralLineage[ 
        23, {3.9524773177113115, 4.0138506590066365}, {{}, {a, b, c, d}}, {
          0.98883751447983492, 1}, {}], 
        AncestralLineage[ 
        24, {4.0138506590066365, 5.7540904800752752}, {{a, b, c, d}}, {
          1}, {}], 
        AncestralLineage[ 
        25, {5.7540904800752752, 5.8356593067548443}, {{a, b, c, d}, {}}, {
          0.18912143960102942, 1}, {}], 
        AncestralLineage[ 
        26, {5.7540904800752752, 5.8356593067548443}, {{}, {a, b, c, d}}, {
          0.18912143960102942, 1}, {}], 
        AncestralLineage[ 
        27, {5.8356593067548443, 6.4604494260089078}, {{a, b, c, d}}, {
          1}, {}], 
        AncestralLineage[ 
        28, {6.4604494260089078, 7.0775598049183523}, {{a, b, c, d}, {}}, {
          0.35885002936128829, 1}, {}], 
        AncestralLineage[ 
        29, {6.4604494260089078, 7.0775598049183523}, {{}, {a, b, c, d}}, {
          0.35885002936128829, 1}, {}], 
        AncestralLineage[ 
        30, {7.0775598049183523, 9.3500560237994925}, {{a, b, c, d}}, {
          1}, {}], 
        AncestralLineage[ 
        31, {9.3500560237994925, 9.8894038967979672}, {{a, b, c, d}, {}}, {
          0.19223283439372979, 1}, {}], 
        AncestralLineage[ 
        32, {9.3500560237994925, 9.8894038967979672}, {{}, {a, b, c, d}}, {
          0.19223283439372979, 1}, {}], 
        AncestralLineage[ 
        33, {9.8894038967979672, 10.04865414492197}, {{a, b, c, d}}, {1}, {}],
         
        AncestralLineage[ 
        34, {10.04865414492197, 10.957847529079562}, {{a, b, c, d}, {}}, {
          0.27813911328582047, 1}, {}], 
        AncestralLineage[ 
        35, {10.04865414492197, 11.256831529989311}, {{}, {a, b, c, d}}, {
          0.27813911328582047, 1}, {}], 
        AncestralLineage[ 
        36, {10.957847529079562, 11.164561785838144}, {{a, b, c, d}, {}}, {
          0.27813911328582047, 1}, {}], 
        AncestralLineage[ 
        37, {10.957847529079562, 11.200948263910437}, {{}}, {1}, {}], 
        AncestralLineage[ 
        38, {11.164561785838144, 11.209929483491738}, {{a, b, c, d}, {}}, {
          0.27813911328582047, 1}, {}], 
        AncestralLineage[ 
        39, {11.164561785838144, 11.419143745929558}, {{}}, {1}, {}], 
        AncestralLineage[ 
        40, {11.200948263910437, 11.209929483491738}, {{}}, {1}, {}], 
        AncestralLineage[ 
        41, {11.200948263910437, 11.245270596164165}, {{}}, {1}, {}], 
        AncestralLineage[ 
        42, {11.209929483491738, 11.256831529989311}, {{a, b, c, d}, {}}, {
          0.27813911328582047, 1}, {}], 
        AncestralLineage[ 
        43, {11.245270596164165, 11.692858213787188}, {{}}, {1}, {}], 
        AncestralLineage[ 
        44, {11.245270596164165, 11.448204985318503}, {{}}, {1}, {}], 
        AncestralLineage[ 
        45, {11.256831529989311, 11.448204985318503}, {{a, b, c, d}}, {
          1}, {}], 
        AncestralLineage[ 
        46, {11.419143745929558, 11.875115781439789}, {{}}, {1}, {}], 
        AncestralLineage[ 
        47, {11.419143745929558, 11.692858213787188}, {{}}, {1}, {}], 
        AncestralLineage[ 
        48, {11.448204985318503, 11.608969128792605}, {{a, b, c, d}}, {
          1}, {}], 
        AncestralLineage[ 49, {11.608969128792605, 
          DirectedInfinity[ 1]}, {{a, b, c, d}, {}}, {0.36853125540207637, 
          1}, {}], 
        AncestralLineage[ 50, {11.608969128792605, 
          DirectedInfinity[ 1]}, {{}, {a, b, c, d}}, {0.36853125540207637, 
          1}, {}], 
        AncestralLineage[ 51, {11.692858213787188, 
          DirectedInfinity[ 1]}, {{}}, {1}, {}], 
        AncestralLineage[ 
        52, {11.875115781439789, 11.880568558037256}, {{}}, {1}, {}], 
        AncestralLineage[ 
        53, {11.875115781439789, 11.880568558037256}, {{}}, {1}, {}], 
        AncestralLineage[ 
        54, {11.880568558037256, 11.89781746698131}, {{}}, {1}, {}], 
        AncestralLineage[ 55, {11.89781746698131, 
          DirectedInfinity[ 1]}, {{}}, {1}, {}], 
        AncestralLineage[ 
        56, {11.89781746698131, 11.9483218337688}, {{}}, {1}, {}], 
        AncestralLineage[ 57, {11.9483218337688, 
          DirectedInfinity[ 1]}, {{}}, {1}, {}], 
        AncestralLineage[ 58, {11.9483218337688, 
          DirectedInfinity[ 1]}, {{}}, {1}, {}]}],
      Editable->False]], "Print",
  CellLabel->"From In[122]:="],

Cell[BoxData[
    \({11.978339898040069`, 5, None}\)], "Print",
  CellLabel->"From In[122]:="],

Cell[BoxData[
    InterpretationBox[\("Coalescing "\[InvisibleSpace]{50, 
          58}\[InvisibleSpace]"; current lineages "\[InvisibleSpace]{49, 50, 
          51, 55, 57, 58}\),
      SequenceForm[ 
      "Coalescing ", {50, 58}, "; current lineages ", {49, 50, 51, 55, 57, 
        58}],
      Editable->False]], "Print",
  CellLabel->"From In[122]:="],

Cell[BoxData[
    InterpretationBox[
      RowBox[{"\<\"G=\"\>", "\[InvisibleSpace]", 
        RowBox[{"{", 
          
          RowBox[{\(AncestralLineage[
              a, {0, 0.05710778878192141`}, {{a}}, {1}, {}]\), 
            ",", \(AncestralLineage[
              b, {0, 0.027696065882077705`}, {{b}}, {1}, {}]\), 
            ",", \(AncestralLineage[
              c, {0, 0.6214825149645679`}, {{c}}, {1}, {}]\), 
            ",", \(AncestralLineage[
              d, {0, 0.027696065882077705`}, {{d}}, {1}, {}]\), 
            ",", \(AncestralLineage[
              1, {0.027696065882077705`, 
                0.05710778878192141`}, {{b, d}}, {1}, {}]\), 
            ",", \(AncestralLineage[
              2, {0.05710778878192141`, 
                0.27049717829601805`}, {{a, b, d}}, {1}, {}]\), 
            ",", \(AncestralLineage[
              3, {0.27049717829601805`, 
                0.4292570949591068`}, {{a, b, d}, {}}, {0.01899643970468609`, 
                1}, {}]\), 
            ",", \(AncestralLineage[
              4, {0.27049717829601805`, 
                0.6214825149645679`}, {{}, {a, b, d}}, {0.01899643970468609`, 
                1}, {}]\), 
            ",", \(AncestralLineage[
              5, {0.4292570949591068`, 
                0.45951657742311824`}, {{a, b, 
                  d}, {}}, {0.01899643970468609`, 1}, {}]\), 
            ",", \(AncestralLineage[
              6, {0.4292570949591068`, 
                0.45951657742311824`}, {{}}, {1}, {}]\), 
            ",", \(AncestralLineage[
              7, {0.45951657742311824`, 
                0.6452036798471656`}, {{a, b, d}, {}}, {0.01899643970468609`, 
                1}, {}]\), 
            ",", \(AncestralLineage[
              8, {0.6214825149645679`, 
                0.6452036798471656`}, {{c}, {a, b, c, 
                  d}}, {0.01899643970468609`, 1}, {}]\), 
            ",", \(AncestralLineage[
              9, {0.6452036798471656`, 
                1.9706637158007017`}, {{a, b, c, d}}, {1}, {}]\), 
            ",", \(AncestralLineage[
              10, {1.9706637158007017`, 
                2.2897969825533644`}, {{a, b, c, 
                  d}, {}}, {0.9371981015363346`, 1}, {}]\), 
            ",", \(AncestralLineage[
              11, {1.9706637158007017`, 
                2.118015261702507`}, {{}, {a, b, c, 
                  d}}, {0.9371981015363346`, 1}, {}]\), 
            ",", \(AncestralLineage[
              12, {2.118015261702507`, 2.3758569290340006`}, {{}}, {1}, {}]\),
             ",", \(AncestralLineage[
              13, {2.118015261702507`, 
                2.228204237719424`}, {{}, {a, b, c, 
                  d}}, {0.9371981015363346`, 1}, {}]\), 
            ",", \(AncestralLineage[
              14, {2.228204237719424`, 2.2897969825533644`}, {{}}, {1}, {}]\),
             ",", \(AncestralLineage[
              15, {2.228204237719424`, 
                2.3639104415829926`}, {{}, {a, b, c, 
                  d}}, {0.9371981015363346`, 1}, {}]\), 
            ",", \(AncestralLineage[
              16, {2.2897969825533644`, 
                2.3639104415829926`}, {{a, b, c, 
                  d}, {}}, {0.9371981015363346`, 1}, {}]\), 
            ",", \(AncestralLineage[
              17, {2.3639104415829926`, 
                2.458462043572085`}, {{a, b, c, d}}, {1}, {}]\), 
            ",", \(AncestralLineage[
              18, {2.3758569290340006`, 2.458462043572085`}, {{}}, {1}, {}]\),
             ",", \(AncestralLineage[
              19, {2.3758569290340006`, 
                2.4862026095016123`}, {{}}, {1}, {}]\), 
            ",", \(AncestralLineage[
              20, {2.458462043572085`, 
                2.4862026095016123`}, {{a, b, c, d}}, {1}, {}]\), 
            ",", \(AncestralLineage[
              21, {2.4862026095016123`, 
                3.9524773177113115`}, {{a, b, c, d}}, {1}, {}]\), 
            ",", \(AncestralLineage[
              22, {3.9524773177113115`, 
                4.0138506590066365`}, {{a, b, c, 
                  d}, {}}, {0.9888375144798349`, 1}, {}]\), 
            ",", \(AncestralLineage[
              23, {3.9524773177113115`, 
                4.0138506590066365`}, {{}, {a, b, c, 
                  d}}, {0.9888375144798349`, 1}, {}]\), 
            ",", \(AncestralLineage[
              24, {4.0138506590066365`, 
                5.754090480075275`}, {{a, b, c, d}}, {1}, {}]\), 
            ",", \(AncestralLineage[
              25, {5.754090480075275`, 
                5.835659306754844`}, {{a, b, c, 
                  d}, {}}, {0.18912143960102942`, 1}, {}]\), 
            ",", \(AncestralLineage[
              26, {5.754090480075275`, 
                5.835659306754844`}, {{}, {a, b, c, 
                  d}}, {0.18912143960102942`, 1}, {}]\), 
            ",", \(AncestralLineage[
              27, {5.835659306754844`, 
                6.460449426008908`}, {{a, b, c, d}}, {1}, {}]\), 
            ",", \(AncestralLineage[
              28, {6.460449426008908`, 
                7.077559804918352`}, {{a, b, c, 
                  d}, {}}, {0.3588500293612883`, 1}, {}]\), 
            ",", \(AncestralLineage[
              29, {6.460449426008908`, 
                7.077559804918352`}, {{}, {a, b, c, 
                  d}}, {0.3588500293612883`, 1}, {}]\), 
            ",", \(AncestralLineage[
              30, {7.077559804918352`, 
                9.350056023799493`}, {{a, b, c, d}}, {1}, {}]\), 
            ",", \(AncestralLineage[
              31, {9.350056023799493`, 
                9.889403896797967`}, {{a, b, c, 
                  d}, {}}, {0.1922328343937298`, 1}, {}]\), 
            ",", \(AncestralLineage[
              32, {9.350056023799493`, 
                9.889403896797967`}, {{}, {a, b, c, 
                  d}}, {0.1922328343937298`, 1}, {}]\), 
            ",", \(AncestralLineage[
              33, {9.889403896797967`, 
                10.04865414492197`}, {{a, b, c, d}}, {1}, {}]\), 
            ",", \(AncestralLineage[
              34, {10.04865414492197`, 
                10.957847529079562`}, {{a, b, c, 
                  d}, {}}, {0.27813911328582047`, 1}, {}]\), 
            ",", \(AncestralLineage[
              35, {10.04865414492197`, 
                11.256831529989311`}, {{}, {a, b, c, 
                  d}}, {0.27813911328582047`, 1}, {}]\), 
            ",", \(AncestralLineage[
              36, {10.957847529079562`, 
                11.164561785838144`}, {{a, b, c, 
                  d}, {}}, {0.27813911328582047`, 1}, {}]\), 
            ",", \(AncestralLineage[
              37, {10.957847529079562`, 
                11.200948263910437`}, {{}}, {1}, {}]\), 
            ",", \(AncestralLineage[
              38, {11.164561785838144`, 
                11.209929483491738`}, {{a, b, c, 
                  d}, {}}, {0.27813911328582047`, 1}, {}]\), 
            ",", \(AncestralLineage[
              39, {11.164561785838144`, 
                11.419143745929558`}, {{}}, {1}, {}]\), 
            ",", \(AncestralLineage[
              40, {11.200948263910437`, 
                11.209929483491738`}, {{}}, {1}, {}]\), 
            ",", \(AncestralLineage[
              41, {11.200948263910437`, 
                11.245270596164165`}, {{}}, {1}, {}]\), 
            ",", \(AncestralLineage[
              42, {11.209929483491738`, 
                11.256831529989311`}, {{a, b, c, 
                  d}, {}}, {0.27813911328582047`, 1}, {}]\), 
            ",", \(AncestralLineage[
              43, {11.245270596164165`, 
                11.692858213787188`}, {{}}, {1}, {}]\), 
            ",", \(AncestralLineage[
              44, {11.245270596164165`, 
                11.448204985318503`}, {{}}, {1}, {}]\), 
            ",", \(AncestralLineage[
              45, {11.256831529989311`, 
                11.448204985318503`}, {{a, b, c, d}}, {1}, {}]\), 
            ",", \(AncestralLineage[
              46, {11.419143745929558`, 
                11.875115781439789`}, {{}}, {1}, {}]\), 
            ",", \(AncestralLineage[
              47, {11.419143745929558`, 
                11.692858213787188`}, {{}}, {1}, {}]\), 
            ",", \(AncestralLineage[
              48, {11.448204985318503`, 
                11.608969128792605`}, {{a, b, c, d}}, {1}, {}]\), ",", 
            RowBox[{"AncestralLineage", "[", 
              RowBox[{"49", ",", 
                RowBox[{"{", 
                  RowBox[{"11.608969128792605`", ",", 
                    InterpretationBox["\[Infinity]",
                      DirectedInfinity[ 1]]}], "}"}], 
                ",", \({{a, b, c, d}, {}}\), 
                ",", \({0.3685312554020764`, 1}\), ",", \({}\)}], "]"}], 
            ",", \(AncestralLineage[
              50, {11.608969128792605`, 
                11.978339898040069`}, {{}, {a, b, c, 
                  d}}, {0.3685312554020764`, 1}, {}]\), ",", 
            RowBox[{"AncestralLineage", "[", 
              RowBox[{"51", ",", 
                RowBox[{"{", 
                  RowBox[{"11.692858213787188`", ",", 
                    InterpretationBox["\[Infinity]",
                      DirectedInfinity[ 1]]}], "}"}], ",", \({{}}\), 
                ",", \({1}\), ",", \({}\)}], "]"}], 
            ",", \(AncestralLineage[
              52, {11.875115781439789`, 
                11.880568558037256`}, {{}}, {1}, {}]\), 
            ",", \(AncestralLineage[
              53, {11.875115781439789`, 
                11.880568558037256`}, {{}}, {1}, {}]\), 
            ",", \(AncestralLineage[
              54, {11.880568558037256`, 11.89781746698131`}, {{}}, {1}, {}]\),
             ",", 
            RowBox[{"AncestralLineage", "[", 
              RowBox[{"55", ",", 
                RowBox[{"{", 
                  RowBox[{"11.89781746698131`", ",", 
                    InterpretationBox["\[Infinity]",
                      DirectedInfinity[ 1]]}], "}"}], ",", \({{}}\), 
                ",", \({1}\), ",", \({}\)}], "]"}], 
            ",", \(AncestralLineage[
              56, {11.89781746698131`, 11.9483218337688`}, {{}}, {1}, {}]\), 
            ",", 
            RowBox[{"AncestralLineage", "[", 
              RowBox[{"57", ",", 
                RowBox[{"{", 
                  RowBox[{"11.9483218337688`", ",", 
                    InterpretationBox["\[Infinity]",
                      DirectedInfinity[ 1]]}], "}"}], ",", \({{}}\), 
                ",", \({1}\), ",", \({}\)}], "]"}], 
            ",", \(AncestralLineage[
              58, {11.9483218337688`, 11.978339898040069`}, {{}}, {1}, {}]\), 
            ",", 
            RowBox[{"AncestralLineage", "[", 
              RowBox[{"59", ",", 
                RowBox[{"{", 
                  RowBox[{"11.978339898040069`", ",", 
                    InterpretationBox["\[Infinity]",
                      DirectedInfinity[ 1]]}], "}"}], 
                ",", \({{}, {a, b, c, d}}\), 
                ",", \({0.3685312554020764`, 1}\), ",", \({}\)}], "]"}]}], 
          "}"}]}],
      SequenceForm[ "G=", {
        AncestralLineage[ a, {0, 0.057107788781921409}, {{a}}, {1}, {}], 
        AncestralLineage[ b, {0, 0.027696065882077705}, {{b}}, {1}, {}], 
        AncestralLineage[ c, {0, 0.62148251496456786}, {{c}}, {1}, {}], 
        AncestralLineage[ d, {0, 0.027696065882077705}, {{d}}, {1}, {}], 
        AncestralLineage[ 
        1, {0.027696065882077705, 0.057107788781921409}, {{b, d}}, {1}, {}], 
        AncestralLineage[ 
        2, {0.057107788781921409, 0.27049717829601805}, {{a, b, d}}, {1}, {}],
         
        AncestralLineage[ 
        3, {0.27049717829601805, 0.4292570949591068}, {{a, b, d}, {}}, {
          0.018996439704686091, 1}, {}], 
        AncestralLineage[ 
        4, {0.27049717829601805, 0.62148251496456786}, {{}, {a, b, d}}, {
          0.018996439704686091, 1}, {}], 
        AncestralLineage[ 
        5, {0.4292570949591068, 0.45951657742311824}, {{a, b, d}, {}}, {
          0.018996439704686091, 1}, {}], 
        AncestralLineage[ 
        6, {0.4292570949591068, 0.45951657742311824}, {{}}, {1}, {}], 
        AncestralLineage[ 
        7, {0.45951657742311824, 0.64520367984716565}, {{a, b, d}, {}}, {
          0.018996439704686091, 1}, {}], 
        AncestralLineage[ 
        8, {0.62148251496456786, 0.64520367984716565}, {{c}, {a, b, c, d}}, {
          0.018996439704686091, 1}, {}], 
        AncestralLineage[ 
        9, {0.64520367984716565, 1.9706637158007017}, {{a, b, c, d}}, {
          1}, {}], 
        AncestralLineage[ 
        10, {1.9706637158007017, 2.2897969825533644}, {{a, b, c, d}, {}}, {
          0.93719810153633465, 1}, {}], 
        AncestralLineage[ 
        11, {1.9706637158007017, 2.118015261702507}, {{}, {a, b, c, d}}, {
          0.93719810153633465, 1}, {}], 
        AncestralLineage[ 
        12, {2.118015261702507, 2.3758569290340006}, {{}}, {1}, {}], 
        AncestralLineage[ 
        13, {2.118015261702507, 2.228204237719424}, {{}, {a, b, c, d}}, {
          0.93719810153633465, 1}, {}], 
        AncestralLineage[ 
        14, {2.228204237719424, 2.2897969825533644}, {{}}, {1}, {}], 
        AncestralLineage[ 
        15, {2.228204237719424, 2.3639104415829926}, {{}, {a, b, c, d}}, {
          0.93719810153633465, 1}, {}], 
        AncestralLineage[ 
        16, {2.2897969825533644, 2.3639104415829926}, {{a, b, c, d}, {}}, {
          0.93719810153633465, 1}, {}], 
        AncestralLineage[ 
        17, {2.3639104415829926, 2.458462043572085}, {{a, b, c, d}}, {1}, {}],
         
        AncestralLineage[ 
        18, {2.3758569290340006, 2.458462043572085}, {{}}, {1}, {}], 
        AncestralLineage[ 
        19, {2.3758569290340006, 2.4862026095016123}, {{}}, {1}, {}], 
        AncestralLineage[ 
        20, {2.458462043572085, 2.4862026095016123}, {{a, b, c, d}}, {1}, {}],
         
        AncestralLineage[ 
        21, {2.4862026095016123, 3.9524773177113115}, {{a, b, c, d}}, {
          1}, {}], 
        AncestralLineage[ 
        22, {3.9524773177113115, 4.0138506590066365}, {{a, b, c, d}, {}}, {
          0.98883751447983492, 1}, {}], 
        AncestralLineage[ 
        23, {3.9524773177113115, 4.0138506590066365}, {{}, {a, b, c, d}}, {
          0.98883751447983492, 1}, {}], 
        AncestralLineage[ 
        24, {4.0138506590066365, 5.7540904800752752}, {{a, b, c, d}}, {
          1}, {}], 
        AncestralLineage[ 
        25, {5.7540904800752752, 5.8356593067548443}, {{a, b, c, d}, {}}, {
          0.18912143960102942, 1}, {}], 
        AncestralLineage[ 
        26, {5.7540904800752752, 5.8356593067548443}, {{}, {a, b, c, d}}, {
          0.18912143960102942, 1}, {}], 
        AncestralLineage[ 
        27, {5.8356593067548443, 6.4604494260089078}, {{a, b, c, d}}, {
          1}, {}], 
        AncestralLineage[ 
        28, {6.4604494260089078, 7.0775598049183523}, {{a, b, c, d}, {}}, {
          0.35885002936128829, 1}, {}], 
        AncestralLineage[ 
        29, {6.4604494260089078, 7.0775598049183523}, {{}, {a, b, c, d}}, {
          0.35885002936128829, 1}, {}], 
        AncestralLineage[ 
        30, {7.0775598049183523, 9.3500560237994925}, {{a, b, c, d}}, {
          1}, {}], 
        AncestralLineage[ 
        31, {9.3500560237994925, 9.8894038967979672}, {{a, b, c, d}, {}}, {
          0.19223283439372979, 1}, {}], 
        AncestralLineage[ 
        32, {9.3500560237994925, 9.8894038967979672}, {{}, {a, b, c, d}}, {
          0.19223283439372979, 1}, {}], 
        AncestralLineage[ 
        33, {9.8894038967979672, 10.04865414492197}, {{a, b, c, d}}, {1}, {}],
         
        AncestralLineage[ 
        34, {10.04865414492197, 10.957847529079562}, {{a, b, c, d}, {}}, {
          0.27813911328582047, 1}, {}], 
        AncestralLineage[ 
        35, {10.04865414492197, 11.256831529989311}, {{}, {a, b, c, d}}, {
          0.27813911328582047, 1}, {}], 
        AncestralLineage[ 
        36, {10.957847529079562, 11.164561785838144}, {{a, b, c, d}, {}}, {
          0.27813911328582047, 1}, {}], 
        AncestralLineage[ 
        37, {10.957847529079562, 11.200948263910437}, {{}}, {1}, {}], 
        AncestralLineage[ 
        38, {11.164561785838144, 11.209929483491738}, {{a, b, c, d}, {}}, {
          0.27813911328582047, 1}, {}], 
        AncestralLineage[ 
        39, {11.164561785838144, 11.419143745929558}, {{}}, {1}, {}], 
        AncestralLineage[ 
        40, {11.200948263910437, 11.209929483491738}, {{}}, {1}, {}], 
        AncestralLineage[ 
        41, {11.200948263910437, 11.245270596164165}, {{}}, {1}, {}], 
        AncestralLineage[ 
        42, {11.209929483491738, 11.256831529989311}, {{a, b, c, d}, {}}, {
          0.27813911328582047, 1}, {}], 
        AncestralLineage[ 
        43, {11.245270596164165, 11.692858213787188}, {{}}, {1}, {}], 
        AncestralLineage[ 
        44, {11.245270596164165, 11.448204985318503}, {{}}, {1}, {}], 
        AncestralLineage[ 
        45, {11.256831529989311, 11.448204985318503}, {{a, b, c, d}}, {
          1}, {}], 
        AncestralLineage[ 
        46, {11.419143745929558, 11.875115781439789}, {{}}, {1}, {}], 
        AncestralLineage[ 
        47, {11.419143745929558, 11.692858213787188}, {{}}, {1}, {}], 
        AncestralLineage[ 
        48, {11.448204985318503, 11.608969128792605}, {{a, b, c, d}}, {
          1}, {}], 
        AncestralLineage[ 49, {11.608969128792605, 
          DirectedInfinity[ 1]}, {{a, b, c, d}, {}}, {0.36853125540207637, 
          1}, {}], 
        AncestralLineage[ 
        50, {11.608969128792605, 11.978339898040069}, {{}, {a, b, c, d}}, {
          0.36853125540207637, 1}, {}], 
        AncestralLineage[ 51, {11.692858213787188, 
          DirectedInfinity[ 1]}, {{}}, {1}, {}], 
        AncestralLineage[ 
        52, {11.875115781439789, 11.880568558037256}, {{}}, {1}, {}], 
        AncestralLineage[ 
        53, {11.875115781439789, 11.880568558037256}, {{}}, {1}, {}], 
        AncestralLineage[ 
        54, {11.880568558037256, 11.89781746698131}, {{}}, {1}, {}], 
        AncestralLineage[ 55, {11.89781746698131, 
          DirectedInfinity[ 1]}, {{}}, {1}, {}], 
        AncestralLineage[ 
        56, {11.89781746698131, 11.9483218337688}, {{}}, {1}, {}], 
        AncestralLineage[ 57, {11.9483218337688, 
          DirectedInfinity[ 1]}, {{}}, {1}, {}], 
        AncestralLineage[ 
        58, {11.9483218337688, 11.978339898040069}, {{}}, {1}, {}], 
        AncestralLineage[ 59, {11.978339898040069, 
          DirectedInfinity[ 1]}, {{}, {a, b, c, d}}, {0.36853125540207637, 
          1}, {}]}],
      Editable->False]], "Print",
  CellLabel->"From In[122]:="],

Cell[BoxData[
    \({12.059878520006723`, 4, None}\)], "Print",
  CellLabel->"From In[122]:="],

Cell[BoxData[
    InterpretationBox[\("Coalescing "\[InvisibleSpace]{55, 
          59}\[InvisibleSpace]"; current lineages "\[InvisibleSpace]{49, 51, 
          55, 57, 59}\),
      SequenceForm[ 
      "Coalescing ", {55, 59}, "; current lineages ", {49, 51, 55, 57, 59}],
      Editable->False]], "Print",
  CellLabel->"From In[122]:="],

Cell[BoxData[
    InterpretationBox[
      RowBox[{"\<\"G=\"\>", "\[InvisibleSpace]", 
        RowBox[{"{", 
          
          RowBox[{\(AncestralLineage[
              a, {0, 0.05710778878192141`}, {{a}}, {1}, {}]\), 
            ",", \(AncestralLineage[
              b, {0, 0.027696065882077705`}, {{b}}, {1}, {}]\), 
            ",", \(AncestralLineage[
              c, {0, 0.6214825149645679`}, {{c}}, {1}, {}]\), 
            ",", \(AncestralLineage[
              d, {0, 0.027696065882077705`}, {{d}}, {1}, {}]\), 
            ",", \(AncestralLineage[
              1, {0.027696065882077705`, 
                0.05710778878192141`}, {{b, d}}, {1}, {}]\), 
            ",", \(AncestralLineage[
              2, {0.05710778878192141`, 
                0.27049717829601805`}, {{a, b, d}}, {1}, {}]\), 
            ",", \(AncestralLineage[
              3, {0.27049717829601805`, 
                0.4292570949591068`}, {{a, b, d}, {}}, {0.01899643970468609`, 
                1}, {}]\), 
            ",", \(AncestralLineage[
              4, {0.27049717829601805`, 
                0.6214825149645679`}, {{}, {a, b, d}}, {0.01899643970468609`, 
                1}, {}]\), 
            ",", \(AncestralLineage[
              5, {0.4292570949591068`, 
                0.45951657742311824`}, {{a, b, 
                  d}, {}}, {0.01899643970468609`, 1}, {}]\), 
            ",", \(AncestralLineage[
              6, {0.4292570949591068`, 
                0.45951657742311824`}, {{}}, {1}, {}]\), 
            ",", \(AncestralLineage[
              7, {0.45951657742311824`, 
                0.6452036798471656`}, {{a, b, d}, {}}, {0.01899643970468609`, 
                1}, {}]\), 
            ",", \(AncestralLineage[
              8, {0.6214825149645679`, 
                0.6452036798471656`}, {{c}, {a, b, c, 
                  d}}, {0.01899643970468609`, 1}, {}]\), 
            ",", \(AncestralLineage[
              9, {0.6452036798471656`, 
                1.9706637158007017`}, {{a, b, c, d}}, {1}, {}]\), 
            ",", \(AncestralLineage[
              10, {1.9706637158007017`, 
                2.2897969825533644`}, {{a, b, c, 
                  d}, {}}, {0.9371981015363346`, 1}, {}]\), 
            ",", \(AncestralLineage[
              11, {1.9706637158007017`, 
                2.118015261702507`}, {{}, {a, b, c, 
                  d}}, {0.9371981015363346`, 1}, {}]\), 
            ",", \(AncestralLineage[
              12, {2.118015261702507`, 2.3758569290340006`}, {{}}, {1}, {}]\),
             ",", \(AncestralLineage[
              13, {2.118015261702507`, 
                2.228204237719424`}, {{}, {a, b, c, 
                  d}}, {0.9371981015363346`, 1}, {}]\), 
            ",", \(AncestralLineage[
              14, {2.228204237719424`, 2.2897969825533644`}, {{}}, {1}, {}]\),
             ",", \(AncestralLineage[
              15, {2.228204237719424`, 
                2.3639104415829926`}, {{}, {a, b, c, 
                  d}}, {0.9371981015363346`, 1}, {}]\), 
            ",", \(AncestralLineage[
              16, {2.2897969825533644`, 
                2.3639104415829926`}, {{a, b, c, 
                  d}, {}}, {0.9371981015363346`, 1}, {}]\), 
            ",", \(AncestralLineage[
              17, {2.3639104415829926`, 
                2.458462043572085`}, {{a, b, c, d}}, {1}, {}]\), 
            ",", \(AncestralLineage[
              18, {2.3758569290340006`, 2.458462043572085`}, {{}}, {1}, {}]\),
             ",", \(AncestralLineage[
              19, {2.3758569290340006`, 
                2.4862026095016123`}, {{}}, {1}, {}]\), 
            ",", \(AncestralLineage[
              20, {2.458462043572085`, 
                2.4862026095016123`}, {{a, b, c, d}}, {1}, {}]\), 
            ",", \(AncestralLineage[
              21, {2.4862026095016123`, 
                3.9524773177113115`}, {{a, b, c, d}}, {1}, {}]\), 
            ",", \(AncestralLineage[
              22, {3.9524773177113115`, 
                4.0138506590066365`}, {{a, b, c, 
                  d}, {}}, {0.9888375144798349`, 1}, {}]\), 
            ",", \(AncestralLineage[
              23, {3.9524773177113115`, 
                4.0138506590066365`}, {{}, {a, b, c, 
                  d}}, {0.9888375144798349`, 1}, {}]\), 
            ",", \(AncestralLineage[
              24, {4.0138506590066365`, 
                5.754090480075275`}, {{a, b, c, d}}, {1}, {}]\), 
            ",", \(AncestralLineage[
              25, {5.754090480075275`, 
                5.835659306754844`}, {{a, b, c, 
                  d}, {}}, {0.18912143960102942`, 1}, {}]\), 
            ",", \(AncestralLineage[
              26, {5.754090480075275`, 
                5.835659306754844`}, {{}, {a, b, c, 
                  d}}, {0.18912143960102942`, 1}, {}]\), 
            ",", \(AncestralLineage[
              27, {5.835659306754844`, 
                6.460449426008908`}, {{a, b, c, d}}, {1}, {}]\), 
            ",", \(AncestralLineage[
              28, {6.460449426008908`, 
                7.077559804918352`}, {{a, b, c, 
                  d}, {}}, {0.3588500293612883`, 1}, {}]\), 
            ",", \(AncestralLineage[
              29, {6.460449426008908`, 
                7.077559804918352`}, {{}, {a, b, c, 
                  d}}, {0.3588500293612883`, 1}, {}]\), 
            ",", \(AncestralLineage[
              30, {7.077559804918352`, 
                9.350056023799493`}, {{a, b, c, d}}, {1}, {}]\), 
            ",", \(AncestralLineage[
              31, {9.350056023799493`, 
                9.889403896797967`}, {{a, b, c, 
                  d}, {}}, {0.1922328343937298`, 1}, {}]\), 
            ",", \(AncestralLineage[
              32, {9.350056023799493`, 
                9.889403896797967`}, {{}, {a, b, c, 
                  d}}, {0.1922328343937298`, 1}, {}]\), 
            ",", \(AncestralLineage[
              33, {9.889403896797967`, 
                10.04865414492197`}, {{a, b, c, d}}, {1}, {}]\), 
            ",", \(AncestralLineage[
              34, {10.04865414492197`, 
                10.957847529079562`}, {{a, b, c, 
                  d}, {}}, {0.27813911328582047`, 1}, {}]\), 
            ",", \(AncestralLineage[
              35, {10.04865414492197`, 
                11.256831529989311`}, {{}, {a, b, c, 
                  d}}, {0.27813911328582047`, 1}, {}]\), 
            ",", \(AncestralLineage[
              36, {10.957847529079562`, 
                11.164561785838144`}, {{a, b, c, 
                  d}, {}}, {0.27813911328582047`, 1}, {}]\), 
            ",", \(AncestralLineage[
              37, {10.957847529079562`, 
                11.200948263910437`}, {{}}, {1}, {}]\), 
            ",", \(AncestralLineage[
              38, {11.164561785838144`, 
                11.209929483491738`}, {{a, b, c, 
                  d}, {}}, {0.27813911328582047`, 1}, {}]\), 
            ",", \(AncestralLineage[
              39, {11.164561785838144`, 
                11.419143745929558`}, {{}}, {1}, {}]\), 
            ",", \(AncestralLineage[
              40, {11.200948263910437`, 
                11.209929483491738`}, {{}}, {1}, {}]\), 
            ",", \(AncestralLineage[
              41, {11.200948263910437`, 
                11.245270596164165`}, {{}}, {1}, {}]\), 
            ",", \(AncestralLineage[
              42, {11.209929483491738`, 
                11.256831529989311`}, {{a, b, c, 
                  d}, {}}, {0.27813911328582047`, 1}, {}]\), 
            ",", \(AncestralLineage[
              43, {11.245270596164165`, 
                11.692858213787188`}, {{}}, {1}, {}]\), 
            ",", \(AncestralLineage[
              44, {11.245270596164165`, 
                11.448204985318503`}, {{}}, {1}, {}]\), 
            ",", \(AncestralLineage[
              45, {11.256831529989311`, 
                11.448204985318503`}, {{a, b, c, d}}, {1}, {}]\), 
            ",", \(AncestralLineage[
              46, {11.419143745929558`, 
                11.875115781439789`}, {{}}, {1}, {}]\), 
            ",", \(AncestralLineage[
              47, {11.419143745929558`, 
                11.692858213787188`}, {{}}, {1}, {}]\), 
            ",", \(AncestralLineage[
              48, {11.448204985318503`, 
                11.608969128792605`}, {{a, b, c, d}}, {1}, {}]\), ",", 
            RowBox[{"AncestralLineage", "[", 
              RowBox[{"49", ",", 
                RowBox[{"{", 
                  RowBox[{"11.608969128792605`", ",", 
                    InterpretationBox["\[Infinity]",
                      DirectedInfinity[ 1]]}], "}"}], 
                ",", \({{a, b, c, d}, {}}\), 
                ",", \({0.3685312554020764`, 1}\), ",", \({}\)}], "]"}], 
            ",", \(AncestralLineage[
              50, {11.608969128792605`, 
                11.978339898040069`}, {{}, {a, b, c, 
                  d}}, {0.3685312554020764`, 1}, {}]\), ",", 
            RowBox[{"AncestralLineage", "[", 
              RowBox[{"51", ",", 
                RowBox[{"{", 
                  RowBox[{"11.692858213787188`", ",", 
                    InterpretationBox["\[Infinity]",
                      DirectedInfinity[ 1]]}], "}"}], ",", \({{}}\), 
                ",", \({1}\), ",", \({}\)}], "]"}], 
            ",", \(AncestralLineage[
              52, {11.875115781439789`, 
                11.880568558037256`}, {{}}, {1}, {}]\), 
            ",", \(AncestralLineage[
              53, {11.875115781439789`, 
                11.880568558037256`}, {{}}, {1}, {}]\), 
            ",", \(AncestralLineage[
              54, {11.880568558037256`, 11.89781746698131`}, {{}}, {1}, {}]\),
             ",", \(AncestralLineage[
              55, {11.89781746698131`, 12.059878520006723`}, {{}}, {1}, {}]\),
             ",", \(AncestralLineage[
              56, {11.89781746698131`, 11.9483218337688`}, {{}}, {1}, {}]\), 
            ",", 
            RowBox[{"AncestralLineage", "[", 
              RowBox[{"57", ",", 
                RowBox[{"{", 
                  RowBox[{"11.9483218337688`", ",", 
                    InterpretationBox["\[Infinity]",
                      DirectedInfinity[ 1]]}], "}"}], ",", \({{}}\), 
                ",", \({1}\), ",", \({}\)}], "]"}], 
            ",", \(AncestralLineage[
              58, {11.9483218337688`, 11.978339898040069`}, {{}}, {1}, {}]\), 
            ",", \(AncestralLineage[
              59, {11.978339898040069`, 
                12.059878520006723`}, {{}, {a, b, c, 
                  d}}, {0.3685312554020764`, 1}, {}]\), ",", 
            RowBox[{"AncestralLineage", "[", 
              RowBox[{"60", ",", 
                RowBox[{"{", 
                  RowBox[{"12.059878520006723`", ",", 
                    InterpretationBox["\[Infinity]",
                      DirectedInfinity[ 1]]}], "}"}], 
                ",", \({{}, {a, b, c, d}}\), 
                ",", \({0.3685312554020764`, 1}\), ",", \({}\)}], "]"}]}], 
          "}"}]}],
      SequenceForm[ "G=", {
        AncestralLineage[ a, {0, 0.057107788781921409}, {{a}}, {1}, {}], 
        AncestralLineage[ b, {0, 0.027696065882077705}, {{b}}, {1}, {}], 
        AncestralLineage[ c, {0, 0.62148251496456786}, {{c}}, {1}, {}], 
        AncestralLineage[ d, {0, 0.027696065882077705}, {{d}}, {1}, {}], 
        AncestralLineage[ 
        1, {0.027696065882077705, 0.057107788781921409}, {{b, d}}, {1}, {}], 
        AncestralLineage[ 
        2, {0.057107788781921409, 0.27049717829601805}, {{a, b, d}}, {1}, {}],
         
        AncestralLineage[ 
        3, {0.27049717829601805, 0.4292570949591068}, {{a, b, d}, {}}, {
          0.018996439704686091, 1}, {}], 
        AncestralLineage[ 
        4, {0.27049717829601805, 0.62148251496456786}, {{}, {a, b, d}}, {
          0.018996439704686091, 1}, {}], 
        AncestralLineage[ 
        5, {0.4292570949591068, 0.45951657742311824}, {{a, b, d}, {}}, {
          0.018996439704686091, 1}, {}], 
        AncestralLineage[ 
        6, {0.4292570949591068, 0.45951657742311824}, {{}}, {1}, {}], 
        AncestralLineage[ 
        7, {0.45951657742311824, 0.64520367984716565}, {{a, b, d}, {}}, {
          0.018996439704686091, 1}, {}], 
        AncestralLineage[ 
        8, {0.62148251496456786, 0.64520367984716565}, {{c}, {a, b, c, d}}, {
          0.018996439704686091, 1}, {}], 
        AncestralLineage[ 
        9, {0.64520367984716565, 1.9706637158007017}, {{a, b, c, d}}, {
          1}, {}], 
        AncestralLineage[ 
        10, {1.9706637158007017, 2.2897969825533644}, {{a, b, c, d}, {}}, {
          0.93719810153633465, 1}, {}], 
        AncestralLineage[ 
        11, {1.9706637158007017, 2.118015261702507}, {{}, {a, b, c, d}}, {
          0.93719810153633465, 1}, {}], 
        AncestralLineage[ 
        12, {2.118015261702507, 2.3758569290340006}, {{}}, {1}, {}], 
        AncestralLineage[ 
        13, {2.118015261702507, 2.228204237719424}, {{}, {a, b, c, d}}, {
          0.93719810153633465, 1}, {}], 
        AncestralLineage[ 
        14, {2.228204237719424, 2.2897969825533644}, {{}}, {1}, {}], 
        AncestralLineage[ 
        15, {2.228204237719424, 2.3639104415829926}, {{}, {a, b, c, d}}, {
          0.93719810153633465, 1}, {}], 
        AncestralLineage[ 
        16, {2.2897969825533644, 2.3639104415829926}, {{a, b, c, d}, {}}, {
          0.93719810153633465, 1}, {}], 
        AncestralLineage[ 
        17, {2.3639104415829926, 2.458462043572085}, {{a, b, c, d}}, {1}, {}],
         
        AncestralLineage[ 
        18, {2.3758569290340006, 2.458462043572085}, {{}}, {1}, {}], 
        AncestralLineage[ 
        19, {2.3758569290340006, 2.4862026095016123}, {{}}, {1}, {}], 
        AncestralLineage[ 
        20, {2.458462043572085, 2.4862026095016123}, {{a, b, c, d}}, {1}, {}],
         
        AncestralLineage[ 
        21, {2.4862026095016123, 3.9524773177113115}, {{a, b, c, d}}, {
          1}, {}], 
        AncestralLineage[ 
        22, {3.9524773177113115, 4.0138506590066365}, {{a, b, c, d}, {}}, {
          0.98883751447983492, 1}, {}], 
        AncestralLineage[ 
        23, {3.9524773177113115, 4.0138506590066365}, {{}, {a, b, c, d}}, {
          0.98883751447983492, 1}, {}], 
        AncestralLineage[ 
        24, {4.0138506590066365, 5.7540904800752752}, {{a, b, c, d}}, {
          1}, {}], 
        AncestralLineage[ 
        25, {5.7540904800752752, 5.8356593067548443}, {{a, b, c, d}, {}}, {
          0.18912143960102942, 1}, {}], 
        AncestralLineage[ 
        26, {5.7540904800752752, 5.8356593067548443}, {{}, {a, b, c, d}}, {
          0.18912143960102942, 1}, {}], 
        AncestralLineage[ 
        27, {5.8356593067548443, 6.4604494260089078}, {{a, b, c, d}}, {
          1}, {}], 
        AncestralLineage[ 
        28, {6.4604494260089078, 7.0775598049183523}, {{a, b, c, d}, {}}, {
          0.35885002936128829, 1}, {}], 
        AncestralLineage[ 
        29, {6.4604494260089078, 7.0775598049183523}, {{}, {a, b, c, d}}, {
          0.35885002936128829, 1}, {}], 
        AncestralLineage[ 
        30, {7.0775598049183523, 9.3500560237994925}, {{a, b, c, d}}, {
          1}, {}], 
        AncestralLineage[ 
        31, {9.3500560237994925, 9.8894038967979672}, {{a, b, c, d}, {}}, {
          0.19223283439372979, 1}, {}], 
        AncestralLineage[ 
        32, {9.3500560237994925, 9.8894038967979672}, {{}, {a, b, c, d}}, {
          0.19223283439372979, 1}, {}], 
        AncestralLineage[ 
        33, {9.8894038967979672, 10.04865414492197}, {{a, b, c, d}}, {1}, {}],
         
        AncestralLineage[ 
        34, {10.04865414492197, 10.957847529079562}, {{a, b, c, d}, {}}, {
          0.27813911328582047, 1}, {}], 
        AncestralLineage[ 
        35, {10.04865414492197, 11.256831529989311}, {{}, {a, b, c, d}}, {
          0.27813911328582047, 1}, {}], 
        AncestralLineage[ 
        36, {10.957847529079562, 11.164561785838144}, {{a, b, c, d}, {}}, {
          0.27813911328582047, 1}, {}], 
        AncestralLineage[ 
        37, {10.957847529079562, 11.200948263910437}, {{}}, {1}, {}], 
        AncestralLineage[ 
        38, {11.164561785838144, 11.209929483491738}, {{a, b, c, d}, {}}, {
          0.27813911328582047, 1}, {}], 
        AncestralLineage[ 
        39, {11.164561785838144, 11.419143745929558}, {{}}, {1}, {}], 
        AncestralLineage[ 
        40, {11.200948263910437, 11.209929483491738}, {{}}, {1}, {}], 
        AncestralLineage[ 
        41, {11.200948263910437, 11.245270596164165}, {{}}, {1}, {}], 
        AncestralLineage[ 
        42, {11.209929483491738, 11.256831529989311}, {{a, b, c, d}, {}}, {
          0.27813911328582047, 1}, {}], 
        AncestralLineage[ 
        43, {11.245270596164165, 11.692858213787188}, {{}}, {1}, {}], 
        AncestralLineage[ 
        44, {11.245270596164165, 11.448204985318503}, {{}}, {1}, {}], 
        AncestralLineage[ 
        45, {11.256831529989311, 11.448204985318503}, {{a, b, c, d}}, {
          1}, {}], 
        AncestralLineage[ 
        46, {11.419143745929558, 11.875115781439789}, {{}}, {1}, {}], 
        AncestralLineage[ 
        47, {11.419143745929558, 11.692858213787188}, {{}}, {1}, {}], 
        AncestralLineage[ 
        48, {11.448204985318503, 11.608969128792605}, {{a, b, c, d}}, {
          1}, {}], 
        AncestralLineage[ 49, {11.608969128792605, 
          DirectedInfinity[ 1]}, {{a, b, c, d}, {}}, {0.36853125540207637, 
          1}, {}], 
        AncestralLineage[ 
        50, {11.608969128792605, 11.978339898040069}, {{}, {a, b, c, d}}, {
          0.36853125540207637, 1}, {}], 
        AncestralLineage[ 51, {11.692858213787188, 
          DirectedInfinity[ 1]}, {{}}, {1}, {}], 
        AncestralLineage[ 
        52, {11.875115781439789, 11.880568558037256}, {{}}, {1}, {}], 
        AncestralLineage[ 
        53, {11.875115781439789, 11.880568558037256}, {{}}, {1}, {}], 
        AncestralLineage[ 
        54, {11.880568558037256, 11.89781746698131}, {{}}, {1}, {}], 
        AncestralLineage[ 
        55, {11.89781746698131, 12.059878520006723}, {{}}, {1}, {}], 
        AncestralLineage[ 
        56, {11.89781746698131, 11.9483218337688}, {{}}, {1}, {}], 
        AncestralLineage[ 57, {11.9483218337688, 
          DirectedInfinity[ 1]}, {{}}, {1}, {}], 
        AncestralLineage[ 
        58, {11.9483218337688, 11.978339898040069}, {{}}, {1}, {}], 
        AncestralLineage[ 
        59, {11.978339898040069, 12.059878520006723}, {{}, {a, b, c, d}}, {
          0.36853125540207637, 1}, {}], 
        AncestralLineage[ 60, {12.059878520006723, 
          DirectedInfinity[ 1]}, {{}, {a, b, c, d}}, {0.36853125540207637, 
          1}, {}]}],
      Editable->False]], "Print",
  CellLabel->"From In[122]:="],

Cell[BoxData[
    RowBox[{"{", 
      RowBox[{\(AncestralLineage[
          a, {0, 0.05710778878192141`}, {{a}}, {1}, {}]\), 
        ",", \(AncestralLineage[
          b, {0, 0.027696065882077705`}, {{b}}, {1}, {}]\), 
        ",", \(AncestralLineage[
          c, {0, 0.6214825149645679`}, {{c}}, {1}, {}]\), 
        ",", \(AncestralLineage[
          d, {0, 0.027696065882077705`}, {{d}}, {1}, {}]\), 
        ",", \(AncestralLineage[
          1, {0.027696065882077705`, 
            0.05710778878192141`}, {{b, d}}, {1}, {}]\), 
        ",", \(AncestralLineage[
          2, {0.05710778878192141`, 
            0.27049717829601805`}, {{a, b, d}}, {1}, {}]\), 
        ",", \(AncestralLineage[
          3, {0.27049717829601805`, 
            0.4292570949591068`}, {{a, b, d}, {}}, {0.01899643970468609`, 
            1}, {}]\), 
        ",", \(AncestralLineage[
          4, {0.27049717829601805`, 
            0.6214825149645679`}, {{}, {a, b, d}}, {0.01899643970468609`, 
            1}, {}]\), 
        ",", \(AncestralLineage[
          5, {0.4292570949591068`, 
            0.45951657742311824`}, {{a, b, d}, {}}, {0.01899643970468609`, 
            1}, {}]\), 
        ",", \(AncestralLineage[
          6, {0.4292570949591068`, 0.45951657742311824`}, {{}}, {1}, {}]\), 
        ",", \(AncestralLineage[
          7, {0.45951657742311824`, 
            0.6452036798471656`}, {{a, b, d}, {}}, {0.01899643970468609`, 
            1}, {}]\), 
        ",", \(AncestralLineage[
          8, {0.6214825149645679`, 
            0.6452036798471656`}, {{c}, {a, b, c, d}}, {0.01899643970468609`, 
            1}, {}]\), 
        ",", \(AncestralLineage[
          9, {0.6452036798471656`, 
            1.9706637158007017`}, {{a, b, c, d}}, {1}, {}]\), 
        ",", \(AncestralLineage[
          10, {1.9706637158007017`, 
            2.2897969825533644`}, {{a, b, c, d}, {}}, {0.9371981015363346`, 
            1}, {}]\), 
        ",", \(AncestralLineage[
          11, {1.9706637158007017`, 
            2.118015261702507`}, {{}, {a, b, c, d}}, {0.9371981015363346`, 
            1}, {}]\), 
        ",", \(AncestralLineage[
          12, {2.118015261702507`, 2.3758569290340006`}, {{}}, {1}, {}]\), 
        ",", \(AncestralLineage[
          13, {2.118015261702507`, 
            2.228204237719424`}, {{}, {a, b, c, d}}, {0.9371981015363346`, 
            1}, {}]\), 
        ",", \(AncestralLineage[
          14, {2.228204237719424`, 2.2897969825533644`}, {{}}, {1}, {}]\), 
        ",", \(AncestralLineage[
          15, {2.228204237719424`, 
            2.3639104415829926`}, {{}, {a, b, c, d}}, {0.9371981015363346`, 
            1}, {}]\), 
        ",", \(AncestralLineage[
          16, {2.2897969825533644`, 
            2.3639104415829926`}, {{a, b, c, d}, {}}, {0.9371981015363346`, 
            1}, {}]\), 
        ",", \(AncestralLineage[
          17, {2.3639104415829926`, 
            2.458462043572085`}, {{a, b, c, d}}, {1}, {}]\), 
        ",", \(AncestralLineage[
          18, {2.3758569290340006`, 2.458462043572085`}, {{}}, {1}, {}]\), 
        ",", \(AncestralLineage[
          19, {2.3758569290340006`, 2.4862026095016123`}, {{}}, {1}, {}]\), 
        ",", \(AncestralLineage[
          20, {2.458462043572085`, 
            2.4862026095016123`}, {{a, b, c, d}}, {1}, {}]\), 
        ",", \(AncestralLineage[
          21, {2.4862026095016123`, 
            3.9524773177113115`}, {{a, b, c, d}}, {1}, {}]\), 
        ",", \(AncestralLineage[
          22, {3.9524773177113115`, 
            4.0138506590066365`}, {{a, b, c, d}, {}}, {0.9888375144798349`, 
            1}, {}]\), 
        ",", \(AncestralLineage[
          23, {3.9524773177113115`, 
            4.0138506590066365`}, {{}, {a, b, c, d}}, {0.9888375144798349`, 
            1}, {}]\), 
        ",", \(AncestralLineage[
          24, {4.0138506590066365`, 
            5.754090480075275`}, {{a, b, c, d}}, {1}, {}]\), 
        ",", \(AncestralLineage[
          25, {5.754090480075275`, 
            5.835659306754844`}, {{a, b, c, d}, {}}, {0.18912143960102942`, 
            1}, {}]\), 
        ",", \(AncestralLineage[
          26, {5.754090480075275`, 
            5.835659306754844`}, {{}, {a, b, c, d}}, {0.18912143960102942`, 
            1}, {}]\), 
        ",", \(AncestralLineage[
          27, {5.835659306754844`, 
            6.460449426008908`}, {{a, b, c, d}}, {1}, {}]\), 
        ",", \(AncestralLineage[
          28, {6.460449426008908`, 
            7.077559804918352`}, {{a, b, c, d}, {}}, {0.3588500293612883`, 
            1}, {}]\), 
        ",", \(AncestralLineage[
          29, {6.460449426008908`, 
            7.077559804918352`}, {{}, {a, b, c, d}}, {0.3588500293612883`, 
            1}, {}]\), 
        ",", \(AncestralLineage[
          30, {7.077559804918352`, 
            9.350056023799493`}, {{a, b, c, d}}, {1}, {}]\), 
        ",", \(AncestralLineage[
          31, {9.350056023799493`, 
            9.889403896797967`}, {{a, b, c, d}, {}}, {0.1922328343937298`, 
            1}, {}]\), 
        ",", \(AncestralLineage[
          32, {9.350056023799493`, 
            9.889403896797967`}, {{}, {a, b, c, d}}, {0.1922328343937298`, 
            1}, {}]\), 
        ",", \(AncestralLineage[
          33, {9.889403896797967`, 
            10.04865414492197`}, {{a, b, c, d}}, {1}, {}]\), 
        ",", \(AncestralLineage[
          34, {10.04865414492197`, 
            10.957847529079562`}, {{a, b, c, d}, {}}, {0.27813911328582047`, 
            1}, {}]\), 
        ",", \(AncestralLineage[
          35, {10.04865414492197`, 
            11.256831529989311`}, {{}, {a, b, c, d}}, {0.27813911328582047`, 
            1}, {}]\), 
        ",", \(AncestralLineage[
          36, {10.957847529079562`, 
            11.164561785838144`}, {{a, b, c, d}, {}}, {0.27813911328582047`, 
            1}, {}]\), 
        ",", \(AncestralLineage[
          37, {10.957847529079562`, 11.200948263910437`}, {{}}, {1}, {}]\), 
        ",", \(AncestralLineage[
          38, {11.164561785838144`, 
            11.209929483491738`}, {{a, b, c, d}, {}}, {0.27813911328582047`, 
            1}, {}]\), 
        ",", \(AncestralLineage[
          39, {11.164561785838144`, 11.419143745929558`}, {{}}, {1}, {}]\), 
        ",", \(AncestralLineage[
          40, {11.200948263910437`, 11.209929483491738`}, {{}}, {1}, {}]\), 
        ",", \(AncestralLineage[
          41, {11.200948263910437`, 11.245270596164165`}, {{}}, {1}, {}]\), 
        ",", \(AncestralLineage[
          42, {11.209929483491738`, 
            11.256831529989311`}, {{a, b, c, d}, {}}, {0.27813911328582047`, 
            1}, {}]\), 
        ",", \(AncestralLineage[
          43, {11.245270596164165`, 11.692858213787188`}, {{}}, {1}, {}]\), 
        ",", \(AncestralLineage[
          44, {11.245270596164165`, 11.448204985318503`}, {{}}, {1}, {}]\), 
        ",", \(AncestralLineage[
          45, {11.256831529989311`, 
            11.448204985318503`}, {{a, b, c, d}}, {1}, {}]\), 
        ",", \(AncestralLineage[
          46, {11.419143745929558`, 11.875115781439789`}, {{}}, {1}, {}]\), 
        ",", \(AncestralLineage[
          47, {11.419143745929558`, 11.692858213787188`}, {{}}, {1}, {}]\), 
        ",", \(AncestralLineage[
          48, {11.448204985318503`, 
            11.608969128792605`}, {{a, b, c, d}}, {1}, {}]\), ",", 
        RowBox[{"AncestralLineage", "[", 
          RowBox[{"49", ",", 
            RowBox[{"{", 
              RowBox[{"11.608969128792605`", ",", 
                InterpretationBox["\[Infinity]",
                  DirectedInfinity[ 1]]}], "}"}], ",", \({{a, b, c, d}, {}}\),
             ",", \({0.3685312554020764`, 1}\), ",", \({}\)}], "]"}], 
        ",", \(AncestralLineage[
          50, {11.608969128792605`, 
            11.978339898040069`}, {{}, {a, b, c, d}}, {0.3685312554020764`, 
            1}, {}]\), ",", 
        RowBox[{"AncestralLineage", "[", 
          RowBox[{"51", ",", 
            RowBox[{"{", 
              RowBox[{"11.692858213787188`", ",", 
                InterpretationBox["\[Infinity]",
                  DirectedInfinity[ 1]]}], "}"}], ",", \({{}}\), ",", \({1}\),
             ",", \({}\)}], "]"}], 
        ",", \(AncestralLineage[
          52, {11.875115781439789`, 11.880568558037256`}, {{}}, {1}, {}]\), 
        ",", \(AncestralLineage[
          53, {11.875115781439789`, 11.880568558037256`}, {{}}, {1}, {}]\), 
        ",", \(AncestralLineage[
          54, {11.880568558037256`, 11.89781746698131`}, {{}}, {1}, {}]\), 
        ",", \(AncestralLineage[
          55, {11.89781746698131`, 12.059878520006723`}, {{}}, {1}, {}]\), 
        ",", \(AncestralLineage[
          56, {11.89781746698131`, 11.9483218337688`}, {{}}, {1}, {}]\), ",", 
        
        RowBox[{"AncestralLineage", "[", 
          RowBox[{"57", ",", 
            RowBox[{"{", 
              RowBox[{"11.9483218337688`", ",", 
                InterpretationBox["\[Infinity]",
                  DirectedInfinity[ 1]]}], "}"}], ",", \({{}}\), ",", \({1}\),
             ",", \({}\)}], "]"}], 
        ",", \(AncestralLineage[
          58, {11.9483218337688`, 11.978339898040069`}, {{}}, {1}, {}]\), 
        ",", \(AncestralLineage[
          59, {11.978339898040069`, 
            12.059878520006723`}, {{}, {a, b, c, d}}, {0.3685312554020764`, 
            1}, {}]\), ",", 
        RowBox[{"AncestralLineage", "[", 
          RowBox[{"60", ",", 
            RowBox[{"{", 
              RowBox[{"12.059878520006723`", ",", 
                InterpretationBox["\[Infinity]",
                  DirectedInfinity[ 1]]}], "}"}], ",", \({{}, {a, b, c, d}}\),
             ",", \({0.3685312554020764`, 1}\), ",", \({}\)}], "]"}]}], 
      "}"}]], "Output",
  CellLabel->"Out[122]="]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    \(Cases[ng, AncestralLineage[_, {_, _}, {{}}, {1}, _List]]\)], "Input",
  CellLabel->"In[193]:="],

Cell[BoxData[
    RowBox[{"{", 
      RowBox[{\(AncestralLineage[
          6, {0.4292570949591068`, 0.45951657742311824`}, {{}}, {1}, {}]\), 
        ",", \(AncestralLineage[
          12, {2.118015261702507`, 2.3758569290340006`}, {{}}, {1}, {}]\), 
        ",", \(AncestralLineage[
          14, {2.228204237719424`, 2.2897969825533644`}, {{}}, {1}, {}]\), 
        ",", \(AncestralLineage[
          18, {2.3758569290340006`, 2.458462043572085`}, {{}}, {1}, {}]\), 
        ",", \(AncestralLineage[
          19, {2.3758569290340006`, 2.4862026095016123`}, {{}}, {1}, {}]\), 
        ",", \(AncestralLineage[
          37, {10.957847529079562`, 11.200948263910437`}, {{}}, {1}, {}]\), 
        ",", \(AncestralLineage[
          39, {11.164561785838144`, 11.419143745929558`}, {{}}, {1}, {}]\), 
        ",", \(AncestralLineage[
          40, {11.200948263910437`, 11.209929483491738`}, {{}}, {1}, {}]\), 
        ",", \(AncestralLineage[
          41, {11.200948263910437`, 11.245270596164165`}, {{}}, {1}, {}]\), 
        ",", \(AncestralLineage[
          43, {11.245270596164165`, 11.692858213787188`}, {{}}, {1}, {}]\), 
        ",", \(AncestralLineage[
          44, {11.245270596164165`, 11.448204985318503`}, {{}}, {1}, {}]\), 
        ",", \(AncestralLineage[
          46, {11.419143745929558`, 11.875115781439789`}, {{}}, {1}, {}]\), 
        ",", \(AncestralLineage[
          47, {11.419143745929558`, 11.692858213787188`}, {{}}, {1}, {}]\), 
        ",", 
        RowBox[{"AncestralLineage", "[", 
          RowBox[{"51", ",", 
            RowBox[{"{", 
              RowBox[{"11.692858213787188`", ",", 
                InterpretationBox["\[Infinity]",
                  DirectedInfinity[ 1]]}], "}"}], ",", \({{}}\), ",", \({1}\),
             ",", \({}\)}], "]"}], 
        ",", \(AncestralLineage[
          52, {11.875115781439789`, 11.880568558037256`}, {{}}, {1}, {}]\), 
        ",", \(AncestralLineage[
          53, {11.875115781439789`, 11.880568558037256`}, {{}}, {1}, {}]\), 
        ",", \(AncestralLineage[
          54, {11.880568558037256`, 11.89781746698131`}, {{}}, {1}, {}]\), 
        ",", \(AncestralLineage[
          55, {11.89781746698131`, 12.059878520006723`}, {{}}, {1}, {}]\), 
        ",", \(AncestralLineage[
          56, {11.89781746698131`, 11.9483218337688`}, {{}}, {1}, {}]\), ",", 
        
        RowBox[{"AncestralLineage", "[", 
          RowBox[{"57", ",", 
            RowBox[{"{", 
              RowBox[{"11.9483218337688`", ",", 
                InterpretationBox["\[Infinity]",
                  DirectedInfinity[ 1]]}], "}"}], ",", \({{}}\), ",", \({1}\),
             ",", \({}\)}], "]"}], 
        ",", \(AncestralLineage[
          58, {11.9483218337688`, 11.978339898040069`}, {{}}, {1}, {}]\)}], 
      "}"}]], "Output",
  CellLabel->"Out[193]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(NullRecombinationEvents[ng]\)], "Input",
  CellLabel->"In[197]:="],

Cell[BoxData[
    \({{0.4292570949591068`, {3}, {5, 6}, 
        1}, {2.118015261702507`, {11}, {13, 12}, 
        1}, {2.228204237719424`, {13}, {15, 14}, 
        1}, {2.3758569290340006`, {12}, {18, 19}, 
        1}, {10.957847529079562`, {34}, {36, 37}, 
        1}, {11.164561785838144`, {36}, {38, 39}, 
        1}, {11.200948263910437`, {37}, {40, 41}, 
        1}, {11.245270596164165`, {41}, {43, 44}, 
        1}, {11.419143745929558`, {39}, {46, 47}, 
        1}, {11.875115781439789`, {46}, {52, 53}, 
        1}, {11.89781746698131`, {54}, {55, 56}, 
        1}, {11.9483218337688`, {56}, {57, 58}, 1}}\)], "Output",
  CellLabel->"Out[197]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(ExtractLineage[ng, #] &\) /@ LineagesPresent[ng, 0.3]\)], "Input",
  CellLabel->"In[132]:="],

Cell[BoxData[
    \({AncestralLineage[c, {0, 0.6214825149645679`}, {{c}}, {1}, {}], 
      AncestralLineage[
        3, {0.27049717829601805`, 
          0.4292570949591068`}, {{a, b, d}, {}}, {0.01899643970468609`, 
          1}, {}], 
      AncestralLineage[
        4, {0.27049717829601805`, 
          0.6214825149645679`}, {{}, {a, b, d}}, {0.01899643970468609`, 
          1}, {}]}\)], "Output",
  CellLabel->"Out[132]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(Junctions[ng]\)], "Input",
  CellLabel->"In[123]:="],

Cell[BoxData[
    \({0.01899643970468609`, 0.18912143960102942`, 0.1922328343937298`, 
      0.27813911328582047`, 0.3588500293612883`, 0.3685312554020764`, 
      0.9371981015363346`, 0.9888375144798349`}\)], "Output",
  CellLabel->"Out[123]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(AllEvents[ng]\)], "Input",
  CellLabel->"In[133]:="],

Cell[BoxData[
    RowBox[{"{", 
      RowBox[{\({0, {}, {a, b, c, d}, None}\), 
        ",", \({0.027696065882077705`, {b, d}, {1}, None}\), 
        ",", \({0.05710778878192141`, {a, 1}, {2}, None}\), 
        ",", \({0.27049717829601805`, {2}, {3, 4}, 0.01899643970468609`}\), 
        ",", \({0.4292570949591068`, {3}, {5, 6}, 1}\), 
        ",", \({0.45951657742311824`, {5, 6}, {7}, None}\), 
        ",", \({0.6214825149645679`, {c, 4}, {8}, None}\), 
        ",", \({0.6452036798471656`, {7, 8}, {9}, None}\), 
        ",", \({1.9706637158007017`, {9}, {10, 11}, 0.9371981015363346`}\), 
        ",", \({2.118015261702507`, {11}, {13, 12}, 1}\), 
        ",", \({2.228204237719424`, {13}, {15, 14}, 1}\), 
        ",", \({2.2897969825533644`, {10, 14}, {16}, None}\), 
        ",", \({2.3639104415829926`, {15, 16}, {17}, None}\), 
        ",", \({2.3758569290340006`, {12}, {18, 19}, 1}\), 
        ",", \({2.458462043572085`, {17, 18}, {20}, None}\), 
        ",", \({2.4862026095016123`, {19, 20}, {21}, None}\), 
        ",", \({3.9524773177113115`, {21}, {22, 23}, 0.9888375144798349`}\), 
        ",", \({4.0138506590066365`, {22, 23}, {24}, None}\), 
        ",", \({5.754090480075275`, {24}, {25, 26}, 0.18912143960102942`}\), 
        ",", \({5.835659306754844`, {25, 26}, {27}, None}\), 
        ",", \({6.460449426008908`, {27}, {28, 29}, 0.3588500293612883`}\), 
        ",", \({7.077559804918352`, {28, 29}, {30}, None}\), 
        ",", \({9.350056023799493`, {30}, {31, 32}, 0.1922328343937298`}\), 
        ",", \({9.889403896797967`, {31, 32}, {33}, None}\), 
        ",", \({10.04865414492197`, {33}, {34, 35}, 0.27813911328582047`}\), 
        ",", \({10.957847529079562`, {34}, {36, 37}, 1}\), 
        ",", \({11.164561785838144`, {36}, {38, 39}, 1}\), 
        ",", \({11.200948263910437`, {37}, {40, 41}, 1}\), 
        ",", \({11.209929483491738`, {38, 40}, {42}, None}\), 
        ",", \({11.245270596164165`, {41}, {43, 44}, 1}\), 
        ",", \({11.256831529989311`, {35, 42}, {45}, None}\), 
        ",", \({11.419143745929558`, {39}, {46, 47}, 1}\), 
        ",", \({11.448204985318503`, {44, 45}, {48}, None}\), 
        ",", \({11.608969128792605`, {48}, {49, 50}, 0.3685312554020764`}\), 
        ",", \({11.692858213787188`, {43, 47}, {51}, None}\), 
        ",", \({11.875115781439789`, {46}, {52, 53}, 1}\), 
        ",", \({11.880568558037256`, {52, 53}, {54}, None}\), 
        ",", \({11.89781746698131`, {54}, {55, 56}, 1}\), 
        ",", \({11.9483218337688`, {56}, {57, 58}, 1}\), 
        ",", \({11.978339898040069`, {50, 58}, {59}, None}\), 
        ",", \({12.059878520006723`, {55, 59}, {60}, None}\), ",", 
        RowBox[{"{", 
          RowBox[{
            InterpretationBox["\[Infinity]",
              DirectedInfinity[ 1]], ",", \({49, 51, 57, 60}\), ",", \({}\), 
            ",", "None"}], "}"}]}], "}"}]], "Output",
  CellLabel->"Out[133]="]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["Example: excluding null lineages", "SubsubsectionIcon"],

Cell[CellGroupData[{

Cell[BoxData[
    \(ng2 = 
      RandomGenealogy[{a, b, c, d}, 40, 1, 
        DeleteNullLineages \[Rule] True]\)], "Input",
  CellLabel->"In[346]:="],

Cell[BoxData[
    \({0.2339831643602032`, 5, 0.11492662691806055`}\)], "Print",
  CellLabel->"From In[346]:="],

Cell[BoxData[
    InterpretationBox[\("Recombining "\[InvisibleSpace]b\[InvisibleSpace]"; \
current lineages "\[InvisibleSpace]{a, b, c, d}\),
      SequenceForm[ "Recombining ", b, "; current lineages ", {a, b, c, d}],
      Editable->False]], "Print",
  CellLabel->"From In[346]:="],

Cell[BoxData[
    InterpretationBox[
      RowBox[{"\<\"G=\"\>", "\[InvisibleSpace]", 
        RowBox[{"{", 
          RowBox[{
            RowBox[{"AncestralLineage", "[", 
              RowBox[{"a", ",", 
                RowBox[{"{", 
                  RowBox[{"0", ",", 
                    InterpretationBox["\[Infinity]",
                      DirectedInfinity[ 1]]}], "}"}], ",", \({{a}}\), 
                ",", \({1}\), ",", \({}\)}], "]"}], 
            ",", \(AncestralLineage[
              b, {0, 0.2339831643602032`}, {{b}}, {1}, {}]\), ",", 
            RowBox[{"AncestralLineage", "[", 
              RowBox[{"c", ",", 
                RowBox[{"{", 
                  RowBox[{"0", ",", 
                    InterpretationBox["\[Infinity]",
                      DirectedInfinity[ 1]]}], "}"}], ",", \({{c}}\), 
                ",", \({1}\), ",", \({}\)}], "]"}], ",", 
            RowBox[{"AncestralLineage", "[", 
              RowBox[{"d", ",", 
                RowBox[{"{", 
                  RowBox[{"0", ",", 
                    InterpretationBox["\[Infinity]",
                      DirectedInfinity[ 1]]}], "}"}], ",", \({{d}}\), 
                ",", \({1}\), ",", \({}\)}], "]"}], ",", 
            RowBox[{"AncestralLineage", "[", 
              RowBox[{"1", ",", 
                RowBox[{"{", 
                  RowBox[{"0.2339831643602032`", ",", 
                    InterpretationBox["\[Infinity]",
                      DirectedInfinity[ 1]]}], "}"}], ",", \({{b}, {}}\), 
                ",", \({0.11492662691806055`, 1}\), ",", \({}\)}], "]"}], ",",
             
            RowBox[{"AncestralLineage", "[", 
              RowBox[{"2", ",", 
                RowBox[{"{", 
                  RowBox[{"0.2339831643602032`", ",", 
                    InterpretationBox["\[Infinity]",
                      DirectedInfinity[ 1]]}], "}"}], ",", \({{}, {b}}\), 
                ",", \({0.11492662691806055`, 1}\), ",", \({}\)}], "]"}]}], 
          "}"}]}],
      SequenceForm[ "G=", {
        AncestralLineage[ a, {0, 
          DirectedInfinity[ 1]}, {{a}}, {1}, {}], 
        AncestralLineage[ b, {0, 0.23398316436020319}, {{b}}, {1}, {}], 
        AncestralLineage[ c, {0, 
          DirectedInfinity[ 1]}, {{c}}, {1}, {}], 
        AncestralLineage[ d, {0, 
          DirectedInfinity[ 1]}, {{d}}, {1}, {}], 
        AncestralLineage[ 1, {0.23398316436020319, 
          DirectedInfinity[ 1]}, {{b}, {}}, {0.11492662691806055, 1}, {}], 
        AncestralLineage[ 2, {0.23398316436020319, 
          DirectedInfinity[ 1]}, {{}, {b}}, {0.11492662691806055, 1}, {}]}],
      Editable->False]], "Print",
  CellLabel->"From In[346]:="],

Cell[BoxData[
    \({0.08837759457967861`, 4, None}\)], "Print",
  CellLabel->"From In[346]:="],

Cell[BoxData[
    InterpretationBox[\("Coalescing "\[InvisibleSpace]{1, 
          2}\[InvisibleSpace]"; current lineages "\[InvisibleSpace]{a, c, d, 
          1, 2}\),
      SequenceForm[ 
      "Coalescing ", {1, 2}, "; current lineages ", {a, c, d, 1, 2}],
      Editable->False]], "Print",
  CellLabel->"From In[346]:="],

Cell[BoxData[
    InterpretationBox[
      RowBox[{"\<\"G=\"\>", "\[InvisibleSpace]", 
        RowBox[{"{", 
          RowBox[{
            RowBox[{"AncestralLineage", "[", 
              RowBox[{"a", ",", 
                RowBox[{"{", 
                  RowBox[{"0", ",", 
                    InterpretationBox["\[Infinity]",
                      DirectedInfinity[ 1]]}], "}"}], ",", \({{a}}\), 
                ",", \({1}\), ",", \({}\)}], "]"}], 
            ",", \(AncestralLineage[
              b, {0, 0.2339831643602032`}, {{b}}, {1}, {}]\), ",", 
            RowBox[{"AncestralLineage", "[", 
              RowBox[{"c", ",", 
                RowBox[{"{", 
                  RowBox[{"0", ",", 
                    InterpretationBox["\[Infinity]",
                      DirectedInfinity[ 1]]}], "}"}], ",", \({{c}}\), 
                ",", \({1}\), ",", \({}\)}], "]"}], ",", 
            RowBox[{"AncestralLineage", "[", 
              RowBox[{"d", ",", 
                RowBox[{"{", 
                  RowBox[{"0", ",", 
                    InterpretationBox["\[Infinity]",
                      DirectedInfinity[ 1]]}], "}"}], ",", \({{d}}\), 
                ",", \({1}\), ",", \({}\)}], "]"}], 
            ",", \(AncestralLineage[
              1, {0.2339831643602032`, 
                0.3223607589398818`}, {{b}, {}}, {0.11492662691806055`, 
                1}, {}]\), 
            ",", \(AncestralLineage[
              2, {0.2339831643602032`, 
                0.3223607589398818`}, {{}, {b}}, {0.11492662691806055`, 
                1}, {}]\), ",", 
            RowBox[{"AncestralLineage", "[", 
              RowBox[{"3", ",", 
                RowBox[{"{", 
                  RowBox[{"0.3223607589398818`", ",", 
                    InterpretationBox["\[Infinity]",
                      DirectedInfinity[ 1]]}], "}"}], ",", \({{b}}\), 
                ",", \({1}\), ",", \({}\)}], "]"}]}], "}"}]}],
      SequenceForm[ "G=", {
        AncestralLineage[ a, {0, 
          DirectedInfinity[ 1]}, {{a}}, {1}, {}], 
        AncestralLineage[ b, {0, 0.23398316436020319}, {{b}}, {1}, {}], 
        AncestralLineage[ c, {0, 
          DirectedInfinity[ 1]}, {{c}}, {1}, {}], 
        AncestralLineage[ d, {0, 
          DirectedInfinity[ 1]}, {{d}}, {1}, {}], 
        AncestralLineage[ 
        1, {0.23398316436020319, 0.32236075893988181}, {{b}, {}}, {
          0.11492662691806055, 1}, {}], 
        AncestralLineage[ 
        2, {0.23398316436020319, 0.32236075893988181}, {{}, {b}}, {
          0.11492662691806055, 1}, {}], 
        AncestralLineage[ 3, {0.32236075893988181, 
          DirectedInfinity[ 1]}, {{b}}, {1}, {}]}],
      Editable->False]], "Print",
  CellLabel->"From In[346]:="],

Cell[BoxData[
    \({0.16293020678290715`, 3, None}\)], "Print",
  CellLabel->"From In[346]:="],

Cell[BoxData[
    InterpretationBox[\("Coalescing "\[InvisibleSpace]{a, 
          c}\[InvisibleSpace]"; current lineages "\[InvisibleSpace]{a, c, d, 
          3}\),
      SequenceForm[ 
      "Coalescing ", {a, c}, "; current lineages ", {a, c, d, 3}],
      Editable->False]], "Print",
  CellLabel->"From In[346]:="],

Cell[BoxData[
    InterpretationBox[
      RowBox[{"\<\"G=\"\>", "\[InvisibleSpace]", 
        RowBox[{"{", 
          
          RowBox[{\(AncestralLineage[
              a, {0, 0.48529096572278896`}, {{a}}, {1}, {}]\), 
            ",", \(AncestralLineage[
              b, {0, 0.2339831643602032`}, {{b}}, {1}, {}]\), 
            ",", \(AncestralLineage[
              c, {0, 0.48529096572278896`}, {{c}}, {1}, {}]\), ",", 
            RowBox[{"AncestralLineage", "[", 
              RowBox[{"d", ",", 
                RowBox[{"{", 
                  RowBox[{"0", ",", 
                    InterpretationBox["\[Infinity]",
                      DirectedInfinity[ 1]]}], "}"}], ",", \({{d}}\), 
                ",", \({1}\), ",", \({}\)}], "]"}], 
            ",", \(AncestralLineage[
              1, {0.2339831643602032`, 
                0.3223607589398818`}, {{b}, {}}, {0.11492662691806055`, 
                1}, {}]\), 
            ",", \(AncestralLineage[
              2, {0.2339831643602032`, 
                0.3223607589398818`}, {{}, {b}}, {0.11492662691806055`, 
                1}, {}]\), ",", 
            RowBox[{"AncestralLineage", "[", 
              RowBox[{"3", ",", 
                RowBox[{"{", 
                  RowBox[{"0.3223607589398818`", ",", 
                    InterpretationBox["\[Infinity]",
                      DirectedInfinity[ 1]]}], "}"}], ",", \({{b}}\), 
                ",", \({1}\), ",", \({}\)}], "]"}], ",", 
            RowBox[{"AncestralLineage", "[", 
              RowBox[{"4", ",", 
                RowBox[{"{", 
                  RowBox[{"0.48529096572278896`", ",", 
                    InterpretationBox["\[Infinity]",
                      DirectedInfinity[ 1]]}], "}"}], ",", \({{a, c}}\), 
                ",", \({1}\), ",", \({}\)}], "]"}]}], "}"}]}],
      SequenceForm[ "G=", {
        AncestralLineage[ a, {0, 0.48529096572278896}, {{a}}, {1}, {}], 
        AncestralLineage[ b, {0, 0.23398316436020319}, {{b}}, {1}, {}], 
        AncestralLineage[ c, {0, 0.48529096572278896}, {{c}}, {1}, {}], 
        AncestralLineage[ d, {0, 
          DirectedInfinity[ 1]}, {{d}}, {1}, {}], 
        AncestralLineage[ 
        1, {0.23398316436020319, 0.32236075893988181}, {{b}, {}}, {
          0.11492662691806055, 1}, {}], 
        AncestralLineage[ 
        2, {0.23398316436020319, 0.32236075893988181}, {{}, {b}}, {
          0.11492662691806055, 1}, {}], 
        AncestralLineage[ 3, {0.32236075893988181, 
          DirectedInfinity[ 1]}, {{b}}, {1}, {}], 
        AncestralLineage[ 4, {0.48529096572278896, 
          DirectedInfinity[ 1]}, {{a, c}}, {1}, {}]}],
      Editable->False]], "Print",
  CellLabel->"From In[346]:="],

Cell[BoxData[
    \({0.03257287141207302`, 2, None}\)], "Print",
  CellLabel->"From In[346]:="],

Cell[BoxData[
    InterpretationBox[\("Coalescing "\[InvisibleSpace]{3, 
          4}\[InvisibleSpace]"; current lineages "\[InvisibleSpace]{d, 3, 
          4}\),
      SequenceForm[ "Coalescing ", {3, 4}, "; current lineages ", {d, 3, 4}],
      Editable->False]], "Print",
  CellLabel->"From In[346]:="],

Cell[BoxData[
    InterpretationBox[
      RowBox[{"\<\"G=\"\>", "\[InvisibleSpace]", 
        RowBox[{"{", 
          
          RowBox[{\(AncestralLineage[
              a, {0, 0.48529096572278896`}, {{a}}, {1}, {}]\), 
            ",", \(AncestralLineage[
              b, {0, 0.2339831643602032`}, {{b}}, {1}, {}]\), 
            ",", \(AncestralLineage[
              c, {0, 0.48529096572278896`}, {{c}}, {1}, {}]\), ",", 
            RowBox[{"AncestralLineage", "[", 
              RowBox[{"d", ",", 
                RowBox[{"{", 
                  RowBox[{"0", ",", 
                    InterpretationBox["\[Infinity]",
                      DirectedInfinity[ 1]]}], "}"}], ",", \({{d}}\), 
                ",", \({1}\), ",", \({}\)}], "]"}], 
            ",", \(AncestralLineage[
              1, {0.2339831643602032`, 
                0.3223607589398818`}, {{b}, {}}, {0.11492662691806055`, 
                1}, {}]\), 
            ",", \(AncestralLineage[
              2, {0.2339831643602032`, 
                0.3223607589398818`}, {{}, {b}}, {0.11492662691806055`, 
                1}, {}]\), 
            ",", \(AncestralLineage[
              3, {0.3223607589398818`, 0.517863837134862`}, {{b}}, {1}, {}]\),
             ",", \(AncestralLineage[
              4, {0.48529096572278896`, 
                0.517863837134862`}, {{a, c}}, {1}, {}]\), ",", 
            RowBox[{"AncestralLineage", "[", 
              RowBox[{"5", ",", 
                RowBox[{"{", 
                  RowBox[{"0.517863837134862`", ",", 
                    InterpretationBox["\[Infinity]",
                      DirectedInfinity[ 1]]}], "}"}], ",", \({{a, b, c}}\), 
                ",", \({1}\), ",", \({}\)}], "]"}]}], "}"}]}],
      SequenceForm[ "G=", {
        AncestralLineage[ a, {0, 0.48529096572278896}, {{a}}, {1}, {}], 
        AncestralLineage[ b, {0, 0.23398316436020319}, {{b}}, {1}, {}], 
        AncestralLineage[ c, {0, 0.48529096572278896}, {{c}}, {1}, {}], 
        AncestralLineage[ d, {0, 
          DirectedInfinity[ 1]}, {{d}}, {1}, {}], 
        AncestralLineage[ 
        1, {0.23398316436020319, 0.32236075893988181}, {{b}, {}}, {
          0.11492662691806055, 1}, {}], 
        AncestralLineage[ 
        2, {0.23398316436020319, 0.32236075893988181}, {{}, {b}}, {
          0.11492662691806055, 1}, {}], 
        AncestralLineage[ 
        3, {0.32236075893988181, 0.51786383713486195}, {{b}}, {1}, {}], 
        AncestralLineage[ 
        4, {0.48529096572278896, 0.51786383713486195}, {{a, c}}, {1}, {}], 
        AncestralLineage[ 5, {0.51786383713486195, 
          DirectedInfinity[ 1]}, {{a, b, c}}, {1}, {}]}],
      Editable->False]], "Print",
  CellLabel->"From In[346]:="],

Cell[BoxData[
    \({1.0067973414016333`, 3, 0.48913575253109154`}\)], "Print",
  CellLabel->"From In[346]:="],

Cell[BoxData[
    InterpretationBox[\("Recombining "\[InvisibleSpace]5\[InvisibleSpace]"; \
current lineages "\[InvisibleSpace]{d, 5}\),
      SequenceForm[ "Recombining ", 5, "; current lineages ", {d, 5}],
      Editable->False]], "Print",
  CellLabel->"From In[346]:="],

Cell[BoxData[
    InterpretationBox[
      RowBox[{"\<\"G=\"\>", "\[InvisibleSpace]", 
        RowBox[{"{", 
          
          RowBox[{\(AncestralLineage[
              a, {0, 0.48529096572278896`}, {{a}}, {1}, {}]\), 
            ",", \(AncestralLineage[
              b, {0, 0.2339831643602032`}, {{b}}, {1}, {}]\), 
            ",", \(AncestralLineage[
              c, {0, 0.48529096572278896`}, {{c}}, {1}, {}]\), ",", 
            RowBox[{"AncestralLineage", "[", 
              RowBox[{"d", ",", 
                RowBox[{"{", 
                  RowBox[{"0", ",", 
                    InterpretationBox["\[Infinity]",
                      DirectedInfinity[ 1]]}], "}"}], ",", \({{d}}\), 
                ",", \({1}\), ",", \({}\)}], "]"}], 
            ",", \(AncestralLineage[
              1, {0.2339831643602032`, 
                0.3223607589398818`}, {{b}, {}}, {0.11492662691806055`, 
                1}, {}]\), 
            ",", \(AncestralLineage[
              2, {0.2339831643602032`, 
                0.3223607589398818`}, {{}, {b}}, {0.11492662691806055`, 
                1}, {}]\), 
            ",", \(AncestralLineage[
              3, {0.3223607589398818`, 0.517863837134862`}, {{b}}, {1}, {}]\),
             ",", \(AncestralLineage[
              4, {0.48529096572278896`, 
                0.517863837134862`}, {{a, c}}, {1}, {}]\), 
            ",", \(AncestralLineage[
              5, {0.517863837134862`, 
                1.5246611785364954`}, {{a, b, c}}, {1}, {}]\), ",", 
            RowBox[{"AncestralLineage", "[", 
              RowBox[{"6", ",", 
                RowBox[{"{", 
                  RowBox[{"1.5246611785364954`", ",", 
                    InterpretationBox["\[Infinity]",
                      DirectedInfinity[ 1]]}], "}"}], 
                ",", \({{a, b, c}, {}}\), ",", \({0.48913575253109154`, 1}\), 
                ",", \({}\)}], "]"}], ",", 
            RowBox[{"AncestralLineage", "[", 
              RowBox[{"7", ",", 
                RowBox[{"{", 
                  RowBox[{"1.5246611785364954`", ",", 
                    InterpretationBox["\[Infinity]",
                      DirectedInfinity[ 1]]}], "}"}], 
                ",", \({{}, {a, b, c}}\), ",", \({0.48913575253109154`, 1}\), 
                ",", \({}\)}], "]"}]}], "}"}]}],
      SequenceForm[ "G=", {
        AncestralLineage[ a, {0, 0.48529096572278896}, {{a}}, {1}, {}], 
        AncestralLineage[ b, {0, 0.23398316436020319}, {{b}}, {1}, {}], 
        AncestralLineage[ c, {0, 0.48529096572278896}, {{c}}, {1}, {}], 
        AncestralLineage[ d, {0, 
          DirectedInfinity[ 1]}, {{d}}, {1}, {}], 
        AncestralLineage[ 
        1, {0.23398316436020319, 0.32236075893988181}, {{b}, {}}, {
          0.11492662691806055, 1}, {}], 
        AncestralLineage[ 
        2, {0.23398316436020319, 0.32236075893988181}, {{}, {b}}, {
          0.11492662691806055, 1}, {}], 
        AncestralLineage[ 
        3, {0.32236075893988181, 0.51786383713486195}, {{b}}, {1}, {}], 
        AncestralLineage[ 
        4, {0.48529096572278896, 0.51786383713486195}, {{a, c}}, {1}, {}], 
        AncestralLineage[ 
        5, {0.51786383713486195, 1.5246611785364954}, {{a, b, c}}, {1}, {}], 
        AncestralLineage[ 6, {1.5246611785364954, 
          DirectedInfinity[ 1]}, {{a, b, c}, {}}, {0.48913575253109154, 
          1}, {}], 
        AncestralLineage[ 7, {1.5246611785364954, 
          DirectedInfinity[ 1]}, {{}, {a, b, c}}, {0.48913575253109154, 
          1}, {}]}],
      Editable->False]], "Print",
  CellLabel->"From In[346]:="],

Cell[BoxData[
    \({0.03348192659222822`, 2, None}\)], "Print",
  CellLabel->"From In[346]:="],

Cell[BoxData[
    InterpretationBox[\("Coalescing "\[InvisibleSpace]{6, 
          7}\[InvisibleSpace]"; current lineages "\[InvisibleSpace]{d, 6, 
          7}\),
      SequenceForm[ "Coalescing ", {6, 7}, "; current lineages ", {d, 6, 7}],
      Editable->False]], "Print",
  CellLabel->"From In[346]:="],

Cell[BoxData[
    InterpretationBox[
      RowBox[{"\<\"G=\"\>", "\[InvisibleSpace]", 
        RowBox[{"{", 
          
          RowBox[{\(AncestralLineage[
              a, {0, 0.48529096572278896`}, {{a}}, {1}, {}]\), 
            ",", \(AncestralLineage[
              b, {0, 0.2339831643602032`}, {{b}}, {1}, {}]\), 
            ",", \(AncestralLineage[
              c, {0, 0.48529096572278896`}, {{c}}, {1}, {}]\), ",", 
            RowBox[{"AncestralLineage", "[", 
              RowBox[{"d", ",", 
                RowBox[{"{", 
                  RowBox[{"0", ",", 
                    InterpretationBox["\[Infinity]",
                      DirectedInfinity[ 1]]}], "}"}], ",", \({{d}}\), 
                ",", \({1}\), ",", \({}\)}], "]"}], 
            ",", \(AncestralLineage[
              1, {0.2339831643602032`, 
                0.3223607589398818`}, {{b}, {}}, {0.11492662691806055`, 
                1}, {}]\), 
            ",", \(AncestralLineage[
              2, {0.2339831643602032`, 
                0.3223607589398818`}, {{}, {b}}, {0.11492662691806055`, 
                1}, {}]\), 
            ",", \(AncestralLineage[
              3, {0.3223607589398818`, 0.517863837134862`}, {{b}}, {1}, {}]\),
             ",", \(AncestralLineage[
              4, {0.48529096572278896`, 
                0.517863837134862`}, {{a, c}}, {1}, {}]\), 
            ",", \(AncestralLineage[
              5, {0.517863837134862`, 
                1.5246611785364954`}, {{a, b, c}}, {1}, {}]\), 
            ",", \(AncestralLineage[
              6, {1.5246611785364954`, 
                1.5581431051287236`}, {{a, b, c}, {}}, {0.48913575253109154`, 
                1}, {}]\), 
            ",", \(AncestralLineage[
              7, {1.5246611785364954`, 
                1.5581431051287236`}, {{}, {a, b, c}}, {0.48913575253109154`, 
                1}, {}]\), ",", 
            RowBox[{"AncestralLineage", "[", 
              RowBox[{"8", ",", 
                RowBox[{"{", 
                  RowBox[{"1.5581431051287236`", ",", 
                    InterpretationBox["\[Infinity]",
                      DirectedInfinity[ 1]]}], "}"}], ",", \({{a, b, c}}\), 
                ",", \({1}\), ",", \({}\)}], "]"}]}], "}"}]}],
      SequenceForm[ "G=", {
        AncestralLineage[ a, {0, 0.48529096572278896}, {{a}}, {1}, {}], 
        AncestralLineage[ b, {0, 0.23398316436020319}, {{b}}, {1}, {}], 
        AncestralLineage[ c, {0, 0.48529096572278896}, {{c}}, {1}, {}], 
        AncestralLineage[ d, {0, 
          DirectedInfinity[ 1]}, {{d}}, {1}, {}], 
        AncestralLineage[ 
        1, {0.23398316436020319, 0.32236075893988181}, {{b}, {}}, {
          0.11492662691806055, 1}, {}], 
        AncestralLineage[ 
        2, {0.23398316436020319, 0.32236075893988181}, {{}, {b}}, {
          0.11492662691806055, 1}, {}], 
        AncestralLineage[ 
        3, {0.32236075893988181, 0.51786383713486195}, {{b}}, {1}, {}], 
        AncestralLineage[ 
        4, {0.48529096572278896, 0.51786383713486195}, {{a, c}}, {1}, {}], 
        AncestralLineage[ 
        5, {0.51786383713486195, 1.5246611785364954}, {{a, b, c}}, {1}, {}], 
        AncestralLineage[ 
        6, {1.5246611785364954, 1.5581431051287236}, {{a, b, c}, {}}, {
          0.48913575253109154, 1}, {}], 
        AncestralLineage[ 
        7, {1.5246611785364954, 1.5581431051287236}, {{}, {a, b, c}}, {
          0.48913575253109154, 1}, {}], 
        AncestralLineage[ 8, {1.5581431051287236, 
          DirectedInfinity[ 1]}, {{a, b, c}}, {1}, {}]}],
      Editable->False]], "Print",
  CellLabel->"From In[346]:="],

Cell[BoxData[
    \({0.09722527253713455`, 3, 0.8125105445944757`}\)], "Print",
  CellLabel->"From In[346]:="],

Cell[BoxData[
    InterpretationBox[\("Recombining "\[InvisibleSpace]8\[InvisibleSpace]"; \
current lineages "\[InvisibleSpace]{d, 8}\),
      SequenceForm[ "Recombining ", 8, "; current lineages ", {d, 8}],
      Editable->False]], "Print",
  CellLabel->"From In[346]:="],

Cell[BoxData[
    InterpretationBox[
      RowBox[{"\<\"G=\"\>", "\[InvisibleSpace]", 
        RowBox[{"{", 
          
          RowBox[{\(AncestralLineage[
              a, {0, 0.48529096572278896`}, {{a}}, {1}, {}]\), 
            ",", \(AncestralLineage[
              b, {0, 0.2339831643602032`}, {{b}}, {1}, {}]\), 
            ",", \(AncestralLineage[
              c, {0, 0.48529096572278896`}, {{c}}, {1}, {}]\), ",", 
            RowBox[{"AncestralLineage", "[", 
              RowBox[{"d", ",", 
                RowBox[{"{", 
                  RowBox[{"0", ",", 
                    InterpretationBox["\[Infinity]",
                      DirectedInfinity[ 1]]}], "}"}], ",", \({{d}}\), 
                ",", \({1}\), ",", \({}\)}], "]"}], 
            ",", \(AncestralLineage[
              1, {0.2339831643602032`, 
                0.3223607589398818`}, {{b}, {}}, {0.11492662691806055`, 
                1}, {}]\), 
            ",", \(AncestralLineage[
              2, {0.2339831643602032`, 
                0.3223607589398818`}, {{}, {b}}, {0.11492662691806055`, 
                1}, {}]\), 
            ",", \(AncestralLineage[
              3, {0.3223607589398818`, 0.517863837134862`}, {{b}}, {1}, {}]\),
             ",", \(AncestralLineage[
              4, {0.48529096572278896`, 
                0.517863837134862`}, {{a, c}}, {1}, {}]\), 
            ",", \(AncestralLineage[
              5, {0.517863837134862`, 
                1.5246611785364954`}, {{a, b, c}}, {1}, {}]\), 
            ",", \(AncestralLineage[
              6, {1.5246611785364954`, 
                1.5581431051287236`}, {{a, b, c}, {}}, {0.48913575253109154`, 
                1}, {}]\), 
            ",", \(AncestralLineage[
              7, {1.5246611785364954`, 
                1.5581431051287236`}, {{}, {a, b, c}}, {0.48913575253109154`, 
                1}, {}]\), 
            ",", \(AncestralLineage[
              8, {1.5581431051287236`, 
                1.655368377665858`}, {{a, b, c}}, {1}, {}]\), ",", 
            RowBox[{"AncestralLineage", "[", 
              RowBox[{"9", ",", 
                RowBox[{"{", 
                  RowBox[{"1.655368377665858`", ",", 
                    InterpretationBox["\[Infinity]",
                      DirectedInfinity[ 1]]}], "}"}], 
                ",", \({{a, b, c}, {}}\), ",", \({0.8125105445944757`, 1}\), 
                ",", \({}\)}], "]"}], ",", 
            RowBox[{"AncestralLineage", "[", 
              RowBox[{"10", ",", 
                RowBox[{"{", 
                  RowBox[{"1.655368377665858`", ",", 
                    InterpretationBox["\[Infinity]",
                      DirectedInfinity[ 1]]}], "}"}], 
                ",", \({{}, {a, b, c}}\), ",", \({0.8125105445944757`, 1}\), 
                ",", \({}\)}], "]"}]}], "}"}]}],
      SequenceForm[ "G=", {
        AncestralLineage[ a, {0, 0.48529096572278896}, {{a}}, {1}, {}], 
        AncestralLineage[ b, {0, 0.23398316436020319}, {{b}}, {1}, {}], 
        AncestralLineage[ c, {0, 0.48529096572278896}, {{c}}, {1}, {}], 
        AncestralLineage[ d, {0, 
          DirectedInfinity[ 1]}, {{d}}, {1}, {}], 
        AncestralLineage[ 
        1, {0.23398316436020319, 0.32236075893988181}, {{b}, {}}, {
          0.11492662691806055, 1}, {}], 
        AncestralLineage[ 
        2, {0.23398316436020319, 0.32236075893988181}, {{}, {b}}, {
          0.11492662691806055, 1}, {}], 
        AncestralLineage[ 
        3, {0.32236075893988181, 0.51786383713486195}, {{b}}, {1}, {}], 
        AncestralLineage[ 
        4, {0.48529096572278896, 0.51786383713486195}, {{a, c}}, {1}, {}], 
        AncestralLineage[ 
        5, {0.51786383713486195, 1.5246611785364954}, {{a, b, c}}, {1}, {}], 
        AncestralLineage[ 
        6, {1.5246611785364954, 1.5581431051287236}, {{a, b, c}, {}}, {
          0.48913575253109154, 1}, {}], 
        AncestralLineage[ 
        7, {1.5246611785364954, 1.5581431051287236}, {{}, {a, b, c}}, {
          0.48913575253109154, 1}, {}], 
        AncestralLineage[ 
        8, {1.5581431051287236, 1.6553683776658581}, {{a, b, c}}, {1}, {}], 
        AncestralLineage[ 9, {1.6553683776658581, 
          DirectedInfinity[ 1]}, {{a, b, c}, {}}, {0.81251054459447569, 
          1}, {}], 
        AncestralLineage[ 10, {1.6553683776658581, 
          DirectedInfinity[ 1]}, {{}, {a, b, c}}, {0.81251054459447569, 
          1}, {}]}],
      Editable->False]], "Print",
  CellLabel->"From In[346]:="],

Cell[BoxData[
    \({0.07245122175122634`, 2, None}\)], "Print",
  CellLabel->"From In[346]:="],

Cell[BoxData[
    InterpretationBox[\("Coalescing "\[InvisibleSpace]{d, 
          9}\[InvisibleSpace]"; current lineages "\[InvisibleSpace]{d, 9, 
          10}\),
      SequenceForm[ "Coalescing ", {d, 9}, "; current lineages ", {d, 9, 10}],
      
      Editable->False]], "Print",
  CellLabel->"From In[346]:="],

Cell[BoxData[
    InterpretationBox[
      RowBox[{"\<\"G=\"\>", "\[InvisibleSpace]", 
        RowBox[{"{", 
          
          RowBox[{\(AncestralLineage[
              a, {0, 0.48529096572278896`}, {{a}}, {1}, {}]\), 
            ",", \(AncestralLineage[
              b, {0, 0.2339831643602032`}, {{b}}, {1}, {}]\), 
            ",", \(AncestralLineage[
              c, {0, 0.48529096572278896`}, {{c}}, {1}, {}]\), 
            ",", \(AncestralLineage[
              d, {0, 1.7278195994170844`}, {{d}}, {1}, {}]\), 
            ",", \(AncestralLineage[
              1, {0.2339831643602032`, 
                0.3223607589398818`}, {{b}, {}}, {0.11492662691806055`, 
                1}, {}]\), 
            ",", \(AncestralLineage[
              2, {0.2339831643602032`, 
                0.3223607589398818`}, {{}, {b}}, {0.11492662691806055`, 
                1}, {}]\), 
            ",", \(AncestralLineage[
              3, {0.3223607589398818`, 0.517863837134862`}, {{b}}, {1}, {}]\),
             ",", \(AncestralLineage[
              4, {0.48529096572278896`, 
                0.517863837134862`}, {{a, c}}, {1}, {}]\), 
            ",", \(AncestralLineage[
              5, {0.517863837134862`, 
                1.5246611785364954`}, {{a, b, c}}, {1}, {}]\), 
            ",", \(AncestralLineage[
              6, {1.5246611785364954`, 
                1.5581431051287236`}, {{a, b, c}, {}}, {0.48913575253109154`, 
                1}, {}]\), 
            ",", \(AncestralLineage[
              7, {1.5246611785364954`, 
                1.5581431051287236`}, {{}, {a, b, c}}, {0.48913575253109154`, 
                1}, {}]\), 
            ",", \(AncestralLineage[
              8, {1.5581431051287236`, 
                1.655368377665858`}, {{a, b, c}}, {1}, {}]\), 
            ",", \(AncestralLineage[
              9, {1.655368377665858`, 
                1.7278195994170844`}, {{a, b, c}, {}}, {0.8125105445944757`, 
                1}, {}]\), ",", 
            RowBox[{"AncestralLineage", "[", 
              RowBox[{"10", ",", 
                RowBox[{"{", 
                  RowBox[{"1.655368377665858`", ",", 
                    InterpretationBox["\[Infinity]",
                      DirectedInfinity[ 1]]}], "}"}], 
                ",", \({{}, {a, b, c}}\), ",", \({0.8125105445944757`, 1}\), 
                ",", \({}\)}], "]"}], ",", 
            RowBox[{"AncestralLineage", "[", 
              RowBox[{"11", ",", 
                RowBox[{"{", 
                  RowBox[{"1.7278195994170844`", ",", 
                    InterpretationBox["\[Infinity]",
                      DirectedInfinity[ 1]]}], "}"}], 
                ",", \({{a, b, c, d}, {d}}\), 
                ",", \({0.8125105445944757`, 1}\), ",", \({}\)}], "]"}]}], 
          "}"}]}],
      SequenceForm[ "G=", {
        AncestralLineage[ a, {0, 0.48529096572278896}, {{a}}, {1}, {}], 
        AncestralLineage[ b, {0, 0.23398316436020319}, {{b}}, {1}, {}], 
        AncestralLineage[ c, {0, 0.48529096572278896}, {{c}}, {1}, {}], 
        AncestralLineage[ d, {0, 1.7278195994170844}, {{d}}, {1}, {}], 
        AncestralLineage[ 
        1, {0.23398316436020319, 0.32236075893988181}, {{b}, {}}, {
          0.11492662691806055, 1}, {}], 
        AncestralLineage[ 
        2, {0.23398316436020319, 0.32236075893988181}, {{}, {b}}, {
          0.11492662691806055, 1}, {}], 
        AncestralLineage[ 
        3, {0.32236075893988181, 0.51786383713486195}, {{b}}, {1}, {}], 
        AncestralLineage[ 
        4, {0.48529096572278896, 0.51786383713486195}, {{a, c}}, {1}, {}], 
        AncestralLineage[ 
        5, {0.51786383713486195, 1.5246611785364954}, {{a, b, c}}, {1}, {}], 
        AncestralLineage[ 
        6, {1.5246611785364954, 1.5581431051287236}, {{a, b, c}, {}}, {
          0.48913575253109154, 1}, {}], 
        AncestralLineage[ 
        7, {1.5246611785364954, 1.5581431051287236}, {{}, {a, b, c}}, {
          0.48913575253109154, 1}, {}], 
        AncestralLineage[ 
        8, {1.5581431051287236, 1.6553683776658581}, {{a, b, c}}, {1}, {}], 
        AncestralLineage[ 
        9, {1.6553683776658581, 1.7278195994170844}, {{a, b, c}, {}}, {
          0.81251054459447569, 1}, {}], 
        AncestralLineage[ 10, {1.6553683776658581, 
          DirectedInfinity[ 1]}, {{}, {a, b, c}}, {0.81251054459447569, 
          1}, {}], 
        AncestralLineage[ 11, {1.7278195994170844, 
          DirectedInfinity[ 1]}, {{a, b, c, d}, {d}}, {0.81251054459447569, 
          1}, {}]}],
      Editable->False]], "Print",
  CellLabel->"From In[346]:="],

Cell[BoxData[
    \({1.1845242766192698`, 3, 0.8211640322266659`}\)], "Print",
  CellLabel->"From In[346]:="],

Cell[BoxData[
    InterpretationBox[\("Recombining "\[InvisibleSpace]11\[InvisibleSpace]"; \
current lineages "\[InvisibleSpace]{10, 11}\),
      SequenceForm[ "Recombining ", 11, "; current lineages ", {10, 11}],
      Editable->False]], "Print",
  CellLabel->"From In[346]:="],

Cell[BoxData[
    InterpretationBox[
      RowBox[{"\<\"G=\"\>", "\[InvisibleSpace]", 
        RowBox[{"{", 
          
          RowBox[{\(AncestralLineage[
              a, {0, 0.48529096572278896`}, {{a}}, {1}, {}]\), 
            ",", \(AncestralLineage[
              b, {0, 0.2339831643602032`}, {{b}}, {1}, {}]\), 
            ",", \(AncestralLineage[
              c, {0, 0.48529096572278896`}, {{c}}, {1}, {}]\), 
            ",", \(AncestralLineage[
              d, {0, 1.7278195994170844`}, {{d}}, {1}, {}]\), 
            ",", \(AncestralLineage[
              1, {0.2339831643602032`, 
                0.3223607589398818`}, {{b}, {}}, {0.11492662691806055`, 
                1}, {}]\), 
            ",", \(AncestralLineage[
              2, {0.2339831643602032`, 
                0.3223607589398818`}, {{}, {b}}, {0.11492662691806055`, 
                1}, {}]\), 
            ",", \(AncestralLineage[
              3, {0.3223607589398818`, 0.517863837134862`}, {{b}}, {1}, {}]\),
             ",", \(AncestralLineage[
              4, {0.48529096572278896`, 
                0.517863837134862`}, {{a, c}}, {1}, {}]\), 
            ",", \(AncestralLineage[
              5, {0.517863837134862`, 
                1.5246611785364954`}, {{a, b, c}}, {1}, {}]\), 
            ",", \(AncestralLineage[
              6, {1.5246611785364954`, 
                1.5581431051287236`}, {{a, b, c}, {}}, {0.48913575253109154`, 
                1}, {}]\), 
            ",", \(AncestralLineage[
              7, {1.5246611785364954`, 
                1.5581431051287236`}, {{}, {a, b, c}}, {0.48913575253109154`, 
                1}, {}]\), 
            ",", \(AncestralLineage[
              8, {1.5581431051287236`, 
                1.655368377665858`}, {{a, b, c}}, {1}, {}]\), 
            ",", \(AncestralLineage[
              9, {1.655368377665858`, 
                1.7278195994170844`}, {{a, b, c}, {}}, {0.8125105445944757`, 
                1}, {}]\), ",", 
            RowBox[{"AncestralLineage", "[", 
              RowBox[{"10", ",", 
                RowBox[{"{", 
                  RowBox[{"1.655368377665858`", ",", 
                    InterpretationBox["\[Infinity]",
                      DirectedInfinity[ 1]]}], "}"}], 
                ",", \({{}, {a, b, c}}\), ",", \({0.8125105445944757`, 1}\), 
                ",", \({}\)}], "]"}], 
            ",", \(AncestralLineage[
              11, {1.7278195994170844`, 
                2.9123438760363545`}, {{a, b, c, 
                  d}, {d}}, {0.8125105445944757`, 1}, {}]\), ",", 
            RowBox[{"AncestralLineage", "[", 
              RowBox[{"12", ",", 
                RowBox[{"{", 
                  RowBox[{"2.9123438760363545`", ",", 
                    InterpretationBox["\[Infinity]",
                      DirectedInfinity[ 1]]}], "}"}], 
                ",", \({{a, b, c, d}, {d}, {}}\), 
                ",", \({0.8125105445944757`, 0.8211640322266659`, 1}\), 
                ",", \({}\)}], "]"}], ",", 
            RowBox[{"AncestralLineage", "[", 
              RowBox[{"13", ",", 
                RowBox[{"{", 
                  RowBox[{"2.9123438760363545`", ",", 
                    InterpretationBox["\[Infinity]",
                      DirectedInfinity[ 1]]}], "}"}], ",", \({{}, {d}}\), 
                ",", \({0.8211640322266659`, 1}\), ",", \({}\)}], "]"}]}], 
          "}"}]}],
      SequenceForm[ "G=", {
        AncestralLineage[ a, {0, 0.48529096572278896}, {{a}}, {1}, {}], 
        AncestralLineage[ b, {0, 0.23398316436020319}, {{b}}, {1}, {}], 
        AncestralLineage[ c, {0, 0.48529096572278896}, {{c}}, {1}, {}], 
        AncestralLineage[ d, {0, 1.7278195994170844}, {{d}}, {1}, {}], 
        AncestralLineage[ 
        1, {0.23398316436020319, 0.32236075893988181}, {{b}, {}}, {
          0.11492662691806055, 1}, {}], 
        AncestralLineage[ 
        2, {0.23398316436020319, 0.32236075893988181}, {{}, {b}}, {
          0.11492662691806055, 1}, {}], 
        AncestralLineage[ 
        3, {0.32236075893988181, 0.51786383713486195}, {{b}}, {1}, {}], 
        AncestralLineage[ 
        4, {0.48529096572278896, 0.51786383713486195}, {{a, c}}, {1}, {}], 
        AncestralLineage[ 
        5, {0.51786383713486195, 1.5246611785364954}, {{a, b, c}}, {1}, {}], 
        AncestralLineage[ 
        6, {1.5246611785364954, 1.5581431051287236}, {{a, b, c}, {}}, {
          0.48913575253109154, 1}, {}], 
        AncestralLineage[ 
        7, {1.5246611785364954, 1.5581431051287236}, {{}, {a, b, c}}, {
          0.48913575253109154, 1}, {}], 
        AncestralLineage[ 
        8, {1.5581431051287236, 1.6553683776658581}, {{a, b, c}}, {1}, {}], 
        AncestralLineage[ 
        9, {1.6553683776658581, 1.7278195994170844}, {{a, b, c}, {}}, {
          0.81251054459447569, 1}, {}], 
        AncestralLineage[ 10, {1.6553683776658581, 
          DirectedInfinity[ 1]}, {{}, {a, b, c}}, {0.81251054459447569, 
          1}, {}], 
        AncestralLineage[ 
        11, {1.7278195994170844, 2.9123438760363545}, {{a, b, c, d}, {d}}, {
          0.81251054459447569, 1}, {}], 
        AncestralLineage[ 12, {2.9123438760363545, 
          DirectedInfinity[ 1]}, {{a, b, c, d}, {d}, {}}, {
          0.81251054459447569, 0.8211640322266659, 1}, {}], 
        AncestralLineage[ 13, {2.9123438760363545, 
          DirectedInfinity[ 1]}, {{}, {d}}, {0.8211640322266659, 1}, {}]}],
      Editable->False]], "Print",
  CellLabel->"From In[346]:="],

Cell[BoxData[
    \({0.13873747444189785`, 2, None}\)], "Print",
  CellLabel->"From In[346]:="],

Cell[BoxData[
    InterpretationBox[\("Coalescing "\[InvisibleSpace]{12, 
          13}\[InvisibleSpace]"; current lineages "\[InvisibleSpace]{10, 12, 
          13}\),
      SequenceForm[ 
      "Coalescing ", {12, 13}, "; current lineages ", {10, 12, 13}],
      Editable->False]], "Print",
  CellLabel->"From In[346]:="],

Cell[BoxData[
    InterpretationBox[
      RowBox[{"\<\"G=\"\>", "\[InvisibleSpace]", 
        RowBox[{"{", 
          
          RowBox[{\(AncestralLineage[
              a, {0, 0.48529096572278896`}, {{a}}, {1}, {}]\), 
            ",", \(AncestralLineage[
              b, {0, 0.2339831643602032`}, {{b}}, {1}, {}]\), 
            ",", \(AncestralLineage[
              c, {0, 0.48529096572278896`}, {{c}}, {1}, {}]\), 
            ",", \(AncestralLineage[
              d, {0, 1.7278195994170844`}, {{d}}, {1}, {}]\), 
            ",", \(AncestralLineage[
              1, {0.2339831643602032`, 
                0.3223607589398818`}, {{b}, {}}, {0.11492662691806055`, 
                1}, {}]\), 
            ",", \(AncestralLineage[
              2, {0.2339831643602032`, 
                0.3223607589398818`}, {{}, {b}}, {0.11492662691806055`, 
                1}, {}]\), 
            ",", \(AncestralLineage[
              3, {0.3223607589398818`, 0.517863837134862`}, {{b}}, {1}, {}]\),
             ",", \(AncestralLineage[
              4, {0.48529096572278896`, 
                0.517863837134862`}, {{a, c}}, {1}, {}]\), 
            ",", \(AncestralLineage[
              5, {0.517863837134862`, 
                1.5246611785364954`}, {{a, b, c}}, {1}, {}]\), 
            ",", \(AncestralLineage[
              6, {1.5246611785364954`, 
                1.5581431051287236`}, {{a, b, c}, {}}, {0.48913575253109154`, 
                1}, {}]\), 
            ",", \(AncestralLineage[
              7, {1.5246611785364954`, 
                1.5581431051287236`}, {{}, {a, b, c}}, {0.48913575253109154`, 
                1}, {}]\), 
            ",", \(AncestralLineage[
              8, {1.5581431051287236`, 
                1.655368377665858`}, {{a, b, c}}, {1}, {}]\), 
            ",", \(AncestralLineage[
              9, {1.655368377665858`, 
                1.7278195994170844`}, {{a, b, c}, {}}, {0.8125105445944757`, 
                1}, {}]\), ",", 
            RowBox[{"AncestralLineage", "[", 
              RowBox[{"10", ",", 
                RowBox[{"{", 
                  RowBox[{"1.655368377665858`", ",", 
                    InterpretationBox["\[Infinity]",
                      DirectedInfinity[ 1]]}], "}"}], 
                ",", \({{}, {a, b, c}}\), ",", \({0.8125105445944757`, 1}\), 
                ",", \({}\)}], "]"}], 
            ",", \(AncestralLineage[
              11, {1.7278195994170844`, 
                2.9123438760363545`}, {{a, b, c, 
                  d}, {d}}, {0.8125105445944757`, 1}, {}]\), 
            ",", \(AncestralLineage[
              12, {2.9123438760363545`, 
                3.051081350478252`}, {{a, b, c, 
                  d}, {d}, {}}, {0.8125105445944757`, 0.8211640322266659`, 
                1}, {}]\), 
            ",", \(AncestralLineage[
              13, {2.9123438760363545`, 
                3.051081350478252`}, {{}, {d}}, {0.8211640322266659`, 
                1}, {}]\), ",", 
            RowBox[{"AncestralLineage", "[", 
              RowBox[{"14", ",", 
                RowBox[{"{", 
                  RowBox[{"3.051081350478252`", ",", 
                    InterpretationBox["\[Infinity]",
                      DirectedInfinity[ 1]]}], "}"}], 
                ",", \({{a, b, c, d}, {d}}\), 
                ",", \({0.8125105445944757`, 1}\), ",", \({}\)}], "]"}]}], 
          "}"}]}],
      SequenceForm[ "G=", {
        AncestralLineage[ a, {0, 0.48529096572278896}, {{a}}, {1}, {}], 
        AncestralLineage[ b, {0, 0.23398316436020319}, {{b}}, {1}, {}], 
        AncestralLineage[ c, {0, 0.48529096572278896}, {{c}}, {1}, {}], 
        AncestralLineage[ d, {0, 1.7278195994170844}, {{d}}, {1}, {}], 
        AncestralLineage[ 
        1, {0.23398316436020319, 0.32236075893988181}, {{b}, {}}, {
          0.11492662691806055, 1}, {}], 
        AncestralLineage[ 
        2, {0.23398316436020319, 0.32236075893988181}, {{}, {b}}, {
          0.11492662691806055, 1}, {}], 
        AncestralLineage[ 
        3, {0.32236075893988181, 0.51786383713486195}, {{b}}, {1}, {}], 
        AncestralLineage[ 
        4, {0.48529096572278896, 0.51786383713486195}, {{a, c}}, {1}, {}], 
        AncestralLineage[ 
        5, {0.51786383713486195, 1.5246611785364954}, {{a, b, c}}, {1}, {}], 
        AncestralLineage[ 
        6, {1.5246611785364954, 1.5581431051287236}, {{a, b, c}, {}}, {
          0.48913575253109154, 1}, {}], 
        AncestralLineage[ 
        7, {1.5246611785364954, 1.5581431051287236}, {{}, {a, b, c}}, {
          0.48913575253109154, 1}, {}], 
        AncestralLineage[ 
        8, {1.5581431051287236, 1.6553683776658581}, {{a, b, c}}, {1}, {}], 
        AncestralLineage[ 
        9, {1.6553683776658581, 1.7278195994170844}, {{a, b, c}, {}}, {
          0.81251054459447569, 1}, {}], 
        AncestralLineage[ 10, {1.6553683776658581, 
          DirectedInfinity[ 1]}, {{}, {a, b, c}}, {0.81251054459447569, 
          1}, {}], 
        AncestralLineage[ 
        11, {1.7278195994170844, 2.9123438760363545}, {{a, b, c, d}, {d}}, {
          0.81251054459447569, 1}, {}], 
        AncestralLineage[ 
        12, {2.9123438760363545, 3.0510813504782521}, {{a, b, c, d}, {
          d}, {}}, {0.81251054459447569, 0.8211640322266659, 1}, {}], 
        AncestralLineage[ 
        13, {2.9123438760363545, 3.0510813504782521}, {{}, {d}}, {
          0.8211640322266659, 1}, {}], 
        AncestralLineage[ 14, {3.0510813504782521, 
          DirectedInfinity[ 1]}, {{a, b, c, d}, {d}}, {0.81251054459447569, 
          1}, {}]}],
      Editable->False]], "Print",
  CellLabel->"From In[346]:="],

Cell[BoxData[
    \({0.5688447340042648`, 3, 0.32006658767516016`}\)], "Print",
  CellLabel->"From In[346]:="],

Cell[BoxData[
    InterpretationBox[\("Recombining "\[InvisibleSpace]10\[InvisibleSpace]"; \
current lineages "\[InvisibleSpace]{10, 14}\),
      SequenceForm[ "Recombining ", 10, "; current lineages ", {10, 14}],
      Editable->False]], "Print",
  CellLabel->"From In[346]:="],

Cell[BoxData[
    InterpretationBox[
      RowBox[{"\<\"G=\"\>", "\[InvisibleSpace]", 
        RowBox[{"{", 
          
          RowBox[{\(AncestralLineage[
              a, {0, 0.48529096572278896`}, {{a}}, {1}, {}]\), 
            ",", \(AncestralLineage[
              b, {0, 0.2339831643602032`}, {{b}}, {1}, {}]\), 
            ",", \(AncestralLineage[
              c, {0, 0.48529096572278896`}, {{c}}, {1}, {}]\), 
            ",", \(AncestralLineage[
              d, {0, 1.7278195994170844`}, {{d}}, {1}, {}]\), 
            ",", \(AncestralLineage[
              1, {0.2339831643602032`, 
                0.3223607589398818`}, {{b}, {}}, {0.11492662691806055`, 
                1}, {}]\), 
            ",", \(AncestralLineage[
              2, {0.2339831643602032`, 
                0.3223607589398818`}, {{}, {b}}, {0.11492662691806055`, 
                1}, {}]\), 
            ",", \(AncestralLineage[
              3, {0.3223607589398818`, 0.517863837134862`}, {{b}}, {1}, {}]\),
             ",", \(AncestralLineage[
              4, {0.48529096572278896`, 
                0.517863837134862`}, {{a, c}}, {1}, {}]\), 
            ",", \(AncestralLineage[
              5, {0.517863837134862`, 
                1.5246611785364954`}, {{a, b, c}}, {1}, {}]\), 
            ",", \(AncestralLineage[
              6, {1.5246611785364954`, 
                1.5581431051287236`}, {{a, b, c}, {}}, {0.48913575253109154`, 
                1}, {}]\), 
            ",", \(AncestralLineage[
              7, {1.5246611785364954`, 
                1.5581431051287236`}, {{}, {a, b, c}}, {0.48913575253109154`, 
                1}, {}]\), 
            ",", \(AncestralLineage[
              8, {1.5581431051287236`, 
                1.655368377665858`}, {{a, b, c}}, {1}, {}]\), 
            ",", \(AncestralLineage[
              9, {1.655368377665858`, 
                1.7278195994170844`}, {{a, b, c}, {}}, {0.8125105445944757`, 
                1}, {}]\), ",", 
            RowBox[{"AncestralLineage", "[", 
              RowBox[{"10", ",", 
                RowBox[{"{", 
                  RowBox[{"1.655368377665858`", ",", 
                    InterpretationBox["\[Infinity]",
                      DirectedInfinity[ 1]]}], "}"}], 
                ",", \({{}, {a, b, c}}\), ",", \({0.8125105445944757`, 1}\), 
                ",", \({}\)}], "]"}], 
            ",", \(AncestralLineage[
              11, {1.7278195994170844`, 
                2.9123438760363545`}, {{a, b, c, 
                  d}, {d}}, {0.8125105445944757`, 1}, {}]\), 
            ",", \(AncestralLineage[
              12, {2.9123438760363545`, 
                3.051081350478252`}, {{a, b, c, 
                  d}, {d}, {}}, {0.8125105445944757`, 0.8211640322266659`, 
                1}, {}]\), 
            ",", \(AncestralLineage[
              13, {2.9123438760363545`, 
                3.051081350478252`}, {{}, {d}}, {0.8211640322266659`, 
                1}, {}]\), ",", 
            RowBox[{"AncestralLineage", "[", 
              RowBox[{"14", ",", 
                RowBox[{"{", 
                  RowBox[{"3.051081350478252`", ",", 
                    InterpretationBox["\[Infinity]",
                      DirectedInfinity[ 1]]}], "}"}], 
                ",", \({{a, b, c, d}, {d}}\), 
                ",", \({0.8125105445944757`, 1}\), ",", \({}\)}], "]"}]}], 
          "}"}]}],
      SequenceForm[ "G=", {
        AncestralLineage[ a, {0, 0.48529096572278896}, {{a}}, {1}, {}], 
        AncestralLineage[ b, {0, 0.23398316436020319}, {{b}}, {1}, {}], 
        AncestralLineage[ c, {0, 0.48529096572278896}, {{c}}, {1}, {}], 
        AncestralLineage[ d, {0, 1.7278195994170844}, {{d}}, {1}, {}], 
        AncestralLineage[ 
        1, {0.23398316436020319, 0.32236075893988181}, {{b}, {}}, {
          0.11492662691806055, 1}, {}], 
        AncestralLineage[ 
        2, {0.23398316436020319, 0.32236075893988181}, {{}, {b}}, {
          0.11492662691806055, 1}, {}], 
        AncestralLineage[ 
        3, {0.32236075893988181, 0.51786383713486195}, {{b}}, {1}, {}], 
        AncestralLineage[ 
        4, {0.48529096572278896, 0.51786383713486195}, {{a, c}}, {1}, {}], 
        AncestralLineage[ 
        5, {0.51786383713486195, 1.5246611785364954}, {{a, b, c}}, {1}, {}], 
        AncestralLineage[ 
        6, {1.5246611785364954, 1.5581431051287236}, {{a, b, c}, {}}, {
          0.48913575253109154, 1}, {}], 
        AncestralLineage[ 
        7, {1.5246611785364954, 1.5581431051287236}, {{}, {a, b, c}}, {
          0.48913575253109154, 1}, {}], 
        AncestralLineage[ 
        8, {1.5581431051287236, 1.6553683776658581}, {{a, b, c}}, {1}, {}], 
        AncestralLineage[ 
        9, {1.6553683776658581, 1.7278195994170844}, {{a, b, c}, {}}, {
          0.81251054459447569, 1}, {}], 
        AncestralLineage[ 10, {1.6553683776658581, 
          DirectedInfinity[ 1]}, {{}, {a, b, c}}, {0.81251054459447569, 
          1}, {}], 
        AncestralLineage[ 
        11, {1.7278195994170844, 2.9123438760363545}, {{a, b, c, d}, {d}}, {
          0.81251054459447569, 1}, {}], 
        AncestralLineage[ 
        12, {2.9123438760363545, 3.0510813504782521}, {{a, b, c, d}, {
          d}, {}}, {0.81251054459447569, 0.8211640322266659, 1}, {}], 
        AncestralLineage[ 
        13, {2.9123438760363545, 3.0510813504782521}, {{}, {d}}, {
          0.8211640322266659, 1}, {}], 
        AncestralLineage[ 14, {3.0510813504782521, 
          DirectedInfinity[ 1]}, {{a, b, c, d}, {d}}, {0.81251054459447569, 
          1}, {}]}],
      Editable->False]], "Print",
  CellLabel->"From In[346]:="],

Cell[BoxData[
    \({0.28032007907990103`, 3, 0.35309946313461227`}\)], "Print",
  CellLabel->"From In[346]:="],

Cell[BoxData[
    InterpretationBox[\("Recombining "\[InvisibleSpace]10\[InvisibleSpace]"; \
current lineages "\[InvisibleSpace]{10, 14}\),
      SequenceForm[ "Recombining ", 10, "; current lineages ", {10, 14}],
      Editable->False]], "Print",
  CellLabel->"From In[346]:="],

Cell[BoxData[
    InterpretationBox[
      RowBox[{"\<\"G=\"\>", "\[InvisibleSpace]", 
        RowBox[{"{", 
          
          RowBox[{\(AncestralLineage[
              a, {0, 0.48529096572278896`}, {{a}}, {1}, {}]\), 
            ",", \(AncestralLineage[
              b, {0, 0.2339831643602032`}, {{b}}, {1}, {}]\), 
            ",", \(AncestralLineage[
              c, {0, 0.48529096572278896`}, {{c}}, {1}, {}]\), 
            ",", \(AncestralLineage[
              d, {0, 1.7278195994170844`}, {{d}}, {1}, {}]\), 
            ",", \(AncestralLineage[
              1, {0.2339831643602032`, 
                0.3223607589398818`}, {{b}, {}}, {0.11492662691806055`, 
                1}, {}]\), 
            ",", \(AncestralLineage[
              2, {0.2339831643602032`, 
                0.3223607589398818`}, {{}, {b}}, {0.11492662691806055`, 
                1}, {}]\), 
            ",", \(AncestralLineage[
              3, {0.3223607589398818`, 0.517863837134862`}, {{b}}, {1}, {}]\),
             ",", \(AncestralLineage[
              4, {0.48529096572278896`, 
                0.517863837134862`}, {{a, c}}, {1}, {}]\), 
            ",", \(AncestralLineage[
              5, {0.517863837134862`, 
                1.5246611785364954`}, {{a, b, c}}, {1}, {}]\), 
            ",", \(AncestralLineage[
              6, {1.5246611785364954`, 
                1.5581431051287236`}, {{a, b, c}, {}}, {0.48913575253109154`, 
                1}, {}]\), 
            ",", \(AncestralLineage[
              7, {1.5246611785364954`, 
                1.5581431051287236`}, {{}, {a, b, c}}, {0.48913575253109154`, 
                1}, {}]\), 
            ",", \(AncestralLineage[
              8, {1.5581431051287236`, 
                1.655368377665858`}, {{a, b, c}}, {1}, {}]\), 
            ",", \(AncestralLineage[
              9, {1.655368377665858`, 
                1.7278195994170844`}, {{a, b, c}, {}}, {0.8125105445944757`, 
                1}, {}]\), ",", 
            RowBox[{"AncestralLineage", "[", 
              RowBox[{"10", ",", 
                RowBox[{"{", 
                  RowBox[{"1.655368377665858`", ",", 
                    InterpretationBox["\[Infinity]",
                      DirectedInfinity[ 1]]}], "}"}], 
                ",", \({{}, {a, b, c}}\), ",", \({0.8125105445944757`, 1}\), 
                ",", \({}\)}], "]"}], 
            ",", \(AncestralLineage[
              11, {1.7278195994170844`, 
                2.9123438760363545`}, {{a, b, c, 
                  d}, {d}}, {0.8125105445944757`, 1}, {}]\), 
            ",", \(AncestralLineage[
              12, {2.9123438760363545`, 
                3.051081350478252`}, {{a, b, c, 
                  d}, {d}, {}}, {0.8125105445944757`, 0.8211640322266659`, 
                1}, {}]\), 
            ",", \(AncestralLineage[
              13, {2.9123438760363545`, 
                3.051081350478252`}, {{}, {d}}, {0.8211640322266659`, 
                1}, {}]\), ",", 
            RowBox[{"AncestralLineage", "[", 
              RowBox[{"14", ",", 
                RowBox[{"{", 
                  RowBox[{"3.051081350478252`", ",", 
                    InterpretationBox["\[Infinity]",
                      DirectedInfinity[ 1]]}], "}"}], 
                ",", \({{a, b, c, d}, {d}}\), 
                ",", \({0.8125105445944757`, 1}\), ",", \({}\)}], "]"}]}], 
          "}"}]}],
      SequenceForm[ "G=", {
        AncestralLineage[ a, {0, 0.48529096572278896}, {{a}}, {1}, {}], 
        AncestralLineage[ b, {0, 0.23398316436020319}, {{b}}, {1}, {}], 
        AncestralLineage[ c, {0, 0.48529096572278896}, {{c}}, {1}, {}], 
        AncestralLineage[ d, {0, 1.7278195994170844}, {{d}}, {1}, {}], 
        AncestralLineage[ 
        1, {0.23398316436020319, 0.32236075893988181}, {{b}, {}}, {
          0.11492662691806055, 1}, {}], 
        AncestralLineage[ 
        2, {0.23398316436020319, 0.32236075893988181}, {{}, {b}}, {
          0.11492662691806055, 1}, {}], 
        AncestralLineage[ 
        3, {0.32236075893988181, 0.51786383713486195}, {{b}}, {1}, {}], 
        AncestralLineage[ 
        4, {0.48529096572278896, 0.51786383713486195}, {{a, c}}, {1}, {}], 
        AncestralLineage[ 
        5, {0.51786383713486195, 1.5246611785364954}, {{a, b, c}}, {1}, {}], 
        AncestralLineage[ 
        6, {1.5246611785364954, 1.5581431051287236}, {{a, b, c}, {}}, {
          0.48913575253109154, 1}, {}], 
        AncestralLineage[ 
        7, {1.5246611785364954, 1.5581431051287236}, {{}, {a, b, c}}, {
          0.48913575253109154, 1}, {}], 
        AncestralLineage[ 
        8, {1.5581431051287236, 1.6553683776658581}, {{a, b, c}}, {1}, {}], 
        AncestralLineage[ 
        9, {1.6553683776658581, 1.7278195994170844}, {{a, b, c}, {}}, {
          0.81251054459447569, 1}, {}], 
        AncestralLineage[ 10, {1.6553683776658581, 
          DirectedInfinity[ 1]}, {{}, {a, b, c}}, {0.81251054459447569, 
          1}, {}], 
        AncestralLineage[ 
        11, {1.7278195994170844, 2.9123438760363545}, {{a, b, c, d}, {d}}, {
          0.81251054459447569, 1}, {}], 
        AncestralLineage[ 
        12, {2.9123438760363545, 3.0510813504782521}, {{a, b, c, d}, {
          d}, {}}, {0.81251054459447569, 0.8211640322266659, 1}, {}], 
        AncestralLineage[ 
        13, {2.9123438760363545, 3.0510813504782521}, {{}, {d}}, {
          0.8211640322266659, 1}, {}], 
        AncestralLineage[ 14, {3.0510813504782521, 
          DirectedInfinity[ 1]}, {{a, b, c, d}, {d}}, {0.81251054459447569, 
          1}, {}]}],
      Editable->False]], "Print",
  CellLabel->"From In[346]:="],

Cell[BoxData[
    \({0.032272023352035`, 3, 0.016431884006824982`}\)], "Print",
  CellLabel->"From In[346]:="],

Cell[BoxData[
    InterpretationBox[\("Recombining "\[InvisibleSpace]14\[InvisibleSpace]"; \
current lineages "\[InvisibleSpace]{10, 14}\),
      SequenceForm[ "Recombining ", 14, "; current lineages ", {10, 14}],
      Editable->False]], "Print",
  CellLabel->"From In[346]:="],

Cell[BoxData[
    InterpretationBox[
      RowBox[{"\<\"G=\"\>", "\[InvisibleSpace]", 
        RowBox[{"{", 
          
          RowBox[{\(AncestralLineage[
              a, {0, 0.48529096572278896`}, {{a}}, {1}, {}]\), 
            ",", \(AncestralLineage[
              b, {0, 0.2339831643602032`}, {{b}}, {1}, {}]\), 
            ",", \(AncestralLineage[
              c, {0, 0.48529096572278896`}, {{c}}, {1}, {}]\), 
            ",", \(AncestralLineage[
              d, {0, 1.7278195994170844`}, {{d}}, {1}, {}]\), 
            ",", \(AncestralLineage[
              1, {0.2339831643602032`, 
                0.3223607589398818`}, {{b}, {}}, {0.11492662691806055`, 
                1}, {}]\), 
            ",", \(AncestralLineage[
              2, {0.2339831643602032`, 
                0.3223607589398818`}, {{}, {b}}, {0.11492662691806055`, 
                1}, {}]\), 
            ",", \(AncestralLineage[
              3, {0.3223607589398818`, 0.517863837134862`}, {{b}}, {1}, {}]\),
             ",", \(AncestralLineage[
              4, {0.48529096572278896`, 
                0.517863837134862`}, {{a, c}}, {1}, {}]\), 
            ",", \(AncestralLineage[
              5, {0.517863837134862`, 
                1.5246611785364954`}, {{a, b, c}}, {1}, {}]\), 
            ",", \(AncestralLineage[
              6, {1.5246611785364954`, 
                1.5581431051287236`}, {{a, b, c}, {}}, {0.48913575253109154`, 
                1}, {}]\), 
            ",", \(AncestralLineage[
              7, {1.5246611785364954`, 
                1.5581431051287236`}, {{}, {a, b, c}}, {0.48913575253109154`, 
                1}, {}]\), 
            ",", \(AncestralLineage[
              8, {1.5581431051287236`, 
                1.655368377665858`}, {{a, b, c}}, {1}, {}]\), 
            ",", \(AncestralLineage[
              9, {1.655368377665858`, 
                1.7278195994170844`}, {{a, b, c}, {}}, {0.8125105445944757`, 
                1}, {}]\), ",", 
            RowBox[{"AncestralLineage", "[", 
              RowBox[{"10", ",", 
                RowBox[{"{", 
                  RowBox[{"1.655368377665858`", ",", 
                    InterpretationBox["\[Infinity]",
                      DirectedInfinity[ 1]]}], "}"}], 
                ",", \({{}, {a, b, c}}\), ",", \({0.8125105445944757`, 1}\), 
                ",", \({}\)}], "]"}], 
            ",", \(AncestralLineage[
              11, {1.7278195994170844`, 
                2.9123438760363545`}, {{a, b, c, 
                  d}, {d}}, {0.8125105445944757`, 1}, {}]\), 
            ",", \(AncestralLineage[
              12, {2.9123438760363545`, 
                3.051081350478252`}, {{a, b, c, 
                  d}, {d}, {}}, {0.8125105445944757`, 0.8211640322266659`, 
                1}, {}]\), 
            ",", \(AncestralLineage[
              13, {2.9123438760363545`, 
                3.051081350478252`}, {{}, {d}}, {0.8211640322266659`, 
                1}, {}]\), 
            ",", \(AncestralLineage[
              14, {3.051081350478252`, 
                3.9325181869144528`}, {{a, b, c, 
                  d}, {d}}, {0.8125105445944757`, 1}, {}]\), ",", 
            RowBox[{"AncestralLineage", "[", 
              RowBox[{"15", ",", 
                RowBox[{"{", 
                  RowBox[{"3.9325181869144528`", ",", 
                    InterpretationBox["\[Infinity]",
                      DirectedInfinity[ 1]]}], "}"}], 
                ",", \({{a, b, c, d}, {}}\), 
                ",", \({0.016431884006824982`, 1}\), ",", \({}\)}], "]"}], 
            ",", 
            RowBox[{"AncestralLineage", "[", 
              RowBox[{"16", ",", 
                RowBox[{"{", 
                  RowBox[{"3.9325181869144528`", ",", 
                    InterpretationBox["\[Infinity]",
                      DirectedInfinity[ 1]]}], "}"}], 
                ",", \({{}, {a, b, c, d}, {d}}\), 
                ",", \({0.016431884006824982`, 0.8125105445944757`, 1}\), 
                ",", \({}\)}], "]"}]}], "}"}]}],
      SequenceForm[ "G=", {
        AncestralLineage[ a, {0, 0.48529096572278896}, {{a}}, {1}, {}], 
        AncestralLineage[ b, {0, 0.23398316436020319}, {{b}}, {1}, {}], 
        AncestralLineage[ c, {0, 0.48529096572278896}, {{c}}, {1}, {}], 
        AncestralLineage[ d, {0, 1.7278195994170844}, {{d}}, {1}, {}], 
        AncestralLineage[ 
        1, {0.23398316436020319, 0.32236075893988181}, {{b}, {}}, {
          0.11492662691806055, 1}, {}], 
        AncestralLineage[ 
        2, {0.23398316436020319, 0.32236075893988181}, {{}, {b}}, {
          0.11492662691806055, 1}, {}], 
        AncestralLineage[ 
        3, {0.32236075893988181, 0.51786383713486195}, {{b}}, {1}, {}], 
        AncestralLineage[ 
        4, {0.48529096572278896, 0.51786383713486195}, {{a, c}}, {1}, {}], 
        AncestralLineage[ 
        5, {0.51786383713486195, 1.5246611785364954}, {{a, b, c}}, {1}, {}], 
        AncestralLineage[ 
        6, {1.5246611785364954, 1.5581431051287236}, {{a, b, c}, {}}, {
          0.48913575253109154, 1}, {}], 
        AncestralLineage[ 
        7, {1.5246611785364954, 1.5581431051287236}, {{}, {a, b, c}}, {
          0.48913575253109154, 1}, {}], 
        AncestralLineage[ 
        8, {1.5581431051287236, 1.6553683776658581}, {{a, b, c}}, {1}, {}], 
        AncestralLineage[ 
        9, {1.6553683776658581, 1.7278195994170844}, {{a, b, c}, {}}, {
          0.81251054459447569, 1}, {}], 
        AncestralLineage[ 10, {1.6553683776658581, 
          DirectedInfinity[ 1]}, {{}, {a, b, c}}, {0.81251054459447569, 
          1}, {}], 
        AncestralLineage[ 
        11, {1.7278195994170844, 2.9123438760363545}, {{a, b, c, d}, {d}}, {
          0.81251054459447569, 1}, {}], 
        AncestralLineage[ 
        12, {2.9123438760363545, 3.0510813504782521}, {{a, b, c, d}, {
          d}, {}}, {0.81251054459447569, 0.8211640322266659, 1}, {}], 
        AncestralLineage[ 
        13, {2.9123438760363545, 3.0510813504782521}, {{}, {d}}, {
          0.8211640322266659, 1}, {}], 
        AncestralLineage[ 
        14, {3.0510813504782521, 3.9325181869144528}, {{a, b, c, d}, {d}}, {
          0.81251054459447569, 1}, {}], 
        AncestralLineage[ 15, {3.9325181869144528, 
          DirectedInfinity[ 1]}, {{a, b, c, d}, {}}, {0.016431884006824982, 
          1}, {}], 
        AncestralLineage[ 16, {3.9325181869144528, 
          DirectedInfinity[ 1]}, {{}, {a, b, c, d}, {d}}, {
          0.016431884006824982, 0.81251054459447569, 1}, {}]}],
      Editable->False]], "Print",
  CellLabel->"From In[346]:="],

Cell[BoxData[
    \({0.1982806890637603`, 2, None}\)], "Print",
  CellLabel->"From In[346]:="],

Cell[BoxData[
    InterpretationBox[\("Coalescing "\[InvisibleSpace]{15, 
          16}\[InvisibleSpace]"; current lineages "\[InvisibleSpace]{10, 15, 
          16}\),
      SequenceForm[ 
      "Coalescing ", {15, 16}, "; current lineages ", {10, 15, 16}],
      Editable->False]], "Print",
  CellLabel->"From In[346]:="],

Cell[BoxData[
    InterpretationBox[
      RowBox[{"\<\"G=\"\>", "\[InvisibleSpace]", 
        RowBox[{"{", 
          
          RowBox[{\(AncestralLineage[
              a, {0, 0.48529096572278896`}, {{a}}, {1}, {}]\), 
            ",", \(AncestralLineage[
              b, {0, 0.2339831643602032`}, {{b}}, {1}, {}]\), 
            ",", \(AncestralLineage[
              c, {0, 0.48529096572278896`}, {{c}}, {1}, {}]\), 
            ",", \(AncestralLineage[
              d, {0, 1.7278195994170844`}, {{d}}, {1}, {}]\), 
            ",", \(AncestralLineage[
              1, {0.2339831643602032`, 
                0.3223607589398818`}, {{b}, {}}, {0.11492662691806055`, 
                1}, {}]\), 
            ",", \(AncestralLineage[
              2, {0.2339831643602032`, 
                0.3223607589398818`}, {{}, {b}}, {0.11492662691806055`, 
                1}, {}]\), 
            ",", \(AncestralLineage[
              3, {0.3223607589398818`, 0.517863837134862`}, {{b}}, {1}, {}]\),
             ",", \(AncestralLineage[
              4, {0.48529096572278896`, 
                0.517863837134862`}, {{a, c}}, {1}, {}]\), 
            ",", \(AncestralLineage[
              5, {0.517863837134862`, 
                1.5246611785364954`}, {{a, b, c}}, {1}, {}]\), 
            ",", \(AncestralLineage[
              6, {1.5246611785364954`, 
                1.5581431051287236`}, {{a, b, c}, {}}, {0.48913575253109154`, 
                1}, {}]\), 
            ",", \(AncestralLineage[
              7, {1.5246611785364954`, 
                1.5581431051287236`}, {{}, {a, b, c}}, {0.48913575253109154`, 
                1}, {}]\), 
            ",", \(AncestralLineage[
              8, {1.5581431051287236`, 
                1.655368377665858`}, {{a, b, c}}, {1}, {}]\), 
            ",", \(AncestralLineage[
              9, {1.655368377665858`, 
                1.7278195994170844`}, {{a, b, c}, {}}, {0.8125105445944757`, 
                1}, {}]\), ",", 
            RowBox[{"AncestralLineage", "[", 
              RowBox[{"10", ",", 
                RowBox[{"{", 
                  RowBox[{"1.655368377665858`", ",", 
                    InterpretationBox["\[Infinity]",
                      DirectedInfinity[ 1]]}], "}"}], 
                ",", \({{}, {a, b, c}}\), ",", \({0.8125105445944757`, 1}\), 
                ",", \({}\)}], "]"}], 
            ",", \(AncestralLineage[
              11, {1.7278195994170844`, 
                2.9123438760363545`}, {{a, b, c, 
                  d}, {d}}, {0.8125105445944757`, 1}, {}]\), 
            ",", \(AncestralLineage[
              12, {2.9123438760363545`, 
                3.051081350478252`}, {{a, b, c, 
                  d}, {d}, {}}, {0.8125105445944757`, 0.8211640322266659`, 
                1}, {}]\), 
            ",", \(AncestralLineage[
              13, {2.9123438760363545`, 
                3.051081350478252`}, {{}, {d}}, {0.8211640322266659`, 
                1}, {}]\), 
            ",", \(AncestralLineage[
              14, {3.051081350478252`, 
                3.9325181869144528`}, {{a, b, c, 
                  d}, {d}}, {0.8125105445944757`, 1}, {}]\), 
            ",", \(AncestralLineage[
              15, {3.9325181869144528`, 
                4.130798875978213`}, {{a, b, c, 
                  d}, {}}, {0.016431884006824982`, 1}, {}]\), 
            ",", \(AncestralLineage[
              16, {3.9325181869144528`, 
                4.130798875978213`}, {{}, {a, b, c, 
                  d}, {d}}, {0.016431884006824982`, 0.8125105445944757`, 
                1}, {}]\), ",", 
            RowBox[{"AncestralLineage", "[", 
              RowBox[{"17", ",", 
                RowBox[{"{", 
                  RowBox[{"4.130798875978213`", ",", 
                    InterpretationBox["\[Infinity]",
                      DirectedInfinity[ 1]]}], "}"}], 
                ",", \({{a, b, c, d}, {d}}\), 
                ",", \({0.8125105445944757`, 1}\), ",", \({}\)}], "]"}]}], 
          "}"}]}],
      SequenceForm[ "G=", {
        AncestralLineage[ a, {0, 0.48529096572278896}, {{a}}, {1}, {}], 
        AncestralLineage[ b, {0, 0.23398316436020319}, {{b}}, {1}, {}], 
        AncestralLineage[ c, {0, 0.48529096572278896}, {{c}}, {1}, {}], 
        AncestralLineage[ d, {0, 1.7278195994170844}, {{d}}, {1}, {}], 
        AncestralLineage[ 
        1, {0.23398316436020319, 0.32236075893988181}, {{b}, {}}, {
          0.11492662691806055, 1}, {}], 
        AncestralLineage[ 
        2, {0.23398316436020319, 0.32236075893988181}, {{}, {b}}, {
          0.11492662691806055, 1}, {}], 
        AncestralLineage[ 
        3, {0.32236075893988181, 0.51786383713486195}, {{b}}, {1}, {}], 
        AncestralLineage[ 
        4, {0.48529096572278896, 0.51786383713486195}, {{a, c}}, {1}, {}], 
        AncestralLineage[ 
        5, {0.51786383713486195, 1.5246611785364954}, {{a, b, c}}, {1}, {}], 
        AncestralLineage[ 
        6, {1.5246611785364954, 1.5581431051287236}, {{a, b, c}, {}}, {
          0.48913575253109154, 1}, {}], 
        AncestralLineage[ 
        7, {1.5246611785364954, 1.5581431051287236}, {{}, {a, b, c}}, {
          0.48913575253109154, 1}, {}], 
        AncestralLineage[ 
        8, {1.5581431051287236, 1.6553683776658581}, {{a, b, c}}, {1}, {}], 
        AncestralLineage[ 
        9, {1.6553683776658581, 1.7278195994170844}, {{a, b, c}, {}}, {
          0.81251054459447569, 1}, {}], 
        AncestralLineage[ 10, {1.6553683776658581, 
          DirectedInfinity[ 1]}, {{}, {a, b, c}}, {0.81251054459447569, 
          1}, {}], 
        AncestralLineage[ 
        11, {1.7278195994170844, 2.9123438760363545}, {{a, b, c, d}, {d}}, {
          0.81251054459447569, 1}, {}], 
        AncestralLineage[ 
        12, {2.9123438760363545, 3.0510813504782521}, {{a, b, c, d}, {
          d}, {}}, {0.81251054459447569, 0.8211640322266659, 1}, {}], 
        AncestralLineage[ 
        13, {2.9123438760363545, 3.0510813504782521}, {{}, {d}}, {
          0.8211640322266659, 1}, {}], 
        AncestralLineage[ 
        14, {3.0510813504782521, 3.9325181869144528}, {{a, b, c, d}, {d}}, {
          0.81251054459447569, 1}, {}], 
        AncestralLineage[ 
        15, {3.9325181869144528, 4.130798875978213}, {{a, b, c, d}, {}}, {
          0.016431884006824982, 1}, {}], 
        AncestralLineage[ 
        16, {3.9325181869144528, 4.130798875978213}, {{}, {a, b, c, d}, {
          d}}, {0.016431884006824982, 0.81251054459447569, 1}, {}], 
        AncestralLineage[ 17, {4.130798875978213, 
          DirectedInfinity[ 1]}, {{a, b, c, d}, {d}}, {0.81251054459447569, 
          1}, {}]}],
      Editable->False]], "Print",
  CellLabel->"From In[346]:="],

Cell[BoxData[
    \({0.7076293942205095`, 3, 0.7440283682703366`}\)], "Print",
  CellLabel->"From In[346]:="],

Cell[BoxData[
    InterpretationBox[\("Recombining "\[InvisibleSpace]17\[InvisibleSpace]"; \
current lineages "\[InvisibleSpace]{10, 17}\),
      SequenceForm[ "Recombining ", 17, "; current lineages ", {10, 17}],
      Editable->False]], "Print",
  CellLabel->"From In[346]:="],

Cell[BoxData[
    InterpretationBox[
      RowBox[{"\<\"G=\"\>", "\[InvisibleSpace]", 
        RowBox[{"{", 
          
          RowBox[{\(AncestralLineage[
              a, {0, 0.48529096572278896`}, {{a}}, {1}, {}]\), 
            ",", \(AncestralLineage[
              b, {0, 0.2339831643602032`}, {{b}}, {1}, {}]\), 
            ",", \(AncestralLineage[
              c, {0, 0.48529096572278896`}, {{c}}, {1}, {}]\), 
            ",", \(AncestralLineage[
              d, {0, 1.7278195994170844`}, {{d}}, {1}, {}]\), 
            ",", \(AncestralLineage[
              1, {0.2339831643602032`, 
                0.3223607589398818`}, {{b}, {}}, {0.11492662691806055`, 
                1}, {}]\), 
            ",", \(AncestralLineage[
              2, {0.2339831643602032`, 
                0.3223607589398818`}, {{}, {b}}, {0.11492662691806055`, 
                1}, {}]\), 
            ",", \(AncestralLineage[
              3, {0.3223607589398818`, 0.517863837134862`}, {{b}}, {1}, {}]\),
             ",", \(AncestralLineage[
              4, {0.48529096572278896`, 
                0.517863837134862`}, {{a, c}}, {1}, {}]\), 
            ",", \(AncestralLineage[
              5, {0.517863837134862`, 
                1.5246611785364954`}, {{a, b, c}}, {1}, {}]\), 
            ",", \(AncestralLineage[
              6, {1.5246611785364954`, 
                1.5581431051287236`}, {{a, b, c}, {}}, {0.48913575253109154`, 
                1}, {}]\), 
            ",", \(AncestralLineage[
              7, {1.5246611785364954`, 
                1.5581431051287236`}, {{}, {a, b, c}}, {0.48913575253109154`, 
                1}, {}]\), 
            ",", \(AncestralLineage[
              8, {1.5581431051287236`, 
                1.655368377665858`}, {{a, b, c}}, {1}, {}]\), 
            ",", \(AncestralLineage[
              9, {1.655368377665858`, 
                1.7278195994170844`}, {{a, b, c}, {}}, {0.8125105445944757`, 
                1}, {}]\), ",", 
            RowBox[{"AncestralLineage", "[", 
              RowBox[{"10", ",", 
                RowBox[{"{", 
                  RowBox[{"1.655368377665858`", ",", 
                    InterpretationBox["\[Infinity]",
                      DirectedInfinity[ 1]]}], "}"}], 
                ",", \({{}, {a, b, c}}\), ",", \({0.8125105445944757`, 1}\), 
                ",", \({}\)}], "]"}], 
            ",", \(AncestralLineage[
              11, {1.7278195994170844`, 
                2.9123438760363545`}, {{a, b, c, 
                  d}, {d}}, {0.8125105445944757`, 1}, {}]\), 
            ",", \(AncestralLineage[
              12, {2.9123438760363545`, 
                3.051081350478252`}, {{a, b, c, 
                  d}, {d}, {}}, {0.8125105445944757`, 0.8211640322266659`, 
                1}, {}]\), 
            ",", \(AncestralLineage[
              13, {2.9123438760363545`, 
                3.051081350478252`}, {{}, {d}}, {0.8211640322266659`, 
                1}, {}]\), 
            ",", \(AncestralLineage[
              14, {3.051081350478252`, 
                3.9325181869144528`}, {{a, b, c, 
                  d}, {d}}, {0.8125105445944757`, 1}, {}]\), 
            ",", \(AncestralLineage[
              15, {3.9325181869144528`, 
                4.130798875978213`}, {{a, b, c, 
                  d}, {}}, {0.016431884006824982`, 1}, {}]\), 
            ",", \(AncestralLineage[
              16, {3.9325181869144528`, 
                4.130798875978213`}, {{}, {a, b, c, 
                  d}, {d}}, {0.016431884006824982`, 0.8125105445944757`, 
                1}, {}]\), 
            ",", \(AncestralLineage[
              17, {4.130798875978213`, 
                4.8384282701987225`}, {{a, b, c, 
                  d}, {d}}, {0.8125105445944757`, 1}, {}]\), ",", 
            RowBox[{"AncestralLineage", "[", 
              RowBox[{"18", ",", 
                RowBox[{"{", 
                  RowBox[{"4.8384282701987225`", ",", 
                    InterpretationBox["\[Infinity]",
                      DirectedInfinity[ 1]]}], "}"}], 
                ",", \({{a, b, c, d}, {}}\), 
                ",", \({0.7440283682703366`, 1}\), ",", \({}\)}], "]"}], ",", 
            
            RowBox[{"AncestralLineage", "[", 
              RowBox[{"19", ",", 
                RowBox[{"{", 
                  RowBox[{"4.8384282701987225`", ",", 
                    InterpretationBox["\[Infinity]",
                      DirectedInfinity[ 1]]}], "}"}], 
                ",", \({{}, {a, b, c, d}, {d}}\), 
                ",", \({0.7440283682703366`, 0.8125105445944757`, 1}\), 
                ",", \({}\)}], "]"}]}], "}"}]}],
      SequenceForm[ "G=", {
        AncestralLineage[ a, {0, 0.48529096572278896}, {{a}}, {1}, {}], 
        AncestralLineage[ b, {0, 0.23398316436020319}, {{b}}, {1}, {}], 
        AncestralLineage[ c, {0, 0.48529096572278896}, {{c}}, {1}, {}], 
        AncestralLineage[ d, {0, 1.7278195994170844}, {{d}}, {1}, {}], 
        AncestralLineage[ 
        1, {0.23398316436020319, 0.32236075893988181}, {{b}, {}}, {
          0.11492662691806055, 1}, {}], 
        AncestralLineage[ 
        2, {0.23398316436020319, 0.32236075893988181}, {{}, {b}}, {
          0.11492662691806055, 1}, {}], 
        AncestralLineage[ 
        3, {0.32236075893988181, 0.51786383713486195}, {{b}}, {1}, {}], 
        AncestralLineage[ 
        4, {0.48529096572278896, 0.51786383713486195}, {{a, c}}, {1}, {}], 
        AncestralLineage[ 
        5, {0.51786383713486195, 1.5246611785364954}, {{a, b, c}}, {1}, {}], 
        AncestralLineage[ 
        6, {1.5246611785364954, 1.5581431051287236}, {{a, b, c}, {}}, {
          0.48913575253109154, 1}, {}], 
        AncestralLineage[ 
        7, {1.5246611785364954, 1.5581431051287236}, {{}, {a, b, c}}, {
          0.48913575253109154, 1}, {}], 
        AncestralLineage[ 
        8, {1.5581431051287236, 1.6553683776658581}, {{a, b, c}}, {1}, {}], 
        AncestralLineage[ 
        9, {1.6553683776658581, 1.7278195994170844}, {{a, b, c}, {}}, {
          0.81251054459447569, 1}, {}], 
        AncestralLineage[ 10, {1.6553683776658581, 
          DirectedInfinity[ 1]}, {{}, {a, b, c}}, {0.81251054459447569, 
          1}, {}], 
        AncestralLineage[ 
        11, {1.7278195994170844, 2.9123438760363545}, {{a, b, c, d}, {d}}, {
          0.81251054459447569, 1}, {}], 
        AncestralLineage[ 
        12, {2.9123438760363545, 3.0510813504782521}, {{a, b, c, d}, {
          d}, {}}, {0.81251054459447569, 0.8211640322266659, 1}, {}], 
        AncestralLineage[ 
        13, {2.9123438760363545, 3.0510813504782521}, {{}, {d}}, {
          0.8211640322266659, 1}, {}], 
        AncestralLineage[ 
        14, {3.0510813504782521, 3.9325181869144528}, {{a, b, c, d}, {d}}, {
          0.81251054459447569, 1}, {}], 
        AncestralLineage[ 
        15, {3.9325181869144528, 4.130798875978213}, {{a, b, c, d}, {}}, {
          0.016431884006824982, 1}, {}], 
        AncestralLineage[ 
        16, {3.9325181869144528, 4.130798875978213}, {{}, {a, b, c, d}, {
          d}}, {0.016431884006824982, 0.81251054459447569, 1}, {}], 
        AncestralLineage[ 
        17, {4.130798875978213, 4.8384282701987225}, {{a, b, c, d}, {d}}, {
          0.81251054459447569, 1}, {}], 
        AncestralLineage[ 18, {4.8384282701987225, 
          DirectedInfinity[ 1]}, {{a, b, c, d}, {}}, {0.74402836827033658, 
          1}, {}], 
        AncestralLineage[ 19, {4.8384282701987225, 
          DirectedInfinity[ 1]}, {{}, {a, b, c, d}, {d}}, {
          0.74402836827033658, 0.81251054459447569, 1}, {}]}],
      Editable->False]], "Print",
  CellLabel->"From In[346]:="],

Cell[BoxData[
    \({0.028049488682987584`, 2, None}\)], "Print",
  CellLabel->"From In[346]:="],

Cell[BoxData[
    InterpretationBox[\("Coalescing "\[InvisibleSpace]{18, 
          19}\[InvisibleSpace]"; current lineages "\[InvisibleSpace]{10, 18, 
          19}\),
      SequenceForm[ 
      "Coalescing ", {18, 19}, "; current lineages ", {10, 18, 19}],
      Editable->False]], "Print",
  CellLabel->"From In[346]:="],

Cell[BoxData[
    InterpretationBox[
      RowBox[{"\<\"G=\"\>", "\[InvisibleSpace]", 
        RowBox[{"{", 
          
          RowBox[{\(AncestralLineage[
              a, {0, 0.48529096572278896`}, {{a}}, {1}, {}]\), 
            ",", \(AncestralLineage[
              b, {0, 0.2339831643602032`}, {{b}}, {1}, {}]\), 
            ",", \(AncestralLineage[
              c, {0, 0.48529096572278896`}, {{c}}, {1}, {}]\), 
            ",", \(AncestralLineage[
              d, {0, 1.7278195994170844`}, {{d}}, {1}, {}]\), 
            ",", \(AncestralLineage[
              1, {0.2339831643602032`, 
                0.3223607589398818`}, {{b}, {}}, {0.11492662691806055`, 
                1}, {}]\), 
            ",", \(AncestralLineage[
              2, {0.2339831643602032`, 
                0.3223607589398818`}, {{}, {b}}, {0.11492662691806055`, 
                1}, {}]\), 
            ",", \(AncestralLineage[
              3, {0.3223607589398818`, 0.517863837134862`}, {{b}}, {1}, {}]\),
             ",", \(AncestralLineage[
              4, {0.48529096572278896`, 
                0.517863837134862`}, {{a, c}}, {1}, {}]\), 
            ",", \(AncestralLineage[
              5, {0.517863837134862`, 
                1.5246611785364954`}, {{a, b, c}}, {1}, {}]\), 
            ",", \(AncestralLineage[
              6, {1.5246611785364954`, 
                1.5581431051287236`}, {{a, b, c}, {}}, {0.48913575253109154`, 
                1}, {}]\), 
            ",", \(AncestralLineage[
              7, {1.5246611785364954`, 
                1.5581431051287236`}, {{}, {a, b, c}}, {0.48913575253109154`, 
                1}, {}]\), 
            ",", \(AncestralLineage[
              8, {1.5581431051287236`, 
                1.655368377665858`}, {{a, b, c}}, {1}, {}]\), 
            ",", \(AncestralLineage[
              9, {1.655368377665858`, 
                1.7278195994170844`}, {{a, b, c}, {}}, {0.8125105445944757`, 
                1}, {}]\), ",", 
            RowBox[{"AncestralLineage", "[", 
              RowBox[{"10", ",", 
                RowBox[{"{", 
                  RowBox[{"1.655368377665858`", ",", 
                    InterpretationBox["\[Infinity]",
                      DirectedInfinity[ 1]]}], "}"}], 
                ",", \({{}, {a, b, c}}\), ",", \({0.8125105445944757`, 1}\), 
                ",", \({}\)}], "]"}], 
            ",", \(AncestralLineage[
              11, {1.7278195994170844`, 
                2.9123438760363545`}, {{a, b, c, 
                  d}, {d}}, {0.8125105445944757`, 1}, {}]\), 
            ",", \(AncestralLineage[
              12, {2.9123438760363545`, 
                3.051081350478252`}, {{a, b, c, 
                  d}, {d}, {}}, {0.8125105445944757`, 0.8211640322266659`, 
                1}, {}]\), 
            ",", \(AncestralLineage[
              13, {2.9123438760363545`, 
                3.051081350478252`}, {{}, {d}}, {0.8211640322266659`, 
                1}, {}]\), 
            ",", \(AncestralLineage[
              14, {3.051081350478252`, 
                3.9325181869144528`}, {{a, b, c, 
                  d}, {d}}, {0.8125105445944757`, 1}, {}]\), 
            ",", \(AncestralLineage[
              15, {3.9325181869144528`, 
                4.130798875978213`}, {{a, b, c, 
                  d}, {}}, {0.016431884006824982`, 1}, {}]\), 
            ",", \(AncestralLineage[
              16, {3.9325181869144528`, 
                4.130798875978213`}, {{}, {a, b, c, 
                  d}, {d}}, {0.016431884006824982`, 0.8125105445944757`, 
                1}, {}]\), 
            ",", \(AncestralLineage[
              17, {4.130798875978213`, 
                4.8384282701987225`}, {{a, b, c, 
                  d}, {d}}, {0.8125105445944757`, 1}, {}]\), 
            ",", \(AncestralLineage[
              18, {4.8384282701987225`, 
                4.86647775888171`}, {{a, b, c, d}, {}}, {0.7440283682703366`, 
                1}, {}]\), 
            ",", \(AncestralLineage[
              19, {4.8384282701987225`, 
                4.86647775888171`}, {{}, {a, b, c, 
                  d}, {d}}, {0.7440283682703366`, 0.8125105445944757`, 
                1}, {}]\), ",", 
            RowBox[{"AncestralLineage", "[", 
              RowBox[{"20", ",", 
                RowBox[{"{", 
                  RowBox[{"4.86647775888171`", ",", 
                    InterpretationBox["\[Infinity]",
                      DirectedInfinity[ 1]]}], "}"}], 
                ",", \({{a, b, c, d}, {d}}\), 
                ",", \({0.8125105445944757`, 1}\), ",", \({}\)}], "]"}]}], 
          "}"}]}],
      SequenceForm[ "G=", {
        AncestralLineage[ a, {0, 0.48529096572278896}, {{a}}, {1}, {}], 
        AncestralLineage[ b, {0, 0.23398316436020319}, {{b}}, {1}, {}], 
        AncestralLineage[ c, {0, 0.48529096572278896}, {{c}}, {1}, {}], 
        AncestralLineage[ d, {0, 1.7278195994170844}, {{d}}, {1}, {}], 
        AncestralLineage[ 
        1, {0.23398316436020319, 0.32236075893988181}, {{b}, {}}, {
          0.11492662691806055, 1}, {}], 
        AncestralLineage[ 
        2, {0.23398316436020319, 0.32236075893988181}, {{}, {b}}, {
          0.11492662691806055, 1}, {}], 
        AncestralLineage[ 
        3, {0.32236075893988181, 0.51786383713486195}, {{b}}, {1}, {}], 
        AncestralLineage[ 
        4, {0.48529096572278896, 0.51786383713486195}, {{a, c}}, {1}, {}], 
        AncestralLineage[ 
        5, {0.51786383713486195, 1.5246611785364954}, {{a, b, c}}, {1}, {}], 
        AncestralLineage[ 
        6, {1.5246611785364954, 1.5581431051287236}, {{a, b, c}, {}}, {
          0.48913575253109154, 1}, {}], 
        AncestralLineage[ 
        7, {1.5246611785364954, 1.5581431051287236}, {{}, {a, b, c}}, {
          0.48913575253109154, 1}, {}], 
        AncestralLineage[ 
        8, {1.5581431051287236, 1.6553683776658581}, {{a, b, c}}, {1}, {}], 
        AncestralLineage[ 
        9, {1.6553683776658581, 1.7278195994170844}, {{a, b, c}, {}}, {
          0.81251054459447569, 1}, {}], 
        AncestralLineage[ 10, {1.6553683776658581, 
          DirectedInfinity[ 1]}, {{}, {a, b, c}}, {0.81251054459447569, 
          1}, {}], 
        AncestralLineage[ 
        11, {1.7278195994170844, 2.9123438760363545}, {{a, b, c, d}, {d}}, {
          0.81251054459447569, 1}, {}], 
        AncestralLineage[ 
        12, {2.9123438760363545, 3.0510813504782521}, {{a, b, c, d}, {
          d}, {}}, {0.81251054459447569, 0.8211640322266659, 1}, {}], 
        AncestralLineage[ 
        13, {2.9123438760363545, 3.0510813504782521}, {{}, {d}}, {
          0.8211640322266659, 1}, {}], 
        AncestralLineage[ 
        14, {3.0510813504782521, 3.9325181869144528}, {{a, b, c, d}, {d}}, {
          0.81251054459447569, 1}, {}], 
        AncestralLineage[ 
        15, {3.9325181869144528, 4.130798875978213}, {{a, b, c, d}, {}}, {
          0.016431884006824982, 1}, {}], 
        AncestralLineage[ 
        16, {3.9325181869144528, 4.130798875978213}, {{}, {a, b, c, d}, {
          d}}, {0.016431884006824982, 0.81251054459447569, 1}, {}], 
        AncestralLineage[ 
        17, {4.130798875978213, 4.8384282701987225}, {{a, b, c, d}, {d}}, {
          0.81251054459447569, 1}, {}], 
        AncestralLineage[ 
        18, {4.8384282701987225, 4.8664777588817101}, {{a, b, c, d}, {}}, {
          0.74402836827033658, 1}, {}], 
        AncestralLineage[ 
        19, {4.8384282701987225, 4.8664777588817101}, {{}, {a, b, c, d}, {
          d}}, {0.74402836827033658, 0.81251054459447569, 1}, {}], 
        AncestralLineage[ 20, {4.8664777588817101, 
          DirectedInfinity[ 1]}, {{a, b, c, d}, {d}}, {0.81251054459447569, 
          1}, {}]}],
      Editable->False]], "Print",
  CellLabel->"From In[346]:="],

Cell[BoxData[
    \({0.3173748817460997`, 3, 0.2950269878840834`}\)], "Print",
  CellLabel->"From In[346]:="],

Cell[BoxData[
    InterpretationBox[\("Recombining "\[InvisibleSpace]10\[InvisibleSpace]"; \
current lineages "\[InvisibleSpace]{10, 20}\),
      SequenceForm[ "Recombining ", 10, "; current lineages ", {10, 20}],
      Editable->False]], "Print",
  CellLabel->"From In[346]:="],

Cell[BoxData[
    InterpretationBox[
      RowBox[{"\<\"G=\"\>", "\[InvisibleSpace]", 
        RowBox[{"{", 
          
          RowBox[{\(AncestralLineage[
              a, {0, 0.48529096572278896`}, {{a}}, {1}, {}]\), 
            ",", \(AncestralLineage[
              b, {0, 0.2339831643602032`}, {{b}}, {1}, {}]\), 
            ",", \(AncestralLineage[
              c, {0, 0.48529096572278896`}, {{c}}, {1}, {}]\), 
            ",", \(AncestralLineage[
              d, {0, 1.7278195994170844`}, {{d}}, {1}, {}]\), 
            ",", \(AncestralLineage[
              1, {0.2339831643602032`, 
                0.3223607589398818`}, {{b}, {}}, {0.11492662691806055`, 
                1}, {}]\), 
            ",", \(AncestralLineage[
              2, {0.2339831643602032`, 
                0.3223607589398818`}, {{}, {b}}, {0.11492662691806055`, 
                1}, {}]\), 
            ",", \(AncestralLineage[
              3, {0.3223607589398818`, 0.517863837134862`}, {{b}}, {1}, {}]\),
             ",", \(AncestralLineage[
              4, {0.48529096572278896`, 
                0.517863837134862`}, {{a, c}}, {1}, {}]\), 
            ",", \(AncestralLineage[
              5, {0.517863837134862`, 
                1.5246611785364954`}, {{a, b, c}}, {1}, {}]\), 
            ",", \(AncestralLineage[
              6, {1.5246611785364954`, 
                1.5581431051287236`}, {{a, b, c}, {}}, {0.48913575253109154`, 
                1}, {}]\), 
            ",", \(AncestralLineage[
              7, {1.5246611785364954`, 
                1.5581431051287236`}, {{}, {a, b, c}}, {0.48913575253109154`, 
                1}, {}]\), 
            ",", \(AncestralLineage[
              8, {1.5581431051287236`, 
                1.655368377665858`}, {{a, b, c}}, {1}, {}]\), 
            ",", \(AncestralLineage[
              9, {1.655368377665858`, 
                1.7278195994170844`}, {{a, b, c}, {}}, {0.8125105445944757`, 
                1}, {}]\), ",", 
            RowBox[{"AncestralLineage", "[", 
              RowBox[{"10", ",", 
                RowBox[{"{", 
                  RowBox[{"1.655368377665858`", ",", 
                    InterpretationBox["\[Infinity]",
                      DirectedInfinity[ 1]]}], "}"}], 
                ",", \({{}, {a, b, c}}\), ",", \({0.8125105445944757`, 1}\), 
                ",", \({}\)}], "]"}], 
            ",", \(AncestralLineage[
              11, {1.7278195994170844`, 
                2.9123438760363545`}, {{a, b, c, 
                  d}, {d}}, {0.8125105445944757`, 1}, {}]\), 
            ",", \(AncestralLineage[
              12, {2.9123438760363545`, 
                3.051081350478252`}, {{a, b, c, 
                  d}, {d}, {}}, {0.8125105445944757`, 0.8211640322266659`, 
                1}, {}]\), 
            ",", \(AncestralLineage[
              13, {2.9123438760363545`, 
                3.051081350478252`}, {{}, {d}}, {0.8211640322266659`, 
                1}, {}]\), 
            ",", \(AncestralLineage[
              14, {3.051081350478252`, 
                3.9325181869144528`}, {{a, b, c, 
                  d}, {d}}, {0.8125105445944757`, 1}, {}]\), 
            ",", \(AncestralLineage[
              15, {3.9325181869144528`, 
                4.130798875978213`}, {{a, b, c, 
                  d}, {}}, {0.016431884006824982`, 1}, {}]\), 
            ",", \(AncestralLineage[
              16, {3.9325181869144528`, 
                4.130798875978213`}, {{}, {a, b, c, 
                  d}, {d}}, {0.016431884006824982`, 0.8125105445944757`, 
                1}, {}]\), 
            ",", \(AncestralLineage[
              17, {4.130798875978213`, 
                4.8384282701987225`}, {{a, b, c, 
                  d}, {d}}, {0.8125105445944757`, 1}, {}]\), 
            ",", \(AncestralLineage[
              18, {4.8384282701987225`, 
                4.86647775888171`}, {{a, b, c, d}, {}}, {0.7440283682703366`, 
                1}, {}]\), 
            ",", \(AncestralLineage[
              19, {4.8384282701987225`, 
                4.86647775888171`}, {{}, {a, b, c, 
                  d}, {d}}, {0.7440283682703366`, 0.8125105445944757`, 
                1}, {}]\), ",", 
            RowBox[{"AncestralLineage", "[", 
              RowBox[{"20", ",", 
                RowBox[{"{", 
                  RowBox[{"4.86647775888171`", ",", 
                    InterpretationBox["\[Infinity]",
                      DirectedInfinity[ 1]]}], "}"}], 
                ",", \({{a, b, c, d}, {d}}\), 
                ",", \({0.8125105445944757`, 1}\), ",", \({}\)}], "]"}]}], 
          "}"}]}],
      SequenceForm[ "G=", {
        AncestralLineage[ a, {0, 0.48529096572278896}, {{a}}, {1}, {}], 
        AncestralLineage[ b, {0, 0.23398316436020319}, {{b}}, {1}, {}], 
        AncestralLineage[ c, {0, 0.48529096572278896}, {{c}}, {1}, {}], 
        AncestralLineage[ d, {0, 1.7278195994170844}, {{d}}, {1}, {}], 
        AncestralLineage[ 
        1, {0.23398316436020319, 0.32236075893988181}, {{b}, {}}, {
          0.11492662691806055, 1}, {}], 
        AncestralLineage[ 
        2, {0.23398316436020319, 0.32236075893988181}, {{}, {b}}, {
          0.11492662691806055, 1}, {}], 
        AncestralLineage[ 
        3, {0.32236075893988181, 0.51786383713486195}, {{b}}, {1}, {}], 
        AncestralLineage[ 
        4, {0.48529096572278896, 0.51786383713486195}, {{a, c}}, {1}, {}], 
        AncestralLineage[ 
        5, {0.51786383713486195, 1.5246611785364954}, {{a, b, c}}, {1}, {}], 
        AncestralLineage[ 
        6, {1.5246611785364954, 1.5581431051287236}, {{a, b, c}, {}}, {
          0.48913575253109154, 1}, {}], 
        AncestralLineage[ 
        7, {1.5246611785364954, 1.5581431051287236}, {{}, {a, b, c}}, {
          0.48913575253109154, 1}, {}], 
        AncestralLineage[ 
        8, {1.5581431051287236, 1.6553683776658581}, {{a, b, c}}, {1}, {}], 
        AncestralLineage[ 
        9, {1.6553683776658581, 1.7278195994170844}, {{a, b, c}, {}}, {
          0.81251054459447569, 1}, {}], 
        AncestralLineage[ 10, {1.6553683776658581, 
          DirectedInfinity[ 1]}, {{}, {a, b, c}}, {0.81251054459447569, 
          1}, {}], 
        AncestralLineage[ 
        11, {1.7278195994170844, 2.9123438760363545}, {{a, b, c, d}, {d}}, {
          0.81251054459447569, 1}, {}], 
        AncestralLineage[ 
        12, {2.9123438760363545, 3.0510813504782521}, {{a, b, c, d}, {
          d}, {}}, {0.81251054459447569, 0.8211640322266659, 1}, {}], 
        AncestralLineage[ 
        13, {2.9123438760363545, 3.0510813504782521}, {{}, {d}}, {
          0.8211640322266659, 1}, {}], 
        AncestralLineage[ 
        14, {3.0510813504782521, 3.9325181869144528}, {{a, b, c, d}, {d}}, {
          0.81251054459447569, 1}, {}], 
        AncestralLineage[ 
        15, {3.9325181869144528, 4.130798875978213}, {{a, b, c, d}, {}}, {
          0.016431884006824982, 1}, {}], 
        AncestralLineage[ 
        16, {3.9325181869144528, 4.130798875978213}, {{}, {a, b, c, d}, {
          d}}, {0.016431884006824982, 0.81251054459447569, 1}, {}], 
        AncestralLineage[ 
        17, {4.130798875978213, 4.8384282701987225}, {{a, b, c, d}, {d}}, {
          0.81251054459447569, 1}, {}], 
        AncestralLineage[ 
        18, {4.8384282701987225, 4.8664777588817101}, {{a, b, c, d}, {}}, {
          0.74402836827033658, 1}, {}], 
        AncestralLineage[ 
        19, {4.8384282701987225, 4.8664777588817101}, {{}, {a, b, c, d}, {
          d}}, {0.74402836827033658, 0.81251054459447569, 1}, {}], 
        AncestralLineage[ 20, {4.8664777588817101, 
          DirectedInfinity[ 1]}, {{a, b, c, d}, {d}}, {0.81251054459447569, 
          1}, {}]}],
      Editable->False]], "Print",
  CellLabel->"From In[346]:="],

Cell[BoxData[
    \({0.058576468989198355`, 3, 0.2754102066203454`}\)], "Print",
  CellLabel->"From In[346]:="],

Cell[BoxData[
    InterpretationBox[\("Recombining "\[InvisibleSpace]10\[InvisibleSpace]"; \
current lineages "\[InvisibleSpace]{10, 20}\),
      SequenceForm[ "Recombining ", 10, "; current lineages ", {10, 20}],
      Editable->False]], "Print",
  CellLabel->"From In[346]:="],

Cell[BoxData[
    InterpretationBox[
      RowBox[{"\<\"G=\"\>", "\[InvisibleSpace]", 
        RowBox[{"{", 
          
          RowBox[{\(AncestralLineage[
              a, {0, 0.48529096572278896`}, {{a}}, {1}, {}]\), 
            ",", \(AncestralLineage[
              b, {0, 0.2339831643602032`}, {{b}}, {1}, {}]\), 
            ",", \(AncestralLineage[
              c, {0, 0.48529096572278896`}, {{c}}, {1}, {}]\), 
            ",", \(AncestralLineage[
              d, {0, 1.7278195994170844`}, {{d}}, {1}, {}]\), 
            ",", \(AncestralLineage[
              1, {0.2339831643602032`, 
                0.3223607589398818`}, {{b}, {}}, {0.11492662691806055`, 
                1}, {}]\), 
            ",", \(AncestralLineage[
              2, {0.2339831643602032`, 
                0.3223607589398818`}, {{}, {b}}, {0.11492662691806055`, 
                1}, {}]\), 
            ",", \(AncestralLineage[
              3, {0.3223607589398818`, 0.517863837134862`}, {{b}}, {1}, {}]\),
             ",", \(AncestralLineage[
              4, {0.48529096572278896`, 
                0.517863837134862`}, {{a, c}}, {1}, {}]\), 
            ",", \(AncestralLineage[
              5, {0.517863837134862`, 
                1.5246611785364954`}, {{a, b, c}}, {1}, {}]\), 
            ",", \(AncestralLineage[
              6, {1.5246611785364954`, 
                1.5581431051287236`}, {{a, b, c}, {}}, {0.48913575253109154`, 
                1}, {}]\), 
            ",", \(AncestralLineage[
              7, {1.5246611785364954`, 
                1.5581431051287236`}, {{}, {a, b, c}}, {0.48913575253109154`, 
                1}, {}]\), 
            ",", \(AncestralLineage[
              8, {1.5581431051287236`, 
                1.655368377665858`}, {{a, b, c}}, {1}, {}]\), 
            ",", \(AncestralLineage[
              9, {1.655368377665858`, 
                1.7278195994170844`}, {{a, b, c}, {}}, {0.8125105445944757`, 
                1}, {}]\), ",", 
            RowBox[{"AncestralLineage", "[", 
              RowBox[{"10", ",", 
                RowBox[{"{", 
                  RowBox[{"1.655368377665858`", ",", 
                    InterpretationBox["\[Infinity]",
                      DirectedInfinity[ 1]]}], "}"}], 
                ",", \({{}, {a, b, c}}\), ",", \({0.8125105445944757`, 1}\), 
                ",", \({}\)}], "]"}], 
            ",", \(AncestralLineage[
              11, {1.7278195994170844`, 
                2.9123438760363545`}, {{a, b, c, 
                  d}, {d}}, {0.8125105445944757`, 1}, {}]\), 
            ",", \(AncestralLineage[
              12, {2.9123438760363545`, 
                3.051081350478252`}, {{a, b, c, 
                  d}, {d}, {}}, {0.8125105445944757`, 0.8211640322266659`, 
                1}, {}]\), 
            ",", \(AncestralLineage[
              13, {2.9123438760363545`, 
                3.051081350478252`}, {{}, {d}}, {0.8211640322266659`, 
                1}, {}]\), 
            ",", \(AncestralLineage[
              14, {3.051081350478252`, 
                3.9325181869144528`}, {{a, b, c, 
                  d}, {d}}, {0.8125105445944757`, 1}, {}]\), 
            ",", \(AncestralLineage[
              15, {3.9325181869144528`, 
                4.130798875978213`}, {{a, b, c, 
                  d}, {}}, {0.016431884006824982`, 1}, {}]\), 
            ",", \(AncestralLineage[
              16, {3.9325181869144528`, 
                4.130798875978213`}, {{}, {a, b, c, 
                  d}, {d}}, {0.016431884006824982`, 0.8125105445944757`, 
                1}, {}]\), 
            ",", \(AncestralLineage[
              17, {4.130798875978213`, 
                4.8384282701987225`}, {{a, b, c, 
                  d}, {d}}, {0.8125105445944757`, 1}, {}]\), 
            ",", \(AncestralLineage[
              18, {4.8384282701987225`, 
                4.86647775888171`}, {{a, b, c, d}, {}}, {0.7440283682703366`, 
                1}, {}]\), 
            ",", \(AncestralLineage[
              19, {4.8384282701987225`, 
                4.86647775888171`}, {{}, {a, b, c, 
                  d}, {d}}, {0.7440283682703366`, 0.8125105445944757`, 
                1}, {}]\), ",", 
            RowBox[{"AncestralLineage", "[", 
              RowBox[{"20", ",", 
                RowBox[{"{", 
                  RowBox[{"4.86647775888171`", ",", 
                    InterpretationBox["\[Infinity]",
                      DirectedInfinity[ 1]]}], "}"}], 
                ",", \({{a, b, c, d}, {d}}\), 
                ",", \({0.8125105445944757`, 1}\), ",", \({}\)}], "]"}]}], 
          "}"}]}],
      SequenceForm[ "G=", {
        AncestralLineage[ a, {0, 0.48529096572278896}, {{a}}, {1}, {}], 
        AncestralLineage[ b, {0, 0.23398316436020319}, {{b}}, {1}, {}], 
        AncestralLineage[ c, {0, 0.48529096572278896}, {{c}}, {1}, {}], 
        AncestralLineage[ d, {0, 1.7278195994170844}, {{d}}, {1}, {}], 
        AncestralLineage[ 
        1, {0.23398316436020319, 0.32236075893988181}, {{b}, {}}, {
          0.11492662691806055, 1}, {}], 
        AncestralLineage[ 
        2, {0.23398316436020319, 0.32236075893988181}, {{}, {b}}, {
          0.11492662691806055, 1}, {}], 
        AncestralLineage[ 
        3, {0.32236075893988181, 0.51786383713486195}, {{b}}, {1}, {}], 
        AncestralLineage[ 
        4, {0.48529096572278896, 0.51786383713486195}, {{a, c}}, {1}, {}], 
        AncestralLineage[ 
        5, {0.51786383713486195, 1.5246611785364954}, {{a, b, c}}, {1}, {}], 
        AncestralLineage[ 
        6, {1.5246611785364954, 1.5581431051287236}, {{a, b, c}, {}}, {
          0.48913575253109154, 1}, {}], 
        AncestralLineage[ 
        7, {1.5246611785364954, 1.5581431051287236}, {{}, {a, b, c}}, {
          0.48913575253109154, 1}, {}], 
        AncestralLineage[ 
        8, {1.5581431051287236, 1.6553683776658581}, {{a, b, c}}, {1}, {}], 
        AncestralLineage[ 
        9, {1.6553683776658581, 1.7278195994170844}, {{a, b, c}, {}}, {
          0.81251054459447569, 1}, {}], 
        AncestralLineage[ 10, {1.6553683776658581, 
          DirectedInfinity[ 1]}, {{}, {a, b, c}}, {0.81251054459447569, 
          1}, {}], 
        AncestralLineage[ 
        11, {1.7278195994170844, 2.9123438760363545}, {{a, b, c, d}, {d}}, {
          0.81251054459447569, 1}, {}], 
        AncestralLineage[ 
        12, {2.9123438760363545, 3.0510813504782521}, {{a, b, c, d}, {
          d}, {}}, {0.81251054459447569, 0.8211640322266659, 1}, {}], 
        AncestralLineage[ 
        13, {2.9123438760363545, 3.0510813504782521}, {{}, {d}}, {
          0.8211640322266659, 1}, {}], 
        AncestralLineage[ 
        14, {3.0510813504782521, 3.9325181869144528}, {{a, b, c, d}, {d}}, {
          0.81251054459447569, 1}, {}], 
        AncestralLineage[ 
        15, {3.9325181869144528, 4.130798875978213}, {{a, b, c, d}, {}}, {
          0.016431884006824982, 1}, {}], 
        AncestralLineage[ 
        16, {3.9325181869144528, 4.130798875978213}, {{}, {a, b, c, d}, {
          d}}, {0.016431884006824982, 0.81251054459447569, 1}, {}], 
        AncestralLineage[ 
        17, {4.130798875978213, 4.8384282701987225}, {{a, b, c, d}, {d}}, {
          0.81251054459447569, 1}, {}], 
        AncestralLineage[ 
        18, {4.8384282701987225, 4.8664777588817101}, {{a, b, c, d}, {}}, {
          0.74402836827033658, 1}, {}], 
        AncestralLineage[ 
        19, {4.8384282701987225, 4.8664777588817101}, {{}, {a, b, c, d}, {
          d}}, {0.74402836827033658, 0.81251054459447569, 1}, {}], 
        AncestralLineage[ 20, {4.8664777588817101, 
          DirectedInfinity[ 1]}, {{a, b, c, d}, {d}}, {0.81251054459447569, 
          1}, {}]}],
      Editable->False]], "Print",
  CellLabel->"From In[346]:="],

Cell[BoxData[
    \({0.05026120641241156`, 3, 0.9265889024279855`}\)], "Print",
  CellLabel->"From In[346]:="],

Cell[BoxData[
    InterpretationBox[\("Recombining "\[InvisibleSpace]20\[InvisibleSpace]"; \
current lineages "\[InvisibleSpace]{10, 20}\),
      SequenceForm[ "Recombining ", 20, "; current lineages ", {10, 20}],
      Editable->False]], "Print",
  CellLabel->"From In[346]:="],

Cell[BoxData[
    InterpretationBox[
      RowBox[{"\<\"G=\"\>", "\[InvisibleSpace]", 
        RowBox[{"{", 
          
          RowBox[{\(AncestralLineage[
              a, {0, 0.48529096572278896`}, {{a}}, {1}, {}]\), 
            ",", \(AncestralLineage[
              b, {0, 0.2339831643602032`}, {{b}}, {1}, {}]\), 
            ",", \(AncestralLineage[
              c, {0, 0.48529096572278896`}, {{c}}, {1}, {}]\), 
            ",", \(AncestralLineage[
              d, {0, 1.7278195994170844`}, {{d}}, {1}, {}]\), 
            ",", \(AncestralLineage[
              1, {0.2339831643602032`, 
                0.3223607589398818`}, {{b}, {}}, {0.11492662691806055`, 
                1}, {}]\), 
            ",", \(AncestralLineage[
              2, {0.2339831643602032`, 
                0.3223607589398818`}, {{}, {b}}, {0.11492662691806055`, 
                1}, {}]\), 
            ",", \(AncestralLineage[
              3, {0.3223607589398818`, 0.517863837134862`}, {{b}}, {1}, {}]\),
             ",", \(AncestralLineage[
              4, {0.48529096572278896`, 
                0.517863837134862`}, {{a, c}}, {1}, {}]\), 
            ",", \(AncestralLineage[
              5, {0.517863837134862`, 
                1.5246611785364954`}, {{a, b, c}}, {1}, {}]\), 
            ",", \(AncestralLineage[
              6, {1.5246611785364954`, 
                1.5581431051287236`}, {{a, b, c}, {}}, {0.48913575253109154`, 
                1}, {}]\), 
            ",", \(AncestralLineage[
              7, {1.5246611785364954`, 
                1.5581431051287236`}, {{}, {a, b, c}}, {0.48913575253109154`, 
                1}, {}]\), 
            ",", \(AncestralLineage[
              8, {1.5581431051287236`, 
                1.655368377665858`}, {{a, b, c}}, {1}, {}]\), 
            ",", \(AncestralLineage[
              9, {1.655368377665858`, 
                1.7278195994170844`}, {{a, b, c}, {}}, {0.8125105445944757`, 
                1}, {}]\), ",", 
            RowBox[{"AncestralLineage", "[", 
              RowBox[{"10", ",", 
                RowBox[{"{", 
                  RowBox[{"1.655368377665858`", ",", 
                    InterpretationBox["\[Infinity]",
                      DirectedInfinity[ 1]]}], "}"}], 
                ",", \({{}, {a, b, c}}\), ",", \({0.8125105445944757`, 1}\), 
                ",", \({}\)}], "]"}], 
            ",", \(AncestralLineage[
              11, {1.7278195994170844`, 
                2.9123438760363545`}, {{a, b, c, 
                  d}, {d}}, {0.8125105445944757`, 1}, {}]\), 
            ",", \(AncestralLineage[
              12, {2.9123438760363545`, 
                3.051081350478252`}, {{a, b, c, 
                  d}, {d}, {}}, {0.8125105445944757`, 0.8211640322266659`, 
                1}, {}]\), 
            ",", \(AncestralLineage[
              13, {2.9123438760363545`, 
                3.051081350478252`}, {{}, {d}}, {0.8211640322266659`, 
                1}, {}]\), 
            ",", \(AncestralLineage[
              14, {3.051081350478252`, 
                3.9325181869144528`}, {{a, b, c, 
                  d}, {d}}, {0.8125105445944757`, 1}, {}]\), 
            ",", \(AncestralLineage[
              15, {3.9325181869144528`, 
                4.130798875978213`}, {{a, b, c, 
                  d}, {}}, {0.016431884006824982`, 1}, {}]\), 
            ",", \(AncestralLineage[
              16, {3.9325181869144528`, 
                4.130798875978213`}, {{}, {a, b, c, 
                  d}, {d}}, {0.016431884006824982`, 0.8125105445944757`, 
                1}, {}]\), 
            ",", \(AncestralLineage[
              17, {4.130798875978213`, 
                4.8384282701987225`}, {{a, b, c, 
                  d}, {d}}, {0.8125105445944757`, 1}, {}]\), 
            ",", \(AncestralLineage[
              18, {4.8384282701987225`, 
                4.86647775888171`}, {{a, b, c, d}, {}}, {0.7440283682703366`, 
                1}, {}]\), 
            ",", \(AncestralLineage[
              19, {4.8384282701987225`, 
                4.86647775888171`}, {{}, {a, b, c, 
                  d}, {d}}, {0.7440283682703366`, 0.8125105445944757`, 
                1}, {}]\), 
            ",", \(AncestralLineage[
              20, {4.86647775888171`, 
                5.292690316029419`}, {{a, b, c, 
                  d}, {d}}, {0.8125105445944757`, 1}, {}]\), ",", 
            RowBox[{"AncestralLineage", "[", 
              RowBox[{"21", ",", 
                RowBox[{"{", 
                  RowBox[{"5.292690316029419`", ",", 
                    InterpretationBox["\[Infinity]",
                      DirectedInfinity[ 1]]}], "}"}], 
                ",", \({{a, b, c, d}, {d}, {}}\), 
                ",", \({0.8125105445944757`, 0.9265889024279855`, 1}\), 
                ",", \({}\)}], "]"}], ",", 
            RowBox[{"AncestralLineage", "[", 
              RowBox[{"22", ",", 
                RowBox[{"{", 
                  RowBox[{"5.292690316029419`", ",", 
                    InterpretationBox["\[Infinity]",
                      DirectedInfinity[ 1]]}], "}"}], ",", \({{}, {d}}\), 
                ",", \({0.9265889024279855`, 1}\), ",", \({}\)}], "]"}]}], 
          "}"}]}],
      SequenceForm[ "G=", {
        AncestralLineage[ a, {0, 0.48529096572278896}, {{a}}, {1}, {}], 
        AncestralLineage[ b, {0, 0.23398316436020319}, {{b}}, {1}, {}], 
        AncestralLineage[ c, {0, 0.48529096572278896}, {{c}}, {1}, {}], 
        AncestralLineage[ d, {0, 1.7278195994170844}, {{d}}, {1}, {}], 
        AncestralLineage[ 
        1, {0.23398316436020319, 0.32236075893988181}, {{b}, {}}, {
          0.11492662691806055, 1}, {}], 
        AncestralLineage[ 
        2, {0.23398316436020319, 0.32236075893988181}, {{}, {b}}, {
          0.11492662691806055, 1}, {}], 
        AncestralLineage[ 
        3, {0.32236075893988181, 0.51786383713486195}, {{b}}, {1}, {}], 
        AncestralLineage[ 
        4, {0.48529096572278896, 0.51786383713486195}, {{a, c}}, {1}, {}], 
        AncestralLineage[ 
        5, {0.51786383713486195, 1.5246611785364954}, {{a, b, c}}, {1}, {}], 
        AncestralLineage[ 
        6, {1.5246611785364954, 1.5581431051287236}, {{a, b, c}, {}}, {
          0.48913575253109154, 1}, {}], 
        AncestralLineage[ 
        7, {1.5246611785364954, 1.5581431051287236}, {{}, {a, b, c}}, {
          0.48913575253109154, 1}, {}], 
        AncestralLineage[ 
        8, {1.5581431051287236, 1.6553683776658581}, {{a, b, c}}, {1}, {}], 
        AncestralLineage[ 
        9, {1.6553683776658581, 1.7278195994170844}, {{a, b, c}, {}}, {
          0.81251054459447569, 1}, {}], 
        AncestralLineage[ 10, {1.6553683776658581, 
          DirectedInfinity[ 1]}, {{}, {a, b, c}}, {0.81251054459447569, 
          1}, {}], 
        AncestralLineage[ 
        11, {1.7278195994170844, 2.9123438760363545}, {{a, b, c, d}, {d}}, {
          0.81251054459447569, 1}, {}], 
        AncestralLineage[ 
        12, {2.9123438760363545, 3.0510813504782521}, {{a, b, c, d}, {
          d}, {}}, {0.81251054459447569, 0.8211640322266659, 1}, {}], 
        AncestralLineage[ 
        13, {2.9123438760363545, 3.0510813504782521}, {{}, {d}}, {
          0.8211640322266659, 1}, {}], 
        AncestralLineage[ 
        14, {3.0510813504782521, 3.9325181869144528}, {{a, b, c, d}, {d}}, {
          0.81251054459447569, 1}, {}], 
        AncestralLineage[ 
        15, {3.9325181869144528, 4.130798875978213}, {{a, b, c, d}, {}}, {
          0.016431884006824982, 1}, {}], 
        AncestralLineage[ 
        16, {3.9325181869144528, 4.130798875978213}, {{}, {a, b, c, d}, {
          d}}, {0.016431884006824982, 0.81251054459447569, 1}, {}], 
        AncestralLineage[ 
        17, {4.130798875978213, 4.8384282701987225}, {{a, b, c, d}, {d}}, {
          0.81251054459447569, 1}, {}], 
        AncestralLineage[ 
        18, {4.8384282701987225, 4.8664777588817101}, {{a, b, c, d}, {}}, {
          0.74402836827033658, 1}, {}], 
        AncestralLineage[ 
        19, {4.8384282701987225, 4.8664777588817101}, {{}, {a, b, c, d}, {
          d}}, {0.74402836827033658, 0.81251054459447569, 1}, {}], 
        AncestralLineage[ 
        20, {4.8664777588817101, 5.292690316029419}, {{a, b, c, d}, {d}}, {
          0.81251054459447569, 1}, {}], 
        AncestralLineage[ 21, {5.292690316029419, 
          DirectedInfinity[ 1]}, {{a, b, c, d}, {d}, {}}, {
          0.81251054459447569, 0.92658890242798553, 1}, {}], 
        AncestralLineage[ 22, {5.292690316029419, 
          DirectedInfinity[ 1]}, {{}, {d}}, {0.92658890242798553, 1}, {}]}],
      Editable->False]], "Print",
  CellLabel->"From In[346]:="],

Cell[BoxData[
    \({0.05331145243873018`, 2, None}\)], "Print",
  CellLabel->"From In[346]:="],

Cell[BoxData[
    InterpretationBox[\("Coalescing "\[InvisibleSpace]{21, 
          22}\[InvisibleSpace]"; current lineages "\[InvisibleSpace]{10, 21, 
          22}\),
      SequenceForm[ 
      "Coalescing ", {21, 22}, "; current lineages ", {10, 21, 22}],
      Editable->False]], "Print",
  CellLabel->"From In[346]:="],

Cell[BoxData[
    InterpretationBox[
      RowBox[{"\<\"G=\"\>", "\[InvisibleSpace]", 
        RowBox[{"{", 
          
          RowBox[{\(AncestralLineage[
              a, {0, 0.48529096572278896`}, {{a}}, {1}, {}]\), 
            ",", \(AncestralLineage[
              b, {0, 0.2339831643602032`}, {{b}}, {1}, {}]\), 
            ",", \(AncestralLineage[
              c, {0, 0.48529096572278896`}, {{c}}, {1}, {}]\), 
            ",", \(AncestralLineage[
              d, {0, 1.7278195994170844`}, {{d}}, {1}, {}]\), 
            ",", \(AncestralLineage[
              1, {0.2339831643602032`, 
                0.3223607589398818`}, {{b}, {}}, {0.11492662691806055`, 
                1}, {}]\), 
            ",", \(AncestralLineage[
              2, {0.2339831643602032`, 
                0.3223607589398818`}, {{}, {b}}, {0.11492662691806055`, 
                1}, {}]\), 
            ",", \(AncestralLineage[
              3, {0.3223607589398818`, 0.517863837134862`}, {{b}}, {1}, {}]\),
             ",", \(AncestralLineage[
              4, {0.48529096572278896`, 
                0.517863837134862`}, {{a, c}}, {1}, {}]\), 
            ",", \(AncestralLineage[
              5, {0.517863837134862`, 
                1.5246611785364954`}, {{a, b, c}}, {1}, {}]\), 
            ",", \(AncestralLineage[
              6, {1.5246611785364954`, 
                1.5581431051287236`}, {{a, b, c}, {}}, {0.48913575253109154`, 
                1}, {}]\), 
            ",", \(AncestralLineage[
              7, {1.5246611785364954`, 
                1.5581431051287236`}, {{}, {a, b, c}}, {0.48913575253109154`, 
                1}, {}]\), 
            ",", \(AncestralLineage[
              8, {1.5581431051287236`, 
                1.655368377665858`}, {{a, b, c}}, {1}, {}]\), 
            ",", \(AncestralLineage[
              9, {1.655368377665858`, 
                1.7278195994170844`}, {{a, b, c}, {}}, {0.8125105445944757`, 
                1}, {}]\), ",", 
            RowBox[{"AncestralLineage", "[", 
              RowBox[{"10", ",", 
                RowBox[{"{", 
                  RowBox[{"1.655368377665858`", ",", 
                    InterpretationBox["\[Infinity]",
                      DirectedInfinity[ 1]]}], "}"}], 
                ",", \({{}, {a, b, c}}\), ",", \({0.8125105445944757`, 1}\), 
                ",", \({}\)}], "]"}], 
            ",", \(AncestralLineage[
              11, {1.7278195994170844`, 
                2.9123438760363545`}, {{a, b, c, 
                  d}, {d}}, {0.8125105445944757`, 1}, {}]\), 
            ",", \(AncestralLineage[
              12, {2.9123438760363545`, 
                3.051081350478252`}, {{a, b, c, 
                  d}, {d}, {}}, {0.8125105445944757`, 0.8211640322266659`, 
                1}, {}]\), 
            ",", \(AncestralLineage[
              13, {2.9123438760363545`, 
                3.051081350478252`}, {{}, {d}}, {0.8211640322266659`, 
                1}, {}]\), 
            ",", \(AncestralLineage[
              14, {3.051081350478252`, 
                3.9325181869144528`}, {{a, b, c, 
                  d}, {d}}, {0.8125105445944757`, 1}, {}]\), 
            ",", \(AncestralLineage[
              15, {3.9325181869144528`, 
                4.130798875978213`}, {{a, b, c, 
                  d}, {}}, {0.016431884006824982`, 1}, {}]\), 
            ",", \(AncestralLineage[
              16, {3.9325181869144528`, 
                4.130798875978213`}, {{}, {a, b, c, 
                  d}, {d}}, {0.016431884006824982`, 0.8125105445944757`, 
                1}, {}]\), 
            ",", \(AncestralLineage[
              17, {4.130798875978213`, 
                4.8384282701987225`}, {{a, b, c, 
                  d}, {d}}, {0.8125105445944757`, 1}, {}]\), 
            ",", \(AncestralLineage[
              18, {4.8384282701987225`, 
                4.86647775888171`}, {{a, b, c, d}, {}}, {0.7440283682703366`, 
                1}, {}]\), 
            ",", \(AncestralLineage[
              19, {4.8384282701987225`, 
                4.86647775888171`}, {{}, {a, b, c, 
                  d}, {d}}, {0.7440283682703366`, 0.8125105445944757`, 
                1}, {}]\), 
            ",", \(AncestralLineage[
              20, {4.86647775888171`, 
                5.292690316029419`}, {{a, b, c, 
                  d}, {d}}, {0.8125105445944757`, 1}, {}]\), 
            ",", \(AncestralLineage[
              21, {5.292690316029419`, 
                5.346001768468149`}, {{a, b, c, 
                  d}, {d}, {}}, {0.8125105445944757`, 0.9265889024279855`, 
                1}, {}]\), 
            ",", \(AncestralLineage[
              22, {5.292690316029419`, 
                5.346001768468149`}, {{}, {d}}, {0.9265889024279855`, 
                1}, {}]\), ",", 
            RowBox[{"AncestralLineage", "[", 
              RowBox[{"23", ",", 
                RowBox[{"{", 
                  RowBox[{"5.346001768468149`", ",", 
                    InterpretationBox["\[Infinity]",
                      DirectedInfinity[ 1]]}], "}"}], 
                ",", \({{a, b, c, d}, {d}}\), 
                ",", \({0.8125105445944757`, 1}\), ",", \({}\)}], "]"}]}], 
          "}"}]}],
      SequenceForm[ "G=", {
        AncestralLineage[ a, {0, 0.48529096572278896}, {{a}}, {1}, {}], 
        AncestralLineage[ b, {0, 0.23398316436020319}, {{b}}, {1}, {}], 
        AncestralLineage[ c, {0, 0.48529096572278896}, {{c}}, {1}, {}], 
        AncestralLineage[ d, {0, 1.7278195994170844}, {{d}}, {1}, {}], 
        AncestralLineage[ 
        1, {0.23398316436020319, 0.32236075893988181}, {{b}, {}}, {
          0.11492662691806055, 1}, {}], 
        AncestralLineage[ 
        2, {0.23398316436020319, 0.32236075893988181}, {{}, {b}}, {
          0.11492662691806055, 1}, {}], 
        AncestralLineage[ 
        3, {0.32236075893988181, 0.51786383713486195}, {{b}}, {1}, {}], 
        AncestralLineage[ 
        4, {0.48529096572278896, 0.51786383713486195}, {{a, c}}, {1}, {}], 
        AncestralLineage[ 
        5, {0.51786383713486195, 1.5246611785364954}, {{a, b, c}}, {1}, {}], 
        AncestralLineage[ 
        6, {1.5246611785364954, 1.5581431051287236}, {{a, b, c}, {}}, {
          0.48913575253109154, 1}, {}], 
        AncestralLineage[ 
        7, {1.5246611785364954, 1.5581431051287236}, {{}, {a, b, c}}, {
          0.48913575253109154, 1}, {}], 
        AncestralLineage[ 
        8, {1.5581431051287236, 1.6553683776658581}, {{a, b, c}}, {1}, {}], 
        AncestralLineage[ 
        9, {1.6553683776658581, 1.7278195994170844}, {{a, b, c}, {}}, {
          0.81251054459447569, 1}, {}], 
        AncestralLineage[ 10, {1.6553683776658581, 
          DirectedInfinity[ 1]}, {{}, {a, b, c}}, {0.81251054459447569, 
          1}, {}], 
        AncestralLineage[ 
        11, {1.7278195994170844, 2.9123438760363545}, {{a, b, c, d}, {d}}, {
          0.81251054459447569, 1}, {}], 
        AncestralLineage[ 
        12, {2.9123438760363545, 3.0510813504782521}, {{a, b, c, d}, {
          d}, {}}, {0.81251054459447569, 0.8211640322266659, 1}, {}], 
        AncestralLineage[ 
        13, {2.9123438760363545, 3.0510813504782521}, {{}, {d}}, {
          0.8211640322266659, 1}, {}], 
        AncestralLineage[ 
        14, {3.0510813504782521, 3.9325181869144528}, {{a, b, c, d}, {d}}, {
          0.81251054459447569, 1}, {}], 
        AncestralLineage[ 
        15, {3.9325181869144528, 4.130798875978213}, {{a, b, c, d}, {}}, {
          0.016431884006824982, 1}, {}], 
        AncestralLineage[ 
        16, {3.9325181869144528, 4.130798875978213}, {{}, {a, b, c, d}, {
          d}}, {0.016431884006824982, 0.81251054459447569, 1}, {}], 
        AncestralLineage[ 
        17, {4.130798875978213, 4.8384282701987225}, {{a, b, c, d}, {d}}, {
          0.81251054459447569, 1}, {}], 
        AncestralLineage[ 
        18, {4.8384282701987225, 4.8664777588817101}, {{a, b, c, d}, {}}, {
          0.74402836827033658, 1}, {}], 
        AncestralLineage[ 
        19, {4.8384282701987225, 4.8664777588817101}, {{}, {a, b, c, d}, {
          d}}, {0.74402836827033658, 0.81251054459447569, 1}, {}], 
        AncestralLineage[ 
        20, {4.8664777588817101, 5.292690316029419}, {{a, b, c, d}, {d}}, {
          0.81251054459447569, 1}, {}], 
        AncestralLineage[ 
        21, {5.292690316029419, 5.3460017684681489}, {{a, b, c, d}, {
          d}, {}}, {0.81251054459447569, 0.92658890242798553, 1}, {}], 
        AncestralLineage[ 
        22, {5.292690316029419, 5.3460017684681489}, {{}, {d}}, {
          0.92658890242798553, 1}, {}], 
        AncestralLineage[ 23, {5.3460017684681489, 
          DirectedInfinity[ 1]}, {{a, b, c, d}, {d}}, {0.81251054459447569, 
          1}, {}]}],
      Editable->False]], "Print",
  CellLabel->"From In[346]:="],

Cell[BoxData[
    \({0.11386965202761881`, 3, 0.373144912940528`}\)], "Print",
  CellLabel->"From In[346]:="],

Cell[BoxData[
    InterpretationBox[\("Recombining "\[InvisibleSpace]23\[InvisibleSpace]"; \
current lineages "\[InvisibleSpace]{10, 23}\),
      SequenceForm[ "Recombining ", 23, "; current lineages ", {10, 23}],
      Editable->False]], "Print",
  CellLabel->"From In[346]:="],

Cell[BoxData[
    InterpretationBox[
      RowBox[{"\<\"G=\"\>", "\[InvisibleSpace]", 
        RowBox[{"{", 
          
          RowBox[{\(AncestralLineage[
              a, {0, 0.48529096572278896`}, {{a}}, {1}, {}]\), 
            ",", \(AncestralLineage[
              b, {0, 0.2339831643602032`}, {{b}}, {1}, {}]\), 
            ",", \(AncestralLineage[
              c, {0, 0.48529096572278896`}, {{c}}, {1}, {}]\), 
            ",", \(AncestralLineage[
              d, {0, 1.7278195994170844`}, {{d}}, {1}, {}]\), 
            ",", \(AncestralLineage[
              1, {0.2339831643602032`, 
                0.3223607589398818`}, {{b}, {}}, {0.11492662691806055`, 
                1}, {}]\), 
            ",", \(AncestralLineage[
              2, {0.2339831643602032`, 
                0.3223607589398818`}, {{}, {b}}, {0.11492662691806055`, 
                1}, {}]\), 
            ",", \(AncestralLineage[
              3, {0.3223607589398818`, 0.517863837134862`}, {{b}}, {1}, {}]\),
             ",", \(AncestralLineage[
              4, {0.48529096572278896`, 
                0.517863837134862`}, {{a, c}}, {1}, {}]\), 
            ",", \(AncestralLineage[
              5, {0.517863837134862`, 
                1.5246611785364954`}, {{a, b, c}}, {1}, {}]\), 
            ",", \(AncestralLineage[
              6, {1.5246611785364954`, 
                1.5581431051287236`}, {{a, b, c}, {}}, {0.48913575253109154`, 
                1}, {}]\), 
            ",", \(AncestralLineage[
              7, {1.5246611785364954`, 
                1.5581431051287236`}, {{}, {a, b, c}}, {0.48913575253109154`, 
                1}, {}]\), 
            ",", \(AncestralLineage[
              8, {1.5581431051287236`, 
                1.655368377665858`}, {{a, b, c}}, {1}, {}]\), 
            ",", \(AncestralLineage[
              9, {1.655368377665858`, 
                1.7278195994170844`}, {{a, b, c}, {}}, {0.8125105445944757`, 
                1}, {}]\), ",", 
            RowBox[{"AncestralLineage", "[", 
              RowBox[{"10", ",", 
                RowBox[{"{", 
                  RowBox[{"1.655368377665858`", ",", 
                    InterpretationBox["\[Infinity]",
                      DirectedInfinity[ 1]]}], "}"}], 
                ",", \({{}, {a, b, c}}\), ",", \({0.8125105445944757`, 1}\), 
                ",", \({}\)}], "]"}], 
            ",", \(AncestralLineage[
              11, {1.7278195994170844`, 
                2.9123438760363545`}, {{a, b, c, 
                  d}, {d}}, {0.8125105445944757`, 1}, {}]\), 
            ",", \(AncestralLineage[
              12, {2.9123438760363545`, 
                3.051081350478252`}, {{a, b, c, 
                  d}, {d}, {}}, {0.8125105445944757`, 0.8211640322266659`, 
                1}, {}]\), 
            ",", \(AncestralLineage[
              13, {2.9123438760363545`, 
                3.051081350478252`}, {{}, {d}}, {0.8211640322266659`, 
                1}, {}]\), 
            ",", \(AncestralLineage[
              14, {3.051081350478252`, 
                3.9325181869144528`}, {{a, b, c, 
                  d}, {d}}, {0.8125105445944757`, 1}, {}]\), 
            ",", \(AncestralLineage[
              15, {3.9325181869144528`, 
                4.130798875978213`}, {{a, b, c, 
                  d}, {}}, {0.016431884006824982`, 1}, {}]\), 
            ",", \(AncestralLineage[
              16, {3.9325181869144528`, 
                4.130798875978213`}, {{}, {a, b, c, 
                  d}, {d}}, {0.016431884006824982`, 0.8125105445944757`, 
                1}, {}]\), 
            ",", \(AncestralLineage[
              17, {4.130798875978213`, 
                4.8384282701987225`}, {{a, b, c, 
                  d}, {d}}, {0.8125105445944757`, 1}, {}]\), 
            ",", \(AncestralLineage[
              18, {4.8384282701987225`, 
                4.86647775888171`}, {{a, b, c, d}, {}}, {0.7440283682703366`, 
                1}, {}]\), 
            ",", \(AncestralLineage[
              19, {4.8384282701987225`, 
                4.86647775888171`}, {{}, {a, b, c, 
                  d}, {d}}, {0.7440283682703366`, 0.8125105445944757`, 
                1}, {}]\), 
            ",", \(AncestralLineage[
              20, {4.86647775888171`, 
                5.292690316029419`}, {{a, b, c, 
                  d}, {d}}, {0.8125105445944757`, 1}, {}]\), 
            ",", \(AncestralLineage[
              21, {5.292690316029419`, 
                5.346001768468149`}, {{a, b, c, 
                  d}, {d}, {}}, {0.8125105445944757`, 0.9265889024279855`, 
                1}, {}]\), 
            ",", \(AncestralLineage[
              22, {5.292690316029419`, 
                5.346001768468149`}, {{}, {d}}, {0.9265889024279855`, 
                1}, {}]\), 
            ",", \(AncestralLineage[
              23, {5.346001768468149`, 
                5.459871420495768`}, {{a, b, c, 
                  d}, {d}}, {0.8125105445944757`, 1}, {}]\), ",", 
            RowBox[{"AncestralLineage", "[", 
              RowBox[{"24", ",", 
                RowBox[{"{", 
                  RowBox[{"5.459871420495768`", ",", 
                    InterpretationBox["\[Infinity]",
                      DirectedInfinity[ 1]]}], "}"}], 
                ",", \({{a, b, c, d}, {}}\), ",", \({0.373144912940528`, 1}\),
                 ",", \({}\)}], "]"}], ",", 
            RowBox[{"AncestralLineage", "[", 
              RowBox[{"25", ",", 
                RowBox[{"{", 
                  RowBox[{"5.459871420495768`", ",", 
                    InterpretationBox["\[Infinity]",
                      DirectedInfinity[ 1]]}], "}"}], 
                ",", \({{}, {a, b, c, d}, {d}}\), 
                ",", \({0.373144912940528`, 0.8125105445944757`, 1}\), 
                ",", \({}\)}], "]"}]}], "}"}]}],
      SequenceForm[ "G=", {
        AncestralLineage[ a, {0, 0.48529096572278896}, {{a}}, {1}, {}], 
        AncestralLineage[ b, {0, 0.23398316436020319}, {{b}}, {1}, {}], 
        AncestralLineage[ c, {0, 0.48529096572278896}, {{c}}, {1}, {}], 
        AncestralLineage[ d, {0, 1.7278195994170844}, {{d}}, {1}, {}], 
        AncestralLineage[ 
        1, {0.23398316436020319, 0.32236075893988181}, {{b}, {}}, {
          0.11492662691806055, 1}, {}], 
        AncestralLineage[ 
        2, {0.23398316436020319, 0.32236075893988181}, {{}, {b}}, {
          0.11492662691806055, 1}, {}], 
        AncestralLineage[ 
        3, {0.32236075893988181, 0.51786383713486195}, {{b}}, {1}, {}], 
        AncestralLineage[ 
        4, {0.48529096572278896, 0.51786383713486195}, {{a, c}}, {1}, {}], 
        AncestralLineage[ 
        5, {0.51786383713486195, 1.5246611785364954}, {{a, b, c}}, {1}, {}], 
        AncestralLineage[ 
        6, {1.5246611785364954, 1.5581431051287236}, {{a, b, c}, {}}, {
          0.48913575253109154, 1}, {}], 
        AncestralLineage[ 
        7, {1.5246611785364954, 1.5581431051287236}, {{}, {a, b, c}}, {
          0.48913575253109154, 1}, {}], 
        AncestralLineage[ 
        8, {1.5581431051287236, 1.6553683776658581}, {{a, b, c}}, {1}, {}], 
        AncestralLineage[ 
        9, {1.6553683776658581, 1.7278195994170844}, {{a, b, c}, {}}, {
          0.81251054459447569, 1}, {}], 
        AncestralLineage[ 10, {1.6553683776658581, 
          DirectedInfinity[ 1]}, {{}, {a, b, c}}, {0.81251054459447569, 
          1}, {}], 
        AncestralLineage[ 
        11, {1.7278195994170844, 2.9123438760363545}, {{a, b, c, d}, {d}}, {
          0.81251054459447569, 1}, {}], 
        AncestralLineage[ 
        12, {2.9123438760363545, 3.0510813504782521}, {{a, b, c, d}, {
          d}, {}}, {0.81251054459447569, 0.8211640322266659, 1}, {}], 
        AncestralLineage[ 
        13, {2.9123438760363545, 3.0510813504782521}, {{}, {d}}, {
          0.8211640322266659, 1}, {}], 
        AncestralLineage[ 
        14, {3.0510813504782521, 3.9325181869144528}, {{a, b, c, d}, {d}}, {
          0.81251054459447569, 1}, {}], 
        AncestralLineage[ 
        15, {3.9325181869144528, 4.130798875978213}, {{a, b, c, d}, {}}, {
          0.016431884006824982, 1}, {}], 
        AncestralLineage[ 
        16, {3.9325181869144528, 4.130798875978213}, {{}, {a, b, c, d}, {
          d}}, {0.016431884006824982, 0.81251054459447569, 1}, {}], 
        AncestralLineage[ 
        17, {4.130798875978213, 4.8384282701987225}, {{a, b, c, d}, {d}}, {
          0.81251054459447569, 1}, {}], 
        AncestralLineage[ 
        18, {4.8384282701987225, 4.8664777588817101}, {{a, b, c, d}, {}}, {
          0.74402836827033658, 1}, {}], 
        AncestralLineage[ 
        19, {4.8384282701987225, 4.8664777588817101}, {{}, {a, b, c, d}, {
          d}}, {0.74402836827033658, 0.81251054459447569, 1}, {}], 
        AncestralLineage[ 
        20, {4.8664777588817101, 5.292690316029419}, {{a, b, c, d}, {d}}, {
          0.81251054459447569, 1}, {}], 
        AncestralLineage[ 
        21, {5.292690316029419, 5.3460017684681489}, {{a, b, c, d}, {
          d}, {}}, {0.81251054459447569, 0.92658890242798553, 1}, {}], 
        AncestralLineage[ 
        22, {5.292690316029419, 5.3460017684681489}, {{}, {d}}, {
          0.92658890242798553, 1}, {}], 
        AncestralLineage[ 
        23, {5.3460017684681489, 5.4598714204957677}, {{a, b, c, d}, {d}}, {
          0.81251054459447569, 1}, {}], 
        AncestralLineage[ 24, {5.4598714204957677, 
          DirectedInfinity[ 1]}, {{a, b, c, d}, {}}, {0.37314491294052798, 
          1}, {}], 
        AncestralLineage[ 25, {5.4598714204957677, 
          DirectedInfinity[ 1]}, {{}, {a, b, c, d}, {d}}, {
          0.37314491294052798, 0.81251054459447569, 1}, {}]}],
      Editable->False]], "Print",
  CellLabel->"From In[346]:="],

Cell[BoxData[
    \({0.07641325131643487`, 4, 0.3247078812484602`}\)], "Print",
  CellLabel->"From In[346]:="],

Cell[BoxData[
    InterpretationBox[\("Recombining "\[InvisibleSpace]24\[InvisibleSpace]"; \
current lineages "\[InvisibleSpace]{10, 24, 25}\),
      SequenceForm[ "Recombining ", 24, "; current lineages ", {10, 24, 25}],
      Editable->False]], "Print",
  CellLabel->"From In[346]:="],

Cell[BoxData[
    InterpretationBox[
      RowBox[{"\<\"G=\"\>", "\[InvisibleSpace]", 
        RowBox[{"{", 
          
          RowBox[{\(AncestralLineage[
              a, {0, 0.48529096572278896`}, {{a}}, {1}, {}]\), 
            ",", \(AncestralLineage[
              b, {0, 0.2339831643602032`}, {{b}}, {1}, {}]\), 
            ",", \(AncestralLineage[
              c, {0, 0.48529096572278896`}, {{c}}, {1}, {}]\), 
            ",", \(AncestralLineage[
              d, {0, 1.7278195994170844`}, {{d}}, {1}, {}]\), 
            ",", \(AncestralLineage[
              1, {0.2339831643602032`, 
                0.3223607589398818`}, {{b}, {}}, {0.11492662691806055`, 
                1}, {}]\), 
            ",", \(AncestralLineage[
              2, {0.2339831643602032`, 
                0.3223607589398818`}, {{}, {b}}, {0.11492662691806055`, 
                1}, {}]\), 
            ",", \(AncestralLineage[
              3, {0.3223607589398818`, 0.517863837134862`}, {{b}}, {1}, {}]\),
             ",", \(AncestralLineage[
              4, {0.48529096572278896`, 
                0.517863837134862`}, {{a, c}}, {1}, {}]\), 
            ",", \(AncestralLineage[
              5, {0.517863837134862`, 
                1.5246611785364954`}, {{a, b, c}}, {1}, {}]\), 
            ",", \(AncestralLineage[
              6, {1.5246611785364954`, 
                1.5581431051287236`}, {{a, b, c}, {}}, {0.48913575253109154`, 
                1}, {}]\), 
            ",", \(AncestralLineage[
              7, {1.5246611785364954`, 
                1.5581431051287236`}, {{}, {a, b, c}}, {0.48913575253109154`, 
                1}, {}]\), 
            ",", \(AncestralLineage[
              8, {1.5581431051287236`, 
                1.655368377665858`}, {{a, b, c}}, {1}, {}]\), 
            ",", \(AncestralLineage[
              9, {1.655368377665858`, 
                1.7278195994170844`}, {{a, b, c}, {}}, {0.8125105445944757`, 
                1}, {}]\), ",", 
            RowBox[{"AncestralLineage", "[", 
              RowBox[{"10", ",", 
                RowBox[{"{", 
                  RowBox[{"1.655368377665858`", ",", 
                    InterpretationBox["\[Infinity]",
                      DirectedInfinity[ 1]]}], "}"}], 
                ",", \({{}, {a, b, c}}\), ",", \({0.8125105445944757`, 1}\), 
                ",", \({}\)}], "]"}], 
            ",", \(AncestralLineage[
              11, {1.7278195994170844`, 
                2.9123438760363545`}, {{a, b, c, 
                  d}, {d}}, {0.8125105445944757`, 1}, {}]\), 
            ",", \(AncestralLineage[
              12, {2.9123438760363545`, 
                3.051081350478252`}, {{a, b, c, 
                  d}, {d}, {}}, {0.8125105445944757`, 0.8211640322266659`, 
                1}, {}]\), 
            ",", \(AncestralLineage[
              13, {2.9123438760363545`, 
                3.051081350478252`}, {{}, {d}}, {0.8211640322266659`, 
                1}, {}]\), 
            ",", \(AncestralLineage[
              14, {3.051081350478252`, 
                3.9325181869144528`}, {{a, b, c, 
                  d}, {d}}, {0.8125105445944757`, 1}, {}]\), 
            ",", \(AncestralLineage[
              15, {3.9325181869144528`, 
                4.130798875978213`}, {{a, b, c, 
                  d}, {}}, {0.016431884006824982`, 1}, {}]\), 
            ",", \(AncestralLineage[
              16, {3.9325181869144528`, 
                4.130798875978213`}, {{}, {a, b, c, 
                  d}, {d}}, {0.016431884006824982`, 0.8125105445944757`, 
                1}, {}]\), 
            ",", \(AncestralLineage[
              17, {4.130798875978213`, 
                4.8384282701987225`}, {{a, b, c, 
                  d}, {d}}, {0.8125105445944757`, 1}, {}]\), 
            ",", \(AncestralLineage[
              18, {4.8384282701987225`, 
                4.86647775888171`}, {{a, b, c, d}, {}}, {0.7440283682703366`, 
                1}, {}]\), 
            ",", \(AncestralLineage[
              19, {4.8384282701987225`, 
                4.86647775888171`}, {{}, {a, b, c, 
                  d}, {d}}, {0.7440283682703366`, 0.8125105445944757`, 
                1}, {}]\), 
            ",", \(AncestralLineage[
              20, {4.86647775888171`, 
                5.292690316029419`}, {{a, b, c, 
                  d}, {d}}, {0.8125105445944757`, 1}, {}]\), 
            ",", \(AncestralLineage[
              21, {5.292690316029419`, 
                5.346001768468149`}, {{a, b, c, 
                  d}, {d}, {}}, {0.8125105445944757`, 0.9265889024279855`, 
                1}, {}]\), 
            ",", \(AncestralLineage[
              22, {5.292690316029419`, 
                5.346001768468149`}, {{}, {d}}, {0.9265889024279855`, 
                1}, {}]\), 
            ",", \(AncestralLineage[
              23, {5.346001768468149`, 
                5.459871420495768`}, {{a, b, c, 
                  d}, {d}}, {0.8125105445944757`, 1}, {}]\), 
            ",", \(AncestralLineage[
              24, {5.459871420495768`, 
                5.5362846718122025`}, {{a, b, c, 
                  d}, {}}, {0.373144912940528`, 1}, {}]\), ",", 
            RowBox[{"AncestralLineage", "[", 
              RowBox[{"25", ",", 
                RowBox[{"{", 
                  RowBox[{"5.459871420495768`", ",", 
                    InterpretationBox["\[Infinity]",
                      DirectedInfinity[ 1]]}], "}"}], 
                ",", \({{}, {a, b, c, d}, {d}}\), 
                ",", \({0.373144912940528`, 0.8125105445944757`, 1}\), 
                ",", \({}\)}], "]"}], ",", 
            RowBox[{"AncestralLineage", "[", 
              RowBox[{"26", ",", 
                RowBox[{"{", 
                  RowBox[{"5.5362846718122025`", ",", 
                    InterpretationBox["\[Infinity]",
                      DirectedInfinity[ 1]]}], "}"}], 
                ",", \({{a, b, c, d}, {}}\), 
                ",", \({0.3247078812484602`, 1}\), ",", \({}\)}], "]"}], ",", 
            
            RowBox[{"AncestralLineage", "[", 
              RowBox[{"27", ",", 
                RowBox[{"{", 
                  RowBox[{"5.5362846718122025`", ",", 
                    InterpretationBox["\[Infinity]",
                      DirectedInfinity[ 1]]}], "}"}], 
                ",", \({{}, {a, b, c, d}, {}}\), 
                ",", \({0.3247078812484602`, 0.373144912940528`, 1}\), 
                ",", \({}\)}], "]"}]}], "}"}]}],
      SequenceForm[ "G=", {
        AncestralLineage[ a, {0, 0.48529096572278896}, {{a}}, {1}, {}], 
        AncestralLineage[ b, {0, 0.23398316436020319}, {{b}}, {1}, {}], 
        AncestralLineage[ c, {0, 0.48529096572278896}, {{c}}, {1}, {}], 
        AncestralLineage[ d, {0, 1.7278195994170844}, {{d}}, {1}, {}], 
        AncestralLineage[ 
        1, {0.23398316436020319, 0.32236075893988181}, {{b}, {}}, {
          0.11492662691806055, 1}, {}], 
        AncestralLineage[ 
        2, {0.23398316436020319, 0.32236075893988181}, {{}, {b}}, {
          0.11492662691806055, 1}, {}], 
        AncestralLineage[ 
        3, {0.32236075893988181, 0.51786383713486195}, {{b}}, {1}, {}], 
        AncestralLineage[ 
        4, {0.48529096572278896, 0.51786383713486195}, {{a, c}}, {1}, {}], 
        AncestralLineage[ 
        5, {0.51786383713486195, 1.5246611785364954}, {{a, b, c}}, {1}, {}], 
        AncestralLineage[ 
        6, {1.5246611785364954, 1.5581431051287236}, {{a, b, c}, {}}, {
          0.48913575253109154, 1}, {}], 
        AncestralLineage[ 
        7, {1.5246611785364954, 1.5581431051287236}, {{}, {a, b, c}}, {
          0.48913575253109154, 1}, {}], 
        AncestralLineage[ 
        8, {1.5581431051287236, 1.6553683776658581}, {{a, b, c}}, {1}, {}], 
        AncestralLineage[ 
        9, {1.6553683776658581, 1.7278195994170844}, {{a, b, c}, {}}, {
          0.81251054459447569, 1}, {}], 
        AncestralLineage[ 10, {1.6553683776658581, 
          DirectedInfinity[ 1]}, {{}, {a, b, c}}, {0.81251054459447569, 
          1}, {}], 
        AncestralLineage[ 
        11, {1.7278195994170844, 2.9123438760363545}, {{a, b, c, d}, {d}}, {
          0.81251054459447569, 1}, {}], 
        AncestralLineage[ 
        12, {2.9123438760363545, 3.0510813504782521}, {{a, b, c, d}, {
          d}, {}}, {0.81251054459447569, 0.8211640322266659, 1}, {}], 
        AncestralLineage[ 
        13, {2.9123438760363545, 3.0510813504782521}, {{}, {d}}, {
          0.8211640322266659, 1}, {}], 
        AncestralLineage[ 
        14, {3.0510813504782521, 3.9325181869144528}, {{a, b, c, d}, {d}}, {
          0.81251054459447569, 1}, {}], 
        AncestralLineage[ 
        15, {3.9325181869144528, 4.130798875978213}, {{a, b, c, d}, {}}, {
          0.016431884006824982, 1}, {}], 
        AncestralLineage[ 
        16, {3.9325181869144528, 4.130798875978213}, {{}, {a, b, c, d}, {
          d}}, {0.016431884006824982, 0.81251054459447569, 1}, {}], 
        AncestralLineage[ 
        17, {4.130798875978213, 4.8384282701987225}, {{a, b, c, d}, {d}}, {
          0.81251054459447569, 1}, {}], 
        AncestralLineage[ 
        18, {4.8384282701987225, 4.8664777588817101}, {{a, b, c, d}, {}}, {
          0.74402836827033658, 1}, {}], 
        AncestralLineage[ 
        19, {4.8384282701987225, 4.8664777588817101}, {{}, {a, b, c, d}, {
          d}}, {0.74402836827033658, 0.81251054459447569, 1}, {}], 
        AncestralLineage[ 
        20, {4.8664777588817101, 5.292690316029419}, {{a, b, c, d}, {d}}, {
          0.81251054459447569, 1}, {}], 
        AncestralLineage[ 
        21, {5.292690316029419, 5.3460017684681489}, {{a, b, c, d}, {
          d}, {}}, {0.81251054459447569, 0.92658890242798553, 1}, {}], 
        AncestralLineage[ 
        22, {5.292690316029419, 5.3460017684681489}, {{}, {d}}, {
          0.92658890242798553, 1}, {}], 
        AncestralLineage[ 
        23, {5.3460017684681489, 5.4598714204957677}, {{a, b, c, d}, {d}}, {
          0.81251054459447569, 1}, {}], 
        AncestralLineage[ 
        24, {5.4598714204957677, 5.5362846718122025}, {{a, b, c, d}, {}}, {
          0.37314491294052798, 1}, {}], 
        AncestralLineage[ 25, {5.4598714204957677, 
          DirectedInfinity[ 1]}, {{}, {a, b, c, d}, {d}}, {
          0.37314491294052798, 0.81251054459447569, 1}, {}], 
        AncestralLineage[ 26, {5.5362846718122025, 
          DirectedInfinity[ 1]}, {{a, b, c, d}, {}}, {0.32470788124846017, 
          1}, {}], 
        AncestralLineage[ 27, {5.5362846718122025, 
          DirectedInfinity[ 1]}, {{}, {a, b, c, d}, {}}, {0.32470788124846017,
           0.37314491294052798, 1}, {}]}],
      Editable->False]], "Print",
  CellLabel->"From In[346]:="],

Cell[BoxData[
    \({0.2676151313871699`, 5, 0.98211937306245`}\)], "Print",
  CellLabel->"From In[346]:="],

Cell[BoxData[
    InterpretationBox[\("Recombining "\[InvisibleSpace]10\[InvisibleSpace]"; \
current lineages "\[InvisibleSpace]{10, 25, 26, 27}\),
      SequenceForm[ 
      "Recombining ", 10, "; current lineages ", {10, 25, 26, 27}],
      Editable->False]], "Print",
  CellLabel->"From In[346]:="],

Cell[BoxData[
    InterpretationBox[
      RowBox[{"\<\"G=\"\>", "\[InvisibleSpace]", 
        RowBox[{"{", 
          
          RowBox[{\(AncestralLineage[
              a, {0, 0.48529096572278896`}, {{a}}, {1}, {}]\), 
            ",", \(AncestralLineage[
              b, {0, 0.2339831643602032`}, {{b}}, {1}, {}]\), 
            ",", \(AncestralLineage[
              c, {0, 0.48529096572278896`}, {{c}}, {1}, {}]\), 
            ",", \(AncestralLineage[
              d, {0, 1.7278195994170844`}, {{d}}, {1}, {}]\), 
            ",", \(AncestralLineage[
              1, {0.2339831643602032`, 
                0.3223607589398818`}, {{b}, {}}, {0.11492662691806055`, 
                1}, {}]\), 
            ",", \(AncestralLineage[
              2, {0.2339831643602032`, 
                0.3223607589398818`}, {{}, {b}}, {0.11492662691806055`, 
                1}, {}]\), 
            ",", \(AncestralLineage[
              3, {0.3223607589398818`, 0.517863837134862`}, {{b}}, {1}, {}]\),
             ",", \(AncestralLineage[
              4, {0.48529096572278896`, 
                0.517863837134862`}, {{a, c}}, {1}, {}]\), 
            ",", \(AncestralLineage[
              5, {0.517863837134862`, 
                1.5246611785364954`}, {{a, b, c}}, {1}, {}]\), 
            ",", \(AncestralLineage[
              6, {1.5246611785364954`, 
                1.5581431051287236`}, {{a, b, c}, {}}, {0.48913575253109154`, 
                1}, {}]\), 
            ",", \(AncestralLineage[
              7, {1.5246611785364954`, 
                1.5581431051287236`}, {{}, {a, b, c}}, {0.48913575253109154`, 
                1}, {}]\), 
            ",", \(AncestralLineage[
              8, {1.5581431051287236`, 
                1.655368377665858`}, {{a, b, c}}, {1}, {}]\), 
            ",", \(AncestralLineage[
              9, {1.655368377665858`, 
                1.7278195994170844`}, {{a, b, c}, {}}, {0.8125105445944757`, 
                1}, {}]\), 
            ",", \(AncestralLineage[
              10, {1.655368377665858`, 
                5.803899803199372`}, {{}, {a, b, c}}, {0.8125105445944757`, 
                1}, {}]\), 
            ",", \(AncestralLineage[
              11, {1.7278195994170844`, 
                2.9123438760363545`}, {{a, b, c, 
                  d}, {d}}, {0.8125105445944757`, 1}, {}]\), 
            ",", \(AncestralLineage[
              12, {2.9123438760363545`, 
                3.051081350478252`}, {{a, b, c, 
                  d}, {d}, {}}, {0.8125105445944757`, 0.8211640322266659`, 
                1}, {}]\), 
            ",", \(AncestralLineage[
              13, {2.9123438760363545`, 
                3.051081350478252`}, {{}, {d}}, {0.8211640322266659`, 
                1}, {}]\), 
            ",", \(AncestralLineage[
              14, {3.051081350478252`, 
                3.9325181869144528`}, {{a, b, c, 
                  d}, {d}}, {0.8125105445944757`, 1}, {}]\), 
            ",", \(AncestralLineage[
              15, {3.9325181869144528`, 
                4.130798875978213`}, {{a, b, c, 
                  d}, {}}, {0.016431884006824982`, 1}, {}]\), 
            ",", \(AncestralLineage[
              16, {3.9325181869144528`, 
                4.130798875978213`}, {{}, {a, b, c, 
                  d}, {d}}, {0.016431884006824982`, 0.8125105445944757`, 
                1}, {}]\), 
            ",", \(AncestralLineage[
              17, {4.130798875978213`, 
                4.8384282701987225`}, {{a, b, c, 
                  d}, {d}}, {0.8125105445944757`, 1}, {}]\), 
            ",", \(AncestralLineage[
              18, {4.8384282701987225`, 
                4.86647775888171`}, {{a, b, c, d}, {}}, {0.7440283682703366`, 
                1}, {}]\), 
            ",", \(AncestralLineage[
              19, {4.8384282701987225`, 
                4.86647775888171`}, {{}, {a, b, c, 
                  d}, {d}}, {0.7440283682703366`, 0.8125105445944757`, 
                1}, {}]\), 
            ",", \(AncestralLineage[
              20, {4.86647775888171`, 
                5.292690316029419`}, {{a, b, c, 
                  d}, {d}}, {0.8125105445944757`, 1}, {}]\), 
            ",", \(AncestralLineage[
              21, {5.292690316029419`, 
                5.346001768468149`}, {{a, b, c, 
                  d}, {d}, {}}, {0.8125105445944757`, 0.9265889024279855`, 
                1}, {}]\), 
            ",", \(AncestralLineage[
              22, {5.292690316029419`, 
                5.346001768468149`}, {{}, {d}}, {0.9265889024279855`, 
                1}, {}]\), 
            ",", \(AncestralLineage[
              23, {5.346001768468149`, 
                5.459871420495768`}, {{a, b, c, 
                  d}, {d}}, {0.8125105445944757`, 1}, {}]\), 
            ",", \(AncestralLineage[
              24, {5.459871420495768`, 
                5.5362846718122025`}, {{a, b, c, 
                  d}, {}}, {0.373144912940528`, 1}, {}]\), ",", 
            RowBox[{"AncestralLineage", "[", 
              RowBox[{"25", ",", 
                RowBox[{"{", 
                  RowBox[{"5.459871420495768`", ",", 
                    InterpretationBox["\[Infinity]",
                      DirectedInfinity[ 1]]}], "}"}], 
                ",", \({{}, {a, b, c, d}, {d}}\), 
                ",", \({0.373144912940528`, 0.8125105445944757`, 1}\), 
                ",", \({}\)}], "]"}], ",", 
            RowBox[{"AncestralLineage", "[", 
              RowBox[{"26", ",", 
                RowBox[{"{", 
                  RowBox[{"5.5362846718122025`", ",", 
                    InterpretationBox["\[Infinity]",
                      DirectedInfinity[ 1]]}], "}"}], 
                ",", \({{a, b, c, d}, {}}\), 
                ",", \({0.3247078812484602`, 1}\), ",", \({}\)}], "]"}], ",", 
            
            RowBox[{"AncestralLineage", "[", 
              RowBox[{"27", ",", 
                RowBox[{"{", 
                  RowBox[{"5.5362846718122025`", ",", 
                    InterpretationBox["\[Infinity]",
                      DirectedInfinity[ 1]]}], "}"}], 
                ",", \({{}, {a, b, c, d}, {}}\), 
                ",", \({0.3247078812484602`, 0.373144912940528`, 1}\), 
                ",", \({}\)}], "]"}], ",", 
            RowBox[{"AncestralLineage", "[", 
              RowBox[{"28", ",", 
                RowBox[{"{", 
                  RowBox[{"5.803899803199372`", ",", 
                    InterpretationBox["\[Infinity]",
                      DirectedInfinity[ 1]]}], "}"}], 
                ",", \({{}, {a, b, c}, {}}\), 
                ",", \({0.8125105445944757`, 0.98211937306245`, 1}\), 
                ",", \({}\)}], "]"}], ",", 
            RowBox[{"AncestralLineage", "[", 
              RowBox[{"29", ",", 
                RowBox[{"{", 
                  RowBox[{"5.803899803199372`", ",", 
                    InterpretationBox["\[Infinity]",
                      DirectedInfinity[ 1]]}], "}"}], 
                ",", \({{}, {a, b, c}}\), ",", \({0.98211937306245`, 1}\), 
                ",", \({}\)}], "]"}]}], "}"}]}],
      SequenceForm[ "G=", {
        AncestralLineage[ a, {0, 0.48529096572278896}, {{a}}, {1}, {}], 
        AncestralLineage[ b, {0, 0.23398316436020319}, {{b}}, {1}, {}], 
        AncestralLineage[ c, {0, 0.48529096572278896}, {{c}}, {1}, {}], 
        AncestralLineage[ d, {0, 1.7278195994170844}, {{d}}, {1}, {}], 
        AncestralLineage[ 
        1, {0.23398316436020319, 0.32236075893988181}, {{b}, {}}, {
          0.11492662691806055, 1}, {}], 
        AncestralLineage[ 
        2, {0.23398316436020319, 0.32236075893988181}, {{}, {b}}, {
          0.11492662691806055, 1}, {}], 
        AncestralLineage[ 
        3, {0.32236075893988181, 0.51786383713486195}, {{b}}, {1}, {}], 
        AncestralLineage[ 
        4, {0.48529096572278896, 0.51786383713486195}, {{a, c}}, {1}, {}], 
        AncestralLineage[ 
        5, {0.51786383713486195, 1.5246611785364954}, {{a, b, c}}, {1}, {}], 
        AncestralLineage[ 
        6, {1.5246611785364954, 1.5581431051287236}, {{a, b, c}, {}}, {
          0.48913575253109154, 1}, {}], 
        AncestralLineage[ 
        7, {1.5246611785364954, 1.5581431051287236}, {{}, {a, b, c}}, {
          0.48913575253109154, 1}, {}], 
        AncestralLineage[ 
        8, {1.5581431051287236, 1.6553683776658581}, {{a, b, c}}, {1}, {}], 
        AncestralLineage[ 
        9, {1.6553683776658581, 1.7278195994170844}, {{a, b, c}, {}}, {
          0.81251054459447569, 1}, {}], 
        AncestralLineage[ 
        10, {1.6553683776658581, 5.8038998031993723}, {{}, {a, b, c}}, {
          0.81251054459447569, 1}, {}], 
        AncestralLineage[ 
        11, {1.7278195994170844, 2.9123438760363545}, {{a, b, c, d}, {d}}, {
          0.81251054459447569, 1}, {}], 
        AncestralLineage[ 
        12, {2.9123438760363545, 3.0510813504782521}, {{a, b, c, d}, {
          d}, {}}, {0.81251054459447569, 0.8211640322266659, 1}, {}], 
        AncestralLineage[ 
        13, {2.9123438760363545, 3.0510813504782521}, {{}, {d}}, {
          0.8211640322266659, 1}, {}], 
        AncestralLineage[ 
        14, {3.0510813504782521, 3.9325181869144528}, {{a, b, c, d}, {d}}, {
          0.81251054459447569, 1}, {}], 
        AncestralLineage[ 
        15, {3.9325181869144528, 4.130798875978213}, {{a, b, c, d}, {}}, {
          0.016431884006824982, 1}, {}], 
        AncestralLineage[ 
        16, {3.9325181869144528, 4.130798875978213}, {{}, {a, b, c, d}, {
          d}}, {0.016431884006824982, 0.81251054459447569, 1}, {}], 
        AncestralLineage[ 
        17, {4.130798875978213, 4.8384282701987225}, {{a, b, c, d}, {d}}, {
          0.81251054459447569, 1}, {}], 
        AncestralLineage[ 
        18, {4.8384282701987225, 4.8664777588817101}, {{a, b, c, d}, {}}, {
          0.74402836827033658, 1}, {}], 
        AncestralLineage[ 
        19, {4.8384282701987225, 4.8664777588817101}, {{}, {a, b, c, d}, {
          d}}, {0.74402836827033658, 0.81251054459447569, 1}, {}], 
        AncestralLineage[ 
        20, {4.8664777588817101, 5.292690316029419}, {{a, b, c, d}, {d}}, {
          0.81251054459447569, 1}, {}], 
        AncestralLineage[ 
        21, {5.292690316029419, 5.3460017684681489}, {{a, b, c, d}, {
          d}, {}}, {0.81251054459447569, 0.92658890242798553, 1}, {}], 
        AncestralLineage[ 
        22, {5.292690316029419, 5.3460017684681489}, {{}, {d}}, {
          0.92658890242798553, 1}, {}], 
        AncestralLineage[ 
        23, {5.3460017684681489, 5.4598714204957677}, {{a, b, c, d}, {d}}, {
          0.81251054459447569, 1}, {}], 
        AncestralLineage[ 
        24, {5.4598714204957677, 5.5362846718122025}, {{a, b, c, d}, {}}, {
          0.37314491294052798, 1}, {}], 
        AncestralLineage[ 25, {5.4598714204957677, 
          DirectedInfinity[ 1]}, {{}, {a, b, c, d}, {d}}, {
          0.37314491294052798, 0.81251054459447569, 1}, {}], 
        AncestralLineage[ 26, {5.5362846718122025, 
          DirectedInfinity[ 1]}, {{a, b, c, d}, {}}, {0.32470788124846017, 
          1}, {}], 
        AncestralLineage[ 27, {5.5362846718122025, 
          DirectedInfinity[ 1]}, {{}, {a, b, c, d}, {}}, {0.32470788124846017,
           0.37314491294052798, 1}, {}], 
        AncestralLineage[ 28, {5.8038998031993723, 
          DirectedInfinity[ 1]}, {{}, {a, b, c}, {}}, {0.81251054459447569, 
          0.98211937306245001, 1}, {}], 
        AncestralLineage[ 29, {5.8038998031993723, 
          DirectedInfinity[ 1]}, {{}, {a, b, c}}, {0.98211937306245001, 
          1}, {}]}],
      Editable->False]], "Print",
  CellLabel->"From In[346]:="],

Cell[BoxData[
    \({0.13795175703603946`, 6, 0.19502785445852`}\)], "Print",
  CellLabel->"From In[346]:="],

Cell[BoxData[
    InterpretationBox[\("Recombining "\[InvisibleSpace]25\[InvisibleSpace]"; \
current lineages "\[InvisibleSpace]{25, 26, 27, 28, 29}\),
      SequenceForm[ 
      "Recombining ", 25, "; current lineages ", {25, 26, 27, 28, 29}],
      Editable->False]], "Print",
  CellLabel->"From In[346]:="],

Cell[BoxData[
    InterpretationBox[
      RowBox[{"\<\"G=\"\>", "\[InvisibleSpace]", 
        RowBox[{"{", 
          
          RowBox[{\(AncestralLineage[
              a, {0, 0.48529096572278896`}, {{a}}, {1}, {}]\), 
            ",", \(AncestralLineage[
              b, {0, 0.2339831643602032`}, {{b}}, {1}, {}]\), 
            ",", \(AncestralLineage[
              c, {0, 0.48529096572278896`}, {{c}}, {1}, {}]\), 
            ",", \(AncestralLineage[
              d, {0, 1.7278195994170844`}, {{d}}, {1}, {}]\), 
            ",", \(AncestralLineage[
              1, {0.2339831643602032`, 
                0.3223607589398818`}, {{b}, {}}, {0.11492662691806055`, 
                1}, {}]\), 
            ",", \(AncestralLineage[
              2, {0.2339831643602032`, 
                0.3223607589398818`}, {{}, {b}}, {0.11492662691806055`, 
                1}, {}]\), 
            ",", \(AncestralLineage[
              3, {0.3223607589398818`, 0.517863837134862`}, {{b}}, {1}, {}]\),
             ",", \(AncestralLineage[
              4, {0.48529096572278896`, 
                0.517863837134862`}, {{a, c}}, {1}, {}]\), 
            ",", \(AncestralLineage[
              5, {0.517863837134862`, 
                1.5246611785364954`}, {{a, b, c}}, {1}, {}]\), 
            ",", \(AncestralLineage[
              6, {1.5246611785364954`, 
                1.5581431051287236`}, {{a, b, c}, {}}, {0.48913575253109154`, 
                1}, {}]\), 
            ",", \(AncestralLineage[
              7, {1.5246611785364954`, 
                1.5581431051287236`}, {{}, {a, b, c}}, {0.48913575253109154`, 
                1}, {}]\), 
            ",", \(AncestralLineage[
              8, {1.5581431051287236`, 
                1.655368377665858`}, {{a, b, c}}, {1}, {}]\), 
            ",", \(AncestralLineage[
              9, {1.655368377665858`, 
                1.7278195994170844`}, {{a, b, c}, {}}, {0.8125105445944757`, 
                1}, {}]\), 
            ",", \(AncestralLineage[
              10, {1.655368377665858`, 
                5.803899803199372`}, {{}, {a, b, c}}, {0.8125105445944757`, 
                1}, {}]\), 
            ",", \(AncestralLineage[
              11, {1.7278195994170844`, 
                2.9123438760363545`}, {{a, b, c, 
                  d}, {d}}, {0.8125105445944757`, 1}, {}]\), 
            ",", \(AncestralLineage[
              12, {2.9123438760363545`, 
                3.051081350478252`}, {{a, b, c, 
                  d}, {d}, {}}, {0.8125105445944757`, 0.8211640322266659`, 
                1}, {}]\), 
            ",", \(AncestralLineage[
              13, {2.9123438760363545`, 
                3.051081350478252`}, {{}, {d}}, {0.8211640322266659`, 
                1}, {}]\), 
            ",", \(AncestralLineage[
              14, {3.051081350478252`, 
                3.9325181869144528`}, {{a, b, c, 
                  d}, {d}}, {0.8125105445944757`, 1}, {}]\), 
            ",", \(AncestralLineage[
              15, {3.9325181869144528`, 
                4.130798875978213`}, {{a, b, c, 
                  d}, {}}, {0.016431884006824982`, 1}, {}]\), 
            ",", \(AncestralLineage[
              16, {3.9325181869144528`, 
                4.130798875978213`}, {{}, {a, b, c, 
                  d}, {d}}, {0.016431884006824982`, 0.8125105445944757`, 
                1}, {}]\), 
            ",", \(AncestralLineage[
              17, {4.130798875978213`, 
                4.8384282701987225`}, {{a, b, c, 
                  d}, {d}}, {0.8125105445944757`, 1}, {}]\), 
            ",", \(AncestralLineage[
              18, {4.8384282701987225`, 
                4.86647775888171`}, {{a, b, c, d}, {}}, {0.7440283682703366`, 
                1}, {}]\), 
            ",", \(AncestralLineage[
              19, {4.8384282701987225`, 
                4.86647775888171`}, {{}, {a, b, c, 
                  d}, {d}}, {0.7440283682703366`, 0.8125105445944757`, 
                1}, {}]\), 
            ",", \(AncestralLineage[
              20, {4.86647775888171`, 
                5.292690316029419`}, {{a, b, c, 
                  d}, {d}}, {0.8125105445944757`, 1}, {}]\), 
            ",", \(AncestralLineage[
              21, {5.292690316029419`, 
                5.346001768468149`}, {{a, b, c, 
                  d}, {d}, {}}, {0.8125105445944757`, 0.9265889024279855`, 
                1}, {}]\), 
            ",", \(AncestralLineage[
              22, {5.292690316029419`, 
                5.346001768468149`}, {{}, {d}}, {0.9265889024279855`, 
                1}, {}]\), 
            ",", \(AncestralLineage[
              23, {5.346001768468149`, 
                5.459871420495768`}, {{a, b, c, 
                  d}, {d}}, {0.8125105445944757`, 1}, {}]\), 
            ",", \(AncestralLineage[
              24, {5.459871420495768`, 
                5.5362846718122025`}, {{a, b, c, 
                  d}, {}}, {0.373144912940528`, 1}, {}]\), ",", 
            RowBox[{"AncestralLineage", "[", 
              RowBox[{"25", ",", 
                RowBox[{"{", 
                  RowBox[{"5.459871420495768`", ",", 
                    InterpretationBox["\[Infinity]",
                      DirectedInfinity[ 1]]}], "}"}], 
                ",", \({{}, {a, b, c, d}, {d}}\), 
                ",", \({0.373144912940528`, 0.8125105445944757`, 1}\), 
                ",", \({}\)}], "]"}], ",", 
            RowBox[{"AncestralLineage", "[", 
              RowBox[{"26", ",", 
                RowBox[{"{", 
                  RowBox[{"5.5362846718122025`", ",", 
                    InterpretationBox["\[Infinity]",
                      DirectedInfinity[ 1]]}], "}"}], 
                ",", \({{a, b, c, d}, {}}\), 
                ",", \({0.3247078812484602`, 1}\), ",", \({}\)}], "]"}], ",", 
            
            RowBox[{"AncestralLineage", "[", 
              RowBox[{"27", ",", 
                RowBox[{"{", 
                  RowBox[{"5.5362846718122025`", ",", 
                    InterpretationBox["\[Infinity]",
                      DirectedInfinity[ 1]]}], "}"}], 
                ",", \({{}, {a, b, c, d}, {}}\), 
                ",", \({0.3247078812484602`, 0.373144912940528`, 1}\), 
                ",", \({}\)}], "]"}], ",", 
            RowBox[{"AncestralLineage", "[", 
              RowBox[{"28", ",", 
                RowBox[{"{", 
                  RowBox[{"5.803899803199372`", ",", 
                    InterpretationBox["\[Infinity]",
                      DirectedInfinity[ 1]]}], "}"}], 
                ",", \({{}, {a, b, c}, {}}\), 
                ",", \({0.8125105445944757`, 0.98211937306245`, 1}\), 
                ",", \({}\)}], "]"}], ",", 
            RowBox[{"AncestralLineage", "[", 
              RowBox[{"29", ",", 
                RowBox[{"{", 
                  RowBox[{"5.803899803199372`", ",", 
                    InterpretationBox["\[Infinity]",
                      DirectedInfinity[ 1]]}], "}"}], 
                ",", \({{}, {a, b, c}}\), ",", \({0.98211937306245`, 1}\), 
                ",", \({}\)}], "]"}]}], "}"}]}],
      SequenceForm[ "G=", {
        AncestralLineage[ a, {0, 0.48529096572278896}, {{a}}, {1}, {}], 
        AncestralLineage[ b, {0, 0.23398316436020319}, {{b}}, {1}, {}], 
        AncestralLineage[ c, {0, 0.48529096572278896}, {{c}}, {1}, {}], 
        AncestralLineage[ d, {0, 1.7278195994170844}, {{d}}, {1}, {}], 
        AncestralLineage[ 
        1, {0.23398316436020319, 0.32236075893988181}, {{b}, {}}, {
          0.11492662691806055, 1}, {}], 
        AncestralLineage[ 
        2, {0.23398316436020319, 0.32236075893988181}, {{}, {b}}, {
          0.11492662691806055, 1}, {}], 
        AncestralLineage[ 
        3, {0.32236075893988181, 0.51786383713486195}, {{b}}, {1}, {}], 
        AncestralLineage[ 
        4, {0.48529096572278896, 0.51786383713486195}, {{a, c}}, {1}, {}], 
        AncestralLineage[ 
        5, {0.51786383713486195, 1.5246611785364954}, {{a, b, c}}, {1}, {}], 
        AncestralLineage[ 
        6, {1.5246611785364954, 1.5581431051287236}, {{a, b, c}, {}}, {
          0.48913575253109154, 1}, {}], 
        AncestralLineage[ 
        7, {1.5246611785364954, 1.5581431051287236}, {{}, {a, b, c}}, {
          0.48913575253109154, 1}, {}], 
        AncestralLineage[ 
        8, {1.5581431051287236, 1.6553683776658581}, {{a, b, c}}, {1}, {}], 
        AncestralLineage[ 
        9, {1.6553683776658581, 1.7278195994170844}, {{a, b, c}, {}}, {
          0.81251054459447569, 1}, {}], 
        AncestralLineage[ 
        10, {1.6553683776658581, 5.8038998031993723}, {{}, {a, b, c}}, {
          0.81251054459447569, 1}, {}], 
        AncestralLineage[ 
        11, {1.7278195994170844, 2.9123438760363545}, {{a, b, c, d}, {d}}, {
          0.81251054459447569, 1}, {}], 
        AncestralLineage[ 
        12, {2.9123438760363545, 3.0510813504782521}, {{a, b, c, d}, {
          d}, {}}, {0.81251054459447569, 0.8211640322266659, 1}, {}], 
        AncestralLineage[ 
        13, {2.9123438760363545, 3.0510813504782521}, {{}, {d}}, {
          0.8211640322266659, 1}, {}], 
        AncestralLineage[ 
        14, {3.0510813504782521, 3.9325181869144528}, {{a, b, c, d}, {d}}, {
          0.81251054459447569, 1}, {}], 
        AncestralLineage[ 
        15, {3.9325181869144528, 4.130798875978213}, {{a, b, c, d}, {}}, {
          0.016431884006824982, 1}, {}], 
        AncestralLineage[ 
        16, {3.9325181869144528, 4.130798875978213}, {{}, {a, b, c, d}, {
          d}}, {0.016431884006824982, 0.81251054459447569, 1}, {}], 
        AncestralLineage[ 
        17, {4.130798875978213, 4.8384282701987225}, {{a, b, c, d}, {d}}, {
          0.81251054459447569, 1}, {}], 
        AncestralLineage[ 
        18, {4.8384282701987225, 4.8664777588817101}, {{a, b, c, d}, {}}, {
          0.74402836827033658, 1}, {}], 
        AncestralLineage[ 
        19, {4.8384282701987225, 4.8664777588817101}, {{}, {a, b, c, d}, {
          d}}, {0.74402836827033658, 0.81251054459447569, 1}, {}], 
        AncestralLineage[ 
        20, {4.8664777588817101, 5.292690316029419}, {{a, b, c, d}, {d}}, {
          0.81251054459447569, 1}, {}], 
        AncestralLineage[ 
        21, {5.292690316029419, 5.3460017684681489}, {{a, b, c, d}, {
          d}, {}}, {0.81251054459447569, 0.92658890242798553, 1}, {}], 
        AncestralLineage[ 
        22, {5.292690316029419, 5.3460017684681489}, {{}, {d}}, {
          0.92658890242798553, 1}, {}], 
        AncestralLineage[ 
        23, {5.3460017684681489, 5.4598714204957677}, {{a, b, c, d}, {d}}, {
          0.81251054459447569, 1}, {}], 
        AncestralLineage[ 
        24, {5.4598714204957677, 5.5362846718122025}, {{a, b, c, d}, {}}, {
          0.37314491294052798, 1}, {}], 
        AncestralLineage[ 25, {5.4598714204957677, 
          DirectedInfinity[ 1]}, {{}, {a, b, c, d}, {d}}, {
          0.37314491294052798, 0.81251054459447569, 1}, {}], 
        AncestralLineage[ 26, {5.5362846718122025, 
          DirectedInfinity[ 1]}, {{a, b, c, d}, {}}, {0.32470788124846017, 
          1}, {}], 
        AncestralLineage[ 27, {5.5362846718122025, 
          DirectedInfinity[ 1]}, {{}, {a, b, c, d}, {}}, {0.32470788124846017,
           0.37314491294052798, 1}, {}], 
        AncestralLineage[ 28, {5.8038998031993723, 
          DirectedInfinity[ 1]}, {{}, {a, b, c}, {}}, {0.81251054459447569, 
          0.98211937306245001, 1}, {}], 
        AncestralLineage[ 29, {5.8038998031993723, 
          DirectedInfinity[ 1]}, {{}, {a, b, c}}, {0.98211937306245001, 
          1}, {}]}],
      Editable->False]], "Print",
  CellLabel->"From In[346]:="],

Cell[BoxData[
    \({0.1443901152932691`, 4, None}\)], "Print",
  CellLabel->"From In[346]:="],

Cell[BoxData[
    InterpretationBox[\("Coalescing "\[InvisibleSpace]{26, 
          28}\[InvisibleSpace]"; current lineages "\[InvisibleSpace]{25, 26, 
          27, 28, 29}\),
      SequenceForm[ 
      "Coalescing ", {26, 28}, "; current lineages ", {25, 26, 27, 28, 29}],
      Editable->False]], "Print",
  CellLabel->"From In[346]:="],

Cell[BoxData[
    InterpretationBox[
      RowBox[{"\<\"G=\"\>", "\[InvisibleSpace]", 
        RowBox[{"{", 
          
          RowBox[{\(AncestralLineage[
              a, {0, 0.48529096572278896`}, {{a}}, {1}, {}]\), 
            ",", \(AncestralLineage[
              b, {0, 0.2339831643602032`}, {{b}}, {1}, {}]\), 
            ",", \(AncestralLineage[
              c, {0, 0.48529096572278896`}, {{c}}, {1}, {}]\), 
            ",", \(AncestralLineage[
              d, {0, 1.7278195994170844`}, {{d}}, {1}, {}]\), 
            ",", \(AncestralLineage[
              1, {0.2339831643602032`, 
                0.3223607589398818`}, {{b}, {}}, {0.11492662691806055`, 
                1}, {}]\), 
            ",", \(AncestralLineage[
              2, {0.2339831643602032`, 
                0.3223607589398818`}, {{}, {b}}, {0.11492662691806055`, 
                1}, {}]\), 
            ",", \(AncestralLineage[
              3, {0.3223607589398818`, 0.517863837134862`}, {{b}}, {1}, {}]\),
             ",", \(AncestralLineage[
              4, {0.48529096572278896`, 
                0.517863837134862`}, {{a, c}}, {1}, {}]\), 
            ",", \(AncestralLineage[
              5, {0.517863837134862`, 
                1.5246611785364954`}, {{a, b, c}}, {1}, {}]\), 
            ",", \(AncestralLineage[
              6, {1.5246611785364954`, 
                1.5581431051287236`}, {{a, b, c}, {}}, {0.48913575253109154`, 
                1}, {}]\), 
            ",", \(AncestralLineage[
              7, {1.5246611785364954`, 
                1.5581431051287236`}, {{}, {a, b, c}}, {0.48913575253109154`, 
                1}, {}]\), 
            ",", \(AncestralLineage[
              8, {1.5581431051287236`, 
                1.655368377665858`}, {{a, b, c}}, {1}, {}]\), 
            ",", \(AncestralLineage[
              9, {1.655368377665858`, 
                1.7278195994170844`}, {{a, b, c}, {}}, {0.8125105445944757`, 
                1}, {}]\), 
            ",", \(AncestralLineage[
              10, {1.655368377665858`, 
                5.803899803199372`}, {{}, {a, b, c}}, {0.8125105445944757`, 
                1}, {}]\), 
            ",", \(AncestralLineage[
              11, {1.7278195994170844`, 
                2.9123438760363545`}, {{a, b, c, 
                  d}, {d}}, {0.8125105445944757`, 1}, {}]\), 
            ",", \(AncestralLineage[
              12, {2.9123438760363545`, 
                3.051081350478252`}, {{a, b, c, 
                  d}, {d}, {}}, {0.8125105445944757`, 0.8211640322266659`, 
                1}, {}]\), 
            ",", \(AncestralLineage[
              13, {2.9123438760363545`, 
                3.051081350478252`}, {{}, {d}}, {0.8211640322266659`, 
                1}, {}]\), 
            ",", \(AncestralLineage[
              14, {3.051081350478252`, 
                3.9325181869144528`}, {{a, b, c, 
                  d}, {d}}, {0.8125105445944757`, 1}, {}]\), 
            ",", \(AncestralLineage[
              15, {3.9325181869144528`, 
                4.130798875978213`}, {{a, b, c, 
                  d}, {}}, {0.016431884006824982`, 1}, {}]\), 
            ",", \(AncestralLineage[
              16, {3.9325181869144528`, 
                4.130798875978213`}, {{}, {a, b, c, 
                  d}, {d}}, {0.016431884006824982`, 0.8125105445944757`, 
                1}, {}]\), 
            ",", \(AncestralLineage[
              17, {4.130798875978213`, 
                4.8384282701987225`}, {{a, b, c, 
                  d}, {d}}, {0.8125105445944757`, 1}, {}]\), 
            ",", \(AncestralLineage[
              18, {4.8384282701987225`, 
                4.86647775888171`}, {{a, b, c, d}, {}}, {0.7440283682703366`, 
                1}, {}]\), 
            ",", \(AncestralLineage[
              19, {4.8384282701987225`, 
                4.86647775888171`}, {{}, {a, b, c, 
                  d}, {d}}, {0.7440283682703366`, 0.8125105445944757`, 
                1}, {}]\), 
            ",", \(AncestralLineage[
              20, {4.86647775888171`, 
                5.292690316029419`}, {{a, b, c, 
                  d}, {d}}, {0.8125105445944757`, 1}, {}]\), 
            ",", \(AncestralLineage[
              21, {5.292690316029419`, 
                5.346001768468149`}, {{a, b, c, 
                  d}, {d}, {}}, {0.8125105445944757`, 0.9265889024279855`, 
                1}, {}]\), 
            ",", \(AncestralLineage[
              22, {5.292690316029419`, 
                5.346001768468149`}, {{}, {d}}, {0.9265889024279855`, 
                1}, {}]\), 
            ",", \(AncestralLineage[
              23, {5.346001768468149`, 
                5.459871420495768`}, {{a, b, c, 
                  d}, {d}}, {0.8125105445944757`, 1}, {}]\), 
            ",", \(AncestralLineage[
              24, {5.459871420495768`, 
                5.5362846718122025`}, {{a, b, c, 
                  d}, {}}, {0.373144912940528`, 1}, {}]\), ",", 
            RowBox[{"AncestralLineage", "[", 
              RowBox[{"25", ",", 
                RowBox[{"{", 
                  RowBox[{"5.459871420495768`", ",", 
                    InterpretationBox["\[Infinity]",
                      DirectedInfinity[ 1]]}], "}"}], 
                ",", \({{}, {a, b, c, d}, {d}}\), 
                ",", \({0.373144912940528`, 0.8125105445944757`, 1}\), 
                ",", \({}\)}], "]"}], 
            ",", \(AncestralLineage[
              26, {5.5362846718122025`, 
                6.08624167552868`}, {{a, b, c, d}, {}}, {0.3247078812484602`, 
                1}, {}]\), ",", 
            RowBox[{"AncestralLineage", "[", 
              RowBox[{"27", ",", 
                RowBox[{"{", 
                  RowBox[{"5.5362846718122025`", ",", 
                    InterpretationBox["\[Infinity]",
                      DirectedInfinity[ 1]]}], "}"}], 
                ",", \({{}, {a, b, c, d}, {}}\), 
                ",", \({0.3247078812484602`, 0.373144912940528`, 1}\), 
                ",", \({}\)}], "]"}], 
            ",", \(AncestralLineage[
              28, {5.803899803199372`, 
                6.08624167552868`}, {{}, {a, b, 
                  c}, {}}, {0.8125105445944757`, 0.98211937306245`, 1}, {}]\),
             ",", 
            RowBox[{"AncestralLineage", "[", 
              RowBox[{"29", ",", 
                RowBox[{"{", 
                  RowBox[{"5.803899803199372`", ",", 
                    InterpretationBox["\[Infinity]",
                      DirectedInfinity[ 1]]}], "}"}], 
                ",", \({{}, {a, b, c}}\), ",", \({0.98211937306245`, 1}\), 
                ",", \({}\)}], "]"}], ",", 
            RowBox[{"AncestralLineage", "[", 
              RowBox[{"30", ",", 
                RowBox[{"{", 
                  RowBox[{"6.08624167552868`", ",", 
                    InterpretationBox["\[Infinity]",
                      DirectedInfinity[ 1]]}], "}"}], 
                ",", \({{a, b, c, d}, {}, {a, b, c}, {}}\), 
                ",", \({0.3247078812484602`, 0.8125105445944757`, 
                  0.98211937306245`, 1}\), ",", \({}\)}], "]"}]}], "}"}]}],
      SequenceForm[ "G=", {
        AncestralLineage[ a, {0, 0.48529096572278896}, {{a}}, {1}, {}], 
        AncestralLineage[ b, {0, 0.23398316436020319}, {{b}}, {1}, {}], 
        AncestralLineage[ c, {0, 0.48529096572278896}, {{c}}, {1}, {}], 
        AncestralLineage[ d, {0, 1.7278195994170844}, {{d}}, {1}, {}], 
        AncestralLineage[ 
        1, {0.23398316436020319, 0.32236075893988181}, {{b}, {}}, {
          0.11492662691806055, 1}, {}], 
        AncestralLineage[ 
        2, {0.23398316436020319, 0.32236075893988181}, {{}, {b}}, {
          0.11492662691806055, 1}, {}], 
        AncestralLineage[ 
        3, {0.32236075893988181, 0.51786383713486195}, {{b}}, {1}, {}], 
        AncestralLineage[ 
        4, {0.48529096572278896, 0.51786383713486195}, {{a, c}}, {1}, {}], 
        AncestralLineage[ 
        5, {0.51786383713486195, 1.5246611785364954}, {{a, b, c}}, {1}, {}], 
        AncestralLineage[ 
        6, {1.5246611785364954, 1.5581431051287236}, {{a, b, c}, {}}, {
          0.48913575253109154, 1}, {}], 
        AncestralLineage[ 
        7, {1.5246611785364954, 1.5581431051287236}, {{}, {a, b, c}}, {
          0.48913575253109154, 1}, {}], 
        AncestralLineage[ 
        8, {1.5581431051287236, 1.6553683776658581}, {{a, b, c}}, {1}, {}], 
        AncestralLineage[ 
        9, {1.6553683776658581, 1.7278195994170844}, {{a, b, c}, {}}, {
          0.81251054459447569, 1}, {}], 
        AncestralLineage[ 
        10, {1.6553683776658581, 5.8038998031993723}, {{}, {a, b, c}}, {
          0.81251054459447569, 1}, {}], 
        AncestralLineage[ 
        11, {1.7278195994170844, 2.9123438760363545}, {{a, b, c, d}, {d}}, {
          0.81251054459447569, 1}, {}], 
        AncestralLineage[ 
        12, {2.9123438760363545, 3.0510813504782521}, {{a, b, c, d}, {
          d}, {}}, {0.81251054459447569, 0.8211640322266659, 1}, {}], 
        AncestralLineage[ 
        13, {2.9123438760363545, 3.0510813504782521}, {{}, {d}}, {
          0.8211640322266659, 1}, {}], 
        AncestralLineage[ 
        14, {3.0510813504782521, 3.9325181869144528}, {{a, b, c, d}, {d}}, {
          0.81251054459447569, 1}, {}], 
        AncestralLineage[ 
        15, {3.9325181869144528, 4.130798875978213}, {{a, b, c, d}, {}}, {
          0.016431884006824982, 1}, {}], 
        AncestralLineage[ 
        16, {3.9325181869144528, 4.130798875978213}, {{}, {a, b, c, d}, {
          d}}, {0.016431884006824982, 0.81251054459447569, 1}, {}], 
        AncestralLineage[ 
        17, {4.130798875978213, 4.8384282701987225}, {{a, b, c, d}, {d}}, {
          0.81251054459447569, 1}, {}], 
        AncestralLineage[ 
        18, {4.8384282701987225, 4.8664777588817101}, {{a, b, c, d}, {}}, {
          0.74402836827033658, 1}, {}], 
        AncestralLineage[ 
        19, {4.8384282701987225, 4.8664777588817101}, {{}, {a, b, c, d}, {
          d}}, {0.74402836827033658, 0.81251054459447569, 1}, {}], 
        AncestralLineage[ 
        20, {4.8664777588817101, 5.292690316029419}, {{a, b, c, d}, {d}}, {
          0.81251054459447569, 1}, {}], 
        AncestralLineage[ 
        21, {5.292690316029419, 5.3460017684681489}, {{a, b, c, d}, {
          d}, {}}, {0.81251054459447569, 0.92658890242798553, 1}, {}], 
        AncestralLineage[ 
        22, {5.292690316029419, 5.3460017684681489}, {{}, {d}}, {
          0.92658890242798553, 1}, {}], 
        AncestralLineage[ 
        23, {5.3460017684681489, 5.4598714204957677}, {{a, b, c, d}, {d}}, {
          0.81251054459447569, 1}, {}], 
        AncestralLineage[ 
        24, {5.4598714204957677, 5.5362846718122025}, {{a, b, c, d}, {}}, {
          0.37314491294052798, 1}, {}], 
        AncestralLineage[ 25, {5.4598714204957677, 
          DirectedInfinity[ 1]}, {{}, {a, b, c, d}, {d}}, {
          0.37314491294052798, 0.81251054459447569, 1}, {}], 
        AncestralLineage[ 
        26, {5.5362846718122025, 6.0862416755286803}, {{a, b, c, d}, {}}, {
          0.32470788124846017, 1}, {}], 
        AncestralLineage[ 27, {5.5362846718122025, 
          DirectedInfinity[ 1]}, {{}, {a, b, c, d}, {}}, {0.32470788124846017,
           0.37314491294052798, 1}, {}], 
        AncestralLineage[ 
        28, {5.8038998031993723, 6.0862416755286803}, {{}, {a, b, c}, {}}, {
          0.81251054459447569, 0.98211937306245001, 1}, {}], 
        AncestralLineage[ 29, {5.8038998031993723, 
          DirectedInfinity[ 1]}, {{}, {a, b, c}}, {0.98211937306245001, 
          1}, {}], 
        AncestralLineage[ 30, {6.0862416755286803, 
          DirectedInfinity[ 1]}, {{a, b, c, d}, {}, {a, b, c}, {}}, {
          0.32470788124846017, 0.81251054459447569, 0.98211937306245001, 
          1}, {}]}],
      Editable->False]], "Print",
  CellLabel->"From In[346]:="],

Cell[BoxData[
    \({0.14774235857295342`, 3, None}\)], "Print",
  CellLabel->"From In[346]:="],

Cell[BoxData[
    InterpretationBox[\("Coalescing "\[InvisibleSpace]{27, 
          29}\[InvisibleSpace]"; current lineages "\[InvisibleSpace]{25, 27, 
          29, 30}\),
      SequenceForm[ 
      "Coalescing ", {27, 29}, "; current lineages ", {25, 27, 29, 30}],
      Editable->False]], "Print",
  CellLabel->"From In[346]:="],

Cell[BoxData[
    InterpretationBox[
      RowBox[{"\<\"G=\"\>", "\[InvisibleSpace]", 
        RowBox[{"{", 
          
          RowBox[{\(AncestralLineage[
              a, {0, 0.48529096572278896`}, {{a}}, {1}, {}]\), 
            ",", \(AncestralLineage[
              b, {0, 0.2339831643602032`}, {{b}}, {1}, {}]\), 
            ",", \(AncestralLineage[
              c, {0, 0.48529096572278896`}, {{c}}, {1}, {}]\), 
            ",", \(AncestralLineage[
              d, {0, 1.7278195994170844`}, {{d}}, {1}, {}]\), 
            ",", \(AncestralLineage[
              1, {0.2339831643602032`, 
                0.3223607589398818`}, {{b}, {}}, {0.11492662691806055`, 
                1}, {}]\), 
            ",", \(AncestralLineage[
              2, {0.2339831643602032`, 
                0.3223607589398818`}, {{}, {b}}, {0.11492662691806055`, 
                1}, {}]\), 
            ",", \(AncestralLineage[
              3, {0.3223607589398818`, 0.517863837134862`}, {{b}}, {1}, {}]\),
             ",", \(AncestralLineage[
              4, {0.48529096572278896`, 
                0.517863837134862`}, {{a, c}}, {1}, {}]\), 
            ",", \(AncestralLineage[
              5, {0.517863837134862`, 
                1.5246611785364954`}, {{a, b, c}}, {1}, {}]\), 
            ",", \(AncestralLineage[
              6, {1.5246611785364954`, 
                1.5581431051287236`}, {{a, b, c}, {}}, {0.48913575253109154`, 
                1}, {}]\), 
            ",", \(AncestralLineage[
              7, {1.5246611785364954`, 
                1.5581431051287236`}, {{}, {a, b, c}}, {0.48913575253109154`, 
                1}, {}]\), 
            ",", \(AncestralLineage[
              8, {1.5581431051287236`, 
                1.655368377665858`}, {{a, b, c}}, {1}, {}]\), 
            ",", \(AncestralLineage[
              9, {1.655368377665858`, 
                1.7278195994170844`}, {{a, b, c}, {}}, {0.8125105445944757`, 
                1}, {}]\), 
            ",", \(AncestralLineage[
              10, {1.655368377665858`, 
                5.803899803199372`}, {{}, {a, b, c}}, {0.8125105445944757`, 
                1}, {}]\), 
            ",", \(AncestralLineage[
              11, {1.7278195994170844`, 
                2.9123438760363545`}, {{a, b, c, 
                  d}, {d}}, {0.8125105445944757`, 1}, {}]\), 
            ",", \(AncestralLineage[
              12, {2.9123438760363545`, 
                3.051081350478252`}, {{a, b, c, 
                  d}, {d}, {}}, {0.8125105445944757`, 0.8211640322266659`, 
                1}, {}]\), 
            ",", \(AncestralLineage[
              13, {2.9123438760363545`, 
                3.051081350478252`}, {{}, {d}}, {0.8211640322266659`, 
                1}, {}]\), 
            ",", \(AncestralLineage[
              14, {3.051081350478252`, 
                3.9325181869144528`}, {{a, b, c, 
                  d}, {d}}, {0.8125105445944757`, 1}, {}]\), 
            ",", \(AncestralLineage[
              15, {3.9325181869144528`, 
                4.130798875978213`}, {{a, b, c, 
                  d}, {}}, {0.016431884006824982`, 1}, {}]\), 
            ",", \(AncestralLineage[
              16, {3.9325181869144528`, 
                4.130798875978213`}, {{}, {a, b, c, 
                  d}, {d}}, {0.016431884006824982`, 0.8125105445944757`, 
                1}, {}]\), 
            ",", \(AncestralLineage[
              17, {4.130798875978213`, 
                4.8384282701987225`}, {{a, b, c, 
                  d}, {d}}, {0.8125105445944757`, 1}, {}]\), 
            ",", \(AncestralLineage[
              18, {4.8384282701987225`, 
                4.86647775888171`}, {{a, b, c, d}, {}}, {0.7440283682703366`, 
                1}, {}]\), 
            ",", \(AncestralLineage[
              19, {4.8384282701987225`, 
                4.86647775888171`}, {{}, {a, b, c, 
                  d}, {d}}, {0.7440283682703366`, 0.8125105445944757`, 
                1}, {}]\), 
            ",", \(AncestralLineage[
              20, {4.86647775888171`, 
                5.292690316029419`}, {{a, b, c, 
                  d}, {d}}, {0.8125105445944757`, 1}, {}]\), 
            ",", \(AncestralLineage[
              21, {5.292690316029419`, 
                5.346001768468149`}, {{a, b, c, 
                  d}, {d}, {}}, {0.8125105445944757`, 0.9265889024279855`, 
                1}, {}]\), 
            ",", \(AncestralLineage[
              22, {5.292690316029419`, 
                5.346001768468149`}, {{}, {d}}, {0.9265889024279855`, 
                1}, {}]\), 
            ",", \(AncestralLineage[
              23, {5.346001768468149`, 
                5.459871420495768`}, {{a, b, c, 
                  d}, {d}}, {0.8125105445944757`, 1}, {}]\), 
            ",", \(AncestralLineage[
              24, {5.459871420495768`, 
                5.5362846718122025`}, {{a, b, c, 
                  d}, {}}, {0.373144912940528`, 1}, {}]\), ",", 
            RowBox[{"AncestralLineage", "[", 
              RowBox[{"25", ",", 
                RowBox[{"{", 
                  RowBox[{"5.459871420495768`", ",", 
                    InterpretationBox["\[Infinity]",
                      DirectedInfinity[ 1]]}], "}"}], 
                ",", \({{}, {a, b, c, d}, {d}}\), 
                ",", \({0.373144912940528`, 0.8125105445944757`, 1}\), 
                ",", \({}\)}], "]"}], 
            ",", \(AncestralLineage[
              26, {5.5362846718122025`, 
                6.08624167552868`}, {{a, b, c, d}, {}}, {0.3247078812484602`, 
                1}, {}]\), 
            ",", \(AncestralLineage[
              27, {5.5362846718122025`, 
                6.233984034101634`}, {{}, {a, b, c, 
                  d}, {}}, {0.3247078812484602`, 0.373144912940528`, 
                1}, {}]\), 
            ",", \(AncestralLineage[
              28, {5.803899803199372`, 
                6.08624167552868`}, {{}, {a, b, 
                  c}, {}}, {0.8125105445944757`, 0.98211937306245`, 1}, {}]\),
             ",", \(AncestralLineage[
              29, {5.803899803199372`, 
                6.233984034101634`}, {{}, {a, b, c}}, {0.98211937306245`, 
                1}, {}]\), ",", 
            RowBox[{"AncestralLineage", "[", 
              RowBox[{"30", ",", 
                RowBox[{"{", 
                  RowBox[{"6.08624167552868`", ",", 
                    InterpretationBox["\[Infinity]",
                      DirectedInfinity[ 1]]}], "}"}], 
                ",", \({{a, b, c, d}, {}, {a, b, c}, {}}\), 
                ",", \({0.3247078812484602`, 0.8125105445944757`, 
                  0.98211937306245`, 1}\), ",", \({}\)}], "]"}], ",", 
            RowBox[{"AncestralLineage", "[", 
              RowBox[{"31", ",", 
                RowBox[{"{", 
                  RowBox[{"6.233984034101634`", ",", 
                    InterpretationBox["\[Infinity]",
                      DirectedInfinity[ 1]]}], "}"}], 
                ",", \({{}, {a, b, c, d}, {}, {a, b, c}}\), 
                ",", \({0.3247078812484602`, 0.373144912940528`, 
                  0.98211937306245`, 1}\), ",", \({}\)}], "]"}]}], "}"}]}],
      SequenceForm[ "G=", {
        AncestralLineage[ a, {0, 0.48529096572278896}, {{a}}, {1}, {}], 
        AncestralLineage[ b, {0, 0.23398316436020319}, {{b}}, {1}, {}], 
        AncestralLineage[ c, {0, 0.48529096572278896}, {{c}}, {1}, {}], 
        AncestralLineage[ d, {0, 1.7278195994170844}, {{d}}, {1}, {}], 
        AncestralLineage[ 
        1, {0.23398316436020319, 0.32236075893988181}, {{b}, {}}, {
          0.11492662691806055, 1}, {}], 
        AncestralLineage[ 
        2, {0.23398316436020319, 0.32236075893988181}, {{}, {b}}, {
          0.11492662691806055, 1}, {}], 
        AncestralLineage[ 
        3, {0.32236075893988181, 0.51786383713486195}, {{b}}, {1}, {}], 
        AncestralLineage[ 
        4, {0.48529096572278896, 0.51786383713486195}, {{a, c}}, {1}, {}], 
        AncestralLineage[ 
        5, {0.51786383713486195, 1.5246611785364954}, {{a, b, c}}, {1}, {}], 
        AncestralLineage[ 
        6, {1.5246611785364954, 1.5581431051287236}, {{a, b, c}, {}}, {
          0.48913575253109154, 1}, {}], 
        AncestralLineage[ 
        7, {1.5246611785364954, 1.5581431051287236}, {{}, {a, b, c}}, {
          0.48913575253109154, 1}, {}], 
        AncestralLineage[ 
        8, {1.5581431051287236, 1.6553683776658581}, {{a, b, c}}, {1}, {}], 
        AncestralLineage[ 
        9, {1.6553683776658581, 1.7278195994170844}, {{a, b, c}, {}}, {
          0.81251054459447569, 1}, {}], 
        AncestralLineage[ 
        10, {1.6553683776658581, 5.8038998031993723}, {{}, {a, b, c}}, {
          0.81251054459447569, 1}, {}], 
        AncestralLineage[ 
        11, {1.7278195994170844, 2.9123438760363545}, {{a, b, c, d}, {d}}, {
          0.81251054459447569, 1}, {}], 
        AncestralLineage[ 
        12, {2.9123438760363545, 3.0510813504782521}, {{a, b, c, d}, {
          d}, {}}, {0.81251054459447569, 0.8211640322266659, 1}, {}], 
        AncestralLineage[ 
        13, {2.9123438760363545, 3.0510813504782521}, {{}, {d}}, {
          0.8211640322266659, 1}, {}], 
        AncestralLineage[ 
        14, {3.0510813504782521, 3.9325181869144528}, {{a, b, c, d}, {d}}, {
          0.81251054459447569, 1}, {}], 
        AncestralLineage[ 
        15, {3.9325181869144528, 4.130798875978213}, {{a, b, c, d}, {}}, {
          0.016431884006824982, 1}, {}], 
        AncestralLineage[ 
        16, {3.9325181869144528, 4.130798875978213}, {{}, {a, b, c, d}, {
          d}}, {0.016431884006824982, 0.81251054459447569, 1}, {}], 
        AncestralLineage[ 
        17, {4.130798875978213, 4.8384282701987225}, {{a, b, c, d}, {d}}, {
          0.81251054459447569, 1}, {}], 
        AncestralLineage[ 
        18, {4.8384282701987225, 4.8664777588817101}, {{a, b, c, d}, {}}, {
          0.74402836827033658, 1}, {}], 
        AncestralLineage[ 
        19, {4.8384282701987225, 4.8664777588817101}, {{}, {a, b, c, d}, {
          d}}, {0.74402836827033658, 0.81251054459447569, 1}, {}], 
        AncestralLineage[ 
        20, {4.8664777588817101, 5.292690316029419}, {{a, b, c, d}, {d}}, {
          0.81251054459447569, 1}, {}], 
        AncestralLineage[ 
        21, {5.292690316029419, 5.3460017684681489}, {{a, b, c, d}, {
          d}, {}}, {0.81251054459447569, 0.92658890242798553, 1}, {}], 
        AncestralLineage[ 
        22, {5.292690316029419, 5.3460017684681489}, {{}, {d}}, {
          0.92658890242798553, 1}, {}], 
        AncestralLineage[ 
        23, {5.3460017684681489, 5.4598714204957677}, {{a, b, c, d}, {d}}, {
          0.81251054459447569, 1}, {}], 
        AncestralLineage[ 
        24, {5.4598714204957677, 5.5362846718122025}, {{a, b, c, d}, {}}, {
          0.37314491294052798, 1}, {}], 
        AncestralLineage[ 25, {5.4598714204957677, 
          DirectedInfinity[ 1]}, {{}, {a, b, c, d}, {d}}, {
          0.37314491294052798, 0.81251054459447569, 1}, {}], 
        AncestralLineage[ 
        26, {5.5362846718122025, 6.0862416755286803}, {{a, b, c, d}, {}}, {
          0.32470788124846017, 1}, {}], 
        AncestralLineage[ 
        27, {5.5362846718122025, 6.2339840341016339}, {{}, {a, b, c, 
          d}, {}}, {0.32470788124846017, 0.37314491294052798, 1}, {}], 
        AncestralLineage[ 
        28, {5.8038998031993723, 6.0862416755286803}, {{}, {a, b, c}, {}}, {
          0.81251054459447569, 0.98211937306245001, 1}, {}], 
        AncestralLineage[ 
        29, {5.8038998031993723, 6.2339840341016339}, {{}, {a, b, c}}, {
          0.98211937306245001, 1}, {}], 
        AncestralLineage[ 30, {6.0862416755286803, 
          DirectedInfinity[ 1]}, {{a, b, c, d}, {}, {a, b, c}, {}}, {
          0.32470788124846017, 0.81251054459447569, 0.98211937306245001, 
          1}, {}], 
        AncestralLineage[ 31, {6.2339840341016339, 
          DirectedInfinity[ 1]}, {{}, {a, b, c, d}, {}, {a, b, c}}, {
          0.32470788124846017, 0.37314491294052798, 0.98211937306245001, 
          1}, {}]}],
      Editable->False]], "Print",
  CellLabel->"From In[346]:="],

Cell[BoxData[
    \({0.21467547299009399`, 2, None}\)], "Print",
  CellLabel->"From In[346]:="],

Cell[BoxData[
    InterpretationBox[\("Coalescing "\[InvisibleSpace]{30, 
          31}\[InvisibleSpace]"; current lineages "\[InvisibleSpace]{25, 30, 
          31}\),
      SequenceForm[ 
      "Coalescing ", {30, 31}, "; current lineages ", {25, 30, 31}],
      Editable->False]], "Print",
  CellLabel->"From In[346]:="],

Cell[BoxData[
    InterpretationBox[
      RowBox[{"\<\"G=\"\>", "\[InvisibleSpace]", 
        RowBox[{"{", 
          
          RowBox[{\(AncestralLineage[
              a, {0, 0.48529096572278896`}, {{a}}, {1}, {}]\), 
            ",", \(AncestralLineage[
              b, {0, 0.2339831643602032`}, {{b}}, {1}, {}]\), 
            ",", \(AncestralLineage[
              c, {0, 0.48529096572278896`}, {{c}}, {1}, {}]\), 
            ",", \(AncestralLineage[
              d, {0, 1.7278195994170844`}, {{d}}, {1}, {}]\), 
            ",", \(AncestralLineage[
              1, {0.2339831643602032`, 
                0.3223607589398818`}, {{b}, {}}, {0.11492662691806055`, 
                1}, {}]\), 
            ",", \(AncestralLineage[
              2, {0.2339831643602032`, 
                0.3223607589398818`}, {{}, {b}}, {0.11492662691806055`, 
                1}, {}]\), 
            ",", \(AncestralLineage[
              3, {0.3223607589398818`, 0.517863837134862`}, {{b}}, {1}, {}]\),
             ",", \(AncestralLineage[
              4, {0.48529096572278896`, 
                0.517863837134862`}, {{a, c}}, {1}, {}]\), 
            ",", \(AncestralLineage[
              5, {0.517863837134862`, 
                1.5246611785364954`}, {{a, b, c}}, {1}, {}]\), 
            ",", \(AncestralLineage[
              6, {1.5246611785364954`, 
                1.5581431051287236`}, {{a, b, c}, {}}, {0.48913575253109154`, 
                1}, {}]\), 
            ",", \(AncestralLineage[
              7, {1.5246611785364954`, 
                1.5581431051287236`}, {{}, {a, b, c}}, {0.48913575253109154`, 
                1}, {}]\), 
            ",", \(AncestralLineage[
              8, {1.5581431051287236`, 
                1.655368377665858`}, {{a, b, c}}, {1}, {}]\), 
            ",", \(AncestralLineage[
              9, {1.655368377665858`, 
                1.7278195994170844`}, {{a, b, c}, {}}, {0.8125105445944757`, 
                1}, {}]\), 
            ",", \(AncestralLineage[
              10, {1.655368377665858`, 
                5.803899803199372`}, {{}, {a, b, c}}, {0.8125105445944757`, 
                1}, {}]\), 
            ",", \(AncestralLineage[
              11, {1.7278195994170844`, 
                2.9123438760363545`}, {{a, b, c, 
                  d}, {d}}, {0.8125105445944757`, 1}, {}]\), 
            ",", \(AncestralLineage[
              12, {2.9123438760363545`, 
                3.051081350478252`}, {{a, b, c, 
                  d}, {d}, {}}, {0.8125105445944757`, 0.8211640322266659`, 
                1}, {}]\), 
            ",", \(AncestralLineage[
              13, {2.9123438760363545`, 
                3.051081350478252`}, {{}, {d}}, {0.8211640322266659`, 
                1}, {}]\), 
            ",", \(AncestralLineage[
              14, {3.051081350478252`, 
                3.9325181869144528`}, {{a, b, c, 
                  d}, {d}}, {0.8125105445944757`, 1}, {}]\), 
            ",", \(AncestralLineage[
              15, {3.9325181869144528`, 
                4.130798875978213`}, {{a, b, c, 
                  d}, {}}, {0.016431884006824982`, 1}, {}]\), 
            ",", \(AncestralLineage[
              16, {3.9325181869144528`, 
                4.130798875978213`}, {{}, {a, b, c, 
                  d}, {d}}, {0.016431884006824982`, 0.8125105445944757`, 
                1}, {}]\), 
            ",", \(AncestralLineage[
              17, {4.130798875978213`, 
                4.8384282701987225`}, {{a, b, c, 
                  d}, {d}}, {0.8125105445944757`, 1}, {}]\), 
            ",", \(AncestralLineage[
              18, {4.8384282701987225`, 
                4.86647775888171`}, {{a, b, c, d}, {}}, {0.7440283682703366`, 
                1}, {}]\), 
            ",", \(AncestralLineage[
              19, {4.8384282701987225`, 
                4.86647775888171`}, {{}, {a, b, c, 
                  d}, {d}}, {0.7440283682703366`, 0.8125105445944757`, 
                1}, {}]\), 
            ",", \(AncestralLineage[
              20, {4.86647775888171`, 
                5.292690316029419`}, {{a, b, c, 
                  d}, {d}}, {0.8125105445944757`, 1}, {}]\), 
            ",", \(AncestralLineage[
              21, {5.292690316029419`, 
                5.346001768468149`}, {{a, b, c, 
                  d}, {d}, {}}, {0.8125105445944757`, 0.9265889024279855`, 
                1}, {}]\), 
            ",", \(AncestralLineage[
              22, {5.292690316029419`, 
                5.346001768468149`}, {{}, {d}}, {0.9265889024279855`, 
                1}, {}]\), 
            ",", \(AncestralLineage[
              23, {5.346001768468149`, 
                5.459871420495768`}, {{a, b, c, 
                  d}, {d}}, {0.8125105445944757`, 1}, {}]\), 
            ",", \(AncestralLineage[
              24, {5.459871420495768`, 
                5.5362846718122025`}, {{a, b, c, 
                  d}, {}}, {0.373144912940528`, 1}, {}]\), ",", 
            RowBox[{"AncestralLineage", "[", 
              RowBox[{"25", ",", 
                RowBox[{"{", 
                  RowBox[{"5.459871420495768`", ",", 
                    InterpretationBox["\[Infinity]",
                      DirectedInfinity[ 1]]}], "}"}], 
                ",", \({{}, {a, b, c, d}, {d}}\), 
                ",", \({0.373144912940528`, 0.8125105445944757`, 1}\), 
                ",", \({}\)}], "]"}], 
            ",", \(AncestralLineage[
              26, {5.5362846718122025`, 
                6.08624167552868`}, {{a, b, c, d}, {}}, {0.3247078812484602`, 
                1}, {}]\), 
            ",", \(AncestralLineage[
              27, {5.5362846718122025`, 
                6.233984034101634`}, {{}, {a, b, c, 
                  d}, {}}, {0.3247078812484602`, 0.373144912940528`, 
                1}, {}]\), 
            ",", \(AncestralLineage[
              28, {5.803899803199372`, 
                6.08624167552868`}, {{}, {a, b, 
                  c}, {}}, {0.8125105445944757`, 0.98211937306245`, 1}, {}]\),
             ",", \(AncestralLineage[
              29, {5.803899803199372`, 
                6.233984034101634`}, {{}, {a, b, c}}, {0.98211937306245`, 
                1}, {}]\), 
            ",", \(AncestralLineage[
              30, {6.08624167552868`, 
                6.448659507091728`}, {{a, b, c, d}, {}, {a, b, 
                  c}, {}}, {0.3247078812484602`, 0.8125105445944757`, 
                0.98211937306245`, 1}, {}]\), 
            ",", \(AncestralLineage[
              31, {6.233984034101634`, 
                6.448659507091728`}, {{}, {a, b, c, d}, {}, {a, b, 
                  c}}, {0.3247078812484602`, 0.373144912940528`, 
                0.98211937306245`, 1}, {}]\), ",", 
            RowBox[{"AncestralLineage", "[", 
              RowBox[{"32", ",", 
                RowBox[{"{", 
                  RowBox[{"6.448659507091728`", ",", 
                    InterpretationBox["\[Infinity]",
                      DirectedInfinity[ 1]]}], "}"}], 
                ",", \({{a, b, c, d}, {}, {a, b, c}}\), 
                ",", \({0.373144912940528`, 0.8125105445944757`, 1}\), 
                ",", \({}\)}], "]"}]}], "}"}]}],
      SequenceForm[ "G=", {
        AncestralLineage[ a, {0, 0.48529096572278896}, {{a}}, {1}, {}], 
        AncestralLineage[ b, {0, 0.23398316436020319}, {{b}}, {1}, {}], 
        AncestralLineage[ c, {0, 0.48529096572278896}, {{c}}, {1}, {}], 
        AncestralLineage[ d, {0, 1.7278195994170844}, {{d}}, {1}, {}], 
        AncestralLineage[ 
        1, {0.23398316436020319, 0.32236075893988181}, {{b}, {}}, {
          0.11492662691806055, 1}, {}], 
        AncestralLineage[ 
        2, {0.23398316436020319, 0.32236075893988181}, {{}, {b}}, {
          0.11492662691806055, 1}, {}], 
        AncestralLineage[ 
        3, {0.32236075893988181, 0.51786383713486195}, {{b}}, {1}, {}], 
        AncestralLineage[ 
        4, {0.48529096572278896, 0.51786383713486195}, {{a, c}}, {1}, {}], 
        AncestralLineage[ 
        5, {0.51786383713486195, 1.5246611785364954}, {{a, b, c}}, {1}, {}], 
        AncestralLineage[ 
        6, {1.5246611785364954, 1.5581431051287236}, {{a, b, c}, {}}, {
          0.48913575253109154, 1}, {}], 
        AncestralLineage[ 
        7, {1.5246611785364954, 1.5581431051287236}, {{}, {a, b, c}}, {
          0.48913575253109154, 1}, {}], 
        AncestralLineage[ 
        8, {1.5581431051287236, 1.6553683776658581}, {{a, b, c}}, {1}, {}], 
        AncestralLineage[ 
        9, {1.6553683776658581, 1.7278195994170844}, {{a, b, c}, {}}, {
          0.81251054459447569, 1}, {}], 
        AncestralLineage[ 
        10, {1.6553683776658581, 5.8038998031993723}, {{}, {a, b, c}}, {
          0.81251054459447569, 1}, {}], 
        AncestralLineage[ 
        11, {1.7278195994170844, 2.9123438760363545}, {{a, b, c, d}, {d}}, {
          0.81251054459447569, 1}, {}], 
        AncestralLineage[ 
        12, {2.9123438760363545, 3.0510813504782521}, {{a, b, c, d}, {
          d}, {}}, {0.81251054459447569, 0.8211640322266659, 1}, {}], 
        AncestralLineage[ 
        13, {2.9123438760363545, 3.0510813504782521}, {{}, {d}}, {
          0.8211640322266659, 1}, {}], 
        AncestralLineage[ 
        14, {3.0510813504782521, 3.9325181869144528}, {{a, b, c, d}, {d}}, {
          0.81251054459447569, 1}, {}], 
        AncestralLineage[ 
        15, {3.9325181869144528, 4.130798875978213}, {{a, b, c, d}, {}}, {
          0.016431884006824982, 1}, {}], 
        AncestralLineage[ 
        16, {3.9325181869144528, 4.130798875978213}, {{}, {a, b, c, d}, {
          d}}, {0.016431884006824982, 0.81251054459447569, 1}, {}], 
        AncestralLineage[ 
        17, {4.130798875978213, 4.8384282701987225}, {{a, b, c, d}, {d}}, {
          0.81251054459447569, 1}, {}], 
        AncestralLineage[ 
        18, {4.8384282701987225, 4.8664777588817101}, {{a, b, c, d}, {}}, {
          0.74402836827033658, 1}, {}], 
        AncestralLineage[ 
        19, {4.8384282701987225, 4.8664777588817101}, {{}, {a, b, c, d}, {
          d}}, {0.74402836827033658, 0.81251054459447569, 1}, {}], 
        AncestralLineage[ 
        20, {4.8664777588817101, 5.292690316029419}, {{a, b, c, d}, {d}}, {
          0.81251054459447569, 1}, {}], 
        AncestralLineage[ 
        21, {5.292690316029419, 5.3460017684681489}, {{a, b, c, d}, {
          d}, {}}, {0.81251054459447569, 0.92658890242798553, 1}, {}], 
        AncestralLineage[ 
        22, {5.292690316029419, 5.3460017684681489}, {{}, {d}}, {
          0.92658890242798553, 1}, {}], 
        AncestralLineage[ 
        23, {5.3460017684681489, 5.4598714204957677}, {{a, b, c, d}, {d}}, {
          0.81251054459447569, 1}, {}], 
        AncestralLineage[ 
        24, {5.4598714204957677, 5.5362846718122025}, {{a, b, c, d}, {}}, {
          0.37314491294052798, 1}, {}], 
        AncestralLineage[ 25, {5.4598714204957677, 
          DirectedInfinity[ 1]}, {{}, {a, b, c, d}, {d}}, {
          0.37314491294052798, 0.81251054459447569, 1}, {}], 
        AncestralLineage[ 
        26, {5.5362846718122025, 6.0862416755286803}, {{a, b, c, d}, {}}, {
          0.32470788124846017, 1}, {}], 
        AncestralLineage[ 
        27, {5.5362846718122025, 6.2339840341016339}, {{}, {a, b, c, 
          d}, {}}, {0.32470788124846017, 0.37314491294052798, 1}, {}], 
        AncestralLineage[ 
        28, {5.8038998031993723, 6.0862416755286803}, {{}, {a, b, c}, {}}, {
          0.81251054459447569, 0.98211937306245001, 1}, {}], 
        AncestralLineage[ 
        29, {5.8038998031993723, 6.2339840341016339}, {{}, {a, b, c}}, {
          0.98211937306245001, 1}, {}], 
        AncestralLineage[ 
        30, {6.0862416755286803, 6.4486595070917279}, {{a, b, c, d}, {}, {a, 
          b, c}, {}}, {0.32470788124846017, 0.81251054459447569, 
          0.98211937306245001, 1}, {}], 
        AncestralLineage[ 
        31, {6.2339840341016339, 6.4486595070917279}, {{}, {a, b, c, d}, {}, {
          a, b, c}}, {0.32470788124846017, 0.37314491294052798, 
          0.98211937306245001, 1}, {}], 
        AncestralLineage[ 32, {6.4486595070917279, 
          DirectedInfinity[ 1]}, {{a, b, c, d}, {}, {a, b, c}}, {
          0.37314491294052798, 0.81251054459447569, 1}, {}]}],
      Editable->False]], "Print",
  CellLabel->"From In[346]:="],

Cell[BoxData[
    \({0.016111601531473587`, 3, 0.1338850878429638`}\)], "Print",
  CellLabel->"From In[346]:="],

Cell[BoxData[
    InterpretationBox[\("Recombining "\[InvisibleSpace]32\[InvisibleSpace]"; \
current lineages "\[InvisibleSpace]{25, 32}\),
      SequenceForm[ "Recombining ", 32, "; current lineages ", {25, 32}],
      Editable->False]], "Print",
  CellLabel->"From In[346]:="],

Cell[BoxData[
    InterpretationBox[
      RowBox[{"\<\"G=\"\>", "\[InvisibleSpace]", 
        RowBox[{"{", 
          
          RowBox[{\(AncestralLineage[
              a, {0, 0.48529096572278896`}, {{a}}, {1}, {}]\), 
            ",", \(AncestralLineage[
              b, {0, 0.2339831643602032`}, {{b}}, {1}, {}]\), 
            ",", \(AncestralLineage[
              c, {0, 0.48529096572278896`}, {{c}}, {1}, {}]\), 
            ",", \(AncestralLineage[
              d, {0, 1.7278195994170844`}, {{d}}, {1}, {}]\), 
            ",", \(AncestralLineage[
              1, {0.2339831643602032`, 
                0.3223607589398818`}, {{b}, {}}, {0.11492662691806055`, 
                1}, {}]\), 
            ",", \(AncestralLineage[
              2, {0.2339831643602032`, 
                0.3223607589398818`}, {{}, {b}}, {0.11492662691806055`, 
                1}, {}]\), 
            ",", \(AncestralLineage[
              3, {0.3223607589398818`, 0.517863837134862`}, {{b}}, {1}, {}]\),
             ",", \(AncestralLineage[
              4, {0.48529096572278896`, 
                0.517863837134862`}, {{a, c}}, {1}, {}]\), 
            ",", \(AncestralLineage[
              5, {0.517863837134862`, 
                1.5246611785364954`}, {{a, b, c}}, {1}, {}]\), 
            ",", \(AncestralLineage[
              6, {1.5246611785364954`, 
                1.5581431051287236`}, {{a, b, c}, {}}, {0.48913575253109154`, 
                1}, {}]\), 
            ",", \(AncestralLineage[
              7, {1.5246611785364954`, 
                1.5581431051287236`}, {{}, {a, b, c}}, {0.48913575253109154`, 
                1}, {}]\), 
            ",", \(AncestralLineage[
              8, {1.5581431051287236`, 
                1.655368377665858`}, {{a, b, c}}, {1}, {}]\), 
            ",", \(AncestralLineage[
              9, {1.655368377665858`, 
                1.7278195994170844`}, {{a, b, c}, {}}, {0.8125105445944757`, 
                1}, {}]\), 
            ",", \(AncestralLineage[
              10, {1.655368377665858`, 
                5.803899803199372`}, {{}, {a, b, c}}, {0.8125105445944757`, 
                1}, {}]\), 
            ",", \(AncestralLineage[
              11, {1.7278195994170844`, 
                2.9123438760363545`}, {{a, b, c, 
                  d}, {d}}, {0.8125105445944757`, 1}, {}]\), 
            ",", \(AncestralLineage[
              12, {2.9123438760363545`, 
                3.051081350478252`}, {{a, b, c, 
                  d}, {d}, {}}, {0.8125105445944757`, 0.8211640322266659`, 
                1}, {}]\), 
            ",", \(AncestralLineage[
              13, {2.9123438760363545`, 
                3.051081350478252`}, {{}, {d}}, {0.8211640322266659`, 
                1}, {}]\), 
            ",", \(AncestralLineage[
              14, {3.051081350478252`, 
                3.9325181869144528`}, {{a, b, c, 
                  d}, {d}}, {0.8125105445944757`, 1}, {}]\), 
            ",", \(AncestralLineage[
              15, {3.9325181869144528`, 
                4.130798875978213`}, {{a, b, c, 
                  d}, {}}, {0.016431884006824982`, 1}, {}]\), 
            ",", \(AncestralLineage[
              16, {3.9325181869144528`, 
                4.130798875978213`}, {{}, {a, b, c, 
                  d}, {d}}, {0.016431884006824982`, 0.8125105445944757`, 
                1}, {}]\), 
            ",", \(AncestralLineage[
              17, {4.130798875978213`, 
                4.8384282701987225`}, {{a, b, c, 
                  d}, {d}}, {0.8125105445944757`, 1}, {}]\), 
            ",", \(AncestralLineage[
              18, {4.8384282701987225`, 
                4.86647775888171`}, {{a, b, c, d}, {}}, {0.7440283682703366`, 
                1}, {}]\), 
            ",", \(AncestralLineage[
              19, {4.8384282701987225`, 
                4.86647775888171`}, {{}, {a, b, c, 
                  d}, {d}}, {0.7440283682703366`, 0.8125105445944757`, 
                1}, {}]\), 
            ",", \(AncestralLineage[
              20, {4.86647775888171`, 
                5.292690316029419`}, {{a, b, c, 
                  d}, {d}}, {0.8125105445944757`, 1}, {}]\), 
            ",", \(AncestralLineage[
              21, {5.292690316029419`, 
                5.346001768468149`}, {{a, b, c, 
                  d}, {d}, {}}, {0.8125105445944757`, 0.9265889024279855`, 
                1}, {}]\), 
            ",", \(AncestralLineage[
              22, {5.292690316029419`, 
                5.346001768468149`}, {{}, {d}}, {0.9265889024279855`, 
                1}, {}]\), 
            ",", \(AncestralLineage[
              23, {5.346001768468149`, 
                5.459871420495768`}, {{a, b, c, 
                  d}, {d}}, {0.8125105445944757`, 1}, {}]\), 
            ",", \(AncestralLineage[
              24, {5.459871420495768`, 
                5.5362846718122025`}, {{a, b, c, 
                  d}, {}}, {0.373144912940528`, 1}, {}]\), ",", 
            RowBox[{"AncestralLineage", "[", 
              RowBox[{"25", ",", 
                RowBox[{"{", 
                  RowBox[{"5.459871420495768`", ",", 
                    InterpretationBox["\[Infinity]",
                      DirectedInfinity[ 1]]}], "}"}], 
                ",", \({{}, {a, b, c, d}, {d}}\), 
                ",", \({0.373144912940528`, 0.8125105445944757`, 1}\), 
                ",", \({}\)}], "]"}], 
            ",", \(AncestralLineage[
              26, {5.5362846718122025`, 
                6.08624167552868`}, {{a, b, c, d}, {}}, {0.3247078812484602`, 
                1}, {}]\), 
            ",", \(AncestralLineage[
              27, {5.5362846718122025`, 
                6.233984034101634`}, {{}, {a, b, c, 
                  d}, {}}, {0.3247078812484602`, 0.373144912940528`, 
                1}, {}]\), 
            ",", \(AncestralLineage[
              28, {5.803899803199372`, 
                6.08624167552868`}, {{}, {a, b, 
                  c}, {}}, {0.8125105445944757`, 0.98211937306245`, 1}, {}]\),
             ",", \(AncestralLineage[
              29, {5.803899803199372`, 
                6.233984034101634`}, {{}, {a, b, c}}, {0.98211937306245`, 
                1}, {}]\), 
            ",", \(AncestralLineage[
              30, {6.08624167552868`, 
                6.448659507091728`}, {{a, b, c, d}, {}, {a, b, 
                  c}, {}}, {0.3247078812484602`, 0.8125105445944757`, 
                0.98211937306245`, 1}, {}]\), 
            ",", \(AncestralLineage[
              31, {6.233984034101634`, 
                6.448659507091728`}, {{}, {a, b, c, d}, {}, {a, b, 
                  c}}, {0.3247078812484602`, 0.373144912940528`, 
                0.98211937306245`, 1}, {}]\), 
            ",", \(AncestralLineage[
              32, {6.448659507091728`, 
                6.464771108623202`}, {{a, b, c, d}, {}, {a, b, 
                  c}}, {0.373144912940528`, 0.8125105445944757`, 1}, {}]\), 
            ",", 
            RowBox[{"AncestralLineage", "[", 
              RowBox[{"33", ",", 
                RowBox[{"{", 
                  RowBox[{"6.464771108623202`", ",", 
                    InterpretationBox["\[Infinity]",
                      DirectedInfinity[ 1]]}], "}"}], 
                ",", \({{a, b, c, d}, {}}\), 
                ",", \({0.1338850878429638`, 1}\), ",", \({}\)}], "]"}], ",", 
            
            RowBox[{"AncestralLineage", "[", 
              RowBox[{"34", ",", 
                RowBox[{"{", 
                  RowBox[{"6.464771108623202`", ",", 
                    InterpretationBox["\[Infinity]",
                      DirectedInfinity[ 1]]}], "}"}], 
                ",", \({{}, {a, b, c, d}, {}, {a, b, c}}\), 
                ",", \({0.1338850878429638`, 0.373144912940528`, 
                  0.8125105445944757`, 1}\), ",", \({}\)}], "]"}]}], "}"}]}],
      SequenceForm[ "G=", {
        AncestralLineage[ a, {0, 0.48529096572278896}, {{a}}, {1}, {}], 
        AncestralLineage[ b, {0, 0.23398316436020319}, {{b}}, {1}, {}], 
        AncestralLineage[ c, {0, 0.48529096572278896}, {{c}}, {1}, {}], 
        AncestralLineage[ d, {0, 1.7278195994170844}, {{d}}, {1}, {}], 
        AncestralLineage[ 
        1, {0.23398316436020319, 0.32236075893988181}, {{b}, {}}, {
          0.11492662691806055, 1}, {}], 
        AncestralLineage[ 
        2, {0.23398316436020319, 0.32236075893988181}, {{}, {b}}, {
          0.11492662691806055, 1}, {}], 
        AncestralLineage[ 
        3, {0.32236075893988181, 0.51786383713486195}, {{b}}, {1}, {}], 
        AncestralLineage[ 
        4, {0.48529096572278896, 0.51786383713486195}, {{a, c}}, {1}, {}], 
        AncestralLineage[ 
        5, {0.51786383713486195, 1.5246611785364954}, {{a, b, c}}, {1}, {}], 
        AncestralLineage[ 
        6, {1.5246611785364954, 1.5581431051287236}, {{a, b, c}, {}}, {
          0.48913575253109154, 1}, {}], 
        AncestralLineage[ 
        7, {1.5246611785364954, 1.5581431051287236}, {{}, {a, b, c}}, {
          0.48913575253109154, 1}, {}], 
        AncestralLineage[ 
        8, {1.5581431051287236, 1.6553683776658581}, {{a, b, c}}, {1}, {}], 
        AncestralLineage[ 
        9, {1.6553683776658581, 1.7278195994170844}, {{a, b, c}, {}}, {
          0.81251054459447569, 1}, {}], 
        AncestralLineage[ 
        10, {1.6553683776658581, 5.8038998031993723}, {{}, {a, b, c}}, {
          0.81251054459447569, 1}, {}], 
        AncestralLineage[ 
        11, {1.7278195994170844, 2.9123438760363545}, {{a, b, c, d}, {d}}, {
          0.81251054459447569, 1}, {}], 
        AncestralLineage[ 
        12, {2.9123438760363545, 3.0510813504782521}, {{a, b, c, d}, {
          d}, {}}, {0.81251054459447569, 0.8211640322266659, 1}, {}], 
        AncestralLineage[ 
        13, {2.9123438760363545, 3.0510813504782521}, {{}, {d}}, {
          0.8211640322266659, 1}, {}], 
        AncestralLineage[ 
        14, {3.0510813504782521, 3.9325181869144528}, {{a, b, c, d}, {d}}, {
          0.81251054459447569, 1}, {}], 
        AncestralLineage[ 
        15, {3.9325181869144528, 4.130798875978213}, {{a, b, c, d}, {}}, {
          0.016431884006824982, 1}, {}], 
        AncestralLineage[ 
        16, {3.9325181869144528, 4.130798875978213}, {{}, {a, b, c, d}, {
          d}}, {0.016431884006824982, 0.81251054459447569, 1}, {}], 
        AncestralLineage[ 
        17, {4.130798875978213, 4.8384282701987225}, {{a, b, c, d}, {d}}, {
          0.81251054459447569, 1}, {}], 
        AncestralLineage[ 
        18, {4.8384282701987225, 4.8664777588817101}, {{a, b, c, d}, {}}, {
          0.74402836827033658, 1}, {}], 
        AncestralLineage[ 
        19, {4.8384282701987225, 4.8664777588817101}, {{}, {a, b, c, d}, {
          d}}, {0.74402836827033658, 0.81251054459447569, 1}, {}], 
        AncestralLineage[ 
        20, {4.8664777588817101, 5.292690316029419}, {{a, b, c, d}, {d}}, {
          0.81251054459447569, 1}, {}], 
        AncestralLineage[ 
        21, {5.292690316029419, 5.3460017684681489}, {{a, b, c, d}, {
          d}, {}}, {0.81251054459447569, 0.92658890242798553, 1}, {}], 
        AncestralLineage[ 
        22, {5.292690316029419, 5.3460017684681489}, {{}, {d}}, {
          0.92658890242798553, 1}, {}], 
        AncestralLineage[ 
        23, {5.3460017684681489, 5.4598714204957677}, {{a, b, c, d}, {d}}, {
          0.81251054459447569, 1}, {}], 
        AncestralLineage[ 
        24, {5.4598714204957677, 5.5362846718122025}, {{a, b, c, d}, {}}, {
          0.37314491294052798, 1}, {}], 
        AncestralLineage[ 25, {5.4598714204957677, 
          DirectedInfinity[ 1]}, {{}, {a, b, c, d}, {d}}, {
          0.37314491294052798, 0.81251054459447569, 1}, {}], 
        AncestralLineage[ 
        26, {5.5362846718122025, 6.0862416755286803}, {{a, b, c, d}, {}}, {
          0.32470788124846017, 1}, {}], 
        AncestralLineage[ 
        27, {5.5362846718122025, 6.2339840341016339}, {{}, {a, b, c, 
          d}, {}}, {0.32470788124846017, 0.37314491294052798, 1}, {}], 
        AncestralLineage[ 
        28, {5.8038998031993723, 6.0862416755286803}, {{}, {a, b, c}, {}}, {
          0.81251054459447569, 0.98211937306245001, 1}, {}], 
        AncestralLineage[ 
        29, {5.8038998031993723, 6.2339840341016339}, {{}, {a, b, c}}, {
          0.98211937306245001, 1}, {}], 
        AncestralLineage[ 
        30, {6.0862416755286803, 6.4486595070917279}, {{a, b, c, d}, {}, {a, 
          b, c}, {}}, {0.32470788124846017, 0.81251054459447569, 
          0.98211937306245001, 1}, {}], 
        AncestralLineage[ 
        31, {6.2339840341016339, 6.4486595070917279}, {{}, {a, b, c, d}, {}, {
          a, b, c}}, {0.32470788124846017, 0.37314491294052798, 
          0.98211937306245001, 1}, {}], 
        AncestralLineage[ 
        32, {6.4486595070917279, 6.4647711086232018}, {{a, b, c, d}, {}, {a, 
          b, c}}, {0.37314491294052798, 0.81251054459447569, 1}, {}], 
        AncestralLineage[ 33, {6.4647711086232018, 
          DirectedInfinity[ 1]}, {{a, b, c, d}, {}}, {0.1338850878429638, 
          1}, {}], 
        AncestralLineage[ 34, {6.4647711086232018, 
          DirectedInfinity[ 1]}, {{}, {a, b, c, d}, {}, {a, b, c}}, {
          0.1338850878429638, 0.37314491294052798, 0.81251054459447569, 
          1}, {}]}],
      Editable->False]], "Print",
  CellLabel->"From In[346]:="],

Cell[BoxData[
    \({0.0580976271395462`, 4, 0.4999999076678714`}\)], "Print",
  CellLabel->"From In[346]:="],

Cell[BoxData[
    InterpretationBox[\("Recombining "\[InvisibleSpace]34\[InvisibleSpace]"; \
current lineages "\[InvisibleSpace]{25, 33, 34}\),
      SequenceForm[ "Recombining ", 34, "; current lineages ", {25, 33, 34}],
      Editable->False]], "Print",
  CellLabel->"From In[346]:="],

Cell[BoxData[
    InterpretationBox[
      RowBox[{"\<\"G=\"\>", "\[InvisibleSpace]", 
        RowBox[{"{", 
          
          RowBox[{\(AncestralLineage[
              a, {0, 0.48529096572278896`}, {{a}}, {1}, {}]\), 
            ",", \(AncestralLineage[
              b, {0, 0.2339831643602032`}, {{b}}, {1}, {}]\), 
            ",", \(AncestralLineage[
              c, {0, 0.48529096572278896`}, {{c}}, {1}, {}]\), 
            ",", \(AncestralLineage[
              d, {0, 1.7278195994170844`}, {{d}}, {1}, {}]\), 
            ",", \(AncestralLineage[
              1, {0.2339831643602032`, 
                0.3223607589398818`}, {{b}, {}}, {0.11492662691806055`, 
                1}, {}]\), 
            ",", \(AncestralLineage[
              2, {0.2339831643602032`, 
                0.3223607589398818`}, {{}, {b}}, {0.11492662691806055`, 
                1}, {}]\), 
            ",", \(AncestralLineage[
              3, {0.3223607589398818`, 0.517863837134862`}, {{b}}, {1}, {}]\),
             ",", \(AncestralLineage[
              4, {0.48529096572278896`, 
                0.517863837134862`}, {{a, c}}, {1}, {}]\), 
            ",", \(AncestralLineage[
              5, {0.517863837134862`, 
                1.5246611785364954`}, {{a, b, c}}, {1}, {}]\), 
            ",", \(AncestralLineage[
              6, {1.5246611785364954`, 
                1.5581431051287236`}, {{a, b, c}, {}}, {0.48913575253109154`, 
                1}, {}]\), 
            ",", \(AncestralLineage[
              7, {1.5246611785364954`, 
                1.5581431051287236`}, {{}, {a, b, c}}, {0.48913575253109154`, 
                1}, {}]\), 
            ",", \(AncestralLineage[
              8, {1.5581431051287236`, 
                1.655368377665858`}, {{a, b, c}}, {1}, {}]\), 
            ",", \(AncestralLineage[
              9, {1.655368377665858`, 
                1.7278195994170844`}, {{a, b, c}, {}}, {0.8125105445944757`, 
                1}, {}]\), 
            ",", \(AncestralLineage[
              10, {1.655368377665858`, 
                5.803899803199372`}, {{}, {a, b, c}}, {0.8125105445944757`, 
                1}, {}]\), 
            ",", \(AncestralLineage[
              11, {1.7278195994170844`, 
                2.9123438760363545`}, {{a, b, c, 
                  d}, {d}}, {0.8125105445944757`, 1}, {}]\), 
            ",", \(AncestralLineage[
              12, {2.9123438760363545`, 
                3.051081350478252`}, {{a, b, c, 
                  d}, {d}, {}}, {0.8125105445944757`, 0.8211640322266659`, 
                1}, {}]\), 
            ",", \(AncestralLineage[
              13, {2.9123438760363545`, 
                3.051081350478252`}, {{}, {d}}, {0.8211640322266659`, 
                1}, {}]\), 
            ",", \(AncestralLineage[
              14, {3.051081350478252`, 
                3.9325181869144528`}, {{a, b, c, 
                  d}, {d}}, {0.8125105445944757`, 1}, {}]\), 
            ",", \(AncestralLineage[
              15, {3.9325181869144528`, 
                4.130798875978213`}, {{a, b, c, 
                  d}, {}}, {0.016431884006824982`, 1}, {}]\), 
            ",", \(AncestralLineage[
              16, {3.9325181869144528`, 
                4.130798875978213`}, {{}, {a, b, c, 
                  d}, {d}}, {0.016431884006824982`, 0.8125105445944757`, 
                1}, {}]\), 
            ",", \(AncestralLineage[
              17, {4.130798875978213`, 
                4.8384282701987225`}, {{a, b, c, 
                  d}, {d}}, {0.8125105445944757`, 1}, {}]\), 
            ",", \(AncestralLineage[
              18, {4.8384282701987225`, 
                4.86647775888171`}, {{a, b, c, d}, {}}, {0.7440283682703366`, 
                1}, {}]\), 
            ",", \(AncestralLineage[
              19, {4.8384282701987225`, 
                4.86647775888171`}, {{}, {a, b, c, 
                  d}, {d}}, {0.7440283682703366`, 0.8125105445944757`, 
                1}, {}]\), 
            ",", \(AncestralLineage[
              20, {4.86647775888171`, 
                5.292690316029419`}, {{a, b, c, 
                  d}, {d}}, {0.8125105445944757`, 1}, {}]\), 
            ",", \(AncestralLineage[
              21, {5.292690316029419`, 
                5.346001768468149`}, {{a, b, c, 
                  d}, {d}, {}}, {0.8125105445944757`, 0.9265889024279855`, 
                1}, {}]\), 
            ",", \(AncestralLineage[
              22, {5.292690316029419`, 
                5.346001768468149`}, {{}, {d}}, {0.9265889024279855`, 
                1}, {}]\), 
            ",", \(AncestralLineage[
              23, {5.346001768468149`, 
                5.459871420495768`}, {{a, b, c, 
                  d}, {d}}, {0.8125105445944757`, 1}, {}]\), 
            ",", \(AncestralLineage[
              24, {5.459871420495768`, 
                5.5362846718122025`}, {{a, b, c, 
                  d}, {}}, {0.373144912940528`, 1}, {}]\), ",", 
            RowBox[{"AncestralLineage", "[", 
              RowBox[{"25", ",", 
                RowBox[{"{", 
                  RowBox[{"5.459871420495768`", ",", 
                    InterpretationBox["\[Infinity]",
                      DirectedInfinity[ 1]]}], "}"}], 
                ",", \({{}, {a, b, c, d}, {d}}\), 
                ",", \({0.373144912940528`, 0.8125105445944757`, 1}\), 
                ",", \({}\)}], "]"}], 
            ",", \(AncestralLineage[
              26, {5.5362846718122025`, 
                6.08624167552868`}, {{a, b, c, d}, {}}, {0.3247078812484602`, 
                1}, {}]\), 
            ",", \(AncestralLineage[
              27, {5.5362846718122025`, 
                6.233984034101634`}, {{}, {a, b, c, 
                  d}, {}}, {0.3247078812484602`, 0.373144912940528`, 
                1}, {}]\), 
            ",", \(AncestralLineage[
              28, {5.803899803199372`, 
                6.08624167552868`}, {{}, {a, b, 
                  c}, {}}, {0.8125105445944757`, 0.98211937306245`, 1}, {}]\),
             ",", \(AncestralLineage[
              29, {5.803899803199372`, 
                6.233984034101634`}, {{}, {a, b, c}}, {0.98211937306245`, 
                1}, {}]\), 
            ",", \(AncestralLineage[
              30, {6.08624167552868`, 
                6.448659507091728`}, {{a, b, c, d}, {}, {a, b, 
                  c}, {}}, {0.3247078812484602`, 0.8125105445944757`, 
                0.98211937306245`, 1}, {}]\), 
            ",", \(AncestralLineage[
              31, {6.233984034101634`, 
                6.448659507091728`}, {{}, {a, b, c, d}, {}, {a, b, 
                  c}}, {0.3247078812484602`, 0.373144912940528`, 
                0.98211937306245`, 1}, {}]\), 
            ",", \(AncestralLineage[
              32, {6.448659507091728`, 
                6.464771108623202`}, {{a, b, c, d}, {}, {a, b, 
                  c}}, {0.373144912940528`, 0.8125105445944757`, 1}, {}]\), 
            ",", 
            RowBox[{"AncestralLineage", "[", 
              RowBox[{"33", ",", 
                RowBox[{"{", 
                  RowBox[{"6.464771108623202`", ",", 
                    InterpretationBox["\[Infinity]",
                      DirectedInfinity[ 1]]}], "}"}], 
                ",", \({{a, b, c, d}, {}}\), 
                ",", \({0.1338850878429638`, 1}\), ",", \({}\)}], "]"}], 
            ",", \(AncestralLineage[
              34, {6.464771108623202`, 
                6.522868735762748`}, {{}, {a, b, c, d}, {}, {a, b, 
                  c}}, {0.1338850878429638`, 0.373144912940528`, 
                0.8125105445944757`, 1}, {}]\), ",", 
            RowBox[{"AncestralLineage", "[", 
              RowBox[{"35", ",", 
                RowBox[{"{", 
                  RowBox[{"6.522868735762748`", ",", 
                    InterpretationBox["\[Infinity]",
                      DirectedInfinity[ 1]]}], "}"}], 
                ",", \({{}, {a, b, c, d}, {}}\), 
                ",", \({0.1338850878429638`, 0.373144912940528`, 1}\), 
                ",", \({}\)}], "]"}], ",", 
            RowBox[{"AncestralLineage", "[", 
              RowBox[{"36", ",", 
                RowBox[{"{", 
                  RowBox[{"6.522868735762748`", ",", 
                    InterpretationBox["\[Infinity]",
                      DirectedInfinity[ 1]]}], "}"}], 
                ",", \({{}, {a, b, c}}\), ",", \({0.8125105445944757`, 1}\), 
                ",", \({}\)}], "]"}]}], "}"}]}],
      SequenceForm[ "G=", {
        AncestralLineage[ a, {0, 0.48529096572278896}, {{a}}, {1}, {}], 
        AncestralLineage[ b, {0, 0.23398316436020319}, {{b}}, {1}, {}], 
        AncestralLineage[ c, {0, 0.48529096572278896}, {{c}}, {1}, {}], 
        AncestralLineage[ d, {0, 1.7278195994170844}, {{d}}, {1}, {}], 
        AncestralLineage[ 
        1, {0.23398316436020319, 0.32236075893988181}, {{b}, {}}, {
          0.11492662691806055, 1}, {}], 
        AncestralLineage[ 
        2, {0.23398316436020319, 0.32236075893988181}, {{}, {b}}, {
          0.11492662691806055, 1}, {}], 
        AncestralLineage[ 
        3, {0.32236075893988181, 0.51786383713486195}, {{b}}, {1}, {}], 
        AncestralLineage[ 
        4, {0.48529096572278896, 0.51786383713486195}, {{a, c}}, {1}, {}], 
        AncestralLineage[ 
        5, {0.51786383713486195, 1.5246611785364954}, {{a, b, c}}, {1}, {}], 
        AncestralLineage[ 
        6, {1.5246611785364954, 1.5581431051287236}, {{a, b, c}, {}}, {
          0.48913575253109154, 1}, {}], 
        AncestralLineage[ 
        7, {1.5246611785364954, 1.5581431051287236}, {{}, {a, b, c}}, {
          0.48913575253109154, 1}, {}], 
        AncestralLineage[ 
        8, {1.5581431051287236, 1.6553683776658581}, {{a, b, c}}, {1}, {}], 
        AncestralLineage[ 
        9, {1.6553683776658581, 1.7278195994170844}, {{a, b, c}, {}}, {
          0.81251054459447569, 1}, {}], 
        AncestralLineage[ 
        10, {1.6553683776658581, 5.8038998031993723}, {{}, {a, b, c}}, {
          0.81251054459447569, 1}, {}], 
        AncestralLineage[ 
        11, {1.7278195994170844, 2.9123438760363545}, {{a, b, c, d}, {d}}, {
          0.81251054459447569, 1}, {}], 
        AncestralLineage[ 
        12, {2.9123438760363545, 3.0510813504782521}, {{a, b, c, d}, {
          d}, {}}, {0.81251054459447569, 0.8211640322266659, 1}, {}], 
        AncestralLineage[ 
        13, {2.9123438760363545, 3.0510813504782521}, {{}, {d}}, {
          0.8211640322266659, 1}, {}], 
        AncestralLineage[ 
        14, {3.0510813504782521, 3.9325181869144528}, {{a, b, c, d}, {d}}, {
          0.81251054459447569, 1}, {}], 
        AncestralLineage[ 
        15, {3.9325181869144528, 4.130798875978213}, {{a, b, c, d}, {}}, {
          0.016431884006824982, 1}, {}], 
        AncestralLineage[ 
        16, {3.9325181869144528, 4.130798875978213}, {{}, {a, b, c, d}, {
          d}}, {0.016431884006824982, 0.81251054459447569, 1}, {}], 
        AncestralLineage[ 
        17, {4.130798875978213, 4.8384282701987225}, {{a, b, c, d}, {d}}, {
          0.81251054459447569, 1}, {}], 
        AncestralLineage[ 
        18, {4.8384282701987225, 4.8664777588817101}, {{a, b, c, d}, {}}, {
          0.74402836827033658, 1}, {}], 
        AncestralLineage[ 
        19, {4.8384282701987225, 4.8664777588817101}, {{}, {a, b, c, d}, {
          d}}, {0.74402836827033658, 0.81251054459447569, 1}, {}], 
        AncestralLineage[ 
        20, {4.8664777588817101, 5.292690316029419}, {{a, b, c, d}, {d}}, {
          0.81251054459447569, 1}, {}], 
        AncestralLineage[ 
        21, {5.292690316029419, 5.3460017684681489}, {{a, b, c, d}, {
          d}, {}}, {0.81251054459447569, 0.92658890242798553, 1}, {}], 
        AncestralLineage[ 
        22, {5.292690316029419, 5.3460017684681489}, {{}, {d}}, {
          0.92658890242798553, 1}, {}], 
        AncestralLineage[ 
        23, {5.3460017684681489, 5.4598714204957677}, {{a, b, c, d}, {d}}, {
          0.81251054459447569, 1}, {}], 
        AncestralLineage[ 
        24, {5.4598714204957677, 5.5362846718122025}, {{a, b, c, d}, {}}, {
          0.37314491294052798, 1}, {}], 
        AncestralLineage[ 25, {5.4598714204957677, 
          DirectedInfinity[ 1]}, {{}, {a, b, c, d}, {d}}, {
          0.37314491294052798, 0.81251054459447569, 1}, {}], 
        AncestralLineage[ 
        26, {5.5362846718122025, 6.0862416755286803}, {{a, b, c, d}, {}}, {
          0.32470788124846017, 1}, {}], 
        AncestralLineage[ 
        27, {5.5362846718122025, 6.2339840341016339}, {{}, {a, b, c, 
          d}, {}}, {0.32470788124846017, 0.37314491294052798, 1}, {}], 
        AncestralLineage[ 
        28, {5.8038998031993723, 6.0862416755286803}, {{}, {a, b, c}, {}}, {
          0.81251054459447569, 0.98211937306245001, 1}, {}], 
        AncestralLineage[ 
        29, {5.8038998031993723, 6.2339840341016339}, {{}, {a, b, c}}, {
          0.98211937306245001, 1}, {}], 
        AncestralLineage[ 
        30, {6.0862416755286803, 6.4486595070917279}, {{a, b, c, d}, {}, {a, 
          b, c}, {}}, {0.32470788124846017, 0.81251054459447569, 
          0.98211937306245001, 1}, {}], 
        AncestralLineage[ 
        31, {6.2339840341016339, 6.4486595070917279}, {{}, {a, b, c, d}, {}, {
          a, b, c}}, {0.32470788124846017, 0.37314491294052798, 
          0.98211937306245001, 1}, {}], 
        AncestralLineage[ 
        32, {6.4486595070917279, 6.4647711086232018}, {{a, b, c, d}, {}, {a, 
          b, c}}, {0.37314491294052798, 0.81251054459447569, 1}, {}], 
        AncestralLineage[ 33, {6.4647711086232018, 
          DirectedInfinity[ 1]}, {{a, b, c, d}, {}}, {0.1338850878429638, 
          1}, {}], 
        AncestralLineage[ 
        34, {6.4647711086232018, 6.5228687357627484}, {{}, {a, b, c, d}, {}, {
          a, b, c}}, {0.1338850878429638, 0.37314491294052798, 
          0.81251054459447569, 1}, {}], 
        AncestralLineage[ 35, {6.5228687357627484, 
          DirectedInfinity[ 1]}, {{}, {a, b, c, d}, {}}, {0.1338850878429638, 
          0.37314491294052798, 1}, {}], 
        AncestralLineage[ 36, {6.5228687357627484, 
          DirectedInfinity[ 1]}, {{}, {a, b, c}}, {0.81251054459447569, 
          1}, {}]}],
      Editable->False]], "Print",
  CellLabel->"From In[346]:="],

Cell[BoxData[
    \({0.08597708725611043`, 5, 0.8534254379052089`}\)], "Print",
  CellLabel->"From In[346]:="],

Cell[BoxData[
    InterpretationBox[\("Recombining "\[InvisibleSpace]33\[InvisibleSpace]"; \
current lineages "\[InvisibleSpace]{25, 33, 35, 36}\),
      SequenceForm[ 
      "Recombining ", 33, "; current lineages ", {25, 33, 35, 36}],
      Editable->False]], "Print",
  CellLabel->"From In[346]:="],

Cell[BoxData[
    InterpretationBox[
      RowBox[{"\<\"G=\"\>", "\[InvisibleSpace]", 
        RowBox[{"{", 
          
          RowBox[{\(AncestralLineage[
              a, {0, 0.48529096572278896`}, {{a}}, {1}, {}]\), 
            ",", \(AncestralLineage[
              b, {0, 0.2339831643602032`}, {{b}}, {1}, {}]\), 
            ",", \(AncestralLineage[
              c, {0, 0.48529096572278896`}, {{c}}, {1}, {}]\), 
            ",", \(AncestralLineage[
              d, {0, 1.7278195994170844`}, {{d}}, {1}, {}]\), 
            ",", \(AncestralLineage[
              1, {0.2339831643602032`, 
                0.3223607589398818`}, {{b}, {}}, {0.11492662691806055`, 
                1}, {}]\), 
            ",", \(AncestralLineage[
              2, {0.2339831643602032`, 
                0.3223607589398818`}, {{}, {b}}, {0.11492662691806055`, 
                1}, {}]\), 
            ",", \(AncestralLineage[
              3, {0.3223607589398818`, 0.517863837134862`}, {{b}}, {1}, {}]\),
             ",", \(AncestralLineage[
              4, {0.48529096572278896`, 
                0.517863837134862`}, {{a, c}}, {1}, {}]\), 
            ",", \(AncestralLineage[
              5, {0.517863837134862`, 
                1.5246611785364954`}, {{a, b, c}}, {1}, {}]\), 
            ",", \(AncestralLineage[
              6, {1.5246611785364954`, 
                1.5581431051287236`}, {{a, b, c}, {}}, {0.48913575253109154`, 
                1}, {}]\), 
            ",", \(AncestralLineage[
              7, {1.5246611785364954`, 
                1.5581431051287236`}, {{}, {a, b, c}}, {0.48913575253109154`, 
                1}, {}]\), 
            ",", \(AncestralLineage[
              8, {1.5581431051287236`, 
                1.655368377665858`}, {{a, b, c}}, {1}, {}]\), 
            ",", \(AncestralLineage[
              9, {1.655368377665858`, 
                1.7278195994170844`}, {{a, b, c}, {}}, {0.8125105445944757`, 
                1}, {}]\), 
            ",", \(AncestralLineage[
              10, {1.655368377665858`, 
                5.803899803199372`}, {{}, {a, b, c}}, {0.8125105445944757`, 
                1}, {}]\), 
            ",", \(AncestralLineage[
              11, {1.7278195994170844`, 
                2.9123438760363545`}, {{a, b, c, 
                  d}, {d}}, {0.8125105445944757`, 1}, {}]\), 
            ",", \(AncestralLineage[
              12, {2.9123438760363545`, 
                3.051081350478252`}, {{a, b, c, 
                  d}, {d}, {}}, {0.8125105445944757`, 0.8211640322266659`, 
                1}, {}]\), 
            ",", \(AncestralLineage[
              13, {2.9123438760363545`, 
                3.051081350478252`}, {{}, {d}}, {0.8211640322266659`, 
                1}, {}]\), 
            ",", \(AncestralLineage[
              14, {3.051081350478252`, 
                3.9325181869144528`}, {{a, b, c, 
                  d}, {d}}, {0.8125105445944757`, 1}, {}]\), 
            ",", \(AncestralLineage[
              15, {3.9325181869144528`, 
                4.130798875978213`}, {{a, b, c, 
                  d}, {}}, {0.016431884006824982`, 1}, {}]\), 
            ",", \(AncestralLineage[
              16, {3.9325181869144528`, 
                4.130798875978213`}, {{}, {a, b, c, 
                  d}, {d}}, {0.016431884006824982`, 0.8125105445944757`, 
                1}, {}]\), 
            ",", \(AncestralLineage[
              17, {4.130798875978213`, 
                4.8384282701987225`}, {{a, b, c, 
                  d}, {d}}, {0.8125105445944757`, 1}, {}]\), 
            ",", \(AncestralLineage[
              18, {4.8384282701987225`, 
                4.86647775888171`}, {{a, b, c, d}, {}}, {0.7440283682703366`, 
                1}, {}]\), 
            ",", \(AncestralLineage[
              19, {4.8384282701987225`, 
                4.86647775888171`}, {{}, {a, b, c, 
                  d}, {d}}, {0.7440283682703366`, 0.8125105445944757`, 
                1}, {}]\), 
            ",", \(AncestralLineage[
              20, {4.86647775888171`, 
                5.292690316029419`}, {{a, b, c, 
                  d}, {d}}, {0.8125105445944757`, 1}, {}]\), 
            ",", \(AncestralLineage[
              21, {5.292690316029419`, 
                5.346001768468149`}, {{a, b, c, 
                  d}, {d}, {}}, {0.8125105445944757`, 0.9265889024279855`, 
                1}, {}]\), 
            ",", \(AncestralLineage[
              22, {5.292690316029419`, 
                5.346001768468149`}, {{}, {d}}, {0.9265889024279855`, 
                1}, {}]\), 
            ",", \(AncestralLineage[
              23, {5.346001768468149`, 
                5.459871420495768`}, {{a, b, c, 
                  d}, {d}}, {0.8125105445944757`, 1}, {}]\), 
            ",", \(AncestralLineage[
              24, {5.459871420495768`, 
                5.5362846718122025`}, {{a, b, c, 
                  d}, {}}, {0.373144912940528`, 1}, {}]\), ",", 
            RowBox[{"AncestralLineage", "[", 
              RowBox[{"25", ",", 
                RowBox[{"{", 
                  RowBox[{"5.459871420495768`", ",", 
                    InterpretationBox["\[Infinity]",
                      DirectedInfinity[ 1]]}], "}"}], 
                ",", \({{}, {a, b, c, d}, {d}}\), 
                ",", \({0.373144912940528`, 0.8125105445944757`, 1}\), 
                ",", \({}\)}], "]"}], 
            ",", \(AncestralLineage[
              26, {5.5362846718122025`, 
                6.08624167552868`}, {{a, b, c, d}, {}}, {0.3247078812484602`, 
                1}, {}]\), 
            ",", \(AncestralLineage[
              27, {5.5362846718122025`, 
                6.233984034101634`}, {{}, {a, b, c, 
                  d}, {}}, {0.3247078812484602`, 0.373144912940528`, 
                1}, {}]\), 
            ",", \(AncestralLineage[
              28, {5.803899803199372`, 
                6.08624167552868`}, {{}, {a, b, 
                  c}, {}}, {0.8125105445944757`, 0.98211937306245`, 1}, {}]\),
             ",", \(AncestralLineage[
              29, {5.803899803199372`, 
                6.233984034101634`}, {{}, {a, b, c}}, {0.98211937306245`, 
                1}, {}]\), 
            ",", \(AncestralLineage[
              30, {6.08624167552868`, 
                6.448659507091728`}, {{a, b, c, d}, {}, {a, b, 
                  c}, {}}, {0.3247078812484602`, 0.8125105445944757`, 
                0.98211937306245`, 1}, {}]\), 
            ",", \(AncestralLineage[
              31, {6.233984034101634`, 
                6.448659507091728`}, {{}, {a, b, c, d}, {}, {a, b, 
                  c}}, {0.3247078812484602`, 0.373144912940528`, 
                0.98211937306245`, 1}, {}]\), 
            ",", \(AncestralLineage[
              32, {6.448659507091728`, 
                6.464771108623202`}, {{a, b, c, d}, {}, {a, b, 
                  c}}, {0.373144912940528`, 0.8125105445944757`, 1}, {}]\), 
            ",", 
            RowBox[{"AncestralLineage", "[", 
              RowBox[{"33", ",", 
                RowBox[{"{", 
                  RowBox[{"6.464771108623202`", ",", 
                    InterpretationBox["\[Infinity]",
                      DirectedInfinity[ 1]]}], "}"}], 
                ",", \({{a, b, c, d}, {}}\), 
                ",", \({0.1338850878429638`, 1}\), ",", \({}\)}], "]"}], 
            ",", \(AncestralLineage[
              34, {6.464771108623202`, 
                6.522868735762748`}, {{}, {a, b, c, d}, {}, {a, b, 
                  c}}, {0.1338850878429638`, 0.373144912940528`, 
                0.8125105445944757`, 1}, {}]\), ",", 
            RowBox[{"AncestralLineage", "[", 
              RowBox[{"35", ",", 
                RowBox[{"{", 
                  RowBox[{"6.522868735762748`", ",", 
                    InterpretationBox["\[Infinity]",
                      DirectedInfinity[ 1]]}], "}"}], 
                ",", \({{}, {a, b, c, d}, {}}\), 
                ",", \({0.1338850878429638`, 0.373144912940528`, 1}\), 
                ",", \({}\)}], "]"}], ",", 
            RowBox[{"AncestralLineage", "[", 
              RowBox[{"36", ",", 
                RowBox[{"{", 
                  RowBox[{"6.522868735762748`", ",", 
                    InterpretationBox["\[Infinity]",
                      DirectedInfinity[ 1]]}], "}"}], 
                ",", \({{}, {a, b, c}}\), ",", \({0.8125105445944757`, 1}\), 
                ",", \({}\)}], "]"}]}], "}"}]}],
      SequenceForm[ "G=", {
        AncestralLineage[ a, {0, 0.48529096572278896}, {{a}}, {1}, {}], 
        AncestralLineage[ b, {0, 0.23398316436020319}, {{b}}, {1}, {}], 
        AncestralLineage[ c, {0, 0.48529096572278896}, {{c}}, {1}, {}], 
        AncestralLineage[ d, {0, 1.7278195994170844}, {{d}}, {1}, {}], 
        AncestralLineage[ 
        1, {0.23398316436020319, 0.32236075893988181}, {{b}, {}}, {
          0.11492662691806055, 1}, {}], 
        AncestralLineage[ 
        2, {0.23398316436020319, 0.32236075893988181}, {{}, {b}}, {
          0.11492662691806055, 1}, {}], 
        AncestralLineage[ 
        3, {0.32236075893988181, 0.51786383713486195}, {{b}}, {1}, {}], 
        AncestralLineage[ 
        4, {0.48529096572278896, 0.51786383713486195}, {{a, c}}, {1}, {}], 
        AncestralLineage[ 
        5, {0.51786383713486195, 1.5246611785364954}, {{a, b, c}}, {1}, {}], 
        AncestralLineage[ 
        6, {1.5246611785364954, 1.5581431051287236}, {{a, b, c}, {}}, {
          0.48913575253109154, 1}, {}], 
        AncestralLineage[ 
        7, {1.5246611785364954, 1.5581431051287236}, {{}, {a, b, c}}, {
          0.48913575253109154, 1}, {}], 
        AncestralLineage[ 
        8, {1.5581431051287236, 1.6553683776658581}, {{a, b, c}}, {1}, {}], 
        AncestralLineage[ 
        9, {1.6553683776658581, 1.7278195994170844}, {{a, b, c}, {}}, {
          0.81251054459447569, 1}, {}], 
        AncestralLineage[ 
        10, {1.6553683776658581, 5.8038998031993723}, {{}, {a, b, c}}, {
          0.81251054459447569, 1}, {}], 
        AncestralLineage[ 
        11, {1.7278195994170844, 2.9123438760363545}, {{a, b, c, d}, {d}}, {
          0.81251054459447569, 1}, {}], 
        AncestralLineage[ 
        12, {2.9123438760363545, 3.0510813504782521}, {{a, b, c, d}, {
          d}, {}}, {0.81251054459447569, 0.8211640322266659, 1}, {}], 
        AncestralLineage[ 
        13, {2.9123438760363545, 3.0510813504782521}, {{}, {d}}, {
          0.8211640322266659, 1}, {}], 
        AncestralLineage[ 
        14, {3.0510813504782521, 3.9325181869144528}, {{a, b, c, d}, {d}}, {
          0.81251054459447569, 1}, {}], 
        AncestralLineage[ 
        15, {3.9325181869144528, 4.130798875978213}, {{a, b, c, d}, {}}, {
          0.016431884006824982, 1}, {}], 
        AncestralLineage[ 
        16, {3.9325181869144528, 4.130798875978213}, {{}, {a, b, c, d}, {
          d}}, {0.016431884006824982, 0.81251054459447569, 1}, {}], 
        AncestralLineage[ 
        17, {4.130798875978213, 4.8384282701987225}, {{a, b, c, d}, {d}}, {
          0.81251054459447569, 1}, {}], 
        AncestralLineage[ 
        18, {4.8384282701987225, 4.8664777588817101}, {{a, b, c, d}, {}}, {
          0.74402836827033658, 1}, {}], 
        AncestralLineage[ 
        19, {4.8384282701987225, 4.8664777588817101}, {{}, {a, b, c, d}, {
          d}}, {0.74402836827033658, 0.81251054459447569, 1}, {}], 
        AncestralLineage[ 
        20, {4.8664777588817101, 5.292690316029419}, {{a, b, c, d}, {d}}, {
          0.81251054459447569, 1}, {}], 
        AncestralLineage[ 
        21, {5.292690316029419, 5.3460017684681489}, {{a, b, c, d}, {
          d}, {}}, {0.81251054459447569, 0.92658890242798553, 1}, {}], 
        AncestralLineage[ 
        22, {5.292690316029419, 5.3460017684681489}, {{}, {d}}, {
          0.92658890242798553, 1}, {}], 
        AncestralLineage[ 
        23, {5.3460017684681489, 5.4598714204957677}, {{a, b, c, d}, {d}}, {
          0.81251054459447569, 1}, {}], 
        AncestralLineage[ 
        24, {5.4598714204957677, 5.5362846718122025}, {{a, b, c, d}, {}}, {
          0.37314491294052798, 1}, {}], 
        AncestralLineage[ 25, {5.4598714204957677, 
          DirectedInfinity[ 1]}, {{}, {a, b, c, d}, {d}}, {
          0.37314491294052798, 0.81251054459447569, 1}, {}], 
        AncestralLineage[ 
        26, {5.5362846718122025, 6.0862416755286803}, {{a, b, c, d}, {}}, {
          0.32470788124846017, 1}, {}], 
        AncestralLineage[ 
        27, {5.5362846718122025, 6.2339840341016339}, {{}, {a, b, c, 
          d}, {}}, {0.32470788124846017, 0.37314491294052798, 1}, {}], 
        AncestralLineage[ 
        28, {5.8038998031993723, 6.0862416755286803}, {{}, {a, b, c}, {}}, {
          0.81251054459447569, 0.98211937306245001, 1}, {}], 
        AncestralLineage[ 
        29, {5.8038998031993723, 6.2339840341016339}, {{}, {a, b, c}}, {
          0.98211937306245001, 1}, {}], 
        AncestralLineage[ 
        30, {6.0862416755286803, 6.4486595070917279}, {{a, b, c, d}, {}, {a, 
          b, c}, {}}, {0.32470788124846017, 0.81251054459447569, 
          0.98211937306245001, 1}, {}], 
        AncestralLineage[ 
        31, {6.2339840341016339, 6.4486595070917279}, {{}, {a, b, c, d}, {}, {
          a, b, c}}, {0.32470788124846017, 0.37314491294052798, 
          0.98211937306245001, 1}, {}], 
        AncestralLineage[ 
        32, {6.4486595070917279, 6.4647711086232018}, {{a, b, c, d}, {}, {a, 
          b, c}}, {0.37314491294052798, 0.81251054459447569, 1}, {}], 
        AncestralLineage[ 33, {6.4647711086232018, 
          DirectedInfinity[ 1]}, {{a, b, c, d}, {}}, {0.1338850878429638, 
          1}, {}], 
        AncestralLineage[ 
        34, {6.4647711086232018, 6.5228687357627484}, {{}, {a, b, c, d}, {}, {
          a, b, c}}, {0.1338850878429638, 0.37314491294052798, 
          0.81251054459447569, 1}, {}], 
        AncestralLineage[ 35, {6.5228687357627484, 
          DirectedInfinity[ 1]}, {{}, {a, b, c, d}, {}}, {0.1338850878429638, 
          0.37314491294052798, 1}, {}], 
        AncestralLineage[ 36, {6.5228687357627484, 
          DirectedInfinity[ 1]}, {{}, {a, b, c}}, {0.81251054459447569, 
          1}, {}]}],
      Editable->False]], "Print",
  CellLabel->"From In[346]:="],

Cell[BoxData[
    \({0.014184508981839403`, 5, 0.03983774434351314`}\)], "Print",
  CellLabel->"From In[346]:="],

Cell[BoxData[
    InterpretationBox[\("Recombining "\[InvisibleSpace]35\[InvisibleSpace]"; \
current lineages "\[InvisibleSpace]{25, 33, 35, 36}\),
      SequenceForm[ 
      "Recombining ", 35, "; current lineages ", {25, 33, 35, 36}],
      Editable->False]], "Print",
  CellLabel->"From In[346]:="],

Cell[BoxData[
    InterpretationBox[
      RowBox[{"\<\"G=\"\>", "\[InvisibleSpace]", 
        RowBox[{"{", 
          
          RowBox[{\(AncestralLineage[
              a, {0, 0.48529096572278896`}, {{a}}, {1}, {}]\), 
            ",", \(AncestralLineage[
              b, {0, 0.2339831643602032`}, {{b}}, {1}, {}]\), 
            ",", \(AncestralLineage[
              c, {0, 0.48529096572278896`}, {{c}}, {1}, {}]\), 
            ",", \(AncestralLineage[
              d, {0, 1.7278195994170844`}, {{d}}, {1}, {}]\), 
            ",", \(AncestralLineage[
              1, {0.2339831643602032`, 
                0.3223607589398818`}, {{b}, {}}, {0.11492662691806055`, 
                1}, {}]\), 
            ",", \(AncestralLineage[
              2, {0.2339831643602032`, 
                0.3223607589398818`}, {{}, {b}}, {0.11492662691806055`, 
                1}, {}]\), 
            ",", \(AncestralLineage[
              3, {0.3223607589398818`, 0.517863837134862`}, {{b}}, {1}, {}]\),
             ",", \(AncestralLineage[
              4, {0.48529096572278896`, 
                0.517863837134862`}, {{a, c}}, {1}, {}]\), 
            ",", \(AncestralLineage[
              5, {0.517863837134862`, 
                1.5246611785364954`}, {{a, b, c}}, {1}, {}]\), 
            ",", \(AncestralLineage[
              6, {1.5246611785364954`, 
                1.5581431051287236`}, {{a, b, c}, {}}, {0.48913575253109154`, 
                1}, {}]\), 
            ",", \(AncestralLineage[
              7, {1.5246611785364954`, 
                1.5581431051287236`}, {{}, {a, b, c}}, {0.48913575253109154`, 
                1}, {}]\), 
            ",", \(AncestralLineage[
              8, {1.5581431051287236`, 
                1.655368377665858`}, {{a, b, c}}, {1}, {}]\), 
            ",", \(AncestralLineage[
              9, {1.655368377665858`, 
                1.7278195994170844`}, {{a, b, c}, {}}, {0.8125105445944757`, 
                1}, {}]\), 
            ",", \(AncestralLineage[
              10, {1.655368377665858`, 
                5.803899803199372`}, {{}, {a, b, c}}, {0.8125105445944757`, 
                1}, {}]\), 
            ",", \(AncestralLineage[
              11, {1.7278195994170844`, 
                2.9123438760363545`}, {{a, b, c, 
                  d}, {d}}, {0.8125105445944757`, 1}, {}]\), 
            ",", \(AncestralLineage[
              12, {2.9123438760363545`, 
                3.051081350478252`}, {{a, b, c, 
                  d}, {d}, {}}, {0.8125105445944757`, 0.8211640322266659`, 
                1}, {}]\), 
            ",", \(AncestralLineage[
              13, {2.9123438760363545`, 
                3.051081350478252`}, {{}, {d}}, {0.8211640322266659`, 
                1}, {}]\), 
            ",", \(AncestralLineage[
              14, {3.051081350478252`, 
                3.9325181869144528`}, {{a, b, c, 
                  d}, {d}}, {0.8125105445944757`, 1}, {}]\), 
            ",", \(AncestralLineage[
              15, {3.9325181869144528`, 
                4.130798875978213`}, {{a, b, c, 
                  d}, {}}, {0.016431884006824982`, 1}, {}]\), 
            ",", \(AncestralLineage[
              16, {3.9325181869144528`, 
                4.130798875978213`}, {{}, {a, b, c, 
                  d}, {d}}, {0.016431884006824982`, 0.8125105445944757`, 
                1}, {}]\), 
            ",", \(AncestralLineage[
              17, {4.130798875978213`, 
                4.8384282701987225`}, {{a, b, c, 
                  d}, {d}}, {0.8125105445944757`, 1}, {}]\), 
            ",", \(AncestralLineage[
              18, {4.8384282701987225`, 
                4.86647775888171`}, {{a, b, c, d}, {}}, {0.7440283682703366`, 
                1}, {}]\), 
            ",", \(AncestralLineage[
              19, {4.8384282701987225`, 
                4.86647775888171`}, {{}, {a, b, c, 
                  d}, {d}}, {0.7440283682703366`, 0.8125105445944757`, 
                1}, {}]\), 
            ",", \(AncestralLineage[
              20, {4.86647775888171`, 
                5.292690316029419`}, {{a, b, c, 
                  d}, {d}}, {0.8125105445944757`, 1}, {}]\), 
            ",", \(AncestralLineage[
              21, {5.292690316029419`, 
                5.346001768468149`}, {{a, b, c, 
                  d}, {d}, {}}, {0.8125105445944757`, 0.9265889024279855`, 
                1}, {}]\), 
            ",", \(AncestralLineage[
              22, {5.292690316029419`, 
                5.346001768468149`}, {{}, {d}}, {0.9265889024279855`, 
                1}, {}]\), 
            ",", \(AncestralLineage[
              23, {5.346001768468149`, 
                5.459871420495768`}, {{a, b, c, 
                  d}, {d}}, {0.8125105445944757`, 1}, {}]\), 
            ",", \(AncestralLineage[
              24, {5.459871420495768`, 
                5.5362846718122025`}, {{a, b, c, 
                  d}, {}}, {0.373144912940528`, 1}, {}]\), ",", 
            RowBox[{"AncestralLineage", "[", 
              RowBox[{"25", ",", 
                RowBox[{"{", 
                  RowBox[{"5.459871420495768`", ",", 
                    InterpretationBox["\[Infinity]",
                      DirectedInfinity[ 1]]}], "}"}], 
                ",", \({{}, {a, b, c, d}, {d}}\), 
                ",", \({0.373144912940528`, 0.8125105445944757`, 1}\), 
                ",", \({}\)}], "]"}], 
            ",", \(AncestralLineage[
              26, {5.5362846718122025`, 
                6.08624167552868`}, {{a, b, c, d}, {}}, {0.3247078812484602`, 
                1}, {}]\), 
            ",", \(AncestralLineage[
              27, {5.5362846718122025`, 
                6.233984034101634`}, {{}, {a, b, c, 
                  d}, {}}, {0.3247078812484602`, 0.373144912940528`, 
                1}, {}]\), 
            ",", \(AncestralLineage[
              28, {5.803899803199372`, 
                6.08624167552868`}, {{}, {a, b, 
                  c}, {}}, {0.8125105445944757`, 0.98211937306245`, 1}, {}]\),
             ",", \(AncestralLineage[
              29, {5.803899803199372`, 
                6.233984034101634`}, {{}, {a, b, c}}, {0.98211937306245`, 
                1}, {}]\), 
            ",", \(AncestralLineage[
              30, {6.08624167552868`, 
                6.448659507091728`}, {{a, b, c, d}, {}, {a, b, 
                  c}, {}}, {0.3247078812484602`, 0.8125105445944757`, 
                0.98211937306245`, 1}, {}]\), 
            ",", \(AncestralLineage[
              31, {6.233984034101634`, 
                6.448659507091728`}, {{}, {a, b, c, d}, {}, {a, b, 
                  c}}, {0.3247078812484602`, 0.373144912940528`, 
                0.98211937306245`, 1}, {}]\), 
            ",", \(AncestralLineage[
              32, {6.448659507091728`, 
                6.464771108623202`}, {{a, b, c, d}, {}, {a, b, 
                  c}}, {0.373144912940528`, 0.8125105445944757`, 1}, {}]\), 
            ",", 
            RowBox[{"AncestralLineage", "[", 
              RowBox[{"33", ",", 
                RowBox[{"{", 
                  RowBox[{"6.464771108623202`", ",", 
                    InterpretationBox["\[Infinity]",
                      DirectedInfinity[ 1]]}], "}"}], 
                ",", \({{a, b, c, d}, {}}\), 
                ",", \({0.1338850878429638`, 1}\), ",", \({}\)}], "]"}], 
            ",", \(AncestralLineage[
              34, {6.464771108623202`, 
                6.522868735762748`}, {{}, {a, b, c, d}, {}, {a, b, 
                  c}}, {0.1338850878429638`, 0.373144912940528`, 
                0.8125105445944757`, 1}, {}]\), ",", 
            RowBox[{"AncestralLineage", "[", 
              RowBox[{"35", ",", 
                RowBox[{"{", 
                  RowBox[{"6.522868735762748`", ",", 
                    InterpretationBox["\[Infinity]",
                      DirectedInfinity[ 1]]}], "}"}], 
                ",", \({{}, {a, b, c, d}, {}}\), 
                ",", \({0.1338850878429638`, 0.373144912940528`, 1}\), 
                ",", \({}\)}], "]"}], ",", 
            RowBox[{"AncestralLineage", "[", 
              RowBox[{"36", ",", 
                RowBox[{"{", 
                  RowBox[{"6.522868735762748`", ",", 
                    InterpretationBox["\[Infinity]",
                      DirectedInfinity[ 1]]}], "}"}], 
                ",", \({{}, {a, b, c}}\), ",", \({0.8125105445944757`, 1}\), 
                ",", \({}\)}], "]"}]}], "}"}]}],
      SequenceForm[ "G=", {
        AncestralLineage[ a, {0, 0.48529096572278896}, {{a}}, {1}, {}], 
        AncestralLineage[ b, {0, 0.23398316436020319}, {{b}}, {1}, {}], 
        AncestralLineage[ c, {0, 0.48529096572278896}, {{c}}, {1}, {}], 
        AncestralLineage[ d, {0, 1.7278195994170844}, {{d}}, {1}, {}], 
        AncestralLineage[ 
        1, {0.23398316436020319, 0.32236075893988181}, {{b}, {}}, {
          0.11492662691806055, 1}, {}], 
        AncestralLineage[ 
        2, {0.23398316436020319, 0.32236075893988181}, {{}, {b}}, {
          0.11492662691806055, 1}, {}], 
        AncestralLineage[ 
        3, {0.32236075893988181, 0.51786383713486195}, {{b}}, {1}, {}], 
        AncestralLineage[ 
        4, {0.48529096572278896, 0.51786383713486195}, {{a, c}}, {1}, {}], 
        AncestralLineage[ 
        5, {0.51786383713486195, 1.5246611785364954}, {{a, b, c}}, {1}, {}], 
        AncestralLineage[ 
        6, {1.5246611785364954, 1.5581431051287236}, {{a, b, c}, {}}, {
          0.48913575253109154, 1}, {}], 
        AncestralLineage[ 
        7, {1.5246611785364954, 1.5581431051287236}, {{}, {a, b, c}}, {
          0.48913575253109154, 1}, {}], 
        AncestralLineage[ 
        8, {1.5581431051287236, 1.6553683776658581}, {{a, b, c}}, {1}, {}], 
        AncestralLineage[ 
        9, {1.6553683776658581, 1.7278195994170844}, {{a, b, c}, {}}, {
          0.81251054459447569, 1}, {}], 
        AncestralLineage[ 
        10, {1.6553683776658581, 5.8038998031993723}, {{}, {a, b, c}}, {
          0.81251054459447569, 1}, {}], 
        AncestralLineage[ 
        11, {1.7278195994170844, 2.9123438760363545}, {{a, b, c, d}, {d}}, {
          0.81251054459447569, 1}, {}], 
        AncestralLineage[ 
        12, {2.9123438760363545, 3.0510813504782521}, {{a, b, c, d}, {
          d}, {}}, {0.81251054459447569, 0.8211640322266659, 1}, {}], 
        AncestralLineage[ 
        13, {2.9123438760363545, 3.0510813504782521}, {{}, {d}}, {
          0.8211640322266659, 1}, {}], 
        AncestralLineage[ 
        14, {3.0510813504782521, 3.9325181869144528}, {{a, b, c, d}, {d}}, {
          0.81251054459447569, 1}, {}], 
        AncestralLineage[ 
        15, {3.9325181869144528, 4.130798875978213}, {{a, b, c, d}, {}}, {
          0.016431884006824982, 1}, {}], 
        AncestralLineage[ 
        16, {3.9325181869144528, 4.130798875978213}, {{}, {a, b, c, d}, {
          d}}, {0.016431884006824982, 0.81251054459447569, 1}, {}], 
        AncestralLineage[ 
        17, {4.130798875978213, 4.8384282701987225}, {{a, b, c, d}, {d}}, {
          0.81251054459447569, 1}, {}], 
        AncestralLineage[ 
        18, {4.8384282701987225, 4.8664777588817101}, {{a, b, c, d}, {}}, {
          0.74402836827033658, 1}, {}], 
        AncestralLineage[ 
        19, {4.8384282701987225, 4.8664777588817101}, {{}, {a, b, c, d}, {
          d}}, {0.74402836827033658, 0.81251054459447569, 1}, {}], 
        AncestralLineage[ 
        20, {4.8664777588817101, 5.292690316029419}, {{a, b, c, d}, {d}}, {
          0.81251054459447569, 1}, {}], 
        AncestralLineage[ 
        21, {5.292690316029419, 5.3460017684681489}, {{a, b, c, d}, {
          d}, {}}, {0.81251054459447569, 0.92658890242798553, 1}, {}], 
        AncestralLineage[ 
        22, {5.292690316029419, 5.3460017684681489}, {{}, {d}}, {
          0.92658890242798553, 1}, {}], 
        AncestralLineage[ 
        23, {5.3460017684681489, 5.4598714204957677}, {{a, b, c, d}, {d}}, {
          0.81251054459447569, 1}, {}], 
        AncestralLineage[ 
        24, {5.4598714204957677, 5.5362846718122025}, {{a, b, c, d}, {}}, {
          0.37314491294052798, 1}, {}], 
        AncestralLineage[ 25, {5.4598714204957677, 
          DirectedInfinity[ 1]}, {{}, {a, b, c, d}, {d}}, {
          0.37314491294052798, 0.81251054459447569, 1}, {}], 
        AncestralLineage[ 
        26, {5.5362846718122025, 6.0862416755286803}, {{a, b, c, d}, {}}, {
          0.32470788124846017, 1}, {}], 
        AncestralLineage[ 
        27, {5.5362846718122025, 6.2339840341016339}, {{}, {a, b, c, 
          d}, {}}, {0.32470788124846017, 0.37314491294052798, 1}, {}], 
        AncestralLineage[ 
        28, {5.8038998031993723, 6.0862416755286803}, {{}, {a, b, c}, {}}, {
          0.81251054459447569, 0.98211937306245001, 1}, {}], 
        AncestralLineage[ 
        29, {5.8038998031993723, 6.2339840341016339}, {{}, {a, b, c}}, {
          0.98211937306245001, 1}, {}], 
        AncestralLineage[ 
        30, {6.0862416755286803, 6.4486595070917279}, {{a, b, c, d}, {}, {a, 
          b, c}, {}}, {0.32470788124846017, 0.81251054459447569, 
          0.98211937306245001, 1}, {}], 
        AncestralLineage[ 
        31, {6.2339840341016339, 6.4486595070917279}, {{}, {a, b, c, d}, {}, {
          a, b, c}}, {0.32470788124846017, 0.37314491294052798, 
          0.98211937306245001, 1}, {}], 
        AncestralLineage[ 
        32, {6.4486595070917279, 6.4647711086232018}, {{a, b, c, d}, {}, {a, 
          b, c}}, {0.37314491294052798, 0.81251054459447569, 1}, {}], 
        AncestralLineage[ 33, {6.4647711086232018, 
          DirectedInfinity[ 1]}, {{a, b, c, d}, {}}, {0.1338850878429638, 
          1}, {}], 
        AncestralLineage[ 
        34, {6.4647711086232018, 6.5228687357627484}, {{}, {a, b, c, d}, {}, {
          a, b, c}}, {0.1338850878429638, 0.37314491294052798, 
          0.81251054459447569, 1}, {}], 
        AncestralLineage[ 35, {6.5228687357627484, 
          DirectedInfinity[ 1]}, {{}, {a, b, c, d}, {}}, {0.1338850878429638, 
          0.37314491294052798, 1}, {}], 
        AncestralLineage[ 36, {6.5228687357627484, 
          DirectedInfinity[ 1]}, {{}, {a, b, c}}, {0.81251054459447569, 
          1}, {}]}],
      Editable->False]], "Print",
  CellLabel->"From In[346]:="],

Cell[BoxData[
    \({0.024258392524260024`, 3, None}\)], "Print",
  CellLabel->"From In[346]:="],

Cell[BoxData[
    InterpretationBox[\("Coalescing "\[InvisibleSpace]{33, 
          36}\[InvisibleSpace]"; current lineages "\[InvisibleSpace]{25, 33, 
          35, 36}\),
      SequenceForm[ 
      "Coalescing ", {33, 36}, "; current lineages ", {25, 33, 35, 36}],
      Editable->False]], "Print",
  CellLabel->"From In[346]:="],

Cell[BoxData[
    InterpretationBox[
      RowBox[{"\<\"G=\"\>", "\[InvisibleSpace]", 
        RowBox[{"{", 
          
          RowBox[{\(AncestralLineage[
              a, {0, 0.48529096572278896`}, {{a}}, {1}, {}]\), 
            ",", \(AncestralLineage[
              b, {0, 0.2339831643602032`}, {{b}}, {1}, {}]\), 
            ",", \(AncestralLineage[
              c, {0, 0.48529096572278896`}, {{c}}, {1}, {}]\), 
            ",", \(AncestralLineage[
              d, {0, 1.7278195994170844`}, {{d}}, {1}, {}]\), 
            ",", \(AncestralLineage[
              1, {0.2339831643602032`, 
                0.3223607589398818`}, {{b}, {}}, {0.11492662691806055`, 
                1}, {}]\), 
            ",", \(AncestralLineage[
              2, {0.2339831643602032`, 
                0.3223607589398818`}, {{}, {b}}, {0.11492662691806055`, 
                1}, {}]\), 
            ",", \(AncestralLineage[
              3, {0.3223607589398818`, 0.517863837134862`}, {{b}}, {1}, {}]\),
             ",", \(AncestralLineage[
              4, {0.48529096572278896`, 
                0.517863837134862`}, {{a, c}}, {1}, {}]\), 
            ",", \(AncestralLineage[
              5, {0.517863837134862`, 
                1.5246611785364954`}, {{a, b, c}}, {1}, {}]\), 
            ",", \(AncestralLineage[
              6, {1.5246611785364954`, 
                1.5581431051287236`}, {{a, b, c}, {}}, {0.48913575253109154`, 
                1}, {}]\), 
            ",", \(AncestralLineage[
              7, {1.5246611785364954`, 
                1.5581431051287236`}, {{}, {a, b, c}}, {0.48913575253109154`, 
                1}, {}]\), 
            ",", \(AncestralLineage[
              8, {1.5581431051287236`, 
                1.655368377665858`}, {{a, b, c}}, {1}, {}]\), 
            ",", \(AncestralLineage[
              9, {1.655368377665858`, 
                1.7278195994170844`}, {{a, b, c}, {}}, {0.8125105445944757`, 
                1}, {}]\), 
            ",", \(AncestralLineage[
              10, {1.655368377665858`, 
                5.803899803199372`}, {{}, {a, b, c}}, {0.8125105445944757`, 
                1}, {}]\), 
            ",", \(AncestralLineage[
              11, {1.7278195994170844`, 
                2.9123438760363545`}, {{a, b, c, 
                  d}, {d}}, {0.8125105445944757`, 1}, {}]\), 
            ",", \(AncestralLineage[
              12, {2.9123438760363545`, 
                3.051081350478252`}, {{a, b, c, 
                  d}, {d}, {}}, {0.8125105445944757`, 0.8211640322266659`, 
                1}, {}]\), 
            ",", \(AncestralLineage[
              13, {2.9123438760363545`, 
                3.051081350478252`}, {{}, {d}}, {0.8211640322266659`, 
                1}, {}]\), 
            ",", \(AncestralLineage[
              14, {3.051081350478252`, 
                3.9325181869144528`}, {{a, b, c, 
                  d}, {d}}, {0.8125105445944757`, 1}, {}]\), 
            ",", \(AncestralLineage[
              15, {3.9325181869144528`, 
                4.130798875978213`}, {{a, b, c, 
                  d}, {}}, {0.016431884006824982`, 1}, {}]\), 
            ",", \(AncestralLineage[
              16, {3.9325181869144528`, 
                4.130798875978213`}, {{}, {a, b, c, 
                  d}, {d}}, {0.016431884006824982`, 0.8125105445944757`, 
                1}, {}]\), 
            ",", \(AncestralLineage[
              17, {4.130798875978213`, 
                4.8384282701987225`}, {{a, b, c, 
                  d}, {d}}, {0.8125105445944757`, 1}, {}]\), 
            ",", \(AncestralLineage[
              18, {4.8384282701987225`, 
                4.86647775888171`}, {{a, b, c, d}, {}}, {0.7440283682703366`, 
                1}, {}]\), 
            ",", \(AncestralLineage[
              19, {4.8384282701987225`, 
                4.86647775888171`}, {{}, {a, b, c, 
                  d}, {d}}, {0.7440283682703366`, 0.8125105445944757`, 
                1}, {}]\), 
            ",", \(AncestralLineage[
              20, {4.86647775888171`, 
                5.292690316029419`}, {{a, b, c, 
                  d}, {d}}, {0.8125105445944757`, 1}, {}]\), 
            ",", \(AncestralLineage[
              21, {5.292690316029419`, 
                5.346001768468149`}, {{a, b, c, 
                  d}, {d}, {}}, {0.8125105445944757`, 0.9265889024279855`, 
                1}, {}]\), 
            ",", \(AncestralLineage[
              22, {5.292690316029419`, 
                5.346001768468149`}, {{}, {d}}, {0.9265889024279855`, 
                1}, {}]\), 
            ",", \(AncestralLineage[
              23, {5.346001768468149`, 
                5.459871420495768`}, {{a, b, c, 
                  d}, {d}}, {0.8125105445944757`, 1}, {}]\), 
            ",", \(AncestralLineage[
              24, {5.459871420495768`, 
                5.5362846718122025`}, {{a, b, c, 
                  d}, {}}, {0.373144912940528`, 1}, {}]\), ",", 
            RowBox[{"AncestralLineage", "[", 
              RowBox[{"25", ",", 
                RowBox[{"{", 
                  RowBox[{"5.459871420495768`", ",", 
                    InterpretationBox["\[Infinity]",
                      DirectedInfinity[ 1]]}], "}"}], 
                ",", \({{}, {a, b, c, d}, {d}}\), 
                ",", \({0.373144912940528`, 0.8125105445944757`, 1}\), 
                ",", \({}\)}], "]"}], 
            ",", \(AncestralLineage[
              26, {5.5362846718122025`, 
                6.08624167552868`}, {{a, b, c, d}, {}}, {0.3247078812484602`, 
                1}, {}]\), 
            ",", \(AncestralLineage[
              27, {5.5362846718122025`, 
                6.233984034101634`}, {{}, {a, b, c, 
                  d}, {}}, {0.3247078812484602`, 0.373144912940528`, 
                1}, {}]\), 
            ",", \(AncestralLineage[
              28, {5.803899803199372`, 
                6.08624167552868`}, {{}, {a, b, 
                  c}, {}}, {0.8125105445944757`, 0.98211937306245`, 1}, {}]\),
             ",", \(AncestralLineage[
              29, {5.803899803199372`, 
                6.233984034101634`}, {{}, {a, b, c}}, {0.98211937306245`, 
                1}, {}]\), 
            ",", \(AncestralLineage[
              30, {6.08624167552868`, 
                6.448659507091728`}, {{a, b, c, d}, {}, {a, b, 
                  c}, {}}, {0.3247078812484602`, 0.8125105445944757`, 
                0.98211937306245`, 1}, {}]\), 
            ",", \(AncestralLineage[
              31, {6.233984034101634`, 
                6.448659507091728`}, {{}, {a, b, c, d}, {}, {a, b, 
                  c}}, {0.3247078812484602`, 0.373144912940528`, 
                0.98211937306245`, 1}, {}]\), 
            ",", \(AncestralLineage[
              32, {6.448659507091728`, 
                6.464771108623202`}, {{a, b, c, d}, {}, {a, b, 
                  c}}, {0.373144912940528`, 0.8125105445944757`, 1}, {}]\), 
            ",", \(AncestralLineage[
              33, {6.464771108623202`, 
                6.647288724524958`}, {{a, b, c, 
                  d}, {}}, {0.1338850878429638`, 1}, {}]\), 
            ",", \(AncestralLineage[
              34, {6.464771108623202`, 
                6.522868735762748`}, {{}, {a, b, c, d}, {}, {a, b, 
                  c}}, {0.1338850878429638`, 0.373144912940528`, 
                0.8125105445944757`, 1}, {}]\), ",", 
            RowBox[{"AncestralLineage", "[", 
              RowBox[{"35", ",", 
                RowBox[{"{", 
                  RowBox[{"6.522868735762748`", ",", 
                    InterpretationBox["\[Infinity]",
                      DirectedInfinity[ 1]]}], "}"}], 
                ",", \({{}, {a, b, c, d}, {}}\), 
                ",", \({0.1338850878429638`, 0.373144912940528`, 1}\), 
                ",", \({}\)}], "]"}], 
            ",", \(AncestralLineage[
              36, {6.522868735762748`, 
                6.647288724524958`}, {{}, {a, b, c}}, {0.8125105445944757`, 
                1}, {}]\), ",", 
            RowBox[{"AncestralLineage", "[", 
              RowBox[{"37", ",", 
                RowBox[{"{", 
                  RowBox[{"6.647288724524958`", ",", 
                    InterpretationBox["\[Infinity]",
                      DirectedInfinity[ 1]]}], "}"}], 
                ",", \({{a, b, c, d}, {}, {a, b, c}}\), 
                ",", \({0.1338850878429638`, 0.8125105445944757`, 1}\), 
                ",", \({}\)}], "]"}]}], "}"}]}],
      SequenceForm[ "G=", {
        AncestralLineage[ a, {0, 0.48529096572278896}, {{a}}, {1}, {}], 
        AncestralLineage[ b, {0, 0.23398316436020319}, {{b}}, {1}, {}], 
        AncestralLineage[ c, {0, 0.48529096572278896}, {{c}}, {1}, {}], 
        AncestralLineage[ d, {0, 1.7278195994170844}, {{d}}, {1}, {}], 
        AncestralLineage[ 
        1, {0.23398316436020319, 0.32236075893988181}, {{b}, {}}, {
          0.11492662691806055, 1}, {}], 
        AncestralLineage[ 
        2, {0.23398316436020319, 0.32236075893988181}, {{}, {b}}, {
          0.11492662691806055, 1}, {}], 
        AncestralLineage[ 
        3, {0.32236075893988181, 0.51786383713486195}, {{b}}, {1}, {}], 
        AncestralLineage[ 
        4, {0.48529096572278896, 0.51786383713486195}, {{a, c}}, {1}, {}], 
        AncestralLineage[ 
        5, {0.51786383713486195, 1.5246611785364954}, {{a, b, c}}, {1}, {}], 
        AncestralLineage[ 
        6, {1.5246611785364954, 1.5581431051287236}, {{a, b, c}, {}}, {
          0.48913575253109154, 1}, {}], 
        AncestralLineage[ 
        7, {1.5246611785364954, 1.5581431051287236}, {{}, {a, b, c}}, {
          0.48913575253109154, 1}, {}], 
        AncestralLineage[ 
        8, {1.5581431051287236, 1.6553683776658581}, {{a, b, c}}, {1}, {}], 
        AncestralLineage[ 
        9, {1.6553683776658581, 1.7278195994170844}, {{a, b, c}, {}}, {
          0.81251054459447569, 1}, {}], 
        AncestralLineage[ 
        10, {1.6553683776658581, 5.8038998031993723}, {{}, {a, b, c}}, {
          0.81251054459447569, 1}, {}], 
        AncestralLineage[ 
        11, {1.7278195994170844, 2.9123438760363545}, {{a, b, c, d}, {d}}, {
          0.81251054459447569, 1}, {}], 
        AncestralLineage[ 
        12, {2.9123438760363545, 3.0510813504782521}, {{a, b, c, d}, {
          d}, {}}, {0.81251054459447569, 0.8211640322266659, 1}, {}], 
        AncestralLineage[ 
        13, {2.9123438760363545, 3.0510813504782521}, {{}, {d}}, {
          0.8211640322266659, 1}, {}], 
        AncestralLineage[ 
        14, {3.0510813504782521, 3.9325181869144528}, {{a, b, c, d}, {d}}, {
          0.81251054459447569, 1}, {}], 
        AncestralLineage[ 
        15, {3.9325181869144528, 4.130798875978213}, {{a, b, c, d}, {}}, {
          0.016431884006824982, 1}, {}], 
        AncestralLineage[ 
        16, {3.9325181869144528, 4.130798875978213}, {{}, {a, b, c, d}, {
          d}}, {0.016431884006824982, 0.81251054459447569, 1}, {}], 
        AncestralLineage[ 
        17, {4.130798875978213, 4.8384282701987225}, {{a, b, c, d}, {d}}, {
          0.81251054459447569, 1}, {}], 
        AncestralLineage[ 
        18, {4.8384282701987225, 4.8664777588817101}, {{a, b, c, d}, {}}, {
          0.74402836827033658, 1}, {}], 
        AncestralLineage[ 
        19, {4.8384282701987225, 4.8664777588817101}, {{}, {a, b, c, d}, {
          d}}, {0.74402836827033658, 0.81251054459447569, 1}, {}], 
        AncestralLineage[ 
        20, {4.8664777588817101, 5.292690316029419}, {{a, b, c, d}, {d}}, {
          0.81251054459447569, 1}, {}], 
        AncestralLineage[ 
        21, {5.292690316029419, 5.3460017684681489}, {{a, b, c, d}, {
          d}, {}}, {0.81251054459447569, 0.92658890242798553, 1}, {}], 
        AncestralLineage[ 
        22, {5.292690316029419, 5.3460017684681489}, {{}, {d}}, {
          0.92658890242798553, 1}, {}], 
        AncestralLineage[ 
        23, {5.3460017684681489, 5.4598714204957677}, {{a, b, c, d}, {d}}, {
          0.81251054459447569, 1}, {}], 
        AncestralLineage[ 
        24, {5.4598714204957677, 5.5362846718122025}, {{a, b, c, d}, {}}, {
          0.37314491294052798, 1}, {}], 
        AncestralLineage[ 25, {5.4598714204957677, 
          DirectedInfinity[ 1]}, {{}, {a, b, c, d}, {d}}, {
          0.37314491294052798, 0.81251054459447569, 1}, {}], 
        AncestralLineage[ 
        26, {5.5362846718122025, 6.0862416755286803}, {{a, b, c, d}, {}}, {
          0.32470788124846017, 1}, {}], 
        AncestralLineage[ 
        27, {5.5362846718122025, 6.2339840341016339}, {{}, {a, b, c, 
          d}, {}}, {0.32470788124846017, 0.37314491294052798, 1}, {}], 
        AncestralLineage[ 
        28, {5.8038998031993723, 6.0862416755286803}, {{}, {a, b, c}, {}}, {
          0.81251054459447569, 0.98211937306245001, 1}, {}], 
        AncestralLineage[ 
        29, {5.8038998031993723, 6.2339840341016339}, {{}, {a, b, c}}, {
          0.98211937306245001, 1}, {}], 
        AncestralLineage[ 
        30, {6.0862416755286803, 6.4486595070917279}, {{a, b, c, d}, {}, {a, 
          b, c}, {}}, {0.32470788124846017, 0.81251054459447569, 
          0.98211937306245001, 1}, {}], 
        AncestralLineage[ 
        31, {6.2339840341016339, 6.4486595070917279}, {{}, {a, b, c, d}, {}, {
          a, b, c}}, {0.32470788124846017, 0.37314491294052798, 
          0.98211937306245001, 1}, {}], 
        AncestralLineage[ 
        32, {6.4486595070917279, 6.4647711086232018}, {{a, b, c, d}, {}, {a, 
          b, c}}, {0.37314491294052798, 0.81251054459447569, 1}, {}], 
        AncestralLineage[ 
        33, {6.4647711086232018, 6.6472887245249579}, {{a, b, c, d}, {}}, {
          0.1338850878429638, 1}, {}], 
        AncestralLineage[ 
        34, {6.4647711086232018, 6.5228687357627484}, {{}, {a, b, c, d}, {}, {
          a, b, c}}, {0.1338850878429638, 0.37314491294052798, 
          0.81251054459447569, 1}, {}], 
        AncestralLineage[ 35, {6.5228687357627484, 
          DirectedInfinity[ 1]}, {{}, {a, b, c, d}, {}}, {0.1338850878429638, 
          0.37314491294052798, 1}, {}], 
        AncestralLineage[ 
        36, {6.5228687357627484, 6.6472887245249579}, {{}, {a, b, c}}, {
          0.81251054459447569, 1}, {}], 
        AncestralLineage[ 37, {6.6472887245249579, 
          DirectedInfinity[ 1]}, {{a, b, c, d}, {}, {a, b, c}}, {
          0.1338850878429638, 0.81251054459447569, 1}, {}]}],
      Editable->False]], "Print",
  CellLabel->"From In[346]:="],

Cell[BoxData[
    \({0.18012798352171866`, 2, None}\)], "Print",
  CellLabel->"From In[346]:="],

Cell[BoxData[
    InterpretationBox[\("Coalescing "\[InvisibleSpace]{25, 
          37}\[InvisibleSpace]"; current lineages "\[InvisibleSpace]{25, 35, 
          37}\),
      SequenceForm[ 
      "Coalescing ", {25, 37}, "; current lineages ", {25, 35, 37}],
      Editable->False]], "Print",
  CellLabel->"From In[346]:="],

Cell[BoxData[
    InterpretationBox[
      RowBox[{"\<\"G=\"\>", "\[InvisibleSpace]", 
        RowBox[{"{", 
          
          RowBox[{\(AncestralLineage[
              a, {0, 0.48529096572278896`}, {{a}}, {1}, {}]\), 
            ",", \(AncestralLineage[
              b, {0, 0.2339831643602032`}, {{b}}, {1}, {}]\), 
            ",", \(AncestralLineage[
              c, {0, 0.48529096572278896`}, {{c}}, {1}, {}]\), 
            ",", \(AncestralLineage[
              d, {0, 1.7278195994170844`}, {{d}}, {1}, {}]\), 
            ",", \(AncestralLineage[
              1, {0.2339831643602032`, 
                0.3223607589398818`}, {{b}, {}}, {0.11492662691806055`, 
                1}, {}]\), 
            ",", \(AncestralLineage[
              2, {0.2339831643602032`, 
                0.3223607589398818`}, {{}, {b}}, {0.11492662691806055`, 
                1}, {}]\), 
            ",", \(AncestralLineage[
              3, {0.3223607589398818`, 0.517863837134862`}, {{b}}, {1}, {}]\),
             ",", \(AncestralLineage[
              4, {0.48529096572278896`, 
                0.517863837134862`}, {{a, c}}, {1}, {}]\), 
            ",", \(AncestralLineage[
              5, {0.517863837134862`, 
                1.5246611785364954`}, {{a, b, c}}, {1}, {}]\), 
            ",", \(AncestralLineage[
              6, {1.5246611785364954`, 
                1.5581431051287236`}, {{a, b, c}, {}}, {0.48913575253109154`, 
                1}, {}]\), 
            ",", \(AncestralLineage[
              7, {1.5246611785364954`, 
                1.5581431051287236`}, {{}, {a, b, c}}, {0.48913575253109154`, 
                1}, {}]\), 
            ",", \(AncestralLineage[
              8, {1.5581431051287236`, 
                1.655368377665858`}, {{a, b, c}}, {1}, {}]\), 
            ",", \(AncestralLineage[
              9, {1.655368377665858`, 
                1.7278195994170844`}, {{a, b, c}, {}}, {0.8125105445944757`, 
                1}, {}]\), 
            ",", \(AncestralLineage[
              10, {1.655368377665858`, 
                5.803899803199372`}, {{}, {a, b, c}}, {0.8125105445944757`, 
                1}, {}]\), 
            ",", \(AncestralLineage[
              11, {1.7278195994170844`, 
                2.9123438760363545`}, {{a, b, c, 
                  d}, {d}}, {0.8125105445944757`, 1}, {}]\), 
            ",", \(AncestralLineage[
              12, {2.9123438760363545`, 
                3.051081350478252`}, {{a, b, c, 
                  d}, {d}, {}}, {0.8125105445944757`, 0.8211640322266659`, 
                1}, {}]\), 
            ",", \(AncestralLineage[
              13, {2.9123438760363545`, 
                3.051081350478252`}, {{}, {d}}, {0.8211640322266659`, 
                1}, {}]\), 
            ",", \(AncestralLineage[
              14, {3.051081350478252`, 
                3.9325181869144528`}, {{a, b, c, 
                  d}, {d}}, {0.8125105445944757`, 1}, {}]\), 
            ",", \(AncestralLineage[
              15, {3.9325181869144528`, 
                4.130798875978213`}, {{a, b, c, 
                  d}, {}}, {0.016431884006824982`, 1}, {}]\), 
            ",", \(AncestralLineage[
              16, {3.9325181869144528`, 
                4.130798875978213`}, {{}, {a, b, c, 
                  d}, {d}}, {0.016431884006824982`, 0.8125105445944757`, 
                1}, {}]\), 
            ",", \(AncestralLineage[
              17, {4.130798875978213`, 
                4.8384282701987225`}, {{a, b, c, 
                  d}, {d}}, {0.8125105445944757`, 1}, {}]\), 
            ",", \(AncestralLineage[
              18, {4.8384282701987225`, 
                4.86647775888171`}, {{a, b, c, d}, {}}, {0.7440283682703366`, 
                1}, {}]\), 
            ",", \(AncestralLineage[
              19, {4.8384282701987225`, 
                4.86647775888171`}, {{}, {a, b, c, 
                  d}, {d}}, {0.7440283682703366`, 0.8125105445944757`, 
                1}, {}]\), 
            ",", \(AncestralLineage[
              20, {4.86647775888171`, 
                5.292690316029419`}, {{a, b, c, 
                  d}, {d}}, {0.8125105445944757`, 1}, {}]\), 
            ",", \(AncestralLineage[
              21, {5.292690316029419`, 
                5.346001768468149`}, {{a, b, c, 
                  d}, {d}, {}}, {0.8125105445944757`, 0.9265889024279855`, 
                1}, {}]\), 
            ",", \(AncestralLineage[
              22, {5.292690316029419`, 
                5.346001768468149`}, {{}, {d}}, {0.9265889024279855`, 
                1}, {}]\), 
            ",", \(AncestralLineage[
              23, {5.346001768468149`, 
                5.459871420495768`}, {{a, b, c, 
                  d}, {d}}, {0.8125105445944757`, 1}, {}]\), 
            ",", \(AncestralLineage[
              24, {5.459871420495768`, 
                5.5362846718122025`}, {{a, b, c, 
                  d}, {}}, {0.373144912940528`, 1}, {}]\), 
            ",", \(AncestralLineage[
              25, {5.459871420495768`, 
                6.827416708046677`}, {{}, {a, b, c, 
                  d}, {d}}, {0.373144912940528`, 0.8125105445944757`, 
                1}, {}]\), 
            ",", \(AncestralLineage[
              26, {5.5362846718122025`, 
                6.08624167552868`}, {{a, b, c, d}, {}}, {0.3247078812484602`, 
                1}, {}]\), 
            ",", \(AncestralLineage[
              27, {5.5362846718122025`, 
                6.233984034101634`}, {{}, {a, b, c, 
                  d}, {}}, {0.3247078812484602`, 0.373144912940528`, 
                1}, {}]\), 
            ",", \(AncestralLineage[
              28, {5.803899803199372`, 
                6.08624167552868`}, {{}, {a, b, 
                  c}, {}}, {0.8125105445944757`, 0.98211937306245`, 1}, {}]\),
             ",", \(AncestralLineage[
              29, {5.803899803199372`, 
                6.233984034101634`}, {{}, {a, b, c}}, {0.98211937306245`, 
                1}, {}]\), 
            ",", \(AncestralLineage[
              30, {6.08624167552868`, 
                6.448659507091728`}, {{a, b, c, d}, {}, {a, b, 
                  c}, {}}, {0.3247078812484602`, 0.8125105445944757`, 
                0.98211937306245`, 1}, {}]\), 
            ",", \(AncestralLineage[
              31, {6.233984034101634`, 
                6.448659507091728`}, {{}, {a, b, c, d}, {}, {a, b, 
                  c}}, {0.3247078812484602`, 0.373144912940528`, 
                0.98211937306245`, 1}, {}]\), 
            ",", \(AncestralLineage[
              32, {6.448659507091728`, 
                6.464771108623202`}, {{a, b, c, d}, {}, {a, b, 
                  c}}, {0.373144912940528`, 0.8125105445944757`, 1}, {}]\), 
            ",", \(AncestralLineage[
              33, {6.464771108623202`, 
                6.647288724524958`}, {{a, b, c, 
                  d}, {}}, {0.1338850878429638`, 1}, {}]\), 
            ",", \(AncestralLineage[
              34, {6.464771108623202`, 
                6.522868735762748`}, {{}, {a, b, c, d}, {}, {a, b, 
                  c}}, {0.1338850878429638`, 0.373144912940528`, 
                0.8125105445944757`, 1}, {}]\), ",", 
            RowBox[{"AncestralLineage", "[", 
              RowBox[{"35", ",", 
                RowBox[{"{", 
                  RowBox[{"6.522868735762748`", ",", 
                    InterpretationBox["\[Infinity]",
                      DirectedInfinity[ 1]]}], "}"}], 
                ",", \({{}, {a, b, c, d}, {}}\), 
                ",", \({0.1338850878429638`, 0.373144912940528`, 1}\), 
                ",", \({}\)}], "]"}], 
            ",", \(AncestralLineage[
              36, {6.522868735762748`, 
                6.647288724524958`}, {{}, {a, b, c}}, {0.8125105445944757`, 
                1}, {}]\), 
            ",", \(AncestralLineage[
              37, {6.647288724524958`, 
                6.827416708046677`}, {{a, b, c, d}, {}, {a, b, 
                  c}}, {0.1338850878429638`, 0.8125105445944757`, 1}, {}]\), 
            ",", 
            RowBox[{"AncestralLineage", "[", 
              RowBox[{"38", ",", 
                RowBox[{"{", 
                  RowBox[{"6.827416708046677`", ",", 
                    InterpretationBox["\[Infinity]",
                      DirectedInfinity[ 1]]}], "}"}], 
                ",", \({{a, b, c, d}, {}, {a, b, c, d}}\), 
                ",", \({0.1338850878429638`, 0.373144912940528`, 1}\), 
                ",", \({}\)}], "]"}]}], "}"}]}],
      SequenceForm[ "G=", {
        AncestralLineage[ a, {0, 0.48529096572278896}, {{a}}, {1}, {}], 
        AncestralLineage[ b, {0, 0.23398316436020319}, {{b}}, {1}, {}], 
        AncestralLineage[ c, {0, 0.48529096572278896}, {{c}}, {1}, {}], 
        AncestralLineage[ d, {0, 1.7278195994170844}, {{d}}, {1}, {}], 
        AncestralLineage[ 
        1, {0.23398316436020319, 0.32236075893988181}, {{b}, {}}, {
          0.11492662691806055, 1}, {}], 
        AncestralLineage[ 
        2, {0.23398316436020319, 0.32236075893988181}, {{}, {b}}, {
          0.11492662691806055, 1}, {}], 
        AncestralLineage[ 
        3, {0.32236075893988181, 0.51786383713486195}, {{b}}, {1}, {}], 
        AncestralLineage[ 
        4, {0.48529096572278896, 0.51786383713486195}, {{a, c}}, {1}, {}], 
        AncestralLineage[ 
        5, {0.51786383713486195, 1.5246611785364954}, {{a, b, c}}, {1}, {}], 
        AncestralLineage[ 
        6, {1.5246611785364954, 1.5581431051287236}, {{a, b, c}, {}}, {
          0.48913575253109154, 1}, {}], 
        AncestralLineage[ 
        7, {1.5246611785364954, 1.5581431051287236}, {{}, {a, b, c}}, {
          0.48913575253109154, 1}, {}], 
        AncestralLineage[ 
        8, {1.5581431051287236, 1.6553683776658581}, {{a, b, c}}, {1}, {}], 
        AncestralLineage[ 
        9, {1.6553683776658581, 1.7278195994170844}, {{a, b, c}, {}}, {
          0.81251054459447569, 1}, {}], 
        AncestralLineage[ 
        10, {1.6553683776658581, 5.8038998031993723}, {{}, {a, b, c}}, {
          0.81251054459447569, 1}, {}], 
        AncestralLineage[ 
        11, {1.7278195994170844, 2.9123438760363545}, {{a, b, c, d}, {d}}, {
          0.81251054459447569, 1}, {}], 
        AncestralLineage[ 
        12, {2.9123438760363545, 3.0510813504782521}, {{a, b, c, d}, {
          d}, {}}, {0.81251054459447569, 0.8211640322266659, 1}, {}], 
        AncestralLineage[ 
        13, {2.9123438760363545, 3.0510813504782521}, {{}, {d}}, {
          0.8211640322266659, 1}, {}], 
        AncestralLineage[ 
        14, {3.0510813504782521, 3.9325181869144528}, {{a, b, c, d}, {d}}, {
          0.81251054459447569, 1}, {}], 
        AncestralLineage[ 
        15, {3.9325181869144528, 4.130798875978213}, {{a, b, c, d}, {}}, {
          0.016431884006824982, 1}, {}], 
        AncestralLineage[ 
        16, {3.9325181869144528, 4.130798875978213}, {{}, {a, b, c, d}, {
          d}}, {0.016431884006824982, 0.81251054459447569, 1}, {}], 
        AncestralLineage[ 
        17, {4.130798875978213, 4.8384282701987225}, {{a, b, c, d}, {d}}, {
          0.81251054459447569, 1}, {}], 
        AncestralLineage[ 
        18, {4.8384282701987225, 4.8664777588817101}, {{a, b, c, d}, {}}, {
          0.74402836827033658, 1}, {}], 
        AncestralLineage[ 
        19, {4.8384282701987225, 4.8664777588817101}, {{}, {a, b, c, d}, {
          d}}, {0.74402836827033658, 0.81251054459447569, 1}, {}], 
        AncestralLineage[ 
        20, {4.8664777588817101, 5.292690316029419}, {{a, b, c, d}, {d}}, {
          0.81251054459447569, 1}, {}], 
        AncestralLineage[ 
        21, {5.292690316029419, 5.3460017684681489}, {{a, b, c, d}, {
          d}, {}}, {0.81251054459447569, 0.92658890242798553, 1}, {}], 
        AncestralLineage[ 
        22, {5.292690316029419, 5.3460017684681489}, {{}, {d}}, {
          0.92658890242798553, 1}, {}], 
        AncestralLineage[ 
        23, {5.3460017684681489, 5.4598714204957677}, {{a, b, c, d}, {d}}, {
          0.81251054459447569, 1}, {}], 
        AncestralLineage[ 
        24, {5.4598714204957677, 5.5362846718122025}, {{a, b, c, d}, {}}, {
          0.37314491294052798, 1}, {}], 
        AncestralLineage[ 
        25, {5.4598714204957677, 6.8274167080466768}, {{}, {a, b, c, d}, {
          d}}, {0.37314491294052798, 0.81251054459447569, 1}, {}], 
        AncestralLineage[ 
        26, {5.5362846718122025, 6.0862416755286803}, {{a, b, c, d}, {}}, {
          0.32470788124846017, 1}, {}], 
        AncestralLineage[ 
        27, {5.5362846718122025, 6.2339840341016339}, {{}, {a, b, c, 
          d}, {}}, {0.32470788124846017, 0.37314491294052798, 1}, {}], 
        AncestralLineage[ 
        28, {5.8038998031993723, 6.0862416755286803}, {{}, {a, b, c}, {}}, {
          0.81251054459447569, 0.98211937306245001, 1}, {}], 
        AncestralLineage[ 
        29, {5.8038998031993723, 6.2339840341016339}, {{}, {a, b, c}}, {
          0.98211937306245001, 1}, {}], 
        AncestralLineage[ 
        30, {6.0862416755286803, 6.4486595070917279}, {{a, b, c, d}, {}, {a, 
          b, c}, {}}, {0.32470788124846017, 0.81251054459447569, 
          0.98211937306245001, 1}, {}], 
        AncestralLineage[ 
        31, {6.2339840341016339, 6.4486595070917279}, {{}, {a, b, c, d}, {}, {
          a, b, c}}, {0.32470788124846017, 0.37314491294052798, 
          0.98211937306245001, 1}, {}], 
        AncestralLineage[ 
        32, {6.4486595070917279, 6.4647711086232018}, {{a, b, c, d}, {}, {a, 
          b, c}}, {0.37314491294052798, 0.81251054459447569, 1}, {}], 
        AncestralLineage[ 
        33, {6.4647711086232018, 6.6472887245249579}, {{a, b, c, d}, {}}, {
          0.1338850878429638, 1}, {}], 
        AncestralLineage[ 
        34, {6.4647711086232018, 6.5228687357627484}, {{}, {a, b, c, d}, {}, {
          a, b, c}}, {0.1338850878429638, 0.37314491294052798, 
          0.81251054459447569, 1}, {}], 
        AncestralLineage[ 35, {6.5228687357627484, 
          DirectedInfinity[ 1]}, {{}, {a, b, c, d}, {}}, {0.1338850878429638, 
          0.37314491294052798, 1}, {}], 
        AncestralLineage[ 
        36, {6.5228687357627484, 6.6472887245249579}, {{}, {a, b, c}}, {
          0.81251054459447569, 1}, {}], 
        AncestralLineage[ 
        37, {6.6472887245249579, 6.8274167080466768}, {{a, b, c, d}, {}, {a, 
          b, c}}, {0.1338850878429638, 0.81251054459447569, 1}, {}], 
        AncestralLineage[ 38, {6.8274167080466768, 
          DirectedInfinity[ 1]}, {{a, b, c, d}, {}, {a, b, c, d}}, {
          0.1338850878429638, 0.37314491294052798, 1}, {}]}],
      Editable->False]], "Print",
  CellLabel->"From In[346]:="],

Cell[BoxData[
    \({0.2589888133032032`, 3, 0.2246826096414379`}\)], "Print",
  CellLabel->"From In[346]:="],

Cell[BoxData[
    InterpretationBox[\("Recombining "\[InvisibleSpace]38\[InvisibleSpace]"; \
current lineages "\[InvisibleSpace]{35, 38}\),
      SequenceForm[ "Recombining ", 38, "; current lineages ", {35, 38}],
      Editable->False]], "Print",
  CellLabel->"From In[346]:="],

Cell[BoxData[
    InterpretationBox[
      RowBox[{"\<\"G=\"\>", "\[InvisibleSpace]", 
        RowBox[{"{", 
          
          RowBox[{\(AncestralLineage[
              a, {0, 0.48529096572278896`}, {{a}}, {1}, {}]\), 
            ",", \(AncestralLineage[
              b, {0, 0.2339831643602032`}, {{b}}, {1}, {}]\), 
            ",", \(AncestralLineage[
              c, {0, 0.48529096572278896`}, {{c}}, {1}, {}]\), 
            ",", \(AncestralLineage[
              d, {0, 1.7278195994170844`}, {{d}}, {1}, {}]\), 
            ",", \(AncestralLineage[
              1, {0.2339831643602032`, 
                0.3223607589398818`}, {{b}, {}}, {0.11492662691806055`, 
                1}, {}]\), 
            ",", \(AncestralLineage[
              2, {0.2339831643602032`, 
                0.3223607589398818`}, {{}, {b}}, {0.11492662691806055`, 
                1}, {}]\), 
            ",", \(AncestralLineage[
              3, {0.3223607589398818`, 0.517863837134862`}, {{b}}, {1}, {}]\),
             ",", \(AncestralLineage[
              4, {0.48529096572278896`, 
                0.517863837134862`}, {{a, c}}, {1}, {}]\), 
            ",", \(AncestralLineage[
              5, {0.517863837134862`, 
                1.5246611785364954`}, {{a, b, c}}, {1}, {}]\), 
            ",", \(AncestralLineage[
              6, {1.5246611785364954`, 
                1.5581431051287236`}, {{a, b, c}, {}}, {0.48913575253109154`, 
                1}, {}]\), 
            ",", \(AncestralLineage[
              7, {1.5246611785364954`, 
                1.5581431051287236`}, {{}, {a, b, c}}, {0.48913575253109154`, 
                1}, {}]\), 
            ",", \(AncestralLineage[
              8, {1.5581431051287236`, 
                1.655368377665858`}, {{a, b, c}}, {1}, {}]\), 
            ",", \(AncestralLineage[
              9, {1.655368377665858`, 
                1.7278195994170844`}, {{a, b, c}, {}}, {0.8125105445944757`, 
                1}, {}]\), 
            ",", \(AncestralLineage[
              10, {1.655368377665858`, 
                5.803899803199372`}, {{}, {a, b, c}}, {0.8125105445944757`, 
                1}, {}]\), 
            ",", \(AncestralLineage[
              11, {1.7278195994170844`, 
                2.9123438760363545`}, {{a, b, c, 
                  d}, {d}}, {0.8125105445944757`, 1}, {}]\), 
            ",", \(AncestralLineage[
              12, {2.9123438760363545`, 
                3.051081350478252`}, {{a, b, c, 
                  d}, {d}, {}}, {0.8125105445944757`, 0.8211640322266659`, 
                1}, {}]\), 
            ",", \(AncestralLineage[
              13, {2.9123438760363545`, 
                3.051081350478252`}, {{}, {d}}, {0.8211640322266659`, 
                1}, {}]\), 
            ",", \(AncestralLineage[
              14, {3.051081350478252`, 
                3.9325181869144528`}, {{a, b, c, 
                  d}, {d}}, {0.8125105445944757`, 1}, {}]\), 
            ",", \(AncestralLineage[
              15, {3.9325181869144528`, 
                4.130798875978213`}, {{a, b, c, 
                  d}, {}}, {0.016431884006824982`, 1}, {}]\), 
            ",", \(AncestralLineage[
              16, {3.9325181869144528`, 
                4.130798875978213`}, {{}, {a, b, c, 
                  d}, {d}}, {0.016431884006824982`, 0.8125105445944757`, 
                1}, {}]\), 
            ",", \(AncestralLineage[
              17, {4.130798875978213`, 
                4.8384282701987225`}, {{a, b, c, 
                  d}, {d}}, {0.8125105445944757`, 1}, {}]\), 
            ",", \(AncestralLineage[
              18, {4.8384282701987225`, 
                4.86647775888171`}, {{a, b, c, d}, {}}, {0.7440283682703366`, 
                1}, {}]\), 
            ",", \(AncestralLineage[
              19, {4.8384282701987225`, 
                4.86647775888171`}, {{}, {a, b, c, 
                  d}, {d}}, {0.7440283682703366`, 0.8125105445944757`, 
                1}, {}]\), 
            ",", \(AncestralLineage[
              20, {4.86647775888171`, 
                5.292690316029419`}, {{a, b, c, 
                  d}, {d}}, {0.8125105445944757`, 1}, {}]\), 
            ",", \(AncestralLineage[
              21, {5.292690316029419`, 
                5.346001768468149`}, {{a, b, c, 
                  d}, {d}, {}}, {0.8125105445944757`, 0.9265889024279855`, 
                1}, {}]\), 
            ",", \(AncestralLineage[
              22, {5.292690316029419`, 
                5.346001768468149`}, {{}, {d}}, {0.9265889024279855`, 
                1}, {}]\), 
            ",", \(AncestralLineage[
              23, {5.346001768468149`, 
                5.459871420495768`}, {{a, b, c, 
                  d}, {d}}, {0.8125105445944757`, 1}, {}]\), 
            ",", \(AncestralLineage[
              24, {5.459871420495768`, 
                5.5362846718122025`}, {{a, b, c, 
                  d}, {}}, {0.373144912940528`, 1}, {}]\), 
            ",", \(AncestralLineage[
              25, {5.459871420495768`, 
                6.827416708046677`}, {{}, {a, b, c, 
                  d}, {d}}, {0.373144912940528`, 0.8125105445944757`, 
                1}, {}]\), 
            ",", \(AncestralLineage[
              26, {5.5362846718122025`, 
                6.08624167552868`}, {{a, b, c, d}, {}}, {0.3247078812484602`, 
                1}, {}]\), 
            ",", \(AncestralLineage[
              27, {5.5362846718122025`, 
                6.233984034101634`}, {{}, {a, b, c, 
                  d}, {}}, {0.3247078812484602`, 0.373144912940528`, 
                1}, {}]\), 
            ",", \(AncestralLineage[
              28, {5.803899803199372`, 
                6.08624167552868`}, {{}, {a, b, 
                  c}, {}}, {0.8125105445944757`, 0.98211937306245`, 1}, {}]\),
             ",", \(AncestralLineage[
              29, {5.803899803199372`, 
                6.233984034101634`}, {{}, {a, b, c}}, {0.98211937306245`, 
                1}, {}]\), 
            ",", \(AncestralLineage[
              30, {6.08624167552868`, 
                6.448659507091728`}, {{a, b, c, d}, {}, {a, b, 
                  c}, {}}, {0.3247078812484602`, 0.8125105445944757`, 
                0.98211937306245`, 1}, {}]\), 
            ",", \(AncestralLineage[
              31, {6.233984034101634`, 
                6.448659507091728`}, {{}, {a, b, c, d}, {}, {a, b, 
                  c}}, {0.3247078812484602`, 0.373144912940528`, 
                0.98211937306245`, 1}, {}]\), 
            ",", \(AncestralLineage[
              32, {6.448659507091728`, 
                6.464771108623202`}, {{a, b, c, d}, {}, {a, b, 
                  c}}, {0.373144912940528`, 0.8125105445944757`, 1}, {}]\), 
            ",", \(AncestralLineage[
              33, {6.464771108623202`, 
                6.647288724524958`}, {{a, b, c, 
                  d}, {}}, {0.1338850878429638`, 1}, {}]\), 
            ",", \(AncestralLineage[
              34, {6.464771108623202`, 
                6.522868735762748`}, {{}, {a, b, c, d}, {}, {a, b, 
                  c}}, {0.1338850878429638`, 0.373144912940528`, 
                0.8125105445944757`, 1}, {}]\), ",", 
            RowBox[{"AncestralLineage", "[", 
              RowBox[{"35", ",", 
                RowBox[{"{", 
                  RowBox[{"6.522868735762748`", ",", 
                    InterpretationBox["\[Infinity]",
                      DirectedInfinity[ 1]]}], "}"}], 
                ",", \({{}, {a, b, c, d}, {}}\), 
                ",", \({0.1338850878429638`, 0.373144912940528`, 1}\), 
                ",", \({}\)}], "]"}], 
            ",", \(AncestralLineage[
              36, {6.522868735762748`, 
                6.647288724524958`}, {{}, {a, b, c}}, {0.8125105445944757`, 
                1}, {}]\), 
            ",", \(AncestralLineage[
              37, {6.647288724524958`, 
                6.827416708046677`}, {{a, b, c, d}, {}, {a, b, 
                  c}}, {0.1338850878429638`, 0.8125105445944757`, 1}, {}]\), 
            ",", \(AncestralLineage[
              38, {6.827416708046677`, 
                7.08640552134988`}, {{a, b, c, d}, {}, {a, b, c, 
                  d}}, {0.1338850878429638`, 0.373144912940528`, 1}, {}]\), 
            ",", 
            RowBox[{"AncestralLineage", "[", 
              RowBox[{"39", ",", 
                RowBox[{"{", 
                  RowBox[{"7.08640552134988`", ",", 
                    InterpretationBox["\[Infinity]",
                      DirectedInfinity[ 1]]}], "}"}], 
                ",", \({{a, b, c, d}, {}}\), 
                ",", \({0.1338850878429638`, 1}\), ",", \({}\)}], "]"}], ",", 
            
            RowBox[{"AncestralLineage", "[", 
              RowBox[{"40", ",", 
                RowBox[{"{", 
                  RowBox[{"7.08640552134988`", ",", 
                    InterpretationBox["\[Infinity]",
                      DirectedInfinity[ 1]]}], "}"}], 
                ",", \({{}, {a, b, c, d}}\), ",", \({0.373144912940528`, 1}\),
                 ",", \({}\)}], "]"}]}], "}"}]}],
      SequenceForm[ "G=", {
        AncestralLineage[ a, {0, 0.48529096572278896}, {{a}}, {1}, {}], 
        AncestralLineage[ b, {0, 0.23398316436020319}, {{b}}, {1}, {}], 
        AncestralLineage[ c, {0, 0.48529096572278896}, {{c}}, {1}, {}], 
        AncestralLineage[ d, {0, 1.7278195994170844}, {{d}}, {1}, {}], 
        AncestralLineage[ 
        1, {0.23398316436020319, 0.32236075893988181}, {{b}, {}}, {
          0.11492662691806055, 1}, {}], 
        AncestralLineage[ 
        2, {0.23398316436020319, 0.32236075893988181}, {{}, {b}}, {
          0.11492662691806055, 1}, {}], 
        AncestralLineage[ 
        3, {0.32236075893988181, 0.51786383713486195}, {{b}}, {1}, {}], 
        AncestralLineage[ 
        4, {0.48529096572278896, 0.51786383713486195}, {{a, c}}, {1}, {}], 
        AncestralLineage[ 
        5, {0.51786383713486195, 1.5246611785364954}, {{a, b, c}}, {1}, {}], 
        AncestralLineage[ 
        6, {1.5246611785364954, 1.5581431051287236}, {{a, b, c}, {}}, {
          0.48913575253109154, 1}, {}], 
        AncestralLineage[ 
        7, {1.5246611785364954, 1.5581431051287236}, {{}, {a, b, c}}, {
          0.48913575253109154, 1}, {}], 
        AncestralLineage[ 
        8, {1.5581431051287236, 1.6553683776658581}, {{a, b, c}}, {1}, {}], 
        AncestralLineage[ 
        9, {1.6553683776658581, 1.7278195994170844}, {{a, b, c}, {}}, {
          0.81251054459447569, 1}, {}], 
        AncestralLineage[ 
        10, {1.6553683776658581, 5.8038998031993723}, {{}, {a, b, c}}, {
          0.81251054459447569, 1}, {}], 
        AncestralLineage[ 
        11, {1.7278195994170844, 2.9123438760363545}, {{a, b, c, d}, {d}}, {
          0.81251054459447569, 1}, {}], 
        AncestralLineage[ 
        12, {2.9123438760363545, 3.0510813504782521}, {{a, b, c, d}, {
          d}, {}}, {0.81251054459447569, 0.8211640322266659, 1}, {}], 
        AncestralLineage[ 
        13, {2.9123438760363545, 3.0510813504782521}, {{}, {d}}, {
          0.8211640322266659, 1}, {}], 
        AncestralLineage[ 
        14, {3.0510813504782521, 3.9325181869144528}, {{a, b, c, d}, {d}}, {
          0.81251054459447569, 1}, {}], 
        AncestralLineage[ 
        15, {3.9325181869144528, 4.130798875978213}, {{a, b, c, d}, {}}, {
          0.016431884006824982, 1}, {}], 
        AncestralLineage[ 
        16, {3.9325181869144528, 4.130798875978213}, {{}, {a, b, c, d}, {
          d}}, {0.016431884006824982, 0.81251054459447569, 1}, {}], 
        AncestralLineage[ 
        17, {4.130798875978213, 4.8384282701987225}, {{a, b, c, d}, {d}}, {
          0.81251054459447569, 1}, {}], 
        AncestralLineage[ 
        18, {4.8384282701987225, 4.8664777588817101}, {{a, b, c, d}, {}}, {
          0.74402836827033658, 1}, {}], 
        AncestralLineage[ 
        19, {4.8384282701987225, 4.8664777588817101}, {{}, {a, b, c, d}, {
          d}}, {0.74402836827033658, 0.81251054459447569, 1}, {}], 
        AncestralLineage[ 
        20, {4.8664777588817101, 5.292690316029419}, {{a, b, c, d}, {d}}, {
          0.81251054459447569, 1}, {}], 
        AncestralLineage[ 
        21, {5.292690316029419, 5.3460017684681489}, {{a, b, c, d}, {
          d}, {}}, {0.81251054459447569, 0.92658890242798553, 1}, {}], 
        AncestralLineage[ 
        22, {5.292690316029419, 5.3460017684681489}, {{}, {d}}, {
          0.92658890242798553, 1}, {}], 
        AncestralLineage[ 
        23, {5.3460017684681489, 5.4598714204957677}, {{a, b, c, d}, {d}}, {
          0.81251054459447569, 1}, {}], 
        AncestralLineage[ 
        24, {5.4598714204957677, 5.5362846718122025}, {{a, b, c, d}, {}}, {
          0.37314491294052798, 1}, {}], 
        AncestralLineage[ 
        25, {5.4598714204957677, 6.8274167080466768}, {{}, {a, b, c, d}, {
          d}}, {0.37314491294052798, 0.81251054459447569, 1}, {}], 
        AncestralLineage[ 
        26, {5.5362846718122025, 6.0862416755286803}, {{a, b, c, d}, {}}, {
          0.32470788124846017, 1}, {}], 
        AncestralLineage[ 
        27, {5.5362846718122025, 6.2339840341016339}, {{}, {a, b, c, 
          d}, {}}, {0.32470788124846017, 0.37314491294052798, 1}, {}], 
        AncestralLineage[ 
        28, {5.8038998031993723, 6.0862416755286803}, {{}, {a, b, c}, {}}, {
          0.81251054459447569, 0.98211937306245001, 1}, {}], 
        AncestralLineage[ 
        29, {5.8038998031993723, 6.2339840341016339}, {{}, {a, b, c}}, {
          0.98211937306245001, 1}, {}], 
        AncestralLineage[ 
        30, {6.0862416755286803, 6.4486595070917279}, {{a, b, c, d}, {}, {a, 
          b, c}, {}}, {0.32470788124846017, 0.81251054459447569, 
          0.98211937306245001, 1}, {}], 
        AncestralLineage[ 
        31, {6.2339840341016339, 6.4486595070917279}, {{}, {a, b, c, d}, {}, {
          a, b, c}}, {0.32470788124846017, 0.37314491294052798, 
          0.98211937306245001, 1}, {}], 
        AncestralLineage[ 
        32, {6.4486595070917279, 6.4647711086232018}, {{a, b, c, d}, {}, {a, 
          b, c}}, {0.37314491294052798, 0.81251054459447569, 1}, {}], 
        AncestralLineage[ 
        33, {6.4647711086232018, 6.6472887245249579}, {{a, b, c, d}, {}}, {
          0.1338850878429638, 1}, {}], 
        AncestralLineage[ 
        34, {6.4647711086232018, 6.5228687357627484}, {{}, {a, b, c, d}, {}, {
          a, b, c}}, {0.1338850878429638, 0.37314491294052798, 
          0.81251054459447569, 1}, {}], 
        AncestralLineage[ 35, {6.5228687357627484, 
          DirectedInfinity[ 1]}, {{}, {a, b, c, d}, {}}, {0.1338850878429638, 
          0.37314491294052798, 1}, {}], 
        AncestralLineage[ 
        36, {6.5228687357627484, 6.6472887245249579}, {{}, {a, b, c}}, {
          0.81251054459447569, 1}, {}], 
        AncestralLineage[ 
        37, {6.6472887245249579, 6.8274167080466768}, {{a, b, c, d}, {}, {a, 
          b, c}}, {0.1338850878429638, 0.81251054459447569, 1}, {}], 
        AncestralLineage[ 
        38, {6.8274167080466768, 7.0864055213498798}, {{a, b, c, d}, {}, {a, 
          b, c, d}}, {0.1338850878429638, 0.37314491294052798, 1}, {}], 
        AncestralLineage[ 39, {7.0864055213498798, 
          DirectedInfinity[ 1]}, {{a, b, c, d}, {}}, {0.1338850878429638, 
          1}, {}], 
        AncestralLineage[ 40, {7.0864055213498798, 
          DirectedInfinity[ 1]}, {{}, {a, b, c, d}}, {0.37314491294052798, 
          1}, {}]}],
      Editable->False]], "Print",
  CellLabel->"From In[346]:="],

Cell[BoxData[
    \({0.2922144907760953`, 4, 0.7325962355113973`}\)], "Print",
  CellLabel->"From In[346]:="],

Cell[BoxData[
    InterpretationBox[\("Recombining "\[InvisibleSpace]40\[InvisibleSpace]"; \
current lineages "\[InvisibleSpace]{35, 39, 40}\),
      SequenceForm[ "Recombining ", 40, "; current lineages ", {35, 39, 40}],
      Editable->False]], "Print",
  CellLabel->"From In[346]:="],

Cell[BoxData[
    InterpretationBox[
      RowBox[{"\<\"G=\"\>", "\[InvisibleSpace]", 
        RowBox[{"{", 
          
          RowBox[{\(AncestralLineage[
              a, {0, 0.48529096572278896`}, {{a}}, {1}, {}]\), 
            ",", \(AncestralLineage[
              b, {0, 0.2339831643602032`}, {{b}}, {1}, {}]\), 
            ",", \(AncestralLineage[
              c, {0, 0.48529096572278896`}, {{c}}, {1}, {}]\), 
            ",", \(AncestralLineage[
              d, {0, 1.7278195994170844`}, {{d}}, {1}, {}]\), 
            ",", \(AncestralLineage[
              1, {0.2339831643602032`, 
                0.3223607589398818`}, {{b}, {}}, {0.11492662691806055`, 
                1}, {}]\), 
            ",", \(AncestralLineage[
              2, {0.2339831643602032`, 
                0.3223607589398818`}, {{}, {b}}, {0.11492662691806055`, 
                1}, {}]\), 
            ",", \(AncestralLineage[
              3, {0.3223607589398818`, 0.517863837134862`}, {{b}}, {1}, {}]\),
             ",", \(AncestralLineage[
              4, {0.48529096572278896`, 
                0.517863837134862`}, {{a, c}}, {1}, {}]\), 
            ",", \(AncestralLineage[
              5, {0.517863837134862`, 
                1.5246611785364954`}, {{a, b, c}}, {1}, {}]\), 
            ",", \(AncestralLineage[
              6, {1.5246611785364954`, 
                1.5581431051287236`}, {{a, b, c}, {}}, {0.48913575253109154`, 
                1}, {}]\), 
            ",", \(AncestralLineage[
              7, {1.5246611785364954`, 
                1.5581431051287236`}, {{}, {a, b, c}}, {0.48913575253109154`, 
                1}, {}]\), 
            ",", \(AncestralLineage[
              8, {1.5581431051287236`, 
                1.655368377665858`}, {{a, b, c}}, {1}, {}]\), 
            ",", \(AncestralLineage[
              9, {1.655368377665858`, 
                1.7278195994170844`}, {{a, b, c}, {}}, {0.8125105445944757`, 
                1}, {}]\), 
            ",", \(AncestralLineage[
              10, {1.655368377665858`, 
                5.803899803199372`}, {{}, {a, b, c}}, {0.8125105445944757`, 
                1}, {}]\), 
            ",", \(AncestralLineage[
              11, {1.7278195994170844`, 
                2.9123438760363545`}, {{a, b, c, 
                  d}, {d}}, {0.8125105445944757`, 1}, {}]\), 
            ",", \(AncestralLineage[
              12, {2.9123438760363545`, 
                3.051081350478252`}, {{a, b, c, 
                  d}, {d}, {}}, {0.8125105445944757`, 0.8211640322266659`, 
                1}, {}]\), 
            ",", \(AncestralLineage[
              13, {2.9123438760363545`, 
                3.051081350478252`}, {{}, {d}}, {0.8211640322266659`, 
                1}, {}]\), 
            ",", \(AncestralLineage[
              14, {3.051081350478252`, 
                3.9325181869144528`}, {{a, b, c, 
                  d}, {d}}, {0.8125105445944757`, 1}, {}]\), 
            ",", \(AncestralLineage[
              15, {3.9325181869144528`, 
                4.130798875978213`}, {{a, b, c, 
                  d}, {}}, {0.016431884006824982`, 1}, {}]\), 
            ",", \(AncestralLineage[
              16, {3.9325181869144528`, 
                4.130798875978213`}, {{}, {a, b, c, 
                  d}, {d}}, {0.016431884006824982`, 0.8125105445944757`, 
                1}, {}]\), 
            ",", \(AncestralLineage[
              17, {4.130798875978213`, 
                4.8384282701987225`}, {{a, b, c, 
                  d}, {d}}, {0.8125105445944757`, 1}, {}]\), 
            ",", \(AncestralLineage[
              18, {4.8384282701987225`, 
                4.86647775888171`}, {{a, b, c, d}, {}}, {0.7440283682703366`, 
                1}, {}]\), 
            ",", \(AncestralLineage[
              19, {4.8384282701987225`, 
                4.86647775888171`}, {{}, {a, b, c, 
                  d}, {d}}, {0.7440283682703366`, 0.8125105445944757`, 
                1}, {}]\), 
            ",", \(AncestralLineage[
              20, {4.86647775888171`, 
                5.292690316029419`}, {{a, b, c, 
                  d}, {d}}, {0.8125105445944757`, 1}, {}]\), 
            ",", \(AncestralLineage[
              21, {5.292690316029419`, 
                5.346001768468149`}, {{a, b, c, 
                  d}, {d}, {}}, {0.8125105445944757`, 0.9265889024279855`, 
                1}, {}]\), 
            ",", \(AncestralLineage[
              22, {5.292690316029419`, 
                5.346001768468149`}, {{}, {d}}, {0.9265889024279855`, 
                1}, {}]\), 
            ",", \(AncestralLineage[
              23, {5.346001768468149`, 
                5.459871420495768`}, {{a, b, c, 
                  d}, {d}}, {0.8125105445944757`, 1}, {}]\), 
            ",", \(AncestralLineage[
              24, {5.459871420495768`, 
                5.5362846718122025`}, {{a, b, c, 
                  d}, {}}, {0.373144912940528`, 1}, {}]\), 
            ",", \(AncestralLineage[
              25, {5.459871420495768`, 
                6.827416708046677`}, {{}, {a, b, c, 
                  d}, {d}}, {0.373144912940528`, 0.8125105445944757`, 
                1}, {}]\), 
            ",", \(AncestralLineage[
              26, {5.5362846718122025`, 
                6.08624167552868`}, {{a, b, c, d}, {}}, {0.3247078812484602`, 
                1}, {}]\), 
            ",", \(AncestralLineage[
              27, {5.5362846718122025`, 
                6.233984034101634`}, {{}, {a, b, c, 
                  d}, {}}, {0.3247078812484602`, 0.373144912940528`, 
                1}, {}]\), 
            ",", \(AncestralLineage[
              28, {5.803899803199372`, 
                6.08624167552868`}, {{}, {a, b, 
                  c}, {}}, {0.8125105445944757`, 0.98211937306245`, 1}, {}]\),
             ",", \(AncestralLineage[
              29, {5.803899803199372`, 
                6.233984034101634`}, {{}, {a, b, c}}, {0.98211937306245`, 
                1}, {}]\), 
            ",", \(AncestralLineage[
              30, {6.08624167552868`, 
                6.448659507091728`}, {{a, b, c, d}, {}, {a, b, 
                  c}, {}}, {0.3247078812484602`, 0.8125105445944757`, 
                0.98211937306245`, 1}, {}]\), 
            ",", \(AncestralLineage[
              31, {6.233984034101634`, 
                6.448659507091728`}, {{}, {a, b, c, d}, {}, {a, b, 
                  c}}, {0.3247078812484602`, 0.373144912940528`, 
                0.98211937306245`, 1}, {}]\), 
            ",", \(AncestralLineage[
              32, {6.448659507091728`, 
                6.464771108623202`}, {{a, b, c, d}, {}, {a, b, 
                  c}}, {0.373144912940528`, 0.8125105445944757`, 1}, {}]\), 
            ",", \(AncestralLineage[
              33, {6.464771108623202`, 
                6.647288724524958`}, {{a, b, c, 
                  d}, {}}, {0.1338850878429638`, 1}, {}]\), 
            ",", \(AncestralLineage[
              34, {6.464771108623202`, 
                6.522868735762748`}, {{}, {a, b, c, d}, {}, {a, b, 
                  c}}, {0.1338850878429638`, 0.373144912940528`, 
                0.8125105445944757`, 1}, {}]\), ",", 
            RowBox[{"AncestralLineage", "[", 
              RowBox[{"35", ",", 
                RowBox[{"{", 
                  RowBox[{"6.522868735762748`", ",", 
                    InterpretationBox["\[Infinity]",
                      DirectedInfinity[ 1]]}], "}"}], 
                ",", \({{}, {a, b, c, d}, {}}\), 
                ",", \({0.1338850878429638`, 0.373144912940528`, 1}\), 
                ",", \({}\)}], "]"}], 
            ",", \(AncestralLineage[
              36, {6.522868735762748`, 
                6.647288724524958`}, {{}, {a, b, c}}, {0.8125105445944757`, 
                1}, {}]\), 
            ",", \(AncestralLineage[
              37, {6.647288724524958`, 
                6.827416708046677`}, {{a, b, c, d}, {}, {a, b, 
                  c}}, {0.1338850878429638`, 0.8125105445944757`, 1}, {}]\), 
            ",", \(AncestralLineage[
              38, {6.827416708046677`, 
                7.08640552134988`}, {{a, b, c, d}, {}, {a, b, c, 
                  d}}, {0.1338850878429638`, 0.373144912940528`, 1}, {}]\), 
            ",", 
            RowBox[{"AncestralLineage", "[", 
              RowBox[{"39", ",", 
                RowBox[{"{", 
                  RowBox[{"7.08640552134988`", ",", 
                    InterpretationBox["\[Infinity]",
                      DirectedInfinity[ 1]]}], "}"}], 
                ",", \({{a, b, c, d}, {}}\), 
                ",", \({0.1338850878429638`, 1}\), ",", \({}\)}], "]"}], 
            ",", \(AncestralLineage[
              40, {7.08640552134988`, 
                7.378620012125975`}, {{}, {a, b, c, d}}, {0.373144912940528`, 
                1}, {}]\), ",", 
            RowBox[{"AncestralLineage", "[", 
              RowBox[{"41", ",", 
                RowBox[{"{", 
                  RowBox[{"7.378620012125975`", ",", 
                    InterpretationBox["\[Infinity]",
                      DirectedInfinity[ 1]]}], "}"}], 
                ",", \({{}, {a, b, c, d}, {}}\), 
                ",", \({0.373144912940528`, 0.7325962355113973`, 1}\), 
                ",", \({}\)}], "]"}], ",", 
            RowBox[{"AncestralLineage", "[", 
              RowBox[{"42", ",", 
                RowBox[{"{", 
                  RowBox[{"7.378620012125975`", ",", 
                    InterpretationBox["\[Infinity]",
                      DirectedInfinity[ 1]]}], "}"}], 
                ",", \({{}, {a, b, c, d}}\), 
                ",", \({0.7325962355113973`, 1}\), ",", \({}\)}], "]"}]}], 
          "}"}]}],
      SequenceForm[ "G=", {
        AncestralLineage[ a, {0, 0.48529096572278896}, {{a}}, {1}, {}], 
        AncestralLineage[ b, {0, 0.23398316436020319}, {{b}}, {1}, {}], 
        AncestralLineage[ c, {0, 0.48529096572278896}, {{c}}, {1}, {}], 
        AncestralLineage[ d, {0, 1.7278195994170844}, {{d}}, {1}, {}], 
        AncestralLineage[ 
        1, {0.23398316436020319, 0.32236075893988181}, {{b}, {}}, {
          0.11492662691806055, 1}, {}], 
        AncestralLineage[ 
        2, {0.23398316436020319, 0.32236075893988181}, {{}, {b}}, {
          0.11492662691806055, 1}, {}], 
        AncestralLineage[ 
        3, {0.32236075893988181, 0.51786383713486195}, {{b}}, {1}, {}], 
        AncestralLineage[ 
        4, {0.48529096572278896, 0.51786383713486195}, {{a, c}}, {1}, {}], 
        AncestralLineage[ 
        5, {0.51786383713486195, 1.5246611785364954}, {{a, b, c}}, {1}, {}], 
        AncestralLineage[ 
        6, {1.5246611785364954, 1.5581431051287236}, {{a, b, c}, {}}, {
          0.48913575253109154, 1}, {}], 
        AncestralLineage[ 
        7, {1.5246611785364954, 1.5581431051287236}, {{}, {a, b, c}}, {
          0.48913575253109154, 1}, {}], 
        AncestralLineage[ 
        8, {1.5581431051287236, 1.6553683776658581}, {{a, b, c}}, {1}, {}], 
        AncestralLineage[ 
        9, {1.6553683776658581, 1.7278195994170844}, {{a, b, c}, {}}, {
          0.81251054459447569, 1}, {}], 
        AncestralLineage[ 
        10, {1.6553683776658581, 5.8038998031993723}, {{}, {a, b, c}}, {
          0.81251054459447569, 1}, {}], 
        AncestralLineage[ 
        11, {1.7278195994170844, 2.9123438760363545}, {{a, b, c, d}, {d}}, {
          0.81251054459447569, 1}, {}], 
        AncestralLineage[ 
        12, {2.9123438760363545, 3.0510813504782521}, {{a, b, c, d}, {
          d}, {}}, {0.81251054459447569, 0.8211640322266659, 1}, {}], 
        AncestralLineage[ 
        13, {2.9123438760363545, 3.0510813504782521}, {{}, {d}}, {
          0.8211640322266659, 1}, {}], 
        AncestralLineage[ 
        14, {3.0510813504782521, 3.9325181869144528}, {{a, b, c, d}, {d}}, {
          0.81251054459447569, 1}, {}], 
        AncestralLineage[ 
        15, {3.9325181869144528, 4.130798875978213}, {{a, b, c, d}, {}}, {
          0.016431884006824982, 1}, {}], 
        AncestralLineage[ 
        16, {3.9325181869144528, 4.130798875978213}, {{}, {a, b, c, d}, {
          d}}, {0.016431884006824982, 0.81251054459447569, 1}, {}], 
        AncestralLineage[ 
        17, {4.130798875978213, 4.8384282701987225}, {{a, b, c, d}, {d}}, {
          0.81251054459447569, 1}, {}], 
        AncestralLineage[ 
        18, {4.8384282701987225, 4.8664777588817101}, {{a, b, c, d}, {}}, {
          0.74402836827033658, 1}, {}], 
        AncestralLineage[ 
        19, {4.8384282701987225, 4.8664777588817101}, {{}, {a, b, c, d}, {
          d}}, {0.74402836827033658, 0.81251054459447569, 1}, {}], 
        AncestralLineage[ 
        20, {4.8664777588817101, 5.292690316029419}, {{a, b, c, d}, {d}}, {
          0.81251054459447569, 1}, {}], 
        AncestralLineage[ 
        21, {5.292690316029419, 5.3460017684681489}, {{a, b, c, d}, {
          d}, {}}, {0.81251054459447569, 0.92658890242798553, 1}, {}], 
        AncestralLineage[ 
        22, {5.292690316029419, 5.3460017684681489}, {{}, {d}}, {
          0.92658890242798553, 1}, {}], 
        AncestralLineage[ 
        23, {5.3460017684681489, 5.4598714204957677}, {{a, b, c, d}, {d}}, {
          0.81251054459447569, 1}, {}], 
        AncestralLineage[ 
        24, {5.4598714204957677, 5.5362846718122025}, {{a, b, c, d}, {}}, {
          0.37314491294052798, 1}, {}], 
        AncestralLineage[ 
        25, {5.4598714204957677, 6.8274167080466768}, {{}, {a, b, c, d}, {
          d}}, {0.37314491294052798, 0.81251054459447569, 1}, {}], 
        AncestralLineage[ 
        26, {5.5362846718122025, 6.0862416755286803}, {{a, b, c, d}, {}}, {
          0.32470788124846017, 1}, {}], 
        AncestralLineage[ 
        27, {5.5362846718122025, 6.2339840341016339}, {{}, {a, b, c, 
          d}, {}}, {0.32470788124846017, 0.37314491294052798, 1}, {}], 
        AncestralLineage[ 
        28, {5.8038998031993723, 6.0862416755286803}, {{}, {a, b, c}, {}}, {
          0.81251054459447569, 0.98211937306245001, 1}, {}], 
        AncestralLineage[ 
        29, {5.8038998031993723, 6.2339840341016339}, {{}, {a, b, c}}, {
          0.98211937306245001, 1}, {}], 
        AncestralLineage[ 
        30, {6.0862416755286803, 6.4486595070917279}, {{a, b, c, d}, {}, {a, 
          b, c}, {}}, {0.32470788124846017, 0.81251054459447569, 
          0.98211937306245001, 1}, {}], 
        AncestralLineage[ 
        31, {6.2339840341016339, 6.4486595070917279}, {{}, {a, b, c, d}, {}, {
          a, b, c}}, {0.32470788124846017, 0.37314491294052798, 
          0.98211937306245001, 1}, {}], 
        AncestralLineage[ 
        32, {6.4486595070917279, 6.4647711086232018}, {{a, b, c, d}, {}, {a, 
          b, c}}, {0.37314491294052798, 0.81251054459447569, 1}, {}], 
        AncestralLineage[ 
        33, {6.4647711086232018, 6.6472887245249579}, {{a, b, c, d}, {}}, {
          0.1338850878429638, 1}, {}], 
        AncestralLineage[ 
        34, {6.4647711086232018, 6.5228687357627484}, {{}, {a, b, c, d}, {}, {
          a, b, c}}, {0.1338850878429638, 0.37314491294052798, 
          0.81251054459447569, 1}, {}], 
        AncestralLineage[ 35, {6.5228687357627484, 
          DirectedInfinity[ 1]}, {{}, {a, b, c, d}, {}}, {0.1338850878429638, 
          0.37314491294052798, 1}, {}], 
        AncestralLineage[ 
        36, {6.5228687357627484, 6.6472887245249579}, {{}, {a, b, c}}, {
          0.81251054459447569, 1}, {}], 
        AncestralLineage[ 
        37, {6.6472887245249579, 6.8274167080466768}, {{a, b, c, d}, {}, {a, 
          b, c}}, {0.1338850878429638, 0.81251054459447569, 1}, {}], 
        AncestralLineage[ 
        38, {6.8274167080466768, 7.0864055213498798}, {{a, b, c, d}, {}, {a, 
          b, c, d}}, {0.1338850878429638, 0.37314491294052798, 1}, {}], 
        AncestralLineage[ 39, {7.0864055213498798, 
          DirectedInfinity[ 1]}, {{a, b, c, d}, {}}, {0.1338850878429638, 
          1}, {}], 
        AncestralLineage[ 
        40, {7.0864055213498798, 7.3786200121259746}, {{}, {a, b, c, d}}, {
          0.37314491294052798, 1}, {}], 
        AncestralLineage[ 41, {7.3786200121259746, 
          DirectedInfinity[ 1]}, {{}, {a, b, c, d}, {}}, {0.37314491294052798,
           0.7325962355113973, 1}, {}], 
        AncestralLineage[ 42, {7.3786200121259746, 
          DirectedInfinity[ 1]}, {{}, {a, b, c, d}}, {0.7325962355113973, 
          1}, {}]}],
      Editable->False]], "Print",
  CellLabel->"From In[346]:="],

Cell[BoxData[
    \({0.005247788252292681`, 3, None}\)], "Print",
  CellLabel->"From In[346]:="],

Cell[BoxData[
    InterpretationBox[\("Coalescing "\[InvisibleSpace]{39, 
          42}\[InvisibleSpace]"; current lineages "\[InvisibleSpace]{35, 39, 
          41, 42}\),
      SequenceForm[ 
      "Coalescing ", {39, 42}, "; current lineages ", {35, 39, 41, 42}],
      Editable->False]], "Print",
  CellLabel->"From In[346]:="],

Cell[BoxData[
    InterpretationBox[
      RowBox[{"\<\"G=\"\>", "\[InvisibleSpace]", 
        RowBox[{"{", 
          
          RowBox[{\(AncestralLineage[
              a, {0, 0.48529096572278896`}, {{a}}, {1}, {}]\), 
            ",", \(AncestralLineage[
              b, {0, 0.2339831643602032`}, {{b}}, {1}, {}]\), 
            ",", \(AncestralLineage[
              c, {0, 0.48529096572278896`}, {{c}}, {1}, {}]\), 
            ",", \(AncestralLineage[
              d, {0, 1.7278195994170844`}, {{d}}, {1}, {}]\), 
            ",", \(AncestralLineage[
              1, {0.2339831643602032`, 
                0.3223607589398818`}, {{b}, {}}, {0.11492662691806055`, 
                1}, {}]\), 
            ",", \(AncestralLineage[
              2, {0.2339831643602032`, 
                0.3223607589398818`}, {{}, {b}}, {0.11492662691806055`, 
                1}, {}]\), 
            ",", \(AncestralLineage[
              3, {0.3223607589398818`, 0.517863837134862`}, {{b}}, {1}, {}]\),
             ",", \(AncestralLineage[
              4, {0.48529096572278896`, 
                0.517863837134862`}, {{a, c}}, {1}, {}]\), 
            ",", \(AncestralLineage[
              5, {0.517863837134862`, 
                1.5246611785364954`}, {{a, b, c}}, {1}, {}]\), 
            ",", \(AncestralLineage[
              6, {1.5246611785364954`, 
                1.5581431051287236`}, {{a, b, c}, {}}, {0.48913575253109154`, 
                1}, {}]\), 
            ",", \(AncestralLineage[
              7, {1.5246611785364954`, 
                1.5581431051287236`}, {{}, {a, b, c}}, {0.48913575253109154`, 
                1}, {}]\), 
            ",", \(AncestralLineage[
              8, {1.5581431051287236`, 
                1.655368377665858`}, {{a, b, c}}, {1}, {}]\), 
            ",", \(AncestralLineage[
              9, {1.655368377665858`, 
                1.7278195994170844`}, {{a, b, c}, {}}, {0.8125105445944757`, 
                1}, {}]\), 
            ",", \(AncestralLineage[
              10, {1.655368377665858`, 
                5.803899803199372`}, {{}, {a, b, c}}, {0.8125105445944757`, 
                1}, {}]\), 
            ",", \(AncestralLineage[
              11, {1.7278195994170844`, 
                2.9123438760363545`}, {{a, b, c, 
                  d}, {d}}, {0.8125105445944757`, 1}, {}]\), 
            ",", \(AncestralLineage[
              12, {2.9123438760363545`, 
                3.051081350478252`}, {{a, b, c, 
                  d}, {d}, {}}, {0.8125105445944757`, 0.8211640322266659`, 
                1}, {}]\), 
            ",", \(AncestralLineage[
              13, {2.9123438760363545`, 
                3.051081350478252`}, {{}, {d}}, {0.8211640322266659`, 
                1}, {}]\), 
            ",", \(AncestralLineage[
              14, {3.051081350478252`, 
                3.9325181869144528`}, {{a, b, c, 
                  d}, {d}}, {0.8125105445944757`, 1}, {}]\), 
            ",", \(AncestralLineage[
              15, {3.9325181869144528`, 
                4.130798875978213`}, {{a, b, c, 
                  d}, {}}, {0.016431884006824982`, 1}, {}]\), 
            ",", \(AncestralLineage[
              16, {3.9325181869144528`, 
                4.130798875978213`}, {{}, {a, b, c, 
                  d}, {d}}, {0.016431884006824982`, 0.8125105445944757`, 
                1}, {}]\), 
            ",", \(AncestralLineage[
              17, {4.130798875978213`, 
                4.8384282701987225`}, {{a, b, c, 
                  d}, {d}}, {0.8125105445944757`, 1}, {}]\), 
            ",", \(AncestralLineage[
              18, {4.8384282701987225`, 
                4.86647775888171`}, {{a, b, c, d}, {}}, {0.7440283682703366`, 
                1}, {}]\), 
            ",", \(AncestralLineage[
              19, {4.8384282701987225`, 
                4.86647775888171`}, {{}, {a, b, c, 
                  d}, {d}}, {0.7440283682703366`, 0.8125105445944757`, 
                1}, {}]\), 
            ",", \(AncestralLineage[
              20, {4.86647775888171`, 
                5.292690316029419`}, {{a, b, c, 
                  d}, {d}}, {0.8125105445944757`, 1}, {}]\), 
            ",", \(AncestralLineage[
              21, {5.292690316029419`, 
                5.346001768468149`}, {{a, b, c, 
                  d}, {d}, {}}, {0.8125105445944757`, 0.9265889024279855`, 
                1}, {}]\), 
            ",", \(AncestralLineage[
              22, {5.292690316029419`, 
                5.346001768468149`}, {{}, {d}}, {0.9265889024279855`, 
                1}, {}]\), 
            ",", \(AncestralLineage[
              23, {5.346001768468149`, 
                5.459871420495768`}, {{a, b, c, 
                  d}, {d}}, {0.8125105445944757`, 1}, {}]\), 
            ",", \(AncestralLineage[
              24, {5.459871420495768`, 
                5.5362846718122025`}, {{a, b, c, 
                  d}, {}}, {0.373144912940528`, 1}, {}]\), 
            ",", \(AncestralLineage[
              25, {5.459871420495768`, 
                6.827416708046677`}, {{}, {a, b, c, 
                  d}, {d}}, {0.373144912940528`, 0.8125105445944757`, 
                1}, {}]\), 
            ",", \(AncestralLineage[
              26, {5.5362846718122025`, 
                6.08624167552868`}, {{a, b, c, d}, {}}, {0.3247078812484602`, 
                1}, {}]\), 
            ",", \(AncestralLineage[
              27, {5.5362846718122025`, 
                6.233984034101634`}, {{}, {a, b, c, 
                  d}, {}}, {0.3247078812484602`, 0.373144912940528`, 
                1}, {}]\), 
            ",", \(AncestralLineage[
              28, {5.803899803199372`, 
                6.08624167552868`}, {{}, {a, b, 
                  c}, {}}, {0.8125105445944757`, 0.98211937306245`, 1}, {}]\),
             ",", \(AncestralLineage[
              29, {5.803899803199372`, 
                6.233984034101634`}, {{}, {a, b, c}}, {0.98211937306245`, 
                1}, {}]\), 
            ",", \(AncestralLineage[
              30, {6.08624167552868`, 
                6.448659507091728`}, {{a, b, c, d}, {}, {a, b, 
                  c}, {}}, {0.3247078812484602`, 0.8125105445944757`, 
                0.98211937306245`, 1}, {}]\), 
            ",", \(AncestralLineage[
              31, {6.233984034101634`, 
                6.448659507091728`}, {{}, {a, b, c, d}, {}, {a, b, 
                  c}}, {0.3247078812484602`, 0.373144912940528`, 
                0.98211937306245`, 1}, {}]\), 
            ",", \(AncestralLineage[
              32, {6.448659507091728`, 
                6.464771108623202`}, {{a, b, c, d}, {}, {a, b, 
                  c}}, {0.373144912940528`, 0.8125105445944757`, 1}, {}]\), 
            ",", \(AncestralLineage[
              33, {6.464771108623202`, 
                6.647288724524958`}, {{a, b, c, 
                  d}, {}}, {0.1338850878429638`, 1}, {}]\), 
            ",", \(AncestralLineage[
              34, {6.464771108623202`, 
                6.522868735762748`}, {{}, {a, b, c, d}, {}, {a, b, 
                  c}}, {0.1338850878429638`, 0.373144912940528`, 
                0.8125105445944757`, 1}, {}]\), ",", 
            RowBox[{"AncestralLineage", "[", 
              RowBox[{"35", ",", 
                RowBox[{"{", 
                  RowBox[{"6.522868735762748`", ",", 
                    InterpretationBox["\[Infinity]",
                      DirectedInfinity[ 1]]}], "}"}], 
                ",", \({{}, {a, b, c, d}, {}}\), 
                ",", \({0.1338850878429638`, 0.373144912940528`, 1}\), 
                ",", \({}\)}], "]"}], 
            ",", \(AncestralLineage[
              36, {6.522868735762748`, 
                6.647288724524958`}, {{}, {a, b, c}}, {0.8125105445944757`, 
                1}, {}]\), 
            ",", \(AncestralLineage[
              37, {6.647288724524958`, 
                6.827416708046677`}, {{a, b, c, d}, {}, {a, b, 
                  c}}, {0.1338850878429638`, 0.8125105445944757`, 1}, {}]\), 
            ",", \(AncestralLineage[
              38, {6.827416708046677`, 
                7.08640552134988`}, {{a, b, c, d}, {}, {a, b, c, 
                  d}}, {0.1338850878429638`, 0.373144912940528`, 1}, {}]\), 
            ",", \(AncestralLineage[
              39, {7.08640552134988`, 
                7.383867800378267`}, {{a, b, c, 
                  d}, {}}, {0.1338850878429638`, 1}, {}]\), 
            ",", \(AncestralLineage[
              40, {7.08640552134988`, 
                7.378620012125975`}, {{}, {a, b, c, d}}, {0.373144912940528`, 
                1}, {}]\), ",", 
            RowBox[{"AncestralLineage", "[", 
              RowBox[{"41", ",", 
                RowBox[{"{", 
                  RowBox[{"7.378620012125975`", ",", 
                    InterpretationBox["\[Infinity]",
                      DirectedInfinity[ 1]]}], "}"}], 
                ",", \({{}, {a, b, c, d}, {}}\), 
                ",", \({0.373144912940528`, 0.7325962355113973`, 1}\), 
                ",", \({}\)}], "]"}], 
            ",", \(AncestralLineage[
              42, {7.378620012125975`, 
                7.383867800378267`}, {{}, {a, b, c, 
                  d}}, {0.7325962355113973`, 1}, {}]\), ",", 
            RowBox[{"AncestralLineage", "[", 
              RowBox[{"43", ",", 
                RowBox[{"{", 
                  RowBox[{"7.383867800378267`", ",", 
                    InterpretationBox["\[Infinity]",
                      DirectedInfinity[ 1]]}], "}"}], 
                ",", \({{a, b, c, d}, {}, {a, b, c, d}}\), 
                ",", \({0.1338850878429638`, 0.7325962355113973`, 1}\), 
                ",", \({}\)}], "]"}]}], "}"}]}],
      SequenceForm[ "G=", {
        AncestralLineage[ a, {0, 0.48529096572278896}, {{a}}, {1}, {}], 
        AncestralLineage[ b, {0, 0.23398316436020319}, {{b}}, {1}, {}], 
        AncestralLineage[ c, {0, 0.48529096572278896}, {{c}}, {1}, {}], 
        AncestralLineage[ d, {0, 1.7278195994170844}, {{d}}, {1}, {}], 
        AncestralLineage[ 
        1, {0.23398316436020319, 0.32236075893988181}, {{b}, {}}, {
          0.11492662691806055, 1}, {}], 
        AncestralLineage[ 
        2, {0.23398316436020319, 0.32236075893988181}, {{}, {b}}, {
          0.11492662691806055, 1}, {}], 
        AncestralLineage[ 
        3, {0.32236075893988181, 0.51786383713486195}, {{b}}, {1}, {}], 
        AncestralLineage[ 
        4, {0.48529096572278896, 0.51786383713486195}, {{a, c}}, {1}, {}], 
        AncestralLineage[ 
        5, {0.51786383713486195, 1.5246611785364954}, {{a, b, c}}, {1}, {}], 
        AncestralLineage[ 
        6, {1.5246611785364954, 1.5581431051287236}, {{a, b, c}, {}}, {
          0.48913575253109154, 1}, {}], 
        AncestralLineage[ 
        7, {1.5246611785364954, 1.5581431051287236}, {{}, {a, b, c}}, {
          0.48913575253109154, 1}, {}], 
        AncestralLineage[ 
        8, {1.5581431051287236, 1.6553683776658581}, {{a, b, c}}, {1}, {}], 
        AncestralLineage[ 
        9, {1.6553683776658581, 1.7278195994170844}, {{a, b, c}, {}}, {
          0.81251054459447569, 1}, {}], 
        AncestralLineage[ 
        10, {1.6553683776658581, 5.8038998031993723}, {{}, {a, b, c}}, {
          0.81251054459447569, 1}, {}], 
        AncestralLineage[ 
        11, {1.7278195994170844, 2.9123438760363545}, {{a, b, c, d}, {d}}, {
          0.81251054459447569, 1}, {}], 
        AncestralLineage[ 
        12, {2.9123438760363545, 3.0510813504782521}, {{a, b, c, d}, {
          d}, {}}, {0.81251054459447569, 0.8211640322266659, 1}, {}], 
        AncestralLineage[ 
        13, {2.9123438760363545, 3.0510813504782521}, {{}, {d}}, {
          0.8211640322266659, 1}, {}], 
        AncestralLineage[ 
        14, {3.0510813504782521, 3.9325181869144528}, {{a, b, c, d}, {d}}, {
          0.81251054459447569, 1}, {}], 
        AncestralLineage[ 
        15, {3.9325181869144528, 4.130798875978213}, {{a, b, c, d}, {}}, {
          0.016431884006824982, 1}, {}], 
        AncestralLineage[ 
        16, {3.9325181869144528, 4.130798875978213}, {{}, {a, b, c, d}, {
          d}}, {0.016431884006824982, 0.81251054459447569, 1}, {}], 
        AncestralLineage[ 
        17, {4.130798875978213, 4.8384282701987225}, {{a, b, c, d}, {d}}, {
          0.81251054459447569, 1}, {}], 
        AncestralLineage[ 
        18, {4.8384282701987225, 4.8664777588817101}, {{a, b, c, d}, {}}, {
          0.74402836827033658, 1}, {}], 
        AncestralLineage[ 
        19, {4.8384282701987225, 4.8664777588817101}, {{}, {a, b, c, d}, {
          d}}, {0.74402836827033658, 0.81251054459447569, 1}, {}], 
        AncestralLineage[ 
        20, {4.8664777588817101, 5.292690316029419}, {{a, b, c, d}, {d}}, {
          0.81251054459447569, 1}, {}], 
        AncestralLineage[ 
        21, {5.292690316029419, 5.3460017684681489}, {{a, b, c, d}, {
          d}, {}}, {0.81251054459447569, 0.92658890242798553, 1}, {}], 
        AncestralLineage[ 
        22, {5.292690316029419, 5.3460017684681489}, {{}, {d}}, {
          0.92658890242798553, 1}, {}], 
        AncestralLineage[ 
        23, {5.3460017684681489, 5.4598714204957677}, {{a, b, c, d}, {d}}, {
          0.81251054459447569, 1}, {}], 
        AncestralLineage[ 
        24, {5.4598714204957677, 5.5362846718122025}, {{a, b, c, d}, {}}, {
          0.37314491294052798, 1}, {}], 
        AncestralLineage[ 
        25, {5.4598714204957677, 6.8274167080466768}, {{}, {a, b, c, d}, {
          d}}, {0.37314491294052798, 0.81251054459447569, 1}, {}], 
        AncestralLineage[ 
        26, {5.5362846718122025, 6.0862416755286803}, {{a, b, c, d}, {}}, {
          0.32470788124846017, 1}, {}], 
        AncestralLineage[ 
        27, {5.5362846718122025, 6.2339840341016339}, {{}, {a, b, c, 
          d}, {}}, {0.32470788124846017, 0.37314491294052798, 1}, {}], 
        AncestralLineage[ 
        28, {5.8038998031993723, 6.0862416755286803}, {{}, {a, b, c}, {}}, {
          0.81251054459447569, 0.98211937306245001, 1}, {}], 
        AncestralLineage[ 
        29, {5.8038998031993723, 6.2339840341016339}, {{}, {a, b, c}}, {
          0.98211937306245001, 1}, {}], 
        AncestralLineage[ 
        30, {6.0862416755286803, 6.4486595070917279}, {{a, b, c, d}, {}, {a, 
          b, c}, {}}, {0.32470788124846017, 0.81251054459447569, 
          0.98211937306245001, 1}, {}], 
        AncestralLineage[ 
        31, {6.2339840341016339, 6.4486595070917279}, {{}, {a, b, c, d}, {}, {
          a, b, c}}, {0.32470788124846017, 0.37314491294052798, 
          0.98211937306245001, 1}, {}], 
        AncestralLineage[ 
        32, {6.4486595070917279, 6.4647711086232018}, {{a, b, c, d}, {}, {a, 
          b, c}}, {0.37314491294052798, 0.81251054459447569, 1}, {}], 
        AncestralLineage[ 
        33, {6.4647711086232018, 6.6472887245249579}, {{a, b, c, d}, {}}, {
          0.1338850878429638, 1}, {}], 
        AncestralLineage[ 
        34, {6.4647711086232018, 6.5228687357627484}, {{}, {a, b, c, d}, {}, {
          a, b, c}}, {0.1338850878429638, 0.37314491294052798, 
          0.81251054459447569, 1}, {}], 
        AncestralLineage[ 35, {6.5228687357627484, 
          DirectedInfinity[ 1]}, {{}, {a, b, c, d}, {}}, {0.1338850878429638, 
          0.37314491294052798, 1}, {}], 
        AncestralLineage[ 
        36, {6.5228687357627484, 6.6472887245249579}, {{}, {a, b, c}}, {
          0.81251054459447569, 1}, {}], 
        AncestralLineage[ 
        37, {6.6472887245249579, 6.8274167080466768}, {{a, b, c, d}, {}, {a, 
          b, c}}, {0.1338850878429638, 0.81251054459447569, 1}, {}], 
        AncestralLineage[ 
        38, {6.8274167080466768, 7.0864055213498798}, {{a, b, c, d}, {}, {a, 
          b, c, d}}, {0.1338850878429638, 0.37314491294052798, 1}, {}], 
        AncestralLineage[ 
        39, {7.0864055213498798, 7.3838678003782672}, {{a, b, c, d}, {}}, {
          0.1338850878429638, 1}, {}], 
        AncestralLineage[ 
        40, {7.0864055213498798, 7.3786200121259746}, {{}, {a, b, c, d}}, {
          0.37314491294052798, 1}, {}], 
        AncestralLineage[ 41, {7.3786200121259746, 
          DirectedInfinity[ 1]}, {{}, {a, b, c, d}, {}}, {0.37314491294052798,
           0.7325962355113973, 1}, {}], 
        AncestralLineage[ 
        42, {7.3786200121259746, 7.3838678003782672}, {{}, {a, b, c, d}}, {
          0.7325962355113973, 1}, {}], 
        AncestralLineage[ 43, {7.3838678003782672, 
          DirectedInfinity[ 1]}, {{a, b, c, d}, {}, {a, b, c, d}}, {
          0.1338850878429638, 0.7325962355113973, 1}, {}]}],
      Editable->False]], "Print",
  CellLabel->"From In[346]:="],

Cell[BoxData[
    \({0.21290123978714287`, 2, None}\)], "Print",
  CellLabel->"From In[346]:="],

Cell[BoxData[
    InterpretationBox[\("Coalescing "\[InvisibleSpace]{41, 
          43}\[InvisibleSpace]"; current lineages "\[InvisibleSpace]{35, 41, 
          43}\),
      SequenceForm[ 
      "Coalescing ", {41, 43}, "; current lineages ", {35, 41, 43}],
      Editable->False]], "Print",
  CellLabel->"From In[346]:="],

Cell[BoxData[
    InterpretationBox[
      RowBox[{"\<\"G=\"\>", "\[InvisibleSpace]", 
        RowBox[{"{", 
          
          RowBox[{\(AncestralLineage[
              a, {0, 0.48529096572278896`}, {{a}}, {1}, {}]\), 
            ",", \(AncestralLineage[
              b, {0, 0.2339831643602032`}, {{b}}, {1}, {}]\), 
            ",", \(AncestralLineage[
              c, {0, 0.48529096572278896`}, {{c}}, {1}, {}]\), 
            ",", \(AncestralLineage[
              d, {0, 1.7278195994170844`}, {{d}}, {1}, {}]\), 
            ",", \(AncestralLineage[
              1, {0.2339831643602032`, 
                0.3223607589398818`}, {{b}, {}}, {0.11492662691806055`, 
                1}, {}]\), 
            ",", \(AncestralLineage[
              2, {0.2339831643602032`, 
                0.3223607589398818`}, {{}, {b}}, {0.11492662691806055`, 
                1}, {}]\), 
            ",", \(AncestralLineage[
              3, {0.3223607589398818`, 0.517863837134862`}, {{b}}, {1}, {}]\),
             ",", \(AncestralLineage[
              4, {0.48529096572278896`, 
                0.517863837134862`}, {{a, c}}, {1}, {}]\), 
            ",", \(AncestralLineage[
              5, {0.517863837134862`, 
                1.5246611785364954`}, {{a, b, c}}, {1}, {}]\), 
            ",", \(AncestralLineage[
              6, {1.5246611785364954`, 
                1.5581431051287236`}, {{a, b, c}, {}}, {0.48913575253109154`, 
                1}, {}]\), 
            ",", \(AncestralLineage[
              7, {1.5246611785364954`, 
                1.5581431051287236`}, {{}, {a, b, c}}, {0.48913575253109154`, 
                1}, {}]\), 
            ",", \(AncestralLineage[
              8, {1.5581431051287236`, 
                1.655368377665858`}, {{a, b, c}}, {1}, {}]\), 
            ",", \(AncestralLineage[
              9, {1.655368377665858`, 
                1.7278195994170844`}, {{a, b, c}, {}}, {0.8125105445944757`, 
                1}, {}]\), 
            ",", \(AncestralLineage[
              10, {1.655368377665858`, 
                5.803899803199372`}, {{}, {a, b, c}}, {0.8125105445944757`, 
                1}, {}]\), 
            ",", \(AncestralLineage[
              11, {1.7278195994170844`, 
                2.9123438760363545`}, {{a, b, c, 
                  d}, {d}}, {0.8125105445944757`, 1}, {}]\), 
            ",", \(AncestralLineage[
              12, {2.9123438760363545`, 
                3.051081350478252`}, {{a, b, c, 
                  d}, {d}, {}}, {0.8125105445944757`, 0.8211640322266659`, 
                1}, {}]\), 
            ",", \(AncestralLineage[
              13, {2.9123438760363545`, 
                3.051081350478252`}, {{}, {d}}, {0.8211640322266659`, 
                1}, {}]\), 
            ",", \(AncestralLineage[
              14, {3.051081350478252`, 
                3.9325181869144528`}, {{a, b, c, 
                  d}, {d}}, {0.8125105445944757`, 1}, {}]\), 
            ",", \(AncestralLineage[
              15, {3.9325181869144528`, 
                4.130798875978213`}, {{a, b, c, 
                  d}, {}}, {0.016431884006824982`, 1}, {}]\), 
            ",", \(AncestralLineage[
              16, {3.9325181869144528`, 
                4.130798875978213`}, {{}, {a, b, c, 
                  d}, {d}}, {0.016431884006824982`, 0.8125105445944757`, 
                1}, {}]\), 
            ",", \(AncestralLineage[
              17, {4.130798875978213`, 
                4.8384282701987225`}, {{a, b, c, 
                  d}, {d}}, {0.8125105445944757`, 1}, {}]\), 
            ",", \(AncestralLineage[
              18, {4.8384282701987225`, 
                4.86647775888171`}, {{a, b, c, d}, {}}, {0.7440283682703366`, 
                1}, {}]\), 
            ",", \(AncestralLineage[
              19, {4.8384282701987225`, 
                4.86647775888171`}, {{}, {a, b, c, 
                  d}, {d}}, {0.7440283682703366`, 0.8125105445944757`, 
                1}, {}]\), 
            ",", \(AncestralLineage[
              20, {4.86647775888171`, 
                5.292690316029419`}, {{a, b, c, 
                  d}, {d}}, {0.8125105445944757`, 1}, {}]\), 
            ",", \(AncestralLineage[
              21, {5.292690316029419`, 
                5.346001768468149`}, {{a, b, c, 
                  d}, {d}, {}}, {0.8125105445944757`, 0.9265889024279855`, 
                1}, {}]\), 
            ",", \(AncestralLineage[
              22, {5.292690316029419`, 
                5.346001768468149`}, {{}, {d}}, {0.9265889024279855`, 
                1}, {}]\), 
            ",", \(AncestralLineage[
              23, {5.346001768468149`, 
                5.459871420495768`}, {{a, b, c, 
                  d}, {d}}, {0.8125105445944757`, 1}, {}]\), 
            ",", \(AncestralLineage[
              24, {5.459871420495768`, 
                5.5362846718122025`}, {{a, b, c, 
                  d}, {}}, {0.373144912940528`, 1}, {}]\), 
            ",", \(AncestralLineage[
              25, {5.459871420495768`, 
                6.827416708046677`}, {{}, {a, b, c, 
                  d}, {d}}, {0.373144912940528`, 0.8125105445944757`, 
                1}, {}]\), 
            ",", \(AncestralLineage[
              26, {5.5362846718122025`, 
                6.08624167552868`}, {{a, b, c, d}, {}}, {0.3247078812484602`, 
                1}, {}]\), 
            ",", \(AncestralLineage[
              27, {5.5362846718122025`, 
                6.233984034101634`}, {{}, {a, b, c, 
                  d}, {}}, {0.3247078812484602`, 0.373144912940528`, 
                1}, {}]\), 
            ",", \(AncestralLineage[
              28, {5.803899803199372`, 
                6.08624167552868`}, {{}, {a, b, 
                  c}, {}}, {0.8125105445944757`, 0.98211937306245`, 1}, {}]\),
             ",", \(AncestralLineage[
              29, {5.803899803199372`, 
                6.233984034101634`}, {{}, {a, b, c}}, {0.98211937306245`, 
                1}, {}]\), 
            ",", \(AncestralLineage[
              30, {6.08624167552868`, 
                6.448659507091728`}, {{a, b, c, d}, {}, {a, b, 
                  c}, {}}, {0.3247078812484602`, 0.8125105445944757`, 
                0.98211937306245`, 1}, {}]\), 
            ",", \(AncestralLineage[
              31, {6.233984034101634`, 
                6.448659507091728`}, {{}, {a, b, c, d}, {}, {a, b, 
                  c}}, {0.3247078812484602`, 0.373144912940528`, 
                0.98211937306245`, 1}, {}]\), 
            ",", \(AncestralLineage[
              32, {6.448659507091728`, 
                6.464771108623202`}, {{a, b, c, d}, {}, {a, b, 
                  c}}, {0.373144912940528`, 0.8125105445944757`, 1}, {}]\), 
            ",", \(AncestralLineage[
              33, {6.464771108623202`, 
                6.647288724524958`}, {{a, b, c, 
                  d}, {}}, {0.1338850878429638`, 1}, {}]\), 
            ",", \(AncestralLineage[
              34, {6.464771108623202`, 
                6.522868735762748`}, {{}, {a, b, c, d}, {}, {a, b, 
                  c}}, {0.1338850878429638`, 0.373144912940528`, 
                0.8125105445944757`, 1}, {}]\), ",", 
            RowBox[{"AncestralLineage", "[", 
              RowBox[{"35", ",", 
                RowBox[{"{", 
                  RowBox[{"6.522868735762748`", ",", 
                    InterpretationBox["\[Infinity]",
                      DirectedInfinity[ 1]]}], "}"}], 
                ",", \({{}, {a, b, c, d}, {}}\), 
                ",", \({0.1338850878429638`, 0.373144912940528`, 1}\), 
                ",", \({}\)}], "]"}], 
            ",", \(AncestralLineage[
              36, {6.522868735762748`, 
                6.647288724524958`}, {{}, {a, b, c}}, {0.8125105445944757`, 
                1}, {}]\), 
            ",", \(AncestralLineage[
              37, {6.647288724524958`, 
                6.827416708046677`}, {{a, b, c, d}, {}, {a, b, 
                  c}}, {0.1338850878429638`, 0.8125105445944757`, 1}, {}]\), 
            ",", \(AncestralLineage[
              38, {6.827416708046677`, 
                7.08640552134988`}, {{a, b, c, d}, {}, {a, b, c, 
                  d}}, {0.1338850878429638`, 0.373144912940528`, 1}, {}]\), 
            ",", \(AncestralLineage[
              39, {7.08640552134988`, 
                7.383867800378267`}, {{a, b, c, 
                  d}, {}}, {0.1338850878429638`, 1}, {}]\), 
            ",", \(AncestralLineage[
              40, {7.08640552134988`, 
                7.378620012125975`}, {{}, {a, b, c, d}}, {0.373144912940528`, 
                1}, {}]\), 
            ",", \(AncestralLineage[
              41, {7.378620012125975`, 
                7.59676904016541`}, {{}, {a, b, c, 
                  d}, {}}, {0.373144912940528`, 0.7325962355113973`, 
                1}, {}]\), 
            ",", \(AncestralLineage[
              42, {7.378620012125975`, 
                7.383867800378267`}, {{}, {a, b, c, 
                  d}}, {0.7325962355113973`, 1}, {}]\), 
            ",", \(AncestralLineage[
              43, {7.383867800378267`, 
                7.59676904016541`}, {{a, b, c, d}, {}, {a, b, c, 
                  d}}, {0.1338850878429638`, 0.7325962355113973`, 1}, {}]\), 
            ",", 
            RowBox[{"AncestralLineage", "[", 
              RowBox[{"44", ",", 
                RowBox[{"{", 
                  RowBox[{"7.59676904016541`", ",", 
                    InterpretationBox["\[Infinity]",
                      DirectedInfinity[ 1]]}], "}"}], 
                ",", \({{a, b, c, d}, {}, {a, b, c, d}}\), 
                ",", \({0.1338850878429638`, 0.373144912940528`, 1}\), 
                ",", \({}\)}], "]"}]}], "}"}]}],
      SequenceForm[ "G=", {
        AncestralLineage[ a, {0, 0.48529096572278896}, {{a}}, {1}, {}], 
        AncestralLineage[ b, {0, 0.23398316436020319}, {{b}}, {1}, {}], 
        AncestralLineage[ c, {0, 0.48529096572278896}, {{c}}, {1}, {}], 
        AncestralLineage[ d, {0, 1.7278195994170844}, {{d}}, {1}, {}], 
        AncestralLineage[ 
        1, {0.23398316436020319, 0.32236075893988181}, {{b}, {}}, {
          0.11492662691806055, 1}, {}], 
        AncestralLineage[ 
        2, {0.23398316436020319, 0.32236075893988181}, {{}, {b}}, {
          0.11492662691806055, 1}, {}], 
        AncestralLineage[ 
        3, {0.32236075893988181, 0.51786383713486195}, {{b}}, {1}, {}], 
        AncestralLineage[ 
        4, {0.48529096572278896, 0.51786383713486195}, {{a, c}}, {1}, {}], 
        AncestralLineage[ 
        5, {0.51786383713486195, 1.5246611785364954}, {{a, b, c}}, {1}, {}], 
        AncestralLineage[ 
        6, {1.5246611785364954, 1.5581431051287236}, {{a, b, c}, {}}, {
          0.48913575253109154, 1}, {}], 
        AncestralLineage[ 
        7, {1.5246611785364954, 1.5581431051287236}, {{}, {a, b, c}}, {
          0.48913575253109154, 1}, {}], 
        AncestralLineage[ 
        8, {1.5581431051287236, 1.6553683776658581}, {{a, b, c}}, {1}, {}], 
        AncestralLineage[ 
        9, {1.6553683776658581, 1.7278195994170844}, {{a, b, c}, {}}, {
          0.81251054459447569, 1}, {}], 
        AncestralLineage[ 
        10, {1.6553683776658581, 5.8038998031993723}, {{}, {a, b, c}}, {
          0.81251054459447569, 1}, {}], 
        AncestralLineage[ 
        11, {1.7278195994170844, 2.9123438760363545}, {{a, b, c, d}, {d}}, {
          0.81251054459447569, 1}, {}], 
        AncestralLineage[ 
        12, {2.9123438760363545, 3.0510813504782521}, {{a, b, c, d}, {
          d}, {}}, {0.81251054459447569, 0.8211640322266659, 1}, {}], 
        AncestralLineage[ 
        13, {2.9123438760363545, 3.0510813504782521}, {{}, {d}}, {
          0.8211640322266659, 1}, {}], 
        AncestralLineage[ 
        14, {3.0510813504782521, 3.9325181869144528}, {{a, b, c, d}, {d}}, {
          0.81251054459447569, 1}, {}], 
        AncestralLineage[ 
        15, {3.9325181869144528, 4.130798875978213}, {{a, b, c, d}, {}}, {
          0.016431884006824982, 1}, {}], 
        AncestralLineage[ 
        16, {3.9325181869144528, 4.130798875978213}, {{}, {a, b, c, d}, {
          d}}, {0.016431884006824982, 0.81251054459447569, 1}, {}], 
        AncestralLineage[ 
        17, {4.130798875978213, 4.8384282701987225}, {{a, b, c, d}, {d}}, {
          0.81251054459447569, 1}, {}], 
        AncestralLineage[ 
        18, {4.8384282701987225, 4.8664777588817101}, {{a, b, c, d}, {}}, {
          0.74402836827033658, 1}, {}], 
        AncestralLineage[ 
        19, {4.8384282701987225, 4.8664777588817101}, {{}, {a, b, c, d}, {
          d}}, {0.74402836827033658, 0.81251054459447569, 1}, {}], 
        AncestralLineage[ 
        20, {4.8664777588817101, 5.292690316029419}, {{a, b, c, d}, {d}}, {
          0.81251054459447569, 1}, {}], 
        AncestralLineage[ 
        21, {5.292690316029419, 5.3460017684681489}, {{a, b, c, d}, {
          d}, {}}, {0.81251054459447569, 0.92658890242798553, 1}, {}], 
        AncestralLineage[ 
        22, {5.292690316029419, 5.3460017684681489}, {{}, {d}}, {
          0.92658890242798553, 1}, {}], 
        AncestralLineage[ 
        23, {5.3460017684681489, 5.4598714204957677}, {{a, b, c, d}, {d}}, {
          0.81251054459447569, 1}, {}], 
        AncestralLineage[ 
        24, {5.4598714204957677, 5.5362846718122025}, {{a, b, c, d}, {}}, {
          0.37314491294052798, 1}, {}], 
        AncestralLineage[ 
        25, {5.4598714204957677, 6.8274167080466768}, {{}, {a, b, c, d}, {
          d}}, {0.37314491294052798, 0.81251054459447569, 1}, {}], 
        AncestralLineage[ 
        26, {5.5362846718122025, 6.0862416755286803}, {{a, b, c, d}, {}}, {
          0.32470788124846017, 1}, {}], 
        AncestralLineage[ 
        27, {5.5362846718122025, 6.2339840341016339}, {{}, {a, b, c, 
          d}, {}}, {0.32470788124846017, 0.37314491294052798, 1}, {}], 
        AncestralLineage[ 
        28, {5.8038998031993723, 6.0862416755286803}, {{}, {a, b, c}, {}}, {
          0.81251054459447569, 0.98211937306245001, 1}, {}], 
        AncestralLineage[ 
        29, {5.8038998031993723, 6.2339840341016339}, {{}, {a, b, c}}, {
          0.98211937306245001, 1}, {}], 
        AncestralLineage[ 
        30, {6.0862416755286803, 6.4486595070917279}, {{a, b, c, d}, {}, {a, 
          b, c}, {}}, {0.32470788124846017, 0.81251054459447569, 
          0.98211937306245001, 1}, {}], 
        AncestralLineage[ 
        31, {6.2339840341016339, 6.4486595070917279}, {{}, {a, b, c, d}, {}, {
          a, b, c}}, {0.32470788124846017, 0.37314491294052798, 
          0.98211937306245001, 1}, {}], 
        AncestralLineage[ 
        32, {6.4486595070917279, 6.4647711086232018}, {{a, b, c, d}, {}, {a, 
          b, c}}, {0.37314491294052798, 0.81251054459447569, 1}, {}], 
        AncestralLineage[ 
        33, {6.4647711086232018, 6.6472887245249579}, {{a, b, c, d}, {}}, {
          0.1338850878429638, 1}, {}], 
        AncestralLineage[ 
        34, {6.4647711086232018, 6.5228687357627484}, {{}, {a, b, c, d}, {}, {
          a, b, c}}, {0.1338850878429638, 0.37314491294052798, 
          0.81251054459447569, 1}, {}], 
        AncestralLineage[ 35, {6.5228687357627484, 
          DirectedInfinity[ 1]}, {{}, {a, b, c, d}, {}}, {0.1338850878429638, 
          0.37314491294052798, 1}, {}], 
        AncestralLineage[ 
        36, {6.5228687357627484, 6.6472887245249579}, {{}, {a, b, c}}, {
          0.81251054459447569, 1}, {}], 
        AncestralLineage[ 
        37, {6.6472887245249579, 6.8274167080466768}, {{a, b, c, d}, {}, {a, 
          b, c}}, {0.1338850878429638, 0.81251054459447569, 1}, {}], 
        AncestralLineage[ 
        38, {6.8274167080466768, 7.0864055213498798}, {{a, b, c, d}, {}, {a, 
          b, c, d}}, {0.1338850878429638, 0.37314491294052798, 1}, {}], 
        AncestralLineage[ 
        39, {7.0864055213498798, 7.3838678003782672}, {{a, b, c, d}, {}}, {
          0.1338850878429638, 1}, {}], 
        AncestralLineage[ 
        40, {7.0864055213498798, 7.3786200121259746}, {{}, {a, b, c, d}}, {
          0.37314491294052798, 1}, {}], 
        AncestralLineage[ 
        41, {7.3786200121259746, 7.5967690401654098}, {{}, {a, b, c, 
          d}, {}}, {0.37314491294052798, 0.7325962355113973, 1}, {}], 
        AncestralLineage[ 
        42, {7.3786200121259746, 7.3838678003782672}, {{}, {a, b, c, d}}, {
          0.7325962355113973, 1}, {}], 
        AncestralLineage[ 
        43, {7.3838678003782672, 7.5967690401654098}, {{a, b, c, d}, {}, {a, 
          b, c, d}}, {0.1338850878429638, 0.7325962355113973, 1}, {}], 
        AncestralLineage[ 44, {7.5967690401654098, 
          DirectedInfinity[ 1]}, {{a, b, c, d}, {}, {a, b, c, d}}, {
          0.1338850878429638, 0.37314491294052798, 1}, {}]}],
      Editable->False]], "Print",
  CellLabel->"From In[346]:="],

Cell[BoxData[
    \({0.06819305539026996`, 1, None}\)], "Print",
  CellLabel->"From In[346]:="],

Cell[BoxData[
    InterpretationBox[\("Coalescing "\[InvisibleSpace]{35, 
          44}\[InvisibleSpace]"; current lineages "\[InvisibleSpace]{35, 
          44}\),
      SequenceForm[ "Coalescing ", {35, 44}, "; current lineages ", {35, 44}],
      
      Editable->False]], "Print",
  CellLabel->"From In[346]:="],

Cell[BoxData[
    InterpretationBox[
      RowBox[{"\<\"G=\"\>", "\[InvisibleSpace]", 
        RowBox[{"{", 
          
          RowBox[{\(AncestralLineage[
              a, {0, 0.48529096572278896`}, {{a}}, {1}, {}]\), 
            ",", \(AncestralLineage[
              b, {0, 0.2339831643602032`}, {{b}}, {1}, {}]\), 
            ",", \(AncestralLineage[
              c, {0, 0.48529096572278896`}, {{c}}, {1}, {}]\), 
            ",", \(AncestralLineage[
              d, {0, 1.7278195994170844`}, {{d}}, {1}, {}]\), 
            ",", \(AncestralLineage[
              1, {0.2339831643602032`, 
                0.3223607589398818`}, {{b}, {}}, {0.11492662691806055`, 
                1}, {}]\), 
            ",", \(AncestralLineage[
              2, {0.2339831643602032`, 
                0.3223607589398818`}, {{}, {b}}, {0.11492662691806055`, 
                1}, {}]\), 
            ",", \(AncestralLineage[
              3, {0.3223607589398818`, 0.517863837134862`}, {{b}}, {1}, {}]\),
             ",", \(AncestralLineage[
              4, {0.48529096572278896`, 
                0.517863837134862`}, {{a, c}}, {1}, {}]\), 
            ",", \(AncestralLineage[
              5, {0.517863837134862`, 
                1.5246611785364954`}, {{a, b, c}}, {1}, {}]\), 
            ",", \(AncestralLineage[
              6, {1.5246611785364954`, 
                1.5581431051287236`}, {{a, b, c}, {}}, {0.48913575253109154`, 
                1}, {}]\), 
            ",", \(AncestralLineage[
              7, {1.5246611785364954`, 
                1.5581431051287236`}, {{}, {a, b, c}}, {0.48913575253109154`, 
                1}, {}]\), 
            ",", \(AncestralLineage[
              8, {1.5581431051287236`, 
                1.655368377665858`}, {{a, b, c}}, {1}, {}]\), 
            ",", \(AncestralLineage[
              9, {1.655368377665858`, 
                1.7278195994170844`}, {{a, b, c}, {}}, {0.8125105445944757`, 
                1}, {}]\), 
            ",", \(AncestralLineage[
              10, {1.655368377665858`, 
                5.803899803199372`}, {{}, {a, b, c}}, {0.8125105445944757`, 
                1}, {}]\), 
            ",", \(AncestralLineage[
              11, {1.7278195994170844`, 
                2.9123438760363545`}, {{a, b, c, 
                  d}, {d}}, {0.8125105445944757`, 1}, {}]\), 
            ",", \(AncestralLineage[
              12, {2.9123438760363545`, 
                3.051081350478252`}, {{a, b, c, 
                  d}, {d}, {}}, {0.8125105445944757`, 0.8211640322266659`, 
                1}, {}]\), 
            ",", \(AncestralLineage[
              13, {2.9123438760363545`, 
                3.051081350478252`}, {{}, {d}}, {0.8211640322266659`, 
                1}, {}]\), 
            ",", \(AncestralLineage[
              14, {3.051081350478252`, 
                3.9325181869144528`}, {{a, b, c, 
                  d}, {d}}, {0.8125105445944757`, 1}, {}]\), 
            ",", \(AncestralLineage[
              15, {3.9325181869144528`, 
                4.130798875978213`}, {{a, b, c, 
                  d}, {}}, {0.016431884006824982`, 1}, {}]\), 
            ",", \(AncestralLineage[
              16, {3.9325181869144528`, 
                4.130798875978213`}, {{}, {a, b, c, 
                  d}, {d}}, {0.016431884006824982`, 0.8125105445944757`, 
                1}, {}]\), 
            ",", \(AncestralLineage[
              17, {4.130798875978213`, 
                4.8384282701987225`}, {{a, b, c, 
                  d}, {d}}, {0.8125105445944757`, 1}, {}]\), 
            ",", \(AncestralLineage[
              18, {4.8384282701987225`, 
                4.86647775888171`}, {{a, b, c, d}, {}}, {0.7440283682703366`, 
                1}, {}]\), 
            ",", \(AncestralLineage[
              19, {4.8384282701987225`, 
                4.86647775888171`}, {{}, {a, b, c, 
                  d}, {d}}, {0.7440283682703366`, 0.8125105445944757`, 
                1}, {}]\), 
            ",", \(AncestralLineage[
              20, {4.86647775888171`, 
                5.292690316029419`}, {{a, b, c, 
                  d}, {d}}, {0.8125105445944757`, 1}, {}]\), 
            ",", \(AncestralLineage[
              21, {5.292690316029419`, 
                5.346001768468149`}, {{a, b, c, 
                  d}, {d}, {}}, {0.8125105445944757`, 0.9265889024279855`, 
                1}, {}]\), 
            ",", \(AncestralLineage[
              22, {5.292690316029419`, 
                5.346001768468149`}, {{}, {d}}, {0.9265889024279855`, 
                1}, {}]\), 
            ",", \(AncestralLineage[
              23, {5.346001768468149`, 
                5.459871420495768`}, {{a, b, c, 
                  d}, {d}}, {0.8125105445944757`, 1}, {}]\), 
            ",", \(AncestralLineage[
              24, {5.459871420495768`, 
                5.5362846718122025`}, {{a, b, c, 
                  d}, {}}, {0.373144912940528`, 1}, {}]\), 
            ",", \(AncestralLineage[
              25, {5.459871420495768`, 
                6.827416708046677`}, {{}, {a, b, c, 
                  d}, {d}}, {0.373144912940528`, 0.8125105445944757`, 
                1}, {}]\), 
            ",", \(AncestralLineage[
              26, {5.5362846718122025`, 
                6.08624167552868`}, {{a, b, c, d}, {}}, {0.3247078812484602`, 
                1}, {}]\), 
            ",", \(AncestralLineage[
              27, {5.5362846718122025`, 
                6.233984034101634`}, {{}, {a, b, c, 
                  d}, {}}, {0.3247078812484602`, 0.373144912940528`, 
                1}, {}]\), 
            ",", \(AncestralLineage[
              28, {5.803899803199372`, 
                6.08624167552868`}, {{}, {a, b, 
                  c}, {}}, {0.8125105445944757`, 0.98211937306245`, 1}, {}]\),
             ",", \(AncestralLineage[
              29, {5.803899803199372`, 
                6.233984034101634`}, {{}, {a, b, c}}, {0.98211937306245`, 
                1}, {}]\), 
            ",", \(AncestralLineage[
              30, {6.08624167552868`, 
                6.448659507091728`}, {{a, b, c, d}, {}, {a, b, 
                  c}, {}}, {0.3247078812484602`, 0.8125105445944757`, 
                0.98211937306245`, 1}, {}]\), 
            ",", \(AncestralLineage[
              31, {6.233984034101634`, 
                6.448659507091728`}, {{}, {a, b, c, d}, {}, {a, b, 
                  c}}, {0.3247078812484602`, 0.373144912940528`, 
                0.98211937306245`, 1}, {}]\), 
            ",", \(AncestralLineage[
              32, {6.448659507091728`, 
                6.464771108623202`}, {{a, b, c, d}, {}, {a, b, 
                  c}}, {0.373144912940528`, 0.8125105445944757`, 1}, {}]\), 
            ",", \(AncestralLineage[
              33, {6.464771108623202`, 
                6.647288724524958`}, {{a, b, c, 
                  d}, {}}, {0.1338850878429638`, 1}, {}]\), 
            ",", \(AncestralLineage[
              34, {6.464771108623202`, 
                6.522868735762748`}, {{}, {a, b, c, d}, {}, {a, b, 
                  c}}, {0.1338850878429638`, 0.373144912940528`, 
                0.8125105445944757`, 1}, {}]\), 
            ",", \(AncestralLineage[
              35, {6.522868735762748`, 
                7.66496209555568`}, {{}, {a, b, c, 
                  d}, {}}, {0.1338850878429638`, 0.373144912940528`, 
                1}, {}]\), 
            ",", \(AncestralLineage[
              36, {6.522868735762748`, 
                6.647288724524958`}, {{}, {a, b, c}}, {0.8125105445944757`, 
                1}, {}]\), 
            ",", \(AncestralLineage[
              37, {6.647288724524958`, 
                6.827416708046677`}, {{a, b, c, d}, {}, {a, b, 
                  c}}, {0.1338850878429638`, 0.8125105445944757`, 1}, {}]\), 
            ",", \(AncestralLineage[
              38, {6.827416708046677`, 
                7.08640552134988`}, {{a, b, c, d}, {}, {a, b, c, 
                  d}}, {0.1338850878429638`, 0.373144912940528`, 1}, {}]\), 
            ",", \(AncestralLineage[
              39, {7.08640552134988`, 
                7.383867800378267`}, {{a, b, c, 
                  d}, {}}, {0.1338850878429638`, 1}, {}]\), 
            ",", \(AncestralLineage[
              40, {7.08640552134988`, 
                7.378620012125975`}, {{}, {a, b, c, d}}, {0.373144912940528`, 
                1}, {}]\), 
            ",", \(AncestralLineage[
              41, {7.378620012125975`, 
                7.59676904016541`}, {{}, {a, b, c, 
                  d}, {}}, {0.373144912940528`, 0.7325962355113973`, 
                1}, {}]\), 
            ",", \(AncestralLineage[
              42, {7.378620012125975`, 
                7.383867800378267`}, {{}, {a, b, c, 
                  d}}, {0.7325962355113973`, 1}, {}]\), 
            ",", \(AncestralLineage[
              43, {7.383867800378267`, 
                7.59676904016541`}, {{a, b, c, d}, {}, {a, b, c, 
                  d}}, {0.1338850878429638`, 0.7325962355113973`, 1}, {}]\), 
            ",", \(AncestralLineage[
              44, {7.59676904016541`, 
                7.66496209555568`}, {{a, b, c, d}, {}, {a, b, c, 
                  d}}, {0.1338850878429638`, 0.373144912940528`, 1}, {}]\), 
            ",", 
            RowBox[{"AncestralLineage", "[", 
              RowBox[{"45", ",", 
                RowBox[{"{", 
                  RowBox[{"7.66496209555568`", ",", 
                    InterpretationBox["\[Infinity]",
                      DirectedInfinity[ 1]]}], "}"}], ",", \({{a, b, c, d}}\),
                 ",", \({1}\), ",", \({}\)}], "]"}]}], "}"}]}],
      SequenceForm[ "G=", {
        AncestralLineage[ a, {0, 0.48529096572278896}, {{a}}, {1}, {}], 
        AncestralLineage[ b, {0, 0.23398316436020319}, {{b}}, {1}, {}], 
        AncestralLineage[ c, {0, 0.48529096572278896}, {{c}}, {1}, {}], 
        AncestralLineage[ d, {0, 1.7278195994170844}, {{d}}, {1}, {}], 
        AncestralLineage[ 
        1, {0.23398316436020319, 0.32236075893988181}, {{b}, {}}, {
          0.11492662691806055, 1}, {}], 
        AncestralLineage[ 
        2, {0.23398316436020319, 0.32236075893988181}, {{}, {b}}, {
          0.11492662691806055, 1}, {}], 
        AncestralLineage[ 
        3, {0.32236075893988181, 0.51786383713486195}, {{b}}, {1}, {}], 
        AncestralLineage[ 
        4, {0.48529096572278896, 0.51786383713486195}, {{a, c}}, {1}, {}], 
        AncestralLineage[ 
        5, {0.51786383713486195, 1.5246611785364954}, {{a, b, c}}, {1}, {}], 
        AncestralLineage[ 
        6, {1.5246611785364954, 1.5581431051287236}, {{a, b, c}, {}}, {
          0.48913575253109154, 1}, {}], 
        AncestralLineage[ 
        7, {1.5246611785364954, 1.5581431051287236}, {{}, {a, b, c}}, {
          0.48913575253109154, 1}, {}], 
        AncestralLineage[ 
        8, {1.5581431051287236, 1.6553683776658581}, {{a, b, c}}, {1}, {}], 
        AncestralLineage[ 
        9, {1.6553683776658581, 1.7278195994170844}, {{a, b, c}, {}}, {
          0.81251054459447569, 1}, {}], 
        AncestralLineage[ 
        10, {1.6553683776658581, 5.8038998031993723}, {{}, {a, b, c}}, {
          0.81251054459447569, 1}, {}], 
        AncestralLineage[ 
        11, {1.7278195994170844, 2.9123438760363545}, {{a, b, c, d}, {d}}, {
          0.81251054459447569, 1}, {}], 
        AncestralLineage[ 
        12, {2.9123438760363545, 3.0510813504782521}, {{a, b, c, d}, {
          d}, {}}, {0.81251054459447569, 0.8211640322266659, 1}, {}], 
        AncestralLineage[ 
        13, {2.9123438760363545, 3.0510813504782521}, {{}, {d}}, {
          0.8211640322266659, 1}, {}], 
        AncestralLineage[ 
        14, {3.0510813504782521, 3.9325181869144528}, {{a, b, c, d}, {d}}, {
          0.81251054459447569, 1}, {}], 
        AncestralLineage[ 
        15, {3.9325181869144528, 4.130798875978213}, {{a, b, c, d}, {}}, {
          0.016431884006824982, 1}, {}], 
        AncestralLineage[ 
        16, {3.9325181869144528, 4.130798875978213}, {{}, {a, b, c, d}, {
          d}}, {0.016431884006824982, 0.81251054459447569, 1}, {}], 
        AncestralLineage[ 
        17, {4.130798875978213, 4.8384282701987225}, {{a, b, c, d}, {d}}, {
          0.81251054459447569, 1}, {}], 
        AncestralLineage[ 
        18, {4.8384282701987225, 4.8664777588817101}, {{a, b, c, d}, {}}, {
          0.74402836827033658, 1}, {}], 
        AncestralLineage[ 
        19, {4.8384282701987225, 4.8664777588817101}, {{}, {a, b, c, d}, {
          d}}, {0.74402836827033658, 0.81251054459447569, 1}, {}], 
        AncestralLineage[ 
        20, {4.8664777588817101, 5.292690316029419}, {{a, b, c, d}, {d}}, {
          0.81251054459447569, 1}, {}], 
        AncestralLineage[ 
        21, {5.292690316029419, 5.3460017684681489}, {{a, b, c, d}, {
          d}, {}}, {0.81251054459447569, 0.92658890242798553, 1}, {}], 
        AncestralLineage[ 
        22, {5.292690316029419, 5.3460017684681489}, {{}, {d}}, {
          0.92658890242798553, 1}, {}], 
        AncestralLineage[ 
        23, {5.3460017684681489, 5.4598714204957677}, {{a, b, c, d}, {d}}, {
          0.81251054459447569, 1}, {}], 
        AncestralLineage[ 
        24, {5.4598714204957677, 5.5362846718122025}, {{a, b, c, d}, {}}, {
          0.37314491294052798, 1}, {}], 
        AncestralLineage[ 
        25, {5.4598714204957677, 6.8274167080466768}, {{}, {a, b, c, d}, {
          d}}, {0.37314491294052798, 0.81251054459447569, 1}, {}], 
        AncestralLineage[ 
        26, {5.5362846718122025, 6.0862416755286803}, {{a, b, c, d}, {}}, {
          0.32470788124846017, 1}, {}], 
        AncestralLineage[ 
        27, {5.5362846718122025, 6.2339840341016339}, {{}, {a, b, c, 
          d}, {}}, {0.32470788124846017, 0.37314491294052798, 1}, {}], 
        AncestralLineage[ 
        28, {5.8038998031993723, 6.0862416755286803}, {{}, {a, b, c}, {}}, {
          0.81251054459447569, 0.98211937306245001, 1}, {}], 
        AncestralLineage[ 
        29, {5.8038998031993723, 6.2339840341016339}, {{}, {a, b, c}}, {
          0.98211937306245001, 1}, {}], 
        AncestralLineage[ 
        30, {6.0862416755286803, 6.4486595070917279}, {{a, b, c, d}, {}, {a, 
          b, c}, {}}, {0.32470788124846017, 0.81251054459447569, 
          0.98211937306245001, 1}, {}], 
        AncestralLineage[ 
        31, {6.2339840341016339, 6.4486595070917279}, {{}, {a, b, c, d}, {}, {
          a, b, c}}, {0.32470788124846017, 0.37314491294052798, 
          0.98211937306245001, 1}, {}], 
        AncestralLineage[ 
        32, {6.4486595070917279, 6.4647711086232018}, {{a, b, c, d}, {}, {a, 
          b, c}}, {0.37314491294052798, 0.81251054459447569, 1}, {}], 
        AncestralLineage[ 
        33, {6.4647711086232018, 6.6472887245249579}, {{a, b, c, d}, {}}, {
          0.1338850878429638, 1}, {}], 
        AncestralLineage[ 
        34, {6.4647711086232018, 6.5228687357627484}, {{}, {a, b, c, d}, {}, {
          a, b, c}}, {0.1338850878429638, 0.37314491294052798, 
          0.81251054459447569, 1}, {}], 
        AncestralLineage[ 
        35, {6.5228687357627484, 7.6649620955556799}, {{}, {a, b, c, 
          d}, {}}, {0.1338850878429638, 0.37314491294052798, 1}, {}], 
        AncestralLineage[ 
        36, {6.5228687357627484, 6.6472887245249579}, {{}, {a, b, c}}, {
          0.81251054459447569, 1}, {}], 
        AncestralLineage[ 
        37, {6.6472887245249579, 6.8274167080466768}, {{a, b, c, d}, {}, {a, 
          b, c}}, {0.1338850878429638, 0.81251054459447569, 1}, {}], 
        AncestralLineage[ 
        38, {6.8274167080466768, 7.0864055213498798}, {{a, b, c, d}, {}, {a, 
          b, c, d}}, {0.1338850878429638, 0.37314491294052798, 1}, {}], 
        AncestralLineage[ 
        39, {7.0864055213498798, 7.3838678003782672}, {{a, b, c, d}, {}}, {
          0.1338850878429638, 1}, {}], 
        AncestralLineage[ 
        40, {7.0864055213498798, 7.3786200121259746}, {{}, {a, b, c, d}}, {
          0.37314491294052798, 1}, {}], 
        AncestralLineage[ 
        41, {7.3786200121259746, 7.5967690401654098}, {{}, {a, b, c, 
          d}, {}}, {0.37314491294052798, 0.7325962355113973, 1}, {}], 
        AncestralLineage[ 
        42, {7.3786200121259746, 7.3838678003782672}, {{}, {a, b, c, d}}, {
          0.7325962355113973, 1}, {}], 
        AncestralLineage[ 
        43, {7.3838678003782672, 7.5967690401654098}, {{a, b, c, d}, {}, {a, 
          b, c, d}}, {0.1338850878429638, 0.7325962355113973, 1}, {}], 
        AncestralLineage[ 
        44, {7.5967690401654098, 7.6649620955556799}, {{a, b, c, d}, {}, {a, 
          b, c, d}}, {0.1338850878429638, 0.37314491294052798, 1}, {}], 
        AncestralLineage[ 45, {7.6649620955556799, 
          DirectedInfinity[ 1]}, {{a, b, c, d}}, {1}, {}]}],
      Editable->False]], "Print",
  CellLabel->"From In[346]:="],

Cell[BoxData[
    \({2.9528890229778426`, 2, 0.39173116823798193`}\)], "Print",
  CellLabel->"From In[346]:="],

Cell[BoxData[
    InterpretationBox[\("Recombining "\[InvisibleSpace]45\[InvisibleSpace]"; \
current lineages "\[InvisibleSpace]{45}\),
      SequenceForm[ "Recombining ", 45, "; current lineages ", {45}],
      Editable->False]], "Print",
  CellLabel->"From In[346]:="],

Cell[BoxData[
    InterpretationBox[
      RowBox[{"\<\"G=\"\>", "\[InvisibleSpace]", 
        RowBox[{"{", 
          
          RowBox[{\(AncestralLineage[
              a, {0, 0.48529096572278896`}, {{a}}, {1}, {}]\), 
            ",", \(AncestralLineage[
              b, {0, 0.2339831643602032`}, {{b}}, {1}, {}]\), 
            ",", \(AncestralLineage[
              c, {0, 0.48529096572278896`}, {{c}}, {1}, {}]\), 
            ",", \(AncestralLineage[
              d, {0, 1.7278195994170844`}, {{d}}, {1}, {}]\), 
            ",", \(AncestralLineage[
              1, {0.2339831643602032`, 
                0.3223607589398818`}, {{b}, {}}, {0.11492662691806055`, 
                1}, {}]\), 
            ",", \(AncestralLineage[
              2, {0.2339831643602032`, 
                0.3223607589398818`}, {{}, {b}}, {0.11492662691806055`, 
                1}, {}]\), 
            ",", \(AncestralLineage[
              3, {0.3223607589398818`, 0.517863837134862`}, {{b}}, {1}, {}]\),
             ",", \(AncestralLineage[
              4, {0.48529096572278896`, 
                0.517863837134862`}, {{a, c}}, {1}, {}]\), 
            ",", \(AncestralLineage[
              5, {0.517863837134862`, 
                1.5246611785364954`}, {{a, b, c}}, {1}, {}]\), 
            ",", \(AncestralLineage[
              6, {1.5246611785364954`, 
                1.5581431051287236`}, {{a, b, c}, {}}, {0.48913575253109154`, 
                1}, {}]\), 
            ",", \(AncestralLineage[
              7, {1.5246611785364954`, 
                1.5581431051287236`}, {{}, {a, b, c}}, {0.48913575253109154`, 
                1}, {}]\), 
            ",", \(AncestralLineage[
              8, {1.5581431051287236`, 
                1.655368377665858`}, {{a, b, c}}, {1}, {}]\), 
            ",", \(AncestralLineage[
              9, {1.655368377665858`, 
                1.7278195994170844`}, {{a, b, c}, {}}, {0.8125105445944757`, 
                1}, {}]\), 
            ",", \(AncestralLineage[
              10, {1.655368377665858`, 
                5.803899803199372`}, {{}, {a, b, c}}, {0.8125105445944757`, 
                1}, {}]\), 
            ",", \(AncestralLineage[
              11, {1.7278195994170844`, 
                2.9123438760363545`}, {{a, b, c, 
                  d}, {d}}, {0.8125105445944757`, 1}, {}]\), 
            ",", \(AncestralLineage[
              12, {2.9123438760363545`, 
                3.051081350478252`}, {{a, b, c, 
                  d}, {d}, {}}, {0.8125105445944757`, 0.8211640322266659`, 
                1}, {}]\), 
            ",", \(AncestralLineage[
              13, {2.9123438760363545`, 
                3.051081350478252`}, {{}, {d}}, {0.8211640322266659`, 
                1}, {}]\), 
            ",", \(AncestralLineage[
              14, {3.051081350478252`, 
                3.9325181869144528`}, {{a, b, c, 
                  d}, {d}}, {0.8125105445944757`, 1}, {}]\), 
            ",", \(AncestralLineage[
              15, {3.9325181869144528`, 
                4.130798875978213`}, {{a, b, c, 
                  d}, {}}, {0.016431884006824982`, 1}, {}]\), 
            ",", \(AncestralLineage[
              16, {3.9325181869144528`, 
                4.130798875978213`}, {{}, {a, b, c, 
                  d}, {d}}, {0.016431884006824982`, 0.8125105445944757`, 
                1}, {}]\), 
            ",", \(AncestralLineage[
              17, {4.130798875978213`, 
                4.8384282701987225`}, {{a, b, c, 
                  d}, {d}}, {0.8125105445944757`, 1}, {}]\), 
            ",", \(AncestralLineage[
              18, {4.8384282701987225`, 
                4.86647775888171`}, {{a, b, c, d}, {}}, {0.7440283682703366`, 
                1}, {}]\), 
            ",", \(AncestralLineage[
              19, {4.8384282701987225`, 
                4.86647775888171`}, {{}, {a, b, c, 
                  d}, {d}}, {0.7440283682703366`, 0.8125105445944757`, 
                1}, {}]\), 
            ",", \(AncestralLineage[
              20, {4.86647775888171`, 
                5.292690316029419`}, {{a, b, c, 
                  d}, {d}}, {0.8125105445944757`, 1}, {}]\), 
            ",", \(AncestralLineage[
              21, {5.292690316029419`, 
                5.346001768468149`}, {{a, b, c, 
                  d}, {d}, {}}, {0.8125105445944757`, 0.9265889024279855`, 
                1}, {}]\), 
            ",", \(AncestralLineage[
              22, {5.292690316029419`, 
                5.346001768468149`}, {{}, {d}}, {0.9265889024279855`, 
                1}, {}]\), 
            ",", \(AncestralLineage[
              23, {5.346001768468149`, 
                5.459871420495768`}, {{a, b, c, 
                  d}, {d}}, {0.8125105445944757`, 1}, {}]\), 
            ",", \(AncestralLineage[
              24, {5.459871420495768`, 
                5.5362846718122025`}, {{a, b, c, 
                  d}, {}}, {0.373144912940528`, 1}, {}]\), 
            ",", \(AncestralLineage[
              25, {5.459871420495768`, 
                6.827416708046677`}, {{}, {a, b, c, 
                  d}, {d}}, {0.373144912940528`, 0.8125105445944757`, 
                1}, {}]\), 
            ",", \(AncestralLineage[
              26, {5.5362846718122025`, 
                6.08624167552868`}, {{a, b, c, d}, {}}, {0.3247078812484602`, 
                1}, {}]\), 
            ",", \(AncestralLineage[
              27, {5.5362846718122025`, 
                6.233984034101634`}, {{}, {a, b, c, 
                  d}, {}}, {0.3247078812484602`, 0.373144912940528`, 
                1}, {}]\), 
            ",", \(AncestralLineage[
              28, {5.803899803199372`, 
                6.08624167552868`}, {{}, {a, b, 
                  c}, {}}, {0.8125105445944757`, 0.98211937306245`, 1}, {}]\),
             ",", \(AncestralLineage[
              29, {5.803899803199372`, 
                6.233984034101634`}, {{}, {a, b, c}}, {0.98211937306245`, 
                1}, {}]\), 
            ",", \(AncestralLineage[
              30, {6.08624167552868`, 
                6.448659507091728`}, {{a, b, c, d}, {}, {a, b, 
                  c}, {}}, {0.3247078812484602`, 0.8125105445944757`, 
                0.98211937306245`, 1}, {}]\), 
            ",", \(AncestralLineage[
              31, {6.233984034101634`, 
                6.448659507091728`}, {{}, {a, b, c, d}, {}, {a, b, 
                  c}}, {0.3247078812484602`, 0.373144912940528`, 
                0.98211937306245`, 1}, {}]\), 
            ",", \(AncestralLineage[
              32, {6.448659507091728`, 
                6.464771108623202`}, {{a, b, c, d}, {}, {a, b, 
                  c}}, {0.373144912940528`, 0.8125105445944757`, 1}, {}]\), 
            ",", \(AncestralLineage[
              33, {6.464771108623202`, 
                6.647288724524958`}, {{a, b, c, 
                  d}, {}}, {0.1338850878429638`, 1}, {}]\), 
            ",", \(AncestralLineage[
              34, {6.464771108623202`, 
                6.522868735762748`}, {{}, {a, b, c, d}, {}, {a, b, 
                  c}}, {0.1338850878429638`, 0.373144912940528`, 
                0.8125105445944757`, 1}, {}]\), 
            ",", \(AncestralLineage[
              35, {6.522868735762748`, 
                7.66496209555568`}, {{}, {a, b, c, 
                  d}, {}}, {0.1338850878429638`, 0.373144912940528`, 
                1}, {}]\), 
            ",", \(AncestralLineage[
              36, {6.522868735762748`, 
                6.647288724524958`}, {{}, {a, b, c}}, {0.8125105445944757`, 
                1}, {}]\), 
            ",", \(AncestralLineage[
              37, {6.647288724524958`, 
                6.827416708046677`}, {{a, b, c, d}, {}, {a, b, 
                  c}}, {0.1338850878429638`, 0.8125105445944757`, 1}, {}]\), 
            ",", \(AncestralLineage[
              38, {6.827416708046677`, 
                7.08640552134988`}, {{a, b, c, d}, {}, {a, b, c, 
                  d}}, {0.1338850878429638`, 0.373144912940528`, 1}, {}]\), 
            ",", \(AncestralLineage[
              39, {7.08640552134988`, 
                7.383867800378267`}, {{a, b, c, 
                  d}, {}}, {0.1338850878429638`, 1}, {}]\), 
            ",", \(AncestralLineage[
              40, {7.08640552134988`, 
                7.378620012125975`}, {{}, {a, b, c, d}}, {0.373144912940528`, 
                1}, {}]\), 
            ",", \(AncestralLineage[
              41, {7.378620012125975`, 
                7.59676904016541`}, {{}, {a, b, c, 
                  d}, {}}, {0.373144912940528`, 0.7325962355113973`, 
                1}, {}]\), 
            ",", \(AncestralLineage[
              42, {7.378620012125975`, 
                7.383867800378267`}, {{}, {a, b, c, 
                  d}}, {0.7325962355113973`, 1}, {}]\), 
            ",", \(AncestralLineage[
              43, {7.383867800378267`, 
                7.59676904016541`}, {{a, b, c, d}, {}, {a, b, c, 
                  d}}, {0.1338850878429638`, 0.7325962355113973`, 1}, {}]\), 
            ",", \(AncestralLineage[
              44, {7.59676904016541`, 
                7.66496209555568`}, {{a, b, c, d}, {}, {a, b, c, 
                  d}}, {0.1338850878429638`, 0.373144912940528`, 1}, {}]\), 
            ",", \(AncestralLineage[
              45, {7.66496209555568`, 
                10.617851118533522`}, {{a, b, c, d}}, {1}, {}]\), ",", 
            RowBox[{"AncestralLineage", "[", 
              RowBox[{"46", ",", 
                RowBox[{"{", 
                  RowBox[{"10.617851118533522`", ",", 
                    InterpretationBox["\[Infinity]",
                      DirectedInfinity[ 1]]}], "}"}], 
                ",", \({{a, b, c, d}, {}}\), 
                ",", \({0.39173116823798193`, 1}\), ",", \({}\)}], "]"}], ",",
             
            RowBox[{"AncestralLineage", "[", 
              RowBox[{"47", ",", 
                RowBox[{"{", 
                  RowBox[{"10.617851118533522`", ",", 
                    InterpretationBox["\[Infinity]",
                      DirectedInfinity[ 1]]}], "}"}], 
                ",", \({{}, {a, b, c, d}}\), 
                ",", \({0.39173116823798193`, 1}\), ",", \({}\)}], "]"}]}], 
          "}"}]}],
      SequenceForm[ "G=", {
        AncestralLineage[ a, {0, 0.48529096572278896}, {{a}}, {1}, {}], 
        AncestralLineage[ b, {0, 0.23398316436020319}, {{b}}, {1}, {}], 
        AncestralLineage[ c, {0, 0.48529096572278896}, {{c}}, {1}, {}], 
        AncestralLineage[ d, {0, 1.7278195994170844}, {{d}}, {1}, {}], 
        AncestralLineage[ 
        1, {0.23398316436020319, 0.32236075893988181}, {{b}, {}}, {
          0.11492662691806055, 1}, {}], 
        AncestralLineage[ 
        2, {0.23398316436020319, 0.32236075893988181}, {{}, {b}}, {
          0.11492662691806055, 1}, {}], 
        AncestralLineage[ 
        3, {0.32236075893988181, 0.51786383713486195}, {{b}}, {1}, {}], 
        AncestralLineage[ 
        4, {0.48529096572278896, 0.51786383713486195}, {{a, c}}, {1}, {}], 
        AncestralLineage[ 
        5, {0.51786383713486195, 1.5246611785364954}, {{a, b, c}}, {1}, {}], 
        AncestralLineage[ 
        6, {1.5246611785364954, 1.5581431051287236}, {{a, b, c}, {}}, {
          0.48913575253109154, 1}, {}], 
        AncestralLineage[ 
        7, {1.5246611785364954, 1.5581431051287236}, {{}, {a, b, c}}, {
          0.48913575253109154, 1}, {}], 
        AncestralLineage[ 
        8, {1.5581431051287236, 1.6553683776658581}, {{a, b, c}}, {1}, {}], 
        AncestralLineage[ 
        9, {1.6553683776658581, 1.7278195994170844}, {{a, b, c}, {}}, {
          0.81251054459447569, 1}, {}], 
        AncestralLineage[ 
        10, {1.6553683776658581, 5.8038998031993723}, {{}, {a, b, c}}, {
          0.81251054459447569, 1}, {}], 
        AncestralLineage[ 
        11, {1.7278195994170844, 2.9123438760363545}, {{a, b, c, d}, {d}}, {
          0.81251054459447569, 1}, {}], 
        AncestralLineage[ 
        12, {2.9123438760363545, 3.0510813504782521}, {{a, b, c, d}, {
          d}, {}}, {0.81251054459447569, 0.8211640322266659, 1}, {}], 
        AncestralLineage[ 
        13, {2.9123438760363545, 3.0510813504782521}, {{}, {d}}, {
          0.8211640322266659, 1}, {}], 
        AncestralLineage[ 
        14, {3.0510813504782521, 3.9325181869144528}, {{a, b, c, d}, {d}}, {
          0.81251054459447569, 1}, {}], 
        AncestralLineage[ 
        15, {3.9325181869144528, 4.130798875978213}, {{a, b, c, d}, {}}, {
          0.016431884006824982, 1}, {}], 
        AncestralLineage[ 
        16, {3.9325181869144528, 4.130798875978213}, {{}, {a, b, c, d}, {
          d}}, {0.016431884006824982, 0.81251054459447569, 1}, {}], 
        AncestralLineage[ 
        17, {4.130798875978213, 4.8384282701987225}, {{a, b, c, d}, {d}}, {
          0.81251054459447569, 1}, {}], 
        AncestralLineage[ 
        18, {4.8384282701987225, 4.8664777588817101}, {{a, b, c, d}, {}}, {
          0.74402836827033658, 1}, {}], 
        AncestralLineage[ 
        19, {4.8384282701987225, 4.8664777588817101}, {{}, {a, b, c, d}, {
          d}}, {0.74402836827033658, 0.81251054459447569, 1}, {}], 
        AncestralLineage[ 
        20, {4.8664777588817101, 5.292690316029419}, {{a, b, c, d}, {d}}, {
          0.81251054459447569, 1}, {}], 
        AncestralLineage[ 
        21, {5.292690316029419, 5.3460017684681489}, {{a, b, c, d}, {
          d}, {}}, {0.81251054459447569, 0.92658890242798553, 1}, {}], 
        AncestralLineage[ 
        22, {5.292690316029419, 5.3460017684681489}, {{}, {d}}, {
          0.92658890242798553, 1}, {}], 
        AncestralLineage[ 
        23, {5.3460017684681489, 5.4598714204957677}, {{a, b, c, d}, {d}}, {
          0.81251054459447569, 1}, {}], 
        AncestralLineage[ 
        24, {5.4598714204957677, 5.5362846718122025}, {{a, b, c, d}, {}}, {
          0.37314491294052798, 1}, {}], 
        AncestralLineage[ 
        25, {5.4598714204957677, 6.8274167080466768}, {{}, {a, b, c, d}, {
          d}}, {0.37314491294052798, 0.81251054459447569, 1}, {}], 
        AncestralLineage[ 
        26, {5.5362846718122025, 6.0862416755286803}, {{a, b, c, d}, {}}, {
          0.32470788124846017, 1}, {}], 
        AncestralLineage[ 
        27, {5.5362846718122025, 6.2339840341016339}, {{}, {a, b, c, 
          d}, {}}, {0.32470788124846017, 0.37314491294052798, 1}, {}], 
        AncestralLineage[ 
        28, {5.8038998031993723, 6.0862416755286803}, {{}, {a, b, c}, {}}, {
          0.81251054459447569, 0.98211937306245001, 1}, {}], 
        AncestralLineage[ 
        29, {5.8038998031993723, 6.2339840341016339}, {{}, {a, b, c}}, {
          0.98211937306245001, 1}, {}], 
        AncestralLineage[ 
        30, {6.0862416755286803, 6.4486595070917279}, {{a, b, c, d}, {}, {a, 
          b, c}, {}}, {0.32470788124846017, 0.81251054459447569, 
          0.98211937306245001, 1}, {}], 
        AncestralLineage[ 
        31, {6.2339840341016339, 6.4486595070917279}, {{}, {a, b, c, d}, {}, {
          a, b, c}}, {0.32470788124846017, 0.37314491294052798, 
          0.98211937306245001, 1}, {}], 
        AncestralLineage[ 
        32, {6.4486595070917279, 6.4647711086232018}, {{a, b, c, d}, {}, {a, 
          b, c}}, {0.37314491294052798, 0.81251054459447569, 1}, {}], 
        AncestralLineage[ 
        33, {6.4647711086232018, 6.6472887245249579}, {{a, b, c, d}, {}}, {
          0.1338850878429638, 1}, {}], 
        AncestralLineage[ 
        34, {6.4647711086232018, 6.5228687357627484}, {{}, {a, b, c, d}, {}, {
          a, b, c}}, {0.1338850878429638, 0.37314491294052798, 
          0.81251054459447569, 1}, {}], 
        AncestralLineage[ 
        35, {6.5228687357627484, 7.6649620955556799}, {{}, {a, b, c, 
          d}, {}}, {0.1338850878429638, 0.37314491294052798, 1}, {}], 
        AncestralLineage[ 
        36, {6.5228687357627484, 6.6472887245249579}, {{}, {a, b, c}}, {
          0.81251054459447569, 1}, {}], 
        AncestralLineage[ 
        37, {6.6472887245249579, 6.8274167080466768}, {{a, b, c, d}, {}, {a, 
          b, c}}, {0.1338850878429638, 0.81251054459447569, 1}, {}], 
        AncestralLineage[ 
        38, {6.8274167080466768, 7.0864055213498798}, {{a, b, c, d}, {}, {a, 
          b, c, d}}, {0.1338850878429638, 0.37314491294052798, 1}, {}], 
        AncestralLineage[ 
        39, {7.0864055213498798, 7.3838678003782672}, {{a, b, c, d}, {}}, {
          0.1338850878429638, 1}, {}], 
        AncestralLineage[ 
        40, {7.0864055213498798, 7.3786200121259746}, {{}, {a, b, c, d}}, {
          0.37314491294052798, 1}, {}], 
        AncestralLineage[ 
        41, {7.3786200121259746, 7.5967690401654098}, {{}, {a, b, c, 
          d}, {}}, {0.37314491294052798, 0.7325962355113973, 1}, {}], 
        AncestralLineage[ 
        42, {7.3786200121259746, 7.3838678003782672}, {{}, {a, b, c, d}}, {
          0.7325962355113973, 1}, {}], 
        AncestralLineage[ 
        43, {7.3838678003782672, 7.5967690401654098}, {{a, b, c, d}, {}, {a, 
          b, c, d}}, {0.1338850878429638, 0.7325962355113973, 1}, {}], 
        AncestralLineage[ 
        44, {7.5967690401654098, 7.6649620955556799}, {{a, b, c, d}, {}, {a, 
          b, c, d}}, {0.1338850878429638, 0.37314491294052798, 1}, {}], 
        AncestralLineage[ 
        45, {7.6649620955556799, 10.617851118533522}, {{a, b, c, d}}, {
          1}, {}], 
        AncestralLineage[ 46, {10.617851118533522, 
          DirectedInfinity[ 1]}, {{a, b, c, d}, {}}, {0.39173116823798193, 
          1}, {}], 
        AncestralLineage[ 47, {10.617851118533522, 
          DirectedInfinity[ 1]}, {{}, {a, b, c, d}}, {0.39173116823798193, 
          1}, {}]}],
      Editable->False]], "Print",
  CellLabel->"From In[346]:="],

Cell[BoxData[
    \({0.25117925310085903`, 3, 0.3248735642968679`}\)], "Print",
  CellLabel->"From In[346]:="],

Cell[BoxData[
    InterpretationBox[\("Recombining "\[InvisibleSpace]46\[InvisibleSpace]"; \
current lineages "\[InvisibleSpace]{46, 47}\),
      SequenceForm[ "Recombining ", 46, "; current lineages ", {46, 47}],
      Editable->False]], "Print",
  CellLabel->"From In[346]:="],

Cell[BoxData[
    InterpretationBox[
      RowBox[{"\<\"G=\"\>", "\[InvisibleSpace]", 
        RowBox[{"{", 
          
          RowBox[{\(AncestralLineage[
              a, {0, 0.48529096572278896`}, {{a}}, {1}, {}]\), 
            ",", \(AncestralLineage[
              b, {0, 0.2339831643602032`}, {{b}}, {1}, {}]\), 
            ",", \(AncestralLineage[
              c, {0, 0.48529096572278896`}, {{c}}, {1}, {}]\), 
            ",", \(AncestralLineage[
              d, {0, 1.7278195994170844`}, {{d}}, {1}, {}]\), 
            ",", \(AncestralLineage[
              1, {0.2339831643602032`, 
                0.3223607589398818`}, {{b}, {}}, {0.11492662691806055`, 
                1}, {}]\), 
            ",", \(AncestralLineage[
              2, {0.2339831643602032`, 
                0.3223607589398818`}, {{}, {b}}, {0.11492662691806055`, 
                1}, {}]\), 
            ",", \(AncestralLineage[
              3, {0.3223607589398818`, 0.517863837134862`}, {{b}}, {1}, {}]\),
             ",", \(AncestralLineage[
              4, {0.48529096572278896`, 
                0.517863837134862`}, {{a, c}}, {1}, {}]\), 
            ",", \(AncestralLineage[
              5, {0.517863837134862`, 
                1.5246611785364954`}, {{a, b, c}}, {1}, {}]\), 
            ",", \(AncestralLineage[
              6, {1.5246611785364954`, 
                1.5581431051287236`}, {{a, b, c}, {}}, {0.48913575253109154`, 
                1}, {}]\), 
            ",", \(AncestralLineage[
              7, {1.5246611785364954`, 
                1.5581431051287236`}, {{}, {a, b, c}}, {0.48913575253109154`, 
                1}, {}]\), 
            ",", \(AncestralLineage[
              8, {1.5581431051287236`, 
                1.655368377665858`}, {{a, b, c}}, {1}, {}]\), 
            ",", \(AncestralLineage[
              9, {1.655368377665858`, 
                1.7278195994170844`}, {{a, b, c}, {}}, {0.8125105445944757`, 
                1}, {}]\), 
            ",", \(AncestralLineage[
              10, {1.655368377665858`, 
                5.803899803199372`}, {{}, {a, b, c}}, {0.8125105445944757`, 
                1}, {}]\), 
            ",", \(AncestralLineage[
              11, {1.7278195994170844`, 
                2.9123438760363545`}, {{a, b, c, 
                  d}, {d}}, {0.8125105445944757`, 1}, {}]\), 
            ",", \(AncestralLineage[
              12, {2.9123438760363545`, 
                3.051081350478252`}, {{a, b, c, 
                  d}, {d}, {}}, {0.8125105445944757`, 0.8211640322266659`, 
                1}, {}]\), 
            ",", \(AncestralLineage[
              13, {2.9123438760363545`, 
                3.051081350478252`}, {{}, {d}}, {0.8211640322266659`, 
                1}, {}]\), 
            ",", \(AncestralLineage[
              14, {3.051081350478252`, 
                3.9325181869144528`}, {{a, b, c, 
                  d}, {d}}, {0.8125105445944757`, 1}, {}]\), 
            ",", \(AncestralLineage[
              15, {3.9325181869144528`, 
                4.130798875978213`}, {{a, b, c, 
                  d}, {}}, {0.016431884006824982`, 1}, {}]\), 
            ",", \(AncestralLineage[
              16, {3.9325181869144528`, 
                4.130798875978213`}, {{}, {a, b, c, 
                  d}, {d}}, {0.016431884006824982`, 0.8125105445944757`, 
                1}, {}]\), 
            ",", \(AncestralLineage[
              17, {4.130798875978213`, 
                4.8384282701987225`}, {{a, b, c, 
                  d}, {d}}, {0.8125105445944757`, 1}, {}]\), 
            ",", \(AncestralLineage[
              18, {4.8384282701987225`, 
                4.86647775888171`}, {{a, b, c, d}, {}}, {0.7440283682703366`, 
                1}, {}]\), 
            ",", \(AncestralLineage[
              19, {4.8384282701987225`, 
                4.86647775888171`}, {{}, {a, b, c, 
                  d}, {d}}, {0.7440283682703366`, 0.8125105445944757`, 
                1}, {}]\), 
            ",", \(AncestralLineage[
              20, {4.86647775888171`, 
                5.292690316029419`}, {{a, b, c, 
                  d}, {d}}, {0.8125105445944757`, 1}, {}]\), 
            ",", \(AncestralLineage[
              21, {5.292690316029419`, 
                5.346001768468149`}, {{a, b, c, 
                  d}, {d}, {}}, {0.8125105445944757`, 0.9265889024279855`, 
                1}, {}]\), 
            ",", \(AncestralLineage[
              22, {5.292690316029419`, 
                5.346001768468149`}, {{}, {d}}, {0.9265889024279855`, 
                1}, {}]\), 
            ",", \(AncestralLineage[
              23, {5.346001768468149`, 
                5.459871420495768`}, {{a, b, c, 
                  d}, {d}}, {0.8125105445944757`, 1}, {}]\), 
            ",", \(AncestralLineage[
              24, {5.459871420495768`, 
                5.5362846718122025`}, {{a, b, c, 
                  d}, {}}, {0.373144912940528`, 1}, {}]\), 
            ",", \(AncestralLineage[
              25, {5.459871420495768`, 
                6.827416708046677`}, {{}, {a, b, c, 
                  d}, {d}}, {0.373144912940528`, 0.8125105445944757`, 
                1}, {}]\), 
            ",", \(AncestralLineage[
              26, {5.5362846718122025`, 
                6.08624167552868`}, {{a, b, c, d}, {}}, {0.3247078812484602`, 
                1}, {}]\), 
            ",", \(AncestralLineage[
              27, {5.5362846718122025`, 
                6.233984034101634`}, {{}, {a, b, c, 
                  d}, {}}, {0.3247078812484602`, 0.373144912940528`, 
                1}, {}]\), 
            ",", \(AncestralLineage[
              28, {5.803899803199372`, 
                6.08624167552868`}, {{}, {a, b, 
                  c}, {}}, {0.8125105445944757`, 0.98211937306245`, 1}, {}]\),
             ",", \(AncestralLineage[
              29, {5.803899803199372`, 
                6.233984034101634`}, {{}, {a, b, c}}, {0.98211937306245`, 
                1}, {}]\), 
            ",", \(AncestralLineage[
              30, {6.08624167552868`, 
                6.448659507091728`}, {{a, b, c, d}, {}, {a, b, 
                  c}, {}}, {0.3247078812484602`, 0.8125105445944757`, 
                0.98211937306245`, 1}, {}]\), 
            ",", \(AncestralLineage[
              31, {6.233984034101634`, 
                6.448659507091728`}, {{}, {a, b, c, d}, {}, {a, b, 
                  c}}, {0.3247078812484602`, 0.373144912940528`, 
                0.98211937306245`, 1}, {}]\), 
            ",", \(AncestralLineage[
              32, {6.448659507091728`, 
                6.464771108623202`}, {{a, b, c, d}, {}, {a, b, 
                  c}}, {0.373144912940528`, 0.8125105445944757`, 1}, {}]\), 
            ",", \(AncestralLineage[
              33, {6.464771108623202`, 
                6.647288724524958`}, {{a, b, c, 
                  d}, {}}, {0.1338850878429638`, 1}, {}]\), 
            ",", \(AncestralLineage[
              34, {6.464771108623202`, 
                6.522868735762748`}, {{}, {a, b, c, d}, {}, {a, b, 
                  c}}, {0.1338850878429638`, 0.373144912940528`, 
                0.8125105445944757`, 1}, {}]\), 
            ",", \(AncestralLineage[
              35, {6.522868735762748`, 
                7.66496209555568`}, {{}, {a, b, c, 
                  d}, {}}, {0.1338850878429638`, 0.373144912940528`, 
                1}, {}]\), 
            ",", \(AncestralLineage[
              36, {6.522868735762748`, 
                6.647288724524958`}, {{}, {a, b, c}}, {0.8125105445944757`, 
                1}, {}]\), 
            ",", \(AncestralLineage[
              37, {6.647288724524958`, 
                6.827416708046677`}, {{a, b, c, d}, {}, {a, b, 
                  c}}, {0.1338850878429638`, 0.8125105445944757`, 1}, {}]\), 
            ",", \(AncestralLineage[
              38, {6.827416708046677`, 
                7.08640552134988`}, {{a, b, c, d}, {}, {a, b, c, 
                  d}}, {0.1338850878429638`, 0.373144912940528`, 1}, {}]\), 
            ",", \(AncestralLineage[
              39, {7.08640552134988`, 
                7.383867800378267`}, {{a, b, c, 
                  d}, {}}, {0.1338850878429638`, 1}, {}]\), 
            ",", \(AncestralLineage[
              40, {7.08640552134988`, 
                7.378620012125975`}, {{}, {a, b, c, d}}, {0.373144912940528`, 
                1}, {}]\), 
            ",", \(AncestralLineage[
              41, {7.378620012125975`, 
                7.59676904016541`}, {{}, {a, b, c, 
                  d}, {}}, {0.373144912940528`, 0.7325962355113973`, 
                1}, {}]\), 
            ",", \(AncestralLineage[
              42, {7.378620012125975`, 
                7.383867800378267`}, {{}, {a, b, c, 
                  d}}, {0.7325962355113973`, 1}, {}]\), 
            ",", \(AncestralLineage[
              43, {7.383867800378267`, 
                7.59676904016541`}, {{a, b, c, d}, {}, {a, b, c, 
                  d}}, {0.1338850878429638`, 0.7325962355113973`, 1}, {}]\), 
            ",", \(AncestralLineage[
              44, {7.59676904016541`, 
                7.66496209555568`}, {{a, b, c, d}, {}, {a, b, c, 
                  d}}, {0.1338850878429638`, 0.373144912940528`, 1}, {}]\), 
            ",", \(AncestralLineage[
              45, {7.66496209555568`, 
                10.617851118533522`}, {{a, b, c, d}}, {1}, {}]\), 
            ",", \(AncestralLineage[
              46, {10.617851118533522`, 
                10.869030371634382`}, {{a, b, c, 
                  d}, {}}, {0.39173116823798193`, 1}, {}]\), ",", 
            RowBox[{"AncestralLineage", "[", 
              RowBox[{"47", ",", 
                RowBox[{"{", 
                  RowBox[{"10.617851118533522`", ",", 
                    InterpretationBox["\[Infinity]",
                      DirectedInfinity[ 1]]}], "}"}], 
                ",", \({{}, {a, b, c, d}}\), 
                ",", \({0.39173116823798193`, 1}\), ",", \({}\)}], "]"}], ",",
             
            RowBox[{"AncestralLineage", "[", 
              RowBox[{"48", ",", 
                RowBox[{"{", 
                  RowBox[{"10.869030371634382`", ",", 
                    InterpretationBox["\[Infinity]",
                      DirectedInfinity[ 1]]}], "}"}], 
                ",", \({{a, b, c, d}, {}}\), 
                ",", \({0.3248735642968679`, 1}\), ",", \({}\)}], "]"}], ",", 
            
            RowBox[{"AncestralLineage", "[", 
              RowBox[{"49", ",", 
                RowBox[{"{", 
                  RowBox[{"10.869030371634382`", ",", 
                    InterpretationBox["\[Infinity]",
                      DirectedInfinity[ 1]]}], "}"}], 
                ",", \({{}, {a, b, c, d}, {}}\), 
                ",", \({0.3248735642968679`, 0.39173116823798193`, 1}\), 
                ",", \({}\)}], "]"}]}], "}"}]}],
      SequenceForm[ "G=", {
        AncestralLineage[ a, {0, 0.48529096572278896}, {{a}}, {1}, {}], 
        AncestralLineage[ b, {0, 0.23398316436020319}, {{b}}, {1}, {}], 
        AncestralLineage[ c, {0, 0.48529096572278896}, {{c}}, {1}, {}], 
        AncestralLineage[ d, {0, 1.7278195994170844}, {{d}}, {1}, {}], 
        AncestralLineage[ 
        1, {0.23398316436020319, 0.32236075893988181}, {{b}, {}}, {
          0.11492662691806055, 1}, {}], 
        AncestralLineage[ 
        2, {0.23398316436020319, 0.32236075893988181}, {{}, {b}}, {
          0.11492662691806055, 1}, {}], 
        AncestralLineage[ 
        3, {0.32236075893988181, 0.51786383713486195}, {{b}}, {1}, {}], 
        AncestralLineage[ 
        4, {0.48529096572278896, 0.51786383713486195}, {{a, c}}, {1}, {}], 
        AncestralLineage[ 
        5, {0.51786383713486195, 1.5246611785364954}, {{a, b, c}}, {1}, {}], 
        AncestralLineage[ 
        6, {1.5246611785364954, 1.5581431051287236}, {{a, b, c}, {}}, {
          0.48913575253109154, 1}, {}], 
        AncestralLineage[ 
        7, {1.5246611785364954, 1.5581431051287236}, {{}, {a, b, c}}, {
          0.48913575253109154, 1}, {}], 
        AncestralLineage[ 
        8, {1.5581431051287236, 1.6553683776658581}, {{a, b, c}}, {1}, {}], 
        AncestralLineage[ 
        9, {1.6553683776658581, 1.7278195994170844}, {{a, b, c}, {}}, {
          0.81251054459447569, 1}, {}], 
        AncestralLineage[ 
        10, {1.6553683776658581, 5.8038998031993723}, {{}, {a, b, c}}, {
          0.81251054459447569, 1}, {}], 
        AncestralLineage[ 
        11, {1.7278195994170844, 2.9123438760363545}, {{a, b, c, d}, {d}}, {
          0.81251054459447569, 1}, {}], 
        AncestralLineage[ 
        12, {2.9123438760363545, 3.0510813504782521}, {{a, b, c, d}, {
          d}, {}}, {0.81251054459447569, 0.8211640322266659, 1}, {}], 
        AncestralLineage[ 
        13, {2.9123438760363545, 3.0510813504782521}, {{}, {d}}, {
          0.8211640322266659, 1}, {}], 
        AncestralLineage[ 
        14, {3.0510813504782521, 3.9325181869144528}, {{a, b, c, d}, {d}}, {
          0.81251054459447569, 1}, {}], 
        AncestralLineage[ 
        15, {3.9325181869144528, 4.130798875978213}, {{a, b, c, d}, {}}, {
          0.016431884006824982, 1}, {}], 
        AncestralLineage[ 
        16, {3.9325181869144528, 4.130798875978213}, {{}, {a, b, c, d}, {
          d}}, {0.016431884006824982, 0.81251054459447569, 1}, {}], 
        AncestralLineage[ 
        17, {4.130798875978213, 4.8384282701987225}, {{a, b, c, d}, {d}}, {
          0.81251054459447569, 1}, {}], 
        AncestralLineage[ 
        18, {4.8384282701987225, 4.8664777588817101}, {{a, b, c, d}, {}}, {
          0.74402836827033658, 1}, {}], 
        AncestralLineage[ 
        19, {4.8384282701987225, 4.8664777588817101}, {{}, {a, b, c, d}, {
          d}}, {0.74402836827033658, 0.81251054459447569, 1}, {}], 
        AncestralLineage[ 
        20, {4.8664777588817101, 5.292690316029419}, {{a, b, c, d}, {d}}, {
          0.81251054459447569, 1}, {}], 
        AncestralLineage[ 
        21, {5.292690316029419, 5.3460017684681489}, {{a, b, c, d}, {
          d}, {}}, {0.81251054459447569, 0.92658890242798553, 1}, {}], 
        AncestralLineage[ 
        22, {5.292690316029419, 5.3460017684681489}, {{}, {d}}, {
          0.92658890242798553, 1}, {}], 
        AncestralLineage[ 
        23, {5.3460017684681489, 5.4598714204957677}, {{a, b, c, d}, {d}}, {
          0.81251054459447569, 1}, {}], 
        AncestralLineage[ 
        24, {5.4598714204957677, 5.5362846718122025}, {{a, b, c, d}, {}}, {
          0.37314491294052798, 1}, {}], 
        AncestralLineage[ 
        25, {5.4598714204957677, 6.8274167080466768}, {{}, {a, b, c, d}, {
          d}}, {0.37314491294052798, 0.81251054459447569, 1}, {}], 
        AncestralLineage[ 
        26, {5.5362846718122025, 6.0862416755286803}, {{a, b, c, d}, {}}, {
          0.32470788124846017, 1}, {}], 
        AncestralLineage[ 
        27, {5.5362846718122025, 6.2339840341016339}, {{}, {a, b, c, 
          d}, {}}, {0.32470788124846017, 0.37314491294052798, 1}, {}], 
        AncestralLineage[ 
        28, {5.8038998031993723, 6.0862416755286803}, {{}, {a, b, c}, {}}, {
          0.81251054459447569, 0.98211937306245001, 1}, {}], 
        AncestralLineage[ 
        29, {5.8038998031993723, 6.2339840341016339}, {{}, {a, b, c}}, {
          0.98211937306245001, 1}, {}], 
        AncestralLineage[ 
        30, {6.0862416755286803, 6.4486595070917279}, {{a, b, c, d}, {}, {a, 
          b, c}, {}}, {0.32470788124846017, 0.81251054459447569, 
          0.98211937306245001, 1}, {}], 
        AncestralLineage[ 
        31, {6.2339840341016339, 6.4486595070917279}, {{}, {a, b, c, d}, {}, {
          a, b, c}}, {0.32470788124846017, 0.37314491294052798, 
          0.98211937306245001, 1}, {}], 
        AncestralLineage[ 
        32, {6.4486595070917279, 6.4647711086232018}, {{a, b, c, d}, {}, {a, 
          b, c}}, {0.37314491294052798, 0.81251054459447569, 1}, {}], 
        AncestralLineage[ 
        33, {6.4647711086232018, 6.6472887245249579}, {{a, b, c, d}, {}}, {
          0.1338850878429638, 1}, {}], 
        AncestralLineage[ 
        34, {6.4647711086232018, 6.5228687357627484}, {{}, {a, b, c, d}, {}, {
          a, b, c}}, {0.1338850878429638, 0.37314491294052798, 
          0.81251054459447569, 1}, {}], 
        AncestralLineage[ 
        35, {6.5228687357627484, 7.6649620955556799}, {{}, {a, b, c, 
          d}, {}}, {0.1338850878429638, 0.37314491294052798, 1}, {}], 
        AncestralLineage[ 
        36, {6.5228687357627484, 6.6472887245249579}, {{}, {a, b, c}}, {
          0.81251054459447569, 1}, {}], 
        AncestralLineage[ 
        37, {6.6472887245249579, 6.8274167080466768}, {{a, b, c, d}, {}, {a, 
          b, c}}, {0.1338850878429638, 0.81251054459447569, 1}, {}], 
        AncestralLineage[ 
        38, {6.8274167080466768, 7.0864055213498798}, {{a, b, c, d}, {}, {a, 
          b, c, d}}, {0.1338850878429638, 0.37314491294052798, 1}, {}], 
        AncestralLineage[ 
        39, {7.0864055213498798, 7.3838678003782672}, {{a, b, c, d}, {}}, {
          0.1338850878429638, 1}, {}], 
        AncestralLineage[ 
        40, {7.0864055213498798, 7.3786200121259746}, {{}, {a, b, c, d}}, {
          0.37314491294052798, 1}, {}], 
        AncestralLineage[ 
        41, {7.3786200121259746, 7.5967690401654098}, {{}, {a, b, c, 
          d}, {}}, {0.37314491294052798, 0.7325962355113973, 1}, {}], 
        AncestralLineage[ 
        42, {7.3786200121259746, 7.3838678003782672}, {{}, {a, b, c, d}}, {
          0.7325962355113973, 1}, {}], 
        AncestralLineage[ 
        43, {7.3838678003782672, 7.5967690401654098}, {{a, b, c, d}, {}, {a, 
          b, c, d}}, {0.1338850878429638, 0.7325962355113973, 1}, {}], 
        AncestralLineage[ 
        44, {7.5967690401654098, 7.6649620955556799}, {{a, b, c, d}, {}, {a, 
          b, c, d}}, {0.1338850878429638, 0.37314491294052798, 1}, {}], 
        AncestralLineage[ 
        45, {7.6649620955556799, 10.617851118533522}, {{a, b, c, d}}, {
          1}, {}], 
        AncestralLineage[ 
        46, {10.617851118533522, 10.869030371634382}, {{a, b, c, d}, {}}, {
          0.39173116823798193, 1}, {}], 
        AncestralLineage[ 47, {10.617851118533522, 
          DirectedInfinity[ 1]}, {{}, {a, b, c, d}}, {0.39173116823798193, 
          1}, {}], 
        AncestralLineage[ 48, {10.869030371634382, 
          DirectedInfinity[ 1]}, {{a, b, c, d}, {}}, {0.32487356429686792, 
          1}, {}], 
        AncestralLineage[ 49, {10.869030371634382, 
          DirectedInfinity[ 1]}, {{}, {a, b, c, d}, {}}, {0.32487356429686792,
           0.39173116823798193, 1}, {}]}],
      Editable->False]], "Print",
  CellLabel->"From In[346]:="],

Cell[BoxData[
    RowBox[{"{", 
      RowBox[{\(AncestralLineage[
          a, {0, 0.48529096572278896`}, {{a}}, {1}, {}]\), 
        ",", \(AncestralLineage[
          b, {0, 0.2339831643602032`}, {{b}}, {1}, {}]\), 
        ",", \(AncestralLineage[
          c, {0, 0.48529096572278896`}, {{c}}, {1}, {}]\), 
        ",", \(AncestralLineage[
          d, {0, 1.7278195994170844`}, {{d}}, {1}, {}]\), 
        ",", \(AncestralLineage[
          1, {0.2339831643602032`, 
            0.3223607589398818`}, {{b}, {}}, {0.11492662691806055`, 1}, {}]\),
         ",", \(AncestralLineage[
          2, {0.2339831643602032`, 
            0.3223607589398818`}, {{}, {b}}, {0.11492662691806055`, 1}, {}]\),
         ",", \(AncestralLineage[
          3, {0.3223607589398818`, 0.517863837134862`}, {{b}}, {1}, {}]\), 
        ",", \(AncestralLineage[
          4, {0.48529096572278896`, 0.517863837134862`}, {{a, c}}, {1}, {}]\),
         ",", \(AncestralLineage[
          5, {0.517863837134862`, 
            1.5246611785364954`}, {{a, b, c}}, {1}, {}]\), 
        ",", \(AncestralLineage[
          6, {1.5246611785364954`, 
            1.5581431051287236`}, {{a, b, c}, {}}, {0.48913575253109154`, 
            1}, {}]\), 
        ",", \(AncestralLineage[
          7, {1.5246611785364954`, 
            1.5581431051287236`}, {{}, {a, b, c}}, {0.48913575253109154`, 
            1}, {}]\), 
        ",", \(AncestralLineage[
          8, {1.5581431051287236`, 
            1.655368377665858`}, {{a, b, c}}, {1}, {}]\), 
        ",", \(AncestralLineage[
          9, {1.655368377665858`, 
            1.7278195994170844`}, {{a, b, c}, {}}, {0.8125105445944757`, 
            1}, {}]\), 
        ",", \(AncestralLineage[
          10, {1.655368377665858`, 
            5.803899803199372`}, {{}, {a, b, c}}, {0.8125105445944757`, 
            1}, {}]\), 
        ",", \(AncestralLineage[
          11, {1.7278195994170844`, 
            2.9123438760363545`}, {{a, b, c, d}, {d}}, {0.8125105445944757`, 
            1}, {}]\), 
        ",", \(AncestralLineage[
          12, {2.9123438760363545`, 
            3.051081350478252`}, {{a, b, c, 
              d}, {d}, {}}, {0.8125105445944757`, 0.8211640322266659`, 
            1}, {}]\), 
        ",", \(AncestralLineage[
          13, {2.9123438760363545`, 
            3.051081350478252`}, {{}, {d}}, {0.8211640322266659`, 1}, {}]\), 
        ",", \(AncestralLineage[
          14, {3.051081350478252`, 
            3.9325181869144528`}, {{a, b, c, d}, {d}}, {0.8125105445944757`, 
            1}, {}]\), 
        ",", \(AncestralLineage[
          15, {3.9325181869144528`, 
            4.130798875978213`}, {{a, b, c, d}, {}}, {0.016431884006824982`, 
            1}, {}]\), 
        ",", \(AncestralLineage[
          16, {3.9325181869144528`, 
            4.130798875978213`}, {{}, {a, b, c, 
              d}, {d}}, {0.016431884006824982`, 0.8125105445944757`, 
            1}, {}]\), 
        ",", \(AncestralLineage[
          17, {4.130798875978213`, 
            4.8384282701987225`}, {{a, b, c, d}, {d}}, {0.8125105445944757`, 
            1}, {}]\), 
        ",", \(AncestralLineage[
          18, {4.8384282701987225`, 
            4.86647775888171`}, {{a, b, c, d}, {}}, {0.7440283682703366`, 
            1}, {}]\), 
        ",", \(AncestralLineage[
          19, {4.8384282701987225`, 
            4.86647775888171`}, {{}, {a, b, c, 
              d}, {d}}, {0.7440283682703366`, 0.8125105445944757`, 1}, {}]\), 
        ",", \(AncestralLineage[
          20, {4.86647775888171`, 
            5.292690316029419`}, {{a, b, c, d}, {d}}, {0.8125105445944757`, 
            1}, {}]\), 
        ",", \(AncestralLineage[
          21, {5.292690316029419`, 
            5.346001768468149`}, {{a, b, c, 
              d}, {d}, {}}, {0.8125105445944757`, 0.9265889024279855`, 
            1}, {}]\), 
        ",", \(AncestralLineage[
          22, {5.292690316029419`, 
            5.346001768468149`}, {{}, {d}}, {0.9265889024279855`, 1}, {}]\), 
        ",", \(AncestralLineage[
          23, {5.346001768468149`, 
            5.459871420495768`}, {{a, b, c, d}, {d}}, {0.8125105445944757`, 
            1}, {}]\), 
        ",", \(AncestralLineage[
          24, {5.459871420495768`, 
            5.5362846718122025`}, {{a, b, c, d}, {}}, {0.373144912940528`, 
            1}, {}]\), 
        ",", \(AncestralLineage[
          25, {5.459871420495768`, 
            6.827416708046677`}, {{}, {a, b, c, 
              d}, {d}}, {0.373144912940528`, 0.8125105445944757`, 1}, {}]\), 
        ",", \(AncestralLineage[
          26, {5.5362846718122025`, 
            6.08624167552868`}, {{a, b, c, d}, {}}, {0.3247078812484602`, 
            1}, {}]\), 
        ",", \(AncestralLineage[
          27, {5.5362846718122025`, 
            6.233984034101634`}, {{}, {a, b, c, 
              d}, {}}, {0.3247078812484602`, 0.373144912940528`, 1}, {}]\), 
        ",", \(AncestralLineage[
          28, {5.803899803199372`, 
            6.08624167552868`}, {{}, {a, b, c}, {}}, {0.8125105445944757`, 
            0.98211937306245`, 1}, {}]\), 
        ",", \(AncestralLineage[
          29, {5.803899803199372`, 
            6.233984034101634`}, {{}, {a, b, c}}, {0.98211937306245`, 
            1}, {}]\), 
        ",", \(AncestralLineage[
          30, {6.08624167552868`, 
            6.448659507091728`}, {{a, b, c, d}, {}, {a, b, 
              c}, {}}, {0.3247078812484602`, 0.8125105445944757`, 
            0.98211937306245`, 1}, {}]\), 
        ",", \(AncestralLineage[
          31, {6.233984034101634`, 
            6.448659507091728`}, {{}, {a, b, c, d}, {}, {a, b, 
              c}}, {0.3247078812484602`, 0.373144912940528`, 
            0.98211937306245`, 1}, {}]\), 
        ",", \(AncestralLineage[
          32, {6.448659507091728`, 
            6.464771108623202`}, {{a, b, c, d}, {}, {a, b, 
              c}}, {0.373144912940528`, 0.8125105445944757`, 1}, {}]\), 
        ",", \(AncestralLineage[
          33, {6.464771108623202`, 
            6.647288724524958`}, {{a, b, c, d}, {}}, {0.1338850878429638`, 
            1}, {}]\), 
        ",", \(AncestralLineage[
          34, {6.464771108623202`, 
            6.522868735762748`}, {{}, {a, b, c, d}, {}, {a, b, 
              c}}, {0.1338850878429638`, 0.373144912940528`, 
            0.8125105445944757`, 1}, {}]\), 
        ",", \(AncestralLineage[
          35, {6.522868735762748`, 
            7.66496209555568`}, {{}, {a, b, c, d}, {}}, {0.1338850878429638`, 
            0.373144912940528`, 1}, {}]\), 
        ",", \(AncestralLineage[
          36, {6.522868735762748`, 
            6.647288724524958`}, {{}, {a, b, c}}, {0.8125105445944757`, 
            1}, {}]\), 
        ",", \(AncestralLineage[
          37, {6.647288724524958`, 
            6.827416708046677`}, {{a, b, c, d}, {}, {a, b, 
              c}}, {0.1338850878429638`, 0.8125105445944757`, 1}, {}]\), 
        ",", \(AncestralLineage[
          38, {6.827416708046677`, 
            7.08640552134988`}, {{a, b, c, d}, {}, {a, b, c, 
              d}}, {0.1338850878429638`, 0.373144912940528`, 1}, {}]\), 
        ",", \(AncestralLineage[
          39, {7.08640552134988`, 
            7.383867800378267`}, {{a, b, c, d}, {}}, {0.1338850878429638`, 
            1}, {}]\), 
        ",", \(AncestralLineage[
          40, {7.08640552134988`, 
            7.378620012125975`}, {{}, {a, b, c, d}}, {0.373144912940528`, 
            1}, {}]\), 
        ",", \(AncestralLineage[
          41, {7.378620012125975`, 
            7.59676904016541`}, {{}, {a, b, c, d}, {}}, {0.373144912940528`, 
            0.7325962355113973`, 1}, {}]\), 
        ",", \(AncestralLineage[
          42, {7.378620012125975`, 
            7.383867800378267`}, {{}, {a, b, c, d}}, {0.7325962355113973`, 
            1}, {}]\), 
        ",", \(AncestralLineage[
          43, {7.383867800378267`, 
            7.59676904016541`}, {{a, b, c, d}, {}, {a, b, c, 
              d}}, {0.1338850878429638`, 0.7325962355113973`, 1}, {}]\), 
        ",", \(AncestralLineage[
          44, {7.59676904016541`, 
            7.66496209555568`}, {{a, b, c, d}, {}, {a, b, c, 
              d}}, {0.1338850878429638`, 0.373144912940528`, 1}, {}]\), 
        ",", \(AncestralLineage[
          45, {7.66496209555568`, 
            10.617851118533522`}, {{a, b, c, d}}, {1}, {}]\), 
        ",", \(AncestralLineage[
          46, {10.617851118533522`, 
            10.869030371634382`}, {{a, b, c, d}, {}}, {0.39173116823798193`, 
            1}, {}]\), ",", 
        RowBox[{"AncestralLineage", "[", 
          RowBox[{"47", ",", 
            RowBox[{"{", 
              RowBox[{"10.617851118533522`", ",", 
                InterpretationBox["\[Infinity]",
                  DirectedInfinity[ 1]]}], "}"}], ",", \({{}, {a, b, c, d}}\),
             ",", \({0.39173116823798193`, 1}\), ",", \({}\)}], "]"}], ",", 
        RowBox[{"AncestralLineage", "[", 
          RowBox[{"48", ",", 
            RowBox[{"{", 
              RowBox[{"10.869030371634382`", ",", 
                InterpretationBox["\[Infinity]",
                  DirectedInfinity[ 1]]}], "}"}], ",", \({{a, b, c, d}, {}}\),
             ",", \({0.3248735642968679`, 1}\), ",", \({}\)}], "]"}], ",", 
        RowBox[{"AncestralLineage", "[", 
          RowBox[{"49", ",", 
            RowBox[{"{", 
              RowBox[{"10.869030371634382`", ",", 
                InterpretationBox["\[Infinity]",
                  DirectedInfinity[ 1]]}], "}"}], 
            ",", \({{}, {a, b, c, d}, {}}\), 
            ",", \({0.3248735642968679`, 0.39173116823798193`, 1}\), 
            ",", \({}\)}], "]"}]}], "}"}]], "Output",
  CellLabel->"Out[346]="]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    \(ng2\)], "Input",
  CellLabel->"In[344]:="],

Cell[BoxData[
    RowBox[{"{", 
      RowBox[{\(AncestralLineage[
          a, {0, 0.07373334908162603`}, {{a}}, {1}, {}]\), 
        ",", \(AncestralLineage[
          b, {0, 0.2319819782761371`}, {{b}}, {1}, {}]\), 
        ",", \(AncestralLineage[
          c, {0, 0.2319819782761371`}, {{c}}, {1}, {}]\), 
        ",", \(AncestralLineage[
          d, {0, 0.8751667472853605`}, {{d}}, {1}, {}]\), 
        ",", \(AncestralLineage[
          1, {0.07373334908162603`, 
            0.8055460733172886`}, {{a}, {}}, {0.600722130435994`, 1}, {}]\), 
        ",", \(AncestralLineage[
          2, {0.07373334908162603`, 
            0.28829421288416535`}, {{}, {a}}, {0.600722130435994`, 1}, {}]\), 
        ",", \(AncestralLineage[
          3, {0.2319819782761371`, 
            0.28829421288416535`}, {{b, c}}, {1}, {}]\), 
        ",", \(AncestralLineage[
          4, {0.28829421288416535`, 
            0.3754709492185473`}, {{b, c}, {a, b, c}}, {0.600722130435994`, 
            1}, {}]\), 
        ",", \(AncestralLineage[
          5, {0.3754709492185473`, 
            0.8055460733172886`}, {{b, c}, {a, b, 
              c}, {}}, {0.600722130435994`, 0.968614243860124`, 1}, {}]\), 
        ",", \(AncestralLineage[
          6, {0.3754709492185473`, 
            1.512553783540983`}, {{}, {a, b, c}}, {0.968614243860124`, 
            1}, {}]\), 
        ",", \(AncestralLineage[
          7, {0.8055460733172886`, 
            0.8751667472853605`}, {{a, b, c}, {}}, {0.968614243860124`, 
            1}, {}]\), 
        ",", \(AncestralLineage[
          8, {0.8751667472853605`, 
            1.512553783540983`}, {{a, b, c, d}, {d}}, {0.968614243860124`, 
            1}, {}]\), 
        ",", \(AncestralLineage[
          9, {1.512553783540983`, 
            2.370592917842951`}, {{a, b, c, d}}, {1}, {}]\), 
        ",", \(AncestralLineage[
          10, {2.370592917842951`, 
            3.2696522745020156`}, {{a, b, c, d}, {}}, {0.6297007797359275`, 
            1}, {}]\), 
        ",", \(AncestralLineage[
          11, {2.370592917842951`, 
            3.2696522745020156`}, {{}, {a, b, c, d}}, {0.6297007797359275`, 
            1}, {}]\), 
        ",", \(AncestralLineage[
          12, {3.2696522745020156`, 
            4.947779226735347`}, {{a, b, c, d}}, {1}, {}]\), 
        ",", \(AncestralLineage[
          13, {4.947779226735347`, 
            6.163690448158069`}, {{a, b, c, d}, {}}, {0.9302900854289595`, 
            1}, {}]\), 
        ",", \(AncestralLineage[
          14, {4.947779226735347`, 
            5.415287282384635`}, {{}, {a, b, c, d}}, {0.9302900854289595`, 
            1}, {}]\), 
        ",", \(AncestralLineage[
          15, {5.415287282384635`, 
            6.163690448158069`}, {{}, {a, b, c, 
              d}, {}}, {0.9302900854289595`, 0.9568605529846635`, 1}, {}]\), 
        ",", \(AncestralLineage[
          16, {5.415287282384635`, 
            6.756795183748956`}, {{}, {a, b, c, d}}, {0.9568605529846635`, 
            1}, {}]\), 
        ",", \(AncestralLineage[
          17, {6.163690448158069`, 
            6.695367207636462`}, {{a, b, c, d}, {}}, {0.9568605529846635`, 
            1}, {}]\), 
        ",", \(AncestralLineage[
          18, {6.695367207636462`, 
            6.756795183748956`}, {{a, b, c, d}, {}}, {0.5497125035314009`, 
            1}, {}]\), 
        ",", \(AncestralLineage[
          19, {6.695367207636462`, 
            9.815780477970131`}, {{}, {a, b, c, 
              d}, {}}, {0.5497125035314009`, 0.9568605529846635`, 1}, {}]\), 
        ",", \(AncestralLineage[
          20, {6.756795183748956`, 
            9.353900147008122`}, {{a, b, c, d}, {}, {a, b, c, 
              d}}, {0.5497125035314009`, 0.9568605529846635`, 1}, {}]\), 
        ",", \(AncestralLineage[
          21, {9.353900147008122`, 
            9.473093620887754`}, {{a, b, c, d}, {}}, {0.27470791209099493`, 
            1}, {}]\), 
        ",", \(AncestralLineage[
          22, {9.353900147008122`, 
            9.815780477970131`}, {{}, {a, b, c, d}, {}, {a, b, c, 
              d}}, {0.27470791209099493`, 0.5497125035314009`, 
            0.9568605529846635`, 1}, {}]\), 
        ",", \(AncestralLineage[
          23, {9.473093620887754`, 
            10.233238633888542`}, {{a, b, c, d}, {}}, {0.12142464419497806`, 
            1}, {}]\), 
        ",", \(AncestralLineage[
          24, {9.473093620887754`, 
            10.233238633888542`}, {{}, {a, b, c, 
              d}, {}}, {0.12142464419497806`, 0.27470791209099493`, 1}, {}]\),
         ",", \(AncestralLineage[
          25, {9.815780477970131`, 
            10.412341479462365`}, {{}, {a, b, c, d}}, {0.27470791209099493`, 
            1}, {}]\), 
        ",", \(AncestralLineage[
          26, {10.233238633888542`, 
            11.345094764569382`}, {{a, b, c, d}, {}}, {0.27470791209099493`, 
            1}, {}]\), 
        ",", \(AncestralLineage[
          27, {10.412341479462365`, 
            10.565420400855485`}, {{}, {a, b, c, 
              d}, {}}, {0.27470791209099493`, 0.9286475577129298`, 1}, {}]\), 
        ",", \(AncestralLineage[
          28, {10.412341479462365`, 
            10.565420400855485`}, {{}, {a, b, c, d}}, {0.9286475577129298`, 
            1}, {}]\), 
        ",", \(AncestralLineage[
          29, {10.565420400855485`, 
            11.345094764569382`}, {{}, {a, b, c, d}}, {0.27470791209099493`, 
            1}, {}]\), 
        ",", \(AncestralLineage[
          30, {11.345094764569382`, 
            11.89733594048177`}, {{a, b, c, d}}, {1}, {}]\), ",", 
        RowBox[{"AncestralLineage", "[", 
          RowBox[{"31", ",", 
            RowBox[{"{", 
              RowBox[{"11.89733594048177`", ",", 
                InterpretationBox["\[Infinity]",
                  DirectedInfinity[ 1]]}], "}"}], ",", \({{a, b, c, d}, {}}\),
             ",", \({0.013321301769923403`, 1}\), ",", \({}\)}], "]"}], 
        ",", \(AncestralLineage[
          32, {11.89733594048177`, 
            12.148430764312428`}, {{}, {a, b, c, d}}, {0.013321301769923403`, 
            1}, {}]\), 
        ",", \(AncestralLineage[
          33, {12.148430764312428`, 
            14.05806199668344`}, {{}, {a, b, c, 
              d}, {}}, {0.013321301769923403`, 0.08185213626681434`, 
            1}, {}]\), 
        ",", \(AncestralLineage[
          34, {12.148430764312428`, 
            14.05806199668344`}, {{}, {a, b, c, d}}, {0.08185213626681434`, 
            1}, {}]\), 
        ",", \(AncestralLineage[
          35, {14.05806199668344`, 
            14.329343133053046`}, {{}, {a, b, c, d}}, {0.013321301769923403`, 
            1}, {}]\), 
        ",", \(AncestralLineage[
          36, {14.329343133053046`, 
            14.838046145198616`}, {{}, {a, b, c, 
              d}, {}}, {0.013321301769923403`, 0.14728427655793813`, 
            1}, {}]\), 
        ",", \(AncestralLineage[
          37, {14.329343133053046`, 
            14.838046145198616`}, {{}, {a, b, c, d}}, {0.14728427655793813`, 
            1}, {}]\), 
        ",", \(AncestralLineage[
          38, {14.838046145198616`, 
            15.318060677079666`}, {{}, {a, b, c, d}}, {0.013321301769923403`, 
            1}, {}]\), 
        ",", \(AncestralLineage[
          39, {15.318060677079666`, 
            15.620676004520396`}, {{}, {a, b, c, 
              d}, {}}, {0.013321301769923403`, 0.9128348745882958`, 1}, {}]\),
         ",", 
        RowBox[{"AncestralLineage", "[", 
          RowBox[{"40", ",", 
            RowBox[{"{", 
              RowBox[{"15.318060677079666`", ",", 
                InterpretationBox["\[Infinity]",
                  DirectedInfinity[ 1]]}], "}"}], ",", \({{}, {a, b, c, d}}\),
             ",", \({0.9128348745882958`, 1}\), ",", \({}\)}], "]"}], ",", 
        RowBox[{"AncestralLineage", "[", 
          RowBox[{"41", ",", 
            RowBox[{"{", 
              RowBox[{"15.620676004520396`", ",", 
                InterpretationBox["\[Infinity]",
                  DirectedInfinity[ 1]]}], "}"}], 
            ",", \({{}, {a, b, c, d}, {}}\), 
            ",", \({0.013321301769923403`, 0.3316994705443799`, 1}\), 
            ",", \({}\)}], "]"}], ",", 
        RowBox[{"AncestralLineage", "[", 
          RowBox[{"42", ",", 
            RowBox[{"{", 
              RowBox[{"15.620676004520396`", ",", 
                InterpretationBox["\[Infinity]",
                  DirectedInfinity[ 1]]}], "}"}], 
            ",", \({{}, {a, b, c, d}, {}}\), 
            ",", \({0.3316994705443799`, 0.9128348745882958`, 1}\), 
            ",", \({}\)}], "]"}]}], "}"}]], "Output",
  CellLabel->"Out[344]="]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    \(Junctions[ng2]\)], "Input",
  CellLabel->"In[338]:="],

Cell[BoxData[
    \({0.04327179712470515`, 0.049751381519860534`, 0.16148696800771944`, 
      0.17446323368651914`, 0.2982747757308165`, 0.3315938662952309`, 
      0.7922859352503193`, 0.8657976552608858`}\)], "Output",
  CellLabel->"Out[338]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(NullLineages[ng2]\)], "Input",
  CellLabel->"In[348]:="],

Cell[BoxData[
    \({}\)], "Output",
  CellLabel->"Out[348]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(ExtractLineage[ng2, #] &\) /@ LineagesPresent[ng2, 100]\)], "Input",
  CellLabel->"In[340]:="],

Cell[BoxData[
    RowBox[{"{", 
      RowBox[{
        RowBox[{"AncestralLineage", "[", 
          RowBox[{"21", ",", 
            RowBox[{"{", 
              RowBox[{"2.038101276817025`", ",", 
                InterpretationBox["\[Infinity]",
                  DirectedInfinity[ 1]]}], "}"}], 
            ",", \({{}, {a, b, c, d}, {d}, {a, b, c, d}, {}}\), 
            ",", \({0.17446323368651914`, 0.2982747757308165`, 
              0.7922859352503193`, 0.8657976552608858`, 1}\), ",", \({}\)}], 
          "]"}], ",", 
        RowBox[{"AncestralLineage", "[", 
          RowBox[{"22", ",", 
            RowBox[{"{", 
              RowBox[{"2.038101276817025`", ",", 
                InterpretationBox["\[Infinity]",
                  DirectedInfinity[ 1]]}], "}"}], ",", \({{}, {a, b, c, d}}\),
             ",", \({0.8657976552608858`, 1}\), ",", \({}\)}], "]"}], ",", 
        RowBox[{"AncestralLineage", "[", 
          RowBox[{"23", ",", 
            RowBox[{"{", 
              RowBox[{"2.1992096193854125`", ",", 
                InterpretationBox["\[Infinity]",
                  DirectedInfinity[ 1]]}], "}"}], 
            ",", \({{a, b, c, d}, {}, {a, b, c}, {}}\), 
            ",", \({0.17446323368651914`, 0.2982747757308165`, 
              0.3315938662952309`, 1}\), ",", \({}\)}], "]"}], ",", 
        RowBox[{"AncestralLineage", "[", 
          RowBox[{"24", ",", 
            RowBox[{"{", 
              RowBox[{"2.1992096193854125`", ",", 
                InterpretationBox["\[Infinity]",
                  DirectedInfinity[ 1]]}], "}"}], 
            ",", \({{}, {a, b, c}, {}}\), 
            ",", \({0.3315938662952309`, 0.7922859352503193`, 1}\), 
            ",", \({}\)}], "]"}]}], "}"}]], "Output",
  CellLabel->"Out[340]="]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(ExtractLineage[ng2, #] &\) /@ {34, 35, 36}\)], "Input",
  CellLabel->"In[349]:="],

Cell[BoxData[
    \({AncestralLineage[
        34, {6.464771108623202`, 
          6.522868735762748`}, {{}, {a, b, c, d}, {}, {a, b, 
            c}}, {0.1338850878429638`, 0.373144912940528`, 
          0.8125105445944757`, 1}, {}], 
      AncestralLineage[
        35, {6.522868735762748`, 
          7.66496209555568`}, {{}, {a, b, c, d}, {}}, {0.1338850878429638`, 
          0.373144912940528`, 1}, {}], 
      AncestralLineage[
        36, {6.522868735762748`, 
          6.647288724524958`}, {{}, {a, b, c}}, {0.8125105445944757`, 
          1}, {}]}\)], "Output",
  CellLabel->"Out[349]="]
}, Closed]],

Cell["\<\
Note two recombinations in trapped material that do not generate \
junctions (1 in last entry)\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(RecombinationEvents[ng2] // TableForm\)], "Input",
  CellLabel->"In[363]:="],

Cell[BoxData[
    InterpretationBox[GridBox[{
          {"0.2339831643602032`", GridBox[{
                {"b"}
                },
              RowSpacings->0.25,
              ColumnSpacings->1,
              RowAlignments->Baseline,
              ColumnAlignments->{Left}], GridBox[{
                {"1"},
                {"2"}
                },
              RowSpacings->0.25,
              ColumnSpacings->1,
              RowAlignments->Baseline,
              ColumnAlignments->{Left}], "0.11492662691806055`"},
          {"1.5246611785364954`", GridBox[{
                {"5"}
                },
              RowSpacings->0.25,
              ColumnSpacings->1,
              RowAlignments->Baseline,
              ColumnAlignments->{Left}], GridBox[{
                {"6"},
                {"7"}
                },
              RowSpacings->0.25,
              ColumnSpacings->1,
              RowAlignments->Baseline,
              ColumnAlignments->{Left}], "0.48913575253109154`"},
          {"1.655368377665858`", GridBox[{
                {"8"}
                },
              RowSpacings->0.25,
              ColumnSpacings->1,
              RowAlignments->Baseline,
              ColumnAlignments->{Left}], GridBox[{
                {"9"},
                {"10"}
                },
              RowSpacings->0.25,
              ColumnSpacings->1,
              RowAlignments->Baseline,
              ColumnAlignments->{Left}], "0.8125105445944757`"},
          {"2.9123438760363545`", GridBox[{
                {"11"}
                },
              RowSpacings->0.25,
              ColumnSpacings->1,
              RowAlignments->Baseline,
              ColumnAlignments->{Left}], GridBox[{
                {"12"},
                {"13"}
                },
              RowSpacings->0.25,
              ColumnSpacings->1,
              RowAlignments->Baseline,
              ColumnAlignments->{Left}], "0.8211640322266659`"},
          {"3.9325181869144528`", GridBox[{
                {"14"}
                },
              RowSpacings->0.25,
              ColumnSpacings->1,
              RowAlignments->Baseline,
              ColumnAlignments->{Left}], GridBox[{
                {"15"},
                {"16"}
                },
              RowSpacings->0.25,
              ColumnSpacings->1,
              RowAlignments->Baseline,
              ColumnAlignments->{Left}], "0.016431884006824982`"},
          {"4.8384282701987225`", GridBox[{
                {"17"}
                },
              RowSpacings->0.25,
              ColumnSpacings->1,
              RowAlignments->Baseline,
              ColumnAlignments->{Left}], GridBox[{
                {"18"},
                {"19"}
                },
              RowSpacings->0.25,
              ColumnSpacings->1,
              RowAlignments->Baseline,
              ColumnAlignments->{Left}], "0.7440283682703366`"},
          {"5.292690316029419`", GridBox[{
                {"20"}
                },
              RowSpacings->0.25,
              ColumnSpacings->1,
              RowAlignments->Baseline,
              ColumnAlignments->{Left}], GridBox[{
                {"21"},
                {"22"}
                },
              RowSpacings->0.25,
              ColumnSpacings->1,
              RowAlignments->Baseline,
              ColumnAlignments->{Left}], "0.9265889024279855`"},
          {"5.459871420495768`", GridBox[{
                {"23"}
                },
              RowSpacings->0.25,
              ColumnSpacings->1,
              RowAlignments->Baseline,
              ColumnAlignments->{Left}], GridBox[{
                {"24"},
                {"25"}
                },
              RowSpacings->0.25,
              ColumnSpacings->1,
              RowAlignments->Baseline,
              ColumnAlignments->{Left}], "0.373144912940528`"},
          {"5.5362846718122025`", GridBox[{
                {"24"}
                },
              RowSpacings->0.25,
              ColumnSpacings->1,
              RowAlignments->Baseline,
              ColumnAlignments->{Left}], GridBox[{
                {"26"},
                {"27"}
                },
              RowSpacings->0.25,
              ColumnSpacings->1,
              RowAlignments->Baseline,
              ColumnAlignments->{Left}], "0.3247078812484602`"},
          {"5.803899803199372`", GridBox[{
                {"10"}
                },
              RowSpacings->0.25,
              ColumnSpacings->1,
              RowAlignments->Baseline,
              ColumnAlignments->{Left}], GridBox[{
                {"28"},
                {"29"}
                },
              RowSpacings->0.25,
              ColumnSpacings->1,
              RowAlignments->Baseline,
              ColumnAlignments->{Left}], "0.98211937306245`"},
          {"6.464771108623202`", GridBox[{
                {"32"}
                },
              RowSpacings->0.25,
              ColumnSpacings->1,
              RowAlignments->Baseline,
              ColumnAlignments->{Left}], GridBox[{
                {"33"},
                {"34"}
                },
              RowSpacings->0.25,
              ColumnSpacings->1,
              RowAlignments->Baseline,
              ColumnAlignments->{Left}], "0.1338850878429638`"},
          {"6.522868735762748`", GridBox[{
                {"34"}
                },
              RowSpacings->0.25,
              ColumnSpacings->1,
              RowAlignments->Baseline,
              ColumnAlignments->{Left}], GridBox[{
                {"36"},
                {"35"}
                },
              RowSpacings->0.25,
              ColumnSpacings->1,
              RowAlignments->Baseline,
              ColumnAlignments->{Left}], "1"},
          {"7.08640552134988`", GridBox[{
                {"38"}
                },
              RowSpacings->0.25,
              ColumnSpacings->1,
              RowAlignments->Baseline,
              ColumnAlignments->{Left}], GridBox[{
                {"40"},
                {"39"}
                },
              RowSpacings->0.25,
              ColumnSpacings->1,
              RowAlignments->Baseline,
              ColumnAlignments->{Left}], "1"},
          {"7.378620012125975`", GridBox[{
                {"40"}
                },
              RowSpacings->0.25,
              ColumnSpacings->1,
              RowAlignments->Baseline,
              ColumnAlignments->{Left}], GridBox[{
                {"41"},
                {"42"}
                },
              RowSpacings->0.25,
              ColumnSpacings->1,
              RowAlignments->Baseline,
              ColumnAlignments->{Left}], "0.7325962355113973`"},
          {"10.617851118533522`", GridBox[{
                {"45"}
                },
              RowSpacings->0.25,
              ColumnSpacings->1,
              RowAlignments->Baseline,
              ColumnAlignments->{Left}], GridBox[{
                {"46"},
                {"47"}
                },
              RowSpacings->0.25,
              ColumnSpacings->1,
              RowAlignments->Baseline,
              ColumnAlignments->{Left}], "0.39173116823798193`"},
          {"10.869030371634382`", GridBox[{
                {"46"}
                },
              RowSpacings->0.25,
              ColumnSpacings->1,
              RowAlignments->Baseline,
              ColumnAlignments->{Left}], GridBox[{
                {"48"},
                {"49"}
                },
              RowSpacings->0.25,
              ColumnSpacings->1,
              RowAlignments->Baseline,
              ColumnAlignments->{Left}], "0.3248735642968679`"}
          },
        RowSpacings->1,
        ColumnSpacings->3,
        RowAlignments->Baseline,
        ColumnAlignments->{Left}],
      TableForm[ {{0.23398316436020319, {b}, {1, 2}, 0.11492662691806055}, {
        1.5246611785364954, {5}, {6, 7}, 0.48913575253109154}, {
        1.6553683776658581, {8}, {9, 10}, 0.81251054459447569}, {
        2.9123438760363545, {11}, {12, 13}, 0.8211640322266659}, {
        3.9325181869144528, {14}, {15, 16}, 0.016431884006824982}, {
        4.8384282701987225, {17}, {18, 19}, 0.74402836827033658}, {
        5.292690316029419, {20}, {21, 22}, 0.92658890242798553}, {
        5.4598714204957677, {23}, {24, 25}, 0.37314491294052798}, {
        5.5362846718122025, {24}, {26, 27}, 0.32470788124846017}, {
        5.8038998031993723, {10}, {28, 29}, 0.98211937306245001}, {
        6.4647711086232018, {32}, {33, 34}, 0.1338850878429638}, {
        6.5228687357627484, {34}, {36, 35}, 1}, {7.0864055213498798, {38}, {
        40, 39}, 1}, {7.3786200121259746, {40}, {41, 42}, 
        0.7325962355113973}, {10.617851118533522, {45}, {46, 47}, 
        0.39173116823798193}, {10.869030371634382, {46}, {48, 49}, 
        0.32487356429686792}}]]], "Output",
  CellLabel->"Out[363]//TableForm="]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    \(NullRecombinationEvents[ng2] // TableForm\)], "Input",
  CellLabel->"In[364]:="],

Cell[BoxData[
    InterpretationBox[GridBox[{
          {"6.522868735762748`", GridBox[{
                {"34"}
                },
              RowSpacings->0.25,
              ColumnSpacings->1,
              RowAlignments->Baseline,
              ColumnAlignments->{Left}], GridBox[{
                {"36"},
                {"35"}
                },
              RowSpacings->0.25,
              ColumnSpacings->1,
              RowAlignments->Baseline,
              ColumnAlignments->{Left}], "1"},
          {"7.08640552134988`", GridBox[{
                {"38"}
                },
              RowSpacings->0.25,
              ColumnSpacings->1,
              RowAlignments->Baseline,
              ColumnAlignments->{Left}], GridBox[{
                {"40"},
                {"39"}
                },
              RowSpacings->0.25,
              ColumnSpacings->1,
              RowAlignments->Baseline,
              ColumnAlignments->{Left}], "1"}
          },
        RowSpacings->1,
        ColumnSpacings->3,
        RowAlignments->Baseline,
        ColumnAlignments->{Left}],
      TableForm[ {{6.5228687357627484, {34}, {36, 35}, 1}, {
        7.0864055213498798, {38}, {40, 39}, 1}}]]], "Output",
  CellLabel->"Out[364]//TableForm="]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    \(CoalescenceEvents[ng2] // TableForm\)], "Input",
  CellLabel->"In[365]:="],

Cell[BoxData[
    InterpretationBox[GridBox[{
          {"0.3223607589398818`", GridBox[{
                {"1"},
                {"2"}
                },
              RowSpacings->0.25,
              ColumnSpacings->1,
              RowAlignments->Baseline,
              ColumnAlignments->{Left}], GridBox[{
                {"3"}
                },
              RowSpacings->0.25,
              ColumnSpacings->1,
              RowAlignments->Baseline,
              ColumnAlignments->{Left}], "None"},
          {"0.48529096572278896`", GridBox[{
                {"a"},
                {"c"}
                },
              RowSpacings->0.25,
              ColumnSpacings->1,
              RowAlignments->Baseline,
              ColumnAlignments->{Left}], GridBox[{
                {"4"}
                },
              RowSpacings->0.25,
              ColumnSpacings->1,
              RowAlignments->Baseline,
              ColumnAlignments->{Left}], "None"},
          {"0.517863837134862`", GridBox[{
                {"3"},
                {"4"}
                },
              RowSpacings->0.25,
              ColumnSpacings->1,
              RowAlignments->Baseline,
              ColumnAlignments->{Left}], GridBox[{
                {"5"}
                },
              RowSpacings->0.25,
              ColumnSpacings->1,
              RowAlignments->Baseline,
              ColumnAlignments->{Left}], "None"},
          {"1.5581431051287236`", GridBox[{
                {"6"},
                {"7"}
                },
              RowSpacings->0.25,
              ColumnSpacings->1,
              RowAlignments->Baseline,
              ColumnAlignments->{Left}], GridBox[{
                {"8"}
                },
              RowSpacings->0.25,
              ColumnSpacings->1,
              RowAlignments->Baseline,
              ColumnAlignments->{Left}], "None"},
          {"1.7278195994170844`", GridBox[{
                {"d"},
                {"9"}
                },
              RowSpacings->0.25,
              ColumnSpacings->1,
              RowAlignments->Baseline,
              ColumnAlignments->{Left}], GridBox[{
                {"11"}
                },
              RowSpacings->0.25,
              ColumnSpacings->1,
              RowAlignments->Baseline,
              ColumnAlignments->{Left}], "None"},
          {"3.051081350478252`", GridBox[{
                {"12"},
                {"13"}
                },
              RowSpacings->0.25,
              ColumnSpacings->1,
              RowAlignments->Baseline,
              ColumnAlignments->{Left}], GridBox[{
                {"14"}
                },
              RowSpacings->0.25,
              ColumnSpacings->1,
              RowAlignments->Baseline,
              ColumnAlignments->{Left}], "None"},
          {"4.130798875978213`", GridBox[{
                {"15"},
                {"16"}
                },
              RowSpacings->0.25,
              ColumnSpacings->1,
              RowAlignments->Baseline,
              ColumnAlignments->{Left}], GridBox[{
                {"17"}
                },
              RowSpacings->0.25,
              ColumnSpacings->1,
              RowAlignments->Baseline,
              ColumnAlignments->{Left}], "None"},
          {"4.86647775888171`", GridBox[{
                {"18"},
                {"19"}
                },
              RowSpacings->0.25,
              ColumnSpacings->1,
              RowAlignments->Baseline,
              ColumnAlignments->{Left}], GridBox[{
                {"20"}
                },
              RowSpacings->0.25,
              ColumnSpacings->1,
              RowAlignments->Baseline,
              ColumnAlignments->{Left}], "None"},
          {"5.346001768468149`", GridBox[{
                {"21"},
                {"22"}
                },
              RowSpacings->0.25,
              ColumnSpacings->1,
              RowAlignments->Baseline,
              ColumnAlignments->{Left}], GridBox[{
                {"23"}
                },
              RowSpacings->0.25,
              ColumnSpacings->1,
              RowAlignments->Baseline,
              ColumnAlignments->{Left}], "None"},
          {"6.08624167552868`", GridBox[{
                {"26"},
                {"28"}
                },
              RowSpacings->0.25,
              ColumnSpacings->1,
              RowAlignments->Baseline,
              ColumnAlignments->{Left}], GridBox[{
                {"30"}
                },
              RowSpacings->0.25,
              ColumnSpacings->1,
              RowAlignments->Baseline,
              ColumnAlignments->{Left}], "None"},
          {"6.233984034101634`", GridBox[{
                {"27"},
                {"29"}
                },
              RowSpacings->0.25,
              ColumnSpacings->1,
              RowAlignments->Baseline,
              ColumnAlignments->{Left}], GridBox[{
                {"31"}
                },
              RowSpacings->0.25,
              ColumnSpacings->1,
              RowAlignments->Baseline,
              ColumnAlignments->{Left}], "None"},
          {"6.448659507091728`", GridBox[{
                {"30"},
                {"31"}
                },
              RowSpacings->0.25,
              ColumnSpacings->1,
              RowAlignments->Baseline,
              ColumnAlignments->{Left}], GridBox[{
                {"32"}
                },
              RowSpacings->0.25,
              ColumnSpacings->1,
              RowAlignments->Baseline,
              ColumnAlignments->{Left}], "None"},
          {"6.647288724524958`", GridBox[{
                {"33"},
                {"36"}
                },
              RowSpacings->0.25,
              ColumnSpacings->1,
              RowAlignments->Baseline,
              ColumnAlignments->{Left}], GridBox[{
                {"37"}
                },
              RowSpacings->0.25,
              ColumnSpacings->1,
              RowAlignments->Baseline,
              ColumnAlignments->{Left}], "None"},
          {"6.827416708046677`", GridBox[{
                {"25"},
                {"37"}
                },
              RowSpacings->0.25,
              ColumnSpacings->1,
              RowAlignments->Baseline,
              ColumnAlignments->{Left}], GridBox[{
                {"38"}
                },
              RowSpacings->0.25,
              ColumnSpacings->1,
              RowAlignments->Baseline,
              ColumnAlignments->{Left}], "None"},
          {"7.383867800378267`", GridBox[{
                {"39"},
                {"42"}
                },
              RowSpacings->0.25,
              ColumnSpacings->1,
              RowAlignments->Baseline,
              ColumnAlignments->{Left}], GridBox[{
                {"43"}
                },
              RowSpacings->0.25,
              ColumnSpacings->1,
              RowAlignments->Baseline,
              ColumnAlignments->{Left}], "None"},
          {"7.59676904016541`", GridBox[{
                {"41"},
                {"43"}
                },
              RowSpacings->0.25,
              ColumnSpacings->1,
              RowAlignments->Baseline,
              ColumnAlignments->{Left}], GridBox[{
                {"44"}
                },
              RowSpacings->0.25,
              ColumnSpacings->1,
              RowAlignments->Baseline,
              ColumnAlignments->{Left}], "None"},
          {"7.66496209555568`", GridBox[{
                {"35"},
                {"44"}
                },
              RowSpacings->0.25,
              ColumnSpacings->1,
              RowAlignments->Baseline,
              ColumnAlignments->{Left}], GridBox[{
                {"45"}
                },
              RowSpacings->0.25,
              ColumnSpacings->1,
              RowAlignments->Baseline,
              ColumnAlignments->{Left}], "None"}
          },
        RowSpacings->1,
        ColumnSpacings->3,
        RowAlignments->Baseline,
        ColumnAlignments->{Left}],
      TableForm[ {{0.32236075893988181, {1, 2}, {3}, None}, {
        0.48529096572278896, {a, c}, {4}, None}, {0.51786383713486195, {3, 
        4}, {5}, None}, {1.5581431051287236, {6, 7}, {8}, None}, {
        1.7278195994170844, {d, 9}, {11}, None}, {3.0510813504782521, {12, 
        13}, {14}, None}, {4.130798875978213, {15, 16}, {17}, None}, {
        4.8664777588817101, {18, 19}, {20}, None}, {5.3460017684681489, {21, 
        22}, {23}, None}, {6.0862416755286803, {26, 28}, {30}, None}, {
        6.2339840341016339, {27, 29}, {31}, None}, {6.4486595070917279, {30, 
        31}, {32}, None}, {6.6472887245249579, {33, 36}, {37}, None}, {
        6.8274167080466768, {25, 37}, {38}, None}, {7.3838678003782672, {39, 
        42}, {43}, None}, {7.5967690401654098, {41, 43}, {44}, None}, {
        7.6649620955556799, {35, 44}, {45}, None}}]]], "Output",
  CellLabel->"Out[365]//TableForm="]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    \(LeafEvents[ng2] // TableForm\)], "Input",
  CellLabel->"In[366]:="],

Cell[BoxData[
    InterpretationBox[GridBox[{
          {"0", 
            InterpretationBox["\<\"\"\>",
              {}], GridBox[{
                {"a"},
                {"b"},
                {"c"},
                {"d"}
                },
              RowSpacings->0.25,
              ColumnSpacings->1,
              RowAlignments->Baseline,
              ColumnAlignments->{Left}], "None"}
          },
        RowSpacings->1,
        ColumnSpacings->3,
        RowAlignments->Baseline,
        ColumnAlignments->{Left}],
      TableForm[ {{0, {}, {a, b, c, d}, None}}]]], "Output",
  CellLabel->"Out[366]//TableForm="]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    \(RootEvents[ng2] // TableForm\)], "Input",
  CellLabel->"In[367]:="],

Cell[BoxData[
    InterpretationBox[GridBox[{
          {
            InterpretationBox["\[Infinity]",
              DirectedInfinity[ 1]], GridBox[{
                {"47"},
                {"48"},
                {"49"}
                },
              RowSpacings->0.25,
              ColumnSpacings->1,
              RowAlignments->Baseline,
              ColumnAlignments->{Left}], 
            InterpretationBox["\<\"\"\>",
              {}], "None"}
          },
        RowSpacings->1,
        ColumnSpacings->3,
        RowAlignments->Baseline,
        ColumnAlignments->{Left}],
      TableForm[ {{
        DirectedInfinity[ 1], {47, 48, 49}, {}, None}}]]], "Output",
  CellLabel->"Out[367]//TableForm="]
}, Closed]],

Cell["\<\
This is much too slow, because Ancestors[...] is extremely \
slow.\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(ExtractGenealogy[ng2, 0.02]\)], "Input",
  CellLabel->"In[461]:="],

Cell[BoxData[
    \({48}\)], "Print",
  CellLabel->"From In[461]:="],

Cell[BoxData[
    \(Node[
      48, {10.869030371634382`}, {Node[
          46, {10.617851118533522`}, {Node[
              45, {7.66496209555568`}, {Node[
                  44, {7.59676904016541`}, {Node[
                      41, {7.378620012125975`}, {Node[
                          40, {7.08640552134988`}, {Node[
                              38, {6.827416708046677`}, {Node[
                                  37, {6.647288724524958`}, {Node[
                                      33, {6.464771108623202`}, {Node[
                                        32, {6.448659507091728`}, {Node[
                                        30, {6.08624167552868`}, {Node[
                                        26, {5.5362846718122025`}, {Node[
                                        24, {5.459871420495768`}, {Node[
                                        23, {5.346001768468149`}, {Node[
                                        21, {5.292690316029419`}, {Node[
                                        20, {4.86647775888171`}, {Node[
                                        18, {4.8384282701987225`}, {Node[
                                        17, {4.130798875978213`}, {Node[
                                        16, {3.9325181869144528`}, {Node[
                                        14, {3.051081350478252`}, {Node[
                                        12, {2.9123438760363545`}, {Node[
                                        11, {1.7278195994170844`}, {Node[
                                        d, {0}, {}], 
                                        Node[9, {1.655368377665858`}, {Node[
                                        8, {1.5581431051287236`}, {Node[
                                        6, {1.5246611785364954`}, {Node[
                                        5, {0.517863837134862`}, {Node[
                                        3, {0.3223607589398818`}, {Node[
                                        1, {0.2339831643602032`}, {Node[
                                        b, {0}, {}]}]}], 
                                        Node[4, {0.48529096572278896`}, {Node[
                                        a, {0}, {}], 
                                        Node[
                                        c, {0}, \
{}]}]}]}]}]}]}]}]}]}]}]}]}]}]}]}]}]}]}]}]}]}]}]}]}]}]}]}]\)], "Output",
  CellLabel->"Out[461]="]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(gg = ExtractGenealogy[ng2];\)\)], "Input",
  CellLabel->"In[463]:="],

Cell[BoxData[
    \({48}\)], "Print",
  CellLabel->"From In[463]:="],

Cell[BoxData[
    \({48}\)], "Print",
  CellLabel->"From In[463]:="],

Cell[BoxData[
    \({48}\)], "Print",
  CellLabel->"From In[463]:="],

Cell[BoxData[
    \({48}\)], "Print",
  CellLabel->"From In[463]:="],

Cell[BoxData[
    \({48}\)], "Print",
  CellLabel->"From In[463]:="],

Cell[BoxData[
    \({49}\)], "Print",
  CellLabel->"From In[463]:="],

Cell[BoxData[
    \({49}\)], "Print",
  CellLabel->"From In[463]:="],

Cell[BoxData[
    \({47}\)], "Print",
  CellLabel->"From In[463]:="],

Cell[BoxData[
    \({47}\)], "Print",
  CellLabel->"From In[463]:="],

Cell[BoxData[
    \({47}\)], "Print",
  CellLabel->"From In[463]:="],

Cell[BoxData[
    \({47}\)], "Print",
  CellLabel->"From In[463]:="],

Cell[BoxData[
    \({47}\)], "Print",
  CellLabel->"From In[463]:="],

Cell[BoxData[
    \({47}\)], "Print",
  CellLabel->"From In[463]:="],

Cell[BoxData[
    \({47}\)], "Print",
  CellLabel->"From In[463]:="],

Cell[BoxData[
    \({47}\)], "Print",
  CellLabel->"From In[463]:="]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(\(Show[PlotGenealogy[#]] &\) /@ gg;\)\)], "Input",
  CellLabel->"In[464]:="],

Cell[CellGroupData[{

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.2 0.2 0.0206011 0.0206011 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
0 g
.5 Mabswid
[ ] 0 setdash
.4 .0412 m
.4 .0206 L
s
.4 .0618 m
.4 .0412 L
s
.7 .0412 m
.6 .0206 L
s
.7 .0412 m
.8 .0206 L
s
.6 .0824 m
.4 .0618 L
s
.6 .0824 m
.7 .0412 L
s
.6 .10301 m
.6 .0824 L
s
.6 .12361 m
.6 .10301 L
s
.6 .14421 m
.6 .12361 L
s
.5 .16481 m
.2 .0206 L
s
.5 .16481 m
.6 .14421 L
s
.5 .18541 m
.5 .16481 L
s
.5 .20601 m
.5 .18541 L
s
.5 .22661 m
.5 .20601 L
s
.5 .24721 m
.5 .22661 L
s
.5 .26781 m
.5 .24721 L
s
.5 .28842 m
.5 .26781 L
s
.5 .30902 m
.5 .28842 L
s
.5 .32962 m
.5 .30902 L
s
.5 .35022 m
.5 .32962 L
s
.5 .37082 m
.5 .35022 L
s
.5 .39142 m
.5 .37082 L
s
.5 .41202 m
.5 .39142 L
s
.5 .43262 m
.5 .41202 L
s
.5 .45322 m
.5 .43262 L
s
.5 .47383 m
.5 .45322 L
s
.5 .49443 m
.5 .47383 L
s
.5 .51503 m
.5 .49443 L
s
.5 .53563 m
.5 .51503 L
s
.5 .55623 m
.5 .53563 L
s
.5 .57683 m
.5 .55623 L
s
.5 .59743 m
.5 .57683 L
s
[(1)] .36 .04532 0 0 Mshowa
[(3)] .36 .06592 0 0 Mshowa
[(4)] .66 .04532 0 0 Mshowa
[(5)] .56 .08652 0 0 Mshowa
[(6)] .56 .10713 0 0 Mshowa
[(8)] .56 .12773 0 0 Mshowa
[(9)] .56 .14833 0 0 Mshowa
[(11)] .46 .16893 0 0 Mshowa
[(12)] .46 .18953 0 0 Mshowa
[(14)] .46 .21013 0 0 Mshowa
[(15)] .46 .23073 0 0 Mshowa
[(17)] .46 .25133 0 0 Mshowa
[(18)] .46 .27193 0 0 Mshowa
[(20)] .46 .29254 0 0 Mshowa
[(21)] .46 .31314 0 0 Mshowa
[(23)] .46 .33374 0 0 Mshowa
[(24)] .46 .35434 0 0 Mshowa
[(26)] .46 .37494 0 0 Mshowa
[(30)] .46 .39554 0 0 Mshowa
[(32)] .46 .41614 0 0 Mshowa
[(33)] .46 .43674 0 0 Mshowa
[(37)] .46 .45735 0 0 Mshowa
[(38)] .46 .47795 0 0 Mshowa
[(40)] .46 .49855 0 0 Mshowa
[(41)] .46 .51915 0 0 Mshowa
[(44)] .46 .53975 0 0 Mshowa
[(45)] .46 .56035 0 0 Mshowa
[(46)] .46 .58095 0 0 Mshowa
[(48)] .46 .60155 0 0 Mshowa
gsave
.2 .01648 -66 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(d) show
1.000 setlinewidth
grestore
gsave
.4 .01648 -66 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(b) show
1.000 setlinewidth
grestore
gsave
.6 .01648 -66 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(a) show
1.000 setlinewidth
grestore
gsave
.8 .01648 -66 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(c) show
1.000 setlinewidth
grestore
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[464]:=",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/B000`400?l00000o`00003oo`3ooolQ
0?ooo`00o`3ooolQ0?ooo`00=`3oool4000003@0oooo1000000g0?ooo`@00000=@3oool3000003X0
oooo000f0?ooo`040000003oool0oooo000003H0oooo00@000000?ooo`3oool00000=@3oool01000
0000oooo0?ooo`00000e0?ooo`050000003oool0oooo0?ooo`000000>@3oool003H0oooo00@00000
0?ooo`3oool00000=P3oool010000000oooo0?ooo`00000f0?ooo`<00000=@3oool00`000000oooo
0?ooo`0k0?ooo`00=P3oool00`000000oooo0?ooo`02000003D0oooo00@000000?ooo`0000000000
=@3oool00`000000oooo0?ooo`03000003<0oooo1@00000i0?ooo`00=`3oool3000000030?ooo`00
0000000003<0oooo0`00000g0?ooo`8000000`3oool5000002X0oooo2000000j0?ooo`00>@3oool0
10000000oooo0?ooo`3oool200000340oooo00<000000?ooo`000000@@3oool500000200oooo1@00
00120?ooo`00>03oool2000000D0oooo0P00000^0?ooo`80000000<0oooo0000003oool0A@3oool4
000001L0oooo1@0000170?ooo`00@@3oool2000002l0oooo00<000000?ooo`3oool0B03oool50000
00d0oooo1@00001<0?ooo`00@`3oool200000200oooo0`00000:0?ooo`030000003oool0oooo04L0
oooo0`0000030?ooo`D000000`3oool500000540oooo00150?ooo`8000007`3oool00`000000oooo
0?ooo`090?ooo`030000003oool0oooo04P0oooo00<000000?ooo`3oool01`3oool3000005H0oooo
00170?ooo`8000007@3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo04D0oooo1@00
00050?ooo`<00000F@3oool004T0oooo0P00000K0?ooo`030000003oool0oooo00T0oooo00<00000
0?ooo`3oool0A@3oool010000000oooo0?ooo`0000040?ooo`800000G03oool004/0oooo0P00000I
0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool0AP3oool00`000000oooo00000002
0?ooo`800000GP3oool004d0oooo0`00000E0?ooo`8000002`3oool00`000000oooo0?ooo`170?oo
o`@00000H03oool00500oooo0P00000C0?ooo`<000002P3oool00`000000oooo0?ooo`160?ooo`<0
0000HP3oool00580oooo0P00000@0?ooo`050000003oool0oooo0?ooo`0000002@3oool600000440
oooo0P00001U0?ooo`00E03oool200000180oooo00<000000?ooo`3oool03@3oool:000003@0oooo
0`00001W0?ooo`00EP3oool2000000h0oooo0P00000J0?ooo`T00000:@3oool2000006X0oooo001H
0?ooo`8000003P3oool00`000000oooo0?ooo`0P0?ooo`X000007@3oool2000006`0oooo001J0?oo
o`800000203oool01@000000oooo0?ooo`3oool0000002`0oooo2P00000@0?ooo`<00000KP3oool0
05`0oooo0P0000070?ooo`<00000=P3oool:000000D0oooo0P00001a0?ooo`00GP3oool2000003d0
oooo00D000000?ooo`3oool0oooo000000060?ooo`D00000L`3oool00600oooo0P00000o0?ooo`03
0000003oool0oooo00P0oooo00<000000?ooo`3oool0L@3oool00680oooo0P00000m0?ooo`030000
003oool0oooo00P0oooo00<000000?ooo`3oool0L@3oool006@0oooo0P00000g0?ooo`@000002`3o
ool00`000000oooo0?ooo`1a0?ooo`00IP3oool2000003D0oooo00<000000?ooo`3oool0303oool0
0`000000oooo0?ooo`1a0?ooo`00J03oool2000003<0oooo1@00000:0?ooo`030000003oool0oooo
0740oooo001Z0?ooo`800000<@3oool01@000000oooo0?ooo`3oool0000000X0oooo00<000000?oo
o`3oool0L@3oool006`0oooo0P00000_0?ooo`050000003oool0oooo0?ooo`0000002P3oool00`00
0000oooo0?ooo`1a0?ooo`00KP3oool2000002d0oooo1000000;0?ooo`030000003oool0oooo0740
oooo001`0?ooo`800000:`3oool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo0740oooo
001b0?ooo`800000:P3oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo0740oooo001d
0?ooo`800000:03oool3000000/0oooo00<000000?ooo`3oool0L@3oool007H0oooo0P00000U0?oo
o`050000003oool0oooo0?ooo`0000002P3oool00`000000oooo0?ooo`1a0?ooo`00N03oool30000
0280oooo00D000000?ooo`3oool0oooo0000000:0?ooo`030000003oool0oooo0740oooo001k0?oo
o`8000008@3oool3000000/0oooo00<000000?ooo`3oool0L@3oool007d0oooo0P00000N0?ooo`05
0000003oool0oooo0?ooo`0000002P3oool00`000000oooo0?ooo`1a0?ooo`00O`3oool2000001`0
oooo00D000000?ooo`3oool0oooo0000000:0?ooo`030000003oool0oooo0740oooo00210?ooo`80
00006`3oool3000000/0oooo00<000000?ooo`3oool0L@3oool008<0oooo0P00000K0?ooo`030000
003oool0oooo00L0oooo0`00001c0?ooo`00Q@3oool2000001X0oooo00@000000?ooo`3oool0oooo
1@00001f0?ooo`00Q`3oool2000001D0oooo1`00001k0?ooo`00R@3oool200000100oooo1@000000
0`3oool000000?ooo`1m0?ooo`00O`3oool3000000<0oooo0`0000030?ooo`8000002@3oool50000
0080oooo00D000000?ooo`3oool0oooo0000001n0?ooo`00P03oool00`000000oooo0?ooo`030?oo
o`030000003oool0oooo00@0oooo0P0000020?ooo`D00000203oool3000007l0oooo00200?ooo`03
0000003oool0oooo00<0oooo00<000000?ooo`3oool01P3oool2000008l0oooo00200?ooo`030000
003oool0oooo00<0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`2>0?ooo`00P03o
ool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool0SP3o
ool007l0oooo0P0000040?ooo`800000203oool00`000000oooo0?ooo`2>0?ooo`00O`3oool30000
0080oooo1@0000060?ooo`030000003oool0oooo08h0oooo00200?ooo`030000003oool0oooo0080
oooo00@000000?ooo`3oool000001P3oool00`000000oooo0?ooo`2>0?ooo`00P03oool00`000000
oooo0?ooo`030?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool0SP3oool00800oooo
00<000000?ooo`3oool0103oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo08h0oooo
00200?ooo`050000003oool0oooo0?ooo`0000000`3oool00`000000oooo0?ooo`040?ooo`030000
003oool0oooo08h0oooo001o0?ooo`8000000`3oool01@000000oooo0?ooo`3oool0000000H0oooo
00<000000?ooo`3oool0SP3oool007l0oooo0`0000030?ooo`@000001P3oool00`000000oooo0?oo
o`2>0?ooo`00P03oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00D0oooo00<00000
0?ooo`3oool0SP3oool00800oooo00@000000?ooo`3oool0oooo1@0000060?ooo`030000003oool0
oooo08h0oooo00200?ooo`050000003oool0oooo0?ooo`0000000P3oool00`000000oooo0?ooo`05
0?ooo`030000003oool0oooo08h0oooo00200?ooo`030000003oool0oooo0080oooo00<000000?oo
o`0000001`3oool00`000000oooo0?ooo`2>0?ooo`00O`3oool2000000D0oooo0P0000070?ooo`03
0000003oool0oooo08h0oooo001o0?ooo`<000000`3oool3000000L0oooo00<000000?ooo`3oool0
SP3oool00800oooo00D000000?ooo`3oool0oooo000000030?ooo`030000003oool0oooo00@0oooo
00<000000?ooo`3oool0SP3oool00800oooo00<000000?ooo`3oool01@3oool00`000000oooo0?oo
o`040?ooo`030000003oool0oooo08h0oooo00200?ooo`030000003oool0oooo00D0oooo00<00000
0?ooo`3oool0103oool00`000000oooo0?ooo`2>0?ooo`00P03oool010000000oooo0?ooo`3oool4
000000L0oooo00<000000?ooo`3oool0SP3oool007l0oooo0P0000030?ooo`030000003oool0oooo
00P0oooo00<000000?ooo`3oool0SP3oool007l0oooo0`0000020?ooo`D000001P3oool00`000000
oooo0?ooo`2>0?ooo`00P03oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00H0oooo
00<000000?ooo`3oool0SP3oool00800oooo00<000000?ooo`3oool0103oool00`000000oooo0?oo
o`050?ooo`030000003oool0oooo08h0oooo00200?ooo`030000003oool0oooo00@0oooo00<00000
0?ooo`3oool01@3oool00`000000oooo0?ooo`2>0?ooo`00P03oool00`000000oooo0?ooo`050?oo
o`030000003oool0oooo00@0oooo00<000000?ooo`3oool0SP3oool007l0oooo0P0000030?ooo`05
0000003oool0oooo0?ooo`0000001P3oool00`000000oooo0?ooo`2>0?ooo`00O`3oool300000080
oooo1@0000060?ooo`030000003oool0oooo08h0oooo00200?ooo`050000003oool0oooo0?ooo`00
00000`3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo08h0oooo00200?ooo`050000
003oool0oooo0?ooo`0000000`3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo08h0
oooo00200?ooo`030000003oool0oooo0080oooo0`0000070?ooo`030000003oool0oooo08h0oooo
00200?ooo`050000003oool0oooo0?ooo`0000000`3oool00`000000oooo0?ooo`040?ooo`030000
003oool0oooo08h0oooo001o0?ooo`8000000`3oool01@000000oooo0?ooo`3oool0000000H0oooo
00<000000?ooo`3oool0SP3oool007h0oooo1@0000020?ooo`<000001`3oool00`000000oooo0?oo
o`2>0?ooo`00O`3oool010000000oooo0?ooo`0000020?ooo`040000003oool0oooo000000H0oooo
00<000000?ooo`3oool0SP3oool00800oooo00<000000?ooo`3oool00P3oool010000000oooo0?oo
o`0000060?ooo`030000003oool0oooo08h0oooo00210?ooo`050000003oool0oooo0?ooo`000000
0P3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo08h0oooo001n0?ooo`050000003o
ool0oooo0?ooo`0000000P3oool010000000oooo0?ooo`0000060?ooo`030000003oool0oooo08h0
oooo001n0?ooo`050000003oool0oooo0?ooo`0000000P3oool010000000oooo0?ooo`0000060?oo
o`030000003oool0oooo08h0oooo001n0?ooo`D000000P3oool3000000L0oooo00<000000?ooo`3o
ool0SP3oool007l0oooo00@000000?ooo`3oool000000`3oool00`000000oooo0?ooo`060?ooo`03
0000003oool0oooo08h0oooo00200?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0
1P3oool00`000000oooo0?ooo`2>0?ooo`00P@3oool00`000000oooo0?ooo`020?ooo`030000003o
ool0oooo00H0oooo00<000000?ooo`3oool0SP3oool007h0oooo00D000000?ooo`3oool0oooo0000
00030?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool0SP3oool007h0oooo00D00000
0?ooo`3oool0oooo000000020?ooo`800000203oool00`000000oooo0?ooo`2>0?ooo`00OP3oool5
00000080oooo0`0000070?ooo`030000003oool0oooo08h0oooo001o0?ooo`060000003oool0oooo
0000003oool000000`3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo08h0oooo0020
0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`2>
0?ooo`00P@3oool00`000000oooo0?ooo`020?ooo`8000001`3oool00`000000oooo0?ooo`2>0?oo
o`00OP3oool01@000000oooo0?ooo`3oool0000000D0oooo00<000000?ooo`3oool0103oool00`00
0000oooo0?ooo`2>0?ooo`00OP3oool01`000000oooo0?ooo`3oool000000?ooo`0000000`3oool0
0`000000oooo0?ooo`040?ooo`030000003oool0oooo08h0oooo001n0?ooo`D000000P3oool40000
00H0oooo00<000000?ooo`3oool0SP3oool007l0oooo00@000000?ooo`3oool00000103oool00`00
0000oooo0?ooo`050?ooo`030000003oool0oooo08h0oooo00200?ooo`040000003oool0oooo0?oo
o`D000001P3oool00`000000oooo0?ooo`2>0?ooo`00P@3oool010000000oooo0?ooo`0000020?oo
o`030000003oool0oooo00D0oooo00<000000?ooo`3oool0SP3oool007h0oooo00D000000?ooo`3o
ool0oooo000000020?ooo`030000003oool0000000L0oooo00<000000?ooo`3oool0SP3oool007h0
oooo1@0000020?ooo`<000001`3oool00`000000oooo0?ooo`2>0?ooo`00O`3oool4000000040?oo
o`000000oooo0?ooo`8000001P3oool00`000000oooo0?ooo`2>0?ooo`00P03oool01@000000oooo
0?ooo`3oool0000000<0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`2>0?ooo`00
P@3oool00`000000oooo0?ooo`04000000L0oooo00<000000?ooo`3oool0SP3oool007h0oooo00L0
00000?ooo`3oool0oooo0000003oool0000000X0oooo00<000000?ooo`3oool0SP3oool007h0oooo
00D000000?ooo`3oool0oooo000000020?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3o
ool0SP3oool007l0oooo0`0000040?ooo`8000001`3oool00`000000oooo0?ooo`2>0?ooo`00OP3o
ool01@000000oooo0?ooo`3oool000000080oooo00@000000?ooo`3oool000001P3oool00`000000
oooo0?ooo`2>0?ooo`00PP3oool010000000oooo0?ooo`0000020?ooo`030000003oool0oooo00@0
oooo00<000000?ooo`3oool0SP3oool00800oooo0P0000030?ooo`040000003oool0oooo000000H0
oooo00<000000?ooo`3oool0SP3oool00880oooo00@000000?ooo`3oool000000P3oool00`000000
oooo0?ooo`040?ooo`030000003oool0oooo08h0oooo001n0?ooo`050000003oool0oooo0?ooo`00
00000P3oool010000000oooo0?ooo`0000060?ooo`030000003oool0oooo08h0oooo001o0?ooo`<0
00000P3oool5000000H0oooo00<000000?ooo`3oool0SP3oool007h0oooo00D000000?ooo`3oool0
oooo000000020?ooo`040000003oool0oooo000000H0oooo00<000000?ooo`3oool0SP3oool00880
oooo00D000000?ooo`3oool0oooo000000080?ooo`030000003oool0oooo08h0oooo00200?ooo`80
00001@3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo08h0oooo00220?ooo`030000
003oool0000000<0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`2>0?ooo`00OP3o
ool01`000000oooo0?ooo`3oool000000?ooo`0000000`3oool00`000000oooo0?ooo`040?ooo`03
0000003oool0oooo08h0oooo001o0?ooo`<000000`3oool3000000L0oooo00<000000?ooo`3oool0
SP3oool007h0oooo00L000000?ooo`3oool0oooo0000003oool0000000<0oooo00<000000?ooo`3o
ool0103oool00`000000oooo0?ooo`2>0?ooo`00PP3oool00`000000oooo0?ooo`030?ooo`030000
003oool0oooo00@0oooo00<000000?ooo`3oool0SP3oool00800oooo0P0000040?ooo`8000001`3o
ool00`000000oooo0?ooo`2>0?ooo`00PP3oool00`000000oooo0?ooo`030?ooo`030000003oool0
oooo00@0oooo00<000000?ooo`3oool0SP3oool007h0oooo00L000000?ooo`3oool0oooo0000003o
ool0000000<0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`2>0?ooo`00O`3oool3
000000<0oooo0`0000070?ooo`030000003oool0oooo08h0oooo001n0?ooo`050000003oool0oooo
0?ooo`0000000`3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo08h0oooo00220?oo
o`030000003oool0oooo0080oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`2>0?oo
o`00P03oool2000000D0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`2>0?ooo`00
PP3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0
SP3oool007h0oooo00L000000?ooo`3oool0oooo0000003oool0000000<0oooo00<000000?ooo`3o
ool0103oool00`000000oooo0?ooo`2>0?ooo`00O`3oool300000080oooo1@0000060?ooo`030000
003oool0oooo08h0oooo001n0?ooo`070000003oool0oooo0?ooo`000000oooo000000030?ooo`03
0000003oool0oooo00@0oooo00<000000?ooo`3oool0SP3oool00880oooo00<000000?ooo`000000
0`3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo08h0oooo00200?ooo`8000000`3o
ool3000000L0oooo00<000000?ooo`3oool0SP3oool00880oooo00<000000?ooo`0000000`3oool0
0`000000oooo0?ooo`040?ooo`030000003oool0oooo08h0oooo001n0?ooo`070000003oool0oooo
0?ooo`000000oooo000000030?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0SP3o
ool007l0oooo100000020?ooo`<000001`3oool00`000000oooo0?ooo`2>0?ooo`00P@3oool01@00
0000oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`2>
0?ooo`00OP3oool500000080oooo00@000000?ooo`3oool000001P3oool00`000000oooo0?ooo`2>
0?ooo`00OP3oool010000000oooo0?ooo`0000030?ooo`040000003oool0oooo000000H0oooo00<0
00000?ooo`3oool0SP3oool007l0oooo00<000000?ooo`0000000`3oool010000000oooo0?ooo`00
00060?ooo`030000003oool0oooo08h0oooo00200?ooo`8000000`3oool010000000oooo0?ooo`00
00060?ooo`030000003oool0oooo08h0oooo00200?ooo`<000000P3oool3000000L0oooo00<00000
0?ooo`3oool0SP3oool00840oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`060?oo
o`030000003oool0oooo08h0oooo001n0?ooo`D000000`3oool00`000000oooo0?ooo`060?ooo`03
0000003oool0oooo08h0oooo001n0?ooo`040000003oool0oooo000000@0oooo00<000000?ooo`3o
ool01P3oool00`000000oooo0?ooo`2>0?ooo`00O`3oool00`000000oooo000000040?ooo`030000
003oool0oooo00H0oooo00<000000?ooo`3oool0SP3oool00800oooo0P0000030?ooo`800000203o
ool00`000000oooo0?ooo`2>0?ooo`00P03oool3000000<0oooo0`0000060?ooo`030000003oool0
oooo08h0oooo00210?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool01@3oool00`00
0000oooo0?ooo`2>0?ooo`00OP3oool5000000030?ooo`000000000000<000001P3oool00`000000
oooo0?ooo`2>0?ooo`00OP3oool010000000oooo0?ooo`0000020?ooo`040000003oool0oooo0000
00L0oooo00<000000?ooo`3oool0SP3oool007l0oooo00<000000?ooo`0000000`3oool00`000000
oooo000000070?ooo`030000003oool0oooo08h0oooo00200?ooo`<000000P3oool3000000L0oooo
00<000000?ooo`3oool0SP3oool00840oooo00@000000?ooo`3oool000000P3oool2000000H0oooo
00<000000?ooo`3oool0SP3oool007h0oooo1@0000050?ooo`030000003oool0oooo00@0oooo00<0
00000?ooo`3oool0SP3oool007h0oooo00@000000?ooo`3oool000001P3oool00`000000oooo0?oo
o`040?ooo`030000003oool0oooo08h0oooo001o0?ooo`030000003oool000000080oooo10000007
0?ooo`030000003oool0oooo08h0oooo00200?ooo`8000000P3oool00`000000oooo0?ooo`080?oo
o`030000003oool0oooo08h0oooo00200?ooo`<0000000<0oooo0000000000000`0000060?ooo`03
0000003oool0oooo08h0oooo00210?ooo`040000003oool0oooo000000<0oooo00<000000?ooo`3o
ool0103oool00`000000oooo0?ooo`2>0?ooo`00OP3oool5000000030?ooo`000000oooo0080oooo
00<000000?ooo`3oool0103oool00`000000oooo0?ooo`2>0?ooo`00OP3oool010000000oooo0?oo
o`0000020?ooo`@000001`3oool00`000000oooo0?ooo`2>0?ooo`00O`3oool00`000000oooo0000
00020?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool0SP3oool00800oooo0P000003
0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool0SP3oool00800oooo0`0000020?oo
o`<000001`3oool00`000000oooo0?ooo`2>0?ooo`00P@3oool010000000oooo0?ooo`0000030?oo
o`030000003oool0oooo00@0oooo00<000000?ooo`3oool0SP3oool007h0oooo1@0000000`3oool0
00000?ooo`020?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0SP3oool007h0oooo
00@000000?ooo`3oool000000`3oool3000009P0oooo001o0?ooo`030000003oool000000080oooo
00D000000?ooo`3oool0oooo0000002G0?ooo`00P03oool200000080oooo00D000000?ooo`3oool0
oooo0000002G0?ooo`00P@3oool010000000oooo0?ooo`3oool3000009P0oooo003o0?ooob40oooo
0000\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-1.0062, -1.00015, \
0.0174648, 0.169552}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.2 0.2 0.0206011 0.0206011 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
0 g
.5 Mabswid
[ ] 0 setdash
.4 .0412 m
.4 .0206 L
s
.4 .0618 m
.4 .0412 L
s
.7 .0412 m
.6 .0206 L
s
.7 .0412 m
.8 .0206 L
s
.6 .0824 m
.4 .0618 L
s
.6 .0824 m
.7 .0412 L
s
.6 .10301 m
.6 .0824 L
s
.6 .12361 m
.6 .10301 L
s
.6 .14421 m
.6 .12361 L
s
.5 .16481 m
.2 .0206 L
s
.5 .16481 m
.6 .14421 L
s
.5 .18541 m
.5 .16481 L
s
.5 .20601 m
.5 .18541 L
s
.5 .22661 m
.5 .20601 L
s
.5 .24721 m
.5 .22661 L
s
.5 .26781 m
.5 .24721 L
s
.5 .28842 m
.5 .26781 L
s
.5 .30902 m
.5 .28842 L
s
.5 .32962 m
.5 .30902 L
s
.5 .35022 m
.5 .32962 L
s
.5 .37082 m
.5 .35022 L
s
.5 .39142 m
.5 .37082 L
s
.5 .41202 m
.5 .39142 L
s
.5 .43262 m
.5 .41202 L
s
.5 .45322 m
.5 .43262 L
s
.5 .47383 m
.5 .45322 L
s
.5 .49443 m
.5 .47383 L
s
.5 .51503 m
.5 .49443 L
s
.5 .53563 m
.5 .51503 L
s
.5 .55623 m
.5 .53563 L
s
.5 .57683 m
.5 .55623 L
s
.5 .59743 m
.5 .57683 L
s
[(1)] .36 .04532 0 0 Mshowa
[(3)] .36 .06592 0 0 Mshowa
[(4)] .66 .04532 0 0 Mshowa
[(5)] .56 .08652 0 0 Mshowa
[(6)] .56 .10713 0 0 Mshowa
[(8)] .56 .12773 0 0 Mshowa
[(9)] .56 .14833 0 0 Mshowa
[(11)] .46 .16893 0 0 Mshowa
[(12)] .46 .18953 0 0 Mshowa
[(14)] .46 .21013 0 0 Mshowa
[(16)] .46 .23073 0 0 Mshowa
[(17)] .46 .25133 0 0 Mshowa
[(18)] .46 .27193 0 0 Mshowa
[(20)] .46 .29254 0 0 Mshowa
[(21)] .46 .31314 0 0 Mshowa
[(23)] .46 .33374 0 0 Mshowa
[(24)] .46 .35434 0 0 Mshowa
[(26)] .46 .37494 0 0 Mshowa
[(30)] .46 .39554 0 0 Mshowa
[(32)] .46 .41614 0 0 Mshowa
[(33)] .46 .43674 0 0 Mshowa
[(37)] .46 .45735 0 0 Mshowa
[(38)] .46 .47795 0 0 Mshowa
[(40)] .46 .49855 0 0 Mshowa
[(41)] .46 .51915 0 0 Mshowa
[(44)] .46 .53975 0 0 Mshowa
[(45)] .46 .56035 0 0 Mshowa
[(46)] .46 .58095 0 0 Mshowa
[(48)] .46 .60155 0 0 Mshowa
gsave
.2 .01648 -66 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(d) show
1.000 setlinewidth
grestore
gsave
.4 .01648 -66 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(b) show
1.000 setlinewidth
grestore
gsave
.6 .01648 -66 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(a) show
1.000 setlinewidth
grestore
gsave
.8 .01648 -66 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(c) show
1.000 setlinewidth
grestore
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[464]:=",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/B000`400?l00000o`00003oo`3ooolQ
0?ooo`00o`3ooolQ0?ooo`00=`3oool4000003@0oooo1000000g0?ooo`@00000=@3oool3000003X0
oooo000f0?ooo`040000003oool0oooo000003H0oooo00@000000?ooo`3oool00000=@3oool01000
0000oooo0?ooo`00000e0?ooo`050000003oool0oooo0?ooo`000000>@3oool003H0oooo00@00000
0?ooo`3oool00000=P3oool010000000oooo0?ooo`00000f0?ooo`<00000=@3oool00`000000oooo
0?ooo`0k0?ooo`00=P3oool00`000000oooo0?ooo`02000003D0oooo00@000000?ooo`0000000000
=@3oool00`000000oooo0?ooo`03000003<0oooo1@00000i0?ooo`00=`3oool3000000030?ooo`00
0000000003<0oooo0`00000g0?ooo`8000000`3oool5000002X0oooo2000000j0?ooo`00>@3oool0
10000000oooo0?ooo`3oool200000340oooo00<000000?ooo`000000@@3oool500000200oooo1@00
00120?ooo`00>03oool2000000D0oooo0P00000^0?ooo`80000000<0oooo0000003oool0A@3oool4
000001L0oooo1@0000170?ooo`00@@3oool2000002l0oooo00<000000?ooo`3oool0B03oool50000
00d0oooo1@00001<0?ooo`00@`3oool200000200oooo0`00000:0?ooo`030000003oool0oooo04L0
oooo0`0000030?ooo`D000000`3oool500000540oooo00150?ooo`8000007`3oool00`000000oooo
0?ooo`090?ooo`030000003oool0oooo04P0oooo00<000000?ooo`3oool01`3oool3000005H0oooo
00170?ooo`8000007@3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo04D0oooo1@00
00050?ooo`<00000F@3oool004T0oooo0P00000K0?ooo`030000003oool0oooo00T0oooo00<00000
0?ooo`3oool0A@3oool010000000oooo0?ooo`0000040?ooo`800000G03oool004/0oooo0P00000I
0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool0AP3oool00`000000oooo00000002
0?ooo`800000GP3oool004d0oooo0`00000E0?ooo`8000002`3oool00`000000oooo0?ooo`170?oo
o`@00000H03oool00500oooo0P00000C0?ooo`<000002P3oool00`000000oooo0?ooo`160?ooo`<0
0000HP3oool00580oooo0P00000@0?ooo`050000003oool0oooo0?ooo`0000002@3oool600000440
oooo0P00001U0?ooo`00E03oool200000180oooo00<000000?ooo`3oool03@3oool:000003@0oooo
0`00001W0?ooo`00EP3oool2000000h0oooo0P00000J0?ooo`T00000:@3oool2000006X0oooo001H
0?ooo`8000003P3oool00`000000oooo0?ooo`0P0?ooo`X000007@3oool2000006`0oooo001J0?oo
o`800000203oool01@000000oooo0?ooo`3oool0000002`0oooo2P00000@0?ooo`<00000KP3oool0
05`0oooo0P0000070?ooo`<00000=P3oool:000000D0oooo0P00001a0?ooo`00GP3oool2000003d0
oooo00D000000?ooo`3oool0oooo000000060?ooo`D00000L`3oool00600oooo0P00000o0?ooo`03
0000003oool0oooo00P0oooo00<000000?ooo`3oool0L@3oool00680oooo0P00000m0?ooo`030000
003oool0oooo00P0oooo00<000000?ooo`3oool0L@3oool006@0oooo0P00000g0?ooo`@000002`3o
ool00`000000oooo0?ooo`1a0?ooo`00IP3oool2000003D0oooo00<000000?ooo`3oool0303oool0
0`000000oooo0?ooo`1a0?ooo`00J03oool2000003<0oooo1@00000:0?ooo`030000003oool0oooo
0740oooo001Z0?ooo`800000<@3oool01@000000oooo0?ooo`3oool0000000X0oooo00<000000?oo
o`3oool0L@3oool006`0oooo0P00000_0?ooo`050000003oool0oooo0?ooo`0000002P3oool00`00
0000oooo0?ooo`1a0?ooo`00KP3oool2000002d0oooo1000000;0?ooo`030000003oool0oooo0740
oooo001`0?ooo`800000:`3oool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo0740oooo
001b0?ooo`800000:P3oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo0740oooo001d
0?ooo`800000:03oool3000000/0oooo00<000000?ooo`3oool0L@3oool007H0oooo0P00000U0?oo
o`050000003oool0oooo0?ooo`0000002P3oool00`000000oooo0?ooo`1a0?ooo`00N03oool30000
0280oooo00D000000?ooo`3oool0oooo0000000:0?ooo`030000003oool0oooo0740oooo001k0?oo
o`8000008@3oool3000000/0oooo00<000000?ooo`3oool0L@3oool007d0oooo0P00000N0?ooo`05
0000003oool0oooo0?ooo`0000002P3oool00`000000oooo0?ooo`1a0?ooo`00O`3oool2000001`0
oooo00D000000?ooo`3oool0oooo0000000:0?ooo`030000003oool0oooo0740oooo00210?ooo`80
00006`3oool3000000/0oooo00<000000?ooo`3oool0L@3oool008<0oooo0P00000K0?ooo`030000
003oool0oooo00L0oooo0`00001c0?ooo`00Q@3oool2000001X0oooo00@000000?ooo`3oool0oooo
1@00001f0?ooo`00Q`3oool2000001D0oooo1`00001k0?ooo`00R@3oool200000100oooo1@000000
0`3oool000000?ooo`1m0?ooo`00O`3oool3000000<0oooo0`0000030?ooo`8000002@3oool50000
0080oooo00D000000?ooo`3oool0oooo0000001n0?ooo`00P03oool00`000000oooo0?ooo`030?oo
o`030000003oool0oooo00@0oooo0P0000020?ooo`D00000203oool3000007l0oooo00200?ooo`03
0000003oool0oooo00<0oooo00<000000?ooo`3oool01P3oool2000008l0oooo00200?ooo`030000
003oool0oooo00<0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`2>0?ooo`00P03o
ool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool0SP3o
ool007l0oooo0P0000040?ooo`800000203oool00`000000oooo0?ooo`2>0?ooo`00O`3oool30000
0080oooo1@0000060?ooo`030000003oool0oooo08h0oooo00200?ooo`030000003oool0oooo0080
oooo00@000000?ooo`3oool000001P3oool00`000000oooo0?ooo`2>0?ooo`00P03oool00`000000
oooo0?ooo`030?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool0SP3oool00800oooo
00<000000?ooo`3oool0103oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo08h0oooo
00200?ooo`050000003oool0oooo0?ooo`0000000`3oool00`000000oooo0?ooo`040?ooo`030000
003oool0oooo08h0oooo001o0?ooo`8000000`3oool01@000000oooo0?ooo`3oool0000000H0oooo
00<000000?ooo`3oool0SP3oool007l0oooo0`0000030?ooo`@000001P3oool00`000000oooo0?oo
o`2>0?ooo`00P03oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00D0oooo00<00000
0?ooo`3oool0SP3oool00800oooo00@000000?ooo`3oool0oooo1@0000060?ooo`030000003oool0
oooo08h0oooo00200?ooo`050000003oool0oooo0?ooo`0000000P3oool00`000000oooo0?ooo`05
0?ooo`030000003oool0oooo08h0oooo00200?ooo`030000003oool0oooo0080oooo00<000000?oo
o`0000001`3oool00`000000oooo0?ooo`2>0?ooo`00O`3oool2000000D0oooo0P0000070?ooo`03
0000003oool0oooo08h0oooo001o0?ooo`<000000`3oool3000000L0oooo00<000000?ooo`3oool0
SP3oool00800oooo00D000000?ooo`3oool0oooo000000030?ooo`030000003oool0oooo00@0oooo
00<000000?ooo`3oool0SP3oool00800oooo00D000000?ooo`3oool0oooo000000030?ooo`030000
003oool0oooo00@0oooo00<000000?ooo`3oool0SP3oool00800oooo00@000000?ooo`3oool0oooo
100000070?ooo`030000003oool0oooo08h0oooo00200?ooo`050000003oool0oooo0?ooo`000000
2P3oool00`000000oooo0?ooo`2>0?ooo`00O`3oool2000000@0oooo00<000000?ooo`3oool01`3o
ool00`000000oooo0?ooo`2>0?ooo`00O`3oool3000000@0oooo0P0000070?ooo`030000003oool0
oooo08h0oooo00200?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool01P3oool00`00
0000oooo0?ooo`2>0?ooo`00P03oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00D0
oooo00<000000?ooo`3oool0SP3oool00800oooo00<000000?ooo`3oool0103oool00`000000oooo
0?ooo`050?ooo`030000003oool0oooo08h0oooo00200?ooo`030000003oool0oooo00D0oooo00<0
00000?ooo`3oool0103oool00`000000oooo0?ooo`2>0?ooo`00O`3oool2000000<0oooo00D00000
0?ooo`3oool0oooo000000060?ooo`030000003oool0oooo08h0oooo001o0?ooo`<000000P3oool5
000000H0oooo00<000000?ooo`3oool0SP3oool00800oooo00D000000?ooo`3oool0oooo00000003
0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0SP3oool00800oooo00D000000?oo
o`3oool0oooo000000030?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0SP3oool0
0800oooo00<000000?ooo`3oool00P3oool3000000L0oooo00<000000?ooo`3oool0SP3oool00800
oooo00D000000?ooo`3oool0oooo000000030?ooo`030000003oool0oooo00@0oooo00<000000?oo
o`3oool0SP3oool007l0oooo0P0000030?ooo`050000003oool0oooo0?ooo`0000001P3oool00`00
0000oooo0?ooo`2>0?ooo`00OP3oool500000080oooo0`0000070?ooo`030000003oool0oooo08h0
oooo001o0?ooo`040000003oool0oooo00000080oooo00@000000?ooo`3oool000001P3oool00`00
0000oooo0?ooo`2>0?ooo`00P03oool00`000000oooo0?ooo`020?ooo`040000003oool0oooo0000
00H0oooo00<000000?ooo`3oool0SP3oool00840oooo00D000000?ooo`3oool0oooo000000020?oo
o`030000003oool0oooo00@0oooo00<000000?ooo`3oool0SP3oool007h0oooo00D000000?ooo`3o
ool0oooo000000020?ooo`040000003oool0oooo000000H0oooo00<000000?ooo`3oool0SP3oool0
07h0oooo00D000000?ooo`3oool0oooo000000020?ooo`040000003oool0oooo000000H0oooo00<0
00000?ooo`3oool0SP3oool007h0oooo1@0000020?ooo`<000001`3oool00`000000oooo0?ooo`2>
0?ooo`00O`3oool010000000oooo0?ooo`0000030?ooo`030000003oool0oooo00H0oooo00<00000
0?ooo`3oool0SP3oool00800oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`060?oo
o`030000003oool0oooo08h0oooo00210?ooo`030000003oool0oooo0080oooo00<000000?ooo`3o
ool01P3oool00`000000oooo0?ooo`2>0?ooo`00OP3oool01@000000oooo0?ooo`3oool0000000<0
oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`2>0?ooo`00OP3oool01@000000oooo
0?ooo`3oool000000080oooo0P0000080?ooo`030000003oool0oooo08h0oooo001n0?ooo`D00000
0P3oool3000000L0oooo00<000000?ooo`3oool0SP3oool007l0oooo00H000000?ooo`3oool00000
0?ooo`0000030?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0SP3oool00800oooo
00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo08h0oooo
00210?ooo`030000003oool0oooo0080oooo0P0000070?ooo`030000003oool0oooo08h0oooo001n
0?ooo`050000003oool0oooo0?ooo`0000001@3oool00`000000oooo0?ooo`040?ooo`030000003o
ool0oooo08h0oooo001n0?ooo`070000003oool0oooo0?ooo`000000oooo000000030?ooo`030000
003oool0oooo00@0oooo00<000000?ooo`3oool0SP3oool007h0oooo1@0000020?ooo`@000001P3o
ool00`000000oooo0?ooo`2>0?ooo`00O`3oool010000000oooo0?ooo`0000040?ooo`030000003o
ool0oooo00D0oooo00<000000?ooo`3oool0SP3oool00800oooo00@000000?ooo`3oool0oooo1@00
00060?ooo`030000003oool0oooo08h0oooo00210?ooo`040000003oool0oooo00000080oooo00<0
00000?ooo`3oool01@3oool00`000000oooo0?ooo`2>0?ooo`00OP3oool01@000000oooo0?ooo`3o
ool000000080oooo00<000000?ooo`0000001`3oool00`000000oooo0?ooo`2>0?ooo`00OP3oool5
00000080oooo0`0000070?ooo`030000003oool0oooo08h0oooo001o0?ooo`@0000000@0oooo0000
003oool0oooo0P0000060?ooo`030000003oool0oooo08h0oooo00200?ooo`050000003oool0oooo
0?ooo`0000000`3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo08h0oooo00210?oo
o`030000003oool0oooo00@000001`3oool00`000000oooo0?ooo`2>0?ooo`00OP3oool01`000000
oooo0?ooo`3oool000000?ooo`0000002P3oool00`000000oooo0?ooo`2>0?ooo`00OP3oool01@00
0000oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`2>
0?ooo`00O`3oool3000000@0oooo0P0000070?ooo`030000003oool0oooo08h0oooo001n0?ooo`05
0000003oool0oooo0?ooo`0000000P3oool010000000oooo0?ooo`0000060?ooo`030000003oool0
oooo08h0oooo00220?ooo`040000003oool0oooo00000080oooo00<000000?ooo`3oool0103oool0
0`000000oooo0?ooo`2>0?ooo`00P03oool2000000<0oooo00@000000?ooo`3oool000001P3oool0
0`000000oooo0?ooo`2>0?ooo`00PP3oool010000000oooo0?ooo`0000020?ooo`030000003oool0
oooo00@0oooo00<000000?ooo`3oool0SP3oool007h0oooo00D000000?ooo`3oool0oooo00000002
0?ooo`040000003oool0oooo000000H0oooo00<000000?ooo`3oool0SP3oool007l0oooo0`000002
0?ooo`D000001P3oool00`000000oooo0?ooo`2>0?ooo`00OP3oool01@000000oooo0?ooo`3oool0
00000080oooo00@000000?ooo`3oool000001P3oool00`000000oooo0?ooo`2>0?ooo`00PP3oool0
1@000000oooo0?ooo`3oool0000000P0oooo00<000000?ooo`3oool0SP3oool00800oooo0P000005
0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool0SP3oool00880oooo00<000000?oo
o`0000000`3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo08h0oooo001n0?ooo`07
0000003oool0oooo0?ooo`000000oooo000000030?ooo`030000003oool0oooo00@0oooo00<00000
0?ooo`3oool0SP3oool007l0oooo0`0000030?ooo`<000001`3oool00`000000oooo0?ooo`2>0?oo
o`00OP3oool01`000000oooo0?ooo`3oool000000?ooo`0000000`3oool00`000000oooo0?ooo`04
0?ooo`030000003oool0oooo08h0oooo00220?ooo`030000003oool0oooo00<0oooo00<000000?oo
o`3oool0103oool00`000000oooo0?ooo`2>0?ooo`00P03oool2000000@0oooo0P0000070?ooo`03
0000003oool0oooo08h0oooo00220?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0
103oool00`000000oooo0?ooo`2>0?ooo`00OP3oool01`000000oooo0?ooo`3oool000000?ooo`00
00000`3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo08h0oooo001o0?ooo`<00000
0`3oool3000000L0oooo00<000000?ooo`3oool0SP3oool007h0oooo00D000000?ooo`3oool0oooo
000000030?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool0SP3oool00880oooo00<0
00000?ooo`3oool00P3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo08h0oooo0020
0?ooo`8000001@3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo08h0oooo00220?oo
o`030000003oool0oooo00<0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`2>0?oo
o`00OP3oool01`000000oooo0?ooo`3oool000000?ooo`0000000`3oool00`000000oooo0?ooo`04
0?ooo`030000003oool0oooo08h0oooo001o0?ooo`<000000P3oool5000000H0oooo00<000000?oo
o`3oool0SP3oool007h0oooo00L000000?ooo`3oool0oooo0000003oool0000000<0oooo00<00000
0?ooo`3oool0103oool00`000000oooo0?ooo`2>0?ooo`00PP3oool00`000000oooo000000030?oo
o`030000003oool0oooo00@0oooo00<000000?ooo`3oool0SP3oool00800oooo0P0000030?ooo`<0
00001`3oool00`000000oooo0?ooo`2>0?ooo`00PP3oool00`000000oooo000000030?ooo`030000
003oool0oooo00@0oooo00<000000?ooo`3oool0SP3oool007h0oooo00L000000?ooo`3oool0oooo
0000003oool0000000<0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`2>0?ooo`00
O`3oool400000080oooo0`0000070?ooo`030000003oool0oooo08h0oooo00210?ooo`050000003o
ool0oooo0?ooo`0000000P3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo08h0oooo
001n0?ooo`D000000P3oool010000000oooo0?ooo`0000060?ooo`030000003oool0oooo08h0oooo
001n0?ooo`040000003oool0oooo000000<0oooo00@000000?ooo`3oool000001P3oool00`000000
oooo0?ooo`2>0?ooo`00O`3oool00`000000oooo000000030?ooo`040000003oool0oooo000000H0
oooo00<000000?ooo`3oool0SP3oool00800oooo0P0000030?ooo`040000003oool0oooo000000H0
oooo00<000000?ooo`3oool0SP3oool00800oooo0`0000020?ooo`<000001`3oool00`000000oooo
0?ooo`2>0?ooo`00P@3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00H0oooo00<0
00000?ooo`3oool0SP3oool007h0oooo1@0000030?ooo`030000003oool0oooo00H0oooo00<00000
0?ooo`3oool0SP3oool007h0oooo00@000000?ooo`3oool00000103oool00`000000oooo0?ooo`06
0?ooo`030000003oool0oooo08h0oooo001o0?ooo`030000003oool0000000@0oooo00<000000?oo
o`3oool01P3oool00`000000oooo0?ooo`2>0?ooo`00P03oool2000000<0oooo0P0000080?ooo`03
0000003oool0oooo08h0oooo00200?ooo`<000000`3oool3000000H0oooo00<000000?ooo`3oool0
SP3oool00840oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`050?ooo`030000003o
ool0oooo08h0oooo001n0?ooo`D0000000<0oooo0000000000000`0000060?ooo`030000003oool0
oooo08h0oooo001n0?ooo`040000003oool0oooo00000080oooo00@000000?ooo`3oool000001`3o
ool00`000000oooo0?ooo`2>0?ooo`00O`3oool00`000000oooo000000030?ooo`030000003oool0
000000L0oooo00<000000?ooo`3oool0SP3oool00800oooo0`0000020?ooo`<000001`3oool00`00
0000oooo0?ooo`2>0?ooo`00P@3oool010000000oooo0?ooo`0000020?ooo`8000001P3oool00`00
0000oooo0?ooo`2>0?ooo`00OP3oool5000000D0oooo00<000000?ooo`3oool0103oool00`000000
oooo0?ooo`2>0?ooo`00OP3oool010000000oooo0?ooo`0000060?ooo`030000003oool0oooo00@0
oooo00<000000?ooo`3oool0SP3oool007l0oooo00<000000?ooo`0000000P3oool4000000L0oooo
00<000000?ooo`3oool0SP3oool00800oooo0P0000020?ooo`030000003oool0oooo00P0oooo00<0
00000?ooo`3oool0SP3oool00800oooo0`0000000`3oool0000000000003000000H0oooo00<00000
0?ooo`3oool0SP3oool00840oooo00@000000?ooo`3oool000000`3oool00`000000oooo0?ooo`04
0?ooo`030000003oool0oooo08h0oooo001n0?ooo`D0000000<0oooo0000003oool00P3oool00`00
0000oooo0?ooo`040?ooo`030000003oool0oooo08h0oooo001n0?ooo`040000003oool0oooo0000
0080oooo100000070?ooo`030000003oool0oooo08h0oooo001o0?ooo`030000003oool000000080
oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`2>0?ooo`00P03oool2000000<0oooo
00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`2>0?ooo`00P03oool300000080oooo0`00
00070?ooo`030000003oool0oooo08h0oooo00210?ooo`040000003oool0oooo000000<0oooo00<0
00000?ooo`3oool0103oool00`000000oooo0?ooo`2>0?ooo`00OP3oool5000000030?ooo`000000
oooo0080oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`2>0?ooo`00OP3oool01000
0000oooo0?ooo`0000030?ooo`<00000V03oool007l0oooo00<000000?ooo`0000000P3oool01@00
0000oooo0?ooo`3oool0000009L0oooo00200?ooo`8000000P3oool01@000000oooo0?ooo`3oool0
000009L0oooo00210?ooo`040000003oool0oooo0?ooo`<00000V03oool00?l0oooo8@3oool00001
\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-1.0062, -1.00015, \
0.0174648, 0.169552}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.2 0.2 0.0206011 0.0206011 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
0 g
.5 Mabswid
[ ] 0 setdash
.4 .0412 m
.4 .0206 L
s
.4 .0618 m
.4 .0412 L
s
.7 .0412 m
.6 .0206 L
s
.7 .0412 m
.8 .0206 L
s
.6 .0824 m
.4 .0618 L
s
.6 .0824 m
.7 .0412 L
s
.6 .10301 m
.6 .0824 L
s
.6 .12361 m
.6 .10301 L
s
.6 .14421 m
.6 .12361 L
s
.5 .16481 m
.2 .0206 L
s
.5 .16481 m
.6 .14421 L
s
.5 .18541 m
.5 .16481 L
s
.5 .20601 m
.5 .18541 L
s
.5 .22661 m
.5 .20601 L
s
.5 .24721 m
.5 .22661 L
s
.5 .26781 m
.5 .24721 L
s
.5 .28842 m
.5 .26781 L
s
.5 .30902 m
.5 .28842 L
s
.5 .32962 m
.5 .30902 L
s
.5 .35022 m
.5 .32962 L
s
.5 .37082 m
.5 .35022 L
s
.5 .39142 m
.5 .37082 L
s
.5 .41202 m
.5 .39142 L
s
.5 .43262 m
.5 .41202 L
s
.5 .45322 m
.5 .43262 L
s
.5 .47383 m
.5 .45322 L
s
.5 .49443 m
.5 .47383 L
s
.5 .51503 m
.5 .49443 L
s
.5 .53563 m
.5 .51503 L
s
.5 .55623 m
.5 .53563 L
s
.5 .57683 m
.5 .55623 L
s
.5 .59743 m
.5 .57683 L
s
[(2)] .36 .04532 0 0 Mshowa
[(3)] .36 .06592 0 0 Mshowa
[(4)] .66 .04532 0 0 Mshowa
[(5)] .56 .08652 0 0 Mshowa
[(6)] .56 .10713 0 0 Mshowa
[(8)] .56 .12773 0 0 Mshowa
[(9)] .56 .14833 0 0 Mshowa
[(11)] .46 .16893 0 0 Mshowa
[(12)] .46 .18953 0 0 Mshowa
[(14)] .46 .21013 0 0 Mshowa
[(16)] .46 .23073 0 0 Mshowa
[(17)] .46 .25133 0 0 Mshowa
[(18)] .46 .27193 0 0 Mshowa
[(20)] .46 .29254 0 0 Mshowa
[(21)] .46 .31314 0 0 Mshowa
[(23)] .46 .33374 0 0 Mshowa
[(24)] .46 .35434 0 0 Mshowa
[(26)] .46 .37494 0 0 Mshowa
[(30)] .46 .39554 0 0 Mshowa
[(32)] .46 .41614 0 0 Mshowa
[(33)] .46 .43674 0 0 Mshowa
[(37)] .46 .45735 0 0 Mshowa
[(38)] .46 .47795 0 0 Mshowa
[(40)] .46 .49855 0 0 Mshowa
[(41)] .46 .51915 0 0 Mshowa
[(44)] .46 .53975 0 0 Mshowa
[(45)] .46 .56035 0 0 Mshowa
[(46)] .46 .58095 0 0 Mshowa
[(48)] .46 .60155 0 0 Mshowa
gsave
.2 .01648 -66 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(d) show
1.000 setlinewidth
grestore
gsave
.4 .01648 -66 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(b) show
1.000 setlinewidth
grestore
gsave
.6 .01648 -66 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(a) show
1.000 setlinewidth
grestore
gsave
.8 .01648 -66 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(c) show
1.000 setlinewidth
grestore
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[464]:=",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/B000`400?l00000o`00003oo`3ooolQ
0?ooo`00o`3ooolQ0?ooo`00=`3oool4000003@0oooo1000000g0?ooo`@00000=@3oool3000003X0
oooo000f0?ooo`040000003oool0oooo000003H0oooo00@000000?ooo`3oool00000=@3oool01000
0000oooo0?ooo`00000e0?ooo`050000003oool0oooo0?ooo`000000>@3oool003H0oooo00@00000
0?ooo`3oool00000=P3oool010000000oooo0?ooo`00000f0?ooo`<00000=@3oool00`000000oooo
0?ooo`0k0?ooo`00=P3oool00`000000oooo0?ooo`02000003D0oooo00@000000?ooo`0000000000
=@3oool00`000000oooo0?ooo`03000003<0oooo1@00000i0?ooo`00=`3oool3000000030?ooo`00
0000000003<0oooo0`00000g0?ooo`8000000`3oool5000002X0oooo2000000j0?ooo`00>@3oool0
10000000oooo0?ooo`3oool200000340oooo00<000000?ooo`000000@@3oool500000200oooo1@00
00120?ooo`00>03oool2000000D0oooo0P00000^0?ooo`80000000<0oooo0000003oool0A@3oool4
000001L0oooo1@0000170?ooo`00@@3oool2000002l0oooo00<000000?ooo`3oool0B03oool50000
00d0oooo1@00001<0?ooo`00@`3oool2000001l0oooo1@0000090?ooo`030000003oool0oooo04L0
oooo0`0000030?ooo`D000000`3oool500000540oooo00150?ooo`8000007P3oool010000000oooo
0?ooo`0000090?ooo`030000003oool0oooo04P0oooo00<000000?ooo`3oool01`3oool3000005H0
oooo00170?ooo`8000007@3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo04D0oooo
1@0000050?ooo`<00000F@3oool004T0oooo0P00000L0?ooo`030000003oool0oooo00P0oooo00<0
00000?ooo`3oool0A@3oool010000000oooo0?ooo`0000040?ooo`800000G03oool004/0oooo0P00
000G0?ooo`050000003oool0oooo0?ooo`0000002@3oool00`000000oooo0?ooo`160?ooo`030000
003oool000000080oooo0P00001N0?ooo`00C@3oool3000001@0oooo00D000000?ooo`3oool0oooo
000000090?ooo`030000003oool0oooo04L0oooo1000001P0?ooo`00D03oool2000001<0oooo0`00
000:0?ooo`030000003oool0oooo04H0oooo0`00001R0?ooo`00DP3oool200000100oooo00D00000
0?ooo`3oool0oooo000000090?ooo`H00000@@3oool2000006D0oooo001D0?ooo`8000004P3oool0
0`000000oooo0?ooo`0=0?ooo`X00000=03oool3000006L0oooo001F0?ooo`8000003P3oool20000
01X0oooo2@00000Y0?ooo`800000JP3oool005P0oooo0P00000>0?ooo`030000003oool0oooo0200
oooo2P00000M0?ooo`800000K03oool005X0oooo0P0000080?ooo`050000003oool0oooo0?ooo`00
0000;03oool:00000100oooo0`00001^0?ooo`00G03oool2000000L0oooo0`00000f0?ooo`X00000
1@3oool200000740oooo001N0?ooo`800000?@3oool01@000000oooo0?ooo`3oool0000000H0oooo
1@00001c0?ooo`00H03oool2000003l0oooo00<000000?ooo`3oool0203oool00`000000oooo0?oo
o`1a0?ooo`00HP3oool2000003d0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`1a
0?ooo`00I03oool2000003L0oooo1000000;0?ooo`030000003oool0oooo0740oooo001V0?ooo`80
0000=@3oool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo0740oooo001X0?ooo`800000
<`3oool5000000X0oooo00<000000?ooo`3oool0L@3oool006X0oooo0P00000a0?ooo`050000003o
ool0oooo0?ooo`0000002P3oool00`000000oooo0?ooo`1a0?ooo`00K03oool2000002l0oooo00D0
00000?ooo`3oool0oooo0000000:0?ooo`030000003oool0oooo0740oooo001^0?ooo`800000;@3o
ool4000000/0oooo00<000000?ooo`3oool0L@3oool00700oooo0P00000[0?ooo`030000003oool0
oooo00`0oooo00<000000?ooo`3oool0L@3oool00780oooo0P00000Z0?ooo`030000003oool0oooo
00/0oooo00<000000?ooo`3oool0L@3oool007@0oooo0P00000X0?ooo`<000002`3oool00`000000
oooo0?ooo`1a0?ooo`00MP3oool2000002D0oooo00D000000?ooo`3oool0oooo0000000:0?ooo`03
0000003oool0oooo0740oooo001h0?ooo`<000008P3oool01@000000oooo0?ooo`3oool0000000X0
oooo00<000000?ooo`3oool0L@3oool007/0oooo0P00000Q0?ooo`<000002`3oool00`000000oooo
0?ooo`1a0?ooo`00O@3oool2000001h0oooo00D000000?ooo`3oool0oooo0000000:0?ooo`030000
003oool0oooo0740oooo001o0?ooo`800000703oool01@000000oooo0?ooo`3oool0000000X0oooo
00<000000?ooo`3oool0L@3oool00840oooo0P00000K0?ooo`<000002`3oool00`000000oooo0?oo
o`1a0?ooo`00P`3oool2000001/0oooo00<000000?ooo`3oool01`3oool3000007<0oooo00250?oo
o`8000006P3oool010000000oooo0?ooo`3oool5000007H0oooo00270?ooo`8000005@3oool70000
07/0oooo00290?ooo`800000403oool5000000030?ooo`000000oooo07d0oooo001o0?ooo`<00000
0`3oool3000000<0oooo0P0000090?ooo`D000000P3oool01@000000oooo0?ooo`3oool0000007h0
oooo00200?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0103oool200000080oooo
1@0000080?ooo`<00000O`3oool00800oooo00<000000?ooo`3oool00`3oool00`000000oooo0?oo
o`060?ooo`800000S`3oool00800oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`06
0?ooo`030000003oool0oooo08h0oooo00200?ooo`030000003oool0oooo00<0oooo00<000000?oo
o`3oool01P3oool00`000000oooo0?ooo`2>0?ooo`00O`3oool2000000@0oooo0P0000080?ooo`03
0000003oool0oooo08h0oooo001o0?ooo`<000000P3oool5000000H0oooo00<000000?ooo`3oool0
SP3oool00800oooo00<000000?ooo`3oool00P3oool010000000oooo0?ooo`0000060?ooo`030000
003oool0oooo08h0oooo00200?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool01P3o
ool00`000000oooo0?ooo`2>0?ooo`00P03oool00`000000oooo0?ooo`040?ooo`030000003oool0
oooo00D0oooo00<000000?ooo`3oool0SP3oool00800oooo00D000000?ooo`3oool0oooo00000003
0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0SP3oool007l0oooo0P0000030?oo
o`050000003oool0oooo0?ooo`0000001P3oool00`000000oooo0?ooo`2>0?ooo`00O`3oool30000
00<0oooo100000060?ooo`030000003oool0oooo08h0oooo00200?ooo`030000003oool0oooo00@0
oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`2>0?ooo`00P03oool010000000oooo
0?ooo`3oool5000000H0oooo00<000000?ooo`3oool0SP3oool00800oooo00D000000?ooo`3oool0
oooo000000020?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool0SP3oool00800oooo
00<000000?ooo`3oool00P3oool00`000000oooo000000070?ooo`030000003oool0oooo08h0oooo
001o0?ooo`8000001@3oool2000000L0oooo00<000000?ooo`3oool0SP3oool007l0oooo0`000003
0?ooo`<000001`3oool00`000000oooo0?ooo`2>0?ooo`00P03oool01@000000oooo0?ooo`3oool0
000000<0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`2>0?ooo`00P03oool01@00
0000oooo0?ooo`3oool0000000<0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`2>
0?ooo`00P03oool010000000oooo0?ooo`3oool4000000L0oooo00<000000?ooo`3oool0SP3oool0
0800oooo00D000000?ooo`3oool0oooo0000000:0?ooo`030000003oool0oooo08h0oooo001o0?oo
o`800000103oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo08h0oooo001o0?ooo`<0
0000103oool2000000L0oooo00<000000?ooo`3oool0SP3oool00800oooo00<000000?ooo`3oool0
0`3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo08h0oooo00200?ooo`030000003o
ool0oooo00@0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`2>0?ooo`00P03oool0
0`000000oooo0?ooo`040?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool0SP3oool0
0800oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo
08h0oooo001o0?ooo`8000000`3oool01@000000oooo0?ooo`3oool0000000H0oooo00<000000?oo
o`3oool0SP3oool007l0oooo0`0000020?ooo`D000001P3oool00`000000oooo0?ooo`2>0?ooo`00
P03oool01@000000oooo0?ooo`3oool0000000<0oooo00<000000?ooo`3oool0103oool00`000000
oooo0?ooo`2>0?ooo`00P03oool01@000000oooo0?ooo`3oool0000000<0oooo00<000000?ooo`3o
ool0103oool00`000000oooo0?ooo`2>0?ooo`00P03oool00`000000oooo0?ooo`020?ooo`<00000
1`3oool00`000000oooo0?ooo`2>0?ooo`00P03oool01@000000oooo0?ooo`3oool0000000<0oooo
00<000000?ooo`3oool0103oool00`000000oooo0?ooo`2>0?ooo`00O`3oool2000000<0oooo00D0
00000?ooo`3oool0oooo000000060?ooo`030000003oool0oooo08h0oooo001n0?ooo`D000000P3o
ool3000000L0oooo00<000000?ooo`3oool0SP3oool007l0oooo00@000000?ooo`3oool000000P3o
ool010000000oooo0?ooo`0000060?ooo`030000003oool0oooo08h0oooo00200?ooo`030000003o
ool0oooo0080oooo00@000000?ooo`3oool000001P3oool00`000000oooo0?ooo`2>0?ooo`00P@3o
ool01@000000oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool0103oool00`000000oooo
0?ooo`2>0?ooo`00OP3oool01@000000oooo0?ooo`3oool000000080oooo00@000000?ooo`3oool0
00001P3oool00`000000oooo0?ooo`2>0?ooo`00OP3oool01@000000oooo0?ooo`3oool000000080
oooo00@000000?ooo`3oool000001P3oool00`000000oooo0?ooo`2>0?ooo`00OP3oool500000080
oooo0`0000070?ooo`030000003oool0oooo08h0oooo001o0?ooo`040000003oool0oooo000000<0
oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`2>0?ooo`00P03oool00`000000oooo
0?ooo`030?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool0SP3oool00840oooo00<0
00000?ooo`3oool00P3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo08h0oooo001n
0?ooo`050000003oool0oooo0?ooo`0000000`3oool00`000000oooo0?ooo`060?ooo`030000003o
ool0oooo08h0oooo001n0?ooo`050000003oool0oooo0?ooo`0000000P3oool2000000P0oooo00<0
00000?ooo`3oool0SP3oool007h0oooo1@0000020?ooo`<000001`3oool00`000000oooo0?ooo`2>
0?ooo`00O`3oool01P000000oooo0?ooo`000000oooo000000<0oooo00<000000?ooo`3oool0103o
ool00`000000oooo0?ooo`2>0?ooo`00P03oool00`000000oooo0?ooo`050?ooo`030000003oool0
oooo00@0oooo00<000000?ooo`3oool0SP3oool00840oooo00<000000?ooo`3oool00P3oool20000
00L0oooo00<000000?ooo`3oool0SP3oool007h0oooo00D000000?ooo`3oool0oooo000000050?oo
o`030000003oool0oooo00@0oooo00<000000?ooo`3oool0SP3oool007h0oooo00L000000?ooo`3o
ool0oooo0000003oool0000000<0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`2>
0?ooo`00OP3oool500000080oooo100000060?ooo`030000003oool0oooo08h0oooo001o0?ooo`04
0000003oool0oooo000000@0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`2>0?oo
o`00P03oool010000000oooo0?ooo`3oool5000000H0oooo00<000000?ooo`3oool0SP3oool00840
oooo00@000000?ooo`3oool000000P3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo
08h0oooo001n0?ooo`050000003oool0oooo0?ooo`0000000P3oool00`000000oooo000000070?oo
o`030000003oool0oooo08h0oooo001n0?ooo`D000000P3oool3000000L0oooo00<000000?ooo`3o
ool0SP3oool007l0oooo10000000103oool000000?ooo`3oool2000000H0oooo00<000000?ooo`3o
ool0SP3oool00800oooo00D000000?ooo`3oool0oooo000000030?ooo`030000003oool0oooo00@0
oooo00<000000?ooo`3oool0SP3oool00840oooo00<000000?ooo`3oool0100000070?ooo`030000
003oool0oooo08h0oooo001n0?ooo`070000003oool0oooo0?ooo`000000oooo0000000:0?ooo`03
0000003oool0oooo08h0oooo001n0?ooo`050000003oool0oooo0?ooo`0000000P3oool00`000000
oooo0?ooo`070?ooo`030000003oool0oooo08h0oooo001o0?ooo`<00000103oool2000000L0oooo
00<000000?ooo`3oool0SP3oool007h0oooo00D000000?ooo`3oool0oooo000000020?ooo`040000
003oool0oooo000000H0oooo00<000000?ooo`3oool0SP3oool00880oooo00@000000?ooo`3oool0
00000P3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo08h0oooo00200?ooo`800000
0`3oool010000000oooo0?ooo`0000060?ooo`030000003oool0oooo08h0oooo00220?ooo`040000
003oool0oooo00000080oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`2>0?ooo`00
OP3oool01@000000oooo0?ooo`3oool000000080oooo00@000000?ooo`3oool000001P3oool00`00
0000oooo0?ooo`2>0?ooo`00O`3oool300000080oooo1@0000060?ooo`030000003oool0oooo08h0
oooo001n0?ooo`050000003oool0oooo0?ooo`0000000P3oool010000000oooo0?ooo`0000060?oo
o`030000003oool0oooo08h0oooo00220?ooo`050000003oool0oooo0?ooo`000000203oool00`00
0000oooo0?ooo`2>0?ooo`00P03oool2000000D0oooo00<000000?ooo`3oool01@3oool00`000000
oooo0?ooo`2>0?ooo`00PP3oool00`000000oooo000000030?ooo`030000003oool0oooo00@0oooo
00<000000?ooo`3oool0SP3oool007h0oooo00L000000?ooo`3oool0oooo0000003oool0000000<0
oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`2>0?ooo`00O`3oool3000000<0oooo
0`0000070?ooo`030000003oool0oooo08h0oooo001n0?ooo`070000003oool0oooo0?ooo`000000
oooo000000030?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0SP3oool00880oooo
00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo08h0oooo
00200?ooo`800000103oool2000000L0oooo00<000000?ooo`3oool0SP3oool00880oooo00<00000
0?ooo`3oool00`3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo08h0oooo001n0?oo
o`070000003oool0oooo0?ooo`000000oooo000000030?ooo`030000003oool0oooo00@0oooo00<0
00000?ooo`3oool0SP3oool007l0oooo0`0000030?ooo`<000001`3oool00`000000oooo0?ooo`2>
0?ooo`00OP3oool01@000000oooo0?ooo`3oool0000000<0oooo00<000000?ooo`3oool01P3oool0
0`000000oooo0?ooo`2>0?ooo`00PP3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo
00D0oooo00<000000?ooo`3oool0SP3oool00800oooo0P0000050?ooo`030000003oool0oooo00D0
oooo00<000000?ooo`3oool0SP3oool00880oooo00<000000?ooo`3oool00`3oool00`000000oooo
0?ooo`040?ooo`030000003oool0oooo08h0oooo001n0?ooo`070000003oool0oooo0?ooo`000000
oooo000000030?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0SP3oool007l0oooo
0`0000020?ooo`D000001P3oool00`000000oooo0?ooo`2>0?ooo`00OP3oool01`000000oooo0?oo
o`3oool000000?ooo`0000000`3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo08h0
oooo00220?ooo`030000003oool0000000<0oooo00<000000?ooo`3oool0103oool00`000000oooo
0?ooo`2>0?ooo`00P03oool2000000<0oooo0`0000070?ooo`030000003oool0oooo08h0oooo0022
0?ooo`030000003oool0000000<0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`2>
0?ooo`00OP3oool01`000000oooo0?ooo`3oool000000?ooo`0000000`3oool00`000000oooo0?oo
o`040?ooo`030000003oool0oooo08h0oooo001o0?ooo`@000000P3oool3000000L0oooo00<00000
0?ooo`3oool0SP3oool00840oooo00D000000?ooo`3oool0oooo000000020?ooo`030000003oool0
oooo00@0oooo00<000000?ooo`3oool0SP3oool007h0oooo1@0000020?ooo`040000003oool0oooo
000000H0oooo00<000000?ooo`3oool0SP3oool007h0oooo00@000000?ooo`3oool000000`3oool0
10000000oooo0?ooo`0000060?ooo`030000003oool0oooo08h0oooo001o0?ooo`030000003oool0
000000<0oooo00@000000?ooo`3oool000001P3oool00`000000oooo0?ooo`2>0?ooo`00P03oool2
000000<0oooo00@000000?ooo`3oool000001P3oool00`000000oooo0?ooo`2>0?ooo`00P03oool3
00000080oooo0`0000070?ooo`030000003oool0oooo08h0oooo00210?ooo`030000003oool0oooo
0080oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`2>0?ooo`00OP3oool5000000<0
oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`2>0?ooo`00OP3oool010000000oooo
0?ooo`0000040?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool0SP3oool007l0oooo
00<000000?ooo`000000103oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo08h0oooo
00200?ooo`8000000`3oool2000000P0oooo00<000000?ooo`3oool0SP3oool00800oooo0`000003
0?ooo`<000001P3oool00`000000oooo0?ooo`2>0?ooo`00P@3oool00`000000oooo0?ooo`030?oo
o`030000003oool0oooo00D0oooo00<000000?ooo`3oool0SP3oool007h0oooo1@0000000`3oool0
000000000003000000H0oooo00<000000?ooo`3oool0SP3oool007h0oooo00@000000?ooo`3oool0
00000P3oool010000000oooo0?ooo`0000070?ooo`030000003oool0oooo08h0oooo001o0?ooo`03
0000003oool0000000<0oooo00<000000?ooo`0000001`3oool00`000000oooo0?ooo`2>0?ooo`00
P03oool300000080oooo0`0000070?ooo`030000003oool0oooo08h0oooo00210?ooo`040000003o
ool0oooo00000080oooo0P0000060?ooo`030000003oool0oooo08h0oooo001n0?ooo`D000001@3o
ool00`000000oooo0?ooo`040?ooo`030000003oool0oooo08h0oooo001n0?ooo`040000003oool0
oooo000000H0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`2>0?ooo`00O`3oool0
0`000000oooo000000020?ooo`@000001`3oool00`000000oooo0?ooo`2>0?ooo`00P03oool20000
0080oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`2>0?ooo`00P03oool300000003
0?ooo`000000000000<000001P3oool00`000000oooo0?ooo`2>0?ooo`00P@3oool010000000oooo
0?ooo`0000030?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0SP3oool007h0oooo
1@0000000`3oool000000?ooo`020?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0
SP3oool007h0oooo00@000000?ooo`3oool000000P3oool4000000L0oooo00<000000?ooo`3oool0
SP3oool007l0oooo00<000000?ooo`0000000P3oool00`000000oooo0?ooo`080?ooo`030000003o
ool0oooo08h0oooo00200?ooo`8000000`3oool00`000000oooo0?ooo`070?ooo`030000003oool0
oooo08h0oooo00200?ooo`<000000P3oool3000000L0oooo00<000000?ooo`3oool0SP3oool00840
oooo00@000000?ooo`3oool000000`3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo
08h0oooo001n0?ooo`D0000000<0oooo0000003oool00P3oool00`000000oooo0?ooo`040?ooo`03
0000003oool0oooo08h0oooo001n0?ooo`040000003oool0oooo000000<0oooo0`00002H0?ooo`00
O`3oool00`000000oooo000000020?ooo`050000003oool0oooo0?ooo`000000U`3oool00800oooo
0P0000020?ooo`050000003oool0oooo0?ooo`000000U`3oool00840oooo00@000000?ooo`3oool0
oooo0`00002H0?ooo`00o`3ooolQ0?ooo`00\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-1.0062, -1.00015, \
0.0174648, 0.169552}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.2 0.2 0.0199366 0.0199366 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
0 g
.5 Mabswid
[ ] 0 setdash
.4 .03987 m
.4 .01994 L
s
.4 .05981 m
.4 .03987 L
s
.7 .03987 m
.6 .01994 L
s
.7 .03987 m
.8 .01994 L
s
.6 .07975 m
.4 .05981 L
s
.6 .07975 m
.7 .03987 L
s
.6 .09968 m
.6 .07975 L
s
.6 .11962 m
.6 .09968 L
s
.6 .13956 m
.6 .11962 L
s
.5 .15949 m
.2 .01994 L
s
.5 .15949 m
.6 .13956 L
s
.5 .17943 m
.5 .15949 L
s
.5 .19937 m
.5 .17943 L
s
.5 .2193 m
.5 .19937 L
s
.5 .23924 m
.5 .2193 L
s
.5 .25918 m
.5 .23924 L
s
.5 .27911 m
.5 .25918 L
s
.5 .29905 m
.5 .27911 L
s
.5 .31899 m
.5 .29905 L
s
.5 .33892 m
.5 .31899 L
s
.5 .35886 m
.5 .33892 L
s
.5 .3788 m
.5 .35886 L
s
.5 .39873 m
.5 .3788 L
s
.5 .41867 m
.5 .39873 L
s
.5 .4386 m
.5 .41867 L
s
.5 .45854 m
.5 .4386 L
s
.5 .47848 m
.5 .45854 L
s
.5 .49841 m
.5 .47848 L
s
.5 .51835 m
.5 .49841 L
s
.5 .53829 m
.5 .51835 L
s
.5 .55822 m
.5 .53829 L
s
.5 .57816 m
.5 .55822 L
s
.5 .5981 m
.5 .57816 L
s
[(2)] .36 .04386 0 0 Mshowa
[(3)] .36 .0638 0 0 Mshowa
[(4)] .66 .04386 0 0 Mshowa
[(5)] .56 .08373 0 0 Mshowa
[(6)] .56 .10367 0 0 Mshowa
[(8)] .56 .12361 0 0 Mshowa
[(9)] .56 .14354 0 0 Mshowa
[(11)] .46 .16348 0 0 Mshowa
[(12)] .46 .18342 0 0 Mshowa
[(14)] .46 .20335 0 0 Mshowa
[(16)] .46 .22329 0 0 Mshowa
[(17)] .46 .24323 0 0 Mshowa
[(18)] .46 .26316 0 0 Mshowa
[(20)] .46 .2831 0 0 Mshowa
[(21)] .46 .30304 0 0 Mshowa
[(23)] .46 .32297 0 0 Mshowa
[(24)] .46 .34291 0 0 Mshowa
[(26)] .46 .36285 0 0 Mshowa
[(30)] .46 .38278 0 0 Mshowa
[(32)] .46 .40272 0 0 Mshowa
[(34)] .46 .42266 0 0 Mshowa
[(36)] .46 .44259 0 0 Mshowa
[(37)] .46 .46253 0 0 Mshowa
[(38)] .46 .48247 0 0 Mshowa
[(40)] .46 .5024 0 0 Mshowa
[(41)] .46 .52234 0 0 Mshowa
[(44)] .46 .54227 0 0 Mshowa
[(45)] .46 .56221 0 0 Mshowa
[(46)] .46 .58215 0 0 Mshowa
[(48)] .46 .60208 0 0 Mshowa
gsave
.2 .01595 -66 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(d) show
1.000 setlinewidth
grestore
gsave
.4 .01595 -66 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(b) show
1.000 setlinewidth
grestore
gsave
.6 .01595 -66 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(a) show
1.000 setlinewidth
grestore
gsave
.8 .01595 -66 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(c) show
1.000 setlinewidth
grestore
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[464]:=",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/B000`400?l00000o`00003oo`3ooolQ
0?ooo`00o`3ooolQ0?ooo`00=`3oool4000003@0oooo1000000g0?ooo`@00000=@3oool3000003X0
oooo000f0?ooo`040000003oool0oooo000003H0oooo00@000000?ooo`3oool00000=@3oool01000
0000oooo0?ooo`00000e0?ooo`050000003oool0oooo0?ooo`000000>@3oool003H0oooo00@00000
0?ooo`3oool00000=P3oool010000000oooo0?ooo`00000f0?ooo`<00000=@3oool00`000000oooo
0?ooo`0k0?ooo`00=P3oool00`000000oooo0?ooo`02000003D0oooo00@000000?ooo`0000000000
=@3oool00`000000oooo0?ooo`03000003<0oooo1@00000i0?ooo`00=`3oool3000000030?ooo`00
0000000003<0oooo0`00000g0?ooo`8000000`3oool5000002X0oooo2000000j0?ooo`00>@3oool0
10000000oooo0?ooo`3oool200000340oooo00<000000?ooo`000000@@3oool500000200oooo1@00
00120?ooo`00>03oool2000000D0oooo0`00000]0?ooo`80000000<0oooo0000003oool0A@3oool4
000001L0oooo1@0000170?ooo`00@P3oool2000002h0oooo00<000000?ooo`3oool0B03oool50000
00d0oooo1@00001<0?ooo`00A03oool2000001h0oooo1@0000090?ooo`030000003oool0oooo04L0
oooo0`0000030?ooo`D000000`3oool500000540oooo00160?ooo`8000007@3oool010000000oooo
0?ooo`0000090?ooo`030000003oool0oooo04P0oooo00<000000?ooo`3oool01`3oool3000005H0
oooo00180?ooo`800000703oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo04D0oooo
1@0000050?ooo`<00000F@3oool004X0oooo0P00000K0?ooo`030000003oool0oooo00P0oooo00<0
00000?ooo`3oool0A@3oool010000000oooo0?ooo`0000040?ooo`800000G03oool004`0oooo0P00
000F0?ooo`050000003oool0oooo0?ooo`0000002@3oool00`000000oooo0?ooo`160?ooo`040000
003oool000000?ooo`<00000GP3oool004h0oooo0`00000C0?ooo`D000002@3oool00`000000oooo
0?ooo`170?ooo`<00000H@3oool00540oooo0P00000A0?ooo`D000002@3oool00`000000oooo0?oo
o`150?ooo`@00000HP3oool005<0oooo0P00000C0?ooo`030000003oool0oooo00L0oooo1`00000n
0?ooo`<00000IP3oool005D0oooo0P00000?0?ooo`8000004@3oool;00000340oooo0P00001Y0?oo
o`00E`3oool2000000l0oooo00<000000?ooo`3oool06@3oool<00000280oooo0`00001[0?ooo`00
F@3oool2000000T0oooo00D000000?ooo`3oool0oooo0000000W0?ooo``00000503oool2000006h0
oooo001K0?ooo`800000203oool3000003@0oooo2`0000060?ooo`<00000L03oool005d0oooo0`00
000m0?ooo`050000003oool0oooo0?ooo`0000001@3oool6000007<0oooo001P0?ooo`800000?`3o
ool00`000000oooo0?ooo`080?ooo`030000003oool0oooo0740oooo001R0?ooo`800000?@3oool0
0`000000oooo0?ooo`080?ooo`030000003oool0oooo0740oooo001T0?ooo`800000=`3oool40000
00/0oooo00<000000?ooo`3oool0L@3oool006H0oooo0P00000e0?ooo`030000003oool0oooo00`0
oooo00<000000?ooo`3oool0L@3oool006P0oooo0P00000c0?ooo`D000002P3oool00`000000oooo
0?ooo`1a0?ooo`00JP3oool300000300oooo00D000000?ooo`3oool0oooo0000000:0?ooo`030000
003oool0oooo0740oooo001]0?ooo`800000;P3oool01@000000oooo0?ooo`3oool0000000X0oooo
00<000000?ooo`3oool0L@3oool006l0oooo0P00000/0?ooo`@000002`3oool00`000000oooo0?oo
o`1a0?ooo`00L@3oool2000002X0oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`1a
0?ooo`00L`3oool2000002T0oooo0`00000;0?ooo`030000003oool0oooo0740oooo001e0?ooo`80
00009P3oool00`000000oooo00000002000000X0oooo00<000000?ooo`3oool0L@3oool007L0oooo
0P00000T0?ooo`050000003oool0oooo0?ooo`0000002P3oool00`000000oooo0?ooo`1a0?ooo`00
N@3oool300000280oooo0`00000;0?ooo`030000003oool0oooo0740oooo001l0?ooo`8000007`3o
ool01@000000oooo0?ooo`3oool0000000X0oooo00<000000?ooo`3oool0L@3oool007h0oooo0P00
000M0?ooo`050000003oool0oooo0?ooo`0000002P3oool00`000000oooo0?ooo`1a0?ooo`00P03o
ool2000001`0oooo0`00000;0?ooo`030000003oool0oooo0740oooo00220?ooo`800000703oool0
0`000000oooo0?ooo`090?ooo`030000003oool0oooo0740oooo00240?ooo`8000006`3oool00`00
0000oooo0?ooo`050?ooo`@00000L`3oool008H0oooo0P00000F0?ooo`@0000000<0oooo00000000
00001000001g0?ooo`00R03oool300000180oooo1P00001m0?ooo`00R`3oool2000000/0oooo1P00
00030?ooo`030000003oool0oooo07`0oooo001o0?ooo`<000000`3oool3000000D0oooo0P000003
0?ooo`H000001P3oool3000007l0oooo00200?ooo`030000003oool0oooo00<0oooo00<000000?oo
o`3oool01P3oool3000008h0oooo00200?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3o
ool01P3oool00`000000oooo0?ooo`2>0?ooo`00P03oool00`000000oooo0?ooo`030?ooo`030000
003oool0oooo00H0oooo00<000000?ooo`3oool0SP3oool00800oooo00<000000?ooo`3oool00`3o
ool00`000000oooo0?ooo`060?ooo`030000003oool0oooo08h0oooo001o0?ooo`800000103oool2
000000P0oooo00<000000?ooo`3oool0SP3oool007l0oooo0`0000020?ooo`D000001P3oool00`00
0000oooo0?ooo`2>0?ooo`00P03oool00`000000oooo0?ooo`020?ooo`040000003oool0oooo0000
00H0oooo00<000000?ooo`3oool0SP3oool00800oooo00<000000?ooo`3oool00`3oool00`000000
oooo0?ooo`060?ooo`030000003oool0oooo08h0oooo00200?ooo`030000003oool0oooo00@0oooo
00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`2>0?ooo`00P03oool01@000000oooo0?oo
o`3oool0000000<0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`2>0?ooo`00O`3o
ool300000080oooo00<000000?ooo`0000000P0000060?ooo`030000003oool0oooo08h0oooo0020
0?ooo`030000003oool0oooo0080oooo0`0000070?ooo`030000003oool0oooo08h0oooo00200?oo
o`040000003oool0oooo0?ooo`D000001P3oool00`000000oooo0?ooo`2>0?ooo`00P03oool01@00
0000oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`2>
0?ooo`00P03oool00`000000oooo0?ooo`020?ooo`030000003oool0000000L0oooo00<000000?oo
o`3oool0SP3oool007l0oooo0P0000050?ooo`8000001`3oool00`000000oooo0?ooo`2>0?ooo`00
O`3oool3000000<0oooo0`0000070?ooo`030000003oool0oooo08h0oooo00200?ooo`050000003o
ool0oooo0?ooo`0000000`3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo08h0oooo
00200?ooo`050000003oool0oooo0?ooo`0000000`3oool00`000000oooo0?ooo`040?ooo`030000
003oool0oooo08h0oooo00200?ooo`040000003oool0oooo0?ooo`@000001`3oool00`000000oooo
0?ooo`2>0?ooo`00P03oool01@000000oooo0?ooo`3oool0000000X0oooo00<000000?ooo`3oool0
SP3oool007l0oooo0P0000040?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool0SP3o
ool007l0oooo0`0000040?ooo`8000001`3oool00`000000oooo0?ooo`2>0?ooo`00P03oool00`00
0000oooo0?ooo`030?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool0SP3oool00800
oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo08h0
oooo00200?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool01@3oool00`000000oooo
0?ooo`2>0?ooo`00P03oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00@0oooo00<0
00000?ooo`3oool0SP3oool007l0oooo0`0000020?ooo`D000001P3oool00`000000oooo0?ooo`2>
0?ooo`00P03oool010000000oooo0?ooo`3oool5000000H0oooo00<000000?ooo`3oool0SP3oool0
0800oooo00D000000?ooo`3oool0oooo000000030?ooo`030000003oool0oooo00@0oooo00<00000
0?ooo`3oool0SP3oool00800oooo00<000000?ooo`3oool00P3oool3000000L0oooo00<000000?oo
o`3oool0SP3oool00800oooo00D000000?ooo`3oool0oooo000000030?ooo`030000003oool0oooo
00@0oooo00<000000?ooo`3oool0SP3oool007l0oooo0P0000030?ooo`050000003oool0oooo0?oo
o`0000001P3oool00`000000oooo0?ooo`2>0?ooo`00OP3oool500000080oooo0`0000070?ooo`03
0000003oool0oooo08h0oooo001o0?ooo`040000003oool0oooo00000080oooo00@000000?ooo`3o
ool000001P3oool00`000000oooo0?ooo`2>0?ooo`00P03oool00`000000oooo0?ooo`020?ooo`04
0000003oool0oooo000000H0oooo00<000000?ooo`3oool0SP3oool00840oooo00D000000?ooo`3o
ool0oooo000000020?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0SP3oool007h0
oooo00D000000?ooo`3oool0oooo000000020?ooo`040000003oool0oooo000000H0oooo00<00000
0?ooo`3oool0SP3oool007h0oooo00D000000?ooo`3oool0oooo000000020?ooo`040000003oool0
oooo000000H0oooo00<000000?ooo`3oool0SP3oool007h0oooo1@0000020?ooo`<000001`3oool0
0`000000oooo0?ooo`2>0?ooo`00O`3oool010000000oooo0?ooo`0000030?ooo`030000003oool0
oooo00H0oooo00<000000?ooo`3oool0SP3oool00800oooo00<000000?ooo`3oool00`3oool00`00
0000oooo0?ooo`060?ooo`030000003oool0oooo08h0oooo00210?ooo`030000003oool0oooo0080
oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`2>0?ooo`00OP3oool01@000000oooo
0?ooo`3oool0000000<0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`2>0?ooo`00
OP3oool01@000000oooo0?ooo`3oool000000080oooo0P0000080?ooo`030000003oool0oooo08h0
oooo001n0?ooo`D000000P3oool3000000L0oooo00<000000?ooo`3oool0SP3oool007l0oooo00H0
00000?ooo`3oool000000?ooo`0000030?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3o
ool0SP3oool00800oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`040?ooo`030000
003oool0oooo08h0oooo00210?ooo`030000003oool0oooo0080oooo0P0000070?ooo`030000003o
ool0oooo08h0oooo001n0?ooo`050000003oool0oooo0?ooo`0000001@3oool00`000000oooo0?oo
o`040?ooo`030000003oool0oooo08h0oooo001n0?ooo`D0000000<0oooo0000003oool00`000006
0?ooo`030000003oool0oooo08h0oooo001o0?ooo`@000000P3oool3000000L0oooo00<000000?oo
o`3oool0SP3oool00800oooo00@000000?ooo`3oool0oooo1@0000060?ooo`030000003oool0oooo
08h0oooo00210?ooo`040000003oool0oooo00000080oooo00<000000?ooo`3oool01@3oool00`00
0000oooo0?ooo`2>0?ooo`00OP3oool01@000000oooo0?ooo`3oool000000080oooo00<000000?oo
o`0000001`3oool00`000000oooo0?ooo`2>0?ooo`00OP3oool01@000000oooo0?ooo`3oool00000
00<0oooo0P0000070?ooo`030000003oool0oooo08h0oooo001n0?ooo`D000000P3oool3000000L0
oooo00<000000?ooo`3oool0SP3oool007l0oooo00H000000?ooo`3oool000000?ooo`0000030?oo
o`030000003oool0oooo00@0oooo00<000000?ooo`3oool0SP3oool00800oooo00D000000?ooo`3o
ool0oooo000000030?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0SP3oool00840
oooo00<000000?ooo`3oool0100000070?ooo`030000003oool0oooo08h0oooo001n0?ooo`070000
003oool0oooo0?ooo`000000oooo0000000:0?ooo`030000003oool0oooo08h0oooo001n0?ooo`05
0000003oool0oooo0?ooo`0000000P3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo
08h0oooo001o0?ooo`<00000103oool2000000L0oooo00<000000?ooo`3oool0SP3oool007h0oooo
00D000000?ooo`3oool0oooo000000020?ooo`040000003oool0oooo000000H0oooo00<000000?oo
o`3oool0SP3oool00880oooo00@000000?ooo`3oool000000P3oool00`000000oooo0?ooo`040?oo
o`030000003oool0oooo08h0oooo00200?ooo`8000000`3oool010000000oooo0?ooo`0000060?oo
o`030000003oool0oooo08h0oooo00220?ooo`040000003oool0oooo00000080oooo00<000000?oo
o`3oool0103oool00`000000oooo0?ooo`2>0?ooo`00OP3oool5000000030?ooo`000000000000<0
00001P3oool00`000000oooo0?ooo`2>0?ooo`00OP3oool500000080oooo100000060?ooo`030000
003oool0oooo08h0oooo00220?ooo`050000003oool0oooo0?ooo`000000203oool00`000000oooo
0?ooo`2>0?ooo`00P03oool2000000D0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?oo
o`2>0?ooo`00PP3oool00`000000oooo000000030?ooo`030000003oool0oooo00@0oooo00<00000
0?ooo`3oool0SP3oool007h0oooo00L000000?ooo`3oool0oooo0000003oool0000000<0oooo00<0
00000?ooo`3oool0103oool00`000000oooo0?ooo`2>0?ooo`00O`3oool3000000<0oooo10000006
0?ooo`030000003oool0oooo08h0oooo001n0?ooo`050000003oool0oooo0?ooo`000000103oool0
0`000000oooo0?ooo`050?ooo`030000003oool0oooo08h0oooo00220?ooo`030000003oool00000
00@000001P3oool00`000000oooo0?ooo`2>0?ooo`00P03oool200000080oooo00@000000?ooo`3o
ool000001`3oool00`000000oooo0?ooo`2>0?ooo`00PP3oool01P000000oooo0?ooo`000000oooo
000000L0oooo00<000000?ooo`3oool0SP3oool007h0oooo00D000000?ooo`3oool0oooo00000003
0?ooo`8000001`3oool00`000000oooo0?ooo`2>0?ooo`00O`3oool3000000<0oooo0`0000070?oo
o`030000003oool0oooo08h0oooo001n0?ooo`070000003oool0oooo0?ooo`000000oooo00000003
0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0SP3oool00880oooo00<000000?oo
o`0000000`3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo08h0oooo00200?ooo`80
00000P3oool4000000L0oooo00<000000?ooo`3oool0SP3oool00880oooo00<000000?ooo`000000
2P3oool00`000000oooo0?ooo`2>0?ooo`00OP3oool500000080oooo0P0000080?ooo`030000003o
ool0oooo08h0oooo001n0?ooo`D000000`3oool2000000L0oooo00<000000?ooo`3oool0SP3oool0
0880oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo
08h0oooo00200?ooo`8000001@3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo08h0
oooo00220?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0103oool00`000000oooo
0?ooo`2>0?ooo`00OP3oool01`000000oooo0?ooo`3oool000000?ooo`0000000`3oool00`000000
oooo0?ooo`040?ooo`030000003oool0oooo08h0oooo001o0?ooo`<000000P3oool5000000H0oooo
00<000000?ooo`3oool0SP3oool007h0oooo00L000000?ooo`3oool0oooo0000003oool0000000<0
oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`2>0?ooo`00PP3oool00`000000oooo
000000030?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0SP3oool00800oooo0P00
00030?ooo`<000001`3oool00`000000oooo0?ooo`2>0?ooo`00PP3oool00`000000oooo00000003
0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0SP3oool007h0oooo00L000000?oo
o`3oool0oooo0000003oool0000000<0oooo00<000000?ooo`3oool0103oool00`000000oooo0?oo
o`2>0?ooo`00O`3oool400000080oooo0`0000070?ooo`030000003oool0oooo08h0oooo00210?oo
o`050000003oool0oooo0?ooo`0000000P3oool00`000000oooo0?ooo`040?ooo`030000003oool0
oooo08h0oooo001n0?ooo`D000000P3oool010000000oooo0?ooo`0000060?ooo`030000003oool0
oooo08h0oooo001n0?ooo`040000003oool0oooo000000<0oooo00@000000?ooo`3oool000001P3o
ool00`000000oooo0?ooo`2>0?ooo`00O`3oool00`000000oooo000000030?ooo`040000003oool0
oooo000000H0oooo00<000000?ooo`3oool0SP3oool00800oooo0P0000030?ooo`040000003oool0
oooo000000H0oooo00<000000?ooo`3oool0SP3oool00800oooo0`0000020?ooo`<000001`3oool0
0`000000oooo0?ooo`2>0?ooo`00P@3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo
00H0oooo00<000000?ooo`3oool0SP3oool007h0oooo1@0000030?ooo`030000003oool0oooo00H0
oooo00<000000?ooo`3oool0SP3oool007h0oooo00@000000?ooo`3oool00000103oool00`000000
oooo0?ooo`060?ooo`030000003oool0oooo08h0oooo001o0?ooo`030000003oool0000000@0oooo
00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`2>0?ooo`00P03oool300000080oooo1000
00060?ooo`030000003oool0oooo08h0oooo00210?ooo`030000003oool0oooo0080oooo0P000007
0?ooo`030000003oool0oooo08h0oooo001n0?ooo`D0000000<0oooo0000000000000`0000060?oo
o`030000003oool0oooo08h0oooo001n0?ooo`040000003oool0oooo00000080oooo00@000000?oo
o`3oool000001`3oool00`000000oooo0?ooo`2>0?ooo`00O`3oool00`000000oooo000000030?oo
o`030000003oool0000000L0oooo00<000000?ooo`3oool0SP3oool00800oooo0P0000040?ooo`80
00001`3oool00`000000oooo0?ooo`2>0?ooo`00P03oool300000080oooo0`0000070?ooo`030000
003oool0oooo08h0oooo00210?ooo`040000003oool0oooo000000<0oooo00<000000?ooo`3oool0
103oool00`000000oooo0?ooo`2>0?ooo`00OP3oool5000000D0oooo00<000000?ooo`3oool0103o
ool00`000000oooo0?ooo`2>0?ooo`00OP3oool010000000oooo0?ooo`0000060?ooo`030000003o
ool0oooo00@0oooo00<000000?ooo`3oool0SP3oool007l0oooo00<000000?ooo`0000000P3oool4
000000L0oooo00<000000?ooo`3oool0SP3oool00800oooo0P0000020?ooo`030000003oool0oooo
00P0oooo00<000000?ooo`3oool0SP3oool00800oooo0`0000000`3oool0000000000003000000H0
oooo00<000000?ooo`3oool0SP3oool00840oooo00@000000?ooo`3oool000000`3oool00`000000
oooo0?ooo`040?ooo`030000003oool0oooo08h0oooo001n0?ooo`D0000000<0oooo0000003oool0
0P3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo08h0oooo001n0?ooo`040000003o
ool0oooo00000080oooo100000070?ooo`030000003oool0oooo08h0oooo001o0?ooo`030000003o
ool000000080oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`2>0?ooo`00P03oool3
00000080oooo0`0000070?ooo`030000003oool0oooo08h0oooo00210?ooo`050000003oool0oooo
0000003oool00`0000060?ooo`030000003oool0oooo08h0oooo001n0?ooo`D0000000<0oooo0000
003oool00P3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo08h0oooo001n0?ooo`04
0000003oool0oooo000000<0oooo0`00002H0?ooo`00O`3oool00`000000oooo000000020?ooo`05
0000003oool0oooo0?ooo`000000U`3oool00800oooo0P0000020?ooo`050000003oool0oooo0?oo
o`000000U`3oool00840oooo00@000000?ooo`3oool0oooo0`00002H0?ooo`00o`3ooolQ0?ooo`00
\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-1.0062, -1.00015, \
0.0174648, 0.175204}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.2 0.2 0.0199366 0.0199366 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
0 g
.5 Mabswid
[ ] 0 setdash
.4 .03987 m
.4 .01994 L
s
.4 .05981 m
.4 .03987 L
s
.7 .03987 m
.6 .01994 L
s
.7 .03987 m
.8 .01994 L
s
.6 .07975 m
.4 .05981 L
s
.6 .07975 m
.7 .03987 L
s
.6 .09968 m
.6 .07975 L
s
.6 .11962 m
.6 .09968 L
s
.6 .13956 m
.6 .11962 L
s
.5 .15949 m
.2 .01994 L
s
.5 .15949 m
.6 .13956 L
s
.5 .17943 m
.5 .15949 L
s
.5 .19937 m
.5 .17943 L
s
.5 .2193 m
.5 .19937 L
s
.5 .23924 m
.5 .2193 L
s
.5 .25918 m
.5 .23924 L
s
.5 .27911 m
.5 .25918 L
s
.5 .29905 m
.5 .27911 L
s
.5 .31899 m
.5 .29905 L
s
.5 .33892 m
.5 .31899 L
s
.5 .35886 m
.5 .33892 L
s
.5 .3788 m
.5 .35886 L
s
.5 .39873 m
.5 .3788 L
s
.5 .41867 m
.5 .39873 L
s
.5 .4386 m
.5 .41867 L
s
.5 .45854 m
.5 .4386 L
s
.5 .47848 m
.5 .45854 L
s
.5 .49841 m
.5 .47848 L
s
.5 .51835 m
.5 .49841 L
s
.5 .53829 m
.5 .51835 L
s
.5 .55822 m
.5 .53829 L
s
.5 .57816 m
.5 .55822 L
s
.5 .5981 m
.5 .57816 L
s
[(2)] .36 .04386 0 0 Mshowa
[(3)] .36 .0638 0 0 Mshowa
[(4)] .66 .04386 0 0 Mshowa
[(5)] .56 .08373 0 0 Mshowa
[(6)] .56 .10367 0 0 Mshowa
[(8)] .56 .12361 0 0 Mshowa
[(9)] .56 .14354 0 0 Mshowa
[(11)] .46 .16348 0 0 Mshowa
[(12)] .46 .18342 0 0 Mshowa
[(14)] .46 .20335 0 0 Mshowa
[(16)] .46 .22329 0 0 Mshowa
[(17)] .46 .24323 0 0 Mshowa
[(18)] .46 .26316 0 0 Mshowa
[(20)] .46 .2831 0 0 Mshowa
[(21)] .46 .30304 0 0 Mshowa
[(23)] .46 .32297 0 0 Mshowa
[(24)] .46 .34291 0 0 Mshowa
[(27)] .46 .36285 0 0 Mshowa
[(31)] .46 .38278 0 0 Mshowa
[(32)] .46 .40272 0 0 Mshowa
[(34)] .46 .42266 0 0 Mshowa
[(36)] .46 .44259 0 0 Mshowa
[(37)] .46 .46253 0 0 Mshowa
[(38)] .46 .48247 0 0 Mshowa
[(40)] .46 .5024 0 0 Mshowa
[(41)] .46 .52234 0 0 Mshowa
[(44)] .46 .54227 0 0 Mshowa
[(45)] .46 .56221 0 0 Mshowa
[(46)] .46 .58215 0 0 Mshowa
[(48)] .46 .60208 0 0 Mshowa
gsave
.2 .01595 -66 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(d) show
1.000 setlinewidth
grestore
gsave
.4 .01595 -66 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(b) show
1.000 setlinewidth
grestore
gsave
.6 .01595 -66 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(a) show
1.000 setlinewidth
grestore
gsave
.8 .01595 -66 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(c) show
1.000 setlinewidth
grestore
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[464]:=",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/B000`400?l00000o`00003oo`3ooolQ
0?ooo`00o`3ooolQ0?ooo`00=`3oool4000003@0oooo1000000g0?ooo`@00000=@3oool3000003X0
oooo000f0?ooo`040000003oool0oooo000003H0oooo00@000000?ooo`3oool00000=@3oool01000
0000oooo0?ooo`00000e0?ooo`050000003oool0oooo0?ooo`000000>@3oool003H0oooo00@00000
0?ooo`3oool00000=P3oool010000000oooo0?ooo`00000f0?ooo`<00000=@3oool00`000000oooo
0?ooo`0k0?ooo`00=P3oool00`000000oooo0?ooo`02000003D0oooo00@000000?ooo`0000000000
=@3oool00`000000oooo0?ooo`03000003<0oooo1@00000i0?ooo`00=`3oool3000000030?ooo`00
0000000003<0oooo0`00000g0?ooo`8000000`3oool5000002X0oooo2000000j0?ooo`00>@3oool0
10000000oooo0?ooo`3oool200000340oooo00<000000?ooo`000000@@3oool500000200oooo1@00
00120?ooo`00>03oool2000000D0oooo0`00000]0?ooo`80000000<0oooo0000003oool0A@3oool4
000001L0oooo1@0000170?ooo`00@P3oool2000002h0oooo00<000000?ooo`3oool0B03oool50000
00d0oooo1@00001<0?ooo`00A03oool2000001h0oooo1@0000090?ooo`030000003oool0oooo04L0
oooo0`0000030?ooo`D000000`3oool500000540oooo00160?ooo`8000007@3oool010000000oooo
0?ooo`0000090?ooo`030000003oool0oooo04P0oooo00<000000?ooo`3oool01`3oool3000005H0
oooo00180?ooo`800000703oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo04D0oooo
1@0000050?ooo`<00000F@3oool004X0oooo0P00000K0?ooo`030000003oool0oooo00P0oooo00<0
00000?ooo`3oool0A@3oool010000000oooo0?ooo`0000040?ooo`800000G03oool004`0oooo0P00
000F0?ooo`050000003oool0oooo0?ooo`0000002@3oool00`000000oooo0?ooo`160?ooo`040000
003oool000000?ooo`<00000GP3oool004h0oooo0`00000C0?ooo`D000002@3oool00`000000oooo
0?ooo`170?ooo`<00000H@3oool00540oooo0P00000A0?ooo`D000002@3oool00`000000oooo0?oo
o`150?ooo`@00000HP3oool005<0oooo0P00000C0?ooo`030000003oool0oooo00L0oooo1`00000n
0?ooo`<00000IP3oool005D0oooo0P00000?0?ooo`8000004@3oool;00000340oooo0P00001Y0?oo
o`00E`3oool2000000l0oooo00<000000?ooo`3oool06@3oool<00000280oooo0`00001[0?ooo`00
F@3oool2000000T0oooo00D000000?ooo`3oool0oooo0000000W0?ooo``00000503oool2000006h0
oooo001K0?ooo`800000203oool3000003@0oooo2`0000060?ooo`<00000L03oool005d0oooo0`00
000m0?ooo`050000003oool0oooo0?ooo`0000001@3oool6000007<0oooo001P0?ooo`800000?`3o
ool00`000000oooo0?ooo`080?ooo`030000003oool0oooo0740oooo001R0?ooo`800000?@3oool0
0`000000oooo0?ooo`080?ooo`030000003oool0oooo0740oooo001T0?ooo`800000=`3oool40000
00/0oooo00<000000?ooo`3oool0L@3oool006H0oooo0P00000e0?ooo`030000003oool0oooo00`0
oooo00<000000?ooo`3oool0L@3oool006P0oooo0P00000c0?ooo`D000002P3oool00`000000oooo
0?ooo`1a0?ooo`00JP3oool300000300oooo00D000000?ooo`3oool0oooo0000000:0?ooo`030000
003oool0oooo0740oooo001]0?ooo`800000;P3oool01@000000oooo0?ooo`3oool0000000X0oooo
00<000000?ooo`3oool0L@3oool006l0oooo0P00000/0?ooo`@000002`3oool00`000000oooo0?oo
o`1a0?ooo`00L@3oool2000002X0oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`1a
0?ooo`00L`3oool2000002T0oooo0`00000;0?ooo`030000003oool0oooo0740oooo001e0?ooo`80
00009P3oool00`000000oooo00000002000000X0oooo00<000000?ooo`3oool0L@3oool007L0oooo
0P00000T0?ooo`050000003oool0oooo0?ooo`0000002P3oool00`000000oooo0?ooo`1a0?ooo`00
N@3oool300000280oooo0`00000;0?ooo`030000003oool0oooo0740oooo001l0?ooo`8000007`3o
ool01@000000oooo0?ooo`3oool0000000X0oooo00<000000?ooo`3oool0L@3oool007h0oooo0P00
000M0?ooo`050000003oool0oooo0?ooo`0000002P3oool00`000000oooo0?ooo`1a0?ooo`00P03o
ool2000001`0oooo0`00000;0?ooo`030000003oool0oooo0740oooo00220?ooo`800000703oool0
0`000000oooo0?ooo`090?ooo`030000003oool0oooo0740oooo00240?ooo`8000006`3oool00`00
0000oooo0?ooo`050?ooo`@00000L`3oool008H0oooo0P00000F0?ooo`@0000000<0oooo00000000
00001000001g0?ooo`00R03oool300000180oooo1P00001m0?ooo`00R`3oool2000000/0oooo1P00
00030?ooo`030000003oool0oooo07`0oooo001o0?ooo`<000000`3oool3000000D0oooo0P000003
0?ooo`H000001P3oool3000007l0oooo00200?ooo`030000003oool0oooo00<0oooo00<000000?oo
o`3oool01P3oool3000008h0oooo00200?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3o
ool01P3oool00`000000oooo0?ooo`2>0?ooo`00P03oool00`000000oooo0?ooo`030?ooo`030000
003oool0oooo00H0oooo00<000000?ooo`3oool0SP3oool00800oooo00<000000?ooo`3oool00`3o
ool00`000000oooo0?ooo`060?ooo`030000003oool0oooo08h0oooo001o0?ooo`800000103oool2
000000P0oooo00<000000?ooo`3oool0SP3oool007l0oooo0`0000020?ooo`D000001P3oool00`00
0000oooo0?ooo`2>0?ooo`00P03oool00`000000oooo0?ooo`020?ooo`040000003oool0oooo0000
00H0oooo00<000000?ooo`3oool0SP3oool00800oooo00<000000?ooo`3oool00`3oool00`000000
oooo0?ooo`060?ooo`030000003oool0oooo08h0oooo00200?ooo`030000003oool0oooo00@0oooo
00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`2>0?ooo`00P03oool01@000000oooo0?oo
o`3oool0000000<0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`2>0?ooo`00O`3o
ool300000080oooo00<000000?ooo`0000000P0000060?ooo`030000003oool0oooo08h0oooo0020
0?ooo`030000003oool0oooo0080oooo0`0000070?ooo`030000003oool0oooo08h0oooo00200?oo
o`040000003oool0oooo0?ooo`D000001P3oool00`000000oooo0?ooo`2>0?ooo`00P03oool01@00
0000oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`2>
0?ooo`00P03oool00`000000oooo0?ooo`020?ooo`030000003oool0000000L0oooo00<000000?oo
o`3oool0SP3oool007l0oooo0P0000050?ooo`8000001`3oool00`000000oooo0?ooo`2>0?ooo`00
O`3oool3000000<0oooo0`0000070?ooo`030000003oool0oooo08h0oooo00200?ooo`050000003o
ool0oooo0?ooo`0000000`3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo08h0oooo
00200?ooo`050000003oool0oooo0?ooo`0000000`3oool00`000000oooo0?ooo`040?ooo`030000
003oool0oooo08h0oooo00200?ooo`040000003oool0oooo0?ooo`@000001`3oool00`000000oooo
0?ooo`2>0?ooo`00P03oool01@000000oooo0?ooo`3oool0000000X0oooo00<000000?ooo`3oool0
SP3oool007l0oooo0P0000040?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool0SP3o
ool007l0oooo0`0000040?ooo`8000001`3oool00`000000oooo0?ooo`2>0?ooo`00P03oool00`00
0000oooo0?ooo`030?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool0SP3oool00800
oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo08h0
oooo00200?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool01@3oool00`000000oooo
0?ooo`2>0?ooo`00P03oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00@0oooo00<0
00000?ooo`3oool0SP3oool007l0oooo0`0000020?ooo`D000001P3oool00`000000oooo0?ooo`2>
0?ooo`00P03oool010000000oooo0?ooo`3oool5000000H0oooo00<000000?ooo`3oool0SP3oool0
0800oooo00D000000?ooo`3oool0oooo000000030?ooo`030000003oool0oooo00@0oooo00<00000
0?ooo`3oool0SP3oool00800oooo00<000000?ooo`3oool00P3oool3000000L0oooo00<000000?oo
o`3oool0SP3oool00800oooo00D000000?ooo`3oool0oooo000000030?ooo`030000003oool0oooo
00@0oooo00<000000?ooo`3oool0SP3oool007l0oooo0P0000030?ooo`050000003oool0oooo0?oo
o`0000001P3oool00`000000oooo0?ooo`2>0?ooo`00OP3oool500000080oooo0`0000070?ooo`03
0000003oool0oooo08h0oooo001o0?ooo`040000003oool0oooo00000080oooo00@000000?ooo`3o
ool000001P3oool00`000000oooo0?ooo`2>0?ooo`00P03oool00`000000oooo0?ooo`020?ooo`04
0000003oool0oooo000000H0oooo00<000000?ooo`3oool0SP3oool00840oooo00D000000?ooo`3o
ool0oooo000000020?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0SP3oool007h0
oooo00D000000?ooo`3oool0oooo000000020?ooo`040000003oool0oooo000000H0oooo00<00000
0?ooo`3oool0SP3oool007h0oooo00D000000?ooo`3oool0oooo000000020?ooo`040000003oool0
oooo000000H0oooo00<000000?ooo`3oool0SP3oool007h0oooo1@0000020?ooo`<000001`3oool0
0`000000oooo0?ooo`2>0?ooo`00O`3oool010000000oooo0?ooo`0000030?ooo`030000003oool0
oooo00H0oooo00<000000?ooo`3oool0SP3oool00800oooo00<000000?ooo`3oool00`3oool00`00
0000oooo0?ooo`060?ooo`030000003oool0oooo08h0oooo00210?ooo`030000003oool0oooo0080
oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`2>0?ooo`00OP3oool01@000000oooo
0?ooo`3oool0000000<0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`2>0?ooo`00
OP3oool01@000000oooo0?ooo`3oool000000080oooo0P0000080?ooo`030000003oool0oooo08h0
oooo001n0?ooo`D000000P3oool3000000L0oooo00<000000?ooo`3oool0SP3oool007l0oooo00H0
00000?ooo`3oool000000?ooo`0000030?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3o
ool0SP3oool00800oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`040?ooo`030000
003oool0oooo08h0oooo00210?ooo`030000003oool0oooo0080oooo0P0000070?ooo`030000003o
ool0oooo08h0oooo001n0?ooo`050000003oool0oooo0?ooo`0000001@3oool00`000000oooo0?oo
o`040?ooo`030000003oool0oooo08h0oooo001n0?ooo`D0000000<0oooo0000003oool00`000006
0?ooo`030000003oool0oooo08h0oooo001o0?ooo`@000000P3oool3000000L0oooo00<000000?oo
o`3oool0SP3oool00800oooo00@000000?ooo`3oool0oooo1@0000060?ooo`030000003oool0oooo
08h0oooo00210?ooo`040000003oool0oooo00000080oooo00<000000?ooo`3oool01@3oool00`00
0000oooo0?ooo`2>0?ooo`00OP3oool01@000000oooo0?ooo`3oool000000080oooo00<000000?oo
o`0000001`3oool00`000000oooo0?ooo`2>0?ooo`00OP3oool01@000000oooo0?ooo`3oool00000
00<0oooo0P0000070?ooo`030000003oool0oooo08h0oooo001n0?ooo`D000000`3oool2000000L0
oooo00<000000?ooo`3oool0SP3oool007l0oooo00@000000?ooo`3oool000000`3oool00`000000
oooo0?ooo`060?ooo`030000003oool0oooo08h0oooo00200?ooo`030000003oool0oooo00@0oooo
00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`2>0?ooo`00P@3oool00`000000oooo0?oo
o`030?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool0SP3oool007h0oooo00D00000
0?ooo`3oool0oooo000000050?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0SP3o
ool007h0oooo00L000000?ooo`3oool0oooo0000003oool0000000<0oooo00<000000?ooo`3oool0
103oool00`000000oooo0?ooo`2>0?ooo`00O`3oool300000080oooo1@0000060?ooo`030000003o
ool0oooo08h0oooo001n0?ooo`050000003oool0oooo0?ooo`0000000`3oool00`000000oooo0?oo
o`060?ooo`030000003oool0oooo08h0oooo00220?ooo`050000003oool0oooo0?ooo`000000203o
ool00`000000oooo0?ooo`2>0?ooo`00P03oool2000000@0oooo00<000000?ooo`3oool01P3oool0
0`000000oooo0?ooo`2>0?ooo`00PP3oool01@000000oooo0?ooo`3oool0000000P0oooo00<00000
0?ooo`3oool0SP3oool007h0oooo1@0000000`3oool0000000000003000000H0oooo00<000000?oo
o`3oool0SP3oool007h0oooo1@0000020?ooo`80000000<0oooo0000003oool01@3oool00`000000
oooo0?ooo`2>0?ooo`00PP3oool01@000000oooo0?ooo`3oool0000000P0oooo00<000000?ooo`3o
ool0SP3oool00800oooo0P0000050?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool0
SP3oool00880oooo00<000000?ooo`0000000`3oool00`000000oooo0?ooo`040?ooo`030000003o
ool0oooo08h0oooo001n0?ooo`070000003oool0oooo0?ooo`000000oooo000000030?ooo`030000
003oool0oooo00@0oooo00<000000?ooo`3oool0SP3oool007l0oooo0`0000030?ooo`@000001P3o
ool00`000000oooo0?ooo`2>0?ooo`00OP3oool01@000000oooo0?ooo`3oool0000000@0oooo00<0
00000?ooo`3oool01@3oool00`000000oooo0?ooo`2>0?ooo`00PP3oool00`000000oooo00000004
000000H0oooo00<000000?ooo`3oool0SP3oool00800oooo0P0000020?ooo`040000003oool0oooo
000000L0oooo00<000000?ooo`3oool0SP3oool00880oooo00H000000?ooo`3oool000000?ooo`00
00070?ooo`030000003oool0oooo08h0oooo001n0?ooo`050000003oool0oooo0?ooo`0000000`3o
ool2000000L0oooo00<000000?ooo`3oool0SP3oool007l0oooo0`0000030?ooo`<000001`3oool0
0`000000oooo0?ooo`2>0?ooo`00OP3oool01`000000oooo0?ooo`3oool000000?ooo`0000000`3o
ool00`000000oooo0?ooo`040?ooo`030000003oool0oooo08h0oooo00220?ooo`030000003oool0
000000<0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`2>0?ooo`00P03oool20000
0080oooo100000070?ooo`030000003oool0oooo08h0oooo00220?ooo`030000003oool0000000X0
oooo00<000000?ooo`3oool0SP3oool007h0oooo1@0000020?ooo`800000203oool00`000000oooo
0?ooo`2>0?ooo`00OP3oool5000000<0oooo0P0000070?ooo`030000003oool0oooo08h0oooo0022
0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`2>
0?ooo`00P03oool2000000D0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`2>0?oo
o`00PP3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3o
ool0SP3oool007h0oooo00L000000?ooo`3oool0oooo0000003oool0000000<0oooo00<000000?oo
o`3oool0103oool00`000000oooo0?ooo`2>0?ooo`00O`3oool300000080oooo1@0000060?ooo`03
0000003oool0oooo08h0oooo001n0?ooo`070000003oool0oooo0?ooo`000000oooo000000030?oo
o`030000003oool0oooo00@0oooo00<000000?ooo`3oool0SP3oool00880oooo00<000000?ooo`00
00000`3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo08h0oooo00200?ooo`800000
0`3oool3000000L0oooo00<000000?ooo`3oool0SP3oool00880oooo00<000000?ooo`0000000`3o
ool00`000000oooo0?ooo`040?ooo`030000003oool0oooo08h0oooo001n0?ooo`070000003oool0
oooo0?ooo`000000oooo000000030?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0
SP3oool007l0oooo100000020?ooo`<000001`3oool00`000000oooo0?ooo`2>0?ooo`00P@3oool0
1@000000oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool0103oool00`000000oooo0?oo
o`2>0?ooo`00OP3oool500000080oooo00@000000?ooo`3oool000001P3oool00`000000oooo0?oo
o`2>0?ooo`00OP3oool010000000oooo0?ooo`0000030?ooo`040000003oool0oooo000000H0oooo
00<000000?ooo`3oool0SP3oool007l0oooo00<000000?ooo`0000000`3oool010000000oooo0?oo
o`0000060?ooo`030000003oool0oooo08h0oooo00200?ooo`8000000`3oool010000000oooo0?oo
o`0000060?ooo`030000003oool0oooo08h0oooo00200?ooo`<000000P3oool3000000L0oooo00<0
00000?ooo`3oool0SP3oool00840oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`06
0?ooo`030000003oool0oooo08h0oooo001n0?ooo`D000000`3oool00`000000oooo0?ooo`060?oo
o`030000003oool0oooo08h0oooo001n0?ooo`040000003oool0oooo000000@0oooo00<000000?oo
o`3oool01P3oool00`000000oooo0?ooo`2>0?ooo`00O`3oool00`000000oooo000000040?ooo`03
0000003oool0oooo00H0oooo00<000000?ooo`3oool0SP3oool00800oooo0`0000020?ooo`@00000
1P3oool00`000000oooo0?ooo`2>0?ooo`00P@3oool00`000000oooo0?ooo`020?ooo`8000001`3o
ool00`000000oooo0?ooo`2>0?ooo`00OP3oool5000000030?ooo`000000000000<000001P3oool0
0`000000oooo0?ooo`2>0?ooo`00OP3oool010000000oooo0?ooo`0000020?ooo`040000003oool0
oooo000000L0oooo00<000000?ooo`3oool0SP3oool007l0oooo00<000000?ooo`0000000`3oool0
0`000000oooo000000070?ooo`030000003oool0oooo08h0oooo00200?ooo`800000103oool20000
00L0oooo00<000000?ooo`3oool0SP3oool00800oooo0`0000020?ooo`<000001`3oool00`000000
oooo0?ooo`2>0?ooo`00P@3oool010000000oooo0?ooo`0000030?ooo`030000003oool0oooo00@0
oooo00<000000?ooo`3oool0SP3oool007h0oooo1@0000050?ooo`030000003oool0oooo00@0oooo
00<000000?ooo`3oool0SP3oool007h0oooo00@000000?ooo`3oool000001P3oool00`000000oooo
0?ooo`040?ooo`030000003oool0oooo08h0oooo001o0?ooo`030000003oool000000080oooo1000
00070?ooo`030000003oool0oooo08h0oooo00200?ooo`8000000P3oool00`000000oooo0?ooo`08
0?ooo`030000003oool0oooo08h0oooo00200?ooo`<0000000<0oooo0000000000000`0000060?oo
o`030000003oool0oooo08h0oooo00210?ooo`040000003oool0oooo000000<0oooo00<000000?oo
o`3oool0103oool00`000000oooo0?ooo`2>0?ooo`00OP3oool5000000030?ooo`000000oooo0080
oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`2>0?ooo`00OP3oool010000000oooo
0?ooo`0000020?ooo`@000001`3oool00`000000oooo0?ooo`2>0?ooo`00O`3oool00`000000oooo
000000020?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool0SP3oool00800oooo0`00
00020?ooo`<000001`3oool00`000000oooo0?ooo`2>0?ooo`00P@3oool01@000000oooo0?ooo`00
0000oooo00<000001P3oool00`000000oooo0?ooo`2>0?ooo`00OP3oool5000000030?ooo`000000
oooo0080oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`2>0?ooo`00OP3oool01000
0000oooo0?ooo`0000030?ooo`<00000V03oool007l0oooo00<000000?ooo`0000000P3oool01@00
0000oooo0?ooo`3oool0000009L0oooo00200?ooo`8000000P3oool01@000000oooo0?ooo`3oool0
000009L0oooo00210?ooo`040000003oool0oooo0?ooo`<00000V03oool00?l0oooo8@3oool00001
\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-1.0062, -1.00015, \
0.0174648, 0.175204}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.2 0.2 0.0199366 0.0199366 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
0 g
.5 Mabswid
[ ] 0 setdash
.4 .03987 m
.4 .01994 L
s
.4 .05981 m
.4 .03987 L
s
.7 .03987 m
.6 .01994 L
s
.7 .03987 m
.8 .01994 L
s
.6 .07975 m
.4 .05981 L
s
.6 .07975 m
.7 .03987 L
s
.6 .09968 m
.6 .07975 L
s
.6 .11962 m
.6 .09968 L
s
.6 .13956 m
.6 .11962 L
s
.5 .15949 m
.2 .01994 L
s
.5 .15949 m
.6 .13956 L
s
.5 .17943 m
.5 .15949 L
s
.5 .19937 m
.5 .17943 L
s
.5 .2193 m
.5 .19937 L
s
.5 .23924 m
.5 .2193 L
s
.5 .25918 m
.5 .23924 L
s
.5 .27911 m
.5 .25918 L
s
.5 .29905 m
.5 .27911 L
s
.5 .31899 m
.5 .29905 L
s
.5 .33892 m
.5 .31899 L
s
.5 .35886 m
.5 .33892 L
s
.5 .3788 m
.5 .35886 L
s
.5 .39873 m
.5 .3788 L
s
.5 .41867 m
.5 .39873 L
s
.5 .4386 m
.5 .41867 L
s
.5 .45854 m
.5 .4386 L
s
.5 .47848 m
.5 .45854 L
s
.5 .49841 m
.5 .47848 L
s
.5 .51835 m
.5 .49841 L
s
.5 .53829 m
.5 .51835 L
s
.5 .55822 m
.5 .53829 L
s
.5 .57816 m
.5 .55822 L
s
.5 .5981 m
.5 .57816 L
s
[(2)] .36 .04386 0 0 Mshowa
[(3)] .36 .0638 0 0 Mshowa
[(4)] .66 .04386 0 0 Mshowa
[(5)] .56 .08373 0 0 Mshowa
[(6)] .56 .10367 0 0 Mshowa
[(8)] .56 .12361 0 0 Mshowa
[(9)] .56 .14354 0 0 Mshowa
[(11)] .46 .16348 0 0 Mshowa
[(12)] .46 .18342 0 0 Mshowa
[(14)] .46 .20335 0 0 Mshowa
[(16)] .46 .22329 0 0 Mshowa
[(17)] .46 .24323 0 0 Mshowa
[(18)] .46 .26316 0 0 Mshowa
[(20)] .46 .2831 0 0 Mshowa
[(21)] .46 .30304 0 0 Mshowa
[(23)] .46 .32297 0 0 Mshowa
[(24)] .46 .34291 0 0 Mshowa
[(27)] .46 .36285 0 0 Mshowa
[(31)] .46 .38278 0 0 Mshowa
[(32)] .46 .40272 0 0 Mshowa
[(34)] .46 .42266 0 0 Mshowa
[(36)] .46 .44259 0 0 Mshowa
[(37)] .46 .46253 0 0 Mshowa
[(38)] .46 .48247 0 0 Mshowa
[(40)] .46 .5024 0 0 Mshowa
[(41)] .46 .52234 0 0 Mshowa
[(44)] .46 .54227 0 0 Mshowa
[(45)] .46 .56221 0 0 Mshowa
[(46)] .46 .58215 0 0 Mshowa
[(49)] .46 .60208 0 0 Mshowa
gsave
.2 .01595 -66 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(d) show
1.000 setlinewidth
grestore
gsave
.4 .01595 -66 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(b) show
1.000 setlinewidth
grestore
gsave
.6 .01595 -66 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(a) show
1.000 setlinewidth
grestore
gsave
.8 .01595 -66 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(c) show
1.000 setlinewidth
grestore
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[464]:=",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/B000`400?l00000o`00003oo`3ooolQ
0?ooo`00o`3ooolQ0?ooo`00=`3oool4000003@0oooo1000000g0?ooo`@00000=@3oool3000003X0
oooo000f0?ooo`040000003oool0oooo000003H0oooo00@000000?ooo`3oool00000=@3oool01000
0000oooo0?ooo`00000e0?ooo`050000003oool0oooo0?ooo`000000>@3oool003H0oooo00@00000
0?ooo`3oool00000=P3oool010000000oooo0?ooo`00000f0?ooo`<00000=@3oool00`000000oooo
0?ooo`0k0?ooo`00=P3oool00`000000oooo0?ooo`02000003D0oooo00@000000?ooo`0000000000
=@3oool00`000000oooo0?ooo`03000003<0oooo1@00000i0?ooo`00=`3oool3000000030?ooo`00
0000000003<0oooo0`00000g0?ooo`8000000`3oool5000002X0oooo2000000j0?ooo`00>@3oool0
10000000oooo0?ooo`3oool200000340oooo00<000000?ooo`000000@@3oool500000200oooo1@00
00120?ooo`00>03oool2000000D0oooo0`00000]0?ooo`80000000<0oooo0000003oool0A@3oool4
000001L0oooo1@0000170?ooo`00@P3oool2000002h0oooo00<000000?ooo`3oool0B03oool50000
00d0oooo1@00001<0?ooo`00A03oool2000001h0oooo1@0000090?ooo`030000003oool0oooo04L0
oooo0`0000030?ooo`D000000`3oool500000540oooo00160?ooo`8000007@3oool010000000oooo
0?ooo`0000090?ooo`030000003oool0oooo04P0oooo00<000000?ooo`3oool01`3oool3000005H0
oooo00180?ooo`800000703oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo04D0oooo
1@0000050?ooo`<00000F@3oool004X0oooo0P00000K0?ooo`030000003oool0oooo00P0oooo00<0
00000?ooo`3oool0A@3oool010000000oooo0?ooo`0000040?ooo`800000G03oool004`0oooo0P00
000F0?ooo`050000003oool0oooo0?ooo`0000002@3oool00`000000oooo0?ooo`160?ooo`040000
003oool000000?ooo`<00000GP3oool004h0oooo0`00000C0?ooo`D000002@3oool00`000000oooo
0?ooo`170?ooo`<00000H@3oool00540oooo0P00000A0?ooo`D000002@3oool00`000000oooo0?oo
o`150?ooo`@00000HP3oool005<0oooo0P00000C0?ooo`030000003oool0oooo00L0oooo1`00000n
0?ooo`<00000IP3oool005D0oooo0P00000?0?ooo`8000004@3oool;00000340oooo0P00001Y0?oo
o`00E`3oool2000000l0oooo00<000000?ooo`3oool06@3oool<00000280oooo0`00001[0?ooo`00
F@3oool2000000T0oooo00D000000?ooo`3oool0oooo0000000W0?ooo``00000503oool2000006h0
oooo001K0?ooo`800000203oool3000003@0oooo2`0000060?ooo`<00000L03oool005d0oooo0`00
000m0?ooo`050000003oool0oooo0?ooo`0000001@3oool6000007<0oooo001P0?ooo`800000?`3o
ool00`000000oooo0?ooo`080?ooo`030000003oool0oooo0740oooo001R0?ooo`800000?@3oool0
0`000000oooo0?ooo`080?ooo`030000003oool0oooo0740oooo001T0?ooo`800000=`3oool40000
00/0oooo00<000000?ooo`3oool0L@3oool006H0oooo0P00000e0?ooo`030000003oool0oooo00`0
oooo00<000000?ooo`3oool0L@3oool006P0oooo0P00000c0?ooo`D000002P3oool00`000000oooo
0?ooo`1a0?ooo`00JP3oool300000300oooo00D000000?ooo`3oool0oooo0000000:0?ooo`030000
003oool0oooo0740oooo001]0?ooo`800000;P3oool01@000000oooo0?ooo`3oool0000000X0oooo
00<000000?ooo`3oool0L@3oool006l0oooo0P00000/0?ooo`@000002`3oool00`000000oooo0?oo
o`1a0?ooo`00L@3oool2000002X0oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`1a
0?ooo`00L`3oool2000002T0oooo0`00000;0?ooo`030000003oool0oooo0740oooo001e0?ooo`80
00009P3oool00`000000oooo00000002000000X0oooo00<000000?ooo`3oool0L@3oool007L0oooo
0P00000T0?ooo`050000003oool0oooo0?ooo`0000002P3oool00`000000oooo0?ooo`1a0?ooo`00
N@3oool300000280oooo0`00000;0?ooo`030000003oool0oooo0740oooo001l0?ooo`8000007`3o
ool01@000000oooo0?ooo`3oool0000000X0oooo00<000000?ooo`3oool0L@3oool007h0oooo0P00
000M0?ooo`050000003oool0oooo0?ooo`0000002P3oool00`000000oooo0?ooo`1a0?ooo`00P03o
ool2000001`0oooo0`00000;0?ooo`030000003oool0oooo0740oooo00220?ooo`800000703oool0
0`000000oooo0?ooo`090?ooo`030000003oool0oooo0740oooo00240?ooo`8000006`3oool00`00
0000oooo0?ooo`050?ooo`@00000L`3oool008H0oooo0P00000F0?ooo`@0000000<0oooo00000000
00001000001g0?ooo`00R03oool300000180oooo1P00001m0?ooo`00R`3oool2000000/0oooo1P00
00030?ooo`030000003oool0oooo07`0oooo001o0?ooo`<000000`3oool3000000D0oooo0P000003
0?ooo`H000001P3oool3000007l0oooo00200?ooo`030000003oool0oooo00<0oooo00<000000?oo
o`3oool01P3oool3000008h0oooo00200?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3o
ool01P3oool00`000000oooo0?ooo`2>0?ooo`00P03oool00`000000oooo0?ooo`030?ooo`030000
003oool0oooo00H0oooo00<000000?ooo`3oool0SP3oool00800oooo00<000000?ooo`3oool00`3o
ool00`000000oooo0?ooo`060?ooo`030000003oool0oooo08h0oooo001o0?ooo`800000103oool2
000000P0oooo00<000000?ooo`3oool0SP3oool007l0oooo0`0000020?ooo`D000001P3oool00`00
0000oooo0?ooo`2>0?ooo`00P03oool00`000000oooo0?ooo`020?ooo`040000003oool0oooo0000
00H0oooo00<000000?ooo`3oool0SP3oool00800oooo00<000000?ooo`3oool00`3oool00`000000
oooo0?ooo`060?ooo`030000003oool0oooo08h0oooo00200?ooo`030000003oool0oooo00@0oooo
00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`2>0?ooo`00P03oool01@000000oooo0?oo
o`3oool0000000<0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`2>0?ooo`00O`3o
ool300000080oooo00<000000?ooo`0000000P0000060?ooo`030000003oool0oooo08h0oooo0020
0?ooo`030000003oool0oooo0080oooo0`0000070?ooo`030000003oool0oooo08h0oooo00200?oo
o`040000003oool0oooo0?ooo`D000001P3oool00`000000oooo0?ooo`2>0?ooo`00P03oool01@00
0000oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`2>
0?ooo`00P03oool00`000000oooo0?ooo`020?ooo`030000003oool0000000L0oooo00<000000?oo
o`3oool0SP3oool007l0oooo0P0000050?ooo`8000001`3oool00`000000oooo0?ooo`2>0?ooo`00
O`3oool3000000<0oooo0`0000070?ooo`030000003oool0oooo08h0oooo00200?ooo`050000003o
ool0oooo0?ooo`0000000`3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo08h0oooo
00200?ooo`050000003oool0oooo0?ooo`0000000`3oool00`000000oooo0?ooo`040?ooo`030000
003oool0oooo08h0oooo00200?ooo`040000003oool0oooo0?ooo`@000001`3oool00`000000oooo
0?ooo`2>0?ooo`00P03oool01@000000oooo0?ooo`3oool0000000X0oooo00<000000?ooo`3oool0
SP3oool007l0oooo0P0000040?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool0SP3o
ool007l0oooo0`0000040?ooo`8000001`3oool00`000000oooo0?ooo`2>0?ooo`00P03oool00`00
0000oooo0?ooo`030?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool0SP3oool00800
oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo08h0
oooo00200?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool01@3oool00`000000oooo
0?ooo`2>0?ooo`00P03oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00@0oooo00<0
00000?ooo`3oool0SP3oool007l0oooo0`0000020?ooo`D000001P3oool00`000000oooo0?ooo`2>
0?ooo`00P03oool010000000oooo0?ooo`3oool5000000H0oooo00<000000?ooo`3oool0SP3oool0
0800oooo00D000000?ooo`3oool0oooo000000030?ooo`030000003oool0oooo00@0oooo00<00000
0?ooo`3oool0SP3oool00800oooo00<000000?ooo`3oool00P3oool3000000L0oooo00<000000?oo
o`3oool0SP3oool00800oooo00D000000?ooo`3oool0oooo000000030?ooo`030000003oool0oooo
00@0oooo00<000000?ooo`3oool0SP3oool007l0oooo0P0000030?ooo`050000003oool0oooo0?oo
o`0000001P3oool00`000000oooo0?ooo`2>0?ooo`00OP3oool500000080oooo0`0000070?ooo`03
0000003oool0oooo08h0oooo001o0?ooo`040000003oool0oooo00000080oooo00@000000?ooo`3o
ool000001P3oool00`000000oooo0?ooo`2>0?ooo`00P03oool00`000000oooo0?ooo`020?ooo`04
0000003oool0oooo000000H0oooo00<000000?ooo`3oool0SP3oool00840oooo00D000000?ooo`3o
ool0oooo000000020?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0SP3oool007h0
oooo00D000000?ooo`3oool0oooo000000020?ooo`040000003oool0oooo000000H0oooo00<00000
0?ooo`3oool0SP3oool007h0oooo00D000000?ooo`3oool0oooo000000020?ooo`040000003oool0
oooo000000H0oooo00<000000?ooo`3oool0SP3oool007h0oooo1@0000020?ooo`<000001`3oool0
0`000000oooo0?ooo`2>0?ooo`00O`3oool010000000oooo0?ooo`0000030?ooo`030000003oool0
oooo00H0oooo00<000000?ooo`3oool0SP3oool00800oooo00<000000?ooo`3oool00`3oool00`00
0000oooo0?ooo`060?ooo`030000003oool0oooo08h0oooo00210?ooo`030000003oool0oooo0080
oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`2>0?ooo`00OP3oool01@000000oooo
0?ooo`3oool0000000<0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`2>0?ooo`00
OP3oool01@000000oooo0?ooo`3oool000000080oooo0P0000080?ooo`030000003oool0oooo08h0
oooo001n0?ooo`D000000P3oool3000000L0oooo00<000000?ooo`3oool0SP3oool007l0oooo00H0
00000?ooo`3oool000000?ooo`0000030?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3o
ool0SP3oool00800oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`040?ooo`030000
003oool0oooo08h0oooo00210?ooo`030000003oool0oooo0080oooo0P0000070?ooo`030000003o
ool0oooo08h0oooo001n0?ooo`050000003oool0oooo0?ooo`0000001@3oool00`000000oooo0?oo
o`040?ooo`030000003oool0oooo08h0oooo001n0?ooo`D0000000<0oooo0000003oool00`000006
0?ooo`030000003oool0oooo08h0oooo001o0?ooo`@000000P3oool3000000L0oooo00<000000?oo
o`3oool0SP3oool00800oooo00@000000?ooo`3oool0oooo1@0000060?ooo`030000003oool0oooo
08h0oooo00210?ooo`040000003oool0oooo00000080oooo00<000000?ooo`3oool01@3oool00`00
0000oooo0?ooo`2>0?ooo`00OP3oool01@000000oooo0?ooo`3oool000000080oooo00<000000?oo
o`0000001`3oool00`000000oooo0?ooo`2>0?ooo`00OP3oool01@000000oooo0?ooo`3oool00000
00<0oooo0P0000070?ooo`030000003oool0oooo08h0oooo001n0?ooo`D000000`3oool2000000L0
oooo00<000000?ooo`3oool0SP3oool007l0oooo00@000000?ooo`3oool000000`3oool00`000000
oooo0?ooo`060?ooo`030000003oool0oooo08h0oooo00200?ooo`030000003oool0oooo00@0oooo
00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`2>0?ooo`00P@3oool00`000000oooo0?oo
o`030?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool0SP3oool007h0oooo00D00000
0?ooo`3oool0oooo000000050?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0SP3o
ool007h0oooo00L000000?ooo`3oool0oooo0000003oool0000000<0oooo00<000000?ooo`3oool0
103oool00`000000oooo0?ooo`2>0?ooo`00O`3oool300000080oooo1@0000060?ooo`030000003o
ool0oooo08h0oooo001n0?ooo`050000003oool0oooo0?ooo`0000000`3oool00`000000oooo0?oo
o`060?ooo`030000003oool0oooo08h0oooo00220?ooo`050000003oool0oooo0?ooo`000000203o
ool00`000000oooo0?ooo`2>0?ooo`00P03oool2000000@0oooo00<000000?ooo`3oool01P3oool0
0`000000oooo0?ooo`2>0?ooo`00PP3oool01@000000oooo0?ooo`3oool0000000P0oooo00<00000
0?ooo`3oool0SP3oool007h0oooo1@0000000`3oool0000000000003000000H0oooo00<000000?oo
o`3oool0SP3oool007h0oooo1@0000020?ooo`80000000<0oooo0000003oool01@3oool00`000000
oooo0?ooo`2>0?ooo`00PP3oool01@000000oooo0?ooo`3oool0000000P0oooo00<000000?ooo`3o
ool0SP3oool00800oooo0P0000050?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool0
SP3oool00880oooo00<000000?ooo`0000000`3oool00`000000oooo0?ooo`040?ooo`030000003o
ool0oooo08h0oooo001n0?ooo`070000003oool0oooo0?ooo`000000oooo000000030?ooo`030000
003oool0oooo00@0oooo00<000000?ooo`3oool0SP3oool007l0oooo0`0000030?ooo`@000001P3o
ool00`000000oooo0?ooo`2>0?ooo`00OP3oool01@000000oooo0?ooo`3oool0000000@0oooo00<0
00000?ooo`3oool01@3oool00`000000oooo0?ooo`2>0?ooo`00PP3oool00`000000oooo00000004
000000H0oooo00<000000?ooo`3oool0SP3oool00800oooo0P0000020?ooo`040000003oool0oooo
000000L0oooo00<000000?ooo`3oool0SP3oool00880oooo00H000000?ooo`3oool000000?ooo`00
00070?ooo`030000003oool0oooo08h0oooo001n0?ooo`050000003oool0oooo0?ooo`0000000`3o
ool2000000L0oooo00<000000?ooo`3oool0SP3oool007l0oooo0`0000030?ooo`<000001`3oool0
0`000000oooo0?ooo`2>0?ooo`00OP3oool01`000000oooo0?ooo`3oool000000?ooo`0000000`3o
ool00`000000oooo0?ooo`040?ooo`030000003oool0oooo08h0oooo00220?ooo`030000003oool0
000000<0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`2>0?ooo`00P03oool20000
0080oooo100000070?ooo`030000003oool0oooo08h0oooo00220?ooo`030000003oool0000000X0
oooo00<000000?ooo`3oool0SP3oool007h0oooo1@0000020?ooo`800000203oool00`000000oooo
0?ooo`2>0?ooo`00OP3oool5000000<0oooo0P0000070?ooo`030000003oool0oooo08h0oooo0022
0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`2>
0?ooo`00P03oool2000000D0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`2>0?oo
o`00PP3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3o
ool0SP3oool007h0oooo00L000000?ooo`3oool0oooo0000003oool0000000<0oooo00<000000?oo
o`3oool0103oool00`000000oooo0?ooo`2>0?ooo`00O`3oool300000080oooo1@0000060?ooo`03
0000003oool0oooo08h0oooo001n0?ooo`070000003oool0oooo0?ooo`000000oooo000000030?oo
o`030000003oool0oooo00@0oooo00<000000?ooo`3oool0SP3oool00880oooo00<000000?ooo`00
00000`3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo08h0oooo00200?ooo`800000
0`3oool3000000L0oooo00<000000?ooo`3oool0SP3oool00880oooo00<000000?ooo`0000000`3o
ool00`000000oooo0?ooo`040?ooo`030000003oool0oooo08h0oooo001n0?ooo`070000003oool0
oooo0?ooo`000000oooo000000030?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0
SP3oool007l0oooo100000020?ooo`<000001`3oool00`000000oooo0?ooo`2>0?ooo`00P@3oool0
1@000000oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool0103oool00`000000oooo0?oo
o`2>0?ooo`00OP3oool500000080oooo00@000000?ooo`3oool000001P3oool00`000000oooo0?oo
o`2>0?ooo`00OP3oool010000000oooo0?ooo`0000030?ooo`040000003oool0oooo000000H0oooo
00<000000?ooo`3oool0SP3oool007l0oooo00<000000?ooo`0000000`3oool010000000oooo0?oo
o`0000060?ooo`030000003oool0oooo08h0oooo00200?ooo`8000000`3oool010000000oooo0?oo
o`0000060?ooo`030000003oool0oooo08h0oooo00200?ooo`<000000P3oool3000000L0oooo00<0
00000?ooo`3oool0SP3oool00840oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`06
0?ooo`030000003oool0oooo08h0oooo001n0?ooo`D000000`3oool00`000000oooo0?ooo`060?oo
o`030000003oool0oooo08h0oooo001n0?ooo`040000003oool0oooo000000@0oooo00<000000?oo
o`3oool01P3oool00`000000oooo0?ooo`2>0?ooo`00O`3oool00`000000oooo000000040?ooo`03
0000003oool0oooo00H0oooo00<000000?ooo`3oool0SP3oool00800oooo0`0000020?ooo`@00000
1P3oool00`000000oooo0?ooo`2>0?ooo`00P@3oool00`000000oooo0?ooo`020?ooo`8000001`3o
ool00`000000oooo0?ooo`2>0?ooo`00OP3oool5000000030?ooo`000000000000<000001P3oool0
0`000000oooo0?ooo`2>0?ooo`00OP3oool010000000oooo0?ooo`0000020?ooo`040000003oool0
oooo000000L0oooo00<000000?ooo`3oool0SP3oool007l0oooo00<000000?ooo`0000000`3oool0
0`000000oooo000000070?ooo`030000003oool0oooo08h0oooo00200?ooo`800000103oool20000
00L0oooo00<000000?ooo`3oool0SP3oool00800oooo0`0000020?ooo`<000001`3oool00`000000
oooo0?ooo`2>0?ooo`00P@3oool010000000oooo0?ooo`0000030?ooo`030000003oool0oooo00@0
oooo00<000000?ooo`3oool0SP3oool007h0oooo1@0000050?ooo`030000003oool0oooo00@0oooo
00<000000?ooo`3oool0SP3oool007h0oooo00@000000?ooo`3oool000001P3oool00`000000oooo
0?ooo`040?ooo`030000003oool0oooo08h0oooo001o0?ooo`030000003oool000000080oooo1000
00070?ooo`030000003oool0oooo08h0oooo00200?ooo`8000000P3oool00`000000oooo0?ooo`08
0?ooo`030000003oool0oooo08h0oooo00200?ooo`<0000000<0oooo0000000000000`0000060?oo
o`030000003oool0oooo08h0oooo00210?ooo`040000003oool0oooo000000<0oooo00<000000?oo
o`3oool0103oool00`000000oooo0?ooo`2>0?ooo`00OP3oool5000000030?ooo`000000oooo0080
oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`2>0?ooo`00OP3oool010000000oooo
0?ooo`0000020?ooo`@000001`3oool00`000000oooo0?ooo`2>0?ooo`00O`3oool00`000000oooo
000000020?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool0SP3oool00800oooo0`00
00020?ooo`800000203oool00`000000oooo0?ooo`2>0?ooo`00P@3oool00`000000oooo0?ooo`02
0?ooo`8000001`3oool00`000000oooo0?ooo`2>0?ooo`00OP3oool5000000D0oooo00<000000?oo
o`3oool0103oool00`000000oooo0?ooo`2>0?ooo`00OP3oool010000000oooo0?ooo`0000030?oo
o`@00000U`3oool007l0oooo00<000000?ooo`0000000P3oool01@000000oooo0?ooo`3oool00000
09L0oooo00200?ooo`8000000P3oool01@000000oooo0?ooo`3oool0000009L0oooo00210?ooo`04
0000003oool0oooo0?ooo`<00000V03oool00?l0oooo8@3oool00001\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-1.0062, -1.00015, \
0.0174648, 0.175204}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.2 0.2 0.0247214 0.0247214 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
0 g
.5 Mabswid
[ ] 0 setdash
.4 .04944 m
.4 .02472 L
s
.4 .07416 m
.4 .04944 L
s
.7 .04944 m
.6 .02472 L
s
.7 .04944 m
.8 .02472 L
s
.6 .09889 m
.4 .07416 L
s
.6 .09889 m
.7 .04944 L
s
.6 .12361 m
.6 .09889 L
s
.6 .14833 m
.6 .12361 L
s
.6 .17305 m
.6 .14833 L
s
.5 .19777 m
.2 .02472 L
s
.5 .19777 m
.6 .17305 L
s
.5 .22249 m
.5 .19777 L
s
.5 .24721 m
.5 .22249 L
s
.5 .27193 m
.5 .24721 L
s
.5 .29666 m
.5 .27193 L
s
.5 .32138 m
.5 .29666 L
s
.5 .3461 m
.5 .32138 L
s
.5 .37082 m
.5 .3461 L
s
.5 .39554 m
.5 .37082 L
s
.5 .42026 m
.5 .39554 L
s
.5 .44498 m
.5 .42026 L
s
.5 .46971 m
.5 .44498 L
s
.5 .49443 m
.5 .46971 L
s
.5 .51915 m
.5 .49443 L
s
.5 .54387 m
.5 .51915 L
s
.5 .56859 m
.5 .54387 L
s
.5 .59331 m
.5 .56859 L
s
[(2)] .36 .05439 0 0 Mshowa
[(3)] .36 .07911 0 0 Mshowa
[(4)] .66 .05439 0 0 Mshowa
[(5)] .56 .10383 0 0 Mshowa
[(6)] .56 .12855 0 0 Mshowa
[(8)] .56 .15327 0 0 Mshowa
[(9)] .56 .17799 0 0 Mshowa
[(11)] .46 .20272 0 0 Mshowa
[(12)] .46 .22744 0 0 Mshowa
[(14)] .46 .25216 0 0 Mshowa
[(16)] .46 .27688 0 0 Mshowa
[(17)] .46 .3016 0 0 Mshowa
[(18)] .46 .32632 0 0 Mshowa
[(20)] .46 .35104 0 0 Mshowa
[(21)] .46 .37576 0 0 Mshowa
[(23)] .46 .40049 0 0 Mshowa
[(25)] .46 .42521 0 0 Mshowa
[(38)] .46 .44993 0 0 Mshowa
[(40)] .46 .47465 0 0 Mshowa
[(41)] .46 .49937 0 0 Mshowa
[(44)] .46 .52409 0 0 Mshowa
[(45)] .46 .54881 0 0 Mshowa
[(46)] .46 .57354 0 0 Mshowa
[(49)] .46 .59826 0 0 Mshowa
gsave
.2 .01978 -66 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(d) show
1.000 setlinewidth
grestore
gsave
.4 .01978 -66 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(b) show
1.000 setlinewidth
grestore
gsave
.6 .01978 -66 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(a) show
1.000 setlinewidth
grestore
gsave
.8 .01978 -66 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(c) show
1.000 setlinewidth
grestore
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[464]:=",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/B000`400?l00000o`00003oo`3ooolQ
0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00=`3oool4000003@0oooo1000000g0?ooo`@00000
=@3oool3000003X0oooo000f0?ooo`040000003oool0oooo000003H0oooo00@000000?ooo`3oool0
0000=@3oool010000000oooo0?ooo`00000e0?ooo`050000003oool0oooo0?ooo`000000>@3oool0
03H0oooo00@000000?ooo`3oool00000=P3oool010000000oooo0?ooo`00000f0?ooo`<00000=@3o
ool00`000000oooo0?ooo`0k0?ooo`00=P3oool010000000oooo0?ooo`00000f0?ooo`040000003o
ool0oooo000003D0oooo00@000000?ooo`3oool00000=@3oool01@000000oooo0?ooo`3oool00000
03T0oooo000g0?ooo`@00000=@3oool3000003L0oooo1@00000d0?ooo`<00000>P3oool003T0oooo
00@000000?ooo`0000000000<`3oool00`000000oooo0000000l0?ooo`@00000;03oool4000003d0
oooo000h0?ooo`8000000`3oool00`000000oooo0?ooo`0_0?ooo`80000000<0oooo0000003oool0
?`3oool4000002@0oooo100000110?ooo`00?P3oool200000380oooo00<000000?ooo`3oool0@P3o
ool4000001/0oooo1@0000150?ooo`00@03oool200000300oooo00<000000?ooo`3oool0AP3oool4
000001<0oooo1000001:0?ooo`00@P3oool2000002h0oooo00<000000?ooo`3oool0BP3oool40000
00/0oooo1000001>0?ooo`00A03oool00`000000oooo0?ooo`0M0?ooo`D000002@3oool00`000000
oooo0?ooo`170?ooo`<00000103oool4000000<0oooo1000001B0?ooo`00A@3oool2000001h0oooo
00@000000?ooo`3oool000002@3oool00`000000oooo0?ooo`180?ooo`030000003oool0oooo00L0
oooo0`00001F0?ooo`00A`3oool2000001d0oooo00<000000?ooo`3oool02@3oool00`000000oooo
0?ooo`150?ooo`D000001P3oool2000005T0oooo00190?ooo`800000703oool00`000000oooo0?oo
o`080?ooo`030000003oool0oooo04D0oooo00@000000?ooo`3oool000001@3oool2000005/0oooo
001;0?ooo`030000003oool0oooo01H0oooo00D000000?ooo`3oool0oooo000000090?ooo`030000
003oool0oooo04H0oooo00<000000?ooo`0000000`3oool2000005d0oooo001<0?ooo`8000005P3o
ool01@000000oooo0?ooo`3oool0000000T0oooo00<000000?ooo`3oool0A`3oool2000000030?oo
o`000000000005l0oooo001>0?ooo`8000005@3oool3000000X0oooo00<000000?ooo`3oool0B03o
ool200000640oooo001@0?ooo`8000004`3oool3000000X0oooo00<000000?ooo`3oool0AP3oool2
000006<0oooo001B0?ooo`030000003oool0oooo00l0oooo00D000000?ooo`3oool0oooo00000009
0?ooo`D00000@P3oool2000006D0oooo001C0?ooo`8000004`3oool00`000000oooo0?ooo`0<0?oo
o`P00000>03oool2000006L0oooo001E0?ooo`8000003`3oool2000001L0oooo2@00000]0?ooo`80
0000J@3oool005L0oooo0P00000?0?ooo`030000003oool0oooo01d0oooo2000000S0?ooo`800000
J`3oool005T0oooo00<000000?ooo`3oool0203oool01@000000oooo0?ooo`3oool0000002L0oooo
2000000I0?ooo`800000K@3oool005X0oooo0P0000090?ooo`<00000<03oool9000000h0oooo0P00
001_0?ooo`00G03oool200000400oooo2`0000040?ooo`800000L@3oool005h0oooo0P00000m0?oo
o`050000003oool0oooo0?ooo`0000001`3oool4000007<0oooo001P0?ooo`030000003oool0oooo
03h0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`1a0?ooo`00H@3oool2000003h0
oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`1a0?ooo`00H`3oool2000003P0oooo
1000000;0?ooo`030000003oool0oooo0740oooo001U0?ooo`800000=P3oool00`000000oooo0?oo
o`0<0?ooo`030000003oool0oooo0740oooo001W0?ooo`800000=03oool5000000X0oooo00<00000
0?ooo`3oool0L@3oool006T0oooo00<000000?ooo`3oool0<P3oool3000000/0oooo00<000000?oo
o`3oool0L@3oool006X0oooo0P00000a0?ooo`050000003oool0oooo0?ooo`0000002P3oool00`00
0000oooo0?ooo`1a0?ooo`00K03oool2000002l0oooo00D000000?ooo`3oool0oooo0000000:0?oo
o`030000003oool0oooo0740oooo001^0?ooo`800000;@3oool4000000/0oooo00<000000?ooo`3o
ool0L@3oool00700oooo00<000000?ooo`3oool0:P3oool00`000000oooo0?ooo`0<0?ooo`030000
003oool0oooo0740oooo001a0?ooo`800000:`3oool00`000000oooo0?ooo`0;0?ooo`030000003o
ool0oooo0740oooo001c0?ooo`800000:P3oool2000000/0oooo00<000000?ooo`3oool0L@3oool0
07D0oooo0P00000W0?ooo`<000002`3oool00`000000oooo0?ooo`1a0?ooo`00M`3oool00`000000
oooo0?ooo`0S0?ooo`050000003oool0oooo0?ooo`0000002P3oool00`000000oooo0?ooo`1a0?oo
o`00N03oool2000002<0oooo00D000000?ooo`3oool0oooo0000000:0?ooo`030000003oool0oooo
0740oooo001j0?ooo`8000008P3oool3000000/0oooo00<000000?ooo`3oool0L@3oool007`0oooo
0P00000O0?ooo`050000003oool0oooo0?ooo`0000002P3oool00`000000oooo0?ooo`1a0?ooo`00
OP3oool00`000000oooo0?ooo`0L0?ooo`050000003oool0oooo0?ooo`0000002P3oool00`000000
oooo0?ooo`1a0?ooo`00O`3oool2000001d0oooo0`00000;0?ooo`030000003oool0oooo0740oooo
00210?ooo`8000006`3oool2000000`0oooo00<000000?ooo`3oool0L@3oool008<0oooo0P00000K
0?ooo`030000003oool0oooo00L0oooo0`00001c0?ooo`00Q@3oool00`000000oooo0?ooo`0I0?oo
o`030000003oool0oooo0080oooo1000001f0?ooo`00QP3oool2000001H0oooo2000001j0?ooo`00
R03oool2000001<0oooo1@00001n0?ooo`00RP3oool2000000d0oooo1@0000030?ooo`030000003o
ool0oooo07`0oooo002<0?ooo`030000003oool0oooo00H0oooo100000050?ooo`<00000O`3oool0
07l0oooo0`0000030?ooo`<000001@3oool200000080oooo1000002;0?ooo`00P03oool00`000000
oooo0?ooo`030?ooo`030000003oool0oooo00H0oooo0P00002?0?ooo`00P03oool00`000000oooo
0?ooo`030?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool0SP3oool00800oooo00<0
00000?ooo`3oool00`3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo08h0oooo0020
0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`2>
0?ooo`00O`3oool2000000@0oooo0P0000080?ooo`030000003oool0oooo08h0oooo00200?ooo`03
0000003oool0oooo00<0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`2>0?ooo`00
O`3oool300000080oooo1@0000060?ooo`030000003oool0oooo08h0oooo00200?ooo`030000003o
ool0oooo0080oooo00@000000?ooo`3oool000001P3oool00`000000oooo0?ooo`2>0?ooo`00P03o
ool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool0SP3o
ool00800oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`050?ooo`030000003oool0
oooo08h0oooo00200?ooo`050000003oool0oooo0?ooo`0000000`3oool00`000000oooo0?ooo`04
0?ooo`030000003oool0oooo08h0oooo001o0?ooo`8000000`3oool01@000000oooo0?ooo`3oool0
000000H0oooo00<000000?ooo`3oool0SP3oool00800oooo00<000000?ooo`3oool00P3oool30000
00L0oooo00<000000?ooo`3oool0SP3oool007l0oooo0`0000040?ooo`<000001P3oool00`000000
oooo0?ooo`2>0?ooo`00P03oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00D0oooo
00<000000?ooo`3oool0SP3oool00800oooo00@000000?ooo`3oool0oooo1@0000060?ooo`030000
003oool0oooo08h0oooo00200?ooo`050000003oool0oooo0?ooo`0000000P3oool00`000000oooo
0?ooo`050?ooo`030000003oool0oooo08h0oooo00200?ooo`030000003oool0oooo0080oooo00<0
00000?ooo`0000001`3oool00`000000oooo0?ooo`2>0?ooo`00O`3oool2000000D0oooo0P000007
0?ooo`030000003oool0oooo08h0oooo00200?ooo`030000003oool0oooo00@0oooo00<000000?oo
o`3oool01@3oool00`000000oooo0?ooo`2>0?ooo`00O`3oool3000000<0oooo0`0000070?ooo`03
0000003oool0oooo08h0oooo00200?ooo`050000003oool0oooo0?ooo`0000000`3oool00`000000
oooo0?ooo`040?ooo`030000003oool0oooo08h0oooo00200?ooo`050000003oool0oooo0?ooo`00
00000`3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo08h0oooo00200?ooo`040000
003oool0oooo0?ooo`@000001`3oool00`000000oooo0?ooo`2>0?ooo`00P03oool01@000000oooo
0?ooo`3oool0000000X0oooo00<000000?ooo`3oool0SP3oool007l0oooo0P0000040?ooo`030000
003oool0oooo00L0oooo00<000000?ooo`3oool0SP3oool00800oooo00<000000?ooo`3oool00`3o
ool2000000L0oooo00<000000?ooo`3oool0SP3oool007l0oooo0`0000040?ooo`030000003oool0
oooo00H0oooo00<000000?ooo`3oool0SP3oool00800oooo00<000000?ooo`3oool00`3oool00`00
0000oooo0?ooo`060?ooo`030000003oool0oooo08h0oooo00200?ooo`030000003oool0oooo00@0
oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`2>0?ooo`00P03oool00`000000oooo
0?ooo`040?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool0SP3oool00800oooo00<0
00000?ooo`3oool01@3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo08h0oooo001o
0?ooo`8000000`3oool01@000000oooo0?ooo`3oool0000000H0oooo00<000000?ooo`3oool0SP3o
ool00800oooo00@000000?ooo`3oool0oooo1@0000060?ooo`030000003oool0oooo08h0oooo001o
0?ooo`<000000`3oool3000000L0oooo00<000000?ooo`3oool0SP3oool00800oooo00D000000?oo
o`3oool0oooo000000030?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0SP3oool0
0800oooo00D000000?ooo`3oool0oooo000000030?ooo`030000003oool0oooo00@0oooo00<00000
0?ooo`3oool0SP3oool00800oooo00<000000?ooo`3oool00P3oool3000000L0oooo00<000000?oo
o`3oool0SP3oool00800oooo00D000000?ooo`3oool0oooo000000030?ooo`030000003oool0oooo
00@0oooo00<000000?ooo`3oool0SP3oool007l0oooo0P0000030?ooo`050000003oool0oooo0?oo
o`0000001P3oool00`000000oooo0?ooo`2>0?ooo`00P03oool00`000000oooo0?ooo`020?ooo`<0
00001`3oool00`000000oooo0?ooo`2>0?ooo`00S`3oool00`000000oooo0?ooo`2>0?ooo`00OP3o
ool5000000<0oooo0P0000070?ooo`030000003oool0oooo08h0oooo001o0?ooo`040000003oool0
oooo00000080oooo00@000000?ooo`3oool000001P3oool00`000000oooo0?ooo`2>0?ooo`00P03o
ool00`000000oooo0?ooo`020?ooo`040000003oool0oooo000000H0oooo00<000000?ooo`3oool0
SP3oool00840oooo00D000000?ooo`3oool0oooo000000020?ooo`030000003oool0oooo00@0oooo
00<000000?ooo`3oool0SP3oool007h0oooo00D000000?ooo`3oool0oooo000000020?ooo`040000
003oool0oooo000000H0oooo00<000000?ooo`3oool0SP3oool007h0oooo00D000000?ooo`3oool0
oooo000000020?ooo`040000003oool0oooo000000H0oooo00<000000?ooo`3oool0SP3oool007l0
oooo0`0000040?ooo`8000001`3oool00`000000oooo0?ooo`2>0?ooo`00OP3oool500000080oooo
0`0000070?ooo`030000003oool0oooo08h0oooo001o0?ooo`040000003oool0oooo000000<0oooo
00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`2>0?ooo`00P03oool00`000000oooo0?oo
o`030?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool0SP3oool00840oooo00<00000
0?ooo`3oool00P3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo08h0oooo001n0?oo
o`050000003oool0oooo0?ooo`0000000`3oool00`000000oooo0?ooo`060?ooo`030000003oool0
oooo08h0oooo001n0?ooo`050000003oool0oooo0?ooo`0000000P3oool2000000P0oooo00<00000
0?ooo`3oool0SP3oool007l0oooo0`0000040?ooo`030000003oool0oooo00H0oooo00<000000?oo
o`3oool0SP3oool007h0oooo1@0000020?ooo`<000001`3oool00`000000oooo0?ooo`2>0?ooo`00
O`3oool01P000000oooo0?ooo`000000oooo000000<0oooo00<000000?ooo`3oool0103oool00`00
0000oooo0?ooo`2>0?ooo`00P03oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00@0
oooo00<000000?ooo`3oool0SP3oool00840oooo00<000000?ooo`3oool00P3oool2000000L0oooo
00<000000?ooo`3oool0SP3oool007h0oooo00D000000?ooo`3oool0oooo000000050?ooo`030000
003oool0oooo00@0oooo00<000000?ooo`3oool0SP3oool007h0oooo00L000000?ooo`3oool0oooo
0000003oool0000000<0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`2>0?ooo`00
O`3oool3000000<0oooo0`0000070?ooo`030000003oool0oooo08h0oooo001n0?ooo`D000000P3o
ool3000000L0oooo00<000000?ooo`3oool0SP3oool007l0oooo00H000000?ooo`3oool000000?oo
o`0000030?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0SP3oool00800oooo00<0
00000?ooo`3oool01@3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo08h0oooo0021
0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`2>
0?ooo`00OP3oool01P000000oooo0?ooo`3oool000000?ooo`@000001`3oool00`000000oooo0?oo
o`2>0?ooo`00OP3oool01`000000oooo0?ooo`3oool000000?ooo`0000002P3oool00`000000oooo
0?ooo`2>0?ooo`00O`3oool300000080oooo1@0000060?ooo`030000003oool0oooo08h0oooo001o
0?ooo`<000000`3oool3000000L0oooo00<000000?ooo`3oool0SP3oool007h0oooo00L000000?oo
o`3oool0oooo0000003oool0000000<0oooo00<000000?ooo`3oool0103oool00`000000oooo0?oo
o`2>0?ooo`00PP3oool00`000000oooo000000030?ooo`030000003oool0oooo00@0oooo00<00000
0?ooo`3oool0SP3oool00800oooo0P0000030?ooo`<000001`3oool00`000000oooo0?ooo`2>0?oo
o`00PP3oool00`000000oooo000000030?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3o
ool0SP3oool007h0oooo00L000000?ooo`3oool0oooo0000003oool0000000<0oooo00<000000?oo
o`3oool0103oool00`000000oooo0?ooo`2>0?ooo`00O`3oool3000000<0oooo0`0000070?ooo`03
0000003oool0oooo08h0oooo00200?ooo`<000000`3oool2000000L0oooo00<000000?ooo`3oool0
SP3oool00840oooo00D000000?ooo`3oool0oooo000000020?ooo`030000003oool0oooo00@0oooo
00<000000?ooo`3oool0SP3oool007h0oooo1@0000020?ooo`040000003oool0oooo000000H0oooo
00<000000?ooo`3oool0SP3oool007h0oooo00@000000?ooo`3oool000000`3oool010000000oooo
0?ooo`0000060?ooo`030000003oool0oooo08h0oooo001o0?ooo`030000003oool0000000<0oooo
00@000000?ooo`3oool000001P3oool00`000000oooo0?ooo`2>0?ooo`00P03oool2000000<0oooo
00@000000?ooo`3oool000001P3oool00`000000oooo0?ooo`2>0?ooo`00P@3oool00`000000oooo
0?ooo`020?ooo`8000001`3oool00`000000oooo0?ooo`2>0?ooo`00P03oool300000080oooo0`00
00070?ooo`030000003oool0oooo08h0oooo00210?ooo`030000003oool0oooo0080oooo00<00000
0?ooo`3oool01P3oool00`000000oooo0?ooo`2>0?ooo`00OP3oool5000000<0oooo00<000000?oo
o`3oool01P3oool00`000000oooo0?ooo`2>0?ooo`00OP3oool010000000oooo0?ooo`0000040?oo
o`030000003oool0oooo00H0oooo00<000000?ooo`3oool0SP3oool007l0oooo00<000000?ooo`00
0000103oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo08h0oooo00200?ooo`800000
0`3oool2000000P0oooo00<000000?ooo`3oool0SP3oool00840oooo00<000000?ooo`3oool00P3o
ool00`000000oooo0?ooo`060?ooo`030000003oool0oooo08h0oooo00200?ooo`<000000`3oool3
000000H0oooo00<000000?ooo`3oool0SP3oool00840oooo00<000000?ooo`3oool00`3oool00`00
0000oooo0?ooo`050?ooo`030000003oool0oooo08h0oooo001n0?ooo`D0000000<0oooo00000000
00000`0000060?ooo`030000003oool0oooo08h0oooo001n0?ooo`040000003oool0oooo00000080
oooo00@000000?ooo`3oool000001`3oool00`000000oooo0?ooo`2>0?ooo`00O`3oool00`000000
oooo000000030?ooo`030000003oool0000000L0oooo00<000000?ooo`3oool0SP3oool00800oooo
0P0000040?ooo`8000001`3oool00`000000oooo0?ooo`2>0?ooo`00P@3oool00`000000oooo0?oo
o`030?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool0SP3oool00800oooo0`000002
0?ooo`<000001`3oool00`000000oooo0?ooo`2>0?ooo`00P@3oool010000000oooo0?ooo`000003
0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0SP3oool007h0oooo1@0000050?oo
o`030000003oool0oooo00@0oooo00<000000?ooo`3oool0SP3oool007h0oooo00@000000?ooo`3o
ool000001P3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo08h0oooo001o0?ooo`03
0000003oool000000080oooo100000070?ooo`030000003oool0oooo08h0oooo00200?ooo`800000
0P3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo08h0oooo00210?ooo`030000003o
ool0oooo00D000001P3oool00`000000oooo0?ooo`2>0?ooo`00P03oool300000080oooo0`000007
0?ooo`030000003oool0oooo08h0oooo00210?ooo`040000003oool0oooo000000<0oooo00<00000
0?ooo`3oool0103oool00`000000oooo0?ooo`2>0?ooo`00OP3oool5000000030?ooo`000000oooo
0080oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`2>0?ooo`00OP3oool010000000
oooo0?ooo`0000020?ooo`@000001`3oool00`000000oooo0?ooo`2>0?ooo`00O`3oool00`000000
oooo000000020?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool0SP3oool00800oooo
0P0000030?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool0SP3oool00840oooo00<0
00000?ooo`3oool00P3oool2000000L0oooo00<000000?ooo`3oool0SP3oool00800oooo0`000002
0?ooo`800000203oool00`000000oooo0?ooo`2>0?ooo`00P@3oool00`000000oooo0?ooo`030?oo
o`030000003oool0oooo00D0oooo00<000000?ooo`3oool0SP3oool007h0oooo1@0000050?ooo`03
0000003oool0oooo09D0oooo001n0?ooo`040000003oool0oooo000000<0oooo1000002G0?ooo`00
O`3oool00`000000oooo000000020?ooo`050000003oool0oooo0?ooo`000000U`3oool00800oooo
0P0000020?ooo`050000003oool0oooo0?ooo`000000U`3oool00840oooo00@000000?ooo`3oool0
oooo0`00002H0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-1.0062, -1.00013, \
0.0174648, 0.141293}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.2 0.2 0.0257514 0.0257514 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
0 g
.5 Mabswid
[ ] 0 setdash
.4 .0515 m
.4 .02575 L
s
.4 .07725 m
.4 .0515 L
s
.7 .0515 m
.6 .02575 L
s
.7 .0515 m
.8 .02575 L
s
.6 .10301 m
.4 .07725 L
s
.6 .10301 m
.7 .0515 L
s
.6 .12876 m
.6 .10301 L
s
.6 .15451 m
.6 .12876 L
s
.6 .18026 m
.6 .15451 L
s
.5 .20601 m
.2 .02575 L
s
.5 .20601 m
.6 .18026 L
s
.5 .23176 m
.5 .20601 L
s
.5 .25751 m
.5 .23176 L
s
.5 .28327 m
.5 .25751 L
s
.5 .30902 m
.5 .28327 L
s
.5 .33477 m
.5 .30902 L
s
.5 .36052 m
.5 .33477 L
s
.5 .38627 m
.5 .36052 L
s
.5 .41202 m
.5 .38627 L
s
.5 .43777 m
.5 .41202 L
s
.5 .46353 m
.5 .43777 L
s
.5 .48928 m
.5 .46353 L
s
.5 .51503 m
.5 .48928 L
s
.5 .54078 m
.5 .51503 L
s
.5 .56653 m
.5 .54078 L
s
.5 .59228 m
.5 .56653 L
s
[(2)] .36 .05665 0 0 Mshowa
[(3)] .36 .0824 0 0 Mshowa
[(4)] .66 .05665 0 0 Mshowa
[(5)] .56 .10816 0 0 Mshowa
[(6)] .56 .13391 0 0 Mshowa
[(8)] .56 .15966 0 0 Mshowa
[(9)] .56 .18541 0 0 Mshowa
[(11)] .46 .21116 0 0 Mshowa
[(12)] .46 .23691 0 0 Mshowa
[(14)] .46 .26266 0 0 Mshowa
[(16)] .46 .28842 0 0 Mshowa
[(17)] .46 .31417 0 0 Mshowa
[(18)] .46 .33992 0 0 Mshowa
[(20)] .46 .36567 0 0 Mshowa
[(21)] .46 .39142 0 0 Mshowa
[(23)] .46 .41717 0 0 Mshowa
[(25)] .46 .44292 0 0 Mshowa
[(38)] .46 .46868 0 0 Mshowa
[(40)] .46 .49443 0 0 Mshowa
[(41)] .46 .52018 0 0 Mshowa
[(44)] .46 .54593 0 0 Mshowa
[(45)] .46 .57168 0 0 Mshowa
[(47)] .46 .59743 0 0 Mshowa
gsave
.2 .0206 -66 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(d) show
1.000 setlinewidth
grestore
gsave
.4 .0206 -66 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(b) show
1.000 setlinewidth
grestore
gsave
.6 .0206 -66 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(a) show
1.000 setlinewidth
grestore
gsave
.8 .0206 -66 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(c) show
1.000 setlinewidth
grestore
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[464]:=",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/B000`400?l00000o`00003oo`3ooolQ
0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00=`3oool4000003@0oooo1000000g0?ooo`@00000
=@3oool3000003X0oooo000f0?ooo`040000003oool0oooo000003H0oooo00@000000?ooo`3oool0
0000=@3oool010000000oooo0?ooo`00000e0?ooo`050000003oool0oooo0?ooo`000000>@3oool0
03H0oooo00@000000?ooo`3oool00000=P3oool010000000oooo0?ooo`00000f0?ooo`<00000=@3o
ool00`000000oooo0?ooo`0k0?ooo`00=P3oool010000000oooo0?ooo`00000f0?ooo`040000003o
ool0oooo000003D0oooo00@000000?ooo`3oool00000=@3oool01@000000oooo0?ooo`3oool00000
03T0oooo000g0?ooo`@00000=@3oool3000003L0oooo1@00000d0?ooo`<00000>P3oool003T0oooo
00<000000?ooo`000000=03oool00`000000oooo0000000l0?ooo`@00000;03oool4000003d0oooo
000h0?ooo`8000000P3oool200000340oooo0P0000000`3oool000000?ooo`0o0?ooo`@00000903o
ool400000440oooo000n0?ooo`800000<P3oool00`000000oooo0?ooo`120?ooo`@000006`3oool5
000004D0oooo00100?ooo`030000003oool0oooo02l0oooo00<000000?ooo`3oool0AP3oool40000
01<0oooo1000001:0?ooo`00@@3oool2000002l0oooo00<000000?ooo`3oool0BP3oool4000000/0
oooo1000001>0?ooo`00@`3oool2000001l0oooo1@0000090?ooo`030000003oool0oooo04L0oooo
0`0000040?ooo`@000000`3oool400000580oooo00150?ooo`030000003oool0oooo01d0oooo00@0
00000?ooo`3oool000002@3oool00`000000oooo0?ooo`180?ooo`030000003oool0oooo00L0oooo
0`00001F0?ooo`00AP3oool2000001h0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?oo
o`150?ooo`D000001P3oool2000005T0oooo00180?ooo`8000007@3oool00`000000oooo0?ooo`08
0?ooo`030000003oool0oooo04D0oooo00@000000?ooo`3oool000001@3oool2000005/0oooo001:
0?ooo`030000003oool0oooo01L0oooo00D000000?ooo`3oool0oooo000000090?ooo`030000003o
ool0oooo04H0oooo00<000000?ooo`0000000`3oool2000005d0oooo001;0?ooo`8000005`3oool0
1@000000oooo0?ooo`3oool0000000T0oooo00<000000?ooo`3oool0A`3oool200000080oooo00<0
00000?ooo`3oool0G@3oool004d0oooo0P00000F0?ooo`<000002P3oool00`000000oooo0?ooo`18
0?ooo`<00000H03oool004l0oooo00<000000?ooo`3oool0803oool00`000000oooo0?ooo`170?oo
o`800000HP3oool00500oooo0P00000C0?ooo`<000002P3oool00`000000oooo0?ooo`150?ooo`80
0000I03oool00580oooo0P00000@0?ooo`050000003oool0oooo0?ooo`0000002@3oool500000440
oooo0P00001V0?ooo`00E03oool00`000000oooo0?ooo`0A0?ooo`030000003oool0oooo00`0oooo
2000000g0?ooo`800000J03oool005D0oooo0P00000?0?ooo`8000005`3oool9000002`0oooo0P00
001Z0?ooo`00E`3oool2000000l0oooo00<000000?ooo`3oool07@3oool8000002<0oooo00<00000
0?ooo`3oool0JP3oool005T0oooo00<000000?ooo`3oool0203oool01@000000oooo0?ooo`3oool0
000002L0oooo2000000I0?ooo`800000K@3oool005X0oooo0P0000090?ooo`<00000<03oool90000
00h0oooo0P00001_0?ooo`00G03oool200000400oooo2`0000040?ooo`800000L@3oool005h0oooo
00<000000?ooo`3oool0?03oool01@000000oooo0?ooo`3oool0000000L0oooo1000001c0?ooo`00
G`3oool200000400oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`1a0?ooo`00H@3o
ool2000003h0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`1a0?ooo`00H`3oool0
0`000000oooo0?ooo`0g0?ooo`@000002`3oool00`000000oooo0?ooo`1a0?ooo`00I03oool20000
03L0oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`1a0?ooo`00IP3oool00`000000
oooo0?ooo`0d0?ooo`D000002P3oool00`000000oooo0?ooo`1a0?ooo`00I`3oool2000003D0oooo
0`00000;0?ooo`030000003oool0oooo0740oooo001Y0?ooo`800000<P3oool01@000000oooo0?oo
o`3oool0000000X0oooo00<000000?ooo`3oool0L@3oool006/0oooo00<000000?ooo`3oool0;`3o
ool01@000000oooo0?ooo`3oool0000000X0oooo00<000000?ooo`3oool0L@3oool006`0oooo0P00
000_0?ooo`@000002`3oool00`000000oooo0?ooo`1a0?ooo`00KP3oool2000002d0oooo00<00000
0?ooo`3oool0303oool00`000000oooo0?ooo`1a0?ooo`00L03oool00`000000oooo0?ooo`0[0?oo
o`030000003oool0oooo00/0oooo00<000000?ooo`3oool0L@3oool00740oooo0P00000/0?ooo`80
00002`3oool00`000000oooo0?ooo`1a0?ooo`00L`3oool2000003L0oooo00<000000?ooo`3oool0
L@3oool007D0oooo00<000000?ooo`3oool09P3oool3000000/0oooo00<000000?ooo`3oool0L@3o
ool007H0oooo0P00000U0?ooo`050000003oool0oooo0?ooo`0000002P3oool00`000000oooo0?oo
o`1a0?ooo`00N03oool2000002<0oooo00D000000?ooo`3oool0oooo0000000:0?ooo`030000003o
ool0oooo0740oooo001j0?ooo`030000003oool0oooo0240oooo0`00000;0?ooo`030000003oool0
oooo0740oooo001k0?ooo`800000803oool01@000000oooo0?ooo`3oool0000000X0oooo00<00000
0?ooo`3oool0L@3oool007d0oooo0P00000N0?ooo`050000003oool0oooo0?ooo`0000002P3oool0
0`000000oooo0?ooo`1a0?ooo`00O`3oool00`000000oooo0?ooo`0L0?ooo`<000002`3oool00`00
0000oooo0?ooo`1a0?ooo`00P03oool2000001`0oooo0P00000<0?ooo`030000003oool0oooo0740
oooo00220?ooo`800000703oool00`000000oooo0?ooo`070?ooo`<00000L`3oool008@0oooo00<0
00000?ooo`3oool06P3oool00`000000oooo0?ooo`030?ooo`<00000MP3oool008D0oooo0P00000G
0?ooo`@0000000<0oooo0000000000000P00001i0?ooo`00Q`3oool2000001@0oooo00<000000?oo
o`0000000`00001m0?ooo`00R@3oool00`000000oooo0?ooo`0@0?ooo`<000000P3oool00`000000
oooo0?ooo`1l0?ooo`00RP3oool2000000`0oooo100000020?ooo`<00000O`3oool008`0oooo0P00
00060?ooo`@00000R03oool007l0oooo0`0000030?ooo`<000001P3oool00`000000oooo0?ooo`03
000008`0oooo00200?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool01P3oool20000
08l0oooo00200?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool01P3oool00`000000
oooo0?ooo`2>0?ooo`00P03oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00H0oooo
00<000000?ooo`3oool0SP3oool00800oooo00<000000?ooo`3oool00`3oool00`000000oooo0?oo
o`060?ooo`030000003oool0oooo08h0oooo001o0?ooo`800000103oool2000000P0oooo00<00000
0?ooo`3oool0SP3oool00800oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`060?oo
o`030000003oool0oooo08h0oooo001o0?ooo`<000000P3oool5000000H0oooo00<000000?ooo`3o
ool0SP3oool00800oooo00<000000?ooo`3oool00P3oool010000000oooo0?ooo`0000060?ooo`03
0000003oool0oooo08h0oooo00200?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0
1P3oool00`000000oooo0?ooo`2>0?ooo`00P03oool00`000000oooo0?ooo`040?ooo`030000003o
ool0oooo00D0oooo00<000000?ooo`3oool0SP3oool00800oooo00D000000?ooo`3oool0oooo0000
00030?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0SP3oool007l0oooo0P000003
0?ooo`050000003oool0oooo0?ooo`0000001P3oool00`000000oooo0?ooo`2>0?ooo`00P03oool0
0`000000oooo0?ooo`020?ooo`<000001`3oool00`000000oooo0?ooo`2>0?ooo`00O`3oool30000
00@0oooo0`0000060?ooo`030000003oool0oooo08h0oooo00200?ooo`030000003oool0oooo00@0
oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`2>0?ooo`00P03oool010000000oooo
0?ooo`3oool5000000H0oooo00<000000?ooo`3oool0SP3oool00800oooo00D000000?ooo`3oool0
oooo000000020?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool0SP3oool00800oooo
00<000000?ooo`3oool00P3oool00`000000oooo000000070?ooo`030000003oool0oooo08h0oooo
001o0?ooo`8000001@3oool2000000L0oooo00<000000?ooo`3oool0SP3oool00800oooo00<00000
0?ooo`3oool0103oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo08h0oooo002?0?oo
o`030000003oool0oooo08h0oooo001o0?ooo`<000000`3oool3000000L0oooo00<000000?ooo`3o
ool0SP3oool00800oooo00D000000?ooo`3oool0oooo000000030?ooo`030000003oool0oooo00@0
oooo00<000000?ooo`3oool0SP3oool00800oooo00D000000?ooo`3oool0oooo000000030?ooo`03
0000003oool0oooo00@0oooo00<000000?ooo`3oool0SP3oool00800oooo00@000000?ooo`3oool0
oooo100000070?ooo`030000003oool0oooo08h0oooo00200?ooo`050000003oool0oooo0?ooo`00
00002P3oool00`000000oooo0?ooo`2>0?ooo`00O`3oool2000000@0oooo00<000000?ooo`3oool0
1`3oool00`000000oooo0?ooo`2>0?ooo`00P03oool00`000000oooo0?ooo`030?ooo`8000001`3o
ool00`000000oooo0?ooo`2>0?ooo`00O`3oool3000000@0oooo00<000000?ooo`3oool01P3oool0
0`000000oooo0?ooo`2>0?ooo`00P03oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo
00H0oooo00<000000?ooo`3oool0SP3oool00800oooo00<000000?ooo`3oool0103oool00`000000
oooo0?ooo`050?ooo`030000003oool0oooo08h0oooo00200?ooo`030000003oool0oooo00@0oooo
00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`2>0?ooo`00P03oool00`000000oooo0?oo
o`050?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0SP3oool007l0oooo0P000003
0?ooo`050000003oool0oooo0?ooo`0000001P3oool00`000000oooo0?ooo`2>0?ooo`00P03oool0
10000000oooo0?ooo`3oool5000000H0oooo00<000000?ooo`3oool0SP3oool007l0oooo0`000003
0?ooo`<000001`3oool00`000000oooo0?ooo`2>0?ooo`00P03oool01@000000oooo0?ooo`3oool0
000000<0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`2>0?ooo`00P03oool01@00
0000oooo0?ooo`3oool0000000<0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`2>
0?ooo`00P03oool00`000000oooo0?ooo`020?ooo`<000001`3oool00`000000oooo0?ooo`2>0?oo
o`00P03oool01@000000oooo0?ooo`3oool0000000<0oooo00<000000?ooo`3oool0103oool00`00
0000oooo0?ooo`2>0?ooo`00O`3oool2000000<0oooo00D000000?ooo`3oool0oooo000000060?oo
o`030000003oool0oooo08h0oooo00200?ooo`030000003oool0oooo0080oooo0`0000070?ooo`03
0000003oool0oooo08h0oooo002?0?ooo`030000003oool0oooo08h0oooo001n0?ooo`D000000`3o
ool2000000L0oooo00<000000?ooo`3oool0SP3oool007l0oooo00@000000?ooo`3oool000000P3o
ool010000000oooo0?ooo`0000060?ooo`030000003oool0oooo08h0oooo00200?ooo`030000003o
ool0oooo0080oooo00@000000?ooo`3oool000001P3oool00`000000oooo0?ooo`2>0?ooo`00P@3o
ool01@000000oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool0103oool00`000000oooo
0?ooo`2>0?ooo`00OP3oool01@000000oooo0?ooo`3oool000000080oooo00@000000?ooo`3oool0
00001P3oool00`000000oooo0?ooo`2>0?ooo`00OP3oool01@000000oooo0?ooo`3oool000000080
oooo00@000000?ooo`3oool000001P3oool00`000000oooo0?ooo`2>0?ooo`00O`3oool3000000@0
oooo0P0000070?ooo`030000003oool0oooo08h0oooo001n0?ooo`D000000P3oool3000000L0oooo
00<000000?ooo`3oool0SP3oool007l0oooo00@000000?ooo`3oool000000`3oool00`000000oooo
0?ooo`060?ooo`030000003oool0oooo08h0oooo00200?ooo`030000003oool0oooo00<0oooo00<0
00000?ooo`3oool01P3oool00`000000oooo0?ooo`2>0?ooo`00P@3oool00`000000oooo0?ooo`02
0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool0SP3oool007h0oooo00D000000?oo
o`3oool0oooo000000030?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool0SP3oool0
07h0oooo00D000000?ooo`3oool0oooo000000020?ooo`800000203oool00`000000oooo0?ooo`2>
0?ooo`00O`3oool3000000@0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`2>0?oo
o`00OP3oool500000080oooo0`0000070?ooo`030000003oool0oooo08h0oooo001o0?ooo`060000
003oool0oooo0000003oool000000`3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo
08h0oooo00200?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool0103oool00`000000
oooo0?ooo`2>0?ooo`00P@3oool00`000000oooo0?ooo`020?ooo`8000001`3oool00`000000oooo
0?ooo`2>0?ooo`00OP3oool01@000000oooo0?ooo`3oool0000000D0oooo00<000000?ooo`3oool0
103oool00`000000oooo0?ooo`2>0?ooo`00OP3oool01`000000oooo0?ooo`3oool000000?ooo`00
00000`3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo08h0oooo001o0?ooo`<00000
0`3oool3000000L0oooo00<000000?ooo`3oool0SP3oool008l0oooo00<000000?ooo`3oool0SP3o
ool007h0oooo1@0000020?ooo`<000001`3oool00`000000oooo0?ooo`2>0?ooo`00O`3oool01P00
0000oooo0?ooo`000000oooo000000<0oooo00<000000?ooo`3oool0103oool00`000000oooo0?oo
o`2>0?ooo`00P03oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00@0oooo00<00000
0?ooo`3oool0SP3oool00840oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`040?oo
o`030000003oool0oooo08h0oooo001n0?ooo`060000003oool0oooo0?ooo`000000oooo10000007
0?ooo`030000003oool0oooo08h0oooo001n0?ooo`070000003oool0oooo0?ooo`000000oooo0000
000:0?ooo`030000003oool0oooo08h0oooo001o0?ooo`<000000P3oool5000000H0oooo00<00000
0?ooo`3oool0SP3oool007l0oooo0`0000030?ooo`<000001`3oool00`000000oooo0?ooo`2>0?oo
o`00OP3oool01`000000oooo0?ooo`3oool000000?ooo`0000000`3oool00`000000oooo0?ooo`04
0?ooo`030000003oool0oooo08h0oooo00220?ooo`030000003oool0000000<0oooo00<000000?oo
o`3oool0103oool00`000000oooo0?ooo`2>0?ooo`00P03oool2000000<0oooo0`0000070?ooo`03
0000003oool0oooo08h0oooo00220?ooo`030000003oool0000000<0oooo00<000000?ooo`3oool0
103oool00`000000oooo0?ooo`2>0?ooo`00OP3oool01`000000oooo0?ooo`3oool000000?ooo`00
00000`3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo08h0oooo001o0?ooo`<00000
0`3oool3000000L0oooo00<000000?ooo`3oool0SP3oool008l0oooo00<000000?ooo`3oool0SP3o
ool00800oooo0`0000030?ooo`8000001`3oool00`000000oooo0?ooo`2>0?ooo`00P@3oool01@00
0000oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`2>
0?ooo`00OP3oool500000080oooo00@000000?ooo`3oool000001P3oool00`000000oooo0?ooo`2>
0?ooo`00OP3oool010000000oooo0?ooo`0000030?ooo`040000003oool0oooo000000H0oooo00<0
00000?ooo`3oool0SP3oool007l0oooo00<000000?ooo`0000000`3oool010000000oooo0?ooo`00
00060?ooo`030000003oool0oooo08h0oooo00200?ooo`8000000`3oool010000000oooo0?ooo`00
00060?ooo`030000003oool0oooo08h0oooo00210?ooo`030000003oool0oooo0080oooo0P000007
0?ooo`030000003oool0oooo08h0oooo00200?ooo`<000000P3oool3000000L0oooo00<000000?oo
o`3oool0SP3oool00840oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`060?ooo`03
0000003oool0oooo08h0oooo001n0?ooo`D000000`3oool00`000000oooo0?ooo`060?ooo`030000
003oool0oooo08h0oooo001n0?ooo`040000003oool0oooo000000@0oooo00<000000?ooo`3oool0
1P3oool00`000000oooo0?ooo`2>0?ooo`00O`3oool00`000000oooo000000040?ooo`030000003o
ool0oooo00H0oooo00<000000?ooo`3oool0SP3oool00800oooo0P0000030?ooo`800000203oool0
0`000000oooo0?ooo`2>0?ooo`00P@3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo
00H0oooo00<000000?ooo`3oool0SP3oool00800oooo0`0000030?ooo`<000001P3oool00`000000
oooo0?ooo`2>0?ooo`00P@3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00D0oooo
00<000000?ooo`3oool0SP3oool007h0oooo1@0000000`3oool0000000000003000000H0oooo00<0
00000?ooo`3oool0SP3oool007h0oooo00@000000?ooo`3oool000000P3oool010000000oooo0?oo
o`0000070?ooo`030000003oool0oooo08h0oooo001o0?ooo`030000003oool0000000<0oooo00<0
00000?ooo`0000001`3oool00`000000oooo0?ooo`2>0?ooo`00P03oool2000000@0oooo0P000007
0?ooo`030000003oool0oooo08h0oooo00210?ooo`030000003oool0oooo00<0oooo00<000000?oo
o`3oool01@3oool00`000000oooo0?ooo`2>0?ooo`00S`3oool00`000000oooo0?ooo`2>0?ooo`00
P03oool300000080oooo0`0000070?ooo`030000003oool0oooo08h0oooo00210?ooo`040000003o
ool0oooo000000<0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`2>0?ooo`00OP3o
ool5000000D0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`2>0?ooo`00OP3oool0
10000000oooo0?ooo`0000060?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0SP3o
ool007l0oooo00<000000?ooo`0000000P3oool4000000L0oooo00<000000?ooo`3oool0SP3oool0
0800oooo0P0000020?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool0SP3oool00840
oooo00<000000?ooo`3oool01@0000060?ooo`030000003oool0oooo08h0oooo00200?ooo`<00000
0`3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo08h0oooo00210?ooo`030000003o
ool0oooo0080oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`2>0?ooo`00OP3oool5
000000@0oooo00<000000?ooo`3oool0UP3oool007h0oooo00@000000?ooo`3oool000001@3oool0
0`000000oooo0?ooo`2F0?ooo`00O`3oool00`000000oooo000000060?ooo`030000003oool0oooo
09D0oooo00200?ooo`8000000P3oool01@000000oooo0?ooo`3oool0000009L0oooo00210?ooo`03
0000003oool0oooo00D00000U`3oool00?l0oooo8@3oool00?l0oooo8@3oool00001\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-1.0062, -1.00012, \
0.0174648, 0.135642}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.2 0.2 0.0257514 0.0257514 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
0 g
.5 Mabswid
[ ] 0 setdash
.4 .0515 m
.4 .02575 L
s
.4 .07725 m
.4 .0515 L
s
.7 .0515 m
.6 .02575 L
s
.7 .0515 m
.8 .02575 L
s
.6 .10301 m
.4 .07725 L
s
.6 .10301 m
.7 .0515 L
s
.6 .12876 m
.6 .10301 L
s
.6 .15451 m
.6 .12876 L
s
.6 .18026 m
.6 .15451 L
s
.5 .20601 m
.2 .02575 L
s
.5 .20601 m
.6 .18026 L
s
.5 .23176 m
.5 .20601 L
s
.5 .25751 m
.5 .23176 L
s
.5 .28327 m
.5 .25751 L
s
.5 .30902 m
.5 .28327 L
s
.5 .33477 m
.5 .30902 L
s
.5 .36052 m
.5 .33477 L
s
.5 .38627 m
.5 .36052 L
s
.5 .41202 m
.5 .38627 L
s
.5 .43777 m
.5 .41202 L
s
.5 .46353 m
.5 .43777 L
s
.5 .48928 m
.5 .46353 L
s
.5 .51503 m
.5 .48928 L
s
.5 .54078 m
.5 .51503 L
s
.5 .56653 m
.5 .54078 L
s
.5 .59228 m
.5 .56653 L
s
[(2)] .36 .05665 0 0 Mshowa
[(3)] .36 .0824 0 0 Mshowa
[(4)] .66 .05665 0 0 Mshowa
[(5)] .56 .10816 0 0 Mshowa
[(7)] .56 .13391 0 0 Mshowa
[(8)] .56 .15966 0 0 Mshowa
[(9)] .56 .18541 0 0 Mshowa
[(11)] .46 .21116 0 0 Mshowa
[(12)] .46 .23691 0 0 Mshowa
[(14)] .46 .26266 0 0 Mshowa
[(16)] .46 .28842 0 0 Mshowa
[(17)] .46 .31417 0 0 Mshowa
[(18)] .46 .33992 0 0 Mshowa
[(20)] .46 .36567 0 0 Mshowa
[(21)] .46 .39142 0 0 Mshowa
[(23)] .46 .41717 0 0 Mshowa
[(25)] .46 .44292 0 0 Mshowa
[(38)] .46 .46868 0 0 Mshowa
[(40)] .46 .49443 0 0 Mshowa
[(41)] .46 .52018 0 0 Mshowa
[(44)] .46 .54593 0 0 Mshowa
[(45)] .46 .57168 0 0 Mshowa
[(47)] .46 .59743 0 0 Mshowa
gsave
.2 .0206 -66 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(d) show
1.000 setlinewidth
grestore
gsave
.4 .0206 -66 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(b) show
1.000 setlinewidth
grestore
gsave
.6 .0206 -66 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(a) show
1.000 setlinewidth
grestore
gsave
.8 .0206 -66 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(c) show
1.000 setlinewidth
grestore
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[464]:=",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/B000`400?l00000o`00003oo`3ooolQ
0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00=`3oool4000003@0oooo1000000g0?ooo`@00000
=@3oool3000003X0oooo000f0?ooo`040000003oool0oooo000003H0oooo00@000000?ooo`3oool0
0000=@3oool010000000oooo0?ooo`00000e0?ooo`050000003oool0oooo0?ooo`000000>@3oool0
03H0oooo00@000000?ooo`3oool00000=P3oool010000000oooo0?ooo`00000f0?ooo`<00000=@3o
ool00`000000oooo0?ooo`0k0?ooo`00=P3oool010000000oooo0?ooo`00000f0?ooo`040000003o
ool0oooo000003D0oooo00@000000?ooo`3oool00000=@3oool01@000000oooo0?ooo`3oool00000
03T0oooo000g0?ooo`@00000=@3oool3000003L0oooo1@00000d0?ooo`<00000>P3oool003T0oooo
00<000000?ooo`000000=03oool00`000000oooo0000000l0?ooo`@00000;03oool4000003d0oooo
000h0?ooo`8000000P3oool200000340oooo0P0000000`3oool000000?ooo`0o0?ooo`@00000903o
ool400000440oooo000n0?ooo`800000<P3oool00`000000oooo0?ooo`120?ooo`@000006`3oool5
000004D0oooo00100?ooo`030000003oool0oooo02l0oooo00<000000?ooo`3oool0AP3oool40000
01<0oooo1000001:0?ooo`00@@3oool2000002l0oooo00<000000?ooo`3oool0BP3oool4000000/0
oooo1000001>0?ooo`00@`3oool2000001l0oooo1@0000090?ooo`030000003oool0oooo04L0oooo
0`0000040?ooo`@000000`3oool400000580oooo00150?ooo`030000003oool0oooo01d0oooo00@0
00000?ooo`3oool000002@3oool00`000000oooo0?ooo`180?ooo`030000003oool0oooo00L0oooo
0`00001F0?ooo`00AP3oool2000001h0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?oo
o`150?ooo`D000001P3oool2000005T0oooo00180?ooo`8000007@3oool00`000000oooo0?ooo`08
0?ooo`030000003oool0oooo04D0oooo00@000000?ooo`3oool000001@3oool2000005/0oooo001:
0?ooo`030000003oool0oooo01L0oooo00D000000?ooo`3oool0oooo000000090?ooo`030000003o
ool0oooo04H0oooo00<000000?ooo`0000000`3oool2000005d0oooo001;0?ooo`8000005`3oool0
1@000000oooo0?ooo`3oool0000000T0oooo00<000000?ooo`3oool0A`3oool200000080oooo00<0
00000?ooo`3oool0G@3oool004d0oooo0P00000F0?ooo`<000002P3oool00`000000oooo0?ooo`18
0?ooo`<00000H03oool004l0oooo00<000000?ooo`3oool0803oool00`000000oooo0?ooo`170?oo
o`800000HP3oool00500oooo0P00000C0?ooo`<000002P3oool00`000000oooo0?ooo`150?ooo`80
0000I03oool00580oooo0P00000@0?ooo`050000003oool0oooo0?ooo`0000002@3oool500000440
oooo0P00001V0?ooo`00E03oool00`000000oooo0?ooo`0A0?ooo`030000003oool0oooo00`0oooo
2000000g0?ooo`800000J03oool005D0oooo0P00000?0?ooo`8000005`3oool9000002`0oooo0P00
001Z0?ooo`00E`3oool2000000l0oooo00<000000?ooo`3oool07@3oool8000002<0oooo00<00000
0?ooo`3oool0JP3oool005T0oooo00<000000?ooo`3oool0203oool01@000000oooo0?ooo`3oool0
000002L0oooo2000000I0?ooo`800000K@3oool005X0oooo0P0000090?ooo`<00000<03oool90000
00h0oooo0P00001_0?ooo`00G03oool200000400oooo2`0000040?ooo`800000L@3oool005h0oooo
00<000000?ooo`3oool0?03oool01@000000oooo0?ooo`3oool0000000L0oooo1000001c0?ooo`00
G`3oool200000400oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`1a0?ooo`00H@3o
ool2000003h0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`1a0?ooo`00H`3oool0
0`000000oooo0?ooo`0g0?ooo`@000002`3oool00`000000oooo0?ooo`1a0?ooo`00I03oool20000
03L0oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`1a0?ooo`00IP3oool00`000000
oooo0?ooo`0d0?ooo`D000002P3oool00`000000oooo0?ooo`1a0?ooo`00I`3oool2000003H0oooo
00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`1a0?ooo`00J@3oool2000003@0oooo00<0
00000?ooo`3oool02P3oool00`000000oooo0?ooo`1a0?ooo`00J`3oool00`000000oooo0?ooo`0b
0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool0L@3oool006`0oooo0P00000b0?oo
o`030000003oool0oooo00T0oooo00<000000?ooo`3oool0L@3oool006h0oooo0P00000a0?ooo`03
0000003oool0oooo00P0oooo00<000000?ooo`3oool0L@3oool00700oooo00<000000?ooo`3oool0
:P3oool01@000000oooo0?ooo`3oool0000000X0oooo00<000000?ooo`3oool0L@3oool00740oooo
0P00000Z0?ooo`D000002P3oool00`000000oooo0?ooo`1a0?ooo`00L`3oool2000003L0oooo00<0
00000?ooo`3oool0L@3oool007D0oooo00<000000?ooo`3oool09P3oool3000000/0oooo00<00000
0?ooo`3oool0L@3oool007H0oooo0P00000U0?ooo`050000003oool0oooo0?ooo`0000002P3oool0
0`000000oooo0?ooo`1a0?ooo`00N03oool2000002<0oooo00D000000?ooo`3oool0oooo0000000:
0?ooo`030000003oool0oooo0740oooo001j0?ooo`030000003oool0oooo0240oooo0`00000;0?oo
o`030000003oool0oooo0740oooo001k0?ooo`800000803oool01@000000oooo0?ooo`3oool00000
00X0oooo00<000000?ooo`3oool0L@3oool007d0oooo0P00000N0?ooo`050000003oool0oooo0?oo
o`0000002P3oool00`000000oooo0?ooo`1a0?ooo`00O`3oool00`000000oooo0?ooo`0L0?ooo`<0
00002`3oool00`000000oooo0?ooo`1a0?ooo`00P03oool2000001`0oooo0P00000<0?ooo`030000
003oool0oooo0740oooo00220?ooo`800000703oool00`000000oooo0?ooo`070?ooo`<00000L`3o
ool008@0oooo00<000000?ooo`3oool06P3oool00`000000oooo0?ooo`030?ooo`<00000MP3oool0
08D0oooo0P00000G0?ooo`@0000000<0oooo0000000000000P00001i0?ooo`00Q`3oool2000001@0
oooo00<000000?ooo`0000000`00001m0?ooo`00R@3oool00`000000oooo0?ooo`0@0?ooo`<00000
0P3oool00`000000oooo0?ooo`1l0?ooo`00RP3oool2000000`0oooo100000020?ooo`<00000O`3o
ool008`0oooo0P0000060?ooo`@00000R03oool007l0oooo0`0000030?ooo`<000001P3oool00`00
0000oooo0?ooo`03000008`0oooo00200?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3o
ool01P3oool2000008l0oooo00200?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0
1P3oool00`000000oooo0?ooo`2>0?ooo`00P03oool00`000000oooo0?ooo`030?ooo`030000003o
ool0oooo00H0oooo00<000000?ooo`3oool0SP3oool00800oooo00<000000?ooo`3oool00`3oool0
0`000000oooo0?ooo`060?ooo`030000003oool0oooo08h0oooo001o0?ooo`800000103oool20000
00P0oooo00<000000?ooo`3oool0SP3oool00800oooo00<000000?ooo`3oool00`3oool00`000000
oooo0?ooo`060?ooo`030000003oool0oooo08h0oooo001o0?ooo`<000000P3oool5000000H0oooo
00<000000?ooo`3oool0SP3oool00800oooo00<000000?ooo`3oool00P3oool010000000oooo0?oo
o`0000060?ooo`030000003oool0oooo08h0oooo00200?ooo`030000003oool0oooo00<0oooo00<0
00000?ooo`3oool01P3oool00`000000oooo0?ooo`2>0?ooo`00P03oool00`000000oooo0?ooo`04
0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool0SP3oool00800oooo00D000000?oo
o`3oool0oooo000000030?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0SP3oool0
07l0oooo0P0000030?ooo`050000003oool0oooo0?ooo`0000001P3oool00`000000oooo0?ooo`2>
0?ooo`00P03oool00`000000oooo0?ooo`020?ooo`<000001`3oool00`000000oooo0?ooo`2>0?oo
o`00O`3oool3000000@0oooo0`0000060?ooo`030000003oool0oooo08h0oooo00200?ooo`030000
003oool0oooo00@0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`2>0?ooo`00P03o
ool010000000oooo0?ooo`3oool5000000H0oooo00<000000?ooo`3oool0SP3oool00800oooo00D0
00000?ooo`3oool0oooo000000020?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool0
SP3oool00800oooo00<000000?ooo`3oool00P3oool00`000000oooo000000070?ooo`030000003o
ool0oooo08h0oooo001o0?ooo`8000001@3oool2000000L0oooo00<000000?ooo`3oool0SP3oool0
0800oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo
08h0oooo002?0?ooo`030000003oool0oooo08h0oooo001o0?ooo`<000000`3oool3000000L0oooo
00<000000?ooo`3oool0SP3oool00800oooo00D000000?ooo`3oool0oooo000000030?ooo`030000
003oool0oooo00@0oooo00<000000?ooo`3oool0SP3oool00800oooo00D000000?ooo`3oool0oooo
000000030?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0SP3oool00800oooo00@0
00000?ooo`3oool0oooo100000070?ooo`030000003oool0oooo08h0oooo00200?ooo`050000003o
ool0oooo0?ooo`0000002P3oool00`000000oooo0?ooo`2>0?ooo`00O`3oool2000000@0oooo00<0
00000?ooo`3oool01`3oool00`000000oooo0?ooo`2>0?ooo`00P03oool00`000000oooo0?ooo`03
0?ooo`8000001`3oool00`000000oooo0?ooo`2>0?ooo`00O`3oool3000000@0oooo00<000000?oo
o`3oool01P3oool00`000000oooo0?ooo`2>0?ooo`00P03oool00`000000oooo0?ooo`030?ooo`03
0000003oool0oooo00H0oooo00<000000?ooo`3oool0SP3oool00800oooo00<000000?ooo`3oool0
103oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo08h0oooo00200?ooo`030000003o
ool0oooo00@0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`2>0?ooo`00P03oool0
0`000000oooo0?ooo`050?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0SP3oool0
07l0oooo0P0000030?ooo`050000003oool0oooo0?ooo`0000001P3oool00`000000oooo0?ooo`2>
0?ooo`00P03oool010000000oooo0?ooo`3oool5000000H0oooo00<000000?ooo`3oool0SP3oool0
07l0oooo0`0000030?ooo`<000001`3oool00`000000oooo0?ooo`2>0?ooo`00P03oool01@000000
oooo0?ooo`3oool0000000<0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`2>0?oo
o`00P03oool01@000000oooo0?ooo`3oool0000000<0oooo00<000000?ooo`3oool0103oool00`00
0000oooo0?ooo`2>0?ooo`00P03oool00`000000oooo0?ooo`020?ooo`<000001`3oool00`000000
oooo0?ooo`2>0?ooo`00P03oool01@000000oooo0?ooo`3oool0000000<0oooo00<000000?ooo`3o
ool0103oool00`000000oooo0?ooo`2>0?ooo`00O`3oool2000000<0oooo00D000000?ooo`3oool0
oooo000000060?ooo`030000003oool0oooo08h0oooo00200?ooo`030000003oool0oooo0080oooo
0`0000070?ooo`030000003oool0oooo08h0oooo002?0?ooo`030000003oool0oooo08h0oooo001n
0?ooo`D000000`3oool2000000L0oooo00<000000?ooo`3oool0SP3oool007l0oooo00@000000?oo
o`3oool000000P3oool010000000oooo0?ooo`0000060?ooo`030000003oool0oooo08h0oooo0020
0?ooo`030000003oool0oooo0080oooo00@000000?ooo`3oool000001P3oool00`000000oooo0?oo
o`2>0?ooo`00P@3oool01@000000oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool0103o
ool00`000000oooo0?ooo`2>0?ooo`00OP3oool01@000000oooo0?ooo`3oool000000080oooo00@0
00000?ooo`3oool000001P3oool00`000000oooo0?ooo`2>0?ooo`00OP3oool01@000000oooo0?oo
o`3oool000000080oooo00@000000?ooo`3oool000001P3oool00`000000oooo0?ooo`2>0?ooo`00
O`3oool3000000@0oooo0P0000070?ooo`030000003oool0oooo08h0oooo001n0?ooo`D000000P3o
ool3000000L0oooo00<000000?ooo`3oool0SP3oool007l0oooo00@000000?ooo`3oool000000`3o
ool00`000000oooo0?ooo`060?ooo`030000003oool0oooo08h0oooo00200?ooo`030000003oool0
oooo00<0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`2>0?ooo`00P@3oool00`00
0000oooo0?ooo`020?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool0SP3oool007h0
oooo00D000000?ooo`3oool0oooo000000030?ooo`030000003oool0oooo00H0oooo00<000000?oo
o`3oool0SP3oool007h0oooo00D000000?ooo`3oool0oooo000000020?ooo`800000203oool00`00
0000oooo0?ooo`2>0?ooo`00O`3oool3000000@0oooo00<000000?ooo`3oool01P3oool00`000000
oooo0?ooo`2>0?ooo`00OP3oool500000080oooo0`0000070?ooo`030000003oool0oooo08h0oooo
001o0?ooo`060000003oool0oooo0000003oool000000`3oool00`000000oooo0?ooo`040?ooo`03
0000003oool0oooo08h0oooo00200?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool0
103oool00`000000oooo0?ooo`2>0?ooo`00P@3oool00`000000oooo0?ooo`020?ooo`8000001`3o
ool00`000000oooo0?ooo`2>0?ooo`00OP3oool01@000000oooo0?ooo`3oool0000000D0oooo00<0
00000?ooo`3oool0103oool00`000000oooo0?ooo`2>0?ooo`00OP3oool01`000000oooo0?ooo`3o
ool000000?ooo`0000000`3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo08h0oooo
001o0?ooo`<000000`3oool3000000L0oooo00<000000?ooo`3oool0SP3oool008l0oooo00<00000
0?ooo`3oool0SP3oool007h0oooo1@0000020?ooo`<000001`3oool00`000000oooo0?ooo`2>0?oo
o`00O`3oool01P000000oooo0?ooo`000000oooo000000<0oooo00<000000?ooo`3oool0103oool0
0`000000oooo0?ooo`2>0?ooo`00P03oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo
00@0oooo00<000000?ooo`3oool0SP3oool00840oooo00<000000?ooo`3oool0103oool00`000000
oooo0?ooo`040?ooo`030000003oool0oooo08h0oooo001n0?ooo`060000003oool0oooo0?ooo`00
0000oooo100000070?ooo`030000003oool0oooo08h0oooo001n0?ooo`070000003oool0oooo0?oo
o`000000oooo0000000:0?ooo`030000003oool0oooo08h0oooo001o0?ooo`<000000P3oool50000
00H0oooo00<000000?ooo`3oool0SP3oool007l0oooo0`0000030?ooo`<000001`3oool00`000000
oooo0?ooo`2>0?ooo`00OP3oool01`000000oooo0?ooo`3oool000000?ooo`0000000`3oool00`00
0000oooo0?ooo`040?ooo`030000003oool0oooo08h0oooo00220?ooo`030000003oool0000000<0
oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`2>0?ooo`00P03oool2000000<0oooo
0`0000070?ooo`030000003oool0oooo08h0oooo00220?ooo`030000003oool0000000<0oooo00<0
00000?ooo`3oool0103oool00`000000oooo0?ooo`2>0?ooo`00OP3oool01`000000oooo0?ooo`3o
ool000000?ooo`0000000`3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo08h0oooo
001o0?ooo`<000000`3oool3000000L0oooo00<000000?ooo`3oool0SP3oool008l0oooo00<00000
0?ooo`3oool0SP3oool00800oooo0`0000030?ooo`8000001`3oool00`000000oooo0?ooo`2>0?oo
o`00P@3oool01@000000oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool0103oool00`00
0000oooo0?ooo`2>0?ooo`00OP3oool500000080oooo00@000000?ooo`3oool000001P3oool00`00
0000oooo0?ooo`2>0?ooo`00OP3oool010000000oooo0?ooo`0000030?ooo`040000003oool0oooo
000000H0oooo00<000000?ooo`3oool0SP3oool007l0oooo00<000000?ooo`0000000`3oool01000
0000oooo0?ooo`0000060?ooo`030000003oool0oooo08h0oooo00200?ooo`8000000`3oool01000
0000oooo0?ooo`0000060?ooo`030000003oool0oooo08h0oooo00210?ooo`030000003oool0oooo
0080oooo0P0000070?ooo`030000003oool0oooo08h0oooo00200?ooo`<000000P3oool3000000L0
oooo00<000000?ooo`3oool0SP3oool00840oooo00<000000?ooo`3oool00P3oool00`000000oooo
0?ooo`060?ooo`030000003oool0oooo08h0oooo001n0?ooo`D000000`3oool00`000000oooo0?oo
o`060?ooo`030000003oool0oooo08h0oooo001n0?ooo`040000003oool0oooo000000@0oooo00<0
00000?ooo`3oool01P3oool00`000000oooo0?ooo`2>0?ooo`00O`3oool00`000000oooo00000004
0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool0SP3oool00800oooo0P0000030?oo
o`800000203oool00`000000oooo0?ooo`2>0?ooo`00P@3oool00`000000oooo0?ooo`020?ooo`03
0000003oool0oooo00H0oooo00<000000?ooo`3oool0SP3oool00800oooo0`0000030?ooo`<00000
1P3oool00`000000oooo0?ooo`2>0?ooo`00P@3oool00`000000oooo0?ooo`030?ooo`030000003o
ool0oooo00D0oooo00<000000?ooo`3oool0SP3oool007h0oooo1@0000000`3oool0000000000003
000000H0oooo00<000000?ooo`3oool0SP3oool007h0oooo00@000000?ooo`3oool000000P3oool0
10000000oooo0?ooo`0000070?ooo`030000003oool0oooo08h0oooo001o0?ooo`030000003oool0
000000<0oooo00<000000?ooo`0000001`3oool00`000000oooo0?ooo`2>0?ooo`00P03oool20000
00@0oooo0P0000070?ooo`030000003oool0oooo08h0oooo00210?ooo`030000003oool0oooo00<0
oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`2>0?ooo`00S`3oool00`000000oooo
0?ooo`2>0?ooo`00P03oool300000080oooo0`0000070?ooo`030000003oool0oooo08h0oooo0021
0?ooo`040000003oool0oooo000000<0oooo00<000000?ooo`3oool0103oool00`000000oooo0?oo
o`2>0?ooo`00OP3oool5000000D0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`2>
0?ooo`00OP3oool010000000oooo0?ooo`0000060?ooo`030000003oool0oooo00@0oooo00<00000
0?ooo`3oool0SP3oool007l0oooo00<000000?ooo`0000000P3oool4000000L0oooo00<000000?oo
o`3oool0SP3oool00800oooo0P0000020?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3o
ool0SP3oool00840oooo00<000000?ooo`3oool01@0000060?ooo`030000003oool0oooo08h0oooo
00200?ooo`<000000`3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo08h0oooo0021
0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`2>
0?ooo`00OP3oool5000000@0oooo00<000000?ooo`3oool0UP3oool007h0oooo00@000000?ooo`3o
ool000001@3oool00`000000oooo0?ooo`2F0?ooo`00O`3oool00`000000oooo000000060?ooo`03
0000003oool0oooo09D0oooo00200?ooo`8000000P3oool01@000000oooo0?ooo`3oool0000009L0
oooo00210?ooo`030000003oool0oooo00D00000U`3oool00?l0oooo8@3oool00?l0oooo8@3oool0
0001\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-1.0062, -1.00012, \
0.0174648, 0.135642}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.2 0.2 0.0247214 0.0247214 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
0 g
.5 Mabswid
[ ] 0 setdash
.4 .04944 m
.4 .02472 L
s
.4 .07416 m
.4 .04944 L
s
.7 .04944 m
.6 .02472 L
s
.7 .04944 m
.8 .02472 L
s
.6 .09889 m
.4 .07416 L
s
.6 .09889 m
.7 .04944 L
s
.6 .12361 m
.6 .09889 L
s
.6 .14833 m
.6 .12361 L
s
.6 .17305 m
.6 .14833 L
s
.5 .19777 m
.2 .02472 L
s
.5 .19777 m
.6 .17305 L
s
.5 .22249 m
.5 .19777 L
s
.5 .24721 m
.5 .22249 L
s
.5 .27193 m
.5 .24721 L
s
.5 .29666 m
.5 .27193 L
s
.5 .32138 m
.5 .29666 L
s
.5 .3461 m
.5 .32138 L
s
.5 .37082 m
.5 .3461 L
s
.5 .39554 m
.5 .37082 L
s
.5 .42026 m
.5 .39554 L
s
.5 .44498 m
.5 .42026 L
s
.5 .46971 m
.5 .44498 L
s
.5 .49443 m
.5 .46971 L
s
.5 .51915 m
.5 .49443 L
s
.5 .54387 m
.5 .51915 L
s
.5 .56859 m
.5 .54387 L
s
.5 .59331 m
.5 .56859 L
s
[(2)] .36 .05439 0 0 Mshowa
[(3)] .36 .07911 0 0 Mshowa
[(4)] .66 .05439 0 0 Mshowa
[(5)] .56 .10383 0 0 Mshowa
[(7)] .56 .12855 0 0 Mshowa
[(8)] .56 .15327 0 0 Mshowa
[(9)] .56 .17799 0 0 Mshowa
[(11)] .46 .20272 0 0 Mshowa
[(12)] .46 .22744 0 0 Mshowa
[(14)] .46 .25216 0 0 Mshowa
[(16)] .46 .27688 0 0 Mshowa
[(17)] .46 .3016 0 0 Mshowa
[(18)] .46 .32632 0 0 Mshowa
[(20)] .46 .35104 0 0 Mshowa
[(21)] .46 .37576 0 0 Mshowa
[(23)] .46 .40049 0 0 Mshowa
[(25)] .46 .42521 0 0 Mshowa
[(38)] .46 .44993 0 0 Mshowa
[(40)] .46 .47465 0 0 Mshowa
[(42)] .46 .49937 0 0 Mshowa
[(43)] .46 .52409 0 0 Mshowa
[(44)] .46 .54881 0 0 Mshowa
[(45)] .46 .57354 0 0 Mshowa
[(47)] .46 .59826 0 0 Mshowa
gsave
.2 .01978 -66 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(d) show
1.000 setlinewidth
grestore
gsave
.4 .01978 -66 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(b) show
1.000 setlinewidth
grestore
gsave
.6 .01978 -66 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(a) show
1.000 setlinewidth
grestore
gsave
.8 .01978 -66 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(c) show
1.000 setlinewidth
grestore
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[464]:=",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/B000`400?l00000o`00003oo`3ooolQ
0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00=`3oool4000003@0oooo1000000g0?ooo`@00000
=@3oool3000003X0oooo000f0?ooo`040000003oool0oooo000003H0oooo00@000000?ooo`3oool0
0000=@3oool010000000oooo0?ooo`00000e0?ooo`050000003oool0oooo0?ooo`000000>@3oool0
03H0oooo00@000000?ooo`3oool00000=P3oool010000000oooo0?ooo`00000f0?ooo`<00000=@3o
ool00`000000oooo0?ooo`0k0?ooo`00=P3oool010000000oooo0?ooo`00000f0?ooo`040000003o
ool0oooo000003D0oooo00@000000?ooo`3oool00000=@3oool01@000000oooo0?ooo`3oool00000
03T0oooo000g0?ooo`@00000=@3oool3000003L0oooo1@00000d0?ooo`<00000>P3oool003T0oooo
00@000000?ooo`0000000000<`3oool00`000000oooo0000000l0?ooo`@00000;03oool4000003d0
oooo000h0?ooo`8000000`3oool00`000000oooo0?ooo`0_0?ooo`80000000<0oooo0000003oool0
?`3oool4000002@0oooo100000110?ooo`00?P3oool200000380oooo00<000000?ooo`3oool0@P3o
ool4000001/0oooo1@0000150?ooo`00@03oool200000300oooo00<000000?ooo`3oool0AP3oool4
000001<0oooo1000001:0?ooo`00@P3oool2000002h0oooo00<000000?ooo`3oool0BP3oool40000
00/0oooo1000001>0?ooo`00A03oool00`000000oooo0?ooo`0M0?ooo`D000002@3oool00`000000
oooo0?ooo`170?ooo`<00000103oool4000000<0oooo1000001B0?ooo`00A@3oool2000001h0oooo
00@000000?ooo`3oool000002@3oool00`000000oooo0?ooo`180?ooo`030000003oool0oooo00L0
oooo0`00001F0?ooo`00A`3oool2000001d0oooo00<000000?ooo`3oool02@3oool00`000000oooo
0?ooo`150?ooo`D000001P3oool2000005T0oooo00190?ooo`800000703oool00`000000oooo0?oo
o`080?ooo`030000003oool0oooo04D0oooo00@000000?ooo`3oool000001@3oool2000005/0oooo
001;0?ooo`030000003oool0oooo01H0oooo00D000000?ooo`3oool0oooo000000090?ooo`030000
003oool0oooo04H0oooo00<000000?ooo`0000000`3oool2000005d0oooo001<0?ooo`8000005P3o
ool01@000000oooo0?ooo`3oool0000000T0oooo00<000000?ooo`3oool0A`3oool2000000030?oo
o`000000000005l0oooo001>0?ooo`8000005@3oool3000000X0oooo00<000000?ooo`3oool0B03o
ool200000640oooo001@0?ooo`8000004`3oool3000000X0oooo00<000000?ooo`3oool0AP3oool2
000006<0oooo001B0?ooo`030000003oool0oooo00l0oooo00D000000?ooo`3oool0oooo00000009
0?ooo`D00000@P3oool2000006D0oooo001C0?ooo`8000004`3oool00`000000oooo0?ooo`0<0?oo
o`P00000>03oool2000006L0oooo001E0?ooo`8000003`3oool2000001L0oooo2@00000]0?ooo`80
0000J@3oool005L0oooo0P00000?0?ooo`030000003oool0oooo01d0oooo2000000S0?ooo`800000
J`3oool005T0oooo00<000000?ooo`3oool0203oool01@000000oooo0?ooo`3oool0000002L0oooo
2000000I0?ooo`800000K@3oool005X0oooo0P0000090?ooo`<00000<03oool9000000h0oooo0P00
001_0?ooo`00G03oool200000400oooo2`0000040?ooo`800000L@3oool005h0oooo0P00000m0?oo
o`050000003oool0oooo0?ooo`0000001`3oool4000007<0oooo001P0?ooo`030000003oool0oooo
03h0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`1a0?ooo`00H@3oool2000003h0
oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`1a0?ooo`00H`3oool2000003P0oooo
1000000;0?ooo`030000003oool0oooo0740oooo001U0?ooo`800000=P3oool00`000000oooo0?oo
o`0<0?ooo`030000003oool0oooo0740oooo001W0?ooo`800000=03oool5000000X0oooo00<00000
0?ooo`3oool0L@3oool006T0oooo00<000000?ooo`3oool0<`3oool00`000000oooo0?ooo`0:0?oo
o`030000003oool0oooo0740oooo001Z0?ooo`800000<`3oool00`000000oooo0?ooo`0:0?ooo`03
0000003oool0oooo0740oooo001/0?ooo`800000<P3oool00`000000oooo0?ooo`090?ooo`030000
003oool0oooo0740oooo001^0?ooo`800000<03oool00`000000oooo0?ooo`090?ooo`030000003o
ool0oooo0740oooo001`0?ooo`030000003oool0oooo02h0oooo00<000000?ooo`3oool0203oool0
0`000000oooo0?ooo`1a0?ooo`00L@3oool2000002X0oooo00D000000?ooo`3oool0oooo0000000:
0?ooo`030000003oool0oooo0740oooo001c0?ooo`800000:03oool5000000X0oooo00<000000?oo
o`3oool0L@3oool007D0oooo0P00000W0?ooo`<000002`3oool00`000000oooo0?ooo`1a0?ooo`00
M`3oool00`000000oooo0?ooo`0S0?ooo`050000003oool0oooo0?ooo`0000002P3oool00`000000
oooo0?ooo`1a0?ooo`00N03oool2000002<0oooo00D000000?ooo`3oool0oooo0000000:0?ooo`03
0000003oool0oooo0740oooo001j0?ooo`8000008P3oool3000000/0oooo00<000000?ooo`3oool0
L@3oool007`0oooo0P00000O0?ooo`050000003oool0oooo0?ooo`0000002P3oool00`000000oooo
0?ooo`1a0?ooo`00OP3oool00`000000oooo0?ooo`0L0?ooo`050000003oool0oooo0?ooo`000000
2P3oool00`000000oooo0?ooo`1a0?ooo`00O`3oool2000001d0oooo0`00000;0?ooo`030000003o
ool0oooo0740oooo00210?ooo`8000006`3oool2000000`0oooo00<000000?ooo`3oool0L@3oool0
08<0oooo0P00000K0?ooo`030000003oool0oooo00L0oooo0`00001c0?ooo`00Q@3oool00`000000
oooo0?ooo`0I0?ooo`030000003oool0oooo0080oooo1000001f0?ooo`00QP3oool2000001H0oooo
2000001j0?ooo`00R03oool2000001<0oooo1@00001n0?ooo`00RP3oool2000000d0oooo1@000003
0?ooo`030000003oool0oooo07`0oooo002<0?ooo`030000003oool0oooo00H0oooo100000050?oo
o`<00000O`3oool007l0oooo0`0000030?ooo`<000001@3oool200000080oooo1000002;0?ooo`00
P03oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00H0oooo0P00002?0?ooo`00P03o
ool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool0SP3o
ool00800oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`060?ooo`030000003oool0
oooo08h0oooo00200?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool01P3oool00`00
0000oooo0?ooo`2>0?ooo`00O`3oool2000000@0oooo0P0000080?ooo`030000003oool0oooo08h0
oooo00200?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool01P3oool00`000000oooo
0?ooo`2>0?ooo`00O`3oool300000080oooo1@0000060?ooo`030000003oool0oooo08h0oooo0020
0?ooo`030000003oool0oooo0080oooo00@000000?ooo`3oool000001P3oool00`000000oooo0?oo
o`2>0?ooo`00P03oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00H0oooo00<00000
0?ooo`3oool0SP3oool00800oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`050?oo
o`030000003oool0oooo08h0oooo00200?ooo`050000003oool0oooo0?ooo`0000000`3oool00`00
0000oooo0?ooo`040?ooo`030000003oool0oooo08h0oooo001o0?ooo`8000000`3oool01@000000
oooo0?ooo`3oool0000000H0oooo00<000000?ooo`3oool0SP3oool00800oooo00<000000?ooo`3o
ool00P3oool3000000L0oooo00<000000?ooo`3oool0SP3oool007l0oooo0`0000040?ooo`<00000
1P3oool00`000000oooo0?ooo`2>0?ooo`00P03oool00`000000oooo0?ooo`040?ooo`030000003o
ool0oooo00D0oooo00<000000?ooo`3oool0SP3oool00800oooo00@000000?ooo`3oool0oooo1@00
00060?ooo`030000003oool0oooo08h0oooo00200?ooo`050000003oool0oooo0?ooo`0000000P3o
ool00`000000oooo0?ooo`050?ooo`030000003oool0oooo08h0oooo00200?ooo`030000003oool0
oooo0080oooo00<000000?ooo`0000001`3oool00`000000oooo0?ooo`2>0?ooo`00O`3oool20000
00D0oooo0P0000070?ooo`030000003oool0oooo08h0oooo00200?ooo`030000003oool0oooo00@0
oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`2>0?ooo`00O`3oool3000000<0oooo
0`0000070?ooo`030000003oool0oooo08h0oooo00200?ooo`050000003oool0oooo0?ooo`000000
0`3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo08h0oooo00200?ooo`050000003o
ool0oooo0?ooo`0000000`3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo08h0oooo
00200?ooo`040000003oool0oooo0?ooo`@000001`3oool00`000000oooo0?ooo`2>0?ooo`00P03o
ool01@000000oooo0?ooo`3oool0000000X0oooo00<000000?ooo`3oool0SP3oool007l0oooo0P00
00040?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool0SP3oool00800oooo00<00000
0?ooo`3oool00`3oool2000000L0oooo00<000000?ooo`3oool0SP3oool007l0oooo0`0000040?oo
o`030000003oool0oooo00H0oooo00<000000?ooo`3oool0SP3oool00800oooo00<000000?ooo`3o
ool00`3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo08h0oooo00200?ooo`030000
003oool0oooo00@0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`2>0?ooo`00P03o
ool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool0SP3o
ool00800oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`040?ooo`030000003oool0
oooo08h0oooo001o0?ooo`8000000`3oool01@000000oooo0?ooo`3oool0000000H0oooo00<00000
0?ooo`3oool0SP3oool00800oooo00@000000?ooo`3oool0oooo1@0000060?ooo`030000003oool0
oooo08h0oooo001o0?ooo`<000000`3oool3000000L0oooo00<000000?ooo`3oool0SP3oool00800
oooo00D000000?ooo`3oool0oooo000000030?ooo`030000003oool0oooo00@0oooo00<000000?oo
o`3oool0SP3oool00800oooo00D000000?ooo`3oool0oooo000000030?ooo`030000003oool0oooo
00@0oooo00<000000?ooo`3oool0SP3oool00800oooo00<000000?ooo`3oool00P3oool3000000L0
oooo00<000000?ooo`3oool0SP3oool00800oooo00D000000?ooo`3oool0oooo000000030?ooo`03
0000003oool0oooo00@0oooo00<000000?ooo`3oool0SP3oool007l0oooo0P0000030?ooo`050000
003oool0oooo0?ooo`0000001P3oool00`000000oooo0?ooo`2>0?ooo`00P03oool00`000000oooo
0?ooo`020?ooo`<000001`3oool00`000000oooo0?ooo`2>0?ooo`00S`3oool00`000000oooo0?oo
o`2>0?ooo`00OP3oool5000000<0oooo0P0000070?ooo`030000003oool0oooo08h0oooo001o0?oo
o`040000003oool0oooo00000080oooo00@000000?ooo`3oool000001P3oool00`000000oooo0?oo
o`2>0?ooo`00P03oool00`000000oooo0?ooo`020?ooo`040000003oool0oooo000000H0oooo00<0
00000?ooo`3oool0SP3oool00840oooo00D000000?ooo`3oool0oooo000000020?ooo`030000003o
ool0oooo00@0oooo00<000000?ooo`3oool0SP3oool007h0oooo00D000000?ooo`3oool0oooo0000
00020?ooo`040000003oool0oooo000000H0oooo00<000000?ooo`3oool0SP3oool007h0oooo00D0
00000?ooo`3oool0oooo000000020?ooo`040000003oool0oooo000000H0oooo00<000000?ooo`3o
ool0SP3oool007l0oooo0`0000040?ooo`8000001`3oool00`000000oooo0?ooo`2>0?ooo`00OP3o
ool500000080oooo0`0000070?ooo`030000003oool0oooo08h0oooo001o0?ooo`040000003oool0
oooo000000<0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`2>0?ooo`00P03oool0
0`000000oooo0?ooo`030?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool0SP3oool0
0840oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo
08h0oooo001n0?ooo`050000003oool0oooo0?ooo`0000000`3oool00`000000oooo0?ooo`060?oo
o`030000003oool0oooo08h0oooo001n0?ooo`050000003oool0oooo0?ooo`0000000P3oool20000
00P0oooo00<000000?ooo`3oool0SP3oool007l0oooo0`0000040?ooo`030000003oool0oooo00H0
oooo00<000000?ooo`3oool0SP3oool007h0oooo1@0000020?ooo`<000001`3oool00`000000oooo
0?ooo`2>0?ooo`00O`3oool01P000000oooo0?ooo`000000oooo000000<0oooo00<000000?ooo`3o
ool0103oool00`000000oooo0?ooo`2>0?ooo`00P03oool00`000000oooo0?ooo`050?ooo`030000
003oool0oooo00@0oooo00<000000?ooo`3oool0SP3oool00840oooo00<000000?ooo`3oool00P3o
ool2000000L0oooo00<000000?ooo`3oool0SP3oool007h0oooo00D000000?ooo`3oool0oooo0000
00050?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0SP3oool007h0oooo00L00000
0?ooo`3oool0oooo0000003oool0000000<0oooo00<000000?ooo`3oool0103oool00`000000oooo
0?ooo`2>0?ooo`00O`3oool3000000<0oooo0`0000070?ooo`030000003oool0oooo08h0oooo001n
0?ooo`D000000P3oool3000000L0oooo00<000000?ooo`3oool0SP3oool007l0oooo00H000000?oo
o`3oool000000?ooo`0000030?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0SP3o
ool00800oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`040?ooo`030000003oool0
oooo08h0oooo00210?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0103oool00`00
0000oooo0?ooo`2>0?ooo`00OP3oool01P000000oooo0?ooo`3oool000000?ooo`@000001`3oool0
0`000000oooo0?ooo`2>0?ooo`00OP3oool01`000000oooo0?ooo`3oool000000?ooo`0000002P3o
ool00`000000oooo0?ooo`2>0?ooo`00O`3oool300000080oooo1@0000060?ooo`030000003oool0
oooo08h0oooo001o0?ooo`<000000`3oool3000000L0oooo00<000000?ooo`3oool0SP3oool007h0
oooo00L000000?ooo`3oool0oooo0000003oool0000000<0oooo00<000000?ooo`3oool0103oool0
0`000000oooo0?ooo`2>0?ooo`00PP3oool00`000000oooo000000030?ooo`030000003oool0oooo
00@0oooo00<000000?ooo`3oool0SP3oool00800oooo0P0000030?ooo`<000001`3oool00`000000
oooo0?ooo`2>0?ooo`00PP3oool00`000000oooo000000030?ooo`030000003oool0oooo00@0oooo
00<000000?ooo`3oool0SP3oool007h0oooo00L000000?ooo`3oool0oooo0000003oool0000000<0
oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`2>0?ooo`00O`3oool3000000<0oooo
0`0000070?ooo`030000003oool0oooo08h0oooo00200?ooo`<000000`3oool2000000L0oooo00<0
00000?ooo`3oool0SP3oool00840oooo00D000000?ooo`3oool0oooo000000020?ooo`030000003o
ool0oooo00@0oooo00<000000?ooo`3oool0SP3oool007h0oooo1@0000020?ooo`040000003oool0
oooo000000H0oooo00<000000?ooo`3oool0SP3oool007h0oooo00@000000?ooo`3oool000000`3o
ool010000000oooo0?ooo`0000060?ooo`030000003oool0oooo08h0oooo001o0?ooo`030000003o
ool0000000<0oooo00@000000?ooo`3oool000001P3oool00`000000oooo0?ooo`2>0?ooo`00P03o
ool2000000<0oooo00@000000?ooo`3oool000001P3oool00`000000oooo0?ooo`2>0?ooo`00P@3o
ool00`000000oooo0?ooo`020?ooo`8000001`3oool00`000000oooo0?ooo`2>0?ooo`00P03oool3
000000030?ooo`000000000000<000001P3oool00`000000oooo0?ooo`2>0?ooo`00P@3oool01@00
0000oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`2>
0?ooo`00OP3oool5000000<0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`2>0?oo
o`00OP3oool010000000oooo0?ooo`0000050?ooo`030000003oool0oooo00D0oooo00<000000?oo
o`3oool0SP3oool007l0oooo00<000000?ooo`0000000P3oool01@000000oooo0?ooo`3oool00000
00H0oooo00<000000?ooo`3oool0SP3oool00800oooo0P0000020?ooo`050000003oool0oooo0?oo
o`0000001P3oool00`000000oooo0?ooo`2>0?ooo`00P@3oool010000000oooo0?ooo`3oool30000
00L0oooo00<000000?ooo`3oool0SP3oool00800oooo0`0000020?ooo`<000001`3oool00`000000
oooo0?ooo`2>0?ooo`00P@3oool010000000oooo0?ooo`0000030?ooo`030000003oool0oooo00@0
oooo00<000000?ooo`3oool0SP3oool007h0oooo1@0000050?ooo`030000003oool0oooo00@0oooo
00<000000?ooo`3oool0SP3oool007h0oooo00@000000?ooo`3oool00000103oool2000000L0oooo
00<000000?ooo`3oool0SP3oool007l0oooo00<000000?ooo`0000001P3oool00`000000oooo0?oo
o`040?ooo`030000003oool0oooo08h0oooo00200?ooo`8000000P3oool01@000000oooo0?ooo`3o
ool0000000H0oooo00<000000?ooo`3oool0SP3oool00840oooo00@000000?ooo`3oool0oooo0`00
00070?ooo`030000003oool0oooo08h0oooo00200?ooo`<000000`3oool3000000H0oooo00<00000
0?ooo`3oool0SP3oool00840oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`050?oo
o`030000003oool0oooo08h0oooo001n0?ooo`D0000000<0oooo0000000000000`0000060?ooo`03
0000003oool0oooo08h0oooo001n0?ooo`040000003oool0oooo00000080oooo00@000000?ooo`3o
ool000001`3oool00`000000oooo0?ooo`2>0?ooo`00O`3oool00`000000oooo000000030?ooo`03
0000003oool0000000L0oooo00<000000?ooo`3oool0SP3oool00800oooo0P0000040?ooo`800000
1`3oool00`000000oooo0?ooo`2>0?ooo`00P@3oool00`000000oooo0?ooo`030?ooo`030000003o
ool0oooo00D0oooo00<000000?ooo`3oool0SP3oool00800oooo0`0000020?ooo`<000001`3oool0
0`000000oooo0?ooo`2>0?ooo`00P@3oool010000000oooo0?ooo`0000030?ooo`030000003oool0
oooo00@0oooo00<000000?ooo`3oool0SP3oool007h0oooo1@0000050?ooo`030000003oool0oooo
00@0oooo00<000000?ooo`3oool0SP3oool007h0oooo00@000000?ooo`3oool000001P3oool00`00
0000oooo0?ooo`040?ooo`030000003oool0oooo08h0oooo001o0?ooo`030000003oool000000080
oooo100000070?ooo`030000003oool0oooo08h0oooo00200?ooo`8000000P3oool00`000000oooo
0?ooo`080?ooo`030000003oool0oooo08h0oooo00210?ooo`030000003oool0oooo00D000001P3o
ool00`000000oooo0?ooo`2>0?ooo`00P03oool3000000<0oooo00<000000?ooo`3oool01P3oool0
0`000000oooo0?ooo`2>0?ooo`00P@3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo
00H0oooo00<000000?ooo`3oool0SP3oool007h0oooo1@0000040?ooo`030000003oool0oooo09H0
oooo001n0?ooo`040000003oool0oooo000000D0oooo00<000000?ooo`3oool0UP3oool007l0oooo
00<000000?ooo`0000001P3oool00`000000oooo0?ooo`2E0?ooo`00P03oool200000080oooo00D0
00000?ooo`3oool0oooo0000002G0?ooo`00P@3oool00`000000oooo0?ooo`05000009L0oooo003o
0?ooob40oooo003o0?ooob40oooo0000\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-1.0062, -1.00013, \
0.0174648, 0.141293}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.2 0.2 0.0247214 0.0247214 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
0 g
.5 Mabswid
[ ] 0 setdash
.4 .04944 m
.4 .02472 L
s
.4 .07416 m
.4 .04944 L
s
.7 .04944 m
.6 .02472 L
s
.7 .04944 m
.8 .02472 L
s
.6 .09889 m
.4 .07416 L
s
.6 .09889 m
.7 .04944 L
s
.6 .12361 m
.6 .09889 L
s
.6 .14833 m
.6 .12361 L
s
.6 .17305 m
.6 .14833 L
s
.5 .19777 m
.2 .02472 L
s
.5 .19777 m
.6 .17305 L
s
.5 .22249 m
.5 .19777 L
s
.5 .24721 m
.5 .22249 L
s
.5 .27193 m
.5 .24721 L
s
.5 .29666 m
.5 .27193 L
s
.5 .32138 m
.5 .29666 L
s
.5 .3461 m
.5 .32138 L
s
.5 .37082 m
.5 .3461 L
s
.5 .39554 m
.5 .37082 L
s
.5 .42026 m
.5 .39554 L
s
.5 .44498 m
.5 .42026 L
s
.5 .46971 m
.5 .44498 L
s
.5 .49443 m
.5 .46971 L
s
.5 .51915 m
.5 .49443 L
s
.5 .54387 m
.5 .51915 L
s
.5 .56859 m
.5 .54387 L
s
.5 .59331 m
.5 .56859 L
s
[(2)] .36 .05439 0 0 Mshowa
[(3)] .36 .07911 0 0 Mshowa
[(4)] .66 .05439 0 0 Mshowa
[(5)] .56 .10383 0 0 Mshowa
[(7)] .56 .12855 0 0 Mshowa
[(8)] .56 .15327 0 0 Mshowa
[(9)] .56 .17799 0 0 Mshowa
[(11)] .46 .20272 0 0 Mshowa
[(12)] .46 .22744 0 0 Mshowa
[(14)] .46 .25216 0 0 Mshowa
[(16)] .46 .27688 0 0 Mshowa
[(17)] .46 .3016 0 0 Mshowa
[(19)] .46 .32632 0 0 Mshowa
[(20)] .46 .35104 0 0 Mshowa
[(21)] .46 .37576 0 0 Mshowa
[(23)] .46 .40049 0 0 Mshowa
[(25)] .46 .42521 0 0 Mshowa
[(38)] .46 .44993 0 0 Mshowa
[(40)] .46 .47465 0 0 Mshowa
[(42)] .46 .49937 0 0 Mshowa
[(43)] .46 .52409 0 0 Mshowa
[(44)] .46 .54881 0 0 Mshowa
[(45)] .46 .57354 0 0 Mshowa
[(47)] .46 .59826 0 0 Mshowa
gsave
.2 .01978 -66 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(d) show
1.000 setlinewidth
grestore
gsave
.4 .01978 -66 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(b) show
1.000 setlinewidth
grestore
gsave
.6 .01978 -66 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(a) show
1.000 setlinewidth
grestore
gsave
.8 .01978 -66 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(c) show
1.000 setlinewidth
grestore
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[464]:=",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/B000`400?l00000o`00003oo`3ooolQ
0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00=`3oool4000003@0oooo1000000g0?ooo`@00000
=@3oool3000003X0oooo000f0?ooo`040000003oool0oooo000003H0oooo00@000000?ooo`3oool0
0000=@3oool010000000oooo0?ooo`00000e0?ooo`050000003oool0oooo0?ooo`000000>@3oool0
03H0oooo00@000000?ooo`3oool00000=P3oool010000000oooo0?ooo`00000f0?ooo`<00000=@3o
ool00`000000oooo0?ooo`0k0?ooo`00=P3oool010000000oooo0?ooo`00000f0?ooo`040000003o
ool0oooo000003D0oooo00@000000?ooo`3oool00000=@3oool01@000000oooo0?ooo`3oool00000
03T0oooo000g0?ooo`@00000=@3oool3000003L0oooo1@00000d0?ooo`<00000>P3oool003T0oooo
00@000000?ooo`0000000000<`3oool00`000000oooo0000000l0?ooo`@00000;03oool4000003d0
oooo000h0?ooo`8000000`3oool00`000000oooo0?ooo`0_0?ooo`80000000<0oooo0000003oool0
?`3oool4000002@0oooo100000110?ooo`00?P3oool200000380oooo00<000000?ooo`3oool0@P3o
ool4000001/0oooo1@0000150?ooo`00@03oool200000300oooo00<000000?ooo`3oool0AP3oool4
000001<0oooo1000001:0?ooo`00@P3oool2000002h0oooo00<000000?ooo`3oool0BP3oool40000
00/0oooo1000001>0?ooo`00A03oool00`000000oooo0?ooo`0M0?ooo`D000002@3oool00`000000
oooo0?ooo`170?ooo`<00000103oool4000000<0oooo1000001B0?ooo`00A@3oool2000001h0oooo
00@000000?ooo`3oool000002@3oool00`000000oooo0?ooo`180?ooo`030000003oool0oooo00L0
oooo0`00001F0?ooo`00A`3oool2000001d0oooo00<000000?ooo`3oool02@3oool00`000000oooo
0?ooo`150?ooo`D000001P3oool2000005T0oooo00190?ooo`800000703oool00`000000oooo0?oo
o`080?ooo`030000003oool0oooo04D0oooo00@000000?ooo`3oool000001@3oool2000005/0oooo
001;0?ooo`030000003oool0oooo01H0oooo00D000000?ooo`3oool0oooo000000090?ooo`030000
003oool0oooo04H0oooo00<000000?ooo`0000000`3oool2000005d0oooo001<0?ooo`8000005P3o
ool01@000000oooo0?ooo`3oool0000000T0oooo00<000000?ooo`3oool0A`3oool2000000030?oo
o`000000000005l0oooo001>0?ooo`8000005@3oool3000000X0oooo00<000000?ooo`3oool0B03o
ool200000640oooo001@0?ooo`8000004`3oool3000000X0oooo00<000000?ooo`3oool0AP3oool2
000006<0oooo001B0?ooo`030000003oool0oooo00l0oooo00D000000?ooo`3oool0oooo00000009
0?ooo`D00000@P3oool2000006D0oooo001C0?ooo`8000004`3oool00`000000oooo0?ooo`0<0?oo
o`P00000>03oool2000006L0oooo001E0?ooo`8000003`3oool2000001L0oooo2@00000]0?ooo`80
0000J@3oool005L0oooo0P00000?0?ooo`030000003oool0oooo01d0oooo2000000S0?ooo`800000
J`3oool005T0oooo00<000000?ooo`3oool0203oool01@000000oooo0?ooo`3oool0000002L0oooo
2000000I0?ooo`800000K@3oool005X0oooo0P0000090?ooo`<00000<03oool9000000h0oooo0P00
001_0?ooo`00G03oool200000400oooo2`0000040?ooo`800000L@3oool005h0oooo0P00000m0?oo
o`050000003oool0oooo0?ooo`0000001`3oool4000007<0oooo001P0?ooo`030000003oool0oooo
03h0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`1a0?ooo`00H@3oool2000003h0
oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`1a0?ooo`00H`3oool2000003P0oooo
1000000;0?ooo`030000003oool0oooo0740oooo001U0?ooo`800000=P3oool00`000000oooo0?oo
o`0<0?ooo`030000003oool0oooo0740oooo001W0?ooo`800000=03oool5000000X0oooo00<00000
0?ooo`3oool0L@3oool006T0oooo00<000000?ooo`3oool0<`3oool00`000000oooo0?ooo`0:0?oo
o`030000003oool0oooo0740oooo001Z0?ooo`800000<`3oool00`000000oooo0?ooo`0:0?ooo`03
0000003oool0oooo0740oooo001/0?ooo`800000<P3oool00`000000oooo0?ooo`090?ooo`030000
003oool0oooo0740oooo001^0?ooo`800000<03oool00`000000oooo0?ooo`090?ooo`030000003o
ool0oooo0740oooo001`0?ooo`030000003oool0oooo02h0oooo00<000000?ooo`3oool0203oool0
0`000000oooo0?ooo`1a0?ooo`00L@3oool2000002X0oooo00D000000?ooo`3oool0oooo0000000:
0?ooo`030000003oool0oooo0740oooo001c0?ooo`800000:03oool5000000X0oooo00<000000?oo
o`3oool0L@3oool007D0oooo0P00000W0?ooo`<000002`3oool00`000000oooo0?ooo`1a0?ooo`00
M`3oool00`000000oooo0?ooo`0S0?ooo`050000003oool0oooo0?ooo`0000002P3oool00`000000
oooo0?ooo`1a0?ooo`00N03oool2000002<0oooo00D000000?ooo`3oool0oooo0000000:0?ooo`03
0000003oool0oooo0740oooo001j0?ooo`8000008P3oool3000000/0oooo00<000000?ooo`3oool0
L@3oool007`0oooo0P00000O0?ooo`050000003oool0oooo0?ooo`0000002P3oool00`000000oooo
0?ooo`1a0?ooo`00OP3oool00`000000oooo0?ooo`0L0?ooo`050000003oool0oooo0?ooo`000000
2P3oool00`000000oooo0?ooo`1a0?ooo`00O`3oool2000001d0oooo0`00000;0?ooo`030000003o
ool0oooo0740oooo00210?ooo`8000006`3oool2000000`0oooo00<000000?ooo`3oool0L@3oool0
08<0oooo0P00000K0?ooo`030000003oool0oooo00L0oooo0`00001c0?ooo`00Q@3oool00`000000
oooo0?ooo`0I0?ooo`030000003oool0oooo0080oooo1000001f0?ooo`00QP3oool2000001H0oooo
2000001j0?ooo`00R03oool2000001<0oooo1@00001n0?ooo`00RP3oool2000000d0oooo1@000003
0?ooo`030000003oool0oooo07`0oooo002<0?ooo`030000003oool0oooo00H0oooo100000050?oo
o`<00000O`3oool007l0oooo0`0000030?ooo`<000001@3oool200000080oooo1000002;0?ooo`00
P03oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00H0oooo0P00002?0?ooo`00P03o
ool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool0SP3o
ool00800oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`060?ooo`030000003oool0
oooo08h0oooo00200?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool01P3oool00`00
0000oooo0?ooo`2>0?ooo`00O`3oool2000000@0oooo0P0000080?ooo`030000003oool0oooo08h0
oooo00200?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool01P3oool00`000000oooo
0?ooo`2>0?ooo`00O`3oool300000080oooo1@0000060?ooo`030000003oool0oooo08h0oooo0020
0?ooo`030000003oool0oooo0080oooo00@000000?ooo`3oool000001P3oool00`000000oooo0?oo
o`2>0?ooo`00P03oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00H0oooo00<00000
0?ooo`3oool0SP3oool00800oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`050?oo
o`030000003oool0oooo08h0oooo00200?ooo`050000003oool0oooo0?ooo`0000000`3oool00`00
0000oooo0?ooo`040?ooo`030000003oool0oooo08h0oooo001o0?ooo`8000000`3oool01@000000
oooo0?ooo`3oool0000000H0oooo00<000000?ooo`3oool0SP3oool00800oooo00<000000?ooo`3o
ool00P3oool3000000L0oooo00<000000?ooo`3oool0SP3oool007l0oooo0`0000040?ooo`<00000
1P3oool00`000000oooo0?ooo`2>0?ooo`00P03oool00`000000oooo0?ooo`040?ooo`030000003o
ool0oooo00D0oooo00<000000?ooo`3oool0SP3oool00800oooo00@000000?ooo`3oool0oooo1@00
00060?ooo`030000003oool0oooo08h0oooo00200?ooo`050000003oool0oooo0?ooo`0000000P3o
ool00`000000oooo0?ooo`050?ooo`030000003oool0oooo08h0oooo00200?ooo`030000003oool0
oooo0080oooo00<000000?ooo`0000001`3oool00`000000oooo0?ooo`2>0?ooo`00O`3oool20000
00D0oooo0P0000070?ooo`030000003oool0oooo08h0oooo00200?ooo`030000003oool0oooo00@0
oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`2>0?ooo`00O`3oool3000000<0oooo
0`0000070?ooo`030000003oool0oooo08h0oooo00200?ooo`050000003oool0oooo0?ooo`000000
0`3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo08h0oooo00200?ooo`050000003o
ool0oooo0?ooo`0000000`3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo08h0oooo
00200?ooo`040000003oool0oooo0?ooo`@000001`3oool00`000000oooo0?ooo`2>0?ooo`00P03o
ool01@000000oooo0?ooo`3oool0000000X0oooo00<000000?ooo`3oool0SP3oool007l0oooo0P00
00040?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool0SP3oool00800oooo00<00000
0?ooo`3oool00`3oool2000000L0oooo00<000000?ooo`3oool0SP3oool007l0oooo0`0000040?oo
o`030000003oool0oooo00H0oooo00<000000?ooo`3oool0SP3oool00800oooo00<000000?ooo`3o
ool00`3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo08h0oooo00200?ooo`030000
003oool0oooo00@0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`2>0?ooo`00P03o
ool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool0SP3o
ool00800oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`040?ooo`030000003oool0
oooo08h0oooo001o0?ooo`8000000`3oool01@000000oooo0?ooo`3oool0000000H0oooo00<00000
0?ooo`3oool0SP3oool00800oooo00@000000?ooo`3oool0oooo1@0000060?ooo`030000003oool0
oooo08h0oooo001o0?ooo`<000000`3oool2000000P0oooo00<000000?ooo`3oool0SP3oool00800
oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo08h0
oooo00200?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool0103oool00`000000oooo
0?ooo`2>0?ooo`00P03oool00`000000oooo0?ooo`020?ooo`@000001P3oool00`000000oooo0?oo
o`2>0?ooo`00P03oool01@000000oooo0?ooo`3oool0000000<0oooo00<000000?ooo`3oool0103o
ool00`000000oooo0?ooo`2>0?ooo`00O`3oool2000000<0oooo00D000000?ooo`3oool0oooo0000
00060?ooo`030000003oool0oooo08h0oooo00200?ooo`030000003oool0oooo0080oooo0`000007
0?ooo`030000003oool0oooo08h0oooo002?0?ooo`030000003oool0oooo08h0oooo001n0?ooo`D0
00000`3oool2000000L0oooo00<000000?ooo`3oool0SP3oool007l0oooo00@000000?ooo`3oool0
00000P3oool010000000oooo0?ooo`0000060?ooo`030000003oool0oooo08h0oooo00200?ooo`03
0000003oool0oooo0080oooo00@000000?ooo`3oool000001P3oool00`000000oooo0?ooo`2>0?oo
o`00P@3oool01@000000oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool0103oool00`00
0000oooo0?ooo`2>0?ooo`00OP3oool01@000000oooo0?ooo`3oool000000080oooo00@000000?oo
o`3oool000001P3oool00`000000oooo0?ooo`2>0?ooo`00OP3oool01@000000oooo0?ooo`3oool0
00000080oooo00@000000?ooo`3oool000001P3oool00`000000oooo0?ooo`2>0?ooo`00O`3oool3
000000@0oooo0P0000070?ooo`030000003oool0oooo08h0oooo001n0?ooo`D000000P3oool30000
00L0oooo00<000000?ooo`3oool0SP3oool007l0oooo00@000000?ooo`3oool000000`3oool00`00
0000oooo0?ooo`060?ooo`030000003oool0oooo08h0oooo00200?ooo`030000003oool0oooo00<0
oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`2>0?ooo`00P@3oool00`000000oooo
0?ooo`020?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool0SP3oool007h0oooo00D0
00000?ooo`3oool0oooo000000030?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool0
SP3oool007h0oooo00D000000?ooo`3oool0oooo000000020?ooo`800000203oool00`000000oooo
0?ooo`2>0?ooo`00O`3oool3000000@0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?oo
o`2>0?ooo`00OP3oool500000080oooo0`0000070?ooo`030000003oool0oooo08h0oooo001o0?oo
o`060000003oool0oooo0000003oool000000`3oool00`000000oooo0?ooo`040?ooo`030000003o
ool0oooo08h0oooo00200?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool0103oool0
0`000000oooo0?ooo`2>0?ooo`00P@3oool00`000000oooo0?ooo`020?ooo`8000001`3oool00`00
0000oooo0?ooo`2>0?ooo`00OP3oool01@000000oooo0?ooo`3oool0000000D0oooo00<000000?oo
o`3oool0103oool00`000000oooo0?ooo`2>0?ooo`00OP3oool01`000000oooo0?ooo`3oool00000
0?ooo`0000000`3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo08h0oooo001o0?oo
o`<000000`3oool3000000L0oooo00<000000?ooo`3oool0SP3oool007h0oooo1@0000020?ooo`<0
00001`3oool00`000000oooo0?ooo`2>0?ooo`00O`3oool01P000000oooo0?ooo`000000oooo0000
00<0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`2>0?ooo`00P03oool00`000000
oooo0?ooo`050?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0SP3oool00840oooo
00<000000?ooo`3oool0103oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo08h0oooo
001n0?ooo`060000003oool0oooo0?ooo`000000oooo100000070?ooo`030000003oool0oooo08h0
oooo001n0?ooo`070000003oool0oooo0?ooo`000000oooo0000000:0?ooo`030000003oool0oooo
08h0oooo001o0?ooo`<000000P3oool5000000H0oooo00<000000?ooo`3oool0SP3oool007l0oooo
0`0000030?ooo`<000001`3oool00`000000oooo0?ooo`2>0?ooo`00OP3oool01`000000oooo0?oo
o`3oool000000?ooo`0000000`3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo08h0
oooo00220?ooo`030000003oool0000000<0oooo00<000000?ooo`3oool0103oool00`000000oooo
0?ooo`2>0?ooo`00P03oool2000000<0oooo0`0000070?ooo`030000003oool0oooo08h0oooo0022
0?ooo`030000003oool0000000<0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`2>
0?ooo`00OP3oool01`000000oooo0?ooo`3oool000000?ooo`0000000`3oool00`000000oooo0?oo
o`040?ooo`030000003oool0oooo08h0oooo001o0?ooo`<000000`3oool3000000L0oooo00<00000
0?ooo`3oool0SP3oool00800oooo0`0000030?ooo`8000001`3oool00`000000oooo0?ooo`2>0?oo
o`00P@3oool01@000000oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool0103oool00`00
0000oooo0?ooo`2>0?ooo`00OP3oool500000080oooo00@000000?ooo`3oool000001P3oool00`00
0000oooo0?ooo`2>0?ooo`00OP3oool010000000oooo0?ooo`0000030?ooo`040000003oool0oooo
000000H0oooo00<000000?ooo`3oool0SP3oool007l0oooo00<000000?ooo`0000000`3oool01000
0000oooo0?ooo`0000060?ooo`030000003oool0oooo08h0oooo00200?ooo`8000000`3oool01000
0000oooo0?ooo`0000060?ooo`030000003oool0oooo08h0oooo00210?ooo`030000003oool0oooo
0080oooo0P0000070?ooo`030000003oool0oooo08h0oooo00200?ooo`<0000000<0oooo00000000
00000`0000060?ooo`030000003oool0oooo08h0oooo00210?ooo`050000003oool0oooo0?ooo`00
00000P3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo08h0oooo001n0?ooo`D00000
0`3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo08h0oooo001n0?ooo`040000003o
ool0oooo000000D0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`2>0?ooo`00O`3o
ool00`000000oooo000000020?ooo`050000003oool0oooo0?ooo`0000001P3oool00`000000oooo
0?ooo`2>0?ooo`00P03oool200000080oooo00D000000?ooo`3oool0oooo000000060?ooo`030000
003oool0oooo08h0oooo00210?ooo`040000003oool0oooo0?ooo`<000001`3oool00`000000oooo
0?ooo`2>0?ooo`00P03oool300000080oooo0`0000070?ooo`030000003oool0oooo08h0oooo0021
0?ooo`040000003oool0oooo000000<0oooo00<000000?ooo`3oool0103oool00`000000oooo0?oo
o`2>0?ooo`00OP3oool5000000D0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`2>
0?ooo`00OP3oool010000000oooo0?ooo`0000040?ooo`8000001`3oool00`000000oooo0?ooo`2>
0?ooo`00O`3oool00`000000oooo000000060?ooo`030000003oool0oooo00@0oooo00<000000?oo
o`3oool0SP3oool00800oooo0P0000020?ooo`050000003oool0oooo0?ooo`0000001P3oool00`00
0000oooo0?ooo`2>0?ooo`00P@3oool010000000oooo0?ooo`3oool3000000L0oooo00<000000?oo
o`3oool0SP3oool00800oooo0`0000030?ooo`<000001P3oool00`000000oooo0?ooo`2>0?ooo`00
P@3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool0
SP3oool007h0oooo1@0000000`3oool0000000000003000000H0oooo00<000000?ooo`3oool0SP3o
ool007h0oooo00@000000?ooo`3oool000000P3oool010000000oooo0?ooo`0000070?ooo`030000
003oool0oooo08h0oooo001o0?ooo`030000003oool0000000<0oooo00<000000?ooo`0000001`3o
ool00`000000oooo0?ooo`2>0?ooo`00P03oool2000000@0oooo0P0000070?ooo`030000003oool0
oooo08h0oooo00210?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool01@3oool00`00
0000oooo0?ooo`2>0?ooo`00P03oool300000080oooo0`0000070?ooo`030000003oool0oooo08h0
oooo00210?ooo`040000003oool0oooo000000<0oooo00<000000?ooo`3oool0103oool00`000000
oooo0?ooo`2>0?ooo`00OP3oool5000000D0oooo00<000000?ooo`3oool0103oool00`000000oooo
0?ooo`2>0?ooo`00OP3oool010000000oooo0?ooo`0000060?ooo`030000003oool0oooo00@0oooo
00<000000?ooo`3oool0SP3oool007l0oooo00<000000?ooo`0000000P3oool4000000L0oooo00<0
00000?ooo`3oool0SP3oool00800oooo0P0000020?ooo`030000003oool0oooo00P0oooo00<00000
0?ooo`3oool0SP3oool00840oooo00<000000?ooo`3oool01@0000060?ooo`030000003oool0oooo
08h0oooo00200?ooo`<000000`3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo08h0
oooo00210?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool01P3oool00`000000oooo
0?ooo`2>0?ooo`00OP3oool5000000@0oooo00<000000?ooo`3oool0UP3oool007h0oooo00@00000
0?ooo`3oool000001@3oool00`000000oooo0?ooo`2F0?ooo`00O`3oool00`000000oooo00000006
0?ooo`030000003oool0oooo09D0oooo00200?ooo`8000000P3oool01@000000oooo0?ooo`3oool0
000009L0oooo00210?ooo`030000003oool0oooo00D00000U`3oool00?l0oooo8@3oool00?l0oooo
8@3oool00001\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-1.0062, -1.00013, \
0.0174648, 0.141293}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.2 0.2 0.0294302 0.0294302 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
0 g
.5 Mabswid
[ ] 0 setdash
.4 .05886 m
.4 .02943 L
s
.4 .08829 m
.4 .05886 L
s
.7 .05886 m
.6 .02943 L
s
.7 .05886 m
.8 .02943 L
s
.6 .11772 m
.4 .08829 L
s
.6 .11772 m
.7 .05886 L
s
.6 .14715 m
.6 .11772 L
s
.6 .17658 m
.6 .14715 L
s
.6 .20601 m
.6 .17658 L
s
.2 .05886 m
.2 .02943 L
s
.2 .08829 m
.2 .05886 L
s
.2 .11772 m
.2 .08829 L
s
.2 .14715 m
.2 .11772 L
s
.2 .17658 m
.2 .14715 L
s
.2 .20601 m
.2 .17658 L
s
.2 .23544 m
.2 .20601 L
s
.2 .26487 m
.2 .23544 L
s
.2 .2943 m
.2 .26487 L
s
.2 .32373 m
.2 .2943 L
s
.6 .23544 m
.6 .20601 L
s
.6 .26487 m
.6 .23544 L
s
.6 .2943 m
.6 .26487 L
s
.6 .32373 m
.6 .2943 L
s
.6 .35316 m
.6 .32373 L
s
.6 .38259 m
.6 .35316 L
s
.5 .41202 m
.2 .32373 L
s
.5 .41202 m
.6 .38259 L
s
.5 .44145 m
.5 .41202 L
s
.5 .47088 m
.5 .44145 L
s
.5 .50031 m
.5 .47088 L
s
.5 .52974 m
.5 .50031 L
s
.5 .55917 m
.5 .52974 L
s
.5 .5886 m
.5 .55917 L
s
[(2)] .36 .06475 0 0 Mshowa
[(3)] .36 .09418 0 0 Mshowa
[(4)] .66 .06475 0 0 Mshowa
[(5)] .56 .12361 0 0 Mshowa
[(7)] .56 .15304 0 0 Mshowa
[(8)] .56 .18247 0 0 Mshowa
[(10)] .56 .2119 0 0 Mshowa
[(11)] .16 .06475 0 0 Mshowa
[(12)] .16 .09418 0 0 Mshowa
[(14)] .16 .12361 0 0 Mshowa
[(16)] .16 .15304 0 0 Mshowa
[(17)] .16 .18247 0 0 Mshowa
[(19)] .16 .2119 0 0 Mshowa
[(20)] .16 .24133 0 0 Mshowa
[(21)] .16 .27076 0 0 Mshowa
[(23)] .16 .30019 0 0 Mshowa
[(25)] .16 .32962 0 0 Mshowa
[(28)] .56 .24133 0 0 Mshowa
[(30)] .56 .27076 0 0 Mshowa
[(32)] .56 .30019 0 0 Mshowa
[(34)] .56 .32962 0 0 Mshowa
[(36)] .56 .35905 0 0 Mshowa
[(37)] .56 .38848 0 0 Mshowa
[(38)] .46 .41791 0 0 Mshowa
[(40)] .46 .44734 0 0 Mshowa
[(42)] .46 .47677 0 0 Mshowa
[(43)] .46 .5062 0 0 Mshowa
[(44)] .46 .53563 0 0 Mshowa
[(45)] .46 .56506 0 0 Mshowa
[(47)] .46 .59449 0 0 Mshowa
gsave
.2 .02354 -66 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(d) show
1.000 setlinewidth
grestore
gsave
.4 .02354 -66 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(b) show
1.000 setlinewidth
grestore
gsave
.6 .02354 -66 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(a) show
1.000 setlinewidth
grestore
gsave
.8 .02354 -66 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(c) show
1.000 setlinewidth
grestore
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[464]:=",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/B000`400?l00000o`00003oo`3ooolQ
0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00=`3oool4000003@0oooo1000
000g0?ooo`@00000=@3oool3000003X0oooo000f0?ooo`040000003oool0oooo000003H0oooo00@0
00000?ooo`3oool00000=@3oool010000000oooo0?ooo`00000e0?ooo`050000003oool0oooo0?oo
o`000000>@3oool003H0oooo00@000000?ooo`3oool00000=P3oool010000000oooo0?ooo`00000f
0?ooo`<00000=@3oool00`000000oooo0?ooo`0k0?ooo`00=P3oool010000000oooo0?ooo`00000f
0?ooo`040000003oool0oooo000003D0oooo00@000000?ooo`3oool00000=@3oool01@000000oooo
0?ooo`3oool0000003T0oooo000g0?ooo`<00000=P3oool3000003L0oooo1@00000d0?ooo`<00000
>P3oool003T0oooo00<000000?ooo`3oool0=03oool00`000000oooo0000000l0?ooo`<00000;P3o
ool3000003d0oooo000h0?ooo`800000=@3oool2000000030?ooo`000000oooo03h0oooo1000000V
0?ooo`@00000@03oool003T0oooo00<000000?ooo`3oool0=P3oool00`000000oooo0?ooo`110?oo
o`<000007`3oool4000004@0oooo000i0?ooo`030000003oool0oooo03H0oooo00<000000?ooo`3o
ool0A03oool4000001P0oooo0`0000180?ooo`00>@3oool00`000000oooo0?ooo`0f0?ooo`030000
003oool0oooo04P0oooo0`00000A0?ooo`@00000B`3oool003T0oooo00<000000?ooo`3oool0=P3o
ool00`000000oooo0?ooo`1;0?ooo`@000002@3oool4000004l0oooo000i0?ooo`030000003oool0
oooo03H0oooo00<000000?ooo`3oool0C`3oool3000000<0oooo0`00001C0?ooo`00:@3oool30000
00<0oooo0`0000070?ooo`030000003oool0oooo02P0oooo1@0000090?ooo`030000003oool0oooo
04L0oooo0`0000080?ooo`<00000EP3oool002X0oooo00<000000?ooo`3oool00`3oool00`000000
oooo0?ooo`060?ooo`030000003oool0oooo02T0oooo00@000000?ooo`3oool000002@3oool00`00
0000oooo0?ooo`180?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool0E`3oool002X0
oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo02X0
oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`150?ooo`D000001@3oool2000005X0
oooo000Z0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool01P3oool00`000000oooo
0?ooo`0[0?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool0A@3oool010000000oooo
0?ooo`0000040?ooo`800000G03oool002X0oooo00<000000?ooo`3oool00`3oool00`000000oooo
0?ooo`060?ooo`030000003oool0oooo02P0oooo00D000000?ooo`3oool0oooo000000090?ooo`03
0000003oool0oooo04H0oooo00<000000?ooo`0000000`3oool00`000000oooo0?ooo`1L0?ooo`00
:@3oool2000000@0oooo0P0000080?ooo`030000003oool0oooo02P0oooo00D000000?ooo`3oool0
oooo000000090?ooo`030000003oool0oooo04L0oooo0P0000000`3oool000000000001O0?ooo`00
:P3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool0
:@3oool3000000X0oooo00<000000?ooo`3oool0B03oool200000640oooo000i0?ooo`030000003o
ool0oooo03H0oooo00<000000?ooo`3oool0A`3oool00`000000oooo0?ooo`1Q0?ooo`00:@3oool3
00000080oooo1@0000060?ooo`030000003oool0oooo02T0oooo0`00000:0?ooo`030000003oool0
oooo04D0oooo0P00001T0?ooo`00:P3oool00`000000oooo0?ooo`020?ooo`040000003oool0oooo
000000H0oooo00<000000?ooo`3oool0:03oool01@000000oooo0?ooo`3oool0000000T0oooo1@00
00110?ooo`800000IP3oool002X0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`06
0?ooo`030000003oool0oooo02`0oooo00<000000?ooo`3oool0303oool7000003T0oooo00<00000
0?ooo`3oool0IP3oool002X0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`050?oo
o`030000003oool0oooo02X0oooo0P00000F0?ooo`L00000<03oool2000006T0oooo000Z0?ooo`05
0000003oool0oooo0?ooo`0000000`3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo
02`0oooo00<000000?ooo`3oool06P3oool7000002L0oooo0P00001[0?ooo`00:@3oool2000000<0
oooo00D000000?ooo`3oool0oooo000000060?ooo`030000003oool0oooo02P0oooo00D000000?oo
o`3oool0oooo0000000S0?ooo`P000007P3oool00`000000oooo0?ooo`1[0?ooo`00:P3oool00`00
0000oooo0?ooo`020?ooo`<000001`3oool00`000000oooo0?ooo`0Y0?ooo`<00000;03oool70000
01D0oooo0P00001^0?ooo`00>@3oool00`000000oooo0?ooo`1O0?ooo`L00000303oool200000700
oooo000Y0?ooo`<00000103oool3000000H0oooo00<000000?ooo`3oool0HP3oool3000000030?oo
o`000000000000D00000103oool00`000000oooo0?ooo`1`0?ooo`00:P3oool00`000000oooo0?oo
o`040?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool0H@3oool01@000000oooo0?oo
o`3oool0000000L0oooo1000001c0?ooo`00:P3oool010000000oooo0?ooo`3oool5000000H0oooo
00<000000?ooo`3oool0I@3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo0740oooo
000Z0?ooo`050000003oool0oooo0?ooo`0000000P3oool00`000000oooo0?ooo`050?ooo`030000
003oool0oooo06D0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`1a0?ooo`00:P3o
ool00`000000oooo0?ooo`020?ooo`030000003oool0000000L0oooo00<000000?ooo`3oool0H@3o
ool4000000/0oooo00<000000?ooo`3oool0L@3oool002T0oooo0P0000050?ooo`8000001`3oool0
0`000000oooo0?ooo`1Q0?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool0L@3oool0
02X0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo
0640oooo1@00000:0?ooo`030000003oool0oooo0740oooo000i0?ooo`030000003oool0oooo0700
oooo00<000000?ooo`3oool0L@3oool003T0oooo00<000000?ooo`3oool0L03oool00`000000oooo
0?ooo`1a0?ooo`00:@3oool3000000<0oooo0`0000070?ooo`030000003oool0oooo06<0oooo00<0
00000?ooo`3oool02P3oool00`000000oooo0?ooo`1a0?ooo`00:P3oool01@000000oooo0?ooo`3o
ool0000000<0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`1S0?ooo`030000003o
ool0oooo00X0oooo00<000000?ooo`3oool0L@3oool002X0oooo00D000000?ooo`3oool0oooo0000
00030?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0I03oool00`000000oooo0?oo
o`090?ooo`030000003oool0oooo0740oooo000Z0?ooo`040000003oool0oooo0?ooo`@000001`3o
ool00`000000oooo0?ooo`1T0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool0L@3o
ool002X0oooo00D000000?ooo`3oool0oooo0000000:0?ooo`030000003oool0oooo06D0oooo00<0
00000?ooo`3oool0203oool00`000000oooo0?ooo`1a0?ooo`00:@3oool2000000@0oooo00<00000
0?ooo`3oool01`3oool00`000000oooo0?ooo`1Q0?ooo`050000003oool0oooo0?ooo`0000002P3o
ool00`000000oooo0?ooo`1a0?ooo`00:P3oool00`000000oooo0?ooo`030?ooo`8000001`3oool0
0`000000oooo0?ooo`1Q0?ooo`D000002P3oool00`000000oooo0?ooo`1a0?ooo`00>@3oool00`00
0000oooo0?ooo`1`0?ooo`030000003oool0oooo0740oooo000Y0?ooo`<00000103oool00`000000
oooo0?ooo`060?ooo`030000003oool0oooo0680oooo0`00000;0?ooo`030000003oool0oooo0740
oooo000Z0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool01P3oool00`000000oooo
0?ooo`1Q0?ooo`050000003oool0oooo0?ooo`0000002P3oool00`000000oooo0?ooo`1a0?ooo`00
:P3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool0
H@3oool01@000000oooo0?ooo`3oool0000000X0oooo00<000000?ooo`3oool0L@3oool002X0oooo
00<000000?ooo`3oool0103oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo0680oooo
0`00000;0?ooo`030000003oool0oooo0740oooo000Z0?ooo`030000003oool0oooo00D0oooo00<0
00000?ooo`3oool0103oool00`000000oooo0?ooo`1Q0?ooo`050000003oool0oooo0?ooo`000000
2P3oool00`000000oooo0?ooo`1a0?ooo`00:@3oool2000000<0oooo00D000000?ooo`3oool0oooo
000000060?ooo`030000003oool0oooo0640oooo00D000000?ooo`3oool0oooo0000000:0?ooo`03
0000003oool0oooo0740oooo000Z0?ooo`040000003oool0oooo0?ooo`D000001P3oool00`000000
oooo0?ooo`1R0?ooo`<000002`3oool00`000000oooo0?ooo`1a0?ooo`00>@3oool00`000000oooo
0?ooo`1`0?ooo`030000003oool0oooo0740oooo000i0?ooo`030000003oool0oooo0700oooo00<0
00000?ooo`3oool0L@3oool002T0oooo0`0000030?ooo`800000203oool00`000000oooo0?ooo`1O
0?ooo`<00000103oool2000000P0oooo00<000000?ooo`3oool0L@3oool002X0oooo00<000000?oo
o`3oool0103oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo0600oooo00<000000?oo
o`3oool00P3oool010000000oooo0?ooo`0000070?ooo`030000003oool0oooo0740oooo000Z0?oo
o`030000003oool0oooo00D0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`1P0?oo
o`030000003oool0oooo0080oooo00@000000?ooo`3oool000001`3oool00`000000oooo0?ooo`1a
0?ooo`00:P3oool00`000000oooo0?ooo`020?ooo`@000001P3oool00`000000oooo0?ooo`1P0?oo
o`030000003oool0oooo0080oooo00@000000?ooo`3oool000001`3oool00`000000oooo0?ooo`1a
0?ooo`00:P3oool01@000000oooo0?ooo`3oool0000000<0oooo00<000000?ooo`3oool0103oool0
0`000000oooo0?ooo`1P0?ooo`030000003oool0oooo0080oooo00@000000?ooo`3oool000001`3o
ool00`000000oooo0?ooo`1a0?ooo`00:@3oool2000000<0oooo00D000000?ooo`3oool0oooo0000
00060?ooo`030000003oool0oooo05l0oooo0P0000040?ooo`040000003oool0oooo000000L0oooo
00<000000?ooo`3oool0L@3oool002X0oooo00<000000?ooo`3oool00P3oool3000000L0oooo00<0
00000?ooo`3oool0H03oool00`000000oooo0?ooo`030?ooo`800000203oool00`000000oooo0?oo
o`1a0?ooo`00>@3oool00`000000oooo0?ooo`1`0?ooo`030000003oool0oooo0740oooo000X0?oo
o`D000000`3oool2000000L0oooo00<000000?ooo`3oool0GP3oool500000080oooo0`0000080?oo
o`030000003oool0oooo0740oooo000Y0?ooo`040000003oool0oooo00000080oooo00@000000?oo
o`3oool000001P3oool00`000000oooo0?ooo`1O0?ooo`060000003oool0oooo0000003oool00000
0`3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo0740oooo000Z0?ooo`030000003o
ool0oooo0080oooo00@000000?ooo`3oool000001P3oool00`000000oooo0?ooo`1P0?ooo`050000
003oool0oooo0?ooo`0000000`3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo0740
oooo000[0?ooo`050000003oool0oooo0?ooo`0000000P3oool00`000000oooo0?ooo`040?ooo`03
0000003oool0oooo0640oooo00@000000?ooo`3oool0oooo0`0000080?ooo`030000003oool0oooo
0740oooo000X0?ooo`050000003oool0oooo0?ooo`0000000P3oool010000000oooo0?ooo`000006
0?ooo`030000003oool0oooo05h0oooo00L000000?ooo`3oool0oooo0000003oool0000000<0oooo
00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`1a0?ooo`00:03oool01@000000oooo0?oo
o`3oool000000080oooo00@000000?ooo`3oool000001P3oool00`000000oooo0?ooo`1N0?ooo`07
0000003oool0oooo0?ooo`000000oooo000000030?ooo`030000003oool0oooo00D0oooo00<00000
0?ooo`3oool0L@3oool002T0oooo0`0000040?ooo`8000001`3oool00`000000oooo0?ooo`1O0?oo
o`<000000`3oool3000000P0oooo00<000000?ooo`3oool0L@3oool003T0oooo00<000000?ooo`3o
ool0L03oool00`000000oooo0?ooo`1a0?ooo`00>@3oool00`000000oooo0?ooo`1`0?ooo`030000
003oool0oooo0740oooo000X0?ooo`D000000P3oool3000000L0oooo00<000000?ooo`3oool0G`3o
ool3000000@0oooo0P0000080?ooo`030000003oool0oooo0740oooo000Y0?ooo`040000003oool0
oooo000000<0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`1N0?ooo`050000003o
ool0oooo0?ooo`0000000P3oool010000000oooo0?ooo`0000070?ooo`030000003oool0oooo0740
oooo000Z0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool01P3oool00`000000oooo
0?ooo`1R0?ooo`040000003oool0oooo00000080oooo00<000000?ooo`3oool01@3oool00`000000
oooo0?ooo`1a0?ooo`00:`3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00H0oooo
00<000000?ooo`3oool0H03oool2000000<0oooo00@000000?ooo`3oool000001`3oool00`000000
oooo0?ooo`1a0?ooo`00:03oool01@000000oooo0?ooo`3oool0000000<0oooo00<000000?ooo`3o
ool01P3oool00`000000oooo0?ooo`1R0?ooo`040000003oool0oooo00000080oooo00<000000?oo
o`3oool01@3oool00`000000oooo0?ooo`1a0?ooo`00:03oool01@000000oooo0?ooo`3oool00000
0080oooo0P0000080?ooo`030000003oool0oooo05h0oooo00D000000?ooo`3oool0oooo00000002
0?ooo`040000003oool0oooo000000L0oooo00<000000?ooo`3oool0L@3oool002T0oooo0`000004
0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool0G`3oool3000000@0oooo0P000008
0?ooo`030000003oool0oooo0740oooo000i0?ooo`030000003oool0oooo0700oooo00<000000?oo
o`3oool0L@3oool002P0oooo1@0000020?ooo`<000001`3oool00`000000oooo0?ooo`1O0?ooo`<0
00000P3oool5000000L0oooo00<000000?ooo`3oool0L@3oool002T0oooo00H000000?ooo`3oool0
00000?ooo`0000030?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0GP3oool01@00
0000oooo0?ooo`3oool000000080oooo00@000000?ooo`3oool000001`3oool00`000000oooo0?oo
o`1a0?ooo`00:P3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00@0oooo00<00000
0?ooo`3oool0HP3oool01@000000oooo0?ooo`3oool0000000T0oooo00<000000?ooo`3oool0L@3o
ool002/0oooo00<000000?ooo`3oool00P3oool2000000L0oooo00<000000?ooo`3oool0H03oool2
000000D0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`1a0?ooo`00:03oool01@00
0000oooo0?ooo`3oool0000000D0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`1R
0?ooo`030000003oool0000000<0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`1a
0?ooo`00:03oool01`000000oooo0?ooo`3oool000000?ooo`0000000`3oool00`000000oooo0?oo
o`040?ooo`030000003oool0oooo05h0oooo00L000000?ooo`3oool0oooo0000003oool0000000<0
oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`1a0?ooo`00:@3oool3000000<0oooo
0`0000070?ooo`030000003oool0oooo05l0oooo0`0000030?ooo`<00000203oool00`000000oooo
0?ooo`1a0?ooo`00>@3oool00`000000oooo0?ooo`1`0?ooo`030000003oool0oooo0740oooo000X
0?ooo`D000000P3oool3000000L0oooo00<000000?ooo`3oool0G`3oool3000000@0oooo0`000007
0?ooo`030000003oool0oooo0740oooo000Y0?ooo`060000003oool0oooo0000003oool000000`3o
ool00`000000oooo0?ooo`040?ooo`<00000GP3oool01@000000oooo0?ooo`3oool0000000@0oooo
00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`1a0?ooo`00:P3oool00`000000oooo0?oo
o`050?ooo`030000003oool0oooo00L0oooo0`00001O0?ooo`030000003oool0000000@000001`3o
ool00`000000oooo0?ooo`1a0?ooo`00:`3oool00`000000oooo0?ooo`040?ooo`030000003oool0
oooo00X0oooo0`00001J0?ooo`8000000P3oool010000000oooo0?ooo`0000080?ooo`030000003o
ool0oooo0740oooo000X0?ooo`060000003oool0oooo0?ooo`000000oooo1000000@0?ooo`@00000
F03oool01P000000oooo0?ooo`000000oooo000000P0oooo00<000000?ooo`3oool0L@3oool002P0
oooo00L000000?ooo`3oool0oooo0000003oool0000001L0oooo0`00001A0?ooo`050000003oool0
oooo0?ooo`0000000`3oool2000000P0oooo00<000000?ooo`3oool0L@3oool002T0oooo0`000002
0?ooo`D000005P3oool3000004l0oooo0`0000050?ooo`030000003oool0oooo00H0oooo00<00000
0?ooo`3oool0L@3oool004`0oooo1000001L0?ooo`030000003oool0oooo0740oooo001@0?ooo`<0
0000F@3oool00`000000oooo0?ooo`1a0?ooo`00D`3oool3000004D0oooo0`0000030?ooo`<00000
203oool00`000000oooo0?ooo`1a0?ooo`00EP3oool300000440oooo00L000000?ooo`3oool0oooo
0000003oool0000000<0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`1a0?ooo`00
F@3oool400000440oooo00<000000?ooo`0000000`3oool00`000000oooo0?ooo`050?ooo`030000
003oool0oooo0740oooo001M0?ooo`<00000?03oool200000080oooo100000080?ooo`030000003o
ool0oooo0740oooo001P0?ooo`<00000>`3oool00`000000oooo0000000;0?ooo`030000003oool0
oooo0740oooo001S0?ooo`@00000<`3oool01@000000oooo0?ooo`3oool000000080oooo00<00000
0?ooo`3oool0203oool00`000000oooo0?ooo`1a0?ooo`00I`3oool300000340oooo0`0000040?oo
o`800000203oool00`000000oooo0?ooo`1a0?ooo`00JP3oool3000003l0oooo00<000000?ooo`3o
ool0L@3oool006d0oooo1000000Z0?ooo`<00000103oool00`000000oooo0?ooo`070?ooo`030000
003oool0oooo0740oooo001a0?ooo`<000009P3oool01@000000oooo0?ooo`3oool0000000<0oooo
00<000000?ooo`3oool01@3oool3000007<0oooo001d0?ooo`<000009`3oool00`000000oooo0?oo
o`020?ooo`040000003oool0oooo0?ooo`<00000MP3oool007L0oooo1000000Q0?ooo`8000001@3o
ool4000007T0oooo001k0?ooo`<00000803oool00`000000oooo0?ooo`04000007/0oooo001n0?oo
o`<000006@3oool00`000000oooo0?ooo`04000000<0oooo00<000000?ooo`3oool0N@3oool00840
oooo0`00000F0?ooo`@000000P3oool5000007/0oooo00240?ooo`@000003`3oool3000008H0oooo
00280?ooo`<000002@3oool3000008T0oooo001o0?ooo`<000000`3oool3000000<0oooo0`000003
0?ooo`<00000S03oool007h0oooo00L000000?ooo`3oool0oooo0000003oool0000000<0oooo00<0
00000?ooo`3oool00`3oool3000008l0oooo00220?ooo`030000003oool0000000<0oooo00<00000
0?ooo`3oool0103oool00`000000oooo0?ooo`2>0?ooo`00P03oool2000000<0oooo0`0000070?oo
o`030000003oool0oooo08h0oooo00220?ooo`030000003oool0000000<0oooo00<000000?ooo`3o
ool0103oool00`000000oooo0?ooo`2>0?ooo`00OP3oool01`000000oooo0?ooo`3oool000000?oo
o`0000000`3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo08h0oooo001o0?ooo`<0
00000`3oool3000000L0oooo00<000000?ooo`3oool0SP3oool008l0oooo00<000000?ooo`3oool0
SP3oool00800oooo0`0000030?ooo`8000001`3oool00`000000oooo0?ooo`2>0?ooo`00P@3oool0
1@000000oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool0103oool00`000000oooo0?oo
o`2>0?ooo`00OP3oool500000080oooo00@000000?ooo`3oool000001P3oool00`000000oooo0?oo
o`2>0?ooo`00OP3oool010000000oooo0?ooo`0000030?ooo`040000003oool0oooo000000H0oooo
00<000000?ooo`3oool0SP3oool007l0oooo00<000000?ooo`0000000`3oool010000000oooo0?oo
o`0000060?ooo`030000003oool0oooo08h0oooo00200?ooo`8000000`3oool010000000oooo0?oo
o`0000060?ooo`030000003oool0oooo08h0oooo00210?ooo`030000003oool0oooo0080oooo0P00
00070?ooo`030000003oool0oooo08h0oooo002?0?ooo`030000003oool0oooo08h0oooo002?0?oo
o`030000003oool0oooo08h0oooo00200?ooo`<0000000<0oooo0000000000000`0000060?ooo`03
0000003oool0oooo08h0oooo00210?ooo`050000003oool0oooo0?ooo`0000000P3oool00`000000
oooo0?ooo`040?ooo`030000003oool0oooo08h0oooo001n0?ooo`D000000`3oool00`000000oooo
0?ooo`060?ooo`030000003oool0oooo08h0oooo001n0?ooo`040000003oool0oooo000000D0oooo
00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`2>0?ooo`00O`3oool00`000000oooo0000
00020?ooo`050000003oool0oooo0?ooo`0000001P3oool00`000000oooo0?ooo`2>0?ooo`00P03o
ool200000080oooo00D000000?ooo`3oool0oooo000000060?ooo`030000003oool0oooo08h0oooo
00210?ooo`040000003oool0oooo0?ooo`<000001`3oool00`000000oooo0?ooo`2>0?ooo`00S`3o
ool00`000000oooo0?ooo`2>0?ooo`00P03oool300000080oooo0`0000070?ooo`030000003oool0
oooo08h0oooo00210?ooo`040000003oool0oooo000000<0oooo00<000000?ooo`3oool0103oool0
0`000000oooo0?ooo`2>0?ooo`00OP3oool5000000D0oooo00<000000?ooo`3oool0103oool00`00
0000oooo0?ooo`2>0?ooo`00OP3oool010000000oooo0?ooo`0000040?ooo`8000001`3oool00`00
0000oooo0?ooo`2>0?ooo`00O`3oool00`000000oooo000000060?ooo`030000003oool0oooo00@0
oooo00<000000?ooo`3oool0SP3oool00800oooo0P0000020?ooo`050000003oool0oooo0?ooo`00
00001P3oool00`000000oooo0?ooo`2>0?ooo`00P@3oool010000000oooo0?ooo`3oool3000000L0
oooo00<000000?ooo`3oool0SP3oool008l0oooo00<000000?ooo`3oool0SP3oool00800oooo0`00
00030?ooo`<000001P3oool00`000000oooo0?ooo`2>0?ooo`00P@3oool00`000000oooo0?ooo`03
0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool0SP3oool007h0oooo1@0000000`3o
ool0000000000003000000H0oooo00<000000?ooo`3oool0SP3oool007h0oooo00@000000?ooo`3o
ool000000P3oool010000000oooo0?ooo`0000070?ooo`030000003oool0oooo08h0oooo001o0?oo
o`030000003oool0000000<0oooo00<000000?ooo`0000001`3oool00`000000oooo0?ooo`2>0?oo
o`00P03oool2000000@0oooo0P0000070?ooo`030000003oool0oooo08h0oooo00210?ooo`030000
003oool0oooo00<0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`2>0?ooo`00S`3o
ool00`000000oooo0?ooo`2>0?ooo`00S`3oool00`000000oooo0?ooo`2>0?ooo`00P03oool30000
0080oooo0`0000070?ooo`030000003oool0oooo08h0oooo00210?ooo`040000003oool0oooo0000
00<0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`2>0?ooo`00OP3oool5000000D0
oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`2>0?ooo`00OP3oool010000000oooo
0?ooo`0000060?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0SP3oool007l0oooo
00<000000?ooo`0000000P3oool4000000L0oooo00<000000?ooo`3oool0SP3oool00800oooo0P00
00020?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool0SP3oool00840oooo00<00000
0?ooo`3oool01@0000060?ooo`030000003oool0oooo08h0oooo002?0?ooo`030000003oool0oooo
08h0oooo00200?ooo`<000000`3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo08h0
oooo00210?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool01P3oool00`000000oooo
0?ooo`2>0?ooo`00OP3oool5000000@0oooo00<000000?ooo`3oool0UP3oool007h0oooo00@00000
0?ooo`3oool000001@3oool00`000000oooo0?ooo`2F0?ooo`00O`3oool00`000000oooo00000006
0?ooo`030000003oool0oooo09D0oooo00200?ooo`8000000P3oool01@000000oooo0?ooo`3oool0
000009L0oooo00210?ooo`030000003oool0oooo00D00000U`3oool00?l0oooo8@3oool00?l0oooo
8@3oool00?l0oooo8@3oool00001\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-1.0062, -1.00011, \
0.0174648, 0.118686}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.2 0.2 0.0294302 0.0294302 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
0 g
.5 Mabswid
[ ] 0 setdash
.4 .05886 m
.4 .02943 L
s
.4 .08829 m
.4 .05886 L
s
.7 .05886 m
.6 .02943 L
s
.7 .05886 m
.8 .02943 L
s
.6 .11772 m
.4 .08829 L
s
.6 .11772 m
.7 .05886 L
s
.6 .14715 m
.6 .11772 L
s
.6 .17658 m
.6 .14715 L
s
.6 .20601 m
.6 .17658 L
s
.2 .05886 m
.2 .02943 L
s
.2 .08829 m
.2 .05886 L
s
.2 .11772 m
.2 .08829 L
s
.2 .14715 m
.2 .11772 L
s
.2 .17658 m
.2 .14715 L
s
.2 .20601 m
.2 .17658 L
s
.2 .23544 m
.2 .20601 L
s
.2 .26487 m
.2 .23544 L
s
.2 .2943 m
.2 .26487 L
s
.2 .32373 m
.2 .2943 L
s
.6 .23544 m
.6 .20601 L
s
.6 .26487 m
.6 .23544 L
s
.6 .2943 m
.6 .26487 L
s
.6 .32373 m
.6 .2943 L
s
.6 .35316 m
.6 .32373 L
s
.6 .38259 m
.6 .35316 L
s
.5 .41202 m
.2 .32373 L
s
.5 .41202 m
.6 .38259 L
s
.5 .44145 m
.5 .41202 L
s
.5 .47088 m
.5 .44145 L
s
.5 .50031 m
.5 .47088 L
s
.5 .52974 m
.5 .50031 L
s
.5 .55917 m
.5 .52974 L
s
.5 .5886 m
.5 .55917 L
s
[(2)] .36 .06475 0 0 Mshowa
[(3)] .36 .09418 0 0 Mshowa
[(4)] .66 .06475 0 0 Mshowa
[(5)] .56 .12361 0 0 Mshowa
[(7)] .56 .15304 0 0 Mshowa
[(8)] .56 .18247 0 0 Mshowa
[(10)] .56 .2119 0 0 Mshowa
[(11)] .16 .06475 0 0 Mshowa
[(13)] .16 .09418 0 0 Mshowa
[(14)] .16 .12361 0 0 Mshowa
[(16)] .16 .15304 0 0 Mshowa
[(17)] .16 .18247 0 0 Mshowa
[(19)] .16 .2119 0 0 Mshowa
[(20)] .16 .24133 0 0 Mshowa
[(21)] .16 .27076 0 0 Mshowa
[(23)] .16 .30019 0 0 Mshowa
[(25)] .16 .32962 0 0 Mshowa
[(28)] .56 .24133 0 0 Mshowa
[(30)] .56 .27076 0 0 Mshowa
[(32)] .56 .30019 0 0 Mshowa
[(34)] .56 .32962 0 0 Mshowa
[(36)] .56 .35905 0 0 Mshowa
[(37)] .56 .38848 0 0 Mshowa
[(38)] .46 .41791 0 0 Mshowa
[(40)] .46 .44734 0 0 Mshowa
[(42)] .46 .47677 0 0 Mshowa
[(43)] .46 .5062 0 0 Mshowa
[(44)] .46 .53563 0 0 Mshowa
[(45)] .46 .56506 0 0 Mshowa
[(47)] .46 .59449 0 0 Mshowa
gsave
.2 .02354 -66 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(d) show
1.000 setlinewidth
grestore
gsave
.4 .02354 -66 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(b) show
1.000 setlinewidth
grestore
gsave
.6 .02354 -66 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(a) show
1.000 setlinewidth
grestore
gsave
.8 .02354 -66 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(c) show
1.000 setlinewidth
grestore
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[464]:=",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/B000`400?l00000o`00003oo`3ooolQ
0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00=`3oool4000003@0oooo1000
000g0?ooo`@00000=@3oool3000003X0oooo000f0?ooo`040000003oool0oooo000003H0oooo00@0
00000?ooo`3oool00000=@3oool010000000oooo0?ooo`00000e0?ooo`050000003oool0oooo0?oo
o`000000>@3oool003H0oooo00@000000?ooo`3oool00000=P3oool010000000oooo0?ooo`00000f
0?ooo`<00000=@3oool00`000000oooo0?ooo`0k0?ooo`00=P3oool010000000oooo0?ooo`00000f
0?ooo`040000003oool0oooo000003D0oooo00@000000?ooo`3oool00000=@3oool01@000000oooo
0?ooo`3oool0000003T0oooo000g0?ooo`<00000=P3oool3000003L0oooo1@00000d0?ooo`<00000
>P3oool003T0oooo00<000000?ooo`3oool0=03oool00`000000oooo0000000l0?ooo`<00000;P3o
ool3000003d0oooo000h0?ooo`800000=@3oool2000000030?ooo`000000oooo03h0oooo1000000V
0?ooo`@00000@03oool003T0oooo00<000000?ooo`3oool0=P3oool00`000000oooo0?ooo`110?oo
o`<000007`3oool4000004@0oooo000i0?ooo`030000003oool0oooo03H0oooo00<000000?ooo`3o
ool0A03oool4000001P0oooo0`0000180?ooo`00>@3oool00`000000oooo0?ooo`0f0?ooo`030000
003oool0oooo04P0oooo0`00000A0?ooo`@00000B`3oool003T0oooo00<000000?ooo`3oool0=P3o
ool00`000000oooo0?ooo`1;0?ooo`@000002@3oool4000004l0oooo000i0?ooo`030000003oool0
oooo03H0oooo00<000000?ooo`3oool0C`3oool3000000<0oooo0`00001C0?ooo`00:@3oool30000
00<0oooo0`0000070?ooo`030000003oool0oooo02P0oooo1@0000090?ooo`030000003oool0oooo
04L0oooo0`0000080?ooo`<00000EP3oool002X0oooo00<000000?ooo`3oool00`3oool00`000000
oooo0?ooo`060?ooo`030000003oool0oooo02T0oooo00@000000?ooo`3oool000002@3oool00`00
0000oooo0?ooo`180?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool0E`3oool002X0
oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo02X0
oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`150?ooo`D000001@3oool2000005X0
oooo000Z0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool01P3oool00`000000oooo
0?ooo`0[0?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool0A@3oool010000000oooo
0?ooo`0000040?ooo`800000G03oool002X0oooo00<000000?ooo`3oool00`3oool00`000000oooo
0?ooo`060?ooo`030000003oool0oooo02P0oooo00D000000?ooo`3oool0oooo000000090?ooo`03
0000003oool0oooo04H0oooo00<000000?ooo`0000000`3oool00`000000oooo0?ooo`1L0?ooo`00
:@3oool2000000@0oooo0P0000080?ooo`030000003oool0oooo02P0oooo00D000000?ooo`3oool0
oooo000000090?ooo`030000003oool0oooo04L0oooo0P0000000`3oool000000000001O0?ooo`00
:P3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool0
:@3oool3000000X0oooo00<000000?ooo`3oool0B03oool200000640oooo000i0?ooo`030000003o
ool0oooo03H0oooo00<000000?ooo`3oool0A`3oool00`000000oooo0?ooo`1Q0?ooo`00:@3oool3
000000<0oooo0`0000070?ooo`030000003oool0oooo02T0oooo0`00000:0?ooo`030000003oool0
oooo04D0oooo0P00001T0?ooo`00:P3oool01@000000oooo0?ooo`3oool0000000<0oooo00<00000
0?ooo`3oool0103oool00`000000oooo0?ooo`0X0?ooo`050000003oool0oooo0?ooo`0000002@3o
ool500000440oooo0P00001V0?ooo`00:P3oool00`000000oooo0?ooo`050?ooo`030000003oool0
oooo00@0oooo00<000000?ooo`3oool0;03oool00`000000oooo0?ooo`0<0?ooo`L00000>@3oool0
0`000000oooo0?ooo`1V0?ooo`00:P3oool00`000000oooo0?ooo`030?ooo`8000001`3oool00`00
0000oooo0?ooo`0Z0?ooo`8000005P3oool700000300oooo0P00001Y0?ooo`00:P3oool00`000000
oooo0?ooo`050?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0;03oool00`000000
oooo0?ooo`0J0?ooo`L000009`3oool2000006/0oooo000Y0?ooo`8000000`3oool01@000000oooo
0?ooo`3oool0000000H0oooo00<000000?ooo`3oool0:03oool01@000000oooo0?ooo`3oool00000
02<0oooo2000000N0?ooo`030000003oool0oooo06/0oooo000Z0?ooo`030000003oool0oooo0080
oooo0`0000070?ooo`030000003oool0oooo02T0oooo0`00000/0?ooo`L000005@3oool2000006h0
oooo000i0?ooo`030000003oool0oooo05l0oooo1`00000<0?ooo`800000L03oool002T0oooo0`00
00040?ooo`<000001P3oool00`000000oooo0?ooo`1R0?ooo`<0000000<0oooo0000000000001@00
00040?ooo`030000003oool0oooo0700oooo000Z0?ooo`030000003oool0oooo00@0oooo00<00000
0?ooo`3oool01@3oool00`000000oooo0?ooo`1Q0?ooo`050000003oool0oooo0?ooo`0000001`3o
ool4000007<0oooo000Z0?ooo`040000003oool0oooo0?ooo`D000001P3oool00`000000oooo0?oo
o`1U0?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool0L@3oool002X0oooo00D00000
0?ooo`3oool0oooo000000020?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool0I@3o
ool00`000000oooo0?ooo`080?ooo`030000003oool0oooo0740oooo000Z0?ooo`030000003oool0
oooo0080oooo00<000000?ooo`0000001`3oool00`000000oooo0?ooo`1Q0?ooo`@000002`3oool0
0`000000oooo0?ooo`1a0?ooo`00:@3oool2000000D0oooo0P0000070?ooo`030000003oool0oooo
0640oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`1a0?ooo`00:P3oool00`000000
oooo0?ooo`040?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool0H@3oool5000000X0
oooo00<000000?ooo`3oool0L@3oool003T0oooo00<000000?ooo`3oool0L03oool00`000000oooo
0?ooo`1a0?ooo`00>@3oool00`000000oooo0?ooo`1`0?ooo`030000003oool0oooo0740oooo000Y
0?ooo`<000000`3oool3000000L0oooo00<000000?ooo`3oool0H`3oool00`000000oooo0?ooo`0:
0?ooo`030000003oool0oooo0740oooo000Z0?ooo`050000003oool0oooo0?ooo`0000000`3oool0
0`000000oooo0?ooo`040?ooo`030000003oool0oooo06<0oooo00<000000?ooo`3oool02P3oool0
0`000000oooo0?ooo`1a0?ooo`00:P3oool01@000000oooo0?ooo`3oool0000000<0oooo00<00000
0?ooo`3oool0103oool00`000000oooo0?ooo`1T0?ooo`030000003oool0oooo00T0oooo00<00000
0?ooo`3oool0L@3oool002X0oooo00@000000?ooo`3oool0oooo100000070?ooo`030000003oool0
oooo06@0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`1a0?ooo`00:P3oool01@00
0000oooo0?ooo`3oool0000000X0oooo00<000000?ooo`3oool0I@3oool00`000000oooo0?ooo`08
0?ooo`030000003oool0oooo0740oooo000Y0?ooo`800000103oool00`000000oooo0?ooo`070?oo
o`030000003oool0oooo0640oooo00D000000?ooo`3oool0oooo0000000:0?ooo`030000003oool0
oooo0740oooo000Z0?ooo`030000003oool0oooo00<0oooo0P0000070?ooo`030000003oool0oooo
0640oooo1@00000:0?ooo`030000003oool0oooo0740oooo000i0?ooo`030000003oool0oooo0700
oooo00<000000?ooo`3oool0L@3oool002T0oooo0`0000040?ooo`030000003oool0oooo00H0oooo
00<000000?ooo`3oool0HP3oool3000000/0oooo00<000000?ooo`3oool0L@3oool002X0oooo00<0
00000?ooo`3oool00`3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo0640oooo00D0
00000?ooo`3oool0oooo0000000:0?ooo`030000003oool0oooo0740oooo000Z0?ooo`030000003o
ool0oooo00@0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`1Q0?ooo`050000003o
ool0oooo0?ooo`0000002P3oool00`000000oooo0?ooo`1a0?ooo`00:P3oool00`000000oooo0?oo
o`040?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool0HP3oool3000000/0oooo00<0
00000?ooo`3oool0L@3oool002X0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`04
0?ooo`030000003oool0oooo0640oooo00D000000?ooo`3oool0oooo0000000:0?ooo`030000003o
ool0oooo0740oooo000Y0?ooo`8000000`3oool01@000000oooo0?ooo`3oool0000000H0oooo00<0
00000?ooo`3oool0H@3oool01@000000oooo0?ooo`3oool0000000X0oooo00<000000?ooo`3oool0
L@3oool002X0oooo00@000000?ooo`3oool0oooo1@0000060?ooo`030000003oool0oooo0680oooo
0`00000;0?ooo`030000003oool0oooo0740oooo000i0?ooo`030000003oool0oooo0700oooo00<0
00000?ooo`3oool0L@3oool003T0oooo00<000000?ooo`3oool0L03oool00`000000oooo0?ooo`1a
0?ooo`00:@3oool3000000<0oooo0P0000080?ooo`030000003oool0oooo05l0oooo0`0000040?oo
o`800000203oool00`000000oooo0?ooo`1a0?ooo`00:P3oool00`000000oooo0?ooo`040?ooo`03
0000003oool0oooo00D0oooo00<000000?ooo`3oool0H03oool00`000000oooo0?ooo`020?ooo`04
0000003oool0oooo000000L0oooo00<000000?ooo`3oool0L@3oool002X0oooo00<000000?ooo`3o
ool01@3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo0600oooo00<000000?ooo`3o
ool00P3oool010000000oooo0?ooo`0000070?ooo`030000003oool0oooo0740oooo000Z0?ooo`03
0000003oool0oooo0080oooo100000060?ooo`030000003oool0oooo0600oooo00<000000?ooo`3o
ool00P3oool010000000oooo0?ooo`0000070?ooo`030000003oool0oooo0740oooo000Z0?ooo`05
0000003oool0oooo0?ooo`0000000`3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo
0600oooo00<000000?ooo`3oool00P3oool010000000oooo0?ooo`0000070?ooo`030000003oool0
oooo0740oooo000Y0?ooo`8000000`3oool01@000000oooo0?ooo`3oool0000000H0oooo00<00000
0?ooo`3oool0G`3oool2000000@0oooo00@000000?ooo`3oool000001`3oool00`000000oooo0?oo
o`1a0?ooo`00:P3oool00`000000oooo0?ooo`020?ooo`<000001`3oool00`000000oooo0?ooo`1P
0?ooo`030000003oool0oooo00<0oooo0P0000080?ooo`030000003oool0oooo0740oooo000i0?oo
o`030000003oool0oooo0700oooo00<000000?ooo`3oool0L@3oool002P0oooo1@0000030?ooo`80
00001`3oool00`000000oooo0?ooo`1N0?ooo`D000000P3oool3000000P0oooo00<000000?ooo`3o
ool0L@3oool002T0oooo00@000000?ooo`3oool000000P3oool010000000oooo0?ooo`0000060?oo
o`030000003oool0oooo05l0oooo00H000000?ooo`3oool000000?ooo`0000030?ooo`030000003o
ool0oooo00D0oooo00<000000?ooo`3oool0L@3oool002X0oooo00<000000?ooo`3oool00P3oool0
10000000oooo0?ooo`0000060?ooo`030000003oool0oooo0600oooo00D000000?ooo`3oool0oooo
000000030?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool0L@3oool002/0oooo00D0
00000?ooo`3oool0oooo000000020?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0
H@3oool010000000oooo0?ooo`3oool3000000P0oooo00<000000?ooo`3oool0L@3oool002P0oooo
00D000000?ooo`3oool0oooo000000020?ooo`040000003oool0oooo000000H0oooo00<000000?oo
o`3oool0GP3oool01`000000oooo0?ooo`3oool000000?ooo`0000000`3oool00`000000oooo0?oo
o`050?ooo`030000003oool0oooo0740oooo000X0?ooo`050000003oool0oooo0?ooo`0000000P3o
ool010000000oooo0?ooo`0000060?ooo`030000003oool0oooo05h0oooo00L000000?ooo`3oool0
oooo0000003oool0000000<0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`1a0?oo
o`00:@3oool3000000@0oooo0P0000070?ooo`030000003oool0oooo05l0oooo0`0000030?ooo`<0
0000203oool00`000000oooo0?ooo`1a0?ooo`00>@3oool00`000000oooo0?ooo`1`0?ooo`030000
003oool0oooo0740oooo000i0?ooo`030000003oool0oooo0700oooo00<000000?ooo`3oool0L@3o
ool002P0oooo1@0000020?ooo`<000001`3oool00`000000oooo0?ooo`1O0?ooo`<00000103oool2
000000P0oooo00<000000?ooo`3oool0L@3oool002T0oooo00@000000?ooo`3oool000000`3oool0
0`000000oooo0?ooo`060?ooo`030000003oool0oooo05h0oooo00D000000?ooo`3oool0oooo0000
00020?ooo`040000003oool0oooo000000L0oooo00<000000?ooo`3oool0L@3oool002X0oooo00<0
00000?ooo`3oool00`3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo0680oooo00@0
00000?ooo`3oool000000P3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo0740oooo
000[0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool01P3oool00`000000oooo0?oo
o`1P0?ooo`8000000`3oool010000000oooo0?ooo`0000070?ooo`030000003oool0oooo0740oooo
000X0?ooo`050000003oool0oooo0?ooo`0000000`3oool00`000000oooo0?ooo`060?ooo`030000
003oool0oooo0680oooo00@000000?ooo`3oool000000P3oool00`000000oooo0?ooo`050?ooo`03
0000003oool0oooo0740oooo000X0?ooo`050000003oool0oooo0?ooo`0000000P3oool2000000P0
oooo00<000000?ooo`3oool0GP3oool01@000000oooo0?ooo`3oool000000080oooo00@000000?oo
o`3oool000001`3oool00`000000oooo0?ooo`1a0?ooo`00:@3oool3000000@0oooo00<000000?oo
o`3oool01P3oool00`000000oooo0?ooo`1O0?ooo`<00000103oool2000000P0oooo00<000000?oo
o`3oool0L@3oool003T0oooo00<000000?ooo`3oool0L03oool00`000000oooo0?ooo`1a0?ooo`00
:03oool500000080oooo0`0000070?ooo`030000003oool0oooo05l0oooo0`0000020?ooo`D00000
1`3oool00`000000oooo0?ooo`1a0?ooo`00:@3oool01P000000oooo0?ooo`000000oooo000000<0
oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`1N0?ooo`050000003oool0oooo0?oo
o`0000000P3oool010000000oooo0?ooo`0000070?ooo`030000003oool0oooo0740oooo000Z0?oo
o`030000003oool0oooo00D0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`1R0?oo
o`050000003oool0oooo0?ooo`0000002@3oool00`000000oooo0?ooo`1a0?ooo`00:`3oool00`00
0000oooo0?ooo`020?ooo`8000001`3oool00`000000oooo0?ooo`1P0?ooo`8000001@3oool00`00
0000oooo0?ooo`060?ooo`030000003oool0oooo0740oooo000X0?ooo`050000003oool0oooo0?oo
o`0000001@3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo0680oooo00<000000?oo
o`0000000`3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo0740oooo000X0?ooo`07
0000003oool0oooo0?ooo`000000oooo000000030?ooo`030000003oool0oooo00@0oooo00<00000
0?ooo`3oool0GP3oool01`000000oooo0?ooo`3oool000000?ooo`0000000`3oool00`000000oooo
0?ooo`050?ooo`030000003oool0oooo0740oooo000Y0?ooo`<000000`3oool3000000L0oooo00<0
00000?ooo`3oool0G`3oool3000000<0oooo0`0000080?ooo`030000003oool0oooo0740oooo000i
0?ooo`030000003oool0oooo0700oooo00<000000?ooo`3oool0L@3oool002P0oooo1@0000020?oo
o`<000001`3oool00`000000oooo0?ooo`1O0?ooo`<00000103oool3000000L0oooo00<000000?oo
o`3oool0L@3oool002T0oooo00H000000?ooo`3oool000000?ooo`0000030?ooo`030000003oool0
oooo00@0oooo0`00001N0?ooo`050000003oool0oooo0?ooo`000000103oool00`000000oooo0?oo
o`060?ooo`030000003oool0oooo0740oooo000Z0?ooo`030000003oool0oooo00D0oooo00<00000
0?ooo`3oool01`3oool3000005l0oooo00<000000?ooo`000000100000070?ooo`030000003oool0
oooo0740oooo000[0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool02P3oool30000
05X0oooo0P0000020?ooo`040000003oool0oooo000000P0oooo00<000000?ooo`3oool0L@3oool0
02P0oooo00H000000?ooo`3oool0oooo0000003oool400000100oooo1000001H0?ooo`060000003o
ool0oooo0000003oool00000203oool00`000000oooo0?ooo`1a0?ooo`00:03oool01`000000oooo
0?ooo`3oool000000?ooo`0000005`3oool300000540oooo00D000000?ooo`3oool0oooo00000003
0?ooo`800000203oool00`000000oooo0?ooo`1a0?ooo`00:@3oool300000080oooo1@00000F0?oo
o`<00000C`3oool3000000D0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`1a0?oo
o`00C03oool4000005`0oooo00<000000?ooo`3oool0L@3oool00500oooo0`00001I0?ooo`030000
003oool0oooo0740oooo001C0?ooo`<00000A@3oool3000000<0oooo0`0000080?ooo`030000003o
ool0oooo0740oooo001F0?ooo`<00000@@3oool01`000000oooo0?ooo`3oool000000?ooo`000000
0`3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo0740oooo001I0?ooo`@00000@@3o
ool00`000000oooo000000030?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool0L@3o
ool005d0oooo0`00000l0?ooo`8000000P3oool4000000P0oooo00<000000?ooo`3oool0L@3oool0
0600oooo0`00000k0?ooo`030000003oool0000000/0oooo00<000000?ooo`3oool0L@3oool006<0
oooo1000000c0?ooo`050000003oool0oooo0?ooo`0000000P3oool00`000000oooo0?ooo`080?oo
o`030000003oool0oooo0740oooo001W0?ooo`<00000<@3oool3000000@0oooo0P0000080?ooo`03
0000003oool0oooo0740oooo001Z0?ooo`<00000?`3oool00`000000oooo0?ooo`1a0?ooo`00K@3o
ool4000002X0oooo0`0000040?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool0L@3o
ool00740oooo0`00000V0?ooo`050000003oool0oooo0?ooo`0000000`3oool00`000000oooo0?oo
o`050?ooo`<00000L`3oool007@0oooo0`00000W0?ooo`030000003oool0oooo0080oooo00@00000
0?ooo`3oool0oooo0`00001f0?ooo`00M`3oool400000240oooo0P0000050?ooo`@00000N@3oool0
07/0oooo0`00000P0?ooo`030000003oool0oooo00@00000N`3oool007h0oooo0`00000I0?ooo`03
0000003oool0oooo00@000000`3oool00`000000oooo0?ooo`1i0?ooo`00P@3oool3000001H0oooo
100000020?ooo`D00000N`3oool008@0oooo1000000?0?ooo`<00000QP3oool008P0oooo0`000009
0?ooo`<00000R@3oool007l0oooo0`0000030?ooo`<000000`3oool3000000<0oooo0`00002<0?oo
o`00OP3oool01`000000oooo0?ooo`3oool000000?ooo`0000000`3oool00`000000oooo0?ooo`03
0?ooo`<00000S`3oool00880oooo00<000000?ooo`0000000`3oool00`000000oooo0?ooo`040?oo
o`030000003oool0oooo08h0oooo00200?ooo`8000000`3oool3000000L0oooo00<000000?ooo`3o
ool0SP3oool00880oooo00<000000?ooo`0000000`3oool00`000000oooo0?ooo`040?ooo`030000
003oool0oooo08h0oooo001n0?ooo`070000003oool0oooo0?ooo`000000oooo000000030?ooo`03
0000003oool0oooo00@0oooo00<000000?ooo`3oool0SP3oool007l0oooo0`0000030?ooo`<00000
1`3oool00`000000oooo0?ooo`2>0?ooo`00S`3oool00`000000oooo0?ooo`2>0?ooo`00P03oool3
000000<0oooo0P0000070?ooo`030000003oool0oooo08h0oooo00210?ooo`050000003oool0oooo
0?ooo`0000000P3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo08h0oooo001n0?oo
o`D000000P3oool010000000oooo0?ooo`0000060?ooo`030000003oool0oooo08h0oooo001n0?oo
o`040000003oool0oooo000000<0oooo00@000000?ooo`3oool000001P3oool00`000000oooo0?oo
o`2>0?ooo`00O`3oool00`000000oooo000000030?ooo`040000003oool0oooo000000H0oooo00<0
00000?ooo`3oool0SP3oool00800oooo0P0000030?ooo`040000003oool0oooo000000H0oooo00<0
00000?ooo`3oool0SP3oool00840oooo00<000000?ooo`3oool00P3oool2000000L0oooo00<00000
0?ooo`3oool0SP3oool008l0oooo00<000000?ooo`3oool0SP3oool008l0oooo00<000000?ooo`3o
ool0SP3oool00800oooo0`0000000`3oool0000000000003000000H0oooo00<000000?ooo`3oool0
SP3oool00840oooo00D000000?ooo`3oool0oooo000000020?ooo`030000003oool0oooo00@0oooo
00<000000?ooo`3oool0SP3oool007h0oooo1@0000030?ooo`030000003oool0oooo00H0oooo00<0
00000?ooo`3oool0SP3oool007h0oooo00@000000?ooo`3oool000001@3oool00`000000oooo0?oo
o`050?ooo`030000003oool0oooo08h0oooo001o0?ooo`030000003oool000000080oooo00D00000
0?ooo`3oool0oooo000000060?ooo`030000003oool0oooo08h0oooo00200?ooo`8000000P3oool0
1@000000oooo0?ooo`3oool0000000H0oooo00<000000?ooo`3oool0SP3oool00840oooo00@00000
0?ooo`3oool0oooo0`0000070?ooo`030000003oool0oooo08h0oooo002?0?ooo`030000003oool0
oooo08h0oooo00200?ooo`<000000P3oool3000000L0oooo00<000000?ooo`3oool0SP3oool00840
oooo00@000000?ooo`3oool000000`3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo
08h0oooo001n0?ooo`D000001@3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo08h0
oooo001n0?ooo`040000003oool0oooo000000@0oooo0P0000070?ooo`030000003oool0oooo08h0
oooo001o0?ooo`030000003oool0000000H0oooo00<000000?ooo`3oool0103oool00`000000oooo
0?ooo`2>0?ooo`00P03oool200000080oooo00D000000?ooo`3oool0oooo000000060?ooo`030000
003oool0oooo08h0oooo00210?ooo`040000003oool0oooo0?ooo`<000001`3oool00`000000oooo
0?ooo`2>0?ooo`00S`3oool00`000000oooo0?ooo`2>0?ooo`00P03oool3000000<0oooo0`000006
0?ooo`030000003oool0oooo08h0oooo00210?ooo`030000003oool0oooo00<0oooo00<000000?oo
o`3oool01@3oool00`000000oooo0?ooo`2>0?ooo`00OP3oool5000000030?ooo`000000000000<0
00001P3oool00`000000oooo0?ooo`2>0?ooo`00OP3oool010000000oooo0?ooo`0000020?ooo`04
0000003oool0oooo000000L0oooo00<000000?ooo`3oool0SP3oool007l0oooo00<000000?ooo`00
00000`3oool00`000000oooo000000070?ooo`030000003oool0oooo08h0oooo00200?ooo`800000
103oool2000000L0oooo00<000000?ooo`3oool0SP3oool00840oooo00<000000?ooo`3oool00`3o
ool00`000000oooo0?ooo`050?ooo`030000003oool0oooo08h0oooo002?0?ooo`030000003oool0
oooo08h0oooo002?0?ooo`030000003oool0oooo08h0oooo00200?ooo`<000000P3oool3000000L0
oooo00<000000?ooo`3oool0SP3oool00840oooo00@000000?ooo`3oool000000`3oool00`000000
oooo0?ooo`040?ooo`030000003oool0oooo08h0oooo001n0?ooo`D000001@3oool00`000000oooo
0?ooo`040?ooo`030000003oool0oooo08h0oooo001n0?ooo`040000003oool0oooo000000H0oooo
00<000000?ooo`3oool0103oool00`000000oooo0?ooo`2>0?ooo`00O`3oool00`000000oooo0000
00020?ooo`@000001`3oool00`000000oooo0?ooo`2>0?ooo`00P03oool200000080oooo00<00000
0?ooo`3oool0203oool00`000000oooo0?ooo`2>0?ooo`00P@3oool00`000000oooo0?ooo`050000
00H0oooo00<000000?ooo`3oool0SP3oool008l0oooo00<000000?ooo`3oool0SP3oool00800oooo
0`0000030?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool0SP3oool00840oooo00<0
00000?ooo`3oool00P3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo08h0oooo001n
0?ooo`D00000103oool00`000000oooo0?ooo`2F0?ooo`00OP3oool010000000oooo0?ooo`000005
0?ooo`030000003oool0oooo09H0oooo001o0?ooo`030000003oool0000000H0oooo00<000000?oo
o`3oool0U@3oool00800oooo0P0000020?ooo`050000003oool0oooo0?ooo`000000U`3oool00840
oooo00<000000?ooo`3oool01@00002G0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ
0?ooo`00\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-1.0062, -1.00011, \
0.0174648, 0.118686}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.2 0.2 0.0294302 0.0294302 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
0 g
.5 Mabswid
[ ] 0 setdash
.4 .05886 m
.4 .02943 L
s
.4 .08829 m
.4 .05886 L
s
.7 .05886 m
.6 .02943 L
s
.7 .05886 m
.8 .02943 L
s
.6 .11772 m
.4 .08829 L
s
.6 .11772 m
.7 .05886 L
s
.6 .14715 m
.6 .11772 L
s
.6 .17658 m
.6 .14715 L
s
.6 .20601 m
.6 .17658 L
s
.2 .05886 m
.2 .02943 L
s
.2 .08829 m
.2 .05886 L
s
.2 .11772 m
.2 .08829 L
s
.2 .14715 m
.2 .11772 L
s
.2 .17658 m
.2 .14715 L
s
.2 .20601 m
.2 .17658 L
s
.2 .23544 m
.2 .20601 L
s
.2 .26487 m
.2 .23544 L
s
.2 .2943 m
.2 .26487 L
s
.2 .32373 m
.2 .2943 L
s
.6 .23544 m
.6 .20601 L
s
.6 .26487 m
.6 .23544 L
s
.6 .2943 m
.6 .26487 L
s
.6 .32373 m
.6 .2943 L
s
.6 .35316 m
.6 .32373 L
s
.6 .38259 m
.6 .35316 L
s
.5 .41202 m
.2 .32373 L
s
.5 .41202 m
.6 .38259 L
s
.5 .44145 m
.5 .41202 L
s
.5 .47088 m
.5 .44145 L
s
.5 .50031 m
.5 .47088 L
s
.5 .52974 m
.5 .50031 L
s
.5 .55917 m
.5 .52974 L
s
.5 .5886 m
.5 .55917 L
s
[(2)] .36 .06475 0 0 Mshowa
[(3)] .36 .09418 0 0 Mshowa
[(4)] .66 .06475 0 0 Mshowa
[(5)] .56 .12361 0 0 Mshowa
[(7)] .56 .15304 0 0 Mshowa
[(8)] .56 .18247 0 0 Mshowa
[(10)] .56 .2119 0 0 Mshowa
[(11)] .16 .06475 0 0 Mshowa
[(13)] .16 .09418 0 0 Mshowa
[(14)] .16 .12361 0 0 Mshowa
[(16)] .16 .15304 0 0 Mshowa
[(17)] .16 .18247 0 0 Mshowa
[(19)] .16 .2119 0 0 Mshowa
[(20)] .16 .24133 0 0 Mshowa
[(22)] .16 .27076 0 0 Mshowa
[(23)] .16 .30019 0 0 Mshowa
[(25)] .16 .32962 0 0 Mshowa
[(28)] .56 .24133 0 0 Mshowa
[(30)] .56 .27076 0 0 Mshowa
[(32)] .56 .30019 0 0 Mshowa
[(34)] .56 .32962 0 0 Mshowa
[(36)] .56 .35905 0 0 Mshowa
[(37)] .56 .38848 0 0 Mshowa
[(38)] .46 .41791 0 0 Mshowa
[(40)] .46 .44734 0 0 Mshowa
[(42)] .46 .47677 0 0 Mshowa
[(43)] .46 .5062 0 0 Mshowa
[(44)] .46 .53563 0 0 Mshowa
[(45)] .46 .56506 0 0 Mshowa
[(47)] .46 .59449 0 0 Mshowa
gsave
.2 .02354 -66 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(d) show
1.000 setlinewidth
grestore
gsave
.4 .02354 -66 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(b) show
1.000 setlinewidth
grestore
gsave
.6 .02354 -66 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(a) show
1.000 setlinewidth
grestore
gsave
.8 .02354 -66 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(c) show
1.000 setlinewidth
grestore
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[464]:=",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/B000`400?l00000o`00003oo`3ooolQ
0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00=`3oool4000003@0oooo1000
000g0?ooo`@00000=@3oool3000003X0oooo000f0?ooo`040000003oool0oooo000003H0oooo00@0
00000?ooo`3oool00000=@3oool010000000oooo0?ooo`00000e0?ooo`050000003oool0oooo0?oo
o`000000>@3oool003H0oooo00@000000?ooo`3oool00000=P3oool010000000oooo0?ooo`00000f
0?ooo`<00000=@3oool00`000000oooo0?ooo`0k0?ooo`00=P3oool010000000oooo0?ooo`00000f
0?ooo`040000003oool0oooo000003D0oooo00@000000?ooo`3oool00000=@3oool01@000000oooo
0?ooo`3oool0000003T0oooo000g0?ooo`<00000=P3oool3000003L0oooo1@00000d0?ooo`<00000
>P3oool003T0oooo00<000000?ooo`3oool0=03oool00`000000oooo0000000l0?ooo`<00000;P3o
ool3000003d0oooo000h0?ooo`800000=@3oool2000000030?ooo`000000oooo03h0oooo1000000V
0?ooo`@00000@03oool003T0oooo00<000000?ooo`3oool0=P3oool00`000000oooo0?ooo`110?oo
o`<000007`3oool4000004@0oooo000i0?ooo`030000003oool0oooo03H0oooo00<000000?ooo`3o
ool0A03oool4000001P0oooo0`0000180?ooo`00>@3oool00`000000oooo0?ooo`0f0?ooo`030000
003oool0oooo04P0oooo0`00000A0?ooo`@00000B`3oool003T0oooo00<000000?ooo`3oool0=P3o
ool00`000000oooo0?ooo`1;0?ooo`@000002@3oool4000004l0oooo000i0?ooo`030000003oool0
oooo03H0oooo00<000000?ooo`3oool0C`3oool3000000<0oooo0`00001C0?ooo`00:@3oool30000
00<0oooo0`0000070?ooo`030000003oool0oooo02P0oooo1@0000090?ooo`030000003oool0oooo
04L0oooo0`0000080?ooo`<00000EP3oool002X0oooo00<000000?ooo`3oool00`3oool00`000000
oooo0?ooo`060?ooo`030000003oool0oooo02T0oooo00@000000?ooo`3oool000002@3oool00`00
0000oooo0?ooo`180?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool0E`3oool002X0
oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo02X0
oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`150?ooo`D000001@3oool2000005X0
oooo000Z0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool01P3oool00`000000oooo
0?ooo`0[0?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool0A@3oool010000000oooo
0?ooo`0000040?ooo`800000G03oool002X0oooo00<000000?ooo`3oool00`3oool00`000000oooo
0?ooo`060?ooo`030000003oool0oooo02P0oooo00D000000?ooo`3oool0oooo000000090?ooo`03
0000003oool0oooo04H0oooo00<000000?ooo`0000000`3oool00`000000oooo0?ooo`1L0?ooo`00
:@3oool2000000@0oooo0P0000080?ooo`030000003oool0oooo02P0oooo00D000000?ooo`3oool0
oooo000000090?ooo`030000003oool0oooo04L0oooo0P0000000`3oool000000000001O0?ooo`00
:P3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool0
:@3oool3000000X0oooo00<000000?ooo`3oool0B03oool200000640oooo000i0?ooo`030000003o
ool0oooo03H0oooo00<000000?ooo`3oool0A`3oool00`000000oooo0?ooo`1Q0?ooo`00:@3oool3
000000<0oooo0`0000070?ooo`030000003oool0oooo02T0oooo0`00000:0?ooo`030000003oool0
oooo04D0oooo0P00001T0?ooo`00:P3oool01@000000oooo0?ooo`3oool0000000<0oooo00<00000
0?ooo`3oool0103oool00`000000oooo0?ooo`0X0?ooo`050000003oool0oooo0?ooo`0000002@3o
ool500000440oooo0P00001V0?ooo`00:P3oool00`000000oooo0?ooo`050?ooo`030000003oool0
oooo00@0oooo00<000000?ooo`3oool0;03oool00`000000oooo0?ooo`0<0?ooo`L00000>@3oool0
0`000000oooo0?ooo`1V0?ooo`00:P3oool00`000000oooo0?ooo`030?ooo`8000001`3oool00`00
0000oooo0?ooo`0Z0?ooo`8000005P3oool700000300oooo0P00001Y0?ooo`00:P3oool00`000000
oooo0?ooo`050?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0;03oool00`000000
oooo0?ooo`0J0?ooo`L000009`3oool2000006/0oooo000Y0?ooo`8000000`3oool01@000000oooo
0?ooo`3oool0000000H0oooo00<000000?ooo`3oool0:03oool01@000000oooo0?ooo`3oool00000
02<0oooo2000000N0?ooo`030000003oool0oooo06/0oooo000Z0?ooo`030000003oool0oooo0080
oooo0`0000070?ooo`030000003oool0oooo02T0oooo0`00000/0?ooo`L000005@3oool2000006h0
oooo000i0?ooo`030000003oool0oooo05l0oooo1`00000<0?ooo`800000L03oool002T0oooo0`00
00040?ooo`<000001P3oool00`000000oooo0?ooo`1R0?ooo`<0000000<0oooo0000000000001@00
00040?ooo`030000003oool0oooo0700oooo000Z0?ooo`030000003oool0oooo00@0oooo00<00000
0?ooo`3oool01@3oool00`000000oooo0?ooo`1Q0?ooo`050000003oool0oooo0?ooo`0000001`3o
ool4000007<0oooo000Z0?ooo`040000003oool0oooo0?ooo`D000001P3oool00`000000oooo0?oo
o`1U0?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool0L@3oool002X0oooo00D00000
0?ooo`3oool0oooo000000020?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool0I@3o
ool00`000000oooo0?ooo`080?ooo`030000003oool0oooo0740oooo000Z0?ooo`030000003oool0
oooo0080oooo00<000000?ooo`0000001`3oool00`000000oooo0?ooo`1Q0?ooo`@000002`3oool0
0`000000oooo0?ooo`1a0?ooo`00:@3oool2000000D0oooo0P0000070?ooo`030000003oool0oooo
0640oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`1a0?ooo`00:P3oool00`000000
oooo0?ooo`040?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool0H@3oool5000000X0
oooo00<000000?ooo`3oool0L@3oool003T0oooo00<000000?ooo`3oool0L03oool00`000000oooo
0?ooo`1a0?ooo`00>@3oool00`000000oooo0?ooo`1`0?ooo`030000003oool0oooo0740oooo000Y
0?ooo`<000000`3oool3000000L0oooo00<000000?ooo`3oool0H`3oool00`000000oooo0?ooo`0:
0?ooo`030000003oool0oooo0740oooo000Z0?ooo`050000003oool0oooo0?ooo`0000000`3oool0
0`000000oooo0?ooo`040?ooo`030000003oool0oooo06<0oooo00<000000?ooo`3oool02P3oool0
0`000000oooo0?ooo`1a0?ooo`00:P3oool01@000000oooo0?ooo`3oool0000000<0oooo00<00000
0?ooo`3oool0103oool00`000000oooo0?ooo`1T0?ooo`030000003oool0oooo00T0oooo00<00000
0?ooo`3oool0L@3oool002X0oooo00@000000?ooo`3oool0oooo100000070?ooo`030000003oool0
oooo06@0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`1a0?ooo`00:P3oool01@00
0000oooo0?ooo`3oool0000000X0oooo00<000000?ooo`3oool0I@3oool00`000000oooo0?ooo`08
0?ooo`030000003oool0oooo0740oooo000Y0?ooo`800000103oool00`000000oooo0?ooo`070?oo
o`030000003oool0oooo0640oooo00D000000?ooo`3oool0oooo0000000:0?ooo`030000003oool0
oooo0740oooo000Z0?ooo`030000003oool0oooo00<0oooo0P0000070?ooo`030000003oool0oooo
0640oooo1@00000:0?ooo`030000003oool0oooo0740oooo000i0?ooo`030000003oool0oooo0700
oooo00<000000?ooo`3oool0L@3oool002T0oooo0`0000040?ooo`030000003oool0oooo00H0oooo
00<000000?ooo`3oool0HP3oool3000000/0oooo00<000000?ooo`3oool0L@3oool002X0oooo00<0
00000?ooo`3oool00`3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo0640oooo00D0
00000?ooo`3oool0oooo0000000:0?ooo`030000003oool0oooo0740oooo000Z0?ooo`030000003o
ool0oooo00@0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`1Q0?ooo`050000003o
ool0oooo0?ooo`0000002P3oool00`000000oooo0?ooo`1a0?ooo`00:P3oool00`000000oooo0?oo
o`040?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool0HP3oool3000000/0oooo00<0
00000?ooo`3oool0L@3oool002X0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`04
0?ooo`030000003oool0oooo0640oooo00D000000?ooo`3oool0oooo0000000:0?ooo`030000003o
ool0oooo0740oooo000Y0?ooo`8000000`3oool01@000000oooo0?ooo`3oool0000000H0oooo00<0
00000?ooo`3oool0H@3oool01@000000oooo0?ooo`3oool0000000X0oooo00<000000?ooo`3oool0
L@3oool002X0oooo00@000000?ooo`3oool0oooo1@0000060?ooo`030000003oool0oooo0680oooo
0`00000;0?ooo`030000003oool0oooo0740oooo000i0?ooo`030000003oool0oooo0700oooo00<0
00000?ooo`3oool0L@3oool003T0oooo00<000000?ooo`3oool0L03oool00`000000oooo0?ooo`1a
0?ooo`00:@3oool3000000<0oooo0P0000080?ooo`030000003oool0oooo05l0oooo0`0000040?oo
o`800000203oool00`000000oooo0?ooo`1a0?ooo`00:P3oool00`000000oooo0?ooo`040?ooo`03
0000003oool0oooo00D0oooo00<000000?ooo`3oool0H03oool00`000000oooo0?ooo`020?ooo`04
0000003oool0oooo000000L0oooo00<000000?ooo`3oool0L@3oool002X0oooo00<000000?ooo`3o
ool01@3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo0600oooo00<000000?ooo`3o
ool00P3oool010000000oooo0?ooo`0000070?ooo`030000003oool0oooo0740oooo000Z0?ooo`03
0000003oool0oooo0080oooo100000060?ooo`030000003oool0oooo0600oooo00<000000?ooo`3o
ool00P3oool010000000oooo0?ooo`0000070?ooo`030000003oool0oooo0740oooo000Z0?ooo`05
0000003oool0oooo0?ooo`0000000`3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo
0600oooo00<000000?ooo`3oool00P3oool010000000oooo0?ooo`0000070?ooo`030000003oool0
oooo0740oooo000Y0?ooo`8000000`3oool01@000000oooo0?ooo`3oool0000000H0oooo00<00000
0?ooo`3oool0G`3oool2000000@0oooo00@000000?ooo`3oool000001`3oool00`000000oooo0?oo
o`1a0?ooo`00:P3oool00`000000oooo0?ooo`020?ooo`<000001`3oool00`000000oooo0?ooo`1P
0?ooo`030000003oool0oooo00<0oooo0P0000080?ooo`030000003oool0oooo0740oooo000i0?oo
o`030000003oool0oooo0700oooo00<000000?ooo`3oool0L@3oool002P0oooo1@0000030?ooo`80
00001`3oool00`000000oooo0?ooo`1N0?ooo`D000000P3oool3000000P0oooo00<000000?ooo`3o
ool0L@3oool002T0oooo00@000000?ooo`3oool000000P3oool010000000oooo0?ooo`0000060?oo
o`030000003oool0oooo05l0oooo00H000000?ooo`3oool000000?ooo`0000030?ooo`030000003o
ool0oooo00D0oooo00<000000?ooo`3oool0L@3oool002X0oooo00<000000?ooo`3oool00P3oool0
10000000oooo0?ooo`0000060?ooo`030000003oool0oooo0600oooo00D000000?ooo`3oool0oooo
000000030?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool0L@3oool002/0oooo00D0
00000?ooo`3oool0oooo000000020?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0
H@3oool010000000oooo0?ooo`3oool3000000P0oooo00<000000?ooo`3oool0L@3oool002P0oooo
00D000000?ooo`3oool0oooo000000020?ooo`040000003oool0oooo000000H0oooo00<000000?oo
o`3oool0GP3oool01`000000oooo0?ooo`3oool000000?ooo`0000000`3oool00`000000oooo0?oo
o`050?ooo`030000003oool0oooo0740oooo000X0?ooo`050000003oool0oooo0?ooo`0000000P3o
ool010000000oooo0?ooo`0000060?ooo`030000003oool0oooo05h0oooo00L000000?ooo`3oool0
oooo0000003oool0000000<0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`1a0?oo
o`00:@3oool3000000@0oooo0P0000070?ooo`030000003oool0oooo05l0oooo0`0000030?ooo`<0
0000203oool00`000000oooo0?ooo`1a0?ooo`00>@3oool00`000000oooo0?ooo`1`0?ooo`030000
003oool0oooo0740oooo000i0?ooo`030000003oool0oooo0700oooo00<000000?ooo`3oool0L@3o
ool002P0oooo1@0000000`3oool0000000000003000000H0oooo00<000000?ooo`3oool0G`3oool3
000000@0oooo0P0000080?ooo`030000003oool0oooo0740oooo000Y0?ooo`040000003oool0oooo
00000080oooo00@000000?ooo`3oool000001P3oool00`000000oooo0?ooo`1N0?ooo`050000003o
ool0oooo0?ooo`0000000P3oool010000000oooo0?ooo`0000070?ooo`030000003oool0oooo0740
oooo000Z0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool01P3oool00`000000oooo
0?ooo`1R0?ooo`040000003oool0oooo00000080oooo00<000000?ooo`3oool01@3oool00`000000
oooo0?ooo`1a0?ooo`00:`3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00D0oooo
00<000000?ooo`3oool0H03oool2000000<0oooo00@000000?ooo`3oool000001`3oool00`000000
oooo0?ooo`1a0?ooo`00:03oool01`000000oooo0?ooo`3oool000000?ooo`0000000`3oool00`00
0000oooo0?ooo`040?ooo`030000003oool0oooo0680oooo00@000000?ooo`3oool000000P3oool0
0`000000oooo0?ooo`050?ooo`030000003oool0oooo0740oooo000X0?ooo`070000003oool0oooo
0?ooo`000000oooo000000030?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0GP3o
ool01@000000oooo0?ooo`3oool000000080oooo00@000000?ooo`3oool000001`3oool00`000000
oooo0?ooo`1a0?ooo`00:@3oool3000000<0oooo0`0000070?ooo`030000003oool0oooo05l0oooo
0`0000040?ooo`800000203oool00`000000oooo0?ooo`1a0?ooo`00>@3oool00`000000oooo0?oo
o`1`0?ooo`030000003oool0oooo0740oooo000X0?ooo`D000000P3oool3000000L0oooo00<00000
0?ooo`3oool0G`3oool300000080oooo1@0000070?ooo`030000003oool0oooo0740oooo000Y0?oo
o`060000003oool0oooo0000003oool000000`3oool00`000000oooo0?ooo`040?ooo`030000003o
ool0oooo05h0oooo00D000000?ooo`3oool0oooo000000020?ooo`040000003oool0oooo000000L0
oooo00<000000?ooo`3oool0L@3oool002X0oooo00<000000?ooo`3oool01@3oool00`000000oooo
0?ooo`040?ooo`030000003oool0oooo0680oooo00D000000?ooo`3oool0oooo000000090?ooo`03
0000003oool0oooo0740oooo000[0?ooo`030000003oool0oooo0080oooo0P0000070?ooo`030000
003oool0oooo0600oooo0P0000050?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool0
L@3oool002P0oooo00D000000?ooo`3oool0oooo000000050?ooo`030000003oool0oooo00@0oooo
00<000000?ooo`3oool0HP3oool00`000000oooo000000030?ooo`030000003oool0oooo00D0oooo
00<000000?ooo`3oool0L@3oool002P0oooo00L000000?ooo`3oool0oooo0000003oool0000000<0
oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`1N0?ooo`070000003oool0oooo0?oo
o`000000oooo000000030?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool0L@3oool0
02T0oooo0`0000030?ooo`<000001`3oool00`000000oooo0?ooo`1O0?ooo`<000000`3oool30000
00P0oooo00<000000?ooo`3oool0L@3oool003T0oooo00<000000?ooo`3oool0L03oool00`000000
oooo0?ooo`1a0?ooo`00:03oool500000080oooo0`0000070?ooo`030000003oool0oooo05l0oooo
0`0000040?ooo`<000001`3oool00`000000oooo0?ooo`1a0?ooo`00:@3oool01P000000oooo0?oo
o`000000oooo000000<0oooo00<000000?ooo`3oool0103oool3000005h0oooo00D000000?ooo`3o
ool0oooo000000040?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool0L@3oool002X0
oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`070?ooo`<00000G`3oool00`000000
oooo00000004000000L0oooo00<000000?ooo`3oool0L@3oool002/0oooo00<000000?ooo`3oool0
103oool00`000000oooo0?ooo`0:0?ooo`<00000FP3oool200000080oooo00@000000?ooo`3oool0
0000203oool00`000000oooo0?ooo`1a0?ooo`00:03oool01P000000oooo0?ooo`3oool000000?oo
o`@00000403oool4000005P0oooo00H000000?ooo`3oool000000?ooo`0000080?ooo`030000003o
ool0oooo0740oooo000X0?ooo`070000003oool0oooo0?ooo`000000oooo0000000G0?ooo`<00000
D@3oool01@000000oooo0?ooo`3oool0000000<0oooo0P0000080?ooo`030000003oool0oooo0740
oooo000Y0?ooo`<000000P3oool5000001H0oooo0`00001?0?ooo`<000001@3oool00`000000oooo
0?ooo`060?ooo`030000003oool0oooo0740oooo001<0?ooo`@00000G03oool00`000000oooo0?oo
o`1a0?ooo`00D03oool3000005T0oooo00<000000?ooo`3oool0L@3oool005<0oooo0`0000150?oo
o`<000000`3oool3000000P0oooo00<000000?ooo`3oool0L@3oool005H0oooo0`0000110?ooo`07
0000003oool0oooo0?ooo`000000oooo000000030?ooo`030000003oool0oooo00D0oooo00<00000
0?ooo`3oool0L@3oool005T0oooo100000110?ooo`030000003oool0000000<0oooo00<000000?oo
o`3oool01@3oool00`000000oooo0?ooo`1a0?ooo`00G@3oool3000003`0oooo0P0000020?ooo`@0
0000203oool00`000000oooo0?ooo`1a0?ooo`00H03oool3000003/0oooo00<000000?ooo`000000
2`3oool00`000000oooo0?ooo`1a0?ooo`00H`3oool4000003<0oooo00D000000?ooo`3oool0oooo
000000020?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool0L@3oool006L0oooo0`00
000a0?ooo`<00000103oool2000000P0oooo00<000000?ooo`3oool0L@3oool006X0oooo0`00000o
0?ooo`030000003oool0oooo0740oooo001]0?ooo`@00000:P3oool3000000@0oooo00<000000?oo
o`3oool01`3oool00`000000oooo0?ooo`1a0?ooo`00L@3oool3000002H0oooo00D000000?ooo`3o
ool0oooo000000030?ooo`030000003oool0oooo00D0oooo0`00001c0?ooo`00M03oool3000002L0
oooo00<000000?ooo`3oool00P3oool010000000oooo0?ooo`3oool3000007H0oooo001g0?ooo`@0
00008@3oool2000000D0oooo1000001i0?ooo`00N`3oool300000200oooo00<000000?ooo`3oool0
1000001k0?ooo`00OP3oool3000001T0oooo00<000000?ooo`3oool0100000030?ooo`030000003o
ool0oooo07T0oooo00210?ooo`<000005P3oool400000080oooo1@00001k0?ooo`00Q03oool40000
00l0oooo0`0000260?ooo`00R03oool3000000T0oooo0`0000290?ooo`00O`3oool3000000<0oooo
0`0000030?ooo`<000000`3oool3000008`0oooo001n0?ooo`070000003oool0oooo0?ooo`000000
oooo000000030?ooo`030000003oool0oooo00<0oooo0`00002?0?ooo`00PP3oool00`000000oooo
000000030?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0SP3oool00800oooo0P00
00030?ooo`<000001`3oool00`000000oooo0?ooo`2>0?ooo`00PP3oool00`000000oooo00000003
0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0SP3oool007h0oooo00L000000?oo
o`3oool0oooo0000003oool0000000<0oooo00<000000?ooo`3oool0103oool00`000000oooo0?oo
o`2>0?ooo`00O`3oool3000000<0oooo0`0000070?ooo`030000003oool0oooo08h0oooo002?0?oo
o`030000003oool0oooo08h0oooo00200?ooo`<000000`3oool2000000L0oooo00<000000?ooo`3o
ool0SP3oool00840oooo00D000000?ooo`3oool0oooo000000020?ooo`030000003oool0oooo00@0
oooo00<000000?ooo`3oool0SP3oool007h0oooo1@0000020?ooo`040000003oool0oooo000000H0
oooo00<000000?ooo`3oool0SP3oool007h0oooo00@000000?ooo`3oool000000`3oool010000000
oooo0?ooo`0000060?ooo`030000003oool0oooo08h0oooo001o0?ooo`030000003oool0000000<0
oooo00@000000?ooo`3oool000001P3oool00`000000oooo0?ooo`2>0?ooo`00P03oool2000000<0
oooo00@000000?ooo`3oool000001P3oool00`000000oooo0?ooo`2>0?ooo`00P@3oool00`000000
oooo0?ooo`020?ooo`8000001`3oool00`000000oooo0?ooo`2>0?ooo`00S`3oool00`000000oooo
0?ooo`2>0?ooo`00S`3oool00`000000oooo0?ooo`2>0?ooo`00P03oool3000000030?ooo`000000
000000<000001P3oool00`000000oooo0?ooo`2>0?ooo`00P@3oool01@000000oooo0?ooo`3oool0
00000080oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`2>0?ooo`00OP3oool50000
00<0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`2>0?ooo`00OP3oool010000000
oooo0?ooo`0000050?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool0SP3oool007l0
oooo00<000000?ooo`0000000P3oool01@000000oooo0?ooo`3oool0000000H0oooo00<000000?oo
o`3oool0SP3oool00800oooo0P0000020?ooo`050000003oool0oooo0?ooo`0000001P3oool00`00
0000oooo0?ooo`2>0?ooo`00P@3oool010000000oooo0?ooo`3oool3000000L0oooo00<000000?oo
o`3oool0SP3oool008l0oooo00<000000?ooo`3oool0SP3oool00800oooo0`0000020?ooo`<00000
1`3oool00`000000oooo0?ooo`2>0?ooo`00P@3oool010000000oooo0?ooo`0000030?ooo`030000
003oool0oooo00@0oooo00<000000?ooo`3oool0SP3oool007h0oooo1@0000050?ooo`030000003o
ool0oooo00@0oooo00<000000?ooo`3oool0SP3oool007h0oooo00@000000?ooo`3oool00000103o
ool2000000L0oooo00<000000?ooo`3oool0SP3oool007l0oooo00<000000?ooo`0000001P3oool0
0`000000oooo0?ooo`040?ooo`030000003oool0oooo08h0oooo00200?ooo`8000000P3oool01@00
0000oooo0?ooo`3oool0000000H0oooo00<000000?ooo`3oool0SP3oool00840oooo00@000000?oo
o`3oool0oooo0`0000070?ooo`030000003oool0oooo08h0oooo002?0?ooo`030000003oool0oooo
08h0oooo00200?ooo`<000000`3oool3000000H0oooo00<000000?ooo`3oool0SP3oool00840oooo
00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo08h0oooo
001n0?ooo`D0000000<0oooo0000000000000`0000060?ooo`030000003oool0oooo08h0oooo001n
0?ooo`040000003oool0oooo00000080oooo00@000000?ooo`3oool000001`3oool00`000000oooo
0?ooo`2>0?ooo`00O`3oool00`000000oooo000000030?ooo`030000003oool0000000L0oooo00<0
00000?ooo`3oool0SP3oool00800oooo0P0000040?ooo`8000001`3oool00`000000oooo0?ooo`2>
0?ooo`00P@3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00D0oooo00<000000?oo
o`3oool0SP3oool008l0oooo00<000000?ooo`3oool0SP3oool008l0oooo00<000000?ooo`3oool0
SP3oool00800oooo0`0000020?ooo`<000001`3oool00`000000oooo0?ooo`2>0?ooo`00P@3oool0
10000000oooo0?ooo`0000030?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0SP3o
ool007h0oooo1@0000050?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0SP3oool0
07h0oooo00@000000?ooo`3oool000001P3oool00`000000oooo0?ooo`040?ooo`030000003oool0
oooo08h0oooo001o0?ooo`030000003oool000000080oooo100000070?ooo`030000003oool0oooo
08h0oooo00200?ooo`8000000P3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo08h0
oooo00210?ooo`030000003oool0oooo00D000001P3oool00`000000oooo0?ooo`2>0?ooo`00S`3o
ool00`000000oooo0?ooo`2>0?ooo`00P03oool3000000<0oooo00<000000?ooo`3oool01P3oool0
0`000000oooo0?ooo`2>0?ooo`00P@3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo
00H0oooo00<000000?ooo`3oool0SP3oool007h0oooo1@0000040?ooo`030000003oool0oooo09H0
oooo001n0?ooo`040000003oool0oooo000000D0oooo00<000000?ooo`3oool0UP3oool007l0oooo
00<000000?ooo`0000001P3oool00`000000oooo0?ooo`2E0?ooo`00P03oool200000080oooo00D0
00000?ooo`3oool0oooo0000002G0?ooo`00P@3oool00`000000oooo0?ooo`05000009L0oooo003o
0?ooob40oooo003o0?ooob40oooo003o0?ooob40oooo0000\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-1.0062, -1.00011, \
0.0174648, 0.118686}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.2 0.2 0.0294302 0.0294302 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
0 g
.5 Mabswid
[ ] 0 setdash
.4 .05886 m
.4 .02943 L
s
.4 .08829 m
.4 .05886 L
s
.7 .05886 m
.6 .02943 L
s
.7 .05886 m
.8 .02943 L
s
.6 .11772 m
.4 .08829 L
s
.6 .11772 m
.7 .05886 L
s
.6 .14715 m
.6 .11772 L
s
.6 .17658 m
.6 .14715 L
s
.6 .20601 m
.6 .17658 L
s
.2 .05886 m
.2 .02943 L
s
.2 .08829 m
.2 .05886 L
s
.2 .11772 m
.2 .08829 L
s
.2 .14715 m
.2 .11772 L
s
.2 .17658 m
.2 .14715 L
s
.2 .20601 m
.2 .17658 L
s
.2 .23544 m
.2 .20601 L
s
.2 .26487 m
.2 .23544 L
s
.2 .2943 m
.2 .26487 L
s
.2 .32373 m
.2 .2943 L
s
.6 .23544 m
.6 .20601 L
s
.6 .26487 m
.6 .23544 L
s
.6 .2943 m
.6 .26487 L
s
.6 .32373 m
.6 .2943 L
s
.6 .35316 m
.6 .32373 L
s
.6 .38259 m
.6 .35316 L
s
.5 .41202 m
.2 .32373 L
s
.5 .41202 m
.6 .38259 L
s
.5 .44145 m
.5 .41202 L
s
.5 .47088 m
.5 .44145 L
s
.5 .50031 m
.5 .47088 L
s
.5 .52974 m
.5 .50031 L
s
.5 .55917 m
.5 .52974 L
s
.5 .5886 m
.5 .55917 L
s
[(2)] .36 .06475 0 0 Mshowa
[(3)] .36 .09418 0 0 Mshowa
[(4)] .66 .06475 0 0 Mshowa
[(5)] .56 .12361 0 0 Mshowa
[(7)] .56 .15304 0 0 Mshowa
[(8)] .56 .18247 0 0 Mshowa
[(10)] .56 .2119 0 0 Mshowa
[(11)] .16 .06475 0 0 Mshowa
[(13)] .16 .09418 0 0 Mshowa
[(14)] .16 .12361 0 0 Mshowa
[(16)] .16 .15304 0 0 Mshowa
[(17)] .16 .18247 0 0 Mshowa
[(19)] .16 .2119 0 0 Mshowa
[(20)] .16 .24133 0 0 Mshowa
[(22)] .16 .27076 0 0 Mshowa
[(23)] .16 .30019 0 0 Mshowa
[(25)] .16 .32962 0 0 Mshowa
[(29)] .56 .24133 0 0 Mshowa
[(31)] .56 .27076 0 0 Mshowa
[(32)] .56 .30019 0 0 Mshowa
[(34)] .56 .32962 0 0 Mshowa
[(36)] .56 .35905 0 0 Mshowa
[(37)] .56 .38848 0 0 Mshowa
[(38)] .46 .41791 0 0 Mshowa
[(40)] .46 .44734 0 0 Mshowa
[(42)] .46 .47677 0 0 Mshowa
[(43)] .46 .5062 0 0 Mshowa
[(44)] .46 .53563 0 0 Mshowa
[(45)] .46 .56506 0 0 Mshowa
[(47)] .46 .59449 0 0 Mshowa
gsave
.2 .02354 -66 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(d) show
1.000 setlinewidth
grestore
gsave
.4 .02354 -66 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(b) show
1.000 setlinewidth
grestore
gsave
.6 .02354 -66 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(a) show
1.000 setlinewidth
grestore
gsave
.8 .02354 -66 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(c) show
1.000 setlinewidth
grestore
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[464]:=",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/B000`400?l00000o`00003oo`3ooolQ
0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00=`3oool4000003@0oooo1000
000g0?ooo`@00000=@3oool3000003X0oooo000f0?ooo`040000003oool0oooo000003H0oooo00@0
00000?ooo`3oool00000=@3oool010000000oooo0?ooo`00000e0?ooo`050000003oool0oooo0?oo
o`000000>@3oool003H0oooo00@000000?ooo`3oool00000=P3oool010000000oooo0?ooo`00000f
0?ooo`<00000=@3oool00`000000oooo0?ooo`0k0?ooo`00=P3oool010000000oooo0?ooo`00000f
0?ooo`040000003oool0oooo000003D0oooo00@000000?ooo`3oool00000=@3oool01@000000oooo
0?ooo`3oool0000003T0oooo000g0?ooo`<00000=P3oool3000003L0oooo1@00000d0?ooo`<00000
>P3oool003T0oooo00<000000?ooo`3oool0=03oool00`000000oooo0000000l0?ooo`<00000;P3o
ool3000003d0oooo000h0?ooo`800000=@3oool2000000030?ooo`000000oooo03h0oooo1000000V
0?ooo`@00000@03oool003T0oooo00<000000?ooo`3oool0=P3oool00`000000oooo0?ooo`110?oo
o`<000007`3oool4000004@0oooo000i0?ooo`030000003oool0oooo03H0oooo00<000000?ooo`3o
ool0A03oool4000001P0oooo0`0000180?ooo`00>@3oool00`000000oooo0?ooo`0f0?ooo`030000
003oool0oooo04P0oooo0`00000A0?ooo`@00000B`3oool003T0oooo00<000000?ooo`3oool0=P3o
ool00`000000oooo0?ooo`1;0?ooo`@000002@3oool4000004l0oooo000i0?ooo`030000003oool0
oooo03H0oooo00<000000?ooo`3oool0C`3oool3000000<0oooo0`00001C0?ooo`00:@3oool30000
00<0oooo0`0000070?ooo`030000003oool0oooo02P0oooo1@0000090?ooo`030000003oool0oooo
04L0oooo0`0000080?ooo`<00000EP3oool002X0oooo00<000000?ooo`3oool00`3oool00`000000
oooo0?ooo`060?ooo`030000003oool0oooo02T0oooo00@000000?ooo`3oool000002@3oool00`00
0000oooo0?ooo`180?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool0E`3oool002X0
oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo02X0
oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`150?ooo`D000001@3oool2000005X0
oooo000Z0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool01P3oool00`000000oooo
0?ooo`0[0?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool0A@3oool010000000oooo
0?ooo`0000040?ooo`800000G03oool002X0oooo00<000000?ooo`3oool00`3oool00`000000oooo
0?ooo`060?ooo`030000003oool0oooo02P0oooo00D000000?ooo`3oool0oooo000000090?ooo`03
0000003oool0oooo04H0oooo00<000000?ooo`0000000`3oool00`000000oooo0?ooo`1L0?ooo`00
:@3oool2000000@0oooo0P0000080?ooo`030000003oool0oooo02P0oooo00D000000?ooo`3oool0
oooo000000090?ooo`030000003oool0oooo04L0oooo0P0000000`3oool000000000001O0?ooo`00
:P3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool0
:@3oool3000000X0oooo00<000000?ooo`3oool0B03oool200000640oooo000i0?ooo`030000003o
ool0oooo03H0oooo00<000000?ooo`3oool0A`3oool00`000000oooo0?ooo`1Q0?ooo`00:@3oool3
000000<0oooo0`0000070?ooo`030000003oool0oooo02T0oooo0`00000:0?ooo`030000003oool0
oooo04D0oooo0P00001T0?ooo`00:P3oool01@000000oooo0?ooo`3oool0000000<0oooo00<00000
0?ooo`3oool0103oool00`000000oooo0?ooo`0X0?ooo`050000003oool0oooo0?ooo`0000002@3o
ool500000440oooo0P00001V0?ooo`00:P3oool00`000000oooo0?ooo`050?ooo`030000003oool0
oooo00@0oooo00<000000?ooo`3oool0;03oool00`000000oooo0?ooo`0<0?ooo`L00000>@3oool0
0`000000oooo0?ooo`1V0?ooo`00:P3oool00`000000oooo0?ooo`030?ooo`8000001`3oool00`00
0000oooo0?ooo`0Z0?ooo`8000005P3oool700000300oooo0P00001Y0?ooo`00:P3oool00`000000
oooo0?ooo`050?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0;03oool00`000000
oooo0?ooo`0J0?ooo`L000009`3oool2000006/0oooo000Y0?ooo`8000000`3oool01@000000oooo
0?ooo`3oool0000000H0oooo00<000000?ooo`3oool0:03oool01@000000oooo0?ooo`3oool00000
02<0oooo2000000N0?ooo`030000003oool0oooo06/0oooo000Z0?ooo`030000003oool0oooo0080
oooo0`0000070?ooo`030000003oool0oooo02T0oooo0`00000/0?ooo`L000005@3oool2000006h0
oooo000i0?ooo`030000003oool0oooo05l0oooo1`00000<0?ooo`800000L03oool002T0oooo0`00
00040?ooo`<000001P3oool00`000000oooo0?ooo`1R0?ooo`<0000000<0oooo0000000000001@00
00040?ooo`030000003oool0oooo0700oooo000Z0?ooo`030000003oool0oooo00@0oooo00<00000
0?ooo`3oool01@3oool00`000000oooo0?ooo`1Q0?ooo`050000003oool0oooo0?ooo`0000001`3o
ool4000007<0oooo000Z0?ooo`040000003oool0oooo0?ooo`D000001P3oool00`000000oooo0?oo
o`1U0?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool0L@3oool002X0oooo00D00000
0?ooo`3oool0oooo000000020?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool0I@3o
ool00`000000oooo0?ooo`080?ooo`030000003oool0oooo0740oooo000Z0?ooo`030000003oool0
oooo0080oooo00<000000?ooo`0000001`3oool00`000000oooo0?ooo`1Q0?ooo`@000002`3oool0
0`000000oooo0?ooo`1a0?ooo`00:@3oool2000000D0oooo0P0000070?ooo`030000003oool0oooo
0640oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`1a0?ooo`00:P3oool00`000000
oooo0?ooo`040?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool0H@3oool5000000X0
oooo00<000000?ooo`3oool0L@3oool003T0oooo00<000000?ooo`3oool0L03oool00`000000oooo
0?ooo`1a0?ooo`00>@3oool00`000000oooo0?ooo`1`0?ooo`030000003oool0oooo0740oooo000Y
0?ooo`<000000`3oool3000000L0oooo00<000000?ooo`3oool0H`3oool00`000000oooo0?ooo`0:
0?ooo`030000003oool0oooo0740oooo000Z0?ooo`050000003oool0oooo0?ooo`0000000`3oool0
0`000000oooo0?ooo`040?ooo`030000003oool0oooo06<0oooo00<000000?ooo`3oool02P3oool0
0`000000oooo0?ooo`1a0?ooo`00:P3oool01@000000oooo0?ooo`3oool0000000<0oooo00<00000
0?ooo`3oool0103oool00`000000oooo0?ooo`1T0?ooo`030000003oool0oooo00T0oooo00<00000
0?ooo`3oool0L@3oool002X0oooo00@000000?ooo`3oool0oooo100000070?ooo`030000003oool0
oooo06@0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`1a0?ooo`00:P3oool01@00
0000oooo0?ooo`3oool0000000X0oooo00<000000?ooo`3oool0I@3oool00`000000oooo0?ooo`08
0?ooo`030000003oool0oooo0740oooo000Y0?ooo`800000103oool00`000000oooo0?ooo`070?oo
o`030000003oool0oooo0640oooo00D000000?ooo`3oool0oooo0000000:0?ooo`030000003oool0
oooo0740oooo000Z0?ooo`030000003oool0oooo00<0oooo0P0000070?ooo`030000003oool0oooo
0640oooo1@00000:0?ooo`030000003oool0oooo0740oooo000i0?ooo`030000003oool0oooo0700
oooo00<000000?ooo`3oool0L@3oool002T0oooo0`0000040?ooo`030000003oool0oooo00H0oooo
00<000000?ooo`3oool0HP3oool3000000/0oooo00<000000?ooo`3oool0L@3oool002X0oooo00<0
00000?ooo`3oool00`3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo0640oooo00D0
00000?ooo`3oool0oooo0000000:0?ooo`030000003oool0oooo0740oooo000Z0?ooo`030000003o
ool0oooo00@0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`1Q0?ooo`050000003o
ool0oooo0?ooo`0000002P3oool00`000000oooo0?ooo`1a0?ooo`00:P3oool00`000000oooo0?oo
o`040?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool0HP3oool3000000/0oooo00<0
00000?ooo`3oool0L@3oool002X0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`04
0?ooo`030000003oool0oooo0640oooo00D000000?ooo`3oool0oooo0000000:0?ooo`030000003o
ool0oooo0740oooo000Y0?ooo`8000000`3oool01@000000oooo0?ooo`3oool0000000H0oooo00<0
00000?ooo`3oool0H@3oool01@000000oooo0?ooo`3oool0000000X0oooo00<000000?ooo`3oool0
L@3oool002X0oooo00@000000?ooo`3oool0oooo1@0000060?ooo`030000003oool0oooo0680oooo
0`00000;0?ooo`030000003oool0oooo0740oooo000i0?ooo`030000003oool0oooo0700oooo00<0
00000?ooo`3oool0L@3oool003T0oooo00<000000?ooo`3oool0L03oool00`000000oooo0?ooo`1a
0?ooo`00:@3oool3000000<0oooo0P0000080?ooo`030000003oool0oooo05l0oooo0`0000040?oo
o`800000203oool00`000000oooo0?ooo`1a0?ooo`00:P3oool00`000000oooo0?ooo`040?ooo`03
0000003oool0oooo00D0oooo00<000000?ooo`3oool0H03oool00`000000oooo0?ooo`020?ooo`04
0000003oool0oooo000000L0oooo00<000000?ooo`3oool0L@3oool002X0oooo00<000000?ooo`3o
ool01@3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo0600oooo00<000000?ooo`3o
ool00P3oool010000000oooo0?ooo`0000070?ooo`030000003oool0oooo0740oooo000Z0?ooo`03
0000003oool0oooo0080oooo100000060?ooo`030000003oool0oooo0600oooo00<000000?ooo`3o
ool00P3oool010000000oooo0?ooo`0000070?ooo`030000003oool0oooo0740oooo000Z0?ooo`05
0000003oool0oooo0?ooo`0000000`3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo
0600oooo00<000000?ooo`3oool00P3oool010000000oooo0?ooo`0000070?ooo`030000003oool0
oooo0740oooo000Y0?ooo`8000000`3oool01@000000oooo0?ooo`3oool0000000H0oooo00<00000
0?ooo`3oool0G`3oool2000000@0oooo00@000000?ooo`3oool000001`3oool00`000000oooo0?oo
o`1a0?ooo`00:P3oool00`000000oooo0?ooo`020?ooo`<000001`3oool00`000000oooo0?ooo`1P
0?ooo`030000003oool0oooo00<0oooo0P0000080?ooo`030000003oool0oooo0740oooo000i0?oo
o`030000003oool0oooo0700oooo00<000000?ooo`3oool0L@3oool002P0oooo1@0000030?ooo`80
00001`3oool00`000000oooo0?ooo`1N0?ooo`D000000P3oool2000000T0oooo00<000000?ooo`3o
ool0L@3oool002T0oooo00@000000?ooo`3oool000000P3oool010000000oooo0?ooo`0000060?oo
o`030000003oool0oooo05l0oooo00@000000?ooo`3oool00000103oool00`000000oooo0?ooo`06
0?ooo`030000003oool0oooo0740oooo000Z0?ooo`030000003oool0oooo0080oooo00@000000?oo
o`3oool000001P3oool00`000000oooo0?ooo`1P0?ooo`030000003oool0oooo00D0oooo00<00000
0?ooo`3oool01@3oool00`000000oooo0?ooo`1a0?ooo`00:`3oool01@000000oooo0?ooo`3oool0
00000080oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`1Q0?ooo`040000003oool0
oooo0?ooo`@000001`3oool00`000000oooo0?ooo`1a0?ooo`00:03oool01@000000oooo0?ooo`3o
ool000000080oooo00@000000?ooo`3oool000001P3oool00`000000oooo0?ooo`1N0?ooo`070000
003oool0oooo0?ooo`000000oooo000000030?ooo`030000003oool0oooo00D0oooo00<000000?oo
o`3oool0L@3oool002P0oooo00D000000?ooo`3oool0oooo000000020?ooo`040000003oool0oooo
000000H0oooo00<000000?ooo`3oool0GP3oool01`000000oooo0?ooo`3oool000000?ooo`000000
0`3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo0740oooo000Y0?ooo`<00000103o
ool2000000L0oooo00<000000?ooo`3oool0G`3oool3000000<0oooo0`0000080?ooo`030000003o
ool0oooo0740oooo000i0?ooo`030000003oool0oooo0700oooo00<000000?ooo`3oool0L@3oool0
03T0oooo00<000000?ooo`3oool0L03oool00`000000oooo0?ooo`1a0?ooo`00:03oool500000003
0?ooo`000000000000<000001P3oool00`000000oooo0?ooo`1O0?ooo`<000000`3oool3000000P0
oooo00<000000?ooo`3oool0L@3oool002T0oooo00@000000?ooo`3oool000000P3oool010000000
oooo0?ooo`0000060?ooo`030000003oool0oooo05h0oooo00D000000?ooo`3oool0oooo00000003
0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool0L@3oool002X0oooo00<000000?oo
o`3oool00`3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo0680oooo00D000000?oo
o`3oool0oooo000000090?ooo`030000003oool0oooo0740oooo000[0?ooo`030000003oool0oooo
00<0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`1P0?ooo`800000103oool00`00
0000oooo0?ooo`070?ooo`030000003oool0oooo0740oooo000X0?ooo`070000003oool0oooo0?oo
o`000000oooo000000030?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0HP3oool0
1@000000oooo0?ooo`3oool0000000T0oooo00<000000?ooo`3oool0L@3oool002P0oooo00L00000
0?ooo`3oool0oooo0000003oool0000000<0oooo00<000000?ooo`3oool0103oool00`000000oooo
0?ooo`1N0?ooo`050000003oool0oooo0?ooo`0000000P3oool2000000T0oooo00<000000?ooo`3o
ool0L@3oool002T0oooo0`0000030?ooo`<000001`3oool00`000000oooo0?ooo`1O0?ooo`<00000
103oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo0740oooo000i0?ooo`030000003o
ool0oooo0700oooo00<000000?ooo`3oool0L@3oool002P0oooo1@0000020?ooo`<000001`3oool0
0`000000oooo0?ooo`1O0?ooo`<000000P3oool5000000L0oooo00<000000?ooo`3oool0L@3oool0
02T0oooo00H000000?ooo`3oool000000?ooo`0000030?ooo`030000003oool0oooo00@0oooo00<0
00000?ooo`3oool0GP3oool01@000000oooo0?ooo`3oool000000080oooo00@000000?ooo`3oool0
00001`3oool00`000000oooo0?ooo`1a0?ooo`00:P3oool00`000000oooo0?ooo`050?ooo`030000
003oool0oooo00@0oooo00<000000?ooo`3oool0HP3oool01@000000oooo0?ooo`3oool0000000T0
oooo00<000000?ooo`3oool0L@3oool002/0oooo00<000000?ooo`3oool00P3oool2000000L0oooo
00<000000?ooo`3oool0H03oool2000000D0oooo00<000000?ooo`3oool01P3oool00`000000oooo
0?ooo`1a0?ooo`00:03oool01@000000oooo0?ooo`3oool0000000D0oooo00<000000?ooo`3oool0
103oool00`000000oooo0?ooo`1R0?ooo`030000003oool0000000<0oooo00<000000?ooo`3oool0
1@3oool00`000000oooo0?ooo`1a0?ooo`00:03oool01`000000oooo0?ooo`3oool000000?ooo`00
00000`3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo05h0oooo00L000000?ooo`3o
ool0oooo0000003oool0000000<0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`1a
0?ooo`00:@3oool3000000<0oooo0`0000070?ooo`030000003oool0oooo05l0oooo0`0000030?oo
o`<00000203oool00`000000oooo0?ooo`1a0?ooo`00>@3oool00`000000oooo0?ooo`1`0?ooo`03
0000003oool0oooo0740oooo000X0?ooo`D000000P3oool3000000L0oooo00<000000?ooo`3oool0
G`3oool3000000@0oooo0`0000070?ooo`030000003oool0oooo0740oooo000Y0?ooo`060000003o
ool0oooo0000003oool000000`3oool00`000000oooo0?ooo`040?ooo`<00000GP3oool01@000000
oooo0?ooo`3oool0000000@0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`1a0?oo
o`00:P3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00L0oooo0`00001O0?ooo`03
0000003oool0000000@000001`3oool00`000000oooo0?ooo`1a0?ooo`00:`3oool00`000000oooo
0?ooo`040?ooo`030000003oool0oooo00X0oooo0`00001J0?ooo`8000000P3oool010000000oooo
0?ooo`0000080?ooo`030000003oool0oooo0740oooo000X0?ooo`060000003oool0oooo0?ooo`00
0000oooo1000000@0?ooo`@00000F03oool01P000000oooo0?ooo`000000oooo000000P0oooo00<0
00000?ooo`3oool0L@3oool002P0oooo00L000000?ooo`3oool0oooo0000003oool0000001L0oooo
0`00001A0?ooo`050000003oool0oooo0?ooo`0000000`3oool2000000P0oooo00<000000?ooo`3o
ool0L@3oool002T0oooo0`0000020?ooo`D000005P3oool3000004l0oooo0`0000050?ooo`030000
003oool0oooo00H0oooo00<000000?ooo`3oool0L@3oool004`0oooo1000001L0?ooo`030000003o
ool0oooo0740oooo001@0?ooo`<00000F@3oool00`000000oooo0?ooo`1a0?ooo`00D`3oool30000
04D0oooo0`0000030?ooo`<00000203oool00`000000oooo0?ooo`1a0?ooo`00EP3oool300000440
oooo00L000000?ooo`3oool0oooo0000003oool0000000<0oooo00<000000?ooo`3oool01@3oool0
0`000000oooo0?ooo`1a0?ooo`00F@3oool400000440oooo00<000000?ooo`0000000`3oool00`00
0000oooo0?ooo`050?ooo`030000003oool0oooo0740oooo001M0?ooo`<00000?03oool200000080
oooo100000080?ooo`030000003oool0oooo0740oooo001P0?ooo`<00000>`3oool00`000000oooo
0000000;0?ooo`030000003oool0oooo0740oooo001S0?ooo`@00000<`3oool01@000000oooo0?oo
o`3oool000000080oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`1a0?ooo`00I`3o
ool300000340oooo0`0000040?ooo`800000203oool00`000000oooo0?ooo`1a0?ooo`00JP3oool3
000003l0oooo00<000000?ooo`3oool0L@3oool006d0oooo1000000Z0?ooo`<00000103oool00`00
0000oooo0?ooo`070?ooo`030000003oool0oooo0740oooo001a0?ooo`<000009P3oool01@000000
oooo0?ooo`3oool0000000<0oooo00<000000?ooo`3oool01@3oool3000007<0oooo001d0?ooo`<0
00009`3oool00`000000oooo0?ooo`020?ooo`040000003oool0oooo0?ooo`<00000MP3oool007L0
oooo1000000Q0?ooo`8000001@3oool4000007T0oooo001k0?ooo`<00000803oool00`000000oooo
0?ooo`04000007/0oooo001n0?ooo`<000006@3oool00`000000oooo0?ooo`04000000<0oooo00<0
00000?ooo`3oool0N@3oool00840oooo0`00000F0?ooo`@000000P3oool5000007/0oooo00240?oo
o`@000003`3oool3000008H0oooo00280?ooo`<000002@3oool3000008T0oooo001o0?ooo`<00000
0`3oool3000000<0oooo0`0000030?ooo`<00000S03oool007h0oooo00L000000?ooo`3oool0oooo
0000003oool0000000<0oooo00<000000?ooo`3oool00`3oool3000008l0oooo00220?ooo`030000
003oool0000000<0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`2>0?ooo`00P03o
ool2000000<0oooo0`0000070?ooo`030000003oool0oooo08h0oooo00220?ooo`030000003oool0
000000<0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`2>0?ooo`00OP3oool01`00
0000oooo0?ooo`3oool000000?ooo`0000000`3oool00`000000oooo0?ooo`040?ooo`030000003o
ool0oooo08h0oooo001o0?ooo`<000000`3oool3000000L0oooo00<000000?ooo`3oool0SP3oool0
08l0oooo00<000000?ooo`3oool0SP3oool00800oooo0`0000030?ooo`8000001`3oool00`000000
oooo0?ooo`2>0?ooo`00P@3oool01@000000oooo0?ooo`3oool000000080oooo00<000000?ooo`3o
ool0103oool00`000000oooo0?ooo`2>0?ooo`00OP3oool500000080oooo00@000000?ooo`3oool0
00001P3oool00`000000oooo0?ooo`2>0?ooo`00OP3oool010000000oooo0?ooo`0000030?ooo`04
0000003oool0oooo000000H0oooo00<000000?ooo`3oool0SP3oool007l0oooo00<000000?ooo`00
00000`3oool010000000oooo0?ooo`0000060?ooo`030000003oool0oooo08h0oooo00200?ooo`80
00000`3oool010000000oooo0?ooo`0000060?ooo`030000003oool0oooo08h0oooo00210?ooo`03
0000003oool0oooo0080oooo0P0000070?ooo`030000003oool0oooo08h0oooo002?0?ooo`030000
003oool0oooo08h0oooo002?0?ooo`030000003oool0oooo08h0oooo00200?ooo`<0000000<0oooo
0000000000000`0000060?ooo`030000003oool0oooo08h0oooo00210?ooo`050000003oool0oooo
0?ooo`0000000P3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo08h0oooo001n0?oo
o`D000000`3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo08h0oooo001n0?ooo`04
0000003oool0oooo000000D0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`2>0?oo
o`00O`3oool00`000000oooo000000020?ooo`050000003oool0oooo0?ooo`0000001P3oool00`00
0000oooo0?ooo`2>0?ooo`00P03oool200000080oooo00D000000?ooo`3oool0oooo000000060?oo
o`030000003oool0oooo08h0oooo00210?ooo`040000003oool0oooo0?ooo`<000001`3oool00`00
0000oooo0?ooo`2>0?ooo`00S`3oool00`000000oooo0?ooo`2>0?ooo`00P03oool300000080oooo
0`0000070?ooo`030000003oool0oooo08h0oooo00210?ooo`040000003oool0oooo000000<0oooo
00<000000?ooo`3oool0103oool00`000000oooo0?ooo`2>0?ooo`00OP3oool5000000D0oooo00<0
00000?ooo`3oool0103oool00`000000oooo0?ooo`2>0?ooo`00OP3oool010000000oooo0?ooo`00
00040?ooo`8000001`3oool00`000000oooo0?ooo`2>0?ooo`00O`3oool00`000000oooo00000006
0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0SP3oool00800oooo0P0000020?oo
o`050000003oool0oooo0?ooo`0000001P3oool00`000000oooo0?ooo`2>0?ooo`00P@3oool01000
0000oooo0?ooo`3oool3000000L0oooo00<000000?ooo`3oool0SP3oool008l0oooo00<000000?oo
o`3oool0SP3oool00800oooo0`0000030?ooo`<000001P3oool00`000000oooo0?ooo`2>0?ooo`00
P@3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool0
SP3oool007h0oooo1@0000000`3oool0000000000003000000H0oooo00<000000?ooo`3oool0SP3o
ool007h0oooo00@000000?ooo`3oool000000P3oool010000000oooo0?ooo`0000070?ooo`030000
003oool0oooo08h0oooo001o0?ooo`030000003oool0000000<0oooo00<000000?ooo`0000001`3o
ool00`000000oooo0?ooo`2>0?ooo`00P03oool2000000@0oooo0P0000070?ooo`030000003oool0
oooo08h0oooo00210?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool01@3oool00`00
0000oooo0?ooo`2>0?ooo`00S`3oool00`000000oooo0?ooo`2>0?ooo`00S`3oool00`000000oooo
0?ooo`2>0?ooo`00P03oool300000080oooo0`0000070?ooo`030000003oool0oooo08h0oooo0021
0?ooo`040000003oool0oooo000000<0oooo00<000000?ooo`3oool0103oool00`000000oooo0?oo
o`2>0?ooo`00OP3oool5000000D0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`2>
0?ooo`00OP3oool010000000oooo0?ooo`0000060?ooo`030000003oool0oooo00@0oooo00<00000
0?ooo`3oool0SP3oool007l0oooo00<000000?ooo`0000000P3oool4000000L0oooo00<000000?oo
o`3oool0SP3oool00800oooo0P0000020?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3o
ool0SP3oool00840oooo00<000000?ooo`3oool01@0000060?ooo`030000003oool0oooo08h0oooo
002?0?ooo`030000003oool0oooo08h0oooo00200?ooo`<000000`3oool00`000000oooo0?ooo`06
0?ooo`030000003oool0oooo08h0oooo00210?ooo`030000003oool0oooo0080oooo00<000000?oo
o`3oool01P3oool00`000000oooo0?ooo`2>0?ooo`00OP3oool5000000@0oooo00<000000?ooo`3o
ool0UP3oool007h0oooo00@000000?ooo`3oool000001@3oool00`000000oooo0?ooo`2F0?ooo`00
O`3oool00`000000oooo000000060?ooo`030000003oool0oooo09D0oooo00200?ooo`8000000P3o
ool01@000000oooo0?ooo`3oool0000009L0oooo00210?ooo`030000003oool0oooo00D00000U`3o
ool00?l0oooo8@3oool00?l0oooo8@3oool00?l0oooo8@3oool00001\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-1.0062, -1.00011, \
0.0174648, 0.118686}}]
}, Closed]]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["Example of ExtractGenealogy", "SubsubsectionIcon"],

Cell[CellGroupData[{

Cell[BoxData[
    \(ExtractGenealogy[ag, 0.5]\)], "Input",
  CellLabel->"In[823]:="],

Cell[BoxData[
    \(Node[
      9, {7}, {Node[
          5, {4}, {Node[1, {1}, {Node[a, {0}, {}], Node[b, {0}, {}]}]}], 
        Node[8, {6}, {Node[
              4, {3}, {Node[d, {0}, {}], 
                Node[2, {2}, {Node[c, {0}, {}]}]}]}]}]\)], "Output",
  CellLabel->"Out[823]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(Show[PlotGenealogy[%]];\)\)], "Input",
  CellLabel->"In[824]:="],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.2 0.2 0.103006 0.103006 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
0 g
.5 Mabswid
[ ] 0 setdash
.3 .20601 m
.2 .10301 L
s
.3 .20601 m
.4 .10301 L
s
.8 .20601 m
.8 .10301 L
s
.7 .30902 m
.6 .10301 L
s
.7 .30902 m
.8 .20601 L
s
.3 .30902 m
.3 .20601 L
s
.7 .41202 m
.7 .30902 L
s
.5 .51503 m
.3 .30902 L
s
.5 .51503 m
.7 .41202 L
s
[(1)] .26 .22661 0 0 Mshowa
[(2)] .76 .22661 0 0 Mshowa
[(4)] .66 .32962 0 0 Mshowa
[(5)] .26 .32962 0 0 Mshowa
[(8)] .66 .43262 0 0 Mshowa
[(9)] .46 .53563 0 0 Mshowa
gsave
.2 .0824 -66 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(a) show
1.000 setlinewidth
grestore
gsave
.4 .0824 -66 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(b) show
1.000 setlinewidth
grestore
gsave
.6 .0824 -66 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(d) show
1.000 setlinewidth
grestore
gsave
.8 .0824 -66 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(c) show
1.000 setlinewidth
grestore
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[824]:=",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/B000`400?l00000o`00003oo`3ooolQ
0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ
0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ
0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ
0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ
0?ooo`00=`3oool4000003@0oooo1000000g0?ooo`@00000=@3oool3000003X0oooo000f0?ooo`04
0000003oool0oooo000003H0oooo00@000000?ooo`3oool00000=@3oool010000000oooo0?ooo`00
000e0?ooo`050000003oool0oooo0?ooo`000000>@3oool003L0oooo0`00000f0?ooo`040000003o
ool0oooo000003D0oooo00@000000?ooo`3oool00000=@3oool00`000000oooo0?ooo`0k0?ooo`00
=P3oool010000000oooo0?ooo`00000f0?ooo`040000003oool0oooo000003D0oooo00@000000?oo
o`3oool00000=@3oool01@000000oooo0?ooo`3oool0000003T0oooo000g0?ooo`800000=`3oool3
000003L0oooo0`00000f0?ooo`<00000>P3oool00700oooo00<000000?ooo`3oool0>@3oool00`00
0000oooo0?ooo`1a0?ooo`00K`3oool2000003X0oooo0P00001c0?ooo`00o`3ooolQ0?ooo`00>@3o
ool00`000000oooo0?ooo`0f0?ooo`030000003oool0oooo03L0oooo00<000000?ooo`3oool0=P3o
ool00`000000oooo0?ooo`0h0?ooo`00>@3oool00`000000oooo0?ooo`0f0?ooo`030000003oool0
oooo03L0oooo00<000000?ooo`3oool0=P3oool00`000000oooo0?ooo`0h0?ooo`00>P3oool00`00
0000oooo0?ooo`0d0?ooo`030000003oool0oooo03T0oooo00<000000?ooo`3oool0=@3oool00`00
0000oooo0?ooo`0h0?ooo`00>`3oool00`000000oooo0?ooo`0b0?ooo`030000003oool0oooo03X0
oooo00<000000?ooo`3oool0=@3oool00`000000oooo0?ooo`0h0?ooo`00?03oool00`000000oooo
0?ooo`0`0?ooo`030000003oool0oooo03`0oooo00<000000?ooo`3oool0=03oool00`000000oooo
0?ooo`0h0?ooo`00?@3oool00`000000oooo0?ooo`0^0?ooo`030000003oool0oooo03d0oooo00<0
00000?ooo`3oool0=03oool00`000000oooo0?ooo`0h0?ooo`00?P3oool00`000000oooo0?ooo`0/
0?ooo`030000003oool0oooo03l0oooo00<000000?ooo`3oool0<`3oool00`000000oooo0?ooo`0h
0?ooo`00?`3oool00`000000oooo0?ooo`0Z0?ooo`030000003oool0oooo0400oooo00<000000?oo
o`3oool0<`3oool00`000000oooo0?ooo`0h0?ooo`00@03oool00`000000oooo0?ooo`0X0?ooo`03
0000003oool0oooo0480oooo00<000000?ooo`3oool0<P3oool00`000000oooo0?ooo`0h0?ooo`00
@@3oool00`000000oooo0?ooo`0V0?ooo`030000003oool0oooo04<0oooo00<000000?ooo`3oool0
<P3oool00`000000oooo0?ooo`0h0?ooo`00@P3oool00`000000oooo0?ooo`0T0?ooo`030000003o
ool0oooo04D0oooo00<000000?ooo`3oool0<@3oool00`000000oooo0?ooo`0h0?ooo`00@`3oool0
0`000000oooo0?ooo`0R0?ooo`030000003oool0oooo04H0oooo00<000000?ooo`3oool0<@3oool0
0`000000oooo0?ooo`0h0?ooo`00A03oool00`000000oooo0?ooo`0P0?ooo`030000003oool0oooo
04L0oooo00<000000?ooo`3oool0<@3oool00`000000oooo0?ooo`0h0?ooo`00A@3oool00`000000
oooo0?ooo`0N0?ooo`030000003oool0oooo04T0oooo00<000000?ooo`3oool0<03oool00`000000
oooo0?ooo`0h0?ooo`00AP3oool00`000000oooo0?ooo`0L0?ooo`030000003oool0oooo04X0oooo
00<000000?ooo`3oool0<03oool00`000000oooo0?ooo`0h0?ooo`00A`3oool00`000000oooo0?oo
o`0J0?ooo`030000003oool0oooo04`0oooo00<000000?ooo`3oool0;`3oool00`000000oooo0?oo
o`0h0?ooo`00B03oool00`000000oooo0?ooo`0I0?ooo`030000003oool0oooo04`0oooo00<00000
0?ooo`3oool0;`3oool00`000000oooo0?ooo`0h0?ooo`00B@3oool00`000000oooo0?ooo`0G0?oo
o`030000003oool0oooo04h0oooo00<000000?ooo`3oool0;P3oool00`000000oooo0?ooo`0h0?oo
o`00BP3oool00`000000oooo0?ooo`0E0?ooo`030000003oool0oooo04l0oooo00<000000?ooo`3o
ool0;P3oool00`000000oooo0?ooo`0h0?ooo`00B`3oool00`000000oooo0?ooo`0C0?ooo`030000
003oool0oooo0540oooo00<000000?ooo`3oool0;@3oool00`000000oooo0?ooo`0h0?ooo`00C03o
ool00`000000oooo0?ooo`0A0?ooo`030000003oool0oooo0580oooo00<000000?ooo`3oool0;@3o
ool00`000000oooo0?ooo`0h0?ooo`00C@3oool00`000000oooo0?ooo`0?0?ooo`030000003oool0
oooo05@0oooo00<000000?ooo`3oool0;03oool00`000000oooo0?ooo`0h0?ooo`00CP3oool00`00
0000oooo0?ooo`0=0?ooo`030000003oool0oooo05D0oooo00<000000?ooo`3oool0;03oool00`00
0000oooo0?ooo`0h0?ooo`00C`3oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo05L0
oooo00<000000?ooo`3oool0:`3oool00`000000oooo0?ooo`0h0?ooo`00D03oool00`000000oooo
0?ooo`090?ooo`030000003oool0oooo05P0oooo00<000000?ooo`3oool0:`3oool00`000000oooo
0?ooo`0h0?ooo`00D@3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo05X0oooo00<0
00000?ooo`3oool0:P3oool00`000000oooo0?ooo`0h0?ooo`00DP3oool00`000000oooo0?ooo`05
0?ooo`030000003oool0oooo05/0oooo00<000000?ooo`3oool0:P3oool00`000000oooo0?ooo`0h
0?ooo`00D`3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo05d0oooo00<000000?oo
o`3oool0:@3oool00`000000oooo0?ooo`0h0?ooo`00E03oool01@000000oooo0?ooo`3oool00000
0600oooo00<000000?ooo`3oool0:@3oool00`000000oooo0?ooo`0h0?ooo`00E@3oool00`000000
oooo0000001R0?ooo`030000003oool0oooo02P0oooo00<000000?ooo`3oool0>03oool005H0oooo
00<000000?ooo`3oool0H@3oool00`000000oooo0?ooo`0X0?ooo`030000003oool0oooo03P0oooo
001F0?ooo`030000003oool0oooo0640oooo00<000000?ooo`3oool09`3oool00`000000oooo0?oo
o`0i0?ooo`00EP3oool00`000000oooo0?ooo`1R0?ooo`030000003oool0oooo02D0oooo00<00000
0?ooo`3oool0>P3oool004P0oooo0`00000;0?ooo`030000003oool0oooo0680oooo00<000000?oo
o`3oool0603oool5000000L0oooo00<000000?ooo`3oool0>`3oool004T0oooo00<000000?ooo`3o
ool02P3oool00`000000oooo0?ooo`1S0?ooo`030000003oool0oooo01P0oooo00@000000?ooo`3o
ool000001P3oool00`000000oooo0?ooo`0l0?ooo`00B@3oool00`000000oooo0?ooo`0:0?ooo`03
0000003oool0oooo06<0oooo00<000000?ooo`3oool06@3oool00`000000oooo0?ooo`050?ooo`03
0000003oool0oooo03d0oooo00190?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool0
I03oool00`000000oooo0?ooo`0I0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0
?P3oool004T0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`1T0?ooo`030000003o
ool0oooo01H0oooo00D000000?ooo`3oool0oooo000000030?ooo`030000003oool0oooo03l0oooo
00180?ooo`800000303oool00`000000oooo0?ooo`1U0?ooo`030000003oool0oooo01D0oooo00D0
00000?ooo`3oool0oooo000000020?ooo`030000003oool0oooo0400oooo00190?ooo`030000003o
ool0oooo00X0oooo00<000000?ooo`3oool0I@3oool00`000000oooo0?ooo`0F0?ooo`<000000P3o
ool00`000000oooo0?ooo`110?ooo`00EP3oool00`000000oooo0?ooo`1V0?ooo`030000003oool0
oooo01T0oooo00<000000?ooo`3oool0@P3oool005H0oooo00<000000?ooo`3oool0IP3oool00`00
0000oooo0?ooo`0H0?ooo`030000003oool0oooo04<0oooo001F0?ooo`030000003oool0oooo06L0
oooo00<000000?ooo`3oool05P3oool00`000000oooo0?ooo`140?ooo`00EP3oool00`000000oooo
0?ooo`1W0?ooo`030000003oool0oooo01D0oooo00<000000?ooo`3oool0A@3oool005H0oooo00<0
00000?ooo`3oool0J03oool00`000000oooo0?ooo`0C0?ooo`030000003oool0oooo04H0oooo001F
0?ooo`030000003oool0oooo06P0oooo00<000000?ooo`3oool04P3oool00`000000oooo0?ooo`17
0?ooo`00EP3oool00`000000oooo0?ooo`1Y0?ooo`030000003oool0oooo0100oooo00<000000?oo
o`3oool0B03oool005H0oooo00<000000?ooo`3oool0J@3oool00`000000oooo0?ooo`0?0?ooo`03
0000003oool0oooo04T0oooo001F0?ooo`030000003oool0oooo06X0oooo00<000000?ooo`3oool0
3@3oool00`000000oooo0?ooo`1:0?ooo`00EP3oool00`000000oooo0?ooo`1Z0?ooo`030000003o
ool0oooo00`0oooo00<000000?ooo`3oool0B`3oool005H0oooo00<000000?ooo`3oool0JP3oool0
0`000000oooo0?ooo`0;0?ooo`030000003oool0oooo04`0oooo001F0?ooo`030000003oool0oooo
06/0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`1=0?ooo`00EP3oool00`000000
oooo0?ooo`1[0?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool0CP3oool005H0oooo
00<000000?ooo`3oool0K03oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo04l0oooo
001F0?ooo`030000003oool0oooo06`0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?oo
o`1@0?ooo`00EP3oool00`000000oooo0?ooo`1]0?ooo`030000003oool0oooo00<0oooo00<00000
0?ooo`3oool0D@3oool005H0oooo00<000000?ooo`3oool0K@3oool00`000000oooo0?ooo`020?oo
o`030000003oool0oooo0580oooo001F0?ooo`030000003oool0oooo06h0oooo00@000000?ooo`3o
ool00000E@3oool005H0oooo00<000000?ooo`3oool0KP3oool00`000000oooo0000001F0?ooo`00
EP3oool00`000000oooo0?ooo`1_0?ooo`030000003oool0oooo05D0oooo001F0?ooo`030000003o
ool0oooo06l0oooo00<000000?ooo`3oool0E@3oool005L0oooo00<000000?ooo`3oool0KP3oool0
0`000000oooo0?ooo`1E0?ooo`00B03oool3000000d0oooo00<000000?ooo`3oool0H@3oool30000
00T0oooo00<000000?ooo`3oool0E@3oool004L0oooo00D000000?ooo`3oool0oooo0000000=0?oo
o`030000003oool0oooo0640oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`1E0?oo
o`00B`3oool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo05d0oooo1@0000090?ooo`03
0000003oool0oooo05D0oooo001;0?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool0
G03oool010000000oooo0?ooo`00000:0?ooo`030000003oool0oooo05D0oooo00170?ooo`@00000
4@3oool00`000000oooo0?ooo`1L0?ooo`030000003oool0000000X0oooo00<000000?ooo`3oool0
E@3oool004L0oooo00<000000?ooo`3oool04`3oool00`000000oooo0?ooo`1L0?ooo`8000002P3o
ool00`000000oooo0?ooo`1E0?ooo`00A`3oool500000180oooo00<000000?ooo`3oool0G03oool0
0`000000oooo0?ooo`080?ooo`030000003oool0oooo05D0oooo001O0?ooo`030000003oool0oooo
06H0oooo00<000000?ooo`3oool0E@3oool00600oooo00<000000?ooo`3oool0I@3oool00`000000
oooo0?ooo`1E0?ooo`00H@3oool00`000000oooo0?ooo`1T0?ooo`030000003oool0oooo05D0oooo
001R0?ooo`030000003oool0oooo06<0oooo00<000000?ooo`3oool0E@3oool006<0oooo00<00000
0?ooo`3oool0HP3oool00`000000oooo0?ooo`1E0?ooo`00I03oool00`000000oooo0?ooo`1Q0?oo
o`030000003oool0oooo05D0oooo001U0?ooo`030000003oool0oooo0600oooo00<000000?ooo`3o
ool0E@3oool006H0oooo00<000000?ooo`3oool0G`3oool00`000000oooo0?ooo`1E0?ooo`00I`3o
ool00`000000oooo0?ooo`1N0?ooo`030000003oool0oooo05D0oooo001X0?ooo`030000003oool0
oooo05d0oooo00<000000?ooo`3oool0E@3oool006T0oooo00<000000?ooo`3oool0G03oool00`00
0000oooo0?ooo`1E0?ooo`00JP3oool00`000000oooo0?ooo`1K0?ooo`030000003oool0oooo05D0
oooo001[0?ooo`030000003oool0oooo05X0oooo00<000000?ooo`3oool0E@3oool006`0oooo00<0
00000?ooo`3oool0F@3oool00`000000oooo0?ooo`1E0?ooo`00K@3oool00`000000oooo0?ooo`1H
0?ooo`030000003oool0oooo05D0oooo001^0?ooo`030000003oool0oooo05L0oooo00<000000?oo
o`3oool0E@3oool006l0oooo00<000000?ooo`3oool0EP3oool00`000000oooo0?ooo`1E0?ooo`00
L03oool00`000000oooo0?ooo`1E0?ooo`030000003oool0oooo05D0oooo001a0?ooo`030000003o
ool0oooo05@0oooo00<000000?ooo`3oool0E@3oool00780oooo00<000000?ooo`3oool0D`3oool0
0`000000oooo0?ooo`1E0?ooo`00L`3oool00`000000oooo0?ooo`1A0?ooo`800000E`3oool007<0
oooo00<000000?ooo`3oool0C`3oool2000005T0oooo001d0?ooo`030000003oool0oooo04`0oooo
0P00001K0?ooo`00M@3oool00`000000oooo0?ooo`130?ooo`<000000`3oool2000005d0oooo001f
0?ooo`030000003oool0oooo0440oooo00@000000?ooo`3oool0oooo0`00001O0?ooo`00M`3oool0
0`000000oooo0?ooo`100?ooo`030000003oool0oooo00800000H@3oool007P0oooo00<000000?oo
o`3oool0@03oool300000680oooo001i0?ooo`030000003oool0oooo03d0oooo0P0000030?ooo`03
0000003oool0oooo05l0oooo001j0?ooo`030000003oool0oooo03X0oooo0P0000000`3oool00000
0?ooo`020?ooo`030000003oool0oooo05l0oooo001k0?ooo`030000003oool0oooo03L0oooo0P00
00040?ooo`<00000HP3oool007`0oooo00<000000?ooo`3oool0=03oool2000006/0oooo001m0?oo
o`030000003oool0oooo0340oooo0P00001]0?ooo`00OP3oool00`000000oooo0?ooo`0^0?ooo`80
0000K`3oool007l0oooo00<000000?ooo`3oool0:`3oool200000740oooo00200?ooo`030000003o
ool0oooo02P0oooo0P00001c0?ooo`00P@3oool00`000000oooo0?ooo`0V0?ooo`030000003oool0
oooo07<0oooo00220?ooo`030000003oool0oooo02<0oooo0P00001f0?ooo`00P`3oool00`000000
oooo0?ooo`0P0?ooo`800000N03oool008@0oooo00<000000?ooo`3oool07@3oool2000007X0oooo
00250?ooo`030000003oool0oooo01X0oooo0P00001l0?ooo`00QP3oool00`000000oooo0?ooo`0G
0?ooo`800000OP3oool008L0oooo00<000000?ooo`3oool0503oool200000800oooo00280?ooo`03
0000003oool0oooo0140oooo0P0000220?ooo`00R@3oool00`000000oooo0?ooo`0>0?ooo`800000
Q03oool008X0oooo00<000000?ooo`3oool02`3oool2000008H0oooo002;0?ooo`030000003oool0
oooo00P0oooo0P0000280?ooo`00S03oool00`000000oooo0?ooo`050?ooo`800000RP3oool008d0
oooo00<000000?ooo`3oool00P3oool2000008`0oooo002>0?ooo`040000003oool00000000008h0
oooo002?0?ooo`030000003oool0oooo08h0oooo003o0?ooob40oooo003o0?ooob40oooo00220?oo
o`800000W03oool008@0oooo00<000000?ooo`3oool0V@3oool008D0oooo00<000000?ooo`3oool0
V03oool00880oooo1000002J0?ooo`00P@3oool01@000000oooo0?ooo`3oool0000009X0oooo0021
0?ooo`050000003oool0oooo0?ooo`000000VP3oool00880oooo0`00002K0?ooo`00o`3ooolQ0?oo
o`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?oo
o`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?oo
o`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?oo
o`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-1.0062, -1.00003, \
0.0174648, 0.0339103}}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(CondenseGenealogy[ExtractGenealogy[ag, 0.5]]\)], "Input",
  CellLabel->"In[825]:="],

Cell[BoxData[
    \(Node[
      9, {7}, {Node[1, {1}, {Node[a, {0}, {}], Node[b, {0}, {}]}], 
        Node[4, {3}, {Node[d, {0}, {}], Node[c, {0}, {}]}]}]\)], "Output",
  CellLabel->"Out[825]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(Show[PlotGenealogy[%]];\)\)], "Input",
  CellLabel->"In[826]:="],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.2 0.2 0.154508 0.154508 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
0 g
.5 Mabswid
[ ] 0 setdash
.3 .30902 m
.2 .15451 L
s
.3 .30902 m
.4 .15451 L
s
.7 .30902 m
.6 .15451 L
s
.7 .30902 m
.8 .15451 L
s
.5 .46353 m
.3 .30902 L
s
.5 .46353 m
.7 .30902 L
s
[(1)] .26 .33992 0 0 Mshowa
[(4)] .66 .33992 0 0 Mshowa
[(9)] .46 .49443 0 0 Mshowa
gsave
.2 .12361 -66 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(a) show
1.000 setlinewidth
grestore
gsave
.4 .12361 -66 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(b) show
1.000 setlinewidth
grestore
gsave
.6 .12361 -66 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(d) show
1.000 setlinewidth
grestore
gsave
.8 .12361 -66 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(c) show
1.000 setlinewidth
grestore
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[826]:=",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/B000`400?l00000o`00003oo`3ooolQ
0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ
0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ
0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ
0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ
0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ
0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ
0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00=`3oool4000003@0oooo1000000g0?ooo`@00000
=@3oool3000003X0oooo000f0?ooo`040000003oool0oooo000003H0oooo00@000000?ooo`3oool0
0000=@3oool010000000oooo0?ooo`00000e0?ooo`050000003oool0oooo0?ooo`000000>@3oool0
03L0oooo0`00000f0?ooo`040000003oool0oooo000003D0oooo00@000000?ooo`3oool00000=@3o
ool00`000000oooo0?ooo`0k0?ooo`00=P3oool010000000oooo0?ooo`00000f0?ooo`040000003o
ool0oooo000003D0oooo00@000000?ooo`3oool00000=@3oool01@000000oooo0?ooo`3oool00000
03T0oooo000g0?ooo`800000=`3oool3000003L0oooo0`00000f0?ooo`<00000>P3oool00700oooo
00<000000?ooo`3oool0>@3oool00`000000oooo0?ooo`1a0?ooo`00K`3oool2000003X0oooo0P00
001c0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00>@3o
ool00`000000oooo0?ooo`0f0?ooo`030000003oool0oooo03L0oooo00<000000?ooo`3oool0=P3o
ool00`000000oooo0?ooo`0h0?ooo`00>@3oool00`000000oooo0?ooo`0f0?ooo`030000003oool0
oooo03L0oooo00<000000?ooo`3oool0=P3oool00`000000oooo0?ooo`0h0?ooo`00>P3oool00`00
0000oooo0?ooo`0d0?ooo`030000003oool0oooo03T0oooo00<000000?ooo`3oool0=03oool00`00
0000oooo0?ooo`0i0?ooo`00>`3oool00`000000oooo0?ooo`0b0?ooo`030000003oool0oooo03/0
oooo00<000000?ooo`3oool0<P3oool00`000000oooo0?ooo`0j0?ooo`00>`3oool00`000000oooo
0?ooo`0b0?ooo`030000003oool0oooo03/0oooo00<000000?ooo`3oool0<P3oool00`000000oooo
0?ooo`0j0?ooo`00?03oool00`000000oooo0?ooo`0`0?ooo`030000003oool0oooo03d0oooo00<0
00000?ooo`3oool0<03oool00`000000oooo0?ooo`0k0?ooo`00?@3oool00`000000oooo0?ooo`0^
0?ooo`030000003oool0oooo03l0oooo00<000000?ooo`3oool0;P3oool00`000000oooo0?ooo`0l
0?ooo`00?@3oool00`000000oooo0?ooo`0^0?ooo`030000003oool0oooo03l0oooo00<000000?oo
o`3oool0;P3oool00`000000oooo0?ooo`0l0?ooo`00?P3oool00`000000oooo0?ooo`0/0?ooo`03
0000003oool0oooo0440oooo00<000000?ooo`3oool0;03oool00`000000oooo0?ooo`0m0?ooo`00
?`3oool00`000000oooo0?ooo`0[0?ooo`030000003oool0oooo0440oooo00<000000?ooo`3oool0
:`3oool00`000000oooo0?ooo`0n0?ooo`00?`3oool00`000000oooo0?ooo`0Z0?ooo`030000003o
ool0oooo04<0oooo00<000000?ooo`3oool0:P3oool00`000000oooo0?ooo`0n0?ooo`00@03oool0
0`000000oooo0?ooo`0X0?ooo`030000003oool0oooo04D0oooo00<000000?ooo`3oool0:03oool0
0`000000oooo0?ooo`0o0?ooo`00@@3oool00`000000oooo0?ooo`0W0?ooo`030000003oool0oooo
04D0oooo00<000000?ooo`3oool09`3oool00`000000oooo0?ooo`100?ooo`00@@3oool00`000000
oooo0?ooo`0V0?ooo`030000003oool0oooo04L0oooo00<000000?ooo`3oool09P3oool00`000000
oooo0?ooo`100?ooo`00@P3oool00`000000oooo0?ooo`0T0?ooo`030000003oool0oooo04T0oooo
00<000000?ooo`3oool0903oool00`000000oooo0?ooo`110?ooo`00@`3oool00`000000oooo0?oo
o`0S0?ooo`030000003oool0oooo04T0oooo00<000000?ooo`3oool08`3oool00`000000oooo0?oo
o`120?ooo`00@`3oool00`000000oooo0?ooo`0R0?ooo`030000003oool0oooo04/0oooo00<00000
0?ooo`3oool08P3oool00`000000oooo0?ooo`120?ooo`00A03oool00`000000oooo0?ooo`0P0?oo
o`030000003oool0oooo04d0oooo00<000000?ooo`3oool0803oool00`000000oooo0?ooo`130?oo
o`00A@3oool00`000000oooo0?ooo`0O0?ooo`030000003oool0oooo04d0oooo00<000000?ooo`3o
ool07`3oool00`000000oooo0?ooo`140?ooo`00A@3oool00`000000oooo0?ooo`0N0?ooo`030000
003oool0oooo04l0oooo00<000000?ooo`3oool07P3oool00`000000oooo0?ooo`140?ooo`00AP3o
ool00`000000oooo0?ooo`0M0?ooo`030000003oool0oooo04l0oooo00<000000?ooo`3oool07@3o
ool00`000000oooo0?ooo`150?ooo`00A`3oool00`000000oooo0?ooo`0K0?ooo`030000003oool0
oooo0540oooo00<000000?ooo`3oool06`3oool00`000000oooo0?ooo`160?ooo`00A`3oool00`00
0000oooo0?ooo`0J0?ooo`030000003oool0oooo05<0oooo00<000000?ooo`3oool06P3oool00`00
0000oooo0?ooo`160?ooo`00B03oool00`000000oooo0?ooo`0I0?ooo`030000003oool0oooo05<0
oooo00<000000?ooo`3oool06@3oool00`000000oooo0?ooo`170?ooo`00B03oool00`000000oooo
0?ooo`0H0?ooo`030000003oool0oooo05D0oooo00<000000?ooo`3oool0603oool00`000000oooo
0?ooo`170?ooo`00B@3oool00`000000oooo0?ooo`0F0?ooo`030000003oool0oooo05L0oooo00<0
00000?ooo`3oool05P3oool00`000000oooo0?ooo`180?ooo`00BP3oool00`000000oooo0?ooo`0E
0?ooo`030000003oool0oooo05L0oooo00<000000?ooo`3oool05@3oool00`000000oooo0?ooo`19
0?ooo`00BP3oool00`000000oooo0?ooo`0D0?ooo`030000003oool0oooo05T0oooo00<000000?oo
o`3oool0503oool00`000000oooo0?ooo`190?ooo`00B`3oool00`000000oooo0?ooo`0B0?ooo`03
0000003oool0oooo05/0oooo00<000000?ooo`3oool04P3oool00`000000oooo0?ooo`1:0?ooo`00
C03oool00`000000oooo0?ooo`0A0?ooo`030000003oool0oooo05/0oooo00<000000?ooo`3oool0
4@3oool00`000000oooo0?ooo`1;0?ooo`00C03oool00`000000oooo0?ooo`0@0?ooo`030000003o
ool0oooo05d0oooo00<000000?ooo`3oool0403oool00`000000oooo0?ooo`1;0?ooo`00C@3oool0
0`000000oooo0?ooo`0?0?ooo`030000003oool0oooo05d0oooo00<000000?ooo`3oool03`3oool0
0`000000oooo0?ooo`1<0?ooo`00CP3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo
05l0oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`1=0?ooo`00CP3oool00`000000
oooo0?ooo`0<0?ooo`030000003oool0oooo0640oooo00<000000?ooo`3oool0303oool00`000000
oooo0?ooo`1=0?ooo`00C`3oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo0640oooo
00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`1>0?ooo`00D03oool00`000000oooo0?oo
o`090?ooo`030000003oool0oooo06<0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?oo
o`1?0?ooo`00D03oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo06D0oooo00<00000
0?ooo`3oool0203oool00`000000oooo0?ooo`1?0?ooo`00D@3oool00`000000oooo0?ooo`070?oo
o`030000003oool0oooo06D0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`1@0?oo
o`00DP3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo06L0oooo00<000000?ooo`3o
ool01@3oool00`000000oooo0?ooo`1A0?ooo`00DP3oool00`000000oooo0?ooo`040?ooo`030000
003oool0oooo06T0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`1A0?ooo`00D`3o
ool00`000000oooo0?ooo`030?ooo`030000003oool0oooo06T0oooo00<000000?ooo`3oool00`3o
ool00`000000oooo0?ooo`1B0?ooo`00E03oool01@000000oooo0?ooo`3oool0000006d0oooo00D0
00000?ooo`3oool0oooo0000001E0?ooo`00E03oool01@000000oooo0?ooo`3oool0000006d0oooo
00D000000?ooo`3oool0oooo0000001E0?ooo`00E@3oool00`000000oooo0000001_0?ooo`030000
003oool0000005H0oooo001F0?ooo`800000K`3oool2000005L0oooo001H0?ooo`030000003oool0
oooo06/0oooo00<000000?ooo`3oool0E`3oool005T0oooo00<000000?ooo`3oool0J@3oool00`00
0000oooo0?ooo`1H0?ooo`00FP3oool2000006L0oooo0P00001K0?ooo`00G03oool00`000000oooo
0?ooo`1S0?ooo`030000003oool0oooo05/0oooo001M0?ooo`030000003oool0oooo0640oooo00<0
00000?ooo`3oool0G03oool004P0oooo0`00000C0?ooo`030000003oool0oooo05/0oooo0`000000
0`3oool000000?ooo`1N0?ooo`00B@3oool00`000000oooo0?ooo`0C0?ooo`800000G03oool30000
0600oooo00190?ooo`030000003oool0oooo01D0oooo00<000000?ooo`3oool0EP3oool500000640
oooo00190?ooo`030000003oool0oooo01H0oooo00<000000?ooo`3oool0E@3oool010000000oooo
00000000001R0?ooo`00B@3oool00`000000oooo0?ooo`0G0?ooo`800000E@3oool2000000030?oo
o`000000oooo0640oooo00180?ooo`8000006`3oool00`000000oooo0?ooo`1A0?ooo`030000003o
ool0oooo00800000HP3oool004T0oooo00<000000?ooo`3oool06P3oool00`000000oooo0?ooo`1?
0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0H03oool006L0oooo00<000000?oo
o`3oool0C@3oool00`000000oooo0?ooo`1V0?ooo`00J03oool2000004/0oooo0P00001Y0?ooo`00
JP3oool00`000000oooo0?ooo`170?ooo`030000003oool0oooo06T0oooo001[0?ooo`030000003o
ool0oooo04D0oooo00<000000?ooo`3oool0JP3oool006`0oooo0P0000130?ooo`800000K@3oool0
06h0oooo00<000000?ooo`3oool0?`3oool00`000000oooo0?ooo`1]0?ooo`00K`3oool00`000000
oooo0?ooo`0m0?ooo`030000003oool0oooo06h0oooo001`0?ooo`800000>`3oool200000740oooo
001b0?ooo`030000003oool0oooo03L0oooo00<000000?ooo`3oool0L@3oool007<0oooo00<00000
0?ooo`3oool0=@3oool00`000000oooo0?ooo`1b0?ooo`00M03oool00`000000oooo0?ooo`0c0?oo
o`030000003oool0oooo07<0oooo001e0?ooo`800000<@3oool2000007H0oooo001g0?ooo`030000
003oool0oooo02d0oooo00<000000?ooo`3oool0MP3oool007P0oooo00<000000?ooo`3oool0:`3o
ool00`000000oooo0?ooo`1g0?ooo`00N@3oool2000002T0oooo0P00001j0?ooo`00N`3oool00`00
0000oooo0?ooo`0U0?ooo`030000003oool0oooo07X0oooo001l0?ooo`030000003oool0oooo02<0
oooo00<000000?ooo`3oool0N`3oool007d0oooo0P00000Q0?ooo`800000OP3oool007l0oooo00<0
00000?ooo`3oool07@3oool00`000000oooo0?ooo`1n0?ooo`00P03oool00`000000oooo0?ooo`0K
0?ooo`030000003oool0oooo07l0oooo00210?ooo`030000003oool0oooo01T0oooo00<000000?oo
o`3oool0P03oool00880oooo0P00000G0?ooo`800000P`3oool008@0oooo00<000000?ooo`3oool0
4`3oool00`000000oooo0?ooo`230?ooo`00Q@3oool00`000000oooo0?ooo`0A0?ooo`030000003o
ool0oooo08@0oooo00260?ooo`8000003`3oool2000008L0oooo00280?ooo`030000003oool0oooo
00/0oooo00<000000?ooo`3oool0Q`3oool008T0oooo00<000000?ooo`3oool02@3oool00`000000
oooo0?ooo`280?ooo`00RP3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo08T0oooo
002;0?ooo`8000001@3oool2000008`0oooo002=0?ooo`050000003oool0oooo0?ooo`000000SP3o
ool008h0oooo00<000000?ooo`000000S`3oool008l0oooo00<000000?ooo`3oool0SP3oool00?l0
oooo8@3oool00?l0oooo8@3oool00?l0oooo8@3oool00?l0oooo8@3oool00?l0oooo8@3oool00?l0
oooo8@3oool00880oooo0P00002L0?ooo`00Q03oool00`000000oooo0?ooo`2I0?ooo`00Q@3oool0
0`000000oooo0?ooo`2H0?ooo`00PP3oool4000009X0oooo00210?ooo`050000003oool0oooo0?oo
o`000000VP3oool00840oooo00D000000?ooo`3oool0oooo0000002J0?ooo`00PP3oool3000009/0
oooo003o0?ooob40oooo003o0?ooob40oooo003o0?ooob40oooo003o0?ooob40oooo003o0?ooob40
oooo003o0?ooob40oooo003o0?ooob40oooo003o0?ooob40oooo003o0?ooob40oooo003o0?ooob40
oooo003o0?ooob40oooo003o0?ooob40oooo003o0?ooob40oooo003o0?ooob40oooo003o0?ooob40
oooo003o0?ooob40oooo003o0?ooob40oooo003o0?ooob40oooo003o0?ooob40oooo003o0?ooob40
oooo003o0?ooob40oooo003o0?ooob40oooo003o0?ooob40oooo003o0?ooob40oooo003o0?ooob40
oooo003o0?ooob40oooo003o0?ooob40oooo003o0?ooob40oooo003o0?ooob40oooo003o0?ooob40
oooo003o0?ooob40oooo0000\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-1.0062, -1.00002, \
0.0174648, 0.022607}}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(ExtractGenealogy[ag]\)], "Input",
  CellLabel->"In[828]:="],

Cell[BoxData[
    \({Node[
        9, {7}, {Node[
            5, {4}, {Node[1, {1}, {Node[a, {0}, {}], Node[b, {0}, {}]}]}], 
          Node[8, {6}, {Node[4, {3}, {Node[d, {0}, {}]}], 
              Node[7, {5}, {Node[3, {2}, {Node[c, {0}, {}]}]}]}]}], 
      Node[9, {7}, {Node[
            5, {4}, {Node[1, {1}, {Node[a, {0}, {}], Node[b, {0}, {}]}]}], 
          Node[8, {6}, {Node[
                4, {3}, {Node[d, {0}, {}], 
                  Node[2, {2}, {Node[c, {0}, {}]}]}]}]}], 
      Node[9, {7}, {Node[
            8, {6}, {Node[
                4, {3}, {Node[d, {0}, {}], 
                  Node[2, {2}, {Node[c, {0}, {}]}]}], 
              Node[7, {5}, {Node[
                    6, {4}, {Node[
                        1, {1}, {Node[a, {0}, {}], 
                          Node[b, {0}, {}]}]}]}]}]}]}\)], "Output",
  CellLabel->"Out[828]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(\(Show[PlotGenealogy[#]] &\) /@ %;\)\)], "Input",
  CellLabel->"In[829]:="],

Cell[CellGroupData[{

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.2 0.2 0.103006 0.103006 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
0 g
.5 Mabswid
[ ] 0 setdash
.3 .20601 m
.2 .10301 L
s
.3 .20601 m
.4 .10301 L
s
.8 .20601 m
.8 .10301 L
s
.6 .20601 m
.6 .10301 L
s
.3 .30902 m
.3 .20601 L
s
.8 .30902 m
.8 .20601 L
s
.7 .41202 m
.6 .20601 L
s
.7 .41202 m
.8 .30902 L
s
.5 .51503 m
.3 .30902 L
s
.5 .51503 m
.7 .41202 L
s
[(1)] .26 .22661 0 0 Mshowa
[(3)] .76 .22661 0 0 Mshowa
[(4)] .56 .22661 0 0 Mshowa
[(5)] .26 .32962 0 0 Mshowa
[(7)] .76 .32962 0 0 Mshowa
[(8)] .66 .43262 0 0 Mshowa
[(9)] .46 .53563 0 0 Mshowa
gsave
.2 .0824 -66 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(a) show
1.000 setlinewidth
grestore
gsave
.4 .0824 -66 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(b) show
1.000 setlinewidth
grestore
gsave
.6 .0824 -66 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(d) show
1.000 setlinewidth
grestore
gsave
.8 .0824 -66 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(c) show
1.000 setlinewidth
grestore
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[829]:=",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/B000`400?l00000o`00003oo`3ooolQ
0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ
0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ
0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ
0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ
0?ooo`00=`3oool4000003@0oooo1000000g0?ooo`@00000=@3oool3000003X0oooo000f0?ooo`04
0000003oool0oooo000003H0oooo00@000000?ooo`3oool00000=@3oool010000000oooo0?ooo`00
000e0?ooo`050000003oool0oooo0?ooo`000000>@3oool003L0oooo0`00000f0?ooo`040000003o
ool0oooo000003D0oooo00@000000?ooo`3oool00000=@3oool00`000000oooo0?ooo`0k0?ooo`00
=P3oool010000000oooo0?ooo`00000f0?ooo`040000003oool0oooo000003D0oooo00@000000?oo
o`3oool00000=@3oool01@000000oooo0?ooo`3oool0000003T0oooo000g0?ooo`800000=`3oool3
000003L0oooo0`00000f0?ooo`<00000>P3oool00700oooo00<000000?ooo`3oool0>@3oool00`00
0000oooo0?ooo`1a0?ooo`00K`3oool2000003X0oooo0P00001c0?ooo`00o`3ooolQ0?ooo`00>@3o
ool00`000000oooo0?ooo`0f0?ooo`030000003oool0oooo03L0oooo00<000000?ooo`3oool0=P3o
ool00`000000oooo0?ooo`0h0?ooo`00>@3oool00`000000oooo0?ooo`0f0?ooo`030000003oool0
oooo03L0oooo00<000000?ooo`3oool0=P3oool00`000000oooo0?ooo`0h0?ooo`00>P3oool00`00
0000oooo0?ooo`0d0?ooo`030000003oool0oooo03P0oooo00<000000?ooo`3oool0=P3oool00`00
0000oooo0?ooo`0h0?ooo`00>`3oool00`000000oooo0?ooo`0b0?ooo`030000003oool0oooo03T0
oooo00<000000?ooo`3oool0=P3oool00`000000oooo0?ooo`0h0?ooo`00?03oool00`000000oooo
0?ooo`0`0?ooo`030000003oool0oooo03X0oooo00<000000?ooo`3oool0=P3oool00`000000oooo
0?ooo`0h0?ooo`00?@3oool00`000000oooo0?ooo`0^0?ooo`030000003oool0oooo03/0oooo00<0
00000?ooo`3oool0=P3oool00`000000oooo0?ooo`0h0?ooo`00?P3oool00`000000oooo0?ooo`0/
0?ooo`030000003oool0oooo03`0oooo00<000000?ooo`3oool0=P3oool00`000000oooo0?ooo`0h
0?ooo`00?`3oool00`000000oooo0?ooo`0Z0?ooo`030000003oool0oooo03d0oooo00<000000?oo
o`3oool0=P3oool00`000000oooo0?ooo`0h0?ooo`00@03oool00`000000oooo0?ooo`0X0?ooo`03
0000003oool0oooo03h0oooo00<000000?ooo`3oool0=P3oool00`000000oooo0?ooo`0h0?ooo`00
@@3oool00`000000oooo0?ooo`0V0?ooo`030000003oool0oooo03l0oooo00<000000?ooo`3oool0
=P3oool00`000000oooo0?ooo`0h0?ooo`00@P3oool00`000000oooo0?ooo`0T0?ooo`030000003o
ool0oooo0400oooo00<000000?ooo`3oool0=P3oool00`000000oooo0?ooo`0h0?ooo`00@`3oool0
0`000000oooo0?ooo`0R0?ooo`030000003oool0oooo0440oooo00<000000?ooo`3oool0=P3oool0
0`000000oooo0?ooo`0h0?ooo`00A03oool00`000000oooo0?ooo`0P0?ooo`030000003oool0oooo
0480oooo00<000000?ooo`3oool0=P3oool00`000000oooo0?ooo`0h0?ooo`00A@3oool00`000000
oooo0?ooo`0N0?ooo`030000003oool0oooo04<0oooo00<000000?ooo`3oool0=P3oool00`000000
oooo0?ooo`0h0?ooo`00AP3oool00`000000oooo0?ooo`0L0?ooo`030000003oool0oooo04@0oooo
00<000000?ooo`3oool0=P3oool00`000000oooo0?ooo`0h0?ooo`00A`3oool00`000000oooo0?oo
o`0J0?ooo`030000003oool0oooo04D0oooo00<000000?ooo`3oool0=P3oool00`000000oooo0?oo
o`0h0?ooo`00B03oool00`000000oooo0?ooo`0I0?ooo`030000003oool0oooo04D0oooo00<00000
0?ooo`3oool0=P3oool00`000000oooo0?ooo`0h0?ooo`00B@3oool00`000000oooo0?ooo`0G0?oo
o`030000003oool0oooo04H0oooo00<000000?ooo`3oool0=P3oool00`000000oooo0?ooo`0h0?oo
o`00BP3oool00`000000oooo0?ooo`0E0?ooo`030000003oool0oooo04L0oooo00<000000?ooo`3o
ool0=P3oool00`000000oooo0?ooo`0h0?ooo`00B`3oool00`000000oooo0?ooo`0C0?ooo`030000
003oool0oooo04P0oooo00<000000?ooo`3oool0=P3oool00`000000oooo0?ooo`0h0?ooo`00C03o
ool00`000000oooo0?ooo`0A0?ooo`030000003oool0oooo04T0oooo00<000000?ooo`3oool0=P3o
ool00`000000oooo0?ooo`0h0?ooo`00C@3oool00`000000oooo0?ooo`0?0?ooo`030000003oool0
oooo04X0oooo00<000000?ooo`3oool0=P3oool00`000000oooo0?ooo`0h0?ooo`00CP3oool00`00
0000oooo0?ooo`0=0?ooo`030000003oool0oooo04/0oooo00<000000?ooo`3oool0=P3oool00`00
0000oooo0?ooo`0h0?ooo`00C`3oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo04`0
oooo00<000000?ooo`3oool0=P3oool00`000000oooo0?ooo`0h0?ooo`00D03oool00`000000oooo
0?ooo`090?ooo`030000003oool0oooo04d0oooo00<000000?ooo`3oool0=P3oool00`000000oooo
0?ooo`0h0?ooo`00D@3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo04h0oooo00<0
00000?ooo`3oool0=P3oool00`000000oooo0?ooo`0h0?ooo`00DP3oool00`000000oooo0?ooo`05
0?ooo`030000003oool0oooo04l0oooo00<000000?ooo`3oool0=P3oool00`000000oooo0?ooo`0h
0?ooo`00D`3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo0500oooo00<000000?oo
o`3oool0=P3oool00`000000oooo0?ooo`0h0?ooo`00E03oool01@000000oooo0?ooo`3oool00000
05<0oooo00<000000?ooo`3oool0=P3oool00`000000oooo0?ooo`0h0?ooo`00E@3oool00`000000
oooo0000001D0?ooo`030000003oool0oooo03H0oooo00<000000?ooo`3oool0>03oool005H0oooo
00<000000?ooo`3oool0D`3oool00`000000oooo0?ooo`0f0?ooo`030000003oool0oooo03P0oooo
001F0?ooo`030000003oool0oooo05<0oooo00<000000?ooo`3oool0=P3oool00`000000oooo0?oo
o`0h0?ooo`00EP3oool00`000000oooo0?ooo`1D0?ooo`030000003oool0oooo03D0oooo00<00000
0?ooo`3oool0>03oool004P0oooo0`00000;0?ooo`030000003oool0oooo04H0oooo0`00000;0?oo
o`030000003oool0oooo02L0oooo0`00000;0?ooo`030000003oool0oooo03P0oooo00190?ooo`03
0000003oool0oooo00X0oooo00<000000?ooo`3oool0A`3oool00`000000oooo0?ooo`0;0?ooo`03
0000003oool0oooo02D0oooo00D000000?ooo`3oool0oooo0000000:0?ooo`030000003oool0oooo
03P0oooo00190?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool0A03oool5000000`0
oooo00<000000?ooo`3oool0:@3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo03P0
oooo00190?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool0A03oool010000000oooo
0?ooo`00000>0?ooo`030000003oool0oooo02H0oooo0P00000;0?ooo`030000003oool0oooo03P0
oooo00190?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool0A@3oool00`000000oooo
0000000>0?ooo`030000003oool0oooo02P0oooo00<000000?ooo`3oool0203oool00`000000oooo
0?ooo`0h0?ooo`00B03oool2000000`0oooo00<000000?ooo`3oool0AP3oool2000000l0oooo00<0
00000?ooo`3oool08`3oool01@000000oooo0?ooo`3oool0000000X0oooo00<000000?ooo`3oool0
>03oool004T0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`170?ooo`030000003o
ool0oooo00d0oooo00<000000?ooo`3oool0903oool3000000/0oooo00<000000?ooo`3oool0>03o
ool005H0oooo00<000000?ooo`3oool0F03oool00`000000oooo0?ooo`0a0?ooo`030000003oool0
oooo03P0oooo001F0?ooo`030000003oool0oooo05P0oooo00<000000?ooo`3oool0<@3oool00`00
0000oooo0?ooo`0h0?ooo`00EP3oool00`000000oooo0?ooo`1H0?ooo`030000003oool0oooo0340
oooo00<000000?ooo`3oool0>03oool005H0oooo00<000000?ooo`3oool0F@3oool00`000000oooo
0?ooo`0`0?ooo`030000003oool0oooo03P0oooo001F0?ooo`030000003oool0oooo05T0oooo00<0
00000?ooo`3oool0<03oool00`000000oooo0?ooo`0h0?ooo`00EP3oool00`000000oooo0?ooo`1J
0?ooo`030000003oool0oooo02l0oooo00<000000?ooo`3oool0>03oool005H0oooo00<000000?oo
o`3oool0FP3oool00`000000oooo0?ooo`0_0?ooo`030000003oool0oooo03P0oooo001F0?ooo`03
0000003oool0oooo05/0oooo00<000000?ooo`3oool0;P3oool00`000000oooo0?ooo`0h0?ooo`00
EP3oool00`000000oooo0?ooo`1K0?ooo`030000003oool0oooo02h0oooo00<000000?ooo`3oool0
>03oool005H0oooo00<000000?ooo`3oool0G03oool00`000000oooo0?ooo`0]0?ooo`030000003o
ool0oooo03P0oooo001F0?ooo`030000003oool0oooo05`0oooo00<000000?ooo`3oool0;@3oool0
0`000000oooo0?ooo`0h0?ooo`00EP3oool00`000000oooo0?ooo`1M0?ooo`030000003oool0oooo
02`0oooo00<000000?ooo`3oool0>03oool005H0oooo00<000000?ooo`3oool0G@3oool00`000000
oooo0?ooo`0/0?ooo`030000003oool0oooo03P0oooo001F0?ooo`030000003oool0oooo05h0oooo
00<000000?ooo`3oool0:`3oool00`000000oooo0?ooo`0h0?ooo`00EP3oool00`000000oooo0?oo
o`1N0?ooo`030000003oool0oooo02/0oooo00<000000?ooo`3oool0>03oool005H0oooo00<00000
0?ooo`3oool0G`3oool00`000000oooo0?ooo`0Z0?ooo`030000003oool0oooo03P0oooo001F0?oo
o`030000003oool0oooo05l0oooo00<000000?ooo`3oool0:P3oool00`000000oooo0?ooo`0h0?oo
o`00EP3oool00`000000oooo0?ooo`1P0?ooo`030000003oool0oooo02T0oooo00<000000?ooo`3o
ool0>03oool005H0oooo00<000000?ooo`3oool0H03oool00`000000oooo0?ooo`0Y0?ooo`030000
003oool0oooo03P0oooo001F0?ooo`030000003oool0oooo0640oooo00<000000?ooo`3oool0:03o
ool00`000000oooo0?ooo`0h0?ooo`00EP3oool00`000000oooo0?ooo`1Q0?ooo`030000003oool0
oooo02P0oooo00<000000?ooo`3oool0>03oool005L0oooo00<000000?ooo`3oool0H03oool00`00
0000oooo0?ooo`0W0?ooo`030000003oool0oooo03T0oooo00180?ooo`<000003@3oool00`000000
oooo0?ooo`1P0?ooo`030000003oool0oooo01X0oooo00<000000?ooo`3oool0203oool00`000000
oooo0?ooo`0j0?ooo`00A`3oool01@000000oooo0?ooo`3oool0000000d0oooo00<000000?ooo`3o
ool0G`3oool00`000000oooo0?ooo`0J0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3o
ool0>`3oool004/0oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`1O0?ooo`030000
003oool0oooo01X0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`0l0?ooo`00B`3o
ool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo05h0oooo00<000000?ooo`3oool06P3o
ool00`000000oooo0?ooo`040?ooo`030000003oool0oooo03d0oooo00170?ooo`@000004@3oool0
0`000000oooo0?ooo`1N0?ooo`030000003oool0oooo01X0oooo00<000000?ooo`3oool00P3oool0
0`000000oooo0?ooo`0n0?ooo`00A`3oool00`000000oooo0?ooo`0C0?ooo`030000003oool0oooo
05d0oooo00<000000?ooo`3oool05P3oool01@000000oooo0?ooo`3oool0000000<0oooo00<00000
0?ooo`3oool0?`3oool004L0oooo1@00000B0?ooo`030000003oool0oooo05d0oooo00<000000?oo
o`3oool05@3oool500000080oooo00<000000?ooo`3oool0@03oool005l0oooo00<000000?ooo`3o
ool0G03oool00`000000oooo0?ooo`0K0?ooo`030000003oool0oooo0440oooo001P0?ooo`030000
003oool0oooo05`0oooo00<000000?ooo`3oool06@3oool00`000000oooo0?ooo`120?ooo`00H@3o
ool00`000000oooo0?ooo`1K0?ooo`030000003oool0oooo01P0oooo00<000000?ooo`3oool0@`3o
ool00680oooo00<000000?ooo`3oool0F`3oool00`000000oooo0?ooo`0F0?ooo`030000003oool0
oooo04@0oooo001S0?ooo`030000003oool0oooo05X0oooo00<000000?ooo`3oool05@3oool00`00
0000oooo0?ooo`150?ooo`00I03oool00`000000oooo0?ooo`1J0?ooo`030000003oool0oooo01<0
oooo00<000000?ooo`3oool0AP3oool006D0oooo00<000000?ooo`3oool0F@3oool00`000000oooo
0?ooo`0B0?ooo`030000003oool0oooo04L0oooo001V0?ooo`030000003oool0oooo05T0oooo00<0
00000?ooo`3oool0403oool00`000000oooo0?ooo`180?ooo`00I`3oool00`000000oooo0?ooo`1H
0?ooo`030000003oool0oooo00l0oooo00<000000?ooo`3oool0B@3oool006P0oooo00<000000?oo
o`3oool0F03oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo04X0oooo001Y0?ooo`03
0000003oool0oooo05L0oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`1;0?ooo`00
JP3oool00`000000oooo0?ooo`1F0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool0
C03oool006/0oooo00<000000?ooo`3oool0EP3oool00`000000oooo0?ooo`090?ooo`030000003o
ool0oooo04d0oooo001/0?ooo`030000003oool0oooo05D0oooo00<000000?ooo`3oool0203oool0
0`000000oooo0?ooo`1>0?ooo`00K@3oool00`000000oooo0?ooo`1E0?ooo`030000003oool0oooo
00H0oooo00<000000?ooo`3oool0C`3oool006h0oooo00<000000?ooo`3oool0E03oool00`000000
oooo0?ooo`050?ooo`030000003oool0oooo0500oooo001_0?ooo`030000003oool0oooo05@0oooo
00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`1A0?ooo`00L03oool00`000000oooo0?oo
o`1C0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0DP3oool00740oooo00<00000
0?ooo`3oool0D`3oool010000000oooo0?ooo`00001E0?ooo`00LP3oool00`000000oooo0?ooo`1B
0?ooo`030000003oool0000005H0oooo001c0?ooo`030000003oool0oooo0540oooo0P00001G0?oo
o`00L`3oool00`000000oooo0?ooo`1?0?ooo`800000F@3oool007@0oooo00<000000?ooo`3oool0
C03oool2000005/0oooo001e0?ooo`030000003oool0oooo04<0oooo0`0000030?ooo`800000G@3o
ool007H0oooo00<000000?ooo`3oool0@@3oool010000000oooo0?ooo`3oool3000005l0oooo001g
0?ooo`030000003oool0oooo0400oooo00<000000?ooo`3oool00P00001Q0?ooo`00N03oool00`00
0000oooo0?ooo`100?ooo`<00000HP3oool007T0oooo00<000000?ooo`3oool0?@3oool2000000<0
oooo00<000000?ooo`3oool0G`3oool007X0oooo00<000000?ooo`3oool0>P3oool2000000030?oo
o`000000oooo0080oooo00<000000?ooo`3oool0G`3oool007/0oooo00<000000?ooo`3oool0=`3o
ool2000000@0oooo0`00001R0?ooo`00O03oool00`000000oooo0?ooo`0d0?ooo`800000J`3oool0
07d0oooo00<000000?ooo`3oool0<@3oool2000006d0oooo001n0?ooo`030000003oool0oooo02h0
oooo0P00001_0?ooo`00O`3oool00`000000oooo0?ooo`0[0?ooo`800000L@3oool00800oooo00<0
00000?ooo`3oool0:03oool2000007<0oooo00210?ooo`030000003oool0oooo02H0oooo00<00000
0?ooo`3oool0L`3oool00880oooo00<000000?ooo`3oool08`3oool2000007H0oooo00230?ooo`03
0000003oool0oooo0200oooo0P00001h0?ooo`00Q03oool00`000000oooo0?ooo`0M0?ooo`800000
NP3oool008D0oooo00<000000?ooo`3oool06P3oool2000007`0oooo00260?ooo`030000003oool0
oooo01L0oooo0P00001n0?ooo`00Q`3oool00`000000oooo0?ooo`0D0?ooo`800000P03oool008P0
oooo00<000000?ooo`3oool04@3oool200000880oooo00290?ooo`030000003oool0oooo00h0oooo
0P0000240?ooo`00RP3oool00`000000oooo0?ooo`0;0?ooo`800000QP3oool008/0oooo00<00000
0?ooo`3oool0203oool2000008P0oooo002<0?ooo`030000003oool0oooo00D0oooo0P00002:0?oo
o`00S@3oool00`000000oooo0?ooo`020?ooo`800000S03oool008h0oooo00@000000?ooo`000000
0000SP3oool008l0oooo00<000000?ooo`3oool0SP3oool00?l0oooo8@3oool00?l0oooo8@3oool0
0880oooo0P00002L0?ooo`00Q03oool00`000000oooo0?ooo`2I0?ooo`00Q@3oool00`000000oooo
0?ooo`2H0?ooo`00PP3oool4000009X0oooo00210?ooo`050000003oool0oooo0?ooo`000000VP3o
ool00840oooo00D000000?ooo`3oool0oooo0000002J0?ooo`00PP3oool3000009/0oooo003o0?oo
ob40oooo003o0?ooob40oooo003o0?ooob40oooo003o0?ooob40oooo003o0?ooob40oooo003o0?oo
ob40oooo003o0?ooob40oooo003o0?ooob40oooo003o0?ooob40oooo003o0?ooob40oooo003o0?oo
ob40oooo003o0?ooob40oooo003o0?ooob40oooo003o0?ooob40oooo003o0?ooob40oooo003o0?oo
ob40oooo003o0?ooob40oooo003o0?ooob40oooo003o0?ooob40oooo003o0?ooob40oooo0000\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-1.0062, -1.00003, \
0.0174648, 0.0339103}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.2 0.2 0.103006 0.103006 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
0 g
.5 Mabswid
[ ] 0 setdash
.3 .20601 m
.2 .10301 L
s
.3 .20601 m
.4 .10301 L
s
.8 .20601 m
.8 .10301 L
s
.7 .30902 m
.6 .10301 L
s
.7 .30902 m
.8 .20601 L
s
.3 .30902 m
.3 .20601 L
s
.7 .41202 m
.7 .30902 L
s
.5 .51503 m
.3 .30902 L
s
.5 .51503 m
.7 .41202 L
s
[(1)] .26 .22661 0 0 Mshowa
[(2)] .76 .22661 0 0 Mshowa
[(4)] .66 .32962 0 0 Mshowa
[(5)] .26 .32962 0 0 Mshowa
[(8)] .66 .43262 0 0 Mshowa
[(9)] .46 .53563 0 0 Mshowa
gsave
.2 .0824 -66 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(a) show
1.000 setlinewidth
grestore
gsave
.4 .0824 -66 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(b) show
1.000 setlinewidth
grestore
gsave
.6 .0824 -66 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(d) show
1.000 setlinewidth
grestore
gsave
.8 .0824 -66 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(c) show
1.000 setlinewidth
grestore
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[829]:=",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/B000`400?l00000o`00003oo`3ooolQ
0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ
0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ
0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ
0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ
0?ooo`00=`3oool4000003@0oooo1000000g0?ooo`@00000=@3oool3000003X0oooo000f0?ooo`04
0000003oool0oooo000003H0oooo00@000000?ooo`3oool00000=@3oool010000000oooo0?ooo`00
000e0?ooo`050000003oool0oooo0?ooo`000000>@3oool003L0oooo0`00000f0?ooo`040000003o
ool0oooo000003D0oooo00@000000?ooo`3oool00000=@3oool00`000000oooo0?ooo`0k0?ooo`00
=P3oool010000000oooo0?ooo`00000f0?ooo`040000003oool0oooo000003D0oooo00@000000?oo
o`3oool00000=@3oool01@000000oooo0?ooo`3oool0000003T0oooo000g0?ooo`800000=`3oool3
000003L0oooo0`00000f0?ooo`<00000>P3oool00700oooo00<000000?ooo`3oool0>@3oool00`00
0000oooo0?ooo`1a0?ooo`00K`3oool2000003X0oooo0P00001c0?ooo`00o`3ooolQ0?ooo`00>@3o
ool00`000000oooo0?ooo`0f0?ooo`030000003oool0oooo03L0oooo00<000000?ooo`3oool0=P3o
ool00`000000oooo0?ooo`0h0?ooo`00>@3oool00`000000oooo0?ooo`0f0?ooo`030000003oool0
oooo03L0oooo00<000000?ooo`3oool0=P3oool00`000000oooo0?ooo`0h0?ooo`00>P3oool00`00
0000oooo0?ooo`0d0?ooo`030000003oool0oooo03T0oooo00<000000?ooo`3oool0=@3oool00`00
0000oooo0?ooo`0h0?ooo`00>`3oool00`000000oooo0?ooo`0b0?ooo`030000003oool0oooo03X0
oooo00<000000?ooo`3oool0=@3oool00`000000oooo0?ooo`0h0?ooo`00?03oool00`000000oooo
0?ooo`0`0?ooo`030000003oool0oooo03`0oooo00<000000?ooo`3oool0=03oool00`000000oooo
0?ooo`0h0?ooo`00?@3oool00`000000oooo0?ooo`0^0?ooo`030000003oool0oooo03d0oooo00<0
00000?ooo`3oool0=03oool00`000000oooo0?ooo`0h0?ooo`00?P3oool00`000000oooo0?ooo`0/
0?ooo`030000003oool0oooo03l0oooo00<000000?ooo`3oool0<`3oool00`000000oooo0?ooo`0h
0?ooo`00?`3oool00`000000oooo0?ooo`0Z0?ooo`030000003oool0oooo0400oooo00<000000?oo
o`3oool0<`3oool00`000000oooo0?ooo`0h0?ooo`00@03oool00`000000oooo0?ooo`0X0?ooo`03
0000003oool0oooo0480oooo00<000000?ooo`3oool0<P3oool00`000000oooo0?ooo`0h0?ooo`00
@@3oool00`000000oooo0?ooo`0V0?ooo`030000003oool0oooo04<0oooo00<000000?ooo`3oool0
<P3oool00`000000oooo0?ooo`0h0?ooo`00@P3oool00`000000oooo0?ooo`0T0?ooo`030000003o
ool0oooo04D0oooo00<000000?ooo`3oool0<@3oool00`000000oooo0?ooo`0h0?ooo`00@`3oool0
0`000000oooo0?ooo`0R0?ooo`030000003oool0oooo04H0oooo00<000000?ooo`3oool0<@3oool0
0`000000oooo0?ooo`0h0?ooo`00A03oool00`000000oooo0?ooo`0P0?ooo`030000003oool0oooo
04L0oooo00<000000?ooo`3oool0<@3oool00`000000oooo0?ooo`0h0?ooo`00A@3oool00`000000
oooo0?ooo`0N0?ooo`030000003oool0oooo04T0oooo00<000000?ooo`3oool0<03oool00`000000
oooo0?ooo`0h0?ooo`00AP3oool00`000000oooo0?ooo`0L0?ooo`030000003oool0oooo04X0oooo
00<000000?ooo`3oool0<03oool00`000000oooo0?ooo`0h0?ooo`00A`3oool00`000000oooo0?oo
o`0J0?ooo`030000003oool0oooo04`0oooo00<000000?ooo`3oool0;`3oool00`000000oooo0?oo
o`0h0?ooo`00B03oool00`000000oooo0?ooo`0I0?ooo`030000003oool0oooo04`0oooo00<00000
0?ooo`3oool0;`3oool00`000000oooo0?ooo`0h0?ooo`00B@3oool00`000000oooo0?ooo`0G0?oo
o`030000003oool0oooo04h0oooo00<000000?ooo`3oool0;P3oool00`000000oooo0?ooo`0h0?oo
o`00BP3oool00`000000oooo0?ooo`0E0?ooo`030000003oool0oooo04l0oooo00<000000?ooo`3o
ool0;P3oool00`000000oooo0?ooo`0h0?ooo`00B`3oool00`000000oooo0?ooo`0C0?ooo`030000
003oool0oooo0540oooo00<000000?ooo`3oool0;@3oool00`000000oooo0?ooo`0h0?ooo`00C03o
ool00`000000oooo0?ooo`0A0?ooo`030000003oool0oooo0580oooo00<000000?ooo`3oool0;@3o
ool00`000000oooo0?ooo`0h0?ooo`00C@3oool00`000000oooo0?ooo`0?0?ooo`030000003oool0
oooo05@0oooo00<000000?ooo`3oool0;03oool00`000000oooo0?ooo`0h0?ooo`00CP3oool00`00
0000oooo0?ooo`0=0?ooo`030000003oool0oooo05D0oooo00<000000?ooo`3oool0;03oool00`00
0000oooo0?ooo`0h0?ooo`00C`3oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo05L0
oooo00<000000?ooo`3oool0:`3oool00`000000oooo0?ooo`0h0?ooo`00D03oool00`000000oooo
0?ooo`090?ooo`030000003oool0oooo05P0oooo00<000000?ooo`3oool0:`3oool00`000000oooo
0?ooo`0h0?ooo`00D@3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo05X0oooo00<0
00000?ooo`3oool0:P3oool00`000000oooo0?ooo`0h0?ooo`00DP3oool00`000000oooo0?ooo`05
0?ooo`030000003oool0oooo05/0oooo00<000000?ooo`3oool0:P3oool00`000000oooo0?ooo`0h
0?ooo`00D`3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo05d0oooo00<000000?oo
o`3oool0:@3oool00`000000oooo0?ooo`0h0?ooo`00E03oool01@000000oooo0?ooo`3oool00000
0600oooo00<000000?ooo`3oool0:@3oool00`000000oooo0?ooo`0h0?ooo`00E@3oool00`000000
oooo0000001R0?ooo`030000003oool0oooo02P0oooo00<000000?ooo`3oool0>03oool005H0oooo
00<000000?ooo`3oool0H@3oool00`000000oooo0?ooo`0X0?ooo`030000003oool0oooo03P0oooo
001F0?ooo`030000003oool0oooo0640oooo00<000000?ooo`3oool09`3oool00`000000oooo0?oo
o`0i0?ooo`00EP3oool00`000000oooo0?ooo`1R0?ooo`030000003oool0oooo02D0oooo00<00000
0?ooo`3oool0>P3oool004P0oooo0`00000;0?ooo`030000003oool0oooo0680oooo00<000000?oo
o`3oool0603oool5000000L0oooo00<000000?ooo`3oool0>`3oool004T0oooo00<000000?ooo`3o
ool02P3oool00`000000oooo0?ooo`1S0?ooo`030000003oool0oooo01P0oooo00@000000?ooo`3o
ool000001P3oool00`000000oooo0?ooo`0l0?ooo`00B@3oool00`000000oooo0?ooo`0:0?ooo`03
0000003oool0oooo06<0oooo00<000000?ooo`3oool06@3oool00`000000oooo0?ooo`050?ooo`03
0000003oool0oooo03d0oooo00190?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool0
I03oool00`000000oooo0?ooo`0I0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0
?P3oool004T0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`1T0?ooo`030000003o
ool0oooo01H0oooo00D000000?ooo`3oool0oooo000000030?ooo`030000003oool0oooo03l0oooo
00180?ooo`800000303oool00`000000oooo0?ooo`1U0?ooo`030000003oool0oooo01D0oooo00D0
00000?ooo`3oool0oooo000000020?ooo`030000003oool0oooo0400oooo00190?ooo`030000003o
ool0oooo00X0oooo00<000000?ooo`3oool0I@3oool00`000000oooo0?ooo`0F0?ooo`<000000P3o
ool00`000000oooo0?ooo`110?ooo`00EP3oool00`000000oooo0?ooo`1V0?ooo`030000003oool0
oooo01T0oooo00<000000?ooo`3oool0@P3oool005H0oooo00<000000?ooo`3oool0IP3oool00`00
0000oooo0?ooo`0H0?ooo`030000003oool0oooo04<0oooo001F0?ooo`030000003oool0oooo06L0
oooo00<000000?ooo`3oool05P3oool00`000000oooo0?ooo`140?ooo`00EP3oool00`000000oooo
0?ooo`1W0?ooo`030000003oool0oooo01D0oooo00<000000?ooo`3oool0A@3oool005H0oooo00<0
00000?ooo`3oool0J03oool00`000000oooo0?ooo`0C0?ooo`030000003oool0oooo04H0oooo001F
0?ooo`030000003oool0oooo06P0oooo00<000000?ooo`3oool04P3oool00`000000oooo0?ooo`17
0?ooo`00EP3oool00`000000oooo0?ooo`1Y0?ooo`030000003oool0oooo0100oooo00<000000?oo
o`3oool0B03oool005H0oooo00<000000?ooo`3oool0J@3oool00`000000oooo0?ooo`0?0?ooo`03
0000003oool0oooo04T0oooo001F0?ooo`030000003oool0oooo06X0oooo00<000000?ooo`3oool0
3@3oool00`000000oooo0?ooo`1:0?ooo`00EP3oool00`000000oooo0?ooo`1Z0?ooo`030000003o
ool0oooo00`0oooo00<000000?ooo`3oool0B`3oool005H0oooo00<000000?ooo`3oool0JP3oool0
0`000000oooo0?ooo`0;0?ooo`030000003oool0oooo04`0oooo001F0?ooo`030000003oool0oooo
06/0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`1=0?ooo`00EP3oool00`000000
oooo0?ooo`1[0?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool0CP3oool005H0oooo
00<000000?ooo`3oool0K03oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo04l0oooo
001F0?ooo`030000003oool0oooo06`0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?oo
o`1@0?ooo`00EP3oool00`000000oooo0?ooo`1]0?ooo`030000003oool0oooo00<0oooo00<00000
0?ooo`3oool0D@3oool005H0oooo00<000000?ooo`3oool0K@3oool00`000000oooo0?ooo`020?oo
o`030000003oool0oooo0580oooo001F0?ooo`030000003oool0oooo06h0oooo00@000000?ooo`3o
ool00000E@3oool005H0oooo00<000000?ooo`3oool0KP3oool00`000000oooo0000001F0?ooo`00
EP3oool00`000000oooo0?ooo`1_0?ooo`030000003oool0oooo05D0oooo001F0?ooo`030000003o
ool0oooo06l0oooo00<000000?ooo`3oool0E@3oool005L0oooo00<000000?ooo`3oool0KP3oool0
0`000000oooo0?ooo`1E0?ooo`00B03oool3000000d0oooo00<000000?ooo`3oool0H@3oool30000
00T0oooo00<000000?ooo`3oool0E@3oool004L0oooo00D000000?ooo`3oool0oooo0000000=0?oo
o`030000003oool0oooo0640oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`1E0?oo
o`00B`3oool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo05d0oooo1@0000090?ooo`03
0000003oool0oooo05D0oooo001;0?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool0
G03oool010000000oooo0?ooo`00000:0?ooo`030000003oool0oooo05D0oooo00170?ooo`@00000
4@3oool00`000000oooo0?ooo`1L0?ooo`030000003oool0000000X0oooo00<000000?ooo`3oool0
E@3oool004L0oooo00<000000?ooo`3oool04`3oool00`000000oooo0?ooo`1L0?ooo`8000002P3o
ool00`000000oooo0?ooo`1E0?ooo`00A`3oool500000180oooo00<000000?ooo`3oool0G03oool0
0`000000oooo0?ooo`080?ooo`030000003oool0oooo05D0oooo001O0?ooo`030000003oool0oooo
06H0oooo00<000000?ooo`3oool0E@3oool00600oooo00<000000?ooo`3oool0I@3oool00`000000
oooo0?ooo`1E0?ooo`00H@3oool00`000000oooo0?ooo`1T0?ooo`030000003oool0oooo05D0oooo
001R0?ooo`030000003oool0oooo06<0oooo00<000000?ooo`3oool0E@3oool006<0oooo00<00000
0?ooo`3oool0HP3oool00`000000oooo0?ooo`1E0?ooo`00I03oool00`000000oooo0?ooo`1Q0?oo
o`030000003oool0oooo05D0oooo001U0?ooo`030000003oool0oooo0600oooo00<000000?ooo`3o
ool0E@3oool006H0oooo00<000000?ooo`3oool0G`3oool00`000000oooo0?ooo`1E0?ooo`00I`3o
ool00`000000oooo0?ooo`1N0?ooo`030000003oool0oooo05D0oooo001X0?ooo`030000003oool0
oooo05d0oooo00<000000?ooo`3oool0E@3oool006T0oooo00<000000?ooo`3oool0G03oool00`00
0000oooo0?ooo`1E0?ooo`00JP3oool00`000000oooo0?ooo`1K0?ooo`030000003oool0oooo05D0
oooo001[0?ooo`030000003oool0oooo05X0oooo00<000000?ooo`3oool0E@3oool006`0oooo00<0
00000?ooo`3oool0F@3oool00`000000oooo0?ooo`1E0?ooo`00K@3oool00`000000oooo0?ooo`1H
0?ooo`030000003oool0oooo05D0oooo001^0?ooo`030000003oool0oooo05L0oooo00<000000?oo
o`3oool0E@3oool006l0oooo00<000000?ooo`3oool0EP3oool00`000000oooo0?ooo`1E0?ooo`00
L03oool00`000000oooo0?ooo`1E0?ooo`030000003oool0oooo05D0oooo001a0?ooo`030000003o
ool0oooo05@0oooo00<000000?ooo`3oool0E@3oool00780oooo00<000000?ooo`3oool0D`3oool0
0`000000oooo0?ooo`1E0?ooo`00L`3oool00`000000oooo0?ooo`1A0?ooo`800000E`3oool007<0
oooo00<000000?ooo`3oool0C`3oool2000005T0oooo001d0?ooo`030000003oool0oooo04`0oooo
0P00001K0?ooo`00M@3oool00`000000oooo0?ooo`130?ooo`<000000`3oool2000005d0oooo001f
0?ooo`030000003oool0oooo0440oooo00@000000?ooo`3oool0oooo0`00001O0?ooo`00M`3oool0
0`000000oooo0?ooo`100?ooo`030000003oool0oooo00800000H@3oool007P0oooo00<000000?oo
o`3oool0@03oool300000680oooo001i0?ooo`030000003oool0oooo03d0oooo0P0000030?ooo`03
0000003oool0oooo05l0oooo001j0?ooo`030000003oool0oooo03X0oooo0P0000000`3oool00000
0?ooo`020?ooo`030000003oool0oooo05l0oooo001k0?ooo`030000003oool0oooo03L0oooo0P00
00040?ooo`<00000HP3oool007`0oooo00<000000?ooo`3oool0=03oool2000006/0oooo001m0?oo
o`030000003oool0oooo0340oooo0P00001]0?ooo`00OP3oool00`000000oooo0?ooo`0^0?ooo`80
0000K`3oool007l0oooo00<000000?ooo`3oool0:`3oool200000740oooo00200?ooo`030000003o
ool0oooo02P0oooo0P00001c0?ooo`00P@3oool00`000000oooo0?ooo`0V0?ooo`030000003oool0
oooo07<0oooo00220?ooo`030000003oool0oooo02<0oooo0P00001f0?ooo`00P`3oool00`000000
oooo0?ooo`0P0?ooo`800000N03oool008@0oooo00<000000?ooo`3oool07@3oool2000007X0oooo
00250?ooo`030000003oool0oooo01X0oooo0P00001l0?ooo`00QP3oool00`000000oooo0?ooo`0G
0?ooo`800000OP3oool008L0oooo00<000000?ooo`3oool0503oool200000800oooo00280?ooo`03
0000003oool0oooo0140oooo0P0000220?ooo`00R@3oool00`000000oooo0?ooo`0>0?ooo`800000
Q03oool008X0oooo00<000000?ooo`3oool02`3oool2000008H0oooo002;0?ooo`030000003oool0
oooo00P0oooo0P0000280?ooo`00S03oool00`000000oooo0?ooo`050?ooo`800000RP3oool008d0
oooo00<000000?ooo`3oool00P3oool2000008`0oooo002>0?ooo`040000003oool00000000008h0
oooo002?0?ooo`030000003oool0oooo08h0oooo003o0?ooob40oooo003o0?ooob40oooo00220?oo
o`800000W03oool008@0oooo00<000000?ooo`3oool0V@3oool008D0oooo00<000000?ooo`3oool0
V03oool00880oooo1000002J0?ooo`00P@3oool01@000000oooo0?ooo`3oool0000009X0oooo0021
0?ooo`050000003oool0oooo0?ooo`000000VP3oool00880oooo0`00002K0?ooo`00o`3ooolQ0?oo
o`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?oo
o`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?oo
o`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?oo
o`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-1.0062, -1.00003, \
0.0174648, 0.0339103}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.2 0.2 0.0882906 0.0882906 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
0 g
.5 Mabswid
[ ] 0 setdash
.7 .17658 m
.6 .08829 L
s
.7 .17658 m
.8 .08829 L
s
.4 .17658 m
.4 .08829 L
s
.3 .26487 m
.2 .08829 L
s
.3 .26487 m
.4 .17658 L
s
.7 .26487 m
.7 .17658 L
s
.7 .35316 m
.7 .26487 L
s
.5 .44145 m
.3 .26487 L
s
.5 .44145 m
.7 .35316 L
s
.5 .52974 m
.5 .44145 L
s
[(1)] .66 .19424 0 0 Mshowa
[(2)] .36 .19424 0 0 Mshowa
[(4)] .26 .28253 0 0 Mshowa
[(6)] .66 .28253 0 0 Mshowa
[(7)] .66 .37082 0 0 Mshowa
[(8)] .46 .45911 0 0 Mshowa
[(9)] .46 .5474 0 0 Mshowa
gsave
.2 .07063 -66 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(d) show
1.000 setlinewidth
grestore
gsave
.4 .07063 -66 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(c) show
1.000 setlinewidth
grestore
gsave
.6 .07063 -66 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(a) show
1.000 setlinewidth
grestore
gsave
.8 .07063 -66 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(b) show
1.000 setlinewidth
grestore
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[829]:=",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/B000`400?l00000o`00003oo`3ooolQ
0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ
0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ
0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ
0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00=`3oool4000003D0oooo0`00000g0?ooo`@00000
=03oool4000003X0oooo000f0?ooo`040000003oool0oooo000003D0oooo00D000000?ooo`3oool0
oooo0000000e0?ooo`040000003oool0oooo000003H0oooo00@000000?ooo`3oool00000>@3oool0
03H0oooo00@000000?ooo`3oool00000=@3oool00`000000oooo0?ooo`0h0?ooo`<00000=P3oool0
10000000oooo0?ooo`00000i0?ooo`00=P3oool010000000oooo0?ooo`00000e0?ooo`050000003o
ool0oooo0?ooo`000000=@3oool010000000oooo0?ooo`00000f0?ooo`040000003oool0oooo0000
03T0oooo000g0?ooo`<00000=P3oool3000003L0oooo0P00000g0?ooo`<00000>P3oool003T0oooo
00<000000?ooo`3oool0Y`3oool00`000000oooo0?ooo`0j0?ooo`00>03oool200000:P0oooo0P00
000l0?ooo`00>@3oool00`000000oooo0?ooo`0f0?ooo`030000003oool0oooo03L0oooo0P00000f
0?ooo`800000>P3oool003T0oooo00<000000?ooo`3oool0=P3oool00`000000oooo0?ooo`0i0?oo
o`030000003oool0oooo0380oooo00<000000?ooo`3oool0>P3oool003X0oooo00<000000?ooo`3o
ool0=@3oool00`000000oooo0?ooo`0j0?ooo`030000003oool0oooo0300oooo00<000000?ooo`3o
ool0>`3oool003X0oooo00<000000?ooo`3oool0=@3oool00`000000oooo0?ooo`0k0?ooo`030000
003oool0oooo02h0oooo00<000000?ooo`3oool0?03oool003/0oooo00<000000?ooo`3oool0=03o
ool00`000000oooo0?ooo`0l0?ooo`030000003oool0oooo02`0oooo00<000000?ooo`3oool0?@3o
ool003`0oooo00<000000?ooo`3oool0<`3oool00`000000oooo0?ooo`0m0?ooo`030000003oool0
oooo02X0oooo00<000000?ooo`3oool0?P3oool003`0oooo00<000000?ooo`3oool0<`3oool00`00
0000oooo0?ooo`0n0?ooo`030000003oool0oooo02L0oooo0P0000110?ooo`00?@3oool00`000000
oooo0?ooo`0b0?ooo`030000003oool0oooo03l0oooo00<000000?ooo`3oool09@3oool00`000000
oooo0?ooo`110?ooo`00?@3oool00`000000oooo0?ooo`0b0?ooo`030000003oool0oooo0400oooo
0P00000T0?ooo`030000003oool0oooo0480oooo000n0?ooo`030000003oool0oooo0340oooo00<0
00000?ooo`3oool0@P3oool00`000000oooo0?ooo`0P0?ooo`030000003oool0oooo04<0oooo000o
0?ooo`030000003oool0oooo0300oooo00<000000?ooo`3oool0@`3oool00`000000oooo0?ooo`0N
0?ooo`030000003oool0oooo04@0oooo000o0?ooo`030000003oool0oooo0300oooo00<000000?oo
o`3oool0A03oool00`000000oooo0?ooo`0L0?ooo`030000003oool0oooo04D0oooo00100?ooo`03
0000003oool0oooo02l0oooo00<000000?ooo`3oool0A@3oool00`000000oooo0?ooo`0I0?ooo`80
0000B03oool00400oooo00<000000?ooo`3oool0;`3oool00`000000oooo0?ooo`160?ooo`030000
003oool0oooo01L0oooo00<000000?ooo`3oool0B03oool00440oooo00<000000?ooo`3oool0;P3o
ool00`000000oooo0?ooo`170?ooo`030000003oool0oooo01D0oooo00<000000?ooo`3oool0B@3o
ool00440oooo00<000000?ooo`3oool0;P3oool00`000000oooo0?ooo`180?ooo`030000003oool0
oooo01<0oooo00<000000?ooo`3oool0BP3oool00480oooo00<000000?ooo`3oool0;@3oool00`00
0000oooo0?ooo`190?ooo`030000003oool0oooo0140oooo00<000000?ooo`3oool0B`3oool004<0
oooo00<000000?ooo`3oool0;03oool00`000000oooo0?ooo`1:0?ooo`800000403oool00`000000
oooo0?ooo`1<0?ooo`00@`3oool00`000000oooo0?ooo`0/0?ooo`030000003oool0oooo04`0oooo
00<000000?ooo`3oool0303oool00`000000oooo0?ooo`1=0?ooo`00A03oool00`000000oooo0?oo
o`0[0?ooo`030000003oool0oooo04d0oooo00<000000?ooo`3oool02@3oool200000500oooo0014
0?ooo`030000003oool0oooo02/0oooo00<000000?ooo`3oool0CP3oool00`000000oooo0?ooo`07
0?ooo`030000003oool0oooo0500oooo00150?ooo`030000003oool0oooo02X0oooo00<000000?oo
o`3oool0C`3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo0540oooo00150?ooo`03
0000003oool0oooo02X0oooo00<000000?ooo`3oool0D03oool00`000000oooo0?ooo`030?ooo`03
0000003oool0oooo0580oooo00160?ooo`030000003oool0oooo02T0oooo00<000000?ooo`3oool0
D@3oool01@000000oooo0?ooo`3oool0000005D0oooo00170?ooo`030000003oool0oooo02P0oooo
00<000000?ooo`3oool0DP3oool00`000000oooo0000001F0?ooo`00A`3oool00`000000oooo0?oo
o`0W0?ooo`800000E@3oool00`000000oooo0?ooo`1E0?ooo`00B03oool00`000000oooo0?ooo`0U
0?ooo`030000003oool0oooo05D0oooo00<000000?ooo`3oool0E@3oool004P0oooo00<000000?oo
o`3oool0903oool00`000000oooo0?ooo`1F0?ooo`030000003oool0oooo05D0oooo00190?ooo`03
0000003oool0oooo01P0oooo1@0000050?ooo`030000003oool0oooo04X0oooo0`00000:0?ooo`03
0000003oool0oooo05D0oooo001:0?ooo`030000003oool0oooo01P0oooo00@000000?ooo`3oool0
0000103oool00`000000oooo0?ooo`1<0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3o
ool0E@3oool004X0oooo00<000000?ooo`3oool06@3oool00`000000oooo0?ooo`030?ooo`030000
003oool0oooo04d0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`1E0?ooo`00B`3o
ool00`000000oooo0?ooo`0I0?ooo`050000003oool0oooo0?ooo`000000D03oool00`000000oooo
0?ooo`090?ooo`030000003oool0oooo05D0oooo001;0?ooo`030000003oool0oooo01H0oooo00L0
00000?ooo`3oool0oooo0000003oool000000540oooo00<000000?ooo`3oool02@3oool00`000000
oooo0?ooo`1E0?ooo`00C03oool00`000000oooo0?ooo`0E0?ooo`040000003oool0oooo0?ooo`80
0000D@3oool2000000/0oooo00<000000?ooo`3oool0E@3oool004`0oooo00<000000?ooo`3oool0
5P3oool3000005@0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`1E0?ooo`00C@3o
ool00`000000oooo0?ooo`0F0?ooo`030000003oool0oooo05l0oooo00<000000?ooo`3oool0E@3o
ool004h0oooo00<000000?ooo`3oool0503oool00`000000oooo0?ooo`1P0?ooo`030000003oool0
oooo05D0oooo001>0?ooo`030000003oool0oooo01<0oooo00<000000?ooo`3oool0H@3oool00`00
0000oooo0?ooo`1E0?ooo`00C`3oool00`000000oooo0?ooo`0A0?ooo`030000003oool0oooo0680
oooo00<000000?ooo`3oool0E@3oool004l0oooo00<000000?ooo`3oool0403oool00`000000oooo
0?ooo`1S0?ooo`030000003oool0oooo05D0oooo001@0?ooo`030000003oool0oooo00h0oooo00<0
00000?ooo`3oool0I03oool00`000000oooo0?ooo`1E0?ooo`00D03oool00`000000oooo0?ooo`0=
0?ooo`030000003oool0oooo06D0oooo00<000000?ooo`3oool0E@3oool00540oooo00<000000?oo
o`3oool02P3oool2000006P0oooo00<000000?ooo`3oool0E@3oool00580oooo00<000000?ooo`3o
ool0203oool00`000000oooo0?ooo`1X0?ooo`030000003oool0oooo05D0oooo001B0?ooo`030000
003oool0oooo00L0oooo00<000000?ooo`3oool0J@3oool00`000000oooo0?ooo`1E0?ooo`00D`3o
ool00`000000oooo0?ooo`050?ooo`030000003oool0oooo06X0oooo00<000000?ooo`3oool0E@3o
ool005<0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`1[0?ooo`030000003oool0
oooo05D0oooo001D0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0K03oool00`00
0000oooo0?ooo`1E0?ooo`00E@3oool010000000oooo0?ooo`00001_0?ooo`030000003oool0oooo
05D0oooo001E0?ooo`030000003oool000000700oooo00<000000?ooo`3oool0E@3oool005H0oooo
0P00001`0?ooo`030000003oool0oooo05D0oooo001H0?ooo`030000003oool0oooo06d0oooo00<0
00000?ooo`3oool0E@3oool005T0oooo00<000000?ooo`3oool0K03oool00`000000oooo0?ooo`1E
0?ooo`00B@3oool3000000h0oooo00<000000?ooo`3oool0GP3oool3000000X0oooo00<000000?oo
o`3oool0E@3oool004X0oooo00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`1L0?ooo`05
0000003oool0oooo0?ooo`0000002@3oool00`000000oooo0?ooo`1E0?ooo`00A`3oool500000100
oooo00<000000?ooo`3oool0F`3oool01@000000oooo0?ooo`3oool0000000T0oooo00<000000?oo
o`3oool0E@3oool004L0oooo00@000000?ooo`3oool000004P3oool00`000000oooo0?ooo`1J0?oo
o`@000002P3oool00`000000oooo0?ooo`1E0?ooo`00B03oool00`000000oooo0000000C0?ooo`03
0000003oool0oooo05T0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`1E0?ooo`00
B@3oool2000001@0oooo0P00001J0?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool0
E@3oool004X0oooo00<000000?ooo`3oool0503oool00`000000oooo0?ooo`1H0?ooo`8000002P3o
ool00`000000oooo0?ooo`1E0?ooo`00HP3oool00`000000oooo0?ooo`1S0?ooo`030000003oool0
oooo05D0oooo001S0?ooo`030000003oool0oooo0680oooo00<000000?ooo`3oool0E@3oool006@0
oooo00<000000?ooo`3oool0H@3oool00`000000oooo0?ooo`1E0?ooo`00I@3oool00`000000oooo
0?ooo`1P0?ooo`030000003oool0oooo05D0oooo001V0?ooo`030000003oool0oooo05l0oooo00<0
00000?ooo`3oool0E@3oool006L0oooo00<000000?ooo`3oool0GP3oool00`000000oooo0?ooo`1E
0?ooo`00J03oool00`000000oooo0?ooo`1M0?ooo`030000003oool0oooo05D0oooo001Y0?ooo`80
0000G@3oool00`000000oooo0?ooo`1E0?ooo`00J`3oool00`000000oooo0?ooo`1J0?ooo`030000
003oool0oooo05D0oooo001/0?ooo`030000003oool0oooo05T0oooo00<000000?ooo`3oool0E@3o
ool006d0oooo00<000000?ooo`3oool0F03oool00`000000oooo0?ooo`1E0?ooo`00KP3oool00`00
0000oooo0?ooo`1G0?ooo`030000003oool0oooo05D0oooo001_0?ooo`030000003oool0oooo05H0
oooo00<000000?ooo`3oool0E@3oool00700oooo00<000000?ooo`3oool0E@3oool00`000000oooo
0?ooo`1E0?ooo`00L@3oool00`000000oooo0?ooo`1D0?ooo`030000003oool0oooo05D0oooo001b
0?ooo`800000E03oool00`000000oooo0?ooo`1E0?ooo`00M03oool00`000000oooo0?ooo`1@0?oo
o`800000E`3oool007D0oooo00<000000?ooo`3oool0C@3oool2000005T0oooo001f0?ooo`030000
003oool0oooo04<0oooo00<000000?ooo`3oool00`3oool3000005/0oooo001g0?ooo`030000003o
ool0oooo0480oooo00@000000?ooo`3oool0oooo0P00001N0?ooo`00N03oool00`000000oooo0?oo
o`120?ooo`<00000H03oool007T0oooo00<000000?ooo`3oool0?`3oool300000680oooo001j0?oo
o`030000003oool0oooo03`0oooo0P0000030?ooo`030000003oool0oooo05l0oooo001k0?ooo`03
0000003oool0oooo03T0oooo0P0000000`3oool000000?ooo`020?ooo`030000003oool0oooo05l0
oooo001l0?ooo`800000=`3oool2000000<0oooo1@00001Q0?ooo`00OP3oool00`000000oooo0?oo
o`0a0?ooo`<00000J`3oool007l0oooo00<000000?ooo`3oool0;P3oool2000006h0oooo00200?oo
o`030000003oool0oooo02/0oooo0P00001`0?ooo`00P@3oool00`000000oooo0?ooo`0W0?ooo`<0
0000LP3oool00880oooo00<000000?ooo`3oool0903oool2000007D0oooo00230?ooo`030000003o
ool0oooo0240oooo0P00001g0?ooo`00Q03oool00`000000oooo0?ooo`0N0?ooo`800000N@3oool0
08D0oooo0P00000K0?ooo`<00000N`3oool008L0oooo00<000000?ooo`3oool05P3oool2000007h0
oooo00280?ooo`030000003oool0oooo01<0oooo0P0000200?ooo`00R@3oool00`000000oooo0?oo
o`0@0?ooo`800000PP3oool008X0oooo00<000000?ooo`3oool0303oool3000008@0oooo002;0?oo
o`030000003oool0oooo00T0oooo0P0000270?ooo`00S03oool00`000000oooo0?ooo`060?ooo`80
0000R@3oool008d0oooo00<000000?ooo`3oool00P3oool3000008/0oooo002>0?ooo`040000003o
ool00000000008h0oooo002?0?ooo`030000003oool0oooo08h0oooo002?0?ooo`030000003oool0
oooo08h0oooo00220?ooo`<000002P3oool00`000000oooo0?ooo`2>0?ooo`00P@3oool01@000000
oooo0?ooo`3oool0000000T0oooo00<000000?ooo`3oool0SP3oool00840oooo00D000000?ooo`3o
ool0oooo000000090?ooo`030000003oool0oooo08h0oooo00220?ooo`<000002P3oool00`000000
oooo0?ooo`2>0?ooo`00P@3oool01@000000oooo0?ooo`3oool0000000T0oooo00<000000?ooo`3o
ool0SP3oool00840oooo00D000000?ooo`3oool0oooo000000090?ooo`030000003oool0oooo08h0
oooo00220?ooo`<000002P3oool00`000000oooo0?ooo`2>0?ooo`00S`3oool00`000000oooo0?oo
o`2>0?ooo`00S`3oool00`000000oooo0?ooo`2>0?ooo`00S`3oool00`000000oooo0?ooo`2>0?oo
o`00S`3oool00`000000oooo0?ooo`2>0?ooo`00S`3oool00`000000oooo0?ooo`2>0?ooo`00S`3o
ool00`000000oooo0?ooo`2>0?ooo`00S`3oool00`000000oooo0?ooo`2>0?ooo`00S`3oool00`00
0000oooo0?ooo`2>0?ooo`00S`3oool00`000000oooo0?ooo`2>0?ooo`00S`3oool00`000000oooo
0?ooo`2>0?ooo`00S`3oool00`000000oooo0?ooo`2>0?ooo`00S`3oool00`000000oooo0?ooo`2>
0?ooo`00S`3oool00`000000oooo0?ooo`2>0?ooo`00S`3oool00`000000oooo0?ooo`2>0?ooo`00
S`3oool00`000000oooo0?ooo`2>0?ooo`00S`3oool00`000000oooo0?ooo`2>0?ooo`00S`3oool0
0`000000oooo0?ooo`2>0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00PP3oool2000009`0oooo
00240?ooo`030000003oool0oooo09T0oooo00250?ooo`030000003oool0oooo09P0oooo00220?oo
o`@00000VP3oool00840oooo00D000000?ooo`3oool0oooo0000002J0?ooo`00P@3oool01@000000
oooo0?ooo`3oool0000009X0oooo00220?ooo`<00000V`3oool00?l0oooo8@3oool00?l0oooo8@3o
ool00?l0oooo8@3oool00?l0oooo8@3oool00?l0oooo8@3oool00?l0oooo8@3oool00?l0oooo8@3o
ool00?l0oooo8@3oool00?l0oooo8@3oool00?l0oooo8@3oool00?l0oooo8@3oool00?l0oooo8@3o
ool00?l0oooo8@3oool00?l0oooo8@3oool00?l0oooo8@3oool00?l0oooo8@3oool00001\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-1.0062, -1.00004, \
0.0174648, 0.0395621}}]
}, Open  ]]
}, Closed]],

Cell[BoxData[
    \(\(ag = {AncestralLineage[
            a, {0, 1}, {{a}}, {1}, {}], \[IndentingNewLine]AncestralLineage[
            b, {0, 1}, {{b}}, {1}, {}], \[IndentingNewLine]AncestralLineage[
            c, {0, 2}, {{c}}, {1}, {}], \[IndentingNewLine]AncestralLineage[
            d, {0, 3}, {{d}}, {1}, {}], \[IndentingNewLine]AncestralLineage[
            1, {1, 4}, {{a, 
                b}}, {1}, {}], \[IndentingNewLine]AncestralLineage[
            2, {2, 3}, {{}, {c}}, {0.3, 
              1}, {}], \[IndentingNewLine]AncestralLineage[
            3, {2, 5}, {{c}, {}}, {0.3, 
              1}, {}], \[IndentingNewLine]AncestralLineage[
            4, {3, 6}, {{d}, {c, d}}, {0.3, 
              1}, {}], \[IndentingNewLine]AncestralLineage[
            5, {4, 7}, {{a, b}, {}}, {0.7, 
              1}, {}], \[IndentingNewLine]AncestralLineage[
            6, {4, 5}, {{}, {a, b}}, {0.7, 
              1}, {}], \[IndentingNewLine]AncestralLineage[
            7, {5, 6}, {{c}, {}, {a, b}}, {0.3, 0.7, 
              1}, {}], \[IndentingNewLine]AncestralLineage[
            8, {6, 7}, {{c, d}, {a, b, c, d}}, {0.7, 
              1}, {}], \[IndentingNewLine]AncestralLineage[
            9, {7, \[Infinity]}, {{a, b, c, d}}, {1}, {}]};\)\)], "Input",
  CellLabel->"In[659]:="]
}, Closed]],

Cell[CellGroupData[{

Cell["Working", "SubsubsectionIcon"],

Cell[BoxData[
    \(\(<< Calculus`DSolveIntegrals`;\)\)], "Input",
  CellLabel->"In[54]:="],

Cell[CellGroupData[{

Cell[BoxData[
    \(DSolve[{\[PartialD]\_t P[t, 
              z] \[Equal] \((\(1\/2\) \[PartialD]\_\(z, z\)P[t, z])\), 
        P[0, z] \[Equal] z, P[t, 1] \[Equal] 1, P[t, 0] \[Equal] 0}, 
      P, {t, z}]\)], "Input",
  CellLabel->"In[58]:="],

Cell[BoxData[
    RowBox[{"DSolve", "[", 
      RowBox[{
        RowBox[{"{", 
          RowBox[{
            RowBox[{
              RowBox[{
                SuperscriptBox["P", 
                  TagBox[\((1, 0)\),
                    Derivative],
                  MultilineFunction->None], "[", \(t, z\), "]"}], "==", 
              RowBox[{\(1\/2\), " ", 
                RowBox[{
                  SuperscriptBox["P", 
                    TagBox[\((0, 2)\),
                      Derivative],
                    MultilineFunction->None], "[", \(t, z\), "]"}]}]}], 
            ",", \(P[0, z] == z\), ",", \(P[t, 1] == 1\), 
            ",", \(P[t, 0] == 0\)}], "}"}], ",", "P", ",", \({t, z}\)}], 
      "]"}]], "Output",
  CellLabel->"Out[58]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(?DSolve\)\)], "Input",
  CellLabel->"In[59]:="],

Cell[BoxData[
    \("DSolve[eqn, y, x] solves a differential equation for the function y, \
with independent variable x. DSolve[{eqn1, eqn2, ...  }, {y1, y2, ...  }, x] \
solves a list of differential equations. DSolve[eqn, y, {x1, x2, ... }] \
solves a partial differential equation."\)], "Print",
  CellLabel->"From In[59]:="]
}, Open  ]],

Cell[BoxData[{
    \(TextForm\`\[PartialD]\_t P\_1 = 
      P\_2 - R\ \ P\_\(\(1\)\(\ \ \ \)\)\), "\[IndentingNewLine]", 
    \(TextForm\`\[PartialD]\_t P\_2 = \((3  P\_3 - P\_2)\) - 
        R\ \((2\ P\_2 - P\_1)\)\)}], "NumberedEquation"],

Cell[BoxData[
    \(TextForm\`P\_1[t] = 
      P\_1[0] \[ExponentialE]\^\(\(-R\)\[VeryThinSpace]t\) + \
\[Integral]\_0\%t P\_2[\[Tau]] \(\[ExponentialE]\^\(\(-R\) \((t - \[Tau])\)\)\
\) \[DifferentialD]\[Tau]\)], "NumberedEquation"],

Cell[BoxData[
    \(\(<< Graphics`;\)\)], "Input",
  CellLabel->"In[2]:="],

Cell[BoxData[
    \(\(soln[P_, R_, km_, tm_] := 
        Module[{t, eqns, init, vars}, \[IndentingNewLine]vars = 
            Array[P, {km}]; \[IndentingNewLine]init = 
            Array[\((If[# \[Equal] 1, 1, 0] \[Equal] \(P[#]\)[
                      0])\) &, {km}]; \[IndentingNewLine]eqns = 
            Array[\((\[PartialD]\_t\( P[#]\)[
                        t] \[Equal] \(#\/2\) \((If[# \[Equal] km, 
                              0, \((# + 1)\) \(P[# + 1]\)[t]] - \((# - 
                                  1)\) \(P[#]\)[t])\) + 
                      R \((\((# - 1)\) \(P[# - 1]\)[t] - # \( P[#]\)[
                                t])\))\) &, {km}]; \
\[IndentingNewLine]\(NDSolve[Join[eqns, init], 
              vars, {t, 0, 
                tm}]\)\[LeftDoubleBracket]1\[RightDoubleBracket]];\)\)], \
"Input"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(tm = 10; R = 0.5; km = 20;\), "\[IndentingNewLine]", 
    \(\(ss = soln[P, R, km, tm];\)\), "\[IndentingNewLine]", 
    \(\(vv = Array[\(P[#]\)[t] &, {km}];\)\), "\[IndentingNewLine]", 
    \(\(Plot[vv /. ss // Evaluate, {t, 0, tm}, 
        PlotRange \[Rule] {{0, tm}, {0, 1}}];\)\), "\[IndentingNewLine]", 
    \(\(vv /. t \[Rule] tm\) /. ss\)}], "Input",
  CellLabel->"In[14]:="],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-2.77556e-17 0.1 0 0.618034 [
[.2 -0.0125 -3 -9 ]
[.2 -0.0125 3 0 ]
[.4 -0.0125 -3 -9 ]
[.4 -0.0125 3 0 ]
[.6 -0.0125 -3 -9 ]
[.6 -0.0125 3 0 ]
[.8 -0.0125 -3 -9 ]
[.8 -0.0125 3 0 ]
[1 -0.0125 -6 -9 ]
[1 -0.0125 6 0 ]
[-0.0125 .12361 -18 -4.5 ]
[-0.0125 .12361 0 4.5 ]
[-0.0125 .24721 -18 -4.5 ]
[-0.0125 .24721 0 4.5 ]
[-0.0125 .37082 -18 -4.5 ]
[-0.0125 .37082 0 4.5 ]
[-0.0125 .49443 -18 -4.5 ]
[-0.0125 .49443 0 4.5 ]
[-0.0125 .61803 -6 -4.5 ]
[-0.0125 .61803 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 0 m
.2 .00625 L
s
[(2)] .2 -0.0125 0 1 Mshowa
.4 0 m
.4 .00625 L
s
[(4)] .4 -0.0125 0 1 Mshowa
.6 0 m
.6 .00625 L
s
[(6)] .6 -0.0125 0 1 Mshowa
.8 0 m
.8 .00625 L
s
[(8)] .8 -0.0125 0 1 Mshowa
1 0 m
1 .00625 L
s
[(10)] 1 -0.0125 0 1 Mshowa
.125 Mabswid
.05 0 m
.05 .00375 L
s
.1 0 m
.1 .00375 L
s
.15 0 m
.15 .00375 L
s
.25 0 m
.25 .00375 L
s
.3 0 m
.3 .00375 L
s
.35 0 m
.35 .00375 L
s
.45 0 m
.45 .00375 L
s
.5 0 m
.5 .00375 L
s
.55 0 m
.55 .00375 L
s
.65 0 m
.65 .00375 L
s
.7 0 m
.7 .00375 L
s
.75 0 m
.75 .00375 L
s
.85 0 m
.85 .00375 L
s
.9 0 m
.9 .00375 L
s
.95 0 m
.95 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .12361 m
.00625 .12361 L
s
[(0.2)] -0.0125 .12361 1 0 Mshowa
0 .24721 m
.00625 .24721 L
s
[(0.4)] -0.0125 .24721 1 0 Mshowa
0 .37082 m
.00625 .37082 L
s
[(0.6)] -0.0125 .37082 1 0 Mshowa
0 .49443 m
.00625 .49443 L
s
[(0.8)] -0.0125 .49443 1 0 Mshowa
0 .61803 m
.00625 .61803 L
s
[(1)] -0.0125 .61803 1 0 Mshowa
.125 Mabswid
0 .0309 m
.00375 .0309 L
s
0 .0618 m
.00375 .0618 L
s
0 .09271 m
.00375 .09271 L
s
0 .15451 m
.00375 .15451 L
s
0 .18541 m
.00375 .18541 L
s
0 .21631 m
.00375 .21631 L
s
0 .27812 m
.00375 .27812 L
s
0 .30902 m
.00375 .30902 L
s
0 .33992 m
.00375 .33992 L
s
0 .40172 m
.00375 .40172 L
s
0 .43262 m
.00375 .43262 L
s
0 .46353 m
.00375 .46353 L
s
0 .52533 m
.00375 .52533 L
s
0 .55623 m
.00375 .55623 L
s
0 .58713 m
.00375 .58713 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
0 .61803 m
.01975 .56493 L
.04057 .52233 L
.06168 .489 L
.08481 .46079 L
.10536 .44116 L
.12734 .42449 L
.14821 .41189 L
.17086 .40101 L
.21279 .38653 L
.23362 .38136 L
.2557 .37696 L
.29542 .37118 L
.3158 .36901 L
.33773 .36713 L
.35842 .36571 L
.38101 .36446 L
.42271 .3628 L
.44336 .36221 L
.46538 .3617 L
.48636 .36131 L
.50904 .36097 L
.55111 .36052 L
.57205 .36036 L
.59417 .36022 L
.63404 .36004 L
.65452 .35997 L
.67648 .35991 L
.69728 .35987 L
.71991 .35983 L
.76175 .35978 L
.78251 .35976 L
.80457 .35974 L
.84421 .35972 L
.86452 .35972 L
.88642 .35971 L
.90705 .3597 L
.92962 .3597 L
.94974 .3597 L
.97123 .35969 L
1 .35969 L
s
0 0 m
.00942 .02603 L
.01975 .04879 L
.04057 .08234 L
.05163 .09557 L
.06347 .10726 L
.08481 .12364 L
.10718 .13629 L
.12833 .14533 L
.1493 .1523 L
.16866 .1574 L
.18999 .1619 L
.20998 .16526 L
.24971 .17017 L
.27097 .17207 L
.29042 .17348 L
.31204 .17475 L
.33211 .17569 L
.37221 .17709 L
.39376 .17764 L
.4133 .17804 L
.43521 .1784 L
.45537 .17867 L
.49585 .17907 L
.51561 .17921 L
.53731 .17933 L
.55951 .17944 L
.57976 .17951 L
.62061 .17963 L
.64065 .17967 L
.66245 .1797 L
.6828 .17973 L
.70527 .17975 L
.7465 .17978 L
.76681 .17979 L
.78871 .1798 L
.80934 .17981 L
.83191 .17982 L
.87351 .17982 L
.8941 .17983 L
.9161 .17983 L
.93701 .17983 L
.95967 .17983 L
1 .17984 L
s
0 0 m
.04057 .01167 L
.08481 .02747 L
.10632 .03358 L
.12636 .03832 L
.16632 .04548 L
.18776 .04831 L
.20726 .0504 L
.22906 .05231 L
.24919 .05373 L
.28952 .05583 L
.30918 .05658 L
.33084 .05725 L
.35293 .0578 L
.37314 .0582 L
.41385 .0588 L
.43379 .05901 L
.45555 .0592 L
.47793 .05935 L
.49822 .05946 L
.53931 .05963 L
.55952 .05969 L
.58138 .05974 L
.60191 .05978 L
.62443 .05981 L
.6659 .05986 L
.68638 .05988 L
.70834 .05989 L
.72914 .0599 L
.75177 .05991 L
.79361 .05992 L
.81437 .05993 L
.83643 .05993 L
.87607 .05994 L
.89638 .05994 L
.91828 .05994 L
.93891 .05994 L
.96148 .05994 L
1 .05994 L
s
0 0 m
.00123 0 L
.00236 0 L
.00365 0 L
.00488 1e-05 L
.00601 1e-05 L
.00706 2e-05 L
.00821 3e-05 L
.00942 5e-05 L
.01196 9e-05 L
.01434 .00014 L
.01694 .00021 L
.01975 .00031 L
.02532 .00055 L
.03062 .00084 L
.04057 .0015 L
.08481 .00516 L
.12491 .00814 L
.14729 .00947 L
.16759 .01047 L
.20868 .01199 L
.22888 .01255 L
.25074 .01303 L
.27127 .0134 L
.2938 .01373 L
.33526 .01416 L
.35575 .01432 L
.37771 .01445 L
.39851 .01456 L
.42113 .01464 L
.46297 .01476 L
.48374 .01481 L
.50579 .01484 L
.54543 .01489 L
.56575 .01491 L
.58765 .01492 L
.60828 .01494 L
.63084 .01495 L
.67245 .01496 L
.69304 .01497 L
.71504 .01497 L
.73594 .01497 L
.75861 .01498 L
.80059 .01498 L
.82146 .01498 L
.84355 .01498 L
.88334 .01498 L
.90376 .01498 L
.92569 .01498 L
.94643 .01499 L
Mistroke
.96903 .01499 L
1 .01499 L
Mfstroke
0 0 m
.00123 0 L
.00236 0 L
.00365 0 L
.00488 0 L
.00601 0 L
.00706 0 L
.00821 0 L
.00942 0 L
.01065 0 L
.01196 0 L
.01434 1e-05 L
.01579 1e-05 L
.01716 1e-05 L
.01975 2e-05 L
.02225 3e-05 L
.02491 5e-05 L
.0297 8e-05 L
.0354 .00012 L
.04057 .00018 L
.06335 .00049 L
.08481 .00083 L
.12529 .00146 L
.14581 .00173 L
.16834 .00198 L
.2098 .00232 L
.23029 .00245 L
.25225 .00256 L
.27305 .00264 L
.29568 .00272 L
.33751 .00281 L
.35828 .00285 L
.38034 .00288 L
.41997 .00292 L
.44029 .00293 L
.46219 .00295 L
.48282 .00296 L
.50538 .00296 L
.54699 .00298 L
.56758 .00298 L
.58958 .00298 L
.61049 .00299 L
.63315 .00299 L
.67513 .00299 L
.696 .00299 L
.7181 .00299 L
.75788 .00299 L
.7783 .003 L
.80024 .003 L
.82097 .003 L
Mistroke
.84358 .003 L
.88532 .003 L
.90602 .003 L
.92806 .003 L
.94907 .003 L
.97177 .003 L
1 .003 L
Mfstroke
0 0 m
.00123 0 L
.00236 0 L
.00365 0 L
.00488 0 L
.00601 0 L
.00706 0 L
.00821 0 L
.00942 0 L
.01065 0 L
.01196 0 L
.0132 0 L
.01434 0 L
.01566 0 L
.01711 0 L
.01975 0 L
.02116 0 L
.02249 0 L
.02497 0 L
.02765 1e-05 L
.03054 1e-05 L
.03576 1e-05 L
.04057 2e-05 L
.05082 4e-05 L
.06208 6e-05 L
.08481 .00012 L
.12725 .00023 L
.16811 .00032 L
.19041 .00035 L
.21154 .00038 L
.25178 .00042 L
.27255 .00043 L
.2946 .00045 L
.33424 .00047 L
.35456 .00047 L
.37646 .00048 L
.39709 .00048 L
.41965 .00049 L
.46126 .00049 L
.48185 .00049 L
.50385 .00049 L
.52476 .00049 L
.54742 .0005 L
.5894 .0005 L
.61027 .0005 L
.63237 .0005 L
.67215 .0005 L
.69257 .0005 L
.7145 .0005 L
.73524 .0005 L
Mistroke
.75784 .0005 L
.79959 .0005 L
.82029 .0005 L
.84233 .0005 L
.86334 .0005 L
.88604 .0005 L
.92817 .0005 L
.94914 .0005 L
.97127 .0005 L
1 .0005 L
Mfstroke
0 0 m
.00123 0 L
.00236 0 L
.00365 0 L
.00488 0 L
.00601 0 L
.00706 0 L
.00821 0 L
.00942 0 L
.01065 0 L
.01196 0 L
.0132 0 L
.01434 0 L
.01566 0 L
.01711 0 L
.01848 0 L
.01975 0 L
.02106 0 L
.02247 0 L
.02503 0 L
.02753 0 L
.02982 0 L
.03505 0 L
.04057 0 L
.04583 0 L
.05147 0 L
.06166 1e-05 L
.08481 1e-05 L
.12824 3e-05 L
.17008 4e-05 L
.21032 5e-05 L
.23108 6e-05 L
.25314 6e-05 L
.29278 6e-05 L
.3131 6e-05 L
.33499 7e-05 L
.35562 7e-05 L
.37819 7e-05 L
.4198 7e-05 L
.44039 7e-05 L
.46239 7e-05 L
.48329 7e-05 L
.50596 7e-05 L
.54794 7e-05 L
.56881 7e-05 L
.5909 7e-05 L
.63069 7e-05 L
.65111 7e-05 L
.67304 7e-05 L
.69378 7e-05 L
Mistroke
.71638 7e-05 L
.75813 7e-05 L
.77883 7e-05 L
.80086 7e-05 L
.82188 7e-05 L
.84458 7e-05 L
.8867 7e-05 L
.90768 7e-05 L
.92981 7e-05 L
.9491 7e-05 L
.96974 7e-05 L
1 7e-05 L
Mfstroke
0 0 m
.00123 0 L
.00236 0 L
.00365 0 L
.00488 0 L
.00601 0 L
.00706 0 L
.00821 0 L
.00942 0 L
.01065 0 L
.01196 0 L
.0132 0 L
.01434 0 L
.01566 0 L
.01641 0 L
.01711 0 L
.01839 0 L
.01975 0 L
.02115 0 L
.02245 0 L
.02384 0 L
.02537 0 L
.02795 0 L
.03067 0 L
.03314 0 L
.03579 0 L
.03707 0 L
.03829 0 L
.04057 0 L
.04181 0 L
.04312 0 L
.0438 0 L
.04455 0 L
.04587 0 L
.05084 0 L
.05603 0 L
.06176 0 L
.07373 0 L
.08481 0 L
.1274 0 L
.1684 1e-05 L
.1893 1e-05 L
.21197 1e-05 L
.25395 1e-05 L
.27482 1e-05 L
.29691 1e-05 L
.3367 1e-05 L
.35712 1e-05 L
.37905 1e-05 L
.39979 1e-05 L
Mistroke
.42239 1e-05 L
.46414 1e-05 L
.48484 1e-05 L
.50687 1e-05 L
.52789 1e-05 L
.55059 1e-05 L
.59271 1e-05 L
.61369 1e-05 L
.63582 1e-05 L
.67575 1e-05 L
.69627 1e-05 L
.71825 1e-05 L
.73909 1e-05 L
.76173 1e-05 L
.80362 1e-05 L
.82443 1e-05 L
.8465 1e-05 L
.88619 1e-05 L
.90655 1e-05 L
.92846 1e-05 L
.94913 1e-05 L
.97171 1e-05 L
1 1e-05 L
Mfstroke
0 0 m
.00123 0 L
.00236 0 L
.00365 0 L
.00488 0 L
.00601 0 L
.00706 0 L
.00821 0 L
.00942 0 L
.01065 0 L
.01196 0 L
.0132 0 L
.01434 0 L
.01566 0 L
.01641 0 L
.01711 0 L
.01839 0 L
.01975 0 L
.02115 0 L
.02245 0 L
.02387 0 L
.02537 0 L
.0279 0 L
.03067 0 L
.03314 0 L
.0345 0 L
.03579 0 L
.03698 0 L
.03829 0 L
s
.03829 0 m
.03876 0 L
s
.04422 0 m
.04452 0 L
.04583 0 L
.04706 0 L
.04838 0 L
.04963 0 L
.05076 0 L
.06202 0 L
.07374 0 L
.08481 0 L
.1252 0 L
.16816 0 L
.18954 0 L
.20954 0 L
.24932 0 L
.27062 0 L
.29008 0 L
.31175 0 L
.33183 0 L
.37199 0 L
.39358 0 L
.41313 0 L
.43508 0 L
.45526 0 L
.49579 0 L
.51559 0 L
.5373 0 L
.55955 0 L
.57981 0 L
.62071 0 L
.64079 0 L
.66261 0 L
.683 0 L
.70548 0 L
.74677 0 L
.76712 0 L
.78903 0 L
.80971 0 L
.83229 0 L
.87395 0 L
.89458 0 L
.91659 0 L
.93754 0 L
.96022 0 L
.98093 0 L
1 0 L
s
0 0 m
.00123 0 L
.00236 0 L
.00365 0 L
.00488 0 L
.00601 0 L
.00706 0 L
.00821 0 L
.00942 0 L
.01065 0 L
.01196 0 L
.0132 0 L
.01434 0 L
.01566 0 L
.01641 0 L
.01711 0 L
.01839 0 L
.01975 0 L
.02043 0 L
.02115 0 L
.02245 0 L
.02384 0 L
.02537 0 L
.02669 0 L
.02811 0 L
.02945 0 L
.03067 0 L
.03193 0 L
.0331 0 L
.03439 0 L
.03575 0 L
.03693 0 L
.03804 0 L
.03926 0 L
.04057 0 L
.04191 0 L
.04266 0 L
.04335 0 L
s
.04335 0 m
.04445 0 L
s
.0471 0 m
.0474 0 L
.04875 0 L
.04951 0 L
.05021 0 L
.05098 0 L
.05181 0 L
.05333 0 L
.05419 0 L
.05498 0 L
.058 0 L
.06365 0 L
.08481 0 L
.12595 0 L
.16967 0 L
.19162 0 L
.21179 0 L
.25232 0 L
.27213 0 L
.29384 0 L
.31609 0 L
.33634 0 L
.37725 0 L
.39733 0 L
.41914 0 L
.43954 0 L
.46202 0 L
.5033 0 L
.52366 0 L
.54557 0 L
.56624 0 L
.58882 0 L
.63048 0 L
.65111 0 L
.67313 0 L
.69407 0 L
.71675 0 L
.75879 0 L
.7797 0 L
.80181 0 L
.84165 0 L
.86211 0 L
.88406 0 L
.90483 0 L
.92745 0 L
.94771 0 L
.96926 0 L
1 0 L
s
0 0 m
.00123 0 L
.00236 0 L
.00365 0 L
.00488 0 L
.00601 0 L
.00706 0 L
.00821 0 L
.00942 0 L
.01065 0 L
.01196 0 L
.0132 0 L
.01434 0 L
.01566 0 L
.01641 0 L
.01711 0 L
.01839 0 L
.01975 0 L
.02043 0 L
.02115 0 L
.02245 0 L
.02318 0 L
.02396 0 L
.0247 0 L
.02537 0 L
.02667 0 L
.0279 0 L
s
.0279 0 m
.02802 0 L
s
.0448 0 m
.0449 0 L
.04566 0 L
.04637 0 L
.04761 0 L
.04894 0 L
s
.04894 0 m
.04922 0 L
s
.05199 0 m
.05306 0 L
.05439 0 L
.05513 0 L
.05592 0 L
.05731 0 L
.05812 0 L
.05898 0 L
.05971 0 L
.06052 0 L
.06126 0 L
.06205 0 L
.0628 0 L
.06349 0 L
.06481 0 L
.06548 0 L
.06622 0 L
.06752 0 L
.06874 0 L
.07008 0 L
.07075 0 L
.07148 0 L
.07229 0 L
.07303 0 L
.07371 0 L
.07444 0 L
.0758 0 L
.07707 0 L
.07831 0 L
.07946 0 L
.0807 0 L
.08206 0 L
.08274 0 L
.08348 0 L
.08481 0 L
.08608 0 L
.08681 0 L
.08749 0 L
.08887 0 L
.08957 0 L
.09035 0 L
.09165 0 L
.09302 0 L
.09547 0 L
.10708 0 L
.1282 0 L
.17076 0 L
.21172 0 L
.23411 0 L
.25526 0 L
Mistroke
.29562 0 L
.31646 0 L
.33855 0 L
.3783 0 L
.39869 0 L
.42062 0 L
.44133 0 L
.46393 0 L
.48581 0 L
.50564 0 L
.52631 0 L
.54834 0 L
.56856 0 L
.57995 0 L
.59043 0 L
.61189 0 L
.63191 0 L
.6718 0 L
.69319 0 L
.71268 0 L
.73443 0 L
.75454 0 L
.77407 0 L
.7948 0 L
.83446 0 L
.85479 0 L
.8767 0 L
.89734 0 L
.91992 0 L
.94005 0 L
.96154 0 L
.9817 0 L
1 0 L
Mfstroke
0 0 m
.00123 0 L
.00236 0 L
.00365 0 L
.00488 0 L
.00601 0 L
.00706 0 L
.00821 0 L
.00942 0 L
.01065 0 L
.01196 0 L
.0132 0 L
.01434 0 L
.01566 0 L
.01641 0 L
.01711 0 L
.01975 0 L
.02106 0 L
.02179 0 L
.02247 0 L
.02372 0 L
.02503 0 L
.02621 0 L
.02732 0 L
.02853 0 L
.02982 0 L
.03121 0 L
.03199 0 L
.03271 0 L
.03404 0 L
.03471 0 L
.03544 0 L
.03672 0 L
.03809 0 L
.03938 0 L
.04057 0 L
.04189 0 L
.04314 0 L
.04384 0 L
s
.04384 0 m
.04455 0 L
s
.04938 0 m
.04961 0 L
.05086 0 L
.05161 0 L
.05233 0 L
.05366 0 L
.05441 0 L
s
.05441 0 m
.05469 0 L
s
.05772 0 m
.05815 0 L
s
.05815 0 m
.05853 0 L
s
.06144 0 m
.06212 0 L
.06344 0 L
s
.06344 0 m
.06416 0 L
s
.06602 0 m
.06615 0 L
.06739 0 L
.06808 0 L
.06882 0 L
s
.06882 0 m
.06962 0 L
s
.07164 0 m
.07316 0 L
.0739 0 L
.07459 0 L
.0753 0 L
.07609 0 L
.07739 0 L
.07877 0 L
.07955 0 L
.0804 0 L
s
.0804 0 m
.08048 0 L
s
.08332 0 m
.08343 0 L
.08481 0 L
.08617 0 L
.08744 0 L
.08883 0 L
.08953 0 L
.0903 0 L
.09159 0 L
.09232 0 L
.09298 0 L
.09429 0 L
.09551 0 L
.0966 0 L
.09778 0 L
.09908 0 L
.10026 0 L
.1015 0 L
.10284 0 L
.1041 0 L
.10527 0 L
.10653 0 L
.10789 0 L
.10917 0 L
.11034 0 L
.11171 0 L
.11244 0 L
.11321 0 L
.11395 0 L
.11462 0 L
.11593 0 L
.11729 0 L
.11803 0 L
.11872 0 L
.11947 0 L
.1203 0 L
.12099 0 L
.12174 0 L
.12322 0 L
.12394 0 L
.12461 0 L
.12586 0 L
.12722 0 L
.12846 0 L
.12976 0 L
.13089 0 L
.13209 0 L
.13339 0 L
.1346 0 L
.13734 0 L
Mistroke
.13857 0 L
Mfstroke
.13857 0 m
.13974 0 L
s
.14197 0 m
.14231 0 L
.14449 0 L
.14572 0 L
.14683 0 L
.14816 0 L
.14942 0 L
.15058 0 L
.15184 0 L
.15323 0 L
.154 0 L
.1547 0 L
.15606 0 L
.15735 0 L
.1587 0 L
.15939 0 L
.16013 0 L
.1627 0 L
.16344 0 L
.16414 0 L
.16495 0 L
.16568 0 L
.16847 0 L
.1708 0 L
.17209 0 L
.17331 0 L
.174 0 L
.17475 0 L
.17606 0 L
.1774 0 L
.17864 0 L
.18133 0 L
.18265 0 L
.18387 0 L
.18455 0 L
.18527 0 L
.18599 0 L
.18679 0 L
.18815 0 L
.18943 0 L
.19063 0 L
.19194 0 L
.19309 0 L
.19432 0 L
.19542 0 L
.19663 0 L
.19768 0 L
.19878 0 L
.20007 0 L
.20126 0 L
Mistroke
.20254 0 L
.20327 0 L
.20394 0 L
.20515 0 L
.20629 0 L
.2076 0 L
.20879 0 L
.21406 0 L
.21664 0 L
.21777 0 L
.21899 0 L
.22027 0 L
.22147 0 L
.22286 0 L
.22414 0 L
.22488 0 L
.22558 0 L
.22688 0 L
.2298 0 L
.24917 0 L
.2685 0 L
.27122 0 L
.27379 0 L
.27676 0 L
.27807 0 L
.27879 0 L
.27946 0 L
.28067 0 L
.28201 0 L
.28314 0 L
.28436 0 L
.28572 0 L
.2864 0 L
.28714 0 L
.28846 0 L
.28969 0 L
.291 0 L
.29243 0 L
.29501 0 L
.29983 0 L
.31066 0 L
.33278 0 L
.35327 0 L
.37579 0 L
.41721 0 L
.43766 0 L
.45961 0 L
.47026 0 L
.47589 0 L
.47897 0 L
Mistroke
.48187 0 L
.48309 0 L
.48438 0 L
.48578 0 L
.48708 0 L
.49283 0 L
.49518 0 L
.49649 0 L
.49768 0 L
.49836 0 L
.49909 0 L
.50043 0 L
.50176 0 L
.50299 0 L
.5043 0 L
.50554 0 L
.50666 0 L
.50788 0 L
.5092 0 L
.51061 0 L
.51314 0 L
.52266 0 L
.52851 0 L
.5299 0 L
.53138 0 L
.53263 0 L
.53402 0 L
.53525 0 L
.53657 0 L
.53782 0 L
.53896 0 L
.54431 0 L
.54933 0 L
.55178 0 L
.55403 0 L
.5564 0 L
.55894 0 L
.56031 0 L
.56158 0 L
.56291 0 L
.56361 0 L
.56436 0 L
.56512 0 L
.56582 0 L
.5666 0 L
.56741 0 L
.57029 0 L
.57568 0 L
.58616 0 L
.58859 0 L
Mistroke
.58988 0 L
.59124 0 L
.59256 0 L
.59375 0 L
.59495 0 L
.59607 0 L
.59675 0 L
.59747 0 L
.59875 0 L
.60164 0 L
.60281 0 L
.60406 0 L
.60544 0 L
.60672 0 L
.61671 0 L
.61883 0 L
.62 0 L
.62111 0 L
.62241 0 L
.62361 0 L
.62473 0 L
.62595 0 L
.62725 0 L
.62864 0 L
.63115 0 L
.63264 0 L
.63404 0 L
.6353 0 L
.63666 0 L
.63739 0 L
.63807 0 L
.63961 0 L
.64272 0 L
.6483 0 L
.64961 0 L
.65104 0 L
.6523 0 L
.65363 0 L
.65483 0 L
.65616 0 L
.65737 0 L
.6585 0 L
.66106 0 L
.66235 0 L
.66308 0 L
.66376 0 L
.66451 0 L
.66519 0 L
.66598 0 L
.66672 0 L
Mistroke
.66803 0 L
.66944 0 L
.67463 0 L
.67749 0 L
.68021 0 L
.68273 0 L
.68342 0 L
.68415 0 L
.68548 0 L
.68678 0 L
.688 0 L
.6891 0 L
.69029 0 L
.69156 0 L
.69228 0 L
.69296 0 L
.69431 0 L
.69508 0 L
.69577 0 L
.69839 0 L
.70081 0 L
.70219 0 L
.70289 0 L
.70365 0 L
.70442 0 L
.70525 0 L
.70603 0 L
.70675 0 L
.70806 0 L
.7088 0 L
.70949 0 L
.7109 0 L
.71166 0 L
.71238 0 L
.7137 0 L
.71439 0 L
.71514 0 L
.71648 0 L
.71769 0 L
.71842 0 L
.7191 0 L
.72064 0 L
.72344 0 L
.72627 0 L
.72892 0 L
.73131 0 L
.73265 0 L
.73388 0 L
.73502 0 L
.73608 0 L
Mistroke
.73724 0 L
.73849 0 L
.73979 0 L
.74103 0 L
.74214 0 L
.74334 0 L
.74455 0 L
.74588 0 L
.74857 0 L
.75108 0 L
.7523 0 L
.75341 0 L
.75467 0 L
.75601 0 L
.75672 0 L
.75748 0 L
.75886 0 L
.76017 0 L
.76156 0 L
.76405 0 L
.76874 0 L
.77138 0 L
.77378 0 L
.77656 0 L
.77919 0 L
.78423 0 L
.78968 0 L
.79258 0 L
.7941 0 L
.7957 0 L
.79701 0 L
.79769 0 L
.79843 0 L
.79972 0 L
.80093 0 L
.80225 0 L
.8035 0 L
.80462 0 L
.80584 0 L
.80713 0 L
.80787 0 L
.80856 0 L
.80995 0 L
.81073 0 L
.81144 0 L
.81271 0 L
.81409 0 L
.8166 0 L
.83594 0 L
.8475 0 L
Mistroke
.85837 0 L
.86813 0 L
.87867 0 L
.89829 0 L
.90943 0 L
.91486 0 L
.91981 0 L
.92501 0 L
.92994 0 L
.94078 0 L
.96291 0 L
1 0 L
Mfstroke
0 0 m
.00123 0 L
.00236 0 L
.00365 0 L
.00488 0 L
.00601 0 L
.00706 0 L
.00821 0 L
.00942 0 L
.01065 0 L
.01196 0 L
.0132 0 L
s
.0132 0 m
.01323 0 L
s
.04557 0 m
.04561 0 L
.04637 0 L
.04769 0 L
.04842 0 L
.0491 0 L
.05041 0 L
s
.05041 0 m
.05153 0 L
s
.05546 0 m
.0559 0 L
s
.0559 0 m
.05617 0 L
s
.05987 0 m
.06032 0 L
.06117 0 L
s
.06117 0 m
.06144 0 L
s
.06321 0 m
.06349 0 L
.06481 0 L
.06604 0 L
s
.06604 0 m
.06686 0 L
s
.06921 0 m
.07019 0 L
.07094 0 L
.07164 0 L
s
.07164 0 m
.0719 0 L
s
.07988 0 m
.08083 0 L
.08204 0 L
.08338 0 L
s
.08338 0 m
.08358 0 L
s
.08705 0 m
.0872 0 L
.08847 0 L
s
.08847 0 m
.08891 0 L
s
.09408 0 m
.0952 0 L
.09644 0 L
.09761 0 L
.09884 0 L
s
.09884 0 m
.10005 0 L
s
.10164 0 m
.1026 0 L
.10366 0 L
.10482 0 L
.10552 0 L
s
.10552 0 m
.10554 0 L
s
.10882 0 m
.109 0 L
.11025 0 L
.1117 0 L
.11307 0 L
.11383 0 L
.11465 0 L
.11608 0 L
s
.11608 0 m
.11648 0 L
s
.12208 0 m
.12292 0 L
.12421 0 L
.12536 0 L
.12661 0 L
.12789 0 L
s
.12789 0 m
.12818 0 L
s
.13781 0 m
.13853 0 L
.1392 0 L
.14045 0 L
.14176 0 L
.14249 0 L
.14317 0 L
.14391 0 L
.14471 0 L
.14543 0 L
s
.14543 0 m
.14601 0 L
s
.15122 0 m
.1514 0 L
.15217 0 L
.15287 0 L
.15405 0 L
s
.15405 0 m
.15431 0 L
s
.16129 0 m
.16224 0 L
.16351 0 L
.16422 0 L
.16497 0 L
.16573 0 L
.16656 0 L
.16728 0 L
.16806 0 L
.16879 0 L
.16945 0 L
.1708 0 L
s
.1708 0 m
.17109 0 L
s
.17431 0 m
.17445 0 L
.1758 0 L
.17648 0 L
.17723 0 L
.17855 0 L
.17979 0 L
s
.17979 0 m
.18082 0 L
s
.1867 0 m
.18699 0 L
.18816 0 L
.18938 0 L
.19072 0 L
.19195 0 L
.19264 0 L
.19338 0 L
.19471 0 L
.19596 0 L
.1971 0 L
.19837 0 L
.19972 0 L
.20042 0 L
.20118 0 L
.20254 0 L
.2033 0 L
.20411 0 L
.20559 0 L
.2063 0 L
.20708 0 L
.20781 0 L
.20849 0 L
.20977 0 L
.21114 0 L
.21244 0 L
.21319 0 L
.21388 0 L
.2146 0 L
.21528 0 L
.21606 0 L
.21677 0 L
.21798 0 L
.21926 0 L
.21992 0 L
.22066 0 L
.22196 0 L
.22269 0 L
.22337 0 L
.22408 0 L
.22486 0 L
.22565 0 L
.2265 0 L
.22799 0 L
.22942 0 L
.23021 0 L
.23094 0 L
.23223 0 L
.23291 0 L
.23365 0 L
Mistroke
.23432 0 L
.23506 0 L
.23639 0 L
.2372 0 L
.23795 0 L
.23864 0 L
.23937 0 L
.24069 0 L
.24193 0 L
.2433 0 L
.244 0 L
.24476 0 L
.24607 0 L
.24729 0 L
.24848 0 L
.24961 0 L
.25093 0 L
.25213 0 L
.25343 0 L
.25416 0 L
.25484 0 L
.25604 0 L
.25735 0 L
.25858 0 L
.25973 0 L
.26106 0 L
.26181 0 L
.26248 0 L
.26379 0 L
.26499 0 L
.26614 0 L
.26735 0 L
.26856 0 L
.26989 0 L
.27104 0 L
.27228 0 L
.27344 0 L
.27451 0 L
.27709 0 L
.27851 0 L
.27983 0 L
.28052 0 L
.28127 0 L
.28209 0 L
.28285 0 L
.2842 0 L
.28563 0 L
.28689 0 L
.28824 0 L
.28951 0 L
Mistroke
.29066 0 L
.29202 0 L
.29279 0 L
.29349 0 L
.29617 0 L
.29737 0 L
.29868 0 L
.29992 0 L
.30107 0 L
.30241 0 L
.30316 0 L
.30383 0 L
.30514 0 L
.30635 0 L
.3075 0 L
.30871 0 L
.30992 0 L
.31126 0 L
.31241 0 L
.31365 0 L
.31587 0 L
.31867 0 L
.32014 0 L
.32095 0 L
.3217 0 L
.32307 0 L
.32379 0 L
.32457 0 L
.32595 0 L
.32722 0 L
.32853 0 L
.32975 0 L
.33109 0 L
.33177 0 L
.33251 0 L
.33387 0 L
.33515 0 L
.3364 0 L
.33755 0 L
.33876 0 L
.34008 0 L
.34132 0 L
.34247 0 L
.34381 0 L
.34449 0 L
.34524 0 L
.34776 0 L
.34891 0 L
.35012 0 L
.35145 0 L
Mistroke
.35267 0 L
.35729 0 L
.35989 0 L
.36131 0 L
.36266 0 L
.36391 0 L
.36527 0 L
.36651 0 L
.36765 0 L
.369 0 L
.37027 0 L
.37099 0 L
.37166 0 L
.37242 0 L
.37315 0 L
.37898 0 L
.38148 0 L
.38279 0 L
.38417 0 L
.38539 0 L
.38672 0 L
.38793 0 L
.38906 0 L
.39178 0 L
.3947 0 L
.3998 0 L
.41911 0 L
.42921 0 L
.43041 0 L
.43167 0 L
.43305 0 L
.43431 0 L
.4357 0 L
.43721 0 L
.43994 0 L
.44603 0 L
.4517 0 L
.4544 0 L
.45573 0 L
.45696 0 L
.45764 0 L
.45837 0 L
.4591 0 L
.4599 0 L
.46128 0 L
.46257 0 L
.46799 0 L
.47066 0 L
.47313 0 L
.47536 0 L
Mistroke
.47774 0 L
.47901 0 L
.48036 0 L
.48151 0 L
.48276 0 L
.48347 0 L
.48422 0 L
.48558 0 L
.4864 0 L
.48718 0 L
.48863 0 L
.49414 0 L
.49908 0 L
.50187 0 L
.50318 0 L
.50444 0 L
.50566 0 L
.50699 0 L
.5082 0 L
.50933 0 L
.51066 0 L
.51187 0 L
.51459 0 L
.5241 0 L
.52945 0 L
.53092 0 L
.53172 0 L
.53247 0 L
.53379 0 L
.53449 0 L
.53525 0 L
.5366 0 L
.53736 0 L
.53807 0 L
.54074 0 L
.54575 0 L
.55518 0 L
.56013 0 L
.56134 0 L
.56262 0 L
.56336 0 L
.56403 0 L
.56535 0 L
.56609 0 L
.56678 0 L
.56754 0 L
.56834 0 L
.57117 0 L
.5765 0 L
.58698 0 L
Mistroke
.58941 0 L
.59069 0 L
.59206 0 L
.59337 0 L
.59456 0 L
.59576 0 L
.59688 0 L
.59756 0 L
.59828 0 L
.59956 0 L
.60105 0 L
.60244 0 L
.60371 0 L
.60487 0 L
.60615 0 L
.60753 0 L
.61685 0 L
.61931 0 L
.62061 0 L
.62196 0 L
.62316 0 L
.62446 0 L
.62565 0 L
.62675 0 L
.62801 0 L
.62915 0 L
.63172 0 L
.63307 0 L
.63378 0 L
.63453 0 L
.63591 0 L
.63719 0 L
.63833 0 L
.63956 0 L
.64178 0 L
.64314 0 L
.64442 0 L
.64683 0 L
.64946 0 L
.65015 0 L
.6509 0 L
.65225 0 L
.65349 0 L
.65464 0 L
.65592 0 L
.65727 0 L
.66033 0 L
.66184 0 L
.66323 0 L
.66449 0 L
Mistroke
.66582 0 L
.66716 0 L
.66793 0 L
.66864 0 L
.66993 0 L
.67116 0 L
.67346 0 L
.67594 0 L
.67864 0 L
.68003 0 L
.68133 0 L
.68205 0 L
.68283 0 L
.68419 0 L
.6855 0 L
.68687 0 L
.68805 0 L
.68934 0 L
.69181 0 L
.69303 0 L
.69415 0 L
.69545 0 L
.69685 0 L
.69931 0 L
.70164 0 L
.70382 0 L
.7061 0 L
.70862 0 L
.711 0 L
.71231 0 L
.71355 0 L
.71425 0 L
.71502 0 L
.71635 0 L
.7177 0 L
.71895 0 L
.72025 0 L
.72146 0 L
.72423 0 L
.7271 0 L
.72851 0 L
.72982 0 L
.73096 0 L
.73216 0 L
.7335 0 L
.73472 0 L
.73583 0 L
.73702 0 L
.73815 0 L
.73919 0 L
Mistroke
.74153 0 L
.74409 0 L
.74925 0 L
.7519 0 L
.7533 0 L
.75406 0 L
.75478 0 L
.75607 0 L
.75676 0 L
.7575 0 L
.75881 0 L
.76 0 L
.76125 0 L
.7624 0 L
.76502 0 L
.76731 0 L
.76979 0 L
.77129 0 L
.77266 0 L
.77398 0 L
.77464 0 L
.77537 0 L
.77798 0 L
.78043 0 L
.78329 0 L
.7859 0 L
.78869 0 L
.79177 0 L
.79302 0 L
.79437 0 L
.79564 0 L
.79681 0 L
.79806 0 L
.79942 0 L
.80011 0 L
.80084 0 L
.80217 0 L
.80679 0 L
.80922 0 L
.81045 0 L
.8118 0 L
.81256 0 L
.81337 0 L
.81413 0 L
.81485 0 L
.81555 0 L
.81632 0 L
.81767 0 L
.82035 0 L
.82321 0 L
Mistroke
.82604 0 L
.8286 0 L
.83118 0 L
.83359 0 L
.83477 0 L
.83604 0 L
.83676 0 L
.83744 0 L
.83872 0 L
.84007 0 L
.84131 0 L
.84413 0 L
.84656 0 L
.84884 0 L
.84998 0 L
.85121 0 L
.85257 0 L
.85383 0 L
.8551 0 L
.85647 0 L
.85775 0 L
.85892 0 L
.86448 0 L
.86993 0 L
.87291 0 L
.87437 0 L
.8757 0 L
.87693 0 L
.87811 0 L
.87935 0 L
.8807 0 L
.88208 0 L
.88355 0 L
.8862 0 L
.88841 0 L
.89079 0 L
.89215 0 L
.89341 0 L
.89587 0 L
.89832 0 L
.89969 0 L
.90094 0 L
.90382 0 L
.9065 0 L
.91195 0 L
.91327 0 L
.914 0 L
.91469 0 L
.91551 0 L
.91625 0 L
Mistroke
.91695 0 L
.91771 0 L
.91909 0 L
.92034 0 L
.92178 0 L
.92314 0 L
.92576 0 L
.92817 0 L
.93042 0 L
.93156 0 L
.93281 0 L
.93406 0 L
.9354 0 L
.93782 0 L
.94827 0 L
.95379 0 L
.95681 0 L
.95829 0 L
.95964 0 L
.96084 0 L
.96211 0 L
.96337 0 L
.96476 0 L
.9655 0 L
.96618 0 L
.96769 0 L
.97041 0 L
.97559 0 L
.97787 0 L
.97916 0 L
.98037 0 L
.9815 0 L
.98272 0 L
.98402 0 L
.98521 0 L
.9865 0 L
.98723 0 L
.98791 0 L
.98915 0 L
.99047 0 L
.99304 0 L
.99547 0 L
1 0 L
Mfstroke
0 0 m
.00123 0 L
.00236 0 L
.00365 0 L
.00488 0 L
.00601 0 L
.00706 0 L
.00821 0 L
.00942 0 L
.01065 0 L
.01196 0 L
.0132 0 L
.01434 0 L
.01566 0 L
.01641 0 L
.01711 0 L
.01839 0 L
.01975 0 L
.02043 0 L
.02115 0 L
.02245 0 L
.02317 0 L
.02384 0 L
.02458 0 L
.02537 0 L
.02605 0 L
.02679 0 L
.02814 0 L
.02945 0 L
.03067 0 L
.03184 0 L
.03295 0 L
.03416 0 L
.03547 0 L
.03676 0 L
.03813 0 L
.03929 0 L
.04057 0 L
.042 0 L
.04281 0 L
.04355 0 L
.04492 0 L
.04561 0 L
.04637 0 L
.04769 0 L
s
.04769 0 m
.04775 0 L
s
.053 0 m
.05307 0 L
.05385 0 L
.05459 0 L
s
.05459 0 m
.0556 0 L
s
.05606 0 m
.05663 0 L
.05731 0 L
.05805 0 L
.05874 0 L
.0595 0 L
s
.0595 0 m
.06012 0 L
s
.06113 0 m
.06117 0 L
.06198 0 L
.0627 0 L
s
.0627 0 m
.06319 0 L
s
.06694 0 m
.0674 0 L
.06816 0 L
.06886 0 L
s
.06886 0 m
.06918 0 L
s
.0719 0 m
.07315 0 L
.07389 0 L
.07457 0 L
.07582 0 L
.07717 0 L
.07831 0 L
.07952 0 L
s
.07952 0 m
.07989 0 L
s
.08359 0 m
.08413 0 L
.08481 0 L
.08604 0 L
s
.08604 0 m
.08705 0 L
s
.08889 0 m
.08985 0 L
.09121 0 L
.09189 0 L
.09264 0 L
.09398 0 L
s
.09398 0 m
.09417 0 L
s
.09913 0 m
.10018 0 L
.10136 0 L
s
.10136 0 m
.10196 0 L
s
.10526 0 m
.10552 0 L
.10628 0 L
.10766 0 L
.109 0 L
s
.109 0 m
.10904 0 L
s
.1163 0 m
.11746 0 L
.11875 0 L
.12009 0 L
.1208 0 L
.12156 0 L
s
.12156 0 m
.12224 0 L
s
.12807 0 m
.12907 0 L
.13035 0 L
.13171 0 L
.13289 0 L
.13399 0 L
.13649 0 L
.13779 0 L
s
.13779 0 m
.13788 0 L
s
.14592 0 m
.14611 0 L
.14739 0 L
.14811 0 L
.14878 0 L
.15005 0 L
s
.15005 0 m
.15129 0 L
s
.15401 0 m
.15405 0 L
.15534 0 L
.15669 0 L
.15795 0 L
.16086 0 L
s
.16086 0 m
.16207 0 L
s
.16997 0 m
.1708 0 L
.17208 0 L
.17322 0 L
.17445 0 L
s
.17445 0 m
.17546 0 L
s
.17804 0 m
.17855 0 L
.17979 0 L
.18103 0 L
.18221 0 L
.18326 0 L
.18442 0 L
.18567 0 L
.18699 0 L
.18816 0 L
.18938 0 L
.19072 0 L
s
.19072 0 m
.19079 0 L
s
.19839 0 m
.19972 0 L
.20042 0 L
.20118 0 L
.20254 0 L
.2033 0 L
s
.2033 0 m
.20333 0 L
s
.21512 0 m
.21528 0 L
.21606 0 L
.21677 0 L
.21798 0 L
.21926 0 L
.21992 0 L
.22066 0 L
.22196 0 L
.22269 0 L
.22337 0 L
.22408 0 L
.22486 0 L
.22565 0 L
.2265 0 L
.22728 0 L
.22799 0 L
.22873 0 L
.22942 0 L
.23014 0 L
.23094 0 L
.23225 0 L
.23298 0 L
.23365 0 L
.23494 0 L
.23566 0 L
.23634 0 L
.23757 0 L
.23889 0 L
.24027 0 L
.24158 0 L
s
.24158 0 m
.24209 0 L
s
.24854 0 m
.2495 0 L
.25085 0 L
.25208 0 L
.2534 0 L
.25415 0 L
.25484 0 L
.25604 0 L
.25735 0 L
.25858 0 L
.25973 0 L
.26106 0 L
.26181 0 L
.26248 0 L
.26379 0 L
s
.26379 0 m
.26438 0 L
s
.27274 0 m
.27344 0 L
.27451 0 L
.27709 0 L
.27851 0 L
.27983 0 L
.28052 0 L
.28127 0 L
.28209 0 L
.28285 0 L
.2842 0 L
.28563 0 L
.28689 0 L
.28824 0 L
.28951 0 L
.29066 0 L
.29202 0 L
.29279 0 L
.29349 0 L
.29479 0 L
.29617 0 L
.29744 0 L
.29882 0 L
.30013 0 L
.30135 0 L
.30255 0 L
.30364 0 L
.30608 0 L
.30745 0 L
.30872 0 L
.3101 0 L
.3108 0 L
.31156 0 L
.31285 0 L
.31423 0 L
.31672 0 L
.3192 0 L
.31988 0 L
.3206 0 L
.3219 0 L
.3231 0 L
.32423 0 L
.32546 0 L
.32679 0 L
.32796 0 L
.32924 0 L
.33045 0 L
.33157 0 L
.3337 0 L
.33478 0 L
Mistroke
.33595 0 L
.33873 0 L
.34006 0 L
.34128 0 L
.34201 0 L
.34271 0 L
.34345 0 L
.34425 0 L
.34496 0 L
.3457 0 L
.34704 0 L
.34827 0 L
.3496 0 L
.35085 0 L
.352 0 L
.35328 0 L
.35467 0 L
.35537 0 L
.35613 0 L
.35748 0 L
.36001 0 L
.36134 0 L
.36201 0 L
.36274 0 L
.36408 0 L
.36533 0 L
.36648 0 L
.36771 0 L
.36891 0 L
.37021 0 L
.37143 0 L
.37257 0 L
.3737 0 L
.37472 0 L
.3759 0 L
.37702 0 L
.37958 0 L
.38099 0 L
.38233 0 L
.38357 0 L
.38492 0 L
.38615 0 L
.38728 0 L
.38847 0 L
.38979 0 L
.39118 0 L
.39245 0 L
.39312 0 L
.39386 0 L
.3946 0 L
Mistroke
.39537 0 L
.39606 0 L
.3968 0 L
.39812 0 L
.39934 0 L
.40066 0 L
.40189 0 L
.40303 0 L
.4055 0 L
.40691 0 L
.40822 0 L
.40933 0 L
.4105 0 L
.41181 0 L
.41299 0 L
.41414 0 L
.41535 0 L
.41639 0 L
.41752 0 L
.4189 0 L
.42019 0 L
.42092 0 L
.42158 0 L
.42307 0 L
.42576 0 L
.42829 0 L
.43101 0 L
.43238 0 L
.43316 0 L
.43389 0 L
.43468 0 L
.43541 0 L
.43625 0 L
.43704 0 L
.43844 0 L
.43996 0 L
.45106 0 L
.45361 0 L
.455 0 L
.4563 0 L
.45741 0 L
.4586 0 L
.45992 0 L
.46112 0 L
.46238 0 L
.46375 0 L
.46623 0 L
.46891 0 L
.47176 0 L
.47423 0 L
Mistroke
.47696 0 L
.47931 0 L
.48059 0 L
.48178 0 L
.48314 0 L
.48386 0 L
.48463 0 L
.486 0 L
.48724 0 L
.49313 0 L
.49577 0 L
.49862 0 L
.50111 0 L
.50249 0 L
Mfstroke
.50249 0 m
.50375 0 L
s
.51069 0 m
.51145 0 L
.51373 0 L
.52466 0 L
.52983 0 L
.53109 0 L
.53243 0 L
.5332 0 L
.53391 0 L
.53528 0 L
.53605 0 L
.53676 0 L
.53753 0 L
.53835 0 L
.54126 0 L
.54676 0 L
.55662 0 L
s
.55662 0 m
.55686 0 L
s
.57635 0 m
.57726 0 L
.57973 0 L
.58206 0 L
.58416 0 L
.58644 0 L
.58889 0 L
.59017 0 L
.59152 0 L
.59271 0 L
.59401 0 L
.59519 0 L
.5963 0 L
.59697 0 L
.59771 0 L
.59905 0 L
.60155 0 L
.60297 0 L
.60448 0 L
.60576 0 L
.60649 0 L
.60718 0 L
.6098 0 L
.61259 0 L
.61419 0 L
.61564 0 L
.61848 0 L
.61978 0 L
s
.61978 0 m
.6203 0 L
s
.62831 0 m
.62923 0 L
.63179 0 L
.6332 0 L
.63452 0 L
.63564 0 L
.63685 0 L
.63819 0 L
.63942 0 L
.64077 0 L
.64222 0 L
.64358 0 L
.64482 0 L
.64753 0 L
.64897 0 L
.6505 0 L
.65169 0 L
.653 0 L
.65419 0 L
.6553 0 L
.65661 0 L
.65781 0 L
.66051 0 L
.66163 0 L
.66283 0 L
.66414 0 L
.66535 0 L
.6666 0 L
.66777 0 L
.66882 0 L
.66995 0 L
.67265 0 L
.6752 0 L
.67814 0 L
.67944 0 L
.68082 0 L
.68202 0 L
.68334 0 L
.68454 0 L
.68567 0 L
.687 0 L
.68821 0 L
.69094 0 L
.69219 0 L
.69353 0 L
.69499 0 L
.69636 0 L
.69883 0 L
.7015 0 L
.70313 0 L
Mistroke
.70463 0 L
.70757 0 L
.71045 0 L
.71171 0 L
.71308 0 L
.71439 0 L
.71561 0 L
.71677 0 L
.71801 0 L
.7193 0 L
.72052 0 L
.72185 0 L
.72329 0 L
.72785 0 L
.72909 0 L
.73043 0 L
.73169 0 L
.73283 0 L
.73419 0 L
.73496 0 L
.73566 0 L
.73696 0 L
.73834 0 L
.7411 0 L
.74414 0 L
.7495 0 L
.75193 0 L
.75327 0 L
.75452 0 L
.7552 0 L
.75594 0 L
.75723 0 L
.75854 0 L
.75974 0 L
.76107 0 L
.76182 0 L
.76252 0 L
.76544 0 L
.76801 0 L
.77045 0 L
.77179 0 L
.7725 0 L
.77325 0 L
.77458 0 L
.77581 0 L
.78076 0 L
.78325 0 L
.78597 0 L
.79047 0 L
.79294 0 L
Mistroke
.79415 0 L
.79527 0 L
.79655 0 L
.79723 0 L
.79795 0 L
.7991 0 L
.80038 0 L
.80156 0 L
.80283 0 L
.80513 0 L
.80797 0 L
.80938 0 L
.81068 0 L
.81185 0 L
.8131 0 L
.81435 0 L
.81574 0 L
.81695 0 L
.81822 0 L
.8205 0 L
.82295 0 L
.82564 0 L
.8301 0 L
.83245 0 L
.83374 0 L
.83494 0 L
.83631 0 L
.83704 0 L
.83782 0 L
.83921 0 L
.84048 0 L
.84176 0 L
.84316 0 L
.84571 0 L
.84816 0 L
.84954 0 L
.85078 0 L
.85195 0 L
.85321 0 L
.8544 0 L
.8555 0 L
.85677 0 L
.85813 0 L
.86059 0 L
.86352 0 L
.86619 0 L
.87166 0 L
.87299 0 L
.87443 0 L
.87525 0 L
Mistroke
.876 0 L
.87672 0 L
.87748 0 L
.87873 0 L
.88006 0 L
.88131 0 L
.88245 0 L
.88506 0 L
.88789 0 L
.88914 0 L
.89047 0 L
.8917 0 L
.89285 0 L
.89507 0 L
.89752 0 L
.90034 0 L
.90301 0 L
.90542 0 L
.90803 0 L
.91087 0 L
.91243 0 L
.91389 0 L
.91526 0 L
.91603 0 L
.91674 0 L
.918 0 L
.91932 0 L
.92061 0 L
.92134 0 L
.92201 0 L
.92455 0 L
.927 0 L
.9293 0 L
.93049 0 L
.93177 0 L
.93246 0 L
.93319 0 L
.93449 0 L
.93585 0 L
.93711 0 L
.93999 0 L
.9425 0 L
.94487 0 L
.94931 0 L
.95445 0 L
.95574 0 L
.95696 0 L
.95815 0 L
.95925 0 L
.96038 0 L
Mistroke
.9616 0 L
.96283 0 L
.96413 0 L
.96544 0 L
.96667 0 L
.96949 0 L
.97513 0 L
.9776 0 L
.97891 0 L
.98031 0 L
.98154 0 L
.98266 0 L
.98379 0 L
.98485 0 L
.98604 0 L
.98715 0 L
.98835 0 L
.98964 0 L
.99083 0 L
.99211 0 L
.99443 0 L
.99718 0 L
.9997 0 L
1 0 L
Mfstroke
0 0 m
.00123 0 L
.00236 0 L
.00365 0 L
.00488 0 L
.00601 0 L
.00706 0 L
.00821 0 L
.00942 0 L
.01065 0 L
.01196 0 L
.0132 0 L
s
.0132 0 m
.01381 0 L
s
.04777 0 m
.04842 0 L
.0491 0 L
.05041 0 L
.05165 0 L
.05239 0 L
s
.05239 0 m
.05307 0 L
s
.05563 0 m
.0559 0 L
s
.0559 0 m
.05604 0 L
s
.06016 0 m
.06032 0 L
s
.06032 0 m
.06102 0 L
s
.06319 0 m
.06349 0 L
.06481 0 L
.06604 0 L
s
.06604 0 m
.06696 0 L
s
.06917 0 m
.07019 0 L
.07094 0 L
.07164 0 L
s
.07164 0 m
.0719 0 L
s
.07988 0 m
.08083 0 L
.08204 0 L
.08338 0 L
s
.08338 0 m
.08359 0 L
s
.08705 0 m
.0872 0 L
.08847 0 L
s
.08847 0 m
.08889 0 L
s
.09416 0 m
.0952 0 L
.09644 0 L
.09761 0 L
.09884 0 L
s
.09884 0 m
.09915 0 L
s
.10195 0 m
.1026 0 L
.10366 0 L
.10482 0 L
s
.10482 0 m
.10528 0 L
s
.10903 0 m
.11025 0 L
.1117 0 L
.11307 0 L
.11383 0 L
.11465 0 L
.11608 0 L
s
.11608 0 m
.11631 0 L
s
.12223 0 m
.12292 0 L
.12421 0 L
.12536 0 L
.12661 0 L
.12789 0 L
s
.12789 0 m
.12807 0 L
s
.13788 0 m
.13853 0 L
.1392 0 L
.14045 0 L
.14176 0 L
.14249 0 L
.14317 0 L
.14391 0 L
.14471 0 L
.14543 0 L
s
.14543 0 m
.14592 0 L
s
.15129 0 m
.1514 0 L
.15217 0 L
.15287 0 L
s
.15287 0 m
.15403 0 L
s
.16204 0 m
.16224 0 L
.16351 0 L
.16422 0 L
.16497 0 L
.16573 0 L
.16656 0 L
.16728 0 L
.16806 0 L
.16879 0 L
.16945 0 L
s
.16945 0 m
.17002 0 L
s
.17541 0 m
.1758 0 L
.17648 0 L
.17723 0 L
s
.17723 0 m
.1782 0 L
s
.19068 0 m
.19072 0 L
.19195 0 L
.19264 0 L
.19338 0 L
.19471 0 L
.19596 0 L
.1971 0 L
.19837 0 L
s
.19837 0 m
.19855 0 L
s
.20316 0 m
.2033 0 L
.20411 0 L
.20559 0 L
.2063 0 L
.20708 0 L
.20781 0 L
.20849 0 L
.20977 0 L
.21114 0 L
.21244 0 L
.21319 0 L
.21388 0 L
.2146 0 L
.21528 0 L
s
.21528 0 m
.21564 0 L
s
.22525 0 m
.22565 0 L
.2265 0 L
.22728 0 L
.22799 0 L
.22873 0 L
.22942 0 L
.23014 0 L
.23094 0 L
.23225 0 L
.23298 0 L
s
.23298 0 m
.23299 0 L
s
.24046 0 m
.24158 0 L
.24303 0 L
.24376 0 L
.24455 0 L
.24589 0 L
.24713 0 L
.24835 0 L
.2495 0 L
.25085 0 L
.25208 0 L
s
.25208 0 m
.25319 0 L
s
.26333 0 m
.26379 0 L
.26499 0 L
.26614 0 L
.26735 0 L
.26856 0 L
.26989 0 L
.27104 0 L
.27228 0 L
.27344 0 L
s
.27344 0 m
.27373 0 L
s
.29064 0 m
.29066 0 L
.29202 0 L
.29279 0 L
.29349 0 L
.29479 0 L
.29617 0 L
.29744 0 L
.29882 0 L
.30013 0 L
.30135 0 L
.30255 0 L
.30364 0 L
s
.30364 0 m
.30529 0 L
s
.31419 0 m
.31423 0 L
.31672 0 L
.3192 0 L
.31988 0 L
.3206 0 L
.3219 0 L
.3231 0 L
.32423 0 L
.32546 0 L
.32679 0 L
.32796 0 L
.32924 0 L
.33045 0 L
.33157 0 L
.3337 0 L
.33478 0 L
.33595 0 L
s
.33595 0 m
.33645 0 L
s
.35115 0 m
.352 0 L
.35328 0 L
.35467 0 L
.35613 0 L
.35748 0 L
.36003 0 L
.36128 0 L
.36243 0 L
.36348 0 L
.36458 0 L
.3657 0 L
.36692 0 L
.36821 0 L
.36944 0 L
.37011 0 L
.37085 0 L
.37214 0 L
.37336 0 L
.37467 0 L
.3759 0 L
.37702 0 L
.38214 0 L
.38339 0 L
.38472 0 L
.38549 0 L
.38619 0 L
.38756 0 L
.38879 0 L
.38994 0 L
.39117 0 L
.39253 0 L
.39371 0 L
.39482 0 L
.39599 0 L
.39725 0 L
.39853 0 L
.3999 0 L
.40069 0 L
.40141 0 L
.40281 0 L
.40425 0 L
.40582 0 L
.40717 0 L
.40789 0 L
.40866 0 L
.41002 0 L
.4113 0 L
.41205 0 L
.41276 0 L
Mistroke
.4141 0 L
.41526 0 L
.4165 0 L
.41786 0 L
.41911 0 L
.42043 0 L
.42117 0 L
.42187 0 L
.42477 0 L
.42727 0 L
.42996 0 L
.43147 0 L
Mfstroke
.43147 0 m
.43224 0 L
s
.4363 0 m
.4368 0 L
.43749 0 L
.43877 0 L
.44166 0 L
.4518 0 L
.45457 0 L
.4553 0 L
.4561 0 L
.45684 0 L
.45753 0 L
.45889 0 L
.45957 0 L
.46033 0 L
.46164 0 L
.46286 0 L
s
.46286 0 m
.46983 0 L
s
.49173 0 m
.49356 0 L
.4961 0 L
.49881 0 L
.50371 0 L
.50438 0 L
.50511 0 L
.50643 0 L
.50779 0 L
.50858 0 L
.5093 0 L
.51057 0 L
.51195 0 L
.51446 0 L
s
.51446 0 m
.51668 0 L
s
.55314 0 m
.55535 0 L
.55801 0 L
.56034 0 L
.56162 0 L
.56282 0 L
.56351 0 L
.56425 0 L
.56554 0 L
.56686 0 L
.56808 0 L
.57857 0 L
.57995 0 L
.58144 0 L
s
.58144 0 m
.58362 0 L
s
.61282 0 m
.61383 0 L
.61529 0 L
.6179 0 L
.62028 0 L
.62097 0 L
.62172 0 L
.62309 0 L
.62385 0 L
.62466 0 L
.62542 0 L
.62611 0 L
.62746 0 L
.62892 0 L
.63157 0 L
.63285 0 L
.63406 0 L
.63473 0 L
.63546 0 L
.63674 0 L
.63795 0 L
.63924 0 L
.64156 0 L
.64285 0 L
.64425 0 L
s
.64425 0 m
.64622 0 L
s
.66017 0 m
.6612 0 L
.66269 0 L
.66406 0 L
.66531 0 L
.66649 0 L
.66774 0 L
.6691 0 L
.66983 0 L
.67049 0 L
.67197 0 L
.67464 0 L
s
.67464 0 m
.67633 0 L
s
.69484 0 m
.6949 0 L
.70034 0 L
.70191 0 L
.7034 0 L
.70619 0 L
.70885 0 L
.71168 0 L
.71306 0 L
.71436 0 L
.71552 0 L
.71678 0 L
.71791 0 L
.71916 0 L
.72046 0 L
.72167 0 L
.72617 0 L
.72739 0 L
.72871 0 L
.72988 0 L
.73112 0 L
s
.73112 0 m
.73177 0 L
s
.73713 0 m
.73769 0 L
.73907 0 L
.74186 0 L
.74444 0 L
.74685 0 L
.75224 0 L
.75371 0 L
.75452 0 L
.75528 0 L
.75661 0 L
.75732 0 L
.75808 0 L
.75881 0 L
.7595 0 L
.76024 0 L
.76104 0 L
.76251 0 L
.76385 0 L
.76659 0 L
.76912 0 L
.77035 0 L
.7717 0 L
.77306 0 L
.7738 0 L
.77449 0 L
.77577 0 L
.77693 0 L
.77955 0 L
.78188 0 L
.78435 0 L
.78706 0 L
.78957 0 L
.79174 0 L
.79288 0 L
.79408 0 L
s
.79408 0 m
.79412 0 L
s
.80139 0 m
.80173 0 L
.80462 0 L
.80733 0 L
.80866 0 L
.80987 0 L
.81095 0 L
.81212 0 L
.81336 0 L
.81454 0 L
.81583 0 L
.81721 0 L
.81838 0 L
.81968 0 L
.82108 0 L
.82257 0 L
.82526 0 L
.82807 0 L
.83115 0 L
.83251 0 L
.83323 0 L
.83399 0 L
.83465 0 L
.83538 0 L
.83667 0 L
.83792 0 L
.83926 0 L
.84053 0 L
.84169 0 L
.84666 0 L
.84802 0 L
.84947 0 L
.85084 0 L
.85208 0 L
.85335 0 L
.85453 0 L
.85581 0 L
.85717 0 L
.85835 0 L
.85945 0 L
.86196 0 L
.86735 0 L
.87018 0 L
.87174 0 L
.8732 0 L
.87457 0 L
.87583 0 L
.87651 0 L
.87723 0 L
.87795 0 L
Mistroke
.87873 0 L
.88001 0 L
.88138 0 L
.88267 0 L
.88385 0 L
.88641 0 L
.88912 0 L
.89054 0 L
.8921 0 L
.89484 0 L
.89741 0 L
.89984 0 L
.90265 0 L
.90522 0 L
.91004 0 L
.91258 0 L
.91397 0 L
.91529 0 L
.91652 0 L
.91785 0 L
.91906 0 L
.92017 0 L
.92123 0 L
.92238 0 L
.9247 0 L
.92735 0 L
.92875 0 L
.93023 0 L
.93152 0 L
.9322 0 L
.93294 0 L
.93424 0 L
.93545 0 L
.93664 0 L
.93794 0 L
.94056 0 L
.94298 0 L
.94523 0 L
.95066 0 L
.95352 0 L
.95508 0 L
.95654 0 L
.95793 0 L
.95919 0 L
.95991 0 L
.96059 0 L
.96131 0 L
.9621 0 L
.96338 0 L
.96475 0 L
Mistroke
.96592 0 L
.96721 0 L
.97147 0 L
.97607 0 L
.97819 0 L
.98042 0 L
.98133 0 L
.98232 0 L
.9834 0 L
.9844 0 L
.98545 0 L
.98642 0 L
.98748 0 L
.9886 0 L
.98958 0 L
.99049 0 L
.99257 0 L
.99444 0 L
.99615 0 L
1 0 L
Mfstroke
0 0 m
.00123 0 L
.00236 0 L
.00365 0 L
.00488 0 L
.00601 0 L
.00706 0 L
.00821 0 L
.00942 0 L
.01065 0 L
.01196 0 L
.0132 0 L
.01434 0 L
.01566 0 L
.01641 0 L
.01711 0 L
.01839 0 L
.01975 0 L
.02043 0 L
.02115 0 L
.02245 0 L
.02317 0 L
.02384 0 L
.02458 0 L
.02537 0 L
.02605 0 L
.02679 0 L
.02814 0 L
.02945 0 L
.03067 0 L
.03184 0 L
.03295 0 L
.03416 0 L
.03547 0 L
.03676 0 L
.03813 0 L
.03929 0 L
.04057 0 L
.04131 0 L
.042 0 L
.04274 0 L
.04355 0 L
.04492 0 L
.04567 0 L
.04637 0 L
.0477 0 L
s
.0477 0 m
.04781 0 L
s
.05302 0 m
.05321 0 L
.05389 0 L
.05462 0 L
s
.05462 0 m
.05522 0 L
s
.05579 0 m
.05627 0 L
.057 0 L
.05779 0 L
.05932 0 L
s
.05932 0 m
.06006 0 L
s
.06113 0 m
.06207 0 L
.06276 0 L
s
.06276 0 m
.0632 0 L
s
.06696 0 m
.06737 0 L
.06812 0 L
.06881 0 L
s
.06881 0 m
.06918 0 L
s
.07189 0 m
.0731 0 L
.07384 0 L
.07452 0 L
.07577 0 L
.07713 0 L
.07828 0 L
.0795 0 L
s
.0795 0 m
.07987 0 L
s
.08358 0 m
.08412 0 L
.08481 0 L
.08604 0 L
s
.08604 0 m
.08705 0 L
s
.08889 0 m
.08985 0 L
.09121 0 L
.09189 0 L
.09264 0 L
.09398 0 L
s
.09398 0 m
.09416 0 L
s
.09916 0 m
.10018 0 L
.10136 0 L
s
.10136 0 m
.10198 0 L
s
.10527 0 m
.10552 0 L
.10628 0 L
.10766 0 L
.109 0 L
s
.109 0 m
.10903 0 L
s
.11631 0 m
.11746 0 L
.11875 0 L
.12009 0 L
.1208 0 L
.12156 0 L
s
.12156 0 m
.12223 0 L
s
.12807 0 m
.12907 0 L
.13035 0 L
.13171 0 L
.13289 0 L
.13399 0 L
.13649 0 L
.13779 0 L
s
.13779 0 m
.13787 0 L
s
.14591 0 m
.14611 0 L
.14739 0 L
.14811 0 L
.14878 0 L
.15005 0 L
s
.15005 0 m
.1513 0 L
s
.15402 0 m
.15405 0 L
.15534 0 L
.15669 0 L
.15795 0 L
.16086 0 L
s
.16086 0 m
.16203 0 L
s
.17002 0 m
.1708 0 L
.17208 0 L
.17322 0 L
.17445 0 L
s
.17445 0 m
.17544 0 L
s
.17819 0 m
.17855 0 L
.17979 0 L
.18103 0 L
.18221 0 L
.18326 0 L
.18442 0 L
.18567 0 L
.18699 0 L
.18816 0 L
.18938 0 L
s
.18938 0 m
.19068 0 L
s
.19863 0 m
.19972 0 L
.20042 0 L
.20118 0 L
.20254 0 L
s
.20254 0 m
.20316 0 L
s
.2156 0 m
.21606 0 L
.21677 0 L
.21798 0 L
.21926 0 L
.21992 0 L
.22066 0 L
.22196 0 L
.22269 0 L
.22337 0 L
.22408 0 L
.22486 0 L
.22565 0 L
s
.22565 0 m
.22575 0 L
s
.23348 0 m
.23365 0 L
.23496 0 L
.23571 0 L
.23639 0 L
.23765 0 L
.23899 0 L
.24019 0 L
s
.24019 0 m
.24055 0 L
s
.25299 0 m
.25343 0 L
.25484 0 L
.2561 0 L
.25749 0 L
.25879 0 L
.26 0 L
.2612 0 L
.26229 0 L
s
.26229 0 m
.26342 0 L
s
.27365 0 m
.27417 0 L
.27536 0 L
.27765 0 L
.27891 0 L
.28008 0 L
.28135 0 L
.28203 0 L
.28276 0 L
.28404 0 L
.28523 0 L
.28628 0 L
.2874 0 L
.28863 0 L
.28978 0 L
.29107 0 L
.29229 0 L
.29339 0 L
s
.29339 0 m
.29437 0 L
s
.30501 0 m
.30594 0 L
.30668 0 L
.30747 0 L
.30816 0 L
.30892 0 L
.31025 0 L
.31155 0 L
.31228 0 L
.31294 0 L
s
.31294 0 m
.31497 0 L
s
.33554 0 m
.33625 0 L
.33755 0 L
.34018 0 L
.3409 0 L
.34166 0 L
.34304 0 L
.34432 0 L
.34552 0 L
.34685 0 L
.34825 0 L
.34942 0 L
.3507 0 L
.35186 0 L
.35295 0 L
s
.35295 0 m
.35589 0 L
s
.36973 0 m
.37009 0 L
.37081 0 L
.37148 0 L
.37274 0 L
.37409 0 L
.37485 0 L
.37568 0 L
.37717 0 L
s
.37717 0 m
.37741 0 L
s
.40647 0 m
.40652 0 L
.40788 0 L
.40864 0 L
.40934 0 L
.41016 0 L
.41094 0 L
.41166 0 L
.41244 0 L
s
.41244 0 m
.41371 0 L
s
.42275 0 m
.42305 0 L
.42574 0 L
.42828 0 L
.43059 0 L
.43186 0 L
.43304 0 L
.43431 0 L
.43498 0 L
.43571 0 L
.43699 0 L
.43817 0 L
s
.43817 0 m
.44332 0 L
s
.46758 0 m
.47352 0 L
.47603 0 L
.4787 0 L
.47979 0 L
.48097 0 L
.48227 0 L
.48348 0 L
.48415 0 L
.48488 0 L
.48564 0 L
.48635 0 L
.48899 0 L
s
.48899 0 m
.49268 0 L
s
.51687 0 m
.51935 0 L
.52231 0 L
.52498 0 L
.52785 0 L
.53045 0 L
.53176 0 L
.5325 0 L
.53319 0 L
.53443 0 L
.53556 0 L
.53687 0 L
.5381 0 L
.54901 0 L
s
.54901 0 m
.55245 0 L
s
.58215 0 m
.58931 0 L
.59062 0 L
.59186 0 L
.59254 0 L
.59329 0 L
.5946 0 L
.59584 0 L
.59716 0 L
.59829 0 L
.59954 0 L
.60222 0 L
.60373 0 L
.60512 0 L
.60634 0 L
.60767 0 L
.61036 0 L
.61268 0 L
s
.61268 0 m
.61334 0 L
s
.6431 0 m
.64315 0 L
.64564 0 L
.64805 0 L
.65031 0 L
.65158 0 L
.65294 0 L
.65368 0 L
.65446 0 L
.65512 0 L
.65585 0 L
.65662 0 L
.65732 0 L
.6589 0 L
.66037 0 L
.66173 0 L
s
.66173 0 m
.66234 0 L
s
.673 0 m
.67503 0 L
.6776 0 L
.67993 0 L
.68121 0 L
.6824 0 L
.68368 0 L
.68436 0 L
.68509 0 L
.68639 0 L
.68756 0 L
.69047 0 L
.69174 0 L
.69315 0 L
.69426 0 L
.69546 0 L
.69672 0 L
.69791 0 L
.70056 0 L
.70308 0 L
s
.70308 0 m
.70366 0 L
s
.72738 0 m
.72836 0 L
.72954 0 L
.73084 0 L
.73202 0 L
.73311 0 L
.7344 0 L
.73556 0 L
.73691 0 L
.73819 0 L
.74087 0 L
s
.74087 0 m
.74352 0 L
s
.78177 0 m
.78481 0 L
.78753 0 L
.79001 0 L
.79254 0 L
.79377 0 L
.79489 0 L
.79604 0 L
.79726 0 L
.79859 0 L
.79984 0 L
.80114 0 L
.80234 0 L
.80505 0 L
.80776 0 L
.81029 0 L
.81156 0 L
.81293 0 L
.8137 0 L
.81444 0 L
.81583 0 L
.82025 0 L
.82257 0 L
.82502 0 L
.82775 0 L
s
.82775 0 m
.82885 0 L
s
.84437 0 m
.84529 0 L
.84796 0 L
.84947 0 L
.85084 0 L
.85212 0 L
.85284 0 L
.85351 0 L
.85473 0 L
.85604 0 L
.85735 0 L
.85855 0 L
.86126 0 L
.86365 0 L
.86618 0 L
s
.86618 0 m
.87008 0 L
s
.88722 0 m
.88779 0 L
.89042 0 L
.89193 0 L
.89331 0 L
.89599 0 L
.8983 0 L
.90074 0 L
.90342 0 L
.9059 0 L
.91069 0 L
.91305 0 L
.9142 0 L
.91524 0 L
.91644 0 L
.91772 0 L
.91839 0 L
.91911 0 L
.92042 0 L
.92162 0 L
.92289 0 L
.92515 0 L
.92761 0 L
.92896 0 L
.93023 0 L
.93096 0 L
.93174 0 L
.93311 0 L
.93379 0 L
.93451 0 L
.9358 0 L
.94069 0 L
.94315 0 L
.94584 0 L
.9506 0 L
.95503 0 L
.95632 0 L
.95753 0 L
.95862 0 L
.9598 0 L
.96109 0 L
.96245 0 L
.96362 0 L
.9649 0 L
.96628 0 L
.96754 0 L
.97039 0 L
.97552 0 L
.97781 0 L
.98024 0 L
Mistroke
.98151 0 L
.98218 0 L
.98291 0 L
.98418 0 L
.98538 0 L
.98651 0 L
.98775 0 L
.98905 0 L
.99025 0 L
.99138 0 L
.99241 0 L
.99472 0 L
.99725 0 L
1 0 L
Mfstroke
0 0 m
.00236 0 L
.00365 0 L
.00488 0 L
.00602 0 L
.00726 0 L
.00839 0 L
.00942 0 L
.01066 0 L
.01181 0 L
.01307 0 L
.01444 0 L
.01512 0 L
.01586 0 L
s
.01586 0 m
.01621 0 L
s
.04705 0 m
.04715 0 L
.04848 0 L
.04961 0 L
.05086 0 L
.05161 0 L
.05233 0 L
s
.05233 0 m
.05278 0 L
s
.05541 0 m
.05587 0 L
s
.05587 0 m
.05605 0 L
s
.06071 0 m
.06088 0 L
s
.06088 0 m
.06114 0 L
s
.06296 0 m
.06344 0 L
.06417 0 L
.06484 0 L
.06615 0 L
s
.06615 0 m
.06694 0 L
s
.06918 0 m
.07015 0 L
.07089 0 L
.07158 0 L
s
.07158 0 m
.07189 0 L
s
.07736 0 m
.07739 0 L
s
.07739 0 m
.07755 0 L
s
.07998 0 m
.0804 0 L
.08115 0 L
.08194 0 L
.08265 0 L
.08343 0 L
s
.08343 0 m
.0836 0 L
s
.08718 0 m
.08744 0 L
.08883 0 L
s
.08883 0 m
.08891 0 L
s
.09412 0 m
.09429 0 L
.09551 0 L
.0966 0 L
.09778 0 L
.09908 0 L
s
.09908 0 m
.09928 0 L
s
.10204 0 m
.10284 0 L
.1041 0 L
.10527 0 L
s
.10527 0 m
.10528 0 L
s
.10903 0 m
.10917 0 L
.11034 0 L
.11171 0 L
.11244 0 L
.11321 0 L
.11395 0 L
.11462 0 L
.11593 0 L
s
.11593 0 m
.1163 0 L
s
.12221 0 m
.12322 0 L
.12394 0 L
.12461 0 L
.12586 0 L
.12722 0 L
s
.12722 0 m
.12809 0 L
s
.13782 0 m
.13857 0 L
.1399 0 L
.14116 0 L
.14231 0 L
.14449 0 L
.14572 0 L
s
.14572 0 m
.14589 0 L
s
.15147 0 m
.15184 0 L
.15323 0 L
.154 0 L
s
.154 0 m
.15402 0 L
s
.16178 0 m
.1627 0 L
.16344 0 L
.16414 0 L
.16495 0 L
.16568 0 L
.16703 0 L
.16778 0 L
.16847 0 L
.16975 0 L
s
.16975 0 m
.17006 0 L
s
.17531 0 m
.1754 0 L
.17608 0 L
.1774 0 L
s
.1774 0 m
.17819 0 L
s
.19067 0 m
.19191 0 L
.1931 0 L
.19419 0 L
.19548 0 L
.19687 0 L
.19816 0 L
s
.19816 0 m
.19872 0 L
s
.20313 0 m
.20396 0 L
.20515 0 L
.20645 0 L
.20767 0 L
.20879 0 L
.21 0 L
.21131 0 L
.21255 0 L
.2137 0 L
.21503 0 L
s
.21503 0 m
.21561 0 L
s
.22783 0 m
.22848 0 L
.22983 0 L
.23057 0 L
.23126 0 L
.23248 0 L
.23382 0 L
s
.23382 0 m
.23407 0 L
s
.24052 0 m
.24098 0 L
.24246 0 L
.24314 0 L
.24385 0 L
.24514 0 L
.24637 0 L
.24753 0 L
.24879 0 L
.25015 0 L
s
.25015 0 m
.25203 0 L
s
.2635 0 m
.26367 0 L
.26453 0 L
.26533 0 L
.26611 0 L
.26684 0 L
.26813 0 L
.26881 0 L
.26953 0 L
.27091 0 L
.27169 0 L
.27242 0 L
s
.27242 0 m
.27354 0 L
s
.29388 0 m
.2984 0 L
.29974 0 L
.30041 0 L
.30114 0 L
.30244 0 L
.30365 0 L
s
.30365 0 m
.30561 0 L
s
.31496 0 m
.31571 0 L
.31846 0 L
.31968 0 L
.32102 0 L
.32228 0 L
.32344 0 L
.32416 0 L
.32493 0 L
.32632 0 L
.32757 0 L
.32893 0 L
.33041 0 L
.33198 0 L
.33477 0 L
s
.33477 0 m
.3355 0 L
s
.35619 0 m
.35677 0 L
.35813 0 L
.35971 0 L
.36048 0 L
.36118 0 L
.36247 0 L
.36385 0 L
.36457 0 L
.36535 0 L
.36609 0 L
.36678 0 L
.36804 0 L
.3694 0 L
s
.3694 0 m
.3702 0 L
s
.37685 0 m
.37728 0 L
.37994 0 L
.38134 0 L
.38282 0 L
.38412 0 L
.38486 0 L
.38554 0 L
.38676 0 L
.38806 0 L
.39785 0 L
.39922 0 L
.39998 0 L
.40067 0 L
.40227 0 L
.40374 0 L
s
.40374 0 m
.40642 0 L
s
.41393 0 m
.41475 0 L
.41594 0 L
.41719 0 L
.41857 0 L
.41984 0 L
.42104 0 L
.42235 0 L
s
.42235 0 m
.42317 0 L
s
.44263 0 m
.45951 0 L
.46462 0 L
s
.46462 0 m
.46788 0 L
s
.49224 0 m
.49932 0 L
.50196 0 L
.50335 0 L
.50411 0 L
.50482 0 L
.50611 0 L
.50679 0 L
.50753 0 L
.50883 0 L
.51002 0 L
.51126 0 L
.51241 0 L
.51502 0 L
s
.51502 0 m
.5169 0 L
s
.55336 0 m
.55492 0 L
.55766 0 L
.56018 0 L
.56128 0 L
.56247 0 L
.56382 0 L
.56509 0 L
.5658 0 L
.56655 0 L
.5679 0 L
.56914 0 L
.5703 0 L
.57295 0 L
.57587 0 L
.57853 0 L
.58 0 L
.5816 0 L
s
.5816 0 m
.58328 0 L
s
.61338 0 m
.61578 0 L
.61868 0 L
.62009 0 L
.62137 0 L
.62273 0 L
.62348 0 L
.62418 0 L
.62495 0 L
.62566 0 L
.62643 0 L
.62725 0 L
.62969 0 L
.63098 0 L
.63235 0 L
.63354 0 L
.63486 0 L
.63606 0 L
.63718 0 L
.63786 0 L
.63858 0 L
.63986 0 L
.64136 0 L
.64276 0 L
s
.64276 0 m
.64328 0 L
s
.66227 0 m
.6623 0 L
.6635 0 L
.66481 0 L
.66599 0 L
.66708 0 L
.66829 0 L
.66962 0 L
.67101 0 L
.6723 0 L
s
.6723 0 m
.67326 0 L
s
.70252 0 m
.70781 0 L
.7104 0 L
.71182 0 L
.71316 0 L
.71441 0 L
.71577 0 L
.717 0 L
.71814 0 L
.71934 0 L
.72066 0 L
.72204 0 L
.72333 0 L
.72625 0 L
s
.72625 0 m
.72762 0 L
s
.7432 0 m
.74328 0 L
.74845 0 L
.7511 0 L
.75249 0 L
.75397 0 L
.75527 0 L
.756 0 L
.75669 0 L
.7579 0 L
.7592 0 L
.76045 0 L
.76182 0 L
.76431 0 L
.76672 0 L
.76898 0 L
.77037 0 L
.77188 0 L
.77324 0 L
.7745 0 L
.77586 0 L
.77736 0 L
.78038 0 L
.78302 0 L
s
.78302 0 m
.78321 0 L
s
.82225 0 m
.82334 0 L
.8263 0 L
.8291 0 L
.83185 0 L
.83305 0 L
.83437 0 L
.83568 0 L
.83706 0 L
.83779 0 L
.83856 0 L
.8393 0 L
.83997 0 L
.84126 0 L
.84267 0 L
.84523 0 L
.84771 0 L
.84906 0 L
s
.84906 0 m
.84921 0 L
s
.86184 0 m
.8658 0 L
.87128 0 L
.87262 0 L
.87405 0 L
.87487 0 L
.87562 0 L
.87637 0 L
.87709 0 L
.87835 0 L
.8797 0 L
.88085 0 L
.88212 0 L
.88759 0 L
.88999 0 L
.89125 0 L
.89257 0 L
.89502 0 L
.89726 0 L
.89987 0 L
.90266 0 L
s
.90266 0 m
.90394 0 L
s
.93512 0 m
.93528 0 L
.93606 0 L
.9369 0 L
.93843 0 L
.9413 0 L
.94383 0 L
.94661 0 L
.95226 0 L
.95478 0 L
.9561 0 L
.95749 0 L
.95871 0 L
.96005 0 L
.96126 0 L
.9624 0 L
.96363 0 L
.96493 0 L
.96604 0 L
.96726 0 L
.96998 0 L
.97253 0 L
.9751 0 L
s
.9751 0 m
.97569 0 L
s
.99842 0 m
1 0 L
s
0 0 m
.00236 0 L
.00365 0 L
.00488 0 L
.00602 0 L
.00726 0 L
.00839 0 L
.00942 0 L
.01066 0 L
.01181 0 L
.01307 0 L
.01444 0 L
.01512 0 L
.01586 0 L
.01721 0 L
.01853 0 L
.01975 0 L
.02106 0 L
.02179 0 L
.02247 0 L
.02372 0 L
.02503 0 L
.02621 0 L
.02732 0 L
.02853 0 L
.02982 0 L
.03121 0 L
.03199 0 L
.03271 0 L
.03404 0 L
.03471 0 L
.03544 0 L
.03672 0 L
.03809 0 L
.03938 0 L
.04057 0 L
.04192 0 L
.04314 0 L
.04382 0 L
.04456 0 L
.0459 0 L
s
.0459 0 m
.04692 0 L
s
.05276 0 m
.05366 0 L
.05441 0 L
.05511 0 L
s
.05511 0 m
.05539 0 L
s
.05606 0 m
.05668 0 L
.05738 0 L
.05815 0 L
.05953 0 L
s
.05953 0 m
.06068 0 L
s
.06116 0 m
.06212 0 L
s
.06212 0 m
.06297 0 L
s
.06693 0 m
.06739 0 L
.06808 0 L
.06882 0 L
s
.06882 0 m
.06918 0 L
s
.07189 0 m
.07316 0 L
.0739 0 L
.07459 0 L
.0753 0 L
.07609 0 L
s
.07609 0 m
.07736 0 L
s
.07753 0 m
.07877 0 L
.07955 0 L
s
.07955 0 m
.07997 0 L
s
.08359 0 m
.08481 0 L
.08617 0 L
s
.08617 0 m
.08718 0 L
s
.0889 0 m
.08953 0 L
.0903 0 L
.09159 0 L
.09232 0 L
.09298 0 L
s
.09298 0 m
.09412 0 L
s
.09929 0 m
.10026 0 L
.1015 0 L
s
.1015 0 m
.10207 0 L
s
.10527 0 m
.10653 0 L
.10789 0 L
s
.10789 0 m
.10904 0 L
s
.11629 0 m
.11729 0 L
.11803 0 L
.11872 0 L
.11947 0 L
.1203 0 L
.12099 0 L
.12174 0 L
s
.12174 0 m
.1222 0 L
s
.12809 0 m
.12846 0 L
.12976 0 L
.13089 0 L
.13209 0 L
.13339 0 L
.1346 0 L
.13734 0 L
s
.13734 0 m
.13781 0 L
s
.14589 0 m
.14683 0 L
.14816 0 L
.14942 0 L
.15058 0 L
s
.15058 0 m
.15148 0 L
s
.15401 0 m
.1547 0 L
.15606 0 L
.15735 0 L
.1587 0 L
.15939 0 L
.16013 0 L
s
.16013 0 m
.16178 0 L
s
.17006 0 m
.17097 0 L
.17209 0 L
.17331 0 L
.17465 0 L
s
.17465 0 m
.17533 0 L
s
.17818 0 m
.17864 0 L
.18116 0 L
.18243 0 L
.18315 0 L
.18383 0 L
.18456 0 L
.18524 0 L
.18675 0 L
.18805 0 L
.18943 0 L
.19061 0 L
s
.19061 0 m
.19067 0 L
s
.19878 0 m
.19937 0 L
.20043 0 L
.20156 0 L
.20282 0 L
s
.20282 0 m
.20313 0 L
s
.21561 0 m
.21577 0 L
.21645 0 L
.21776 0 L
.21897 0 L
.22011 0 L
.22132 0 L
.22254 0 L
.22387 0 L
.22502 0 L
.22626 0 L
.22742 0 L
s
.22742 0 m
.22794 0 L
s
.23442 0 m
.23518 0 L
.23586 0 L
.23661 0 L
.23742 0 L
.23818 0 L
.23888 0 L
.23962 0 L
s
.23962 0 m
.24051 0 L
s
.25203 0 m
.25532 0 L
.25668 0 L
.2574 0 L
.25815 0 L
.25954 0 L
.26081 0 L
.26218 0 L
.26295 0 L
s
.26295 0 m
.26355 0 L
s
.27354 0 m
.27491 0 L
.27632 0 L
.27764 0 L
.27887 0 L
.28004 0 L
.28138 0 L
.28259 0 L
.28329 0 L
.28402 0 L
.28534 0 L
.28608 0 L
.28687 0 L
.28761 0 L
.28831 0 L
.28961 0 L
.2908 0 L
.29211 0 L
.29285 0 L
.29354 0 L
s
.29354 0 m
.29395 0 L
s
.30602 0 m
.30717 0 L
.30824 0 L
.30947 0 L
.31081 0 L
.31194 0 L
.31314 0 L
.31448 0 L
s
.31448 0 m
.31495 0 L
s
.33549 0 m
.33742 0 L
.33882 0 L
.3403 0 L
.34159 0 L
.34232 0 L
.34301 0 L
.34422 0 L
.34552 0 L
.34778 0 L
.34903 0 L
.3502 0 L
.35159 0 L
.35284 0 L
.35404 0 L
.3553 0 L
s
.3553 0 m
.35621 0 L
s
.37031 0 m
.37069 0 L
.37187 0 L
.37312 0 L
.37444 0 L
.3758 0 L
s
.3758 0 m
.3769 0 L
s
.40557 0 m
.40589 0 L
.40726 0 L
.40855 0 L
.40988 0 L
.41059 0 L
.41135 0 L
.4127 0 L
.41394 0 L
s
.41394 0 m
.41502 0 L
s
.42271 0 m
.42365 0 L
.42506 0 L
.428 0 L
.42939 0 L
.4307 0 L
.43194 0 L
.43329 0 L
.43451 0 L
.43564 0 L
.43699 0 L
.43821 0 L
.44095 0 L
s
.44095 0 m
.4431 0 L
s
.46778 0 m
.47092 0 L
.47593 0 L
.47817 0 L
.47936 0 L
.48062 0 L
.48139 0 L
.48209 0 L
.48344 0 L
.48483 0 L
.48613 0 L
.48739 0 L
.48855 0 L
.49116 0 L
s
.49116 0 m
.49249 0 L
s
.51694 0 m
.51767 0 L
.52227 0 L
.52471 0 L
.52731 0 L
.52996 0 L
.53136 0 L
.53206 0 L
.53283 0 L
.53364 0 L
.53439 0 L
.53509 0 L
.53583 0 L
.53659 0 L
.53731 0 L
.53866 0 L
.54396 0 L
s
.54396 0 m
.55322 0 L
s
.58333 0 m
.58411 0 L
.58899 0 L
.59027 0 L
.59095 0 L
.59166 0 L
.59298 0 L
.59419 0 L
.59492 0 L
.59561 0 L
.59637 0 L
.59718 0 L
.5986 0 L
.59989 0 L
.60246 0 L
.60376 0 L
.60519 0 L
.6059 0 L
.60665 0 L
.60802 0 L
.61064 0 L
.61215 0 L
s
.61215 0 m
.61334 0 L
s
.6418 0 m
.64775 0 L
.64914 0 L
.65063 0 L
.65135 0 L
.65203 0 L
.65331 0 L
.65465 0 L
.65541 0 L
.65611 0 L
.65681 0 L
.65759 0 L
.65917 0 L
.66178 0 L
s
.66178 0 m
.66243 0 L
s
.67325 0 m
.67491 0 L
.67754 0 L
.68044 0 L
.68123 0 L
.68197 0 L
.68264 0 L
.68337 0 L
.68416 0 L
.685 0 L
.68579 0 L
.68651 0 L
.6879 0 L
.68939 0 L
.6921 0 L
.69334 0 L
.69467 0 L
.69612 0 L
.69747 0 L
.69887 0 L
.70038 0 L
.70314 0 L
s
.70314 0 m
.7033 0 L
s
.72765 0 m
.72867 0 L
.72994 0 L
.7311 0 L
.73239 0 L
.73377 0 L
.73494 0 L
.73603 0 L
.73723 0 L
.7385 0 L
.74064 0 L
.74299 0 L
s
.74299 0 m
.74318 0 L
s
.7831 0 m
.7834 0 L
.78592 0 L
.78865 0 L
.79118 0 L
.79358 0 L
.79482 0 L
.79617 0 L
.79739 0 L
.79853 0 L
.79975 0 L
.80109 0 L
.8025 0 L
.80382 0 L
.80848 0 L
.80961 0 L
.81082 0 L
.81214 0 L
.81337 0 L
.81408 0 L
.81484 0 L
.81623 0 L
.81758 0 L
.81883 0 L
.82141 0 L
s
.82141 0 m
.82304 0 L
s
.84889 0 m
.8502 0 L
.85146 0 L
.85261 0 L
.85386 0 L
.85518 0 L
.85641 0 L
.85761 0 L
.85892 0 L
.86131 0 L
s
.86131 0 m
.86287 0 L
s
.90266 0 m
.90457 0 L
.90727 0 L
.91012 0 L
.91168 0 L
.91314 0 L
.91439 0 L
.91572 0 L
.91649 0 L
.91721 0 L
.91856 0 L
.91986 0 L
.92123 0 L
.92253 0 L
.92371 0 L
.92663 0 L
.92932 0 L
.93072 0 L
.93221 0 L
.93298 0 L
.93369 0 L
.93448 0 L
.93533 0 L
.93685 0 L
.93828 0 L
.94098 0 L
s
.94098 0 m
.9434 0 L
s
.9739 0 m
.97685 0 L
.97916 0 L
.98038 0 L
.98168 0 L
.9828 0 L
.98404 0 L
.98516 0 L
.98622 0 L
.9873 0 L
.98829 0 L
.98937 0 L
.99052 0 L
.99286 0 L
.99504 0 L
1 0 L
s
0 0 m
0 0 rlineto s
.04713 0 m
.04837 0 L
s
.04837 0 m
.0496 0 L
s
.04967 0 m
.05077 0 L
.05149 0 L
.05217 0 L
.05291 0 L
s
.05291 0 m
.05298 0 L
s
.06325 0 m
.06377 0 L
.06446 0 L
.06527 0 L
.06603 0 L
.06674 0 L
s
.06674 0 m
.06695 0 L
s
.06918 0 m
.06984 0 L
.0707 0 L
.07149 0 L
s
.07149 0 m
.07194 0 L
s
.0775 0 m
.07774 0 L
s
.07774 0 m
.07792 0 L
s
.08003 0 m
.08052 0 L
.08183 0 L
.08257 0 L
.08325 0 L
s
.08325 0 m
.08356 0 L
s
.08703 0 m
.08757 0 L
.08889 0 L
s
.08889 0 m
.0889 0 L
s
.09407 0 m
.09439 0 L
.09519 0 L
.09595 0 L
.09731 0 L
.09856 0 L
s
.09856 0 m
.09919 0 L
s
.10213 0 m
.10239 0 L
.10315 0 L
.10387 0 L
.10514 0 L
s
.10514 0 m
.10525 0 L
s
.10908 0 m
.11032 0 L
.11157 0 L
.11289 0 L
.11414 0 L
.11545 0 L
s
.11545 0 m
.11631 0 L
s
.12216 0 m
.12401 0 L
.12524 0 L
.12636 0 L
.12759 0 L
s
.12759 0 m
.12807 0 L
s
.13765 0 m
.13916 0 L
.14051 0 L
.14173 0 L
.14288 0 L
.14412 0 L
.14529 0 L
s
.14529 0 m
.14586 0 L
s
.15132 0 m
.15141 0 L
.15277 0 L
.15354 0 L
s
.15354 0 m
.15399 0 L
s
.16199 0 m
.16238 0 L
.16312 0 L
.16382 0 L
.16463 0 L
.16537 0 L
.16671 0 L
.16746 0 L
.16816 0 L
s
.16816 0 m
.16988 0 L
s
.17539 0 m
.17577 0 L
.17699 0 L
s
.17699 0 m
.17821 0 L
s
.19067 0 m
.19184 0 L
.19317 0 L
.19392 0 L
.19473 0 L
.1955 0 L
.19621 0 L
.19763 0 L
s
.19763 0 m
.19876 0 L
s
.20312 0 m
.20405 0 L
.2053 0 L
.20662 0 L
.20731 0 L
.20807 0 L
.20941 0 L
.21487 0 L
s
.21487 0 m
.21543 0 L
s
.22796 0 m
.2284 0 L
.22978 0 L
.23049 0 L
.23125 0 L
.23198 0 L
.23264 0 L
.23391 0 L
s
.23391 0 m
.23465 0 L
s
.24055 0 m
.24112 0 L
.24248 0 L
.24377 0 L
.24448 0 L
.24525 0 L
.2466 0 L
.2517 0 L
s
.2517 0 m
.25248 0 L
s
.26359 0 m
.26456 0 L
.26524 0 L
.26596 0 L
.26728 0 L
.26862 0 L
.26929 0 L
.27003 0 L
.27134 0 L
.27256 0 L
s
.27256 0 m
.27352 0 L
s
.29424 0 m
.29465 0 L
.29595 0 L
.29714 0 L
.29841 0 L
.29909 0 L
.2998 0 L
.30108 0 L
.30227 0 L
.30338 0 L
.30461 0 L
.30593 0 L
s
.30593 0 m
.30631 0 L
s
.31494 0 m
.31556 0 L
.31823 0 L
.3197 0 L
.32107 0 L
.32223 0 L
.32349 0 L
.3242 0 L
.32488 0 L
.32616 0 L
.33219 0 L
s
.33219 0 m
.33493 0 L
s
.35623 0 m
.35728 0 L
.35846 0 L
.36064 0 L
.36185 0 L
.36296 0 L
.36427 0 L
.3655 0 L
.36664 0 L
.36787 0 L
.36916 0 L
s
.36916 0 m
.37034 0 L
s
.37681 0 m
.37777 0 L
.38036 0 L
.38279 0 L
.38414 0 L
.3849 0 L
.3856 0 L
.38684 0 L
.38814 0 L
.39775 0 L
.39899 0 L
.40033 0 L
.4016 0 L
.40277 0 L
s
.40277 0 m
.40507 0 L
s
.41573 0 m
.41666 0 L
.41744 0 L
.41815 0 L
.41953 0 L
.42079 0 L
.42196 0 L
s
.42196 0 m
.42228 0 L
s
.44319 0 m
.45036 0 L
.45317 0 L
.45471 0 L
.45547 0 L
.45617 0 L
.45753 0 L
.45824 0 L
.459 0 L
.46022 0 L
.46157 0 L
.46289 0 L
.46409 0 L
.46679 0 L
s
.46679 0 m
.46768 0 L
s
.49255 0 m
.49282 0 L
.50217 0 L
.50345 0 L
.50481 0 L
.50552 0 L
.5063 0 L
.50768 0 L
.50898 0 L
.5097 0 L
.51037 0 L
.5129 0 L
s
.5129 0 m
.51695 0 L
s
.55277 0 m
.55532 0 L
.55787 0 L
.56056 0 L
.56166 0 L
.56285 0 L
.56415 0 L
.56536 0 L
.56608 0 L
.56686 0 L
.5676 0 L
.56827 0 L
.57093 0 L
.57693 0 L
.57952 0 L
.58198 0 L
s
.58198 0 m
.58327 0 L
s
.61336 0 m
.61346 0 L
.61475 0 L
.61759 0 L
.6202 0 L
.62151 0 L
.62225 0 L
.62295 0 L
.62371 0 L
.6244 0 L
.6252 0 L
.62596 0 L
.62728 0 L
.62872 0 L
.63119 0 L
.63256 0 L
.63385 0 L
.63505 0 L
.63636 0 L
.63755 0 L
.63865 0 L
.64007 0 L
.64161 0 L
.64306 0 L
s
.64306 0 m
.64332 0 L
s
.66257 0 m
.66291 0 L
.66369 0 L
.66441 0 L
.66509 0 L
.66581 0 L
.66651 0 L
.66726 0 L
.66861 0 L
.66944 0 L
.67022 0 L
.67168 0 L
s
.67168 0 m
.67324 0 L
s
.70324 0 m
.70532 0 L
.70761 0 L
.71212 0 L
.71338 0 L
.71477 0 L
.71607 0 L
.71728 0 L
.71848 0 L
.71957 0 L
.72082 0 L
.72201 0 L
.7247 0 L
.72755 0 L
s
.72755 0 m
.72767 0 L
s
.74314 0 m
.74435 0 L
.74703 0 L
.75186 0 L
.75316 0 L
.75438 0 L
.75506 0 L
.75579 0 L
.75707 0 L
.7583 0 L
.75959 0 L
.7607 0 L
.76192 0 L
.76487 0 L
.76766 0 L
.77018 0 L
.7716 0 L
.77291 0 L
.77364 0 L
.77432 0 L
.77559 0 L
.77696 0 L
.77844 0 L
.78132 0 L
s
.78132 0 m
.78302 0 L
s
.82294 0 m
.82363 0 L
.8263 0 L
.83177 0 L
.8331 0 L
.8338 0 L
.83454 0 L
.83536 0 L
.83611 0 L
.83682 0 L
.83759 0 L
.83895 0 L
.84019 0 L
.84088 0 L
.84162 0 L
.84298 0 L
.84541 0 L
.84799 0 L
s
.84799 0 m
.84911 0 L
s
.86293 0 m
.86309 0 L
.86892 0 L
.87137 0 L
.87396 0 L
.87531 0 L
.87608 0 L
.8768 0 L
.87806 0 L
.87941 0 L
.88069 0 L
.88142 0 L
.88211 0 L
.88497 0 L
.88747 0 L
.89011 0 L
.89151 0 L
.89303 0 L
.89571 0 L
.90174 0 L
s
.90174 0 m
.90267 0 L
s
.94248 0 m
.94349 0 L
.94905 0 L
.95494 0 L
.95736 0 L
.95872 0 L
.95996 0 L
.96066 0 L
.96143 0 L
.96215 0 L
.96282 0 L
.96412 0 L
.9655 0 L
.96662 0 L
.96765 0 L
.96997 0 L
s
.96997 0 m
.97418 0 L
s
0 0 m
.00236 0 L
.00365 0 L
.00488 0 L
.00602 0 L
.00726 0 L
.00839 0 L
.00942 0 L
.01066 0 L
.01181 0 L
.01307 0 L
.01444 0 L
.01512 0 L
.01586 0 L
.01721 0 L
.01853 0 L
.01975 0 L
.02106 0 L
.02179 0 L
.02247 0 L
.02372 0 L
.02503 0 L
.02621 0 L
.02732 0 L
.02853 0 L
.02982 0 L
.03121 0 L
.03199 0 L
.03271 0 L
.03404 0 L
.03471 0 L
.03544 0 L
.03672 0 L
.03809 0 L
.03938 0 L
.04057 0 L
.04192 0 L
.04314 0 L
.04382 0 L
.04456 0 L
.0459 0 L
s
.0459 0 m
.04666 0 L
s
.0496 0 m
.04961 0 L
s
.04961 0 m
.04967 0 L
s
.05274 0 m
.05366 0 L
.05441 0 L
.05511 0 L
s
.05511 0 m
.05537 0 L
s
.05607 0 m
.05668 0 L
.05738 0 L
.05815 0 L
.05953 0 L
s
.05953 0 m
.06066 0 L
s
.06118 0 m
.06212 0 L
s
.06212 0 m
.06298 0 L
s
.06692 0 m
.06739 0 L
.06808 0 L
.06882 0 L
s
.06882 0 m
.06918 0 L
s
.07188 0 m
.07316 0 L
.0739 0 L
.07459 0 L
.0753 0 L
.07609 0 L
s
.07609 0 m
.07737 0 L
s
.0775 0 m
.07877 0 L
.07955 0 L
s
.07955 0 m
.07997 0 L
s
.08359 0 m
.08481 0 L
.08617 0 L
s
.08617 0 m
.08719 0 L
s
.0889 0 m
.08953 0 L
.0903 0 L
.09159 0 L
.09232 0 L
.09298 0 L
s
.09298 0 m
.09411 0 L
s
.0993 0 m
.10026 0 L
.1015 0 L
s
.1015 0 m
.10211 0 L
s
.10526 0 m
.10527 0 L
.10653 0 L
.10789 0 L
s
.10789 0 m
.10904 0 L
s
.11628 0 m
.11729 0 L
.11803 0 L
.11872 0 L
.11947 0 L
.1203 0 L
.12099 0 L
.12174 0 L
s
.12174 0 m
.1222 0 L
s
.12809 0 m
.12846 0 L
.12976 0 L
.13089 0 L
.13209 0 L
.13339 0 L
.1346 0 L
.13734 0 L
s
.13734 0 m
.13781 0 L
s
.14589 0 m
.14683 0 L
.14816 0 L
.14942 0 L
.15058 0 L
s
.15058 0 m
.1515 0 L
s
.15401 0 m
.1547 0 L
.15606 0 L
.15735 0 L
.1587 0 L
.15939 0 L
.16013 0 L
s
.16013 0 m
.16177 0 L
s
.16973 0 m
.17097 0 L
.17217 0 L
.17331 0 L
.17465 0 L
s
.17465 0 m
.17553 0 L
s
.17821 0 m
.17864 0 L
.17994 0 L
.18062 0 L
.18133 0 L
.18265 0 L
.18387 0 L
.18459 0 L
.18526 0 L
.18679 0 L
.18806 0 L
.18943 0 L
s
.18943 0 m
.19068 0 L
s
.19887 0 m
.19956 0 L
.20077 0 L
.2019 0 L
.2031 0 L
s
.2031 0 m
.20315 0 L
s
.21554 0 m
.21627 0 L
.21745 0 L
.21872 0 L
.21952 0 L
.22025 0 L
.22095 0 L
.22169 0 L
.22307 0 L
.22437 0 L
.22559 0 L
.22689 0 L
.22763 0 L
s
.22763 0 m
.22804 0 L
s
.23476 0 m
.23515 0 L
.23645 0 L
.23781 0 L
.23897 0 L
.24024 0 L
s
.24024 0 m
.24051 0 L
s
.253 0 m
.25413 0 L
.25544 0 L
.25666 0 L
.25799 0 L
.2592 0 L
.26054 0 L
.26121 0 L
.26194 0 L
s
.26194 0 m
.26357 0 L
s
.27364 0 m
.27406 0 L
.27649 0 L
.27796 0 L
.27869 0 L
.27937 0 L
.28063 0 L
.282 0 L
.2827 0 L
.28346 0 L
.28484 0 L
.28606 0 L
.2874 0 L
.28816 0 L
.28886 0 L
.2896 0 L
.2904 0 L
.29114 0 L
.29184 0 L
.29316 0 L
s
.29316 0 m
.29431 0 L
s
.30643 0 m
.3069 0 L
.30763 0 L
.30894 0 L
.31021 0 L
.31139 0 L
.31268 0 L
.31407 0 L
s
.31407 0 m
.31487 0 L
s
.33557 0 m
.33616 0 L
.33869 0 L
.34 0 L
.34073 0 L
.34142 0 L
.34223 0 L
.34297 0 L
.34366 0 L
.34442 0 L
.34701 0 L
.34829 0 L
.34946 0 L
.35081 0 L
.35152 0 L
.35228 0 L
.35349 0 L
.35483 0 L
.35615 0 L
s
.35615 0 m
.35625 0 L
s
.37044 0 m
.37063 0 L
.37182 0 L
.37302 0 L
.37433 0 L
s
.37433 0 m
.37644 0 L
s
.40481 0 m
.40642 0 L
.40759 0 L
.40885 0 L
.41023 0 L
.41152 0 L
.41221 0 L
.41296 0 L
.41433 0 L
s
.41433 0 m
.41625 0 L
s
.41808 0 m
.4267 0 L
.42937 0 L
.43067 0 L
.43185 0 L
.4331 0 L
.43444 0 L
.43514 0 L
.4359 0 L
.43727 0 L
.438 0 L
.4388 0 L
.44042 0 L
.44332 0 L
s
.44332 0 m
.44371 0 L
s
.46773 0 m
.47081 0 L
.47626 0 L
.47886 0 L
.48014 0 L
.48131 0 L
.48248 0 L
.48372 0 L
.48496 0 L
.48632 0 L
.48867 0 L
.49085 0 L
s
.49085 0 m
.49254 0 L
s
.51686 0 m
.52144 0 L
.52405 0 L
.52682 0 L
.52984 0 L
.53133 0 L
.53269 0 L
.534 0 L
.53539 0 L
.53611 0 L
.53678 0 L
.53751 0 L
.5383 0 L
.54339 0 L
s
.54339 0 m
.55321 0 L
s
.58199 0 m
.58681 0 L
.58935 0 L
.59075 0 L
.59208 0 L
.59332 0 L
.59466 0 L
.59588 0 L
.59702 0 L
.59832 0 L
.59951 0 L
.60216 0 L
.60356 0 L
.6043 0 L
.60508 0 L
.60651 0 L
.60782 0 L
.61032 0 L
.61164 0 L
.61303 0 L
s
.61303 0 m
.61332 0 L
s
.64325 0 m
.64519 0 L
.64785 0 L
.65015 0 L
.65131 0 L
.65259 0 L
.65397 0 L
.65526 0 L
.65646 0 L
.65774 0 L
.66007 0 L
.66227 0 L
s
.66227 0 m
.66264 0 L
s
.67324 0 m
.67464 0 L
.67715 0 L
.68009 0 L
.68079 0 L
.68154 0 L
.68288 0 L
.6842 0 L
.68539 0 L
.68607 0 L
.6868 0 L
.68813 0 L
.69869 0 L
.70007 0 L
.70156 0 L
s
.70156 0 m
.70318 0 L
s
.72775 0 m
.72852 0 L
.72981 0 L
.73055 0 L
.73122 0 L
.732 0 L
.73283 0 L
.7336 0 L
.73433 0 L
.7357 0 L
.73647 0 L
.73719 0 L
.73862 0 L
.73991 0 L
.74282 0 L
s
.74282 0 m
.74317 0 L
s
.78308 0 m
.78499 0 L
.79053 0 L
.79199 0 L
.79358 0 L
.79431 0 L
.79508 0 L
.79647 0 L
.79778 0 L
.79901 0 L
.80036 0 L
.80111 0 L
.80181 0 L
.80668 0 L
.80909 0 L
.81026 0 L
.81133 0 L
.81246 0 L
.81366 0 L
.81498 0 L
.81622 0 L
s
.81622 0 m
.82177 0 L
s
.84921 0 m
.84925 0 L
.85046 0 L
.85182 0 L
.85256 0 L
.85326 0 L
.85395 0 L
.85467 0 L
.85597 0 L
.85669 0 L
.85737 0 L
.85891 0 L
.86129 0 L
s
.86129 0 m
.8629 0 L
s
.9028 0 m
.90377 0 L
.90821 0 L
.91093 0 L
.91227 0 L
.91351 0 L
.91463 0 L
.91582 0 L
.91702 0 L
.91834 0 L
.91957 0 L
.9209 0 L
.92215 0 L
.9233 0 L
.92583 0 L
.9286 0 L
.92983 0 L
.93115 0 L
.93238 0 L
.93351 0 L
.93466 0 L
.93591 0 L
.93708 0 L
.93817 0 L
.9406 0 L
s
.9406 0 m
.94275 0 L
s
.97418 0 m
.97528 0 L
.97799 0 L
.97918 0 L
.98049 0 L
.98164 0 L
.98287 0 L
.98417 0 L
.98539 0 L
.98608 0 L
.98682 0 L
.98817 0 L
.98949 0 L
.99071 0 L
.99307 0 L
.99521 0 L
1 0 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[14]:=",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/B000`400?l00000o`00003oo`3ooolQ
0?ooo`00AP3oool500000340oooo0`00000`0?ooo`<00000<03oool3000002h0oooo0`0000040?oo
o`800000103oool004L0oooo00@000000?ooo`3oool00000<P3oool00`000000oooo0?ooo`0^0?oo
o`050000003oool0oooo0?ooo`000000;P3oool01@000000oooo0?ooo`3oool0000002h0oooo00<0
00000?ooo`3oool00P3oool010000000oooo0?ooo`0000030?ooo`00B03oool00`000000oooo0?oo
o`0_0?ooo`D00000;`3oool01@000000oooo0?ooo`3oool0000002h0oooo00D000000?ooo`3oool0
oooo0000000^0?ooo`030000003oool0oooo0080oooo00@000000?ooo`3oool000000`3oool004T0
oooo00<000000?ooo`3oool0;P3oool010000000oooo0?ooo`00000`0?ooo`@00000<03oool30000
02l0oooo00<000000?ooo`3oool00P3oool010000000oooo0?ooo`0000030?ooo`00AP3oool01@00
0000oooo0?ooo`3oool000000300oooo00<000000?ooo`000000<03oool00`000000oooo0?ooo`0`
0?ooo`050000003oool0oooo0?ooo`000000;P3oool00`000000oooo0?ooo`020?ooo`040000003o
ool0oooo000000<0oooo00160?ooo`050000003oool0oooo0?ooo`000000<@3oool200000340oooo
00<000000?ooo`3oool0;`3oool01@000000oooo0?ooo`3oool0000002d0oooo0P0000040?ooo`04
0000003oool0oooo000000<0oooo00170?ooo`<00000<`3oool00`000000oooo0?ooo`0`0?ooo`80
0000<03oool3000002l0oooo00<000000?ooo`3oool00`3oool2000000@0oooo003o0?ooob40oooo
003o0?ooob40oooo003o0?ooob40oooo003o0?ooob40oooo000E0?ooool000001@0000070?ooo`00
5@3oool00`000000oooo0?ooo`04000000H0oooo00<000000?ooo`3oool00P3oool:000000/0oooo
00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo00L0oooo
^@0000070?ooo`005@3oool00`000000oooo0?ooo`040?ooo`<000004P3oool>00000>40oooo000E
0?ooo`800000203oool3000001d0oooo<@00002`0?ooo`005@3oool2000000/0oooo0`00001;0?oo
ojT000001`3oool001D0oooo0P00000>0?ooo`<00000n03oool001D0oooo00<000000?ooo`000000
403oool300000?D0oooo000E0?ooo`030000003oool0000001<0oooo0`00003b0?ooo`005@3oool3
000001H0oooo0`00003_0?ooo`005@3oool010000000oooo0?ooo`00000H0?ooo`@00000j`3oool0
01D0oooo00D000000?ooo`3oool0oooo0000000K0?ooo`D00000iP3oool001D0oooo00D000000?oo
o`3oool0oooo0000000P0?ooo`D00000h@3oool001D0oooo00<000000?ooo`3oool00P3oool00`00
0000oooo0?ooo`0R0?ooo`/00000eP3oool001D0oooo00<000000?ooo`3oool00P3oool00`000000
oooo0?ooo`0]0?ooo`X00000c03oool001D0oooo00<000000?ooo`3oool00`3oool00`000000oooo
0?ooo`0f0?oooaD00000]`3oool001D0oooo00<000000?ooo`3oool0103oool00`000000oooo0?oo
o`1:0?oook0000001`3oool001D0oooo0P0000050?ooo`030000003oool0oooo0?l0oooo0P3oool0
01D0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`3o0?ooo`40oooo000E0?ooo`03
0000003oool0oooo00H0oooo00<000000?ooo`3oool0o`3oool001D0oooo00<000000?ooo`3oool0
1P3oool00`000000oooo0?ooo`3o0?ooo`005@3oool00`000000oooo0?ooo`070?ooo`030000003o
ool0oooo0?h0oooo000E0?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool0o@3oool0
01D0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`3m0?ooo`005@3oool00`000000
oooo0?ooo`090?ooo`030000003oool0oooo0?`0oooo000E0?ooo`8000002P3oool00`000000oooo
0?ooo`3l0?ooo`005@3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo0?/0oooo000E
0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool0nP3oool001D0oooo00<000000?oo
o`3oool0303oool00`000000oooo0?ooo`3i0?ooo`005@3oool00`000000oooo0?ooo`0=0?ooo`80
0000n@3oool00080oooo0P0000040?ooo`040000003oool0oooo0?ooo`D00000103oool00`000000
oooo0?ooo`0?0?ooo`030000003oool0oooo0?H0oooo00001@3oool000000?ooo`3oool0000000P0
oooo00@000000?ooo`3oool00000103oool00`000000oooo0?ooo`0@0?ooo`800000mP3oool00005
0?ooo`000000oooo0?ooo`0000002@3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo
0180oooo00<000000?ooo`3oool0l`3oool000050?ooo`000000oooo0?ooo`0000002P3oool00`00
0000oooo0?ooo`030?ooo`<000004`3oool200000?<0oooo00001@3oool000000?ooo`3oool00000
00L0oooo00D000000?ooo`3oool0oooo000000040?ooo`030000003oool0oooo01D0oooo0P00003a
0?ooo`0000D0oooo0000003oool0oooo000000070?ooo`050000003oool0oooo0?ooo`000000103o
ool00`000000oooo0?ooo`0G0?ooo`800000k`3oool00080oooo0P0000090?ooo`<000001@3oool0
0`000000oooo0?ooo`0I0?ooo`800000k@3oool001D0oooo00<000000?ooo`3oool06`3oool30000
0>X0oooo000E0?ooo`030000003oool0oooo01h0oooo0`00003W0?ooo`005@3oool00`000000oooo
0?ooo`0Q0?ooo`<00000i03oool001D0oooo00<000000?ooo`3oool0903oool200000>80oooo000E
0?ooo`8000009`3oool300000=l0oooo000E0?ooo`030000003oool0oooo02T0oooo1000003K0?oo
o`005@3oool00`000000oooo0?ooo`0]0?ooo`D00000eP3oool001D0oooo00<000000?ooo`3oool0
<P3oool800000<h0oooo000E0?ooo`030000003oool0oooo03X0oooo3@0000310?ooo`005@3oool0
0`000000oooo0?ooo`170?oooa800000[`3oool001D0oooo00<000000?ooo`3oool0F@3ooonX0000
00L0oooo000E0?ooo`030000003oool0oooo0?l0oooo2@3oool001D0oooo0P00003o0?ooo`X0oooo
000E0?ooo`030000003oool0oooo0?l0oooo2@3oool001D0oooo00<000000?ooo`3oool0o`3oool9
0?ooo`005@3oool00`000000oooo0?ooo`3o0?ooo`T0oooo000E0?ooo`030000003oool0oooo0?l0
oooo2@3oool001D0oooo00<000000?ooo`3oool0o`3oool90?ooo`005@3oool00`000000oooo0?oo
o`3o0?ooo`T0oooo000E0?ooo`030000003oool0oooo0?l0oooo2@3oool001D0oooo0P00003o0?oo
o`X0oooo000E0?ooo`030000003oool0oooo0?l0oooo2@3oool001D0oooo00<000000?ooo`3oool0
o`3oool90?ooo`005@3oool00`000000oooo0?ooo`3o0?ooo`T0oooo000E0?ooo`030000003oool0
oooo0?l0oooo2@3oool00080oooo0P0000040?ooo`030000003oool0oooo00<0oooo0`0000040?oo
o`030000003oool0oooo0?l0oooo2@3oool000050?ooo`000000oooo0?ooo`0000002P3oool00`00
0000oooo0?ooo`030?ooo`030000003oool0oooo0?l0oooo2@3oool000050?ooo`000000oooo0?oo
o`0000001`3oool5000000@0oooo00<000000?ooo`3oool0o`3oool90?ooo`0000D0oooo0000003o
ool0oooo000000070?ooo`040000003oool0oooo000000D0oooo0`00003o0?ooo`T0oooo00001@3o
ool000000?ooo`3oool0000000P0oooo00<000000?ooo`0000001@3oool00`000000oooo0?ooo`3o
0?ooo`T0oooo00001@3oool000000?ooo`3oool0000000T0oooo0P0000050?ooo`030000003oool0
oooo0?l0oooo2@3oool00080oooo0P00000;0?ooo`030000003oool0oooo00<0oooo00<000000?oo
o`3oool0o`3oool90?ooo`005@3oool00`000000oooo0?ooo`3o0?ooo`T0oooo000E0?ooo`030000
003oool0oooo0?l0oooo2@3oool001D0oooo00<000000?ooo`3oool0o`3oool90?ooo`005@3oool0
0`000000oooo0?ooo`3o0?ooo`T0oooo000E0?ooo`800000o`3oool:0?ooo`005@3oool00`000000
oooo0?ooo`3o0?ooo`T0oooo000E0?ooo`030000003oool0oooo0?l0oooo2@3oool001D0oooo00<0
00000?ooo`3oool0o`3oool90?ooo`005@3oool00`000000oooo0?ooo`3o0?ooo`T0oooo000E0?oo
o`030000003oool0oooo0?l0oooo2@3oool001D0oooo00<000000?ooo`3oool0o`3oool90?ooo`00
5@3oool00`000000oooo0?ooo`3o0?ooo`T0oooo000E0?ooo`800000o`3oool:0?ooo`005@3oool0
0`000000oooo0?ooo`3o0?ooo`T0oooo000E0?ooo`030000003oool0oooo0?l0oooo2@3oool001D0
oooo00<000000?ooo`3oool0o`3oool90?ooo`005@3oool00`000000oooo0?ooo`3o0?ooo`T0oooo
000E0?ooo`030000003oool0oooo0?l0oooo2@3oool001D0oooo00<000000?ooo`3oool0o`3oool9
0?ooo`005@3oool00`000000oooo0?ooo`3o0?ooo`T0oooo000E0?ooo`800000o`3oool:0?ooo`00
5@3oool00`000000oooo0?ooo`3o0?ooo`T0oooo000E0?ooo`030000003oool0oooo0?l0oooo2@3o
ool001D0oooo00<000000?ooo`3oool0o`3oool90?ooo`005@3oool00`000000oooo0?ooo`3o0?oo
o`T0oooo00020?ooo`800000103oool00`000000oooo0?ooo`020?ooo`<000001@3oool00`000000
oooo0?ooo`1i0?ooohP000001`3oool000050?ooo`000000oooo0?ooo`0000001`3oool01@000000
oooo0?ooo`3oool0000000@0oooo00<000000?ooo`3oool0G@3ooolL000008l0oooo00001@3oool0
00000?ooo`3oool0000000L0oooo00D000000?ooo`3oool0oooo000000040?ooo`030000003oool0
oooo04d0oooo4000002[0?ooo`0000D0oooo0000003oool0oooo000000070?ooo`@000001@3oool3
000004L0oooo1P00002k0?ooo`0000D0oooo0000003oool0oooo000000070?ooo`030000003oool0
oooo00H0oooo00<000000?ooo`3oool0@P3oool500000<40oooo00001@3oool000000?ooo`3oool0
000000P0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`0m0?ooo`D00000aP3oool0
0080oooo0P00000:0?ooo`8000001@3oool00`000000oooo0?ooo`0g0?ooo`H00000b`3oool001D0
oooo00<000000?ooo`3oool0<`3oool400000=40oooo000E0?ooo`030000003oool0oooo0300oooo
0`00003E0?ooo`005@3oool00`000000oooo0?ooo`0]0?ooo`<00000f03oool001D0oooo00<00000
0?ooo`3oool0:P3oool300000=/0oooo000E0?ooo`800000:@3oool200000=h0oooo000E0?ooo`03
0000003oool0oooo02H0oooo0P00003P0?ooo`005@3oool00`000000oooo0?ooo`0T0?ooo`800000
hP3oool001D0oooo00<000000?ooo`3oool08P3oool200000>@0oooo000E0?ooo`030000003oool0
oooo0200oooo0P00003V0?ooo`005@3oool00`000000oooo0?ooo`0O0?ooo`030000003oool0oooo
0>H0oooo000E0?ooo`030000003oool0oooo01d0oooo0P00003Y0?ooo`005@3oool00`000000oooo
0?ooo`0L0?ooo`030000003oool0oooo0>T0oooo000E0?ooo`8000006`3oool200000>`0oooo000E
0?ooo`030000003oool0oooo01T0oooo00<000000?ooo`3oool0k03oool001D0oooo00<000000?oo
o`3oool0603oool00`000000oooo0?ooo`3]0?ooo`005@3oool00`000000oooo0?ooo`0G0?ooo`03
0000003oool0oooo0>h0oooo000E0?ooo`030000003oool0oooo01H0oooo00<000000?ooo`3oool0
k`3oool001D0oooo00<000000?ooo`3oool05@3oool00`000000oooo0?ooo`3`0?ooo`005@3oool0
0`000000oooo0?ooo`0D0?ooo`030000003oool0oooo0?40oooo000E0?ooo`030000003oool0oooo
01<0oooo00<000000?ooo`3oool0lP3oool001D0oooo0P00000D0?ooo`030000003oool0oooo0?80
oooo000E0?ooo`030000003oool0oooo0180oooo00<000000?ooo`3oool0l`3oool001D0oooo00<0
00000?ooo`3oool04@3oool00`000000oooo0?ooo`3d0?ooo`005@3oool00`000000oooo0?ooo`0@
0?ooo`030000003oool0oooo0?D0oooo000E0?ooo`030000003oool0oooo0100oooo00<000000?oo
o`3oool0m@3oool00080oooo0P0000040?ooo`030000003oool0oooo0080oooo0`0000050?ooo`03
0000003oool0oooo00l0oooo00<000000?ooo`3oool0mP3oool000050?ooo`000000oooo0?ooo`00
00001`3oool01@000000oooo0?ooo`3oool0000000@0oooo00<000000?ooo`3oool03P3oool00`00
0000oooo0?ooo`3g0?ooo`0000D0oooo0000003oool0oooo000000070?ooo`050000003oool0oooo
0?ooo`000000103oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo0?P0oooo00001@3o
ool000000?ooo`3oool0000000P0oooo0`0000050?ooo`<000003@3oool00`000000oooo0?ooo`3h
0?ooo`0000D0oooo0000003oool0oooo000000070?ooo`050000003oool0oooo0?ooo`000000103o
ool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo0?T0oooo00001@3oool000000?ooo`3o
ool0000000L0oooo00D000000?ooo`3oool0oooo000000040?ooo`030000003oool0oooo00/0oooo
00<000000?ooo`3oool0nP3oool00080oooo0P0000090?ooo`<000001@3oool00`000000oooo0?oo
o`0;0?ooo`030000003oool0oooo0?X0oooo000E0?ooo`030000003oool0oooo00X0oooo00<00000
0?ooo`3oool0n`3oool001D0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`3k0?oo
o`005@3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo0?`0oooo000E0?ooo`030000
003oool0oooo00P0oooo00<000000?ooo`3oool0o@3oool001D0oooo0P0000090?ooo`030000003o
ool0oooo0?d0oooo000E0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool0oP3oool0
01D0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`3n0?ooo`005@3oool00`000000
oooo0?ooo`060?ooo`030000003oool0oooo0?l0oooo000E0?ooo`030000003oool0oooo00H0oooo
00<000000?ooo`3oool0o`3oool001D0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?oo
o`3o0?ooo`40oooo000E0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0o`3oool2
0?ooo`005@3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo0?l0oooo0P3oool001D0
oooo0P0000040?ooo`030000003oool0oooo0?l0oooo0`3oool001D0oooo00<000000?ooo`3oool0
0`3oool00`000000oooo0?ooo`3o0?ooo`<0oooo000E0?ooo`030000003oool0oooo0080oooo00<0
00000?ooo`3oool0o`3oool40?ooo`005@3oool00`000000oooo0?ooo`020?ooo`030000003oool0
oooo0?l0oooo103oool001D0oooo00D000000?ooo`3oool0oooo0000003o0?ooo`L0oooo000E0?oo
o`050000003oool0oooo0?ooo`000000o`3oool70?ooo`005@3oool01@000000oooo0?ooo`3oool0
00000?l0oooo1`3oool001D0oooo00@000000?ooo`3oool00000o`3oool80?ooo`005@3oool20000
00030?ooo`000000oooo0?l0oooo1`3oool001D0oooo00@000000?ooo`3oool00000o`3oool80?oo
o`005@3oool00`000000oooo0000003o0?ooo`T0oooo000E0?ooo`030000003oool000000?l0oooo
2@3oool001D0oooo00<000000?ooo`000000o`3oool90?ooo`003@3oool3000000D0oooo0P00003o
0?ooo`X0oooo000>0?ooo`030000003oool0oooo00@0oooo0P00003o0?ooo`X0oooo000>0?ooo`03
0000003oool0oooo00@0oooo0P00003o0?ooo`X0oooo000>0?ooo`030000003oool0oooo00@0oooo
0`00003o0?ooo`T0oooo000>0?ooo`030000003oool0oooo0?l0oooo403oool000d0oooo0P00003o
0?oooa80oooo000>0?ooo`030000003oool0oooo0?l0oooo403oool00?l0oooo8@3oool00001\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.830159, -0.0764114, \
0.0385797, 0.00624232}}],

Cell[BoxData[
    \({0.5819906775276001`, 0.29098102382845764`, 0.09699140340259005`, 
      0.024247520892720257`, 0.004849461154747642`, 0.0008082384871706997`, 
      0.00011546210789068051`, 0.000014432712162477048`, 
      1.6036301589146098`*^-6, 1.6036264797632756`*^-7, 
      1.4578394848996553`*^-8, 1.2148643865091175`*^-9, 
      9.345064442329264`*^-11, 6.675633351046066`*^-12, 
      4.443169780280864`*^-13, 2.841769493462252`*^-14, 
      1.2366072807090048`*^-15, 
      2.8667227405707946`*^-16, \(-6.254959090238213`*^-17\), 
      1.3491538338694024`*^-17}\)], "Output",
  CellLabel->"Out[18]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
    \(tm = 10; R = 1; km = 20;\), "\[IndentingNewLine]", 
    \(\(ss = soln[P, R, km, tm];\)\), "\[IndentingNewLine]", 
    \(\(vv = Array[\(P[#]\)[t] &, {km}];\)\), "\[IndentingNewLine]", 
    \(\(Plot[vv /. ss // Evaluate, {t, 0, tm}, 
        PlotRange \[Rule] {{0, tm}, {0, 1}}];\)\), "\[IndentingNewLine]", 
    \(\(vv /. t \[Rule] tm\) /. ss\)}], "Input",
  CellLabel->"In[19]:="],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-2.77556e-17 0.1 0 0.618034 [
[.2 -0.0125 -3 -9 ]
[.2 -0.0125 3 0 ]
[.4 -0.0125 -3 -9 ]
[.4 -0.0125 3 0 ]
[.6 -0.0125 -3 -9 ]
[.6 -0.0125 3 0 ]
[.8 -0.0125 -3 -9 ]
[.8 -0.0125 3 0 ]
[1 -0.0125 -6 -9 ]
[1 -0.0125 6 0 ]
[-0.0125 .12361 -18 -4.5 ]
[-0.0125 .12361 0 4.5 ]
[-0.0125 .24721 -18 -4.5 ]
[-0.0125 .24721 0 4.5 ]
[-0.0125 .37082 -18 -4.5 ]
[-0.0125 .37082 0 4.5 ]
[-0.0125 .49443 -18 -4.5 ]
[-0.0125 .49443 0 4.5 ]
[-0.0125 .61803 -6 -4.5 ]
[-0.0125 .61803 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 0 m
.2 .00625 L
s
[(2)] .2 -0.0125 0 1 Mshowa
.4 0 m
.4 .00625 L
s
[(4)] .4 -0.0125 0 1 Mshowa
.6 0 m
.6 .00625 L
s
[(6)] .6 -0.0125 0 1 Mshowa
.8 0 m
.8 .00625 L
s
[(8)] .8 -0.0125 0 1 Mshowa
1 0 m
1 .00625 L
s
[(10)] 1 -0.0125 0 1 Mshowa
.125 Mabswid
.05 0 m
.05 .00375 L
s
.1 0 m
.1 .00375 L
s
.15 0 m
.15 .00375 L
s
.25 0 m
.25 .00375 L
s
.3 0 m
.3 .00375 L
s
.35 0 m
.35 .00375 L
s
.45 0 m
.45 .00375 L
s
.5 0 m
.5 .00375 L
s
.55 0 m
.55 .00375 L
s
.65 0 m
.65 .00375 L
s
.7 0 m
.7 .00375 L
s
.75 0 m
.75 .00375 L
s
.85 0 m
.85 .00375 L
s
.9 0 m
.9 .00375 L
s
.95 0 m
.95 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .12361 m
.00625 .12361 L
s
[(0.2)] -0.0125 .12361 1 0 Mshowa
0 .24721 m
.00625 .24721 L
s
[(0.4)] -0.0125 .24721 1 0 Mshowa
0 .37082 m
.00625 .37082 L
s
[(0.6)] -0.0125 .37082 1 0 Mshowa
0 .49443 m
.00625 .49443 L
s
[(0.8)] -0.0125 .49443 1 0 Mshowa
0 .61803 m
.00625 .61803 L
s
[(1)] -0.0125 .61803 1 0 Mshowa
.125 Mabswid
0 .0309 m
.00375 .0309 L
s
0 .0618 m
.00375 .0618 L
s
0 .09271 m
.00375 .09271 L
s
0 .15451 m
.00375 .15451 L
s
0 .18541 m
.00375 .18541 L
s
0 .21631 m
.00375 .21631 L
s
0 .27812 m
.00375 .27812 L
s
0 .30902 m
.00375 .30902 L
s
0 .33992 m
.00375 .33992 L
s
0 .40172 m
.00375 .40172 L
s
0 .43262 m
.00375 .43262 L
s
0 .46353 m
.00375 .46353 L
s
0 .52533 m
.00375 .52533 L
s
0 .55623 m
.00375 .55623 L
s
0 .58713 m
.00375 .58713 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
0 .61803 m
.01975 .51616 L
.04057 .44015 L
.06168 .38394 L
.08481 .33841 L
.10536 .30784 L
.12734 .28259 L
.14971 .2628 L
.17086 .24824 L
.2112 .2285 L
.23202 .2213 L
.25411 .21529 L
.29383 .20755 L
.31421 .20472 L
.33613 .20231 L
.35833 .20039 L
.37942 .19896 L
.41952 .197 L
.44018 .19628 L
.4622 .19568 L
.48468 .19519 L
.50586 .19483 L
.54634 .19434 L
.56728 .19416 L
.58939 .19401 L
.62926 .19382 L
.64975 .19375 L
.67171 .19369 L
.69401 .19364 L
.71514 .1936 L
.75538 .19355 L
.77615 .19354 L
.79821 .19352 L
.83784 .1935 L
.85816 .1935 L
.88006 .19349 L
.9011 .19348 L
.92325 .19348 L
.94398 .19348 L
.96327 .19348 L
1 .19347 L
s
0 0 m
.00488 .02743 L
.00942 .04877 L
.01975 .08594 L
.02981 .11149 L
.04057 .13107 L
.05248 .14647 L
.06373 .15691 L
.07384 .16391 L
.08481 .1697 L
.09472 .17374 L
.10564 .17722 L
.11704 .18005 L
.12772 .18214 L
.13862 .18387 L
.14898 .18521 L
.16843 .18714 L
.18922 .18863 L
.20853 .18966 L
.23008 .19052 L
.24962 .19112 L
.26983 .1916 L
.29169 .19201 L
.31262 .19231 L
.33474 .19257 L
.37461 .19289 L
.3951 .193 L
.41706 .1931 L
.43936 .19318 L
.46049 .19324 L
.50073 .19332 L
.5215 .19335 L
.54355 .19338 L
.58319 .19341 L
.60351 .19342 L
.6254 .19343 L
.64603 .19344 L
.6686 .19344 L
.71021 .19345 L
.7308 .19345 L
.7528 .19346 L
.77521 .19346 L
.79637 .19346 L
.83676 .19346 L
.85763 .19346 L
.87972 .19346 L
.9195 .19346 L
.93992 .19347 L
.96186 .19347 L
1 .19347 L
Mistroke
Mfstroke
0 0 m
.04057 .03551 L
.06168 .05514 L
.08481 .07217 L
.10632 .08442 L
.12636 .0934 L
.14599 .1004 L
.1673 .10642 L
.18967 .11137 L
.21082 .11504 L
.23124 .11785 L
.25373 .12029 L
.29505 .12347 L
.31543 .12457 L
.33735 .12552 L
.35954 .12627 L
.38064 .12683 L
.42074 .12759 L
.44139 .12788 L
.46342 .12811 L
.4859 .1283 L
.50708 .12844 L
.54756 .12863 L
.56849 .12871 L
.59061 .12876 L
.63048 .12884 L
.65096 .12887 L
.67292 .12889 L
.69523 .12891 L
.71635 .12892 L
.7566 .12894 L
.77736 .12895 L
.79942 .12896 L
.83906 .12896 L
.85937 .12897 L
.88127 .12897 L
.90232 .12897 L
.92447 .12897 L
.9452 .12897 L
.96448 .12897 L
1 .12898 L
s
0 0 m
.00123 0 L
.00236 1e-05 L
.00365 3e-05 L
.00488 6e-05 L
.00601 .0001 L
.00706 .00016 L
.00821 .00023 L
.00942 .00033 L
.01196 .00061 L
.01434 .00096 L
.01975 .00203 L
.02499 .0034 L
.02978 .00489 L
.04057 .00879 L
.08481 .02633 L
.10643 .03368 L
.1265 .03943 L
.16661 .04812 L
.18815 .05151 L
.20769 .054 L
.2296 .05623 L
.24976 .05786 L
.29024 .06024 L
.31001 .06107 L
.3317 .06179 L
.3539 .06238 L
.37415 .0628 L
.415 .06341 L
.43504 .06362 L
.45684 .06381 L
.47719 .06394 L
.49966 .06406 L
.54089 .06422 L
.5612 .06427 L
.5831 .06432 L
.60373 .06435 L
.6263 .06438 L
.6679 .06442 L
.6885 .06444 L
.71049 .06445 L
.73291 .06446 L
.75407 .06446 L
.79446 .06447 L
.81533 .06448 L
.83742 .06448 L
.85821 .06448 L
.8772 .06448 L
.89762 .06448 L
.91956 .06448 L
Mistroke
.93953 .06449 L
.96131 .06449 L
1 .06449 L
Mfstroke
0 0 m
.00123 0 L
.00236 0 L
.00365 0 L
.00488 0 L
.00601 1e-05 L
.00706 1e-05 L
.00821 2e-05 L
.00942 3e-05 L
.01065 4e-05 L
.01196 6e-05 L
.01434 .00011 L
.01579 .00015 L
.01716 .00019 L
.01975 .00029 L
.02491 .00057 L
.0297 .00092 L
.04057 .00199 L
.06198 .00489 L
.08481 .00835 L
.12847 .01424 L
.15038 .01656 L
.17054 .01832 L
.21102 .02095 L
.23078 .02189 L
.25248 .02271 L
.27468 .02337 L
.29493 .02386 L
.33578 .02456 L
.35582 .0248 L
.37762 .02501 L
.39797 .02517 L
.42044 .02531 L
.46167 .02549 L
.48198 .02555 L
.50388 .0256 L
.52451 .02564 L
.54708 .02567 L
.58868 .02572 L
.60927 .02573 L
.63127 .02575 L
.65369 .02576 L
.67485 .02577 L
.71523 .02578 L
.7361 .02578 L
.7582 .02578 L
.79798 .02579 L
.8184 .02579 L
.84034 .02579 L
.86257 .02579 L
Mistroke
.88368 .02579 L
.90475 .02579 L
.92384 .02579 L
.94453 .02579 L
.96657 .02579 L
1 .02579 L
Mfstroke
0 0 m
.00123 0 L
.00236 0 L
.00365 0 L
.00488 0 L
.00601 0 L
.00706 0 L
.00821 0 L
.00942 0 L
.01065 0 L
.01196 1e-05 L
.0132 1e-05 L
.01434 1e-05 L
.01566 2e-05 L
.01711 2e-05 L
.01975 4e-05 L
.02249 6e-05 L
.02497 9e-05 L
.03054 .00018 L
.03571 .00029 L
.04057 .00042 L
.05164 .00079 L
.06182 .00122 L
.08481 .00233 L
.12627 .00427 L
.16614 .00571 L
.18663 .00627 L
.20859 .00675 L
.22939 .00713 L
.25202 .00745 L
.29385 .00787 L
.31462 .00802 L
.33667 .00814 L
.37631 .0083 L
.39663 .00836 L
.41853 .00841 L
.43916 .00845 L
.46172 .00848 L
.50333 .00853 L
.52392 .00854 L
.54592 .00855 L
.56833 .00856 L
.58949 .00857 L
.62988 .00858 L
.65075 .00858 L
.67284 .00859 L
.71263 .00859 L
.73305 .00859 L
.75498 .00859 L
.77572 .00859 L
Mistroke
.79832 .0086 L
.82023 .0086 L
.84007 .0086 L
.86077 .0086 L
.8828 .0086 L
.90305 .0086 L
.92493 .0086 L
.94591 .0086 L
.96804 .0086 L
1 .0086 L
Mfstroke
0 0 m
.00123 0 L
.00236 0 L
.00365 0 L
.00488 0 L
.00601 0 L
.00706 0 L
.00821 0 L
.00942 0 L
.01065 0 L
.01196 0 L
.0132 0 L
.01434 0 L
.01566 0 L
.01711 0 L
.01848 0 L
.01975 1e-05 L
.02247 1e-05 L
.02503 1e-05 L
.02733 2e-05 L
.02982 3e-05 L
.03542 5e-05 L
.04057 8e-05 L
.05082 .00016 L
.06208 .00028 L
.08481 .00058 L
.12725 .00115 L
.16811 .00159 L
.19041 .00177 L
.21154 .00191 L
.25178 .0021 L
.27255 .00217 L
.2946 .00223 L
.33424 .00231 L
.35456 .00234 L
.37646 .00237 L
.39709 .00238 L
.41965 .0024 L
.46126 .00242 L
.48185 .00243 L
.50385 .00243 L
.52626 .00244 L
.54742 .00244 L
.58781 .00245 L
.60868 .00245 L
.63077 .00245 L
.67056 .00245 L
.69098 .00245 L
.71291 .00245 L
.73515 .00245 L
Mistroke
.75625 .00246 L
.79641 .00246 L
.81711 .00246 L
.83914 .00246 L
.86167 .00246 L
.88286 .00246 L
.9022 .00246 L
.92339 .00246 L
.94437 .00246 L
.9665 .00246 L
1 .00246 L
Mfstroke
0 0 m
.00123 0 L
.00236 0 L
.00365 0 L
.00488 0 L
.00601 0 L
.00706 0 L
.00821 0 L
.00942 0 L
.01065 0 L
.01196 0 L
.0132 0 L
.01434 0 L
.01566 0 L
.01641 0 L
.01711 0 L
.01839 0 L
.01975 0 L
.02115 0 L
.02245 0 L
.02384 0 L
.02537 0 L
.02795 0 L
.03067 0 L
.03579 1e-05 L
.04057 1e-05 L
.0463 2e-05 L
.05174 3e-05 L
.06192 6e-05 L
.08481 .00013 L
.12505 .00027 L
.14541 .00033 L
.16788 .00039 L
.20911 .00047 L
.22942 .0005 L
.25132 .00052 L
.27195 .00054 L
.29452 .00056 L
.33612 .00058 L
.35671 .00058 L
.37871 .00059 L
.40112 .0006 L
.42228 .0006 L
.46267 .0006 L
.48354 .00061 L
.50564 .00061 L
.54542 .00061 L
.56584 .00061 L
.58778 .00061 L
.60851 .00061 L
Mistroke
.63112 .00061 L
.67286 .00061 L
.69356 .00061 L
.7156 .00061 L
.73661 .00061 L
.75931 .00061 L
.77941 .00061 L
.80144 .00061 L
.82241 .00061 L
.84455 .00061 L
.86507 .00061 L
.88705 .00061 L
.90939 .00061 L
.93053 .00061 L
.95008 .00061 L
.97083 .00061 L
1 .00061 L
Mfstroke
0 0 m
.00123 0 L
.00236 0 L
.00365 0 L
.00488 0 L
.00601 0 L
.00706 0 L
.00821 0 L
.00942 0 L
.01065 0 L
.01196 0 L
.0132 0 L
.01434 0 L
.01566 0 L
.01641 0 L
.01711 0 L
.01839 0 L
.01975 0 L
.02115 0 L
.02245 0 L
.02387 0 L
.02537 0 L
.0279 0 L
.03067 0 L
.03314 0 L
.03579 0 L
.04057 0 L
.04626 0 L
.05245 1e-05 L
.06371 1e-05 L
.08481 3e-05 L
.12763 6e-05 L
.16886 8e-05 L
.2085 .0001 L
.22881 .00011 L
.25071 .00011 L
.27134 .00012 L
.29391 .00012 L
.33551 .00013 L
.3561 .00013 L
.3781 .00013 L
.40052 .00013 L
.42168 .00013 L
.46206 .00013 L
.48293 .00013 L
.50503 .00014 L
.52582 .00014 L
.5349 .00014 L
.5397 .00014 L
.54233 .00014 L
Mistroke
.54481 .00014 L
.54766 .00014 L
.55025 .00014 L
.55529 .00014 L
.56013 .00014 L
.56256 .00014 L
.56523 .00014 L
.5666 .00014 L
.56807 .00014 L
.57073 .00014 L
.57578 .00014 L
.58717 .00014 L
.59788 .00014 L
.60951 .00014 L
.63065 .00014 L
.65105 .00014 L
.67353 .00014 L
.69483 .00014 L
.71481 .00014 L
.73605 .00014 L
.75549 .00014 L
.7754 .00014 L
.79715 .00014 L
.81778 .00014 L
.83979 .00014 L
.86074 .00014 L
.88342 .00014 L
.90345 .00014 L
.91483 .00014 L
.92546 .00014 L
.94637 .00014 L
.96848 .00014 L
1 .00014 L
Mfstroke
0 0 m
.00123 0 L
.00236 0 L
.00365 0 L
.00488 0 L
.00601 0 L
.00706 0 L
.00821 0 L
.00942 0 L
.01065 0 L
.01196 0 L
.0132 0 L
.01434 0 L
.01566 0 L
.01641 0 L
.01711 0 L
.01839 0 L
.01975 0 L
.02115 0 L
.02245 0 L
.02387 0 L
.02537 0 L
.02659 0 L
.0279 0 L
.02865 0 L
.02933 0 L
.03067 0 L
.0331 0 L
.03575 0 L
.04057 0 L
.04586 0 L
.05171 0 L
.06355 0 L
.08481 0 L
.12702 1e-05 L
.16764 2e-05 L
.18827 2e-05 L
.21084 2e-05 L
.25245 2e-05 L
.27304 2e-05 L
.29504 2e-05 L
.31594 3e-05 L
.33861 3e-05 L
.3586 3e-05 L
.38059 3e-05 L
.40146 3e-05 L
.42355 3e-05 L
.44569 3e-05 L
.46591 3e-05 L
.50668 3e-05 L
Mistroke
.51166 3e-05 L
.5141 3e-05 L
.51518 3e-05 L
.51635 3e-05 L
.51761 3e-05 L
.51895 3e-05 L
.51965 3e-05 L
.5204 3e-05 L
.52176 3e-05 L
.52665 3e-05 L
.52811 3e-05 L
.52969 3e-05 L
.53118 3e-05 L
.53256 3e-05 L
.53518 3e-05 L
.53795 3e-05 L
.53919 3e-05 L
.54052 3e-05 L
.54178 3e-05 L
.54293 3e-05 L
.54421 3e-05 L
.54494 3e-05 L
.54561 3e-05 L
.54842 3e-05 L
.5595 3e-05 L
.56215 3e-05 L
.56359 3e-05 L
.56494 3e-05 L
.56609 3e-05 L
.56733 3e-05 L
.5687 3e-05 L
.56995 3e-05 L
.57114 3e-05 L
.57225 3e-05 L
.57344 3e-05 L
.57476 3e-05 L
.5759 3e-05 L
.57697 3e-05 L
.5781 3e-05 L
.57932 3e-05 L
.58056 3e-05 L
.5819 3e-05 L
.58258 3e-05 L
.58331 3e-05 L
.58462 3e-05 L
.58593 3e-05 L
.58716 3e-05 L
.58948 3e-05 L
.59068 3e-05 L
.59198 3e-05 L
Mistroke
.59321 3e-05 L
.59433 3e-05 L
.59564 3e-05 L
.59707 3e-05 L
.59967 3e-05 L
.60109 3e-05 L
.60238 3e-05 L
.60309 3e-05 L
.60387 3e-05 L
.60527 3e-05 L
.61047 3e-05 L
.62983 3e-05 L
.63493 3e-05 L
.63975 3e-05 L
.64104 3e-05 L
.64241 3e-05 L
.64313 3e-05 L
.64392 3e-05 L
.64463 3e-05 L
.64531 3e-05 L
.64658 3e-05 L
.64775 3e-05 L
.64902 3e-05 L
.65037 3e-05 L
.65111 3e-05 L
.65178 3e-05 L
.65309 3e-05 L
.65382 3e-05 L
.65461 3e-05 L
.65605 3e-05 L
.65756 3e-05 L
.65916 3e-05 L
.66053 3e-05 L
.6613 3e-05 L
.66203 3e-05 L
.6627 3e-05 L
.66344 3e-05 L
.66477 3e-05 L
.66609 3e-05 L
.66727 3e-05 L
.668 3e-05 L
.66869 3e-05 L
.66942 3e-05 L
.6702 3e-05 L
.67089 3e-05 L
.67161 3e-05 L
.67291 3e-05 L
.67782 3e-05 L
.68024 3e-05 L
.68247 3e-05 L
Mistroke
.68372 3e-05 L
.68504 3e-05 L
.68636 3e-05 L
.68712 3e-05 L
.68783 3e-05 L
.68905 3e-05 L
.69017 3e-05 L
.69147 3e-05 L
.6927 3e-05 L
.69405 3e-05 L
.69548 3e-05 L
.69807 3e-05 L
.69952 3e-05 L
.70108 3e-05 L
.7018 3e-05 L
.70257 3e-05 L
.70393 3e-05 L
.70528 3e-05 L
.70654 3e-05 L
.70793 3e-05 L
.70941 3e-05 L
.71439 3e-05 L
.71708 3e-05 L
.71844 3e-05 L
.71993 3e-05 L
.72507 3e-05 L
.73065 3e-05 L
.73359 3e-05 L
.73668 3e-05 L
.73799 3e-05 L
.73939 3e-05 L
.7402 3e-05 L
.74093 3e-05 L
.74167 3e-05 L
.74236 3e-05 L
.74366 3e-05 L
.74486 3e-05 L
.74618 3e-05 L
.74691 3e-05 L
.74758 3e-05 L
.74879 3e-05 L
.75009 3e-05 L
.7513 3e-05 L
.75245 3e-05 L
.75501 3e-05 L
.75781 3e-05 L
.80053 3e-05 L
.82029 3e-05 L
.83068 3e-05 L
.83636 3e-05 L
Mistroke
.83913 3e-05 L
.84165 3e-05 L
.84436 3e-05 L
.84725 3e-05 L
.85339 3e-05 L
.86417 3e-05 L
.88536 3e-05 L
.89509 3e-05 L
.90543 3e-05 L
.91676 3e-05 L
.92724 3e-05 L
.93655 3e-05 L
.94634 3e-05 L
.95147 3e-05 L
.95708 3e-05 L
.96692 3e-05 L
1 3e-05 L
Mfstroke
0 0 m
.00123 0 L
.00236 0 L
.00365 0 L
.00488 0 L
.00601 0 L
.00706 0 L
.00821 0 L
.00942 0 L
.01065 0 L
.01196 0 L
.0132 0 L
.01434 0 L
.01566 0 L
.01641 0 L
.01711 0 L
.01839 0 L
.01975 0 L
.02115 0 L
.02245 0 L
.02313 0 L
.02387 0 L
.02465 0 L
.02537 0 L
.02669 0 L
.02742 0 L
.02811 0 L
.03067 0 L
.03177 0 L
.03293 0 L
.03421 0 L
.03537 0 L
.03665 0 L
.03738 0 L
.03805 0 L
.03927 0 L
.04057 0 L
.0459 0 L
.05157 0 L
.05691 0 L
.06176 0 L
.08481 0 L
.12679 0 L
.16718 0 L
.18764 0 L
.21014 0 L
.25152 0 L
.27194 0 L
.29387 0 L
.31611 0 L
Mistroke
.33721 0 L
.37737 0 L
.39807 0 L
.4201 0 L
.43093 0 L
.44263 0 L
.448 0 L
.44931 0 L
.45071 0 L
.45151 0 L
.45224 0 L
.45298 0 L
.45367 0 L
.4549 0 L
.4562 0 L
.45731 0 L
.45854 0 L
.45985 0 L
.46054 0 L
.46126 0 L
.4626 0 L
.46382 0 L
.46503 0 L
.4663 0 L
.4677 0 L
.46899 0 L
.47019 0 L
.47132 0 L
.47255 0 L
.47387 0 L
.47459 0 L
.47538 0 L
.47681 0 L
.47949 0 L
.48459 0 L
.48945 0 L
.49063 0 L
.4919 0 L
.49263 0 L
.4933 0 L
.49461 0 L
.49573 0 L
.49677 0 L
.49791 0 L
.49913 0 L
.50389 0 L
.5066 0 L
.50947 0 L
.51196 0 L
.51333 0 L
Mistroke
.51463 0 L
.51534 0 L
.51612 0 L
.51749 0 L
.51816 0 L
.51888 0 L
.52017 0 L
.52096 0 L
.52182 0 L
.52337 0 L
.52628 0 L
.53164 0 L
.53433 0 L
.5373 0 L
.53983 1e-05 L
.54055 1e-05 L
.54124 1e-05 L
.54254 1e-05 L
.54375 1e-05 L
.54488 1e-05 L
.54612 1e-05 L
.54743 1e-05 L
.54863 1e-05 L
.54991 0 L
.55223 0 L
.55349 0 L
.55464 0 L
.55728 0 L
.55864 0 L
.56013 0 L
.56281 0 L
.5641 0 L
.56545 0 L
.56661 0 L
.56789 0 L
.56917 0 L
.57039 0 L
.57148 0 L
.57267 0 L
.57396 0 L
.57534 0 L
.57664 0 L
.57781 0 L
.58709 0 L
.58837 0 L
.58975 0 L
.59105 0 L
.59223 0 L
.59356 0 L
.59482 0 L
Mistroke
.59617 0 L
.59765 0 L
.59891 0 L
.6001 0 L
.60133 0 L
.60269 0 L
.60387 0 L
.60494 0 L
.60617 0 L
.60735 0 L
.6128 0 L
.6141 0 L
.61548 0 L
.61665 0 L
.61794 0 L
.61941 0 L
.62078 0 L
.62239 0 L
.62386 0 L
.62519 0 L
.62645 0 L
.62778 0 L
.62854 0 L
.62923 0 L
.63045 0 L
.63173 0 L
.63314 0 L
.63443 0 L
.63676 0 L
.63931 0 L
.64058 0 L
.64195 0 L
.64323 0 L
.6444 0 L
.64579 0 L
.64657 0 L
.64729 0 L
.6486 0 L
.65002 0 L
.65122 0 L
.65232 0 L
.65343 0 L
.65448 0 L
.65703 0 L
.65939 0 L
.66169 0 L
.66414 0 L
.66661 0 L
.66792 0 L
.66864 0 L
Mistroke
.66932 0 L
.67007 0 L
.67074 0 L
.67207 0 L
.67345 0 L
.67424 0 L
.67496 0 L
.67763 0 L
.68014 0 L
.68144 0 L
.68217 0 L
.68284 0 L
.68353 0 L
.68429 0 L
.68508 0 L
.68582 0 L
.6866 0 L
.68734 0 L
.68873 0 L
.69022 0 L
.69184 0 L
.69439 0 L
.6972 0 L
.69993 0 L
.70144 0 L
.70218 0 L
.70287 0 L
.70418 0 L
.70487 0 L
.70561 0 L
.7068 0 L
.70812 0 L
.70933 0 L
.71065 0 L
.71303 0 L
.71553 0 L
.71626 0 L
.71694 0 L
.71822 0 L
.71942 0 L
.72054 0 L
.72176 0 L
.72305 0 L
.72435 0 L
.72575 0 L
.72707 0 L
.72828 0 L
.73123 0 L
.73403 0 L
.7354 0 L
Mistroke
.73669 0 L
.7374 0 L
.73818 0 L
.73952 0 L
.74082 0 L
.74218 0 L
.74334 0 L
.74462 0 L
.74751 0 L
.74909 0 L
.7506 0 L
.75199 0 L
.75278 0 L
.75352 0 L
.75481 0 L
.75618 0 L
.75737 0 L
.75868 0 L
.76131 0 L
.76602 0 L
.76868 0 L
.77014 0 L
.77151 0 L
.7728 0 L
.77352 0 L
.77419 0 L
.77537 0 L
.77663 0 L
.77782 0 L
.7789 0 L
.78016 0 L
.78135 0 L
.78245 0 L
.78346 0 L
.78458 0 L
.78577 0 L
.78707 0 L
.78849 0 L
.79104 0 L
.79582 0 L
.80066 0 L
.80332 0 L
.80462 0 L
.80583 0 L
.80652 0 L
.80726 0 L
.80799 0 L
.8088 0 L
.80948 0 L
.8102 0 L
Mistroke
.81151 0 L
.81293 0 L
.81427 0 L
.8168 0 L
.81752 0 L
.8182 0 L
.81946 0 L
.82082 0 L
.82158 0 L
.82229 0 L
.82347 0 L
.82476 0 L
.82612 0 L
.82738 0 L
.8281 0 L
.82888 0 L
.8303 0 L
.83168 0 L
.83296 0 L
.83608 0 L
.83744 0 L
.83822 0 L
.83894 0 L
.84008 0 L
.8413 0 L
.84261 0 L
.84379 0 L
.84509 0 L
.84649 0 L
.84903 0 L
.85143 0 L
.85264 0 L
.85397 0 L
.8551 0 L
.85632 0 L
.85852 0 L
.88014 0 L
.88135 0 L
.88262 0 L
.88329 0 L
.88402 0 L
.88531 0 L
.88652 0 L
.88782 0 L
.88895 0 L
.89017 0 L
.89096 0 L
.89168 0 L
.89237 0 L
.89311 0 L
Mistroke
.89438 0 L
.8951 0 L
.89578 0 L
.89705 0 L
.89822 0 L
.90086 0 L
.90359 0 L
.90657 0 L
.91258 0 L
.91822 0 L
.92346 0 L
.92473 0 L
.92607 0 L
.92677 0 L
.92754 0 L
.9289 0 L
.93018 0 L
.93155 0 L
.93285 0 L
.93403 0 L
.93639 0 L
.93896 0 L
.94137 0 L
.94364 0 L
.945 0 L
.94572 0 L
.94648 0 L
.94782 0 L
.94905 0 L
.94974 0 L
.95048 0 L
.9518 0 L
.95262 0 L
.95338 0 L
.95482 0 L
.96518 0 L
.97397 0 L
.98328 0 L
1 0 L
Mfstroke
0 0 m
.00123 0 L
.00236 0 L
.00365 0 L
.00488 0 L
.00601 0 L
.00706 0 L
.00821 0 L
.00942 0 L
.01065 0 L
.01196 0 L
.0132 0 L
.01434 0 L
.01566 0 L
.01641 0 L
.01711 0 L
.01839 0 L
.01975 0 L
.02043 0 L
.02115 0 L
.02245 0 L
.02317 0 L
.02384 0 L
s
.02384 0 m
.02397 0 L
s
.02715 0 m
.02814 0 L
.02945 0 L
s
.02945 0 m
.02963 0 L
s
.03613 0 m
.03676 0 L
.03813 0 L
.03929 0 L
.04057 0 L
.04131 0 L
.042 0 L
.04275 0 L
.04355 0 L
.0449 0 L
.04566 0 L
.04637 0 L
.0477 0 L
.04892 0 L
.04959 0 L
.05032 0 L
.05165 0 L
.06349 0 L
.07455 0 L
.08481 0 L
.12595 0 L
.16967 0 L
.19162 0 L
.21179 0 L
.25232 0 L
.27213 0 L
.29384 0 L
.31609 0 L
.32661 0 L
.33124 0 L
.33251 0 L
.33387 0 L
.33516 0 L
.33634 0 L
.33868 0 L
.34123 0 L
.34376 0 L
.34642 0 L
.35736 0 L
.37725 0 L
.41989 0 L
.42485 0 L
.42727 0 L
.42832 0 L
.42947 0 L
.43067 0 L
.4318 0 L
.4331 0 L
.4343 0 L
.43961 0 L
Mistroke
.44084 0 L
.44216 0 L
.44362 0 L
.44499 0 L
.44778 0 L
.44846 0 L
.44918 0 L
.44998 0 L
.45072 0 L
.4514 0 L
.45215 0 L
.45351 0 L
.45483 0 L
.45605 0 L
.46095 0 L
.46658 0 L
.46799 0 L
.46933 0 L
.47053 0 L
.47185 0 L
.47322 0 L
.4745 0 L
.47588 0 L
.47735 0 L
.4834 0 L
.48912 0 L
.49049 0 L
.49123 0 L
.49193 0 L
.49316 0 L
.49451 0 L
.49573 0 L
.49684 0 L
.49934 0 L
.50457 0 L
.50963 0 L
.51239 0 L
.51375 0 L
.51499 0 L
.51607 0 L
.5172 0 L
.51833 0 L
.51957 0 L
.52084 0 L
.52219 0 L
.52463 0 L
.52745 0 L
.53051 0 L
.53339 0 L
.53605 0 L
Mistroke
.53866 0 L
.53993 0 L
.5411 0 L
.54232 0 L
.54364 0 L
.54432 0 L
.54507 0 L
.54643 0 L
.54893 0 L
.55029 0 L
.55156 0 L
.55294 0 L
.55445 0 L
.55582 0 L
.55711 0 L
.55964 0 L
.56196 0 L
.56447 0 L
.56574 0 L
.56647 0 L
.56714 0 L
.56787 0 L
.56853 0 L
.5693 0 L
.57003 0 L
.5713 0 L
.57269 0 L
.5742 0 L
.57503 0 L
.57581 0 L
.57654 0 L
.57733 0 L
.57871 0 L
.58133 0 L
.58279 0 L
.58413 0 L
.58672 0 L
.58918 0 L
.59039 0 L
.59167 0 L
.59276 0 L
.59396 0 L
.59525 0 L
.59598 0 L
.59664 0 L
.59916 0 L
.60048 0 L
.60171 0 L
.60305 0 L
.60381 0 L
Mistroke
.60449 0 L
.60588 0 L
.60666 0 L
.60738 0 L
.60871 0 L
.60938 0 L
.61011 0 L
.61082 0 L
.61159 0 L
.61299 0 L
.61437 0 L
.61562 0 L
.61638 0 L
.6171 0 L
.61786 0 L
.61869 0 L
.61941 0 L
.62017 0 L
.62153 0 L
.6228 0 L
.624 0 L
.62538 0 L
.62663 0 L
.62802 0 L
.6288 0 L
.62953 0 L
.63084 0 L
.63223 0 L
.63473 0 L
.63737 0 L
.63965 0 L
.6409 0 L
.64208 0 L
.64346 0 L
.64471 0 L
.64589 0 L
.64716 0 L
.6498 0 L
.65052 0 L
.6513 0 L
.65197 0 L
.6527 0 L
.654 0 L
.65524 0 L
.65756 0 L
.65885 0 L
.66023 0 L
.6627 0 L
.66502 0 L
.66718 0 L
Mistroke
.66827 0 L
.66944 0 L
.67073 0 L
.67191 0 L
.67317 0 L
.67454 0 L
.67702 0 L
.67926 0 L
.68045 0 L
.68172 0 L
.6831 0 L
.6844 0 L
.68515 0 L
.68588 0 L
.68723 0 L
.68849 0 L
.68966 0 L
.69231 0 L
.6968 0 L
.69924 0 L
.70153 0 L
.70272 0 L
.70401 0 L
.70473 0 L
.70543 0 L
.70672 0 L
.70791 0 L
.70901 0 L
.7115 0 L
.71427 0 L
.71563 0 L
.71688 0 L
.71819 0 L
.71887 0 L
.7196 0 L
.72034 0 L
.72103 0 L
.7226 0 L
.7252 0 L
.72765 0 L
.73048 0 L
.73305 0 L
.73542 0 L
.73662 0 L
.73793 0 L
.73905 0 L
.74025 0 L
.74139 0 L
.74243 0 L
.74518 0 L
Mistroke
.74776 0 L
.74889 0 L
.75008 0 L
.75139 0 L
.75259 0 L
.75383 0 L
.75499 0 L
.75626 0 L
.75761 0 L
.75893 0 L
.76036 0 L
.76171 0 L
.76296 0 L
.76412 0 L
.7654 0 L
.76674 0 L
.76799 0 L
.76914 0 L
.7702 0 L
.77141 0 L
.77257 0 L
.77394 0 L
.77518 0 L
.77797 0 L
.78058 0 L
.78172 0 L
.78298 0 L
.78435 0 L
.78509 0 L
.78579 0 L
.78656 0 L
.78726 0 L
.78807 0 L
.78883 0 L
.7902 0 L
.79147 0 L
.79435 0 L
.79688 0 L
.7992 0 L
.80171 0 L
.80303 0 L
.80444 0 L
.8057 0 L
.80683 0 L
.80798 0 L
.80906 0 L
.81028 0 L
.8114 0 L
.81393 0 L
.81634 0 L
Mistroke
.81766 0 L
.81893 0 L
.82041 0 L
.82177 0 L
.82443 0 L
.827 0 L
.82975 0 L
.83276 0 L
.83555 0 L
.83697 0 L
.83829 0 L
.83967 0 L
.8404 0 L
.84119 0 L
.84185 0 L
.84258 0 L
.8439 0 L
.84518 0 L
.84637 0 L
.84929 0 L
.85072 0 L
.85204 0 L
.85341 0 L
.85414 0 L
.8549 0 L
.85568 0 L
.85641 0 L
.8572 0 L
.85806 0 L
.85939 0 L
.86083 0 L
.86218 0 L
.86341 0 L
.8648 0 L
.86611 0 L
.86685 0 L
.86753 0 L
.86908 0 L
.87162 0 L
.87286 0 L
.874 0 L
.87533 0 L
.87602 0 L
.87675 0 L
.87794 0 L
.87924 0 L
.87997 0 L
.88065 0 L
.88194 0 L
.88482 0 L
Mistroke
.89001 0 L
.89273 0 L
.89421 0 L
.8956 0 L
.89633 0 L
.89711 0 L
.89797 0 L
.89876 0 L
.89948 0 L
.90026 0 L
.90099 0 L
.90168 0 L
.90301 0 L
.90444 0 L
.90705 0 L
.90959 0 L
.91192 0 L
.91723 0 L
.92011 0 L
.92284 0 L
.92405 0 L
.92534 0 L
.92601 0 L
.92674 0 L
.92805 0 L
.92922 0 L
.93049 0 L
.93169 0 L
.93279 0 L
.93408 0 L
.93527 0 L
.93799 0 L
.9408 0 L
.94346 0 L
.9458 0 L
.94712 0 L
.94833 0 L
.94936 0 L
.95049 0 L
.95166 0 L
.95277 0 L
.95405 0 L
.95527 0 L
.95637 0 L
.95756 0 L
.96271 0 L
.96718 0 L
.97201 0 L
.97658 0 L
.98077 0 L
Mistroke
.98331 0 L
.98568 0 L
.98815 0 L
.99086 0 L
.99527 0 L
1 0 L
Mfstroke
0 0 m
.00123 0 L
.00236 0 L
.00365 0 L
.00488 0 L
.00601 0 L
.00706 0 L
.00821 0 L
.00942 0 L
.01065 0 L
.01196 0 L
.0132 0 L
.01434 0 L
.01566 0 L
.01641 0 L
.01711 0 L
.01839 0 L
.01975 0 L
.02043 0 L
.02115 0 L
.02245 0 L
.02396 0 L
.0247 0 L
.02537 0 L
s
.02537 0 m
.02547 0 L
s
.0296 0 m
.03067 0 L
.03185 0 L
.03316 0 L
.03453 0 L
.03581 0 L
.037 0 L
s
.037 0 m
.03708 0 L
s
.03974 0 m
.04057 0 L
s
.04057 0 m
.04107 0 L
s
.04172 0 m
.04199 0 L
s
.04199 0 m
.04242 0 L
s
.04448 0 m
.04465 0 L
.04586 0 L
s
.04586 0 m
.04672 0 L
s
.04745 0 m
.04791 0 L
.04861 0 L
s
.04861 0 m
.04908 0 L
s
.04983 0 m
.05001 0 L
.05078 0 L
.05151 0 L
.05274 0 L
.05404 0 L
.05527 0 L
.05638 0 L
.0577 0 L
s
.0577 0 m
.05835 0 L
s
.05975 0 m
.06037 0 L
.0617 0 L
.06244 0 L
.06314 0 L
.06445 0 L
.0652 0 L
.06599 0 L
.06666 0 L
.0674 0 L
.06872 0 L
.06995 0 L
.07129 0 L
.07204 0 L
.07272 0 L
.07343 0 L
.07418 0 L
.07554 0 L
.07701 0 L
.07779 0 L
.07861 0 L
.07948 0 L
.08029 0 L
.08104 0 L
.08186 0 L
.0826 0 L
.08339 0 L
.08413 0 L
.08481 0 L
.12661 0 L
.16682 0 L
.18715 0 L
.20961 0 L
.23109 0 L
.25081 0 L
.25328 0 L
.25464 0 L
.25592 0 L
.25712 0 L
.25842 0 L
.2596 0 L
.26069 0 L
.26193 0 L
.2631 0 L
.26432 0 L
.26566 0 L
.26703 0 L
.26828 0 L
.26897 0 L
.26972 0 L
Mistroke
.2711 0 L
.27659 0 L
.27961 0 L
.28033 0 L
.28109 0 L
.28245 0 L
.28372 0 L
.28444 0 L
.28511 0 L
.28661 0 L
.28798 0 L
.28922 0 L
.2904 0 L
.29164 0 L
.29299 0 L
.29429 0 L
.29548 0 L
.29669 0 L
.29781 0 L
.29905 0 L
.3004 0 L
.30172 0 L
.30246 0 L
.30313 0 L
.30831 0 L
.31103 0 L
.3124 0 L
.31391 0 L
.3152 0 L
.31658 0 L
.31789 0 L
.31909 0 L
.32029 0 L
.32157 0 L
.32277 0 L
.32386 0 L
.32505 0 L
.32617 0 L
.32738 0 L
.32868 0 L
.32984 0 L
.33107 0 L
.33211 0 L
.33325 0 L
.33463 0 L
.3359 0 L
.33727 0 L
.33878 0 L
.34009 0 L
.34132 0 L
Mistroke
.34261 0 L
.34401 0 L
.3538 0 L
.37578 0 L
.38091 0 L
.38226 0 L
.38297 0 L
.38372 0 L
.38511 0 L
.38638 0 L
.38715 0 L
.38788 0 L
.38953 0 L
.39238 0 L
.39796 0 L
.40318 0 L
.40443 0 L
.40575 0 L
.40689 0 L
.40813 0 L
.40881 0 L
.40954 0 L
.41087 0 L
.41162 0 L
.41242 0 L
.41384 0 L
.41633 0 L
.41774 0 L
.41905 0 L
.4218 0 L
.42435 0 L
.42566 0 L
.42708 0 L
.42789 0 L
.42864 0 L
.42938 0 L
.43009 0 L
.43135 0 L
.43251 0 L
.43515 0 L
.43792 0 L
.44052 0 L
.4429 0 L
.44548 0 L
.44762 0 L
.44875 0 L
.44997 0 L
.45129 0 L
.45252 0 L
.45324 0 L
Mistroke
.45393 0 L
.45521 0 L
.46003 0 L
.46236 0 L
.46486 0 L
.46761 0 L
.46895 0 L
.47019 0 L
.4715 0 L
.47219 0 L
.47293 0 L
.47371 0 L
.47444 0 L
.47582 0 L
.48097 0 L
.48332 0 L
.48581 0 L
.49026 0 L
.49145 0 L
.49274 0 L
.49395 0 L
.49505 0 L
.49635 0 L
.49708 0 L
.49776 0 L
.50032 0 L
Mfstroke
.50032 0 m
.50963 0 L
s
.52617 0 m
.53103 0 L
.53363 0 L
.53644 0 L
.53909 0 L
.54025 0 L
.5415 0 L
.54288 0 L
.54417 0 L
.54489 0 L
.54565 0 L
.54701 0 L
.55212 0 L
.55501 0 L
.5566 0 L
.55811 0 L
.56103 0 L
.5637 0 L
s
.5637 0 m
.56384 0 L
s
.57224 0 m
.57376 0 L
.575 0 L
.57633 0 L
.57709 0 L
.57778 0 L
.57914 0 L
.5848 0 L
.58743 0 L
.58989 0 L
.59113 0 L
.59246 0 L
.59322 0 L
.59393 0 L
.59528 0 L
.59769 0 L
.59888 0 L
.59996 0 L
.60122 0 L
.60258 0 L
.60373 0 L
.60495 0 L
.60629 0 L
.60753 0 L
.6089 0 L
.60967 0 L
.61037 0 L
.61161 0 L
.61295 0 L
.61421 0 L
.6154 0 L
.61676 0 L
.61749 0 L
.61827 0 L
.61908 0 L
.61986 0 L
.62132 0 L
.62267 0 L
.62413 0 L
.62551 0 L
.62679 0 L
.62801 0 L
.62935 0 L
.63002 0 L
.63075 0 L
.63206 0 L
.63456 0 L
.63684 0 L
.63947 0 L
.64087 0 L
Mistroke
.64157 0 L
.64234 0 L
.64302 0 L
.64374 0 L
.64505 0 L
.64636 0 L
.64756 0 L
.64973 0 L
.65092 0 L
.65205 0 L
.65338 0 L
.65459 0 L
.65696 0 L
.65816 0 L
.65943 0 L
.66171 0 L
.66686 0 L
.66813 0 L
.66951 0 L
.67082 0 L
.67203 0 L
.67323 0 L
.67432 0 L
.67676 0 L
.67939 0 L
.68078 0 L
.68153 0 L
.68224 0 L
.68352 0 L
.6842 0 L
.68493 0 L
.68622 0 L
.6874 0 L
.68859 0 L
.68985 0 L
.69213 0 L
.69457 0 L
.69727 0 L
.69943 0 L
.70174 0 L
.70306 0 L
.70427 0 L
.70548 0 L
.70662 0 L
.70791 0 L
.7091 0 L
.71179 0 L
.71438 0 L
.71576 0 L
.71651 0 L
Mistroke
.71723 0 L
.71851 0 L
.71967 0 L
.72077 0 L
.72196 0 L
.72453 0 L
.72695 0 L
.72985 0 L
.73246 0 L
.73395 0 L
.73552 0 L
.73686 0 L
.73762 0 L
.73833 0 L
.73961 0 L
.74077 0 L
.74212 0 L
.74339 0 L
.74622 0 L
.7476 0 L
.74886 0 L
.74998 0 L
.75119 0 L
.75248 0 L
.7537 0 L
.75504 0 L
.75579 0 L
.75647 0 L
.75779 0 L
.75904 0 L
.76035 0 L
.76174 0 L
.76292 0 L
.76422 0 L
.76715 0 L
.76844 0 L
.76911 0 L
.76983 0 L
.77112 0 L
.77231 0 L
.77343 0 L
.77466 0 L
.77595 0 L
.77733 0 L
.77984 0 L
.78107 0 L
.78222 0 L
.78341 0 L
.78472 0 L
.78585 0 L
Mistroke
.78688 0 L
.78807 0 L
.78919 0 L
.7904 0 L
.7917 0 L
.79405 0 L
.79684 0 L
.7994 0 L
.80205 0 L
.80345 0 L
.80422 0 L
.80494 0 L
.80563 0 L
.80637 0 L
.80767 0 L
.80899 0 L
.8102 0 L
.82958 0 L
.83452 0 L
.83583 0 L
.83725 0 L
.83859 0 L
.83982 0 L
.84098 0 L
.84225 0 L
.84358 0 L
.84482 0 L
.84938 0 L
.85076 0 L
.85204 0 L
.85337 0 L
.85408 0 L
.85483 0 L
.85618 0 L
.85745 0 L
.8586 0 L
.85983 0 L
.8613 0 L
.86268 0 L
.86411 0 L
.86569 0 L
.86829 0 L
.87109 0 L
.87377 0 L
.87513 0 L
.8759 0 L
.87662 0 L
.87791 0 L
.87909 0 L
.88038 0 L
Mistroke
.88175 0 L
.88314 0 L
.88462 0 L
.88729 0 L
.8902 0 L
.89173 0 L
.89336 0 L
.89477 0 L
.89551 0 L
.89632 0 L
.89705 0 L
.89773 0 L
.89905 0 L
.90036 0 L
.90111 0 L
.9018 0 L
.90307 0 L
.90442 0 L
.90714 0 L
.9097 0 L
.91448 0 L
.91978 0 L
.92238 0 L
.92474 0 L
.92602 0 L
.92723 0 L
.92851 0 L
.92923 0 L
.9299 0 L
.93121 0 L
.93195 0 L
.93265 0 L
.93406 0 L
.93557 0 L
.9405 0 L
.94319 0 L
.9445 0 L
.94569 0 L
.94672 0 L
.94784 0 L
.94901 0 L
.95013 0 L
.95135 0 L
.95265 0 L
.95375 0 L
.95497 0 L
.95633 0 L
.95759 0 L
.95898 0 L
.95975 0 L
Mistroke
.96045 0 L
.96174 0 L
.96246 0 L
.96313 0 L
.96436 0 L
.96565 0 L
.9679 0 L
.96913 0 L
.9703 0 L
.97169 0 L
.97294 0 L
.97412 0 L
.9754 0 L
.9809 0 L
.98359 0 L
.98477 0 L
.98605 0 L
.98738 0 L
.98864 0 L
.98934 0 L
.99008 0 L
.99142 0 L
.99219 0 L
.99302 0 L
.99453 0 L
.99734 0 L
1 0 L
Mfstroke
0 0 m
.00123 0 L
.00236 0 L
.00365 0 L
.00488 0 L
.00601 0 L
.00706 0 L
.00821 0 L
.00942 0 L
.01065 0 L
.01196 0 L
.0131 0 L
.01434 0 L
.01509 0 L
.01579 0 L
s
.01579 0 m
.01582 0 L
s
.02089 0 m
.02115 0 L
.02245 0 L
.02317 0 L
.02384 0 L
.02458 0 L
.02537 0 L
.02605 0 L
.02679 0 L
.02814 0 L
.02945 0 L
s
.02945 0 m
.0297 0 L
s
.03651 0 m
.03676 0 L
.03813 0 L
.03929 0 L
s
.03929 0 m
.03974 0 L
s
.04106 0 m
.04131 0 L
s
.04131 0 m
.04187 0 L
s
.04276 0 m
.04355 0 L
.0449 0 L
s
.0449 0 m
.04492 0 L
s
.04759 0 m
.0477 0 L
.04892 0 L
.04959 0 L
.05032 0 L
.05165 0 L
.05245 0 L
s
.05245 0 m
.05282 0 L
s
.0541 0 m
.05462 0 L
.05543 0 L
s
.05543 0 m
.05562 0 L
s
.05803 0 m
.05854 0 L
.05921 0 L
.06 0 L
s
.06 0 m
.06042 0 L
s
.06145 0 m
.06205 0 L
.0628 0 L
.06349 0 L
.06464 0 L
s
.06464 0 m
.06541 0 L
s
.0671 0 m
.06719 0 L
.06841 0 L
.06975 0 L
.0705 0 L
.07121 0 L
.07248 0 L
.07383 0 L
.07457 0 L
.07525 0 L
.076 0 L
.07679 0 L
.07812 0 L
.07888 0 L
.07959 0 L
.0809 0 L
.08211 0 L
.08349 0 L
.08481 0 L
.086 0 L
.08729 0 L
.0885 0 L
.08962 0 L
.09096 0 L
.0922 0 L
.0935 0 L
.09419 0 L
.09493 0 L
s
.09493 0 m
.095 0 L
s
.09681 0 m
.09765 0 L
.09885 0 L
.10013 0 L
.10149 0 L
.10277 0 L
.10349 0 L
.10418 0 L
.10497 0 L
.10569 0 L
.10691 0 L
.10801 0 L
.10928 0 L
.11048 0 L
.1116 0 L
.11262 0 L
.11375 0 L
.11493 0 L
.11613 0 L
.11742 0 L
.11864 0 L
.11974 0 L
.12104 0 L
.12178 0 L
.12245 0 L
.1237 0 L
.12502 0 L
.12622 0 L
.12753 0 L
.12889 0 L
.13016 0 L
.13135 0 L
.13244 0 L
.13369 0 L
.13487 0 L
.13616 0 L
.13752 0 L
.13868 0 L
.13996 0 L
.14134 0 L
.14211 0 L
.14281 0 L
.14418 0 L
.14548 0 L
.14669 0 L
.14779 0 L
.14906 0 L
.15025 0 L
.15136 0 L
.15237 0 L
Mistroke
.15349 0 L
.15467 0 L
.15586 0 L
.15714 0 L
.15835 0 L
.15945 0 L
.16074 0 L
.16146 0 L
.16214 0 L
.16468 0 L
.16599 0 L
.16723 0 L
.16835 0 L
.16957 0 L
.17089 0 L
.17229 0 L
.17483 0 L
.17606 0 L
.17739 0 L
.17981 0 L
.18433 0 L
.18559 0 L
.18695 0 L
.18772 0 L
.18843 0 L
.18981 0 L
.19561 0 L
.20599 0 L
.22771 0 L
.23726 0 L
.23973 0 L
.24234 0 L
.2437 0 L
.24447 0 L
.24519 0 L
.24646 0 L
.24781 0 L
.24911 0 L
.2498 0 L
.25052 0 L
.25185 0 L
.25308 0 L
.25418 0 L
.25536 0 L
.25666 0 L
.25787 0 L
.25908 0 L
.2604 0 L
.2628 0 L
.26514 0 L
Mistroke
.26628 0 L
.26732 0 L
.26862 0 L
.2693 0 L
.27003 0 L
.27125 0 L
.27258 0 L
.27735 0 L
.28002 0 L
.28079 0 L
.28152 0 L
.28288 0 L
.28417 0 L
.28536 0 L
.28667 0 L
.28804 0 L
.28926 0 L
.29059 0 L
.29292 0 L
.29564 0 L
.29694 0 L
.29817 0 L
.29933 0 L
.30058 0 L
.30172 0 L
.30277 0 L
.30767 0 L
.31311 0 L
.31447 0 L
.31576 0 L
.31693 0 L
.31819 0 L
.31952 0 L
.32075 0 L
.32143 0 L
.32216 0 L
.32349 0 L
.32483 0 L
.32631 0 L
.32707 0 L
.32788 0 L
.32931 0 L
.33061 0 L
.33129 0 L
.33201 0 L
.33333 0 L
.33455 0 L
.33572 0 L
.33682 0 L
.33801 0 L
Mistroke
.33931 0 L
.34069 0 L
.342 0 L
.34328 0 L
.34447 0 L
.35001 0 L
.35232 0 L
.35353 0 L
.35481 0 L
.35594 0 L
.35717 0 L
.35829 0 L
.35934 0 L
.36065 0 L
.36186 0 L
.36324 0 L
.36455 0 L
.36565 0 L
.36682 0 L
.3681 0 L
.36928 0 L
.37912 0 L
.38182 0 L
.38329 0 L
.38466 0 L
.38583 0 L
.38708 0 L
.38847 0 L
.38973 0 L
.39203 0 L
.39447 0 L
.39574 0 L
.39714 0 L
.39961 0 L
.40193 0 L
.40321 0 L
.40442 0 L
.40555 0 L
.40678 0 L
.40789 0 L
.40893 0 L
.41028 0 L
.41097 0 L
.41172 0 L
.41428 0 L
.41727 0 L
.42006 0 L
.42287 0 L
.42554 0 L
.4267 0 L
Mistroke
.42793 0 L
.42928 0 L
.43052 0 L
.43164 0 L
.43284 0 L
.43502 0 L
.43997 0 L
.44525 0 L
.44644 0 L
.44773 0 L
.44895 0 L
.45008 0 L
.45135 0 L
.4527 0 L
.45383 0 L
.45507 0 L
.4604 0 L
.46279 0 L
.46536 0 L
.46777 0 L
.46882 0 L
.46999 0 L
.47135 0 L
.47209 0 L
.47279 0 L
.47355 0 L
.47425 0 L
.47502 0 L
.47583 0 L
.48137 0 L
.48376 0 L
Mfstroke
.48376 0 m
.48459 0 L
s
.50007 0 m
.50249 0 L
.50519 0 L
.50806 0 L
.51121 0 L
.51274 0 L
.51414 0 L
.51547 0 L
.51615 0 L
.51689 0 L
.51763 0 L
.51842 0 L
.51917 0 L
.51985 0 L
.52118 0 L
.52262 0 L
.52524 0 L
s
.52524 0 m
.53381 0 L
s
.55756 0 m
.55893 0 L
.56164 0 L
.56301 0 L
.56431 0 L
.56547 0 L
.56672 0 L
.56745 0 L
.56822 0 L
.56959 0 L
.57035 0 L
.57105 0 L
.57265 0 L
.57401 0 L
.5753 0 L
.57602 0 L
.57679 0 L
.57814 0 L
s
.57814 0 m
.58448 0 L
s
.60029 0 m
.60035 0 L
.60105 0 L
.60181 0 L
.60316 0 L
.60443 0 L
.60519 0 L
.60592 0 L
.60728 0 L
.60804 0 L
.60874 0 L
.60952 0 L
.61034 0 L
.6116 0 L
.61296 0 L
.61414 0 L
.61543 0 L
.61617 0 L
.61685 0 L
.61758 0 L
.61836 0 L
.61908 0 L
.61977 0 L
.62105 0 L
.62339 0 L
.62468 0 L
.62591 0 L
.6266 0 L
.62735 0 L
.62867 0 L
.63001 0 L
.63125 0 L
.63267 0 L
.634 0 L
.63649 0 L
.6392 0 L
.63991 0 L
.64068 0 L
.64206 0 L
.64327 0 L
.64437 0 L
.64568 0 L
.64691 0 L
.64907 0 L
.65026 0 L
.65137 0 L
.65256 0 L
.65388 0 L
.65499 0 L
.65619 0 L
Mistroke
.65753 0 L
.65893 0 L
.66143 0 L
.66391 0 L
.6666 0 L
.66784 0 L
.66914 0 L
.67025 0 L
.67148 0 L
.67221 0 L
.67288 0 L
.67365 0 L
.67438 0 L
.6771 0 L
.67957 0 L
.68092 0 L
.6822 0 L
.68329 0 L
.68448 0 L
.68579 0 L
.68699 0 L
.68803 0 L
.68916 0 L
.69144 0 L
.69395 0 L
.69664 0 L
.69895 0 L
.7015 0 L
Mfstroke
.7015 0 m
.70213 0 L
s
.70945 0 m
.70954 0 L
.71223 0 L
.71363 0 L
.71513 0 L
.71656 0 L
.71787 0 L
.7186 0 L
.7194 0 L
.72024 0 L
.72102 0 L
.72388 0 L
.73401 0 L
.73544 0 L
.73679 0 L
.73746 0 L
.73819 0 L
.739 0 L
.73974 0 L
.74097 0 L
.74231 0 L
.74299 0 L
.74372 0 L
.74503 0 L
.74799 0 L
.74944 0 L
.75078 0 L
.752 0 L
.75329 0 L
.75459 0 L
.75532 0 L
.75601 0 L
.75736 0 L
.75863 0 L
.75978 0 L
.76103 0 L
.76238 0 L
.76382 0 L
.76641 0 L
.76895 0 L
.76964 0 L
.77037 0 L
.77168 0 L
.77291 0 L
.77405 0 L
.7753 0 L
.77664 0 L
.78113 0 L
.78223 0 L
.7834 0 L
Mistroke
.78469 0 L
.7859 0 L
.78661 0 L
.78739 0 L
.78813 0 L
.78881 0 L
.7901 0 L
.79147 0 L
.79417 0 L
.79662 0 L
.80221 0 L
.80374 0 L
.80457 0 L
.80536 0 L
.80674 0 L
.80747 0 L
.80826 0 L
.80898 0 L
.80966 0 L
.81039 0 L
.81118 0 L
.81395 0 L
.81663 0 L
.81794 0 L
.81914 0 L
.82028 0 L
.82149 0 L
.82402 0 L
.82678 0 L
.8294 0 L
.83192 0 L
.83464 0 L
.83691 0 L
.83812 0 L
.83941 0 L
.84014 0 L
.84081 0 L
.84212 0 L
.84282 0 L
.84358 0 L
.84431 0 L
.84498 0 L
.84762 0 L
.85011 0 L
.85126 0 L
.85247 0 L
.85379 0 L
.85501 0 L
.85611 0 L
.85713 0 L
Mistroke
.85825 0 L
.85945 0 L
.86073 0 L
.86212 0 L
.86344 0 L
.86465 0 L
.86695 0 L
.86939 0 L
.8719 0 L
.87327 0 L
.87454 0 L
.87563 0 L
.87679 0 L
.87808 0 L
.87925 0 L
.88062 0 L
.88187 0 L
.88325 0 L
.88471 0 L
.88987 0 L
.89215 0 L
.8934 0 L
.8946 0 L
.8957 0 L
.89691 0 L
.898 0 L
.89902 0 L
.90021 0 L
.90133 0 L
.90256 0 L
.90389 0 L
.90659 0 L
.90907 0 L
.91403 0 L
.91681 0 L
.91934 0 L
.92175 0 L
.92431 0 L
.92536 0 L
.9265 0 L
.92774 0 L
.9289 0 L
.92959 0 L
.93034 0 L
.9317 0 L
.93303 0 L
.93426 0 L
.94007 0 L
.9427 0 L
.94518 0 L
Mistroke
.94655 0 L
.94727 0 L
.94803 0 L
.94938 0 L
.95062 0 L
.9519 0 L
.95263 0 L
.9533 0 L
.95453 0 L
.95583 0 L
.95811 0 L
.96058 0 L
.96319 0 L
.96565 0 L
.96832 0 L
.96974 0 L
.97125 0 L
.97257 0 L
.97378 0 L
.97499 0 L
.97614 0 L
.97742 0 L
.97861 0 L
.98129 0 L
.98358 0 L
.98485 0 L
.98605 0 L
.98716 0 L
.98837 0 L
.98947 0 L
.9905 0 L
.99165 0 L
.99269 0 L
.99389 0 L
.99502 0 L
1 0 L
Mfstroke
0 0 m
.00123 0 L
.00236 0 L
.00365 0 L
.00488 0 L
.00601 0 L
.00706 0 L
.00821 0 L
.00942 0 L
.01065 0 L
s
.01065 0 m
.01087 0 L
s
.01454 0 m
.01566 0 L
.01641 0 L
.01711 0 L
s
.01711 0 m
.01725 0 L
s
.02971 0 m
.03067 0 L
.03184 0 L
.03295 0 L
.03416 0 L
.03547 0 L
s
.03547 0 m
.03649 0 L
s
.0397 0 m
.04057 0 L
s
.04057 0 m
.04106 0 L
s
.04189 0 m
.042 0 L
.04275 0 L
s
.04275 0 m
.04279 0 L
s
.04486 0 m
.0449 0 L
.04566 0 L
.04637 0 L
s
.04637 0 m
.04759 0 L
s
.05274 0 m
.05321 0 L
.05389 0 L
s
.05389 0 m
.05426 0 L
s
.05559 0 m
.05627 0 L
.057 0 L
.05779 0 L
s
.05779 0 m
.05806 0 L
s
.06034 0 m
.06074 0 L
s
.06074 0 m
.06165 0 L
s
.06514 0 m
.06586 0 L
.06719 0 L
.06841 0 L
.06975 0 L
.0705 0 L
.07121 0 L
.07248 0 L
s
.07248 0 m
.07253 0 L
s
.07699 0 m
.07812 0 L
s
.07812 0 m
.0786 0 L
s
.08687 0 m
.08729 0 L
s
.08729 0 m
.08804 0 L
s
.0931 0 m
.0935 0 L
.09419 0 L
.09493 0 L
.09566 0 L
.09633 0 L
.09765 0 L
s
.09765 0 m
.09822 0 L
s
.10459 0 m
.10497 0 L
.10569 0 L
.10691 0 L
s
.10691 0 m
.1071 0 L
s
.10939 0 m
.11048 0 L
.1116 0 L
.11262 0 L
.11375 0 L
s
.11375 0 m
.1139 0 L
s
.11963 0 m
.11974 0 L
.12042 0 L
.12116 0 L
.1225 0 L
.12381 0 L
.12502 0 L
.12626 0 L
.12756 0 L
.12868 0 L
.12989 0 L
.13121 0 L
.13194 0 L
.13261 0 L
.13391 0 L
.13514 0 L
.13629 0 L
.13751 0 L
.13855 0 L
.1397 0 L
.14093 0 L
.14225 0 L
.14349 0 L
.14463 0 L
.14597 0 L
.14672 0 L
.14739 0 L
.14872 0 L
.14995 0 L
.15065 0 L
.15138 0 L
.15212 0 L
.15293 0 L
.1544 0 L
.15574 0 L
.15709 0 L
.15837 0 L
.15972 0 L
.16049 0 L
.16119 0 L
.16236 0 L
.16366 0 L
.16501 0 L
.16627 0 L
.16753 0 L
.16888 0 L
.16965 0 L
.17037 0 L
.17172 0 L
.17302 0 L
Mistroke
.17421 0 L
.17552 0 L
.17691 0 L
.17807 0 L
.17931 0 L
.18038 0 L
.18155 0 L
.18292 0 L
.18421 0 L
.18547 0 L
.18664 0 L
.18789 0 L
.18925 0 L
.19052 0 L
.19169 0 L
.19298 0 L
.19435 0 L
.19514 0 L
.19586 0 L
.19659 0 L
.19727 0 L
.19855 0 L
.19991 0 L
.20062 0 L
.2014 0 L
.20277 0 L
.20352 0 L
.20421 0 L
.20495 0 L
.20576 0 L
.20651 0 L
.2072 0 L
.20856 0 L
.23014 0 L
.24969 0 L
.25234 0 L
.25364 0 L
.25482 0 L
.25607 0 L
.2574 0 L
.2581 0 L
.25886 0 L
.26024 0 L
.26245 0 L
.26485 0 L
.26621 0 L
.26747 0 L
.26867 0 L
.26993 0 L
.27129 0 L
Mistroke
.27256 0 L
.27407 0 L
.27544 0 L
.2769 0 L
.27827 0 L
.27974 0 L
.28054 0 L
.28129 0 L
.28255 0 L
.28392 0 L
.28509 0 L
.28634 0 L
.2878 0 L
.28853 0 L
.28919 0 L
.29044 0 L
.2918 0 L
.29665 0 L
.29798 0 L
.29865 0 L
.29938 0 L
.30068 0 L
.30189 0 L
.30312 0 L
.30428 0 L
.30647 0 L
.3088 0 L
.31012 0 L
.31136 0 L
.31398 0 L
.31472 0 L
.31543 0 L
.31676 0 L
.3179 0 L
.31915 0 L
.32049 0 L
.32173 0 L
.32244 0 L
.3232 0 L
.32459 0 L
.32582 0 L
.32718 0 L
.32794 0 L
.32865 0 L
.3302 0 L
.33155 0 L
.33229 0 L
.33298 0 L
.33428 0 L
.33497 0 L
Mistroke
.33571 0 L
.33703 0 L
.33824 0 L
.33957 0 L
.34033 0 L
.34103 0 L
.34177 0 L
.34245 0 L
.34323 0 L
.34396 0 L
.34532 0 L
.34659 0 L
.34791 0 L
.34866 0 L
.34937 0 L
.35063 0 L
.35178 0 L
.35303 0 L
.35436 0 L
.35558 0 L
.35668 0 L
.35779 0 L
.35883 0 L
.36006 0 L
.36118 0 L
.36241 0 L
.36371 0 L
.36605 0 L
.36735 0 L
.36855 0 L
.36922 0 L
.36996 0 L
.37129 0 L
.37262 0 L
.37385 0 L
.37511 0 L
.37631 0 L
.37768 0 L
.37895 0 L
.38006 0 L
.38124 0 L
.38255 0 L
.38374 0 L
.38443 0 L
.38516 0 L
.38589 0 L
.38669 0 L
.38738 0 L
.38812 0 L
.38946 0 L
Mistroke
.39216 0 L
.39465 0 L
.39603 0 L
.39749 0 L
.40058 0 L
.40348 0 L
.4049 0 L
.4062 0 L
.40737 0 L
.40861 0 L
.40985 0 L
.4112 0 L
.41259 0 L
.41406 0 L
.41673 0 L
.41944 0 L
.42232 0 L
.4248 0 L
.42617 0 L
.42747 0 L
.42819 0 L
.42897 0 L
.43034 0 L
.43101 0 L
.43173 0 L
.43302 0 L
.43912 0 L
.44484 0 L
.4462 0 L
.44764 0 L
.44887 0 L
.45022 0 L
.45143 0 L
.45272 0 L
.45394 0 L
.45505 0 L
.46028 0 L
Mfstroke
.46028 0 m
.46103 0 L
s
.47932 0 m
.48034 0 L
.48316 0 L
.48622 0 L
.48891 0 L
.49039 0 L
.49177 0 L
.49301 0 L
.49434 0 L
.4951 0 L
.49582 0 L
.49717 0 L
s
.49717 0 m
.50189 0 L
s
.5333 0 m
.53518 0 L
.53747 0 L
.53979 0 L
.54111 0 L
.54233 0 L
.54306 0 L
.54372 0 L
.54448 0 L
.5452 0 L
.54651 0 L
.54793 0 L
.55305 0 L
.55447 0 L
.55598 0 L
.55871 0 L
s
.55871 0 m
.55884 0 L
s
.58344 0 m
.58584 0 L
.5885 0 L
.5898 0 L
.59102 0 L
.59211 0 L
.59328 0 L
.59458 0 L
.59575 0 L
.59824 0 L
.5996 0 L
.60086 0 L
.60224 0 L
.60296 0 L
.60374 0 L
.60513 0 L
.60639 0 L
.60757 0 L
.60883 0 L
.61021 0 L
.61148 0 L
s
.61148 0 m
.61331 0 L
s
.61997 0 m
.62073 0 L
.62328 0 L
.62439 0 L
.62562 0 L
.62692 0 L
.62829 0 L
.62901 0 L
.62979 0 L
.63052 0 L
.63118 0 L
.63247 0 L
.63388 0 L
s
.63388 0 m
.63577 0 L
s
.65614 0 m
.65764 0 L
.6632 0 L
.66563 0 L
.6669 0 L
.66826 0 L
.66948 0 L
.67082 0 L
.67204 0 L
.67319 0 L
.67436 0 L
.67543 0 L
.67785 0 L
.68036 0 L
.68105 0 L
s
.68105 0 m
.68109 0 L
s
.69082 0 m
.6936 0 L
.69641 0 L
.69942 0 L
.70076 0 L
.70221 0 L
.70359 0 L
.70486 0 L
.70601 0 L
.70727 0 L
.70859 0 L
.70982 0 L
.71241 0 L
.71383 0 L
.71518 0 L
.71643 0 L
.71779 0 L
.71902 0 L
.72015 0 L
.72136 0 L
.72268 0 L
.72535 0 L
.72676 0 L
.72828 0 L
.73103 0 L
s
.73103 0 m
.73338 0 L
s
.74567 0 m
.74795 0 L
.74917 0 L
.75046 0 L
.75113 0 L
.75186 0 L
.75315 0 L
.75446 0 L
.75569 0 L
.75689 0 L
.75798 0 L
.75917 0 L
.76045 0 L
.76181 0 L
.76307 0 L
.76593 0 L
.76843 0 L
.76911 0 L
.76984 0 L
.77113 0 L
.77242 0 L
.77361 0 L
.77493 0 L
.77566 0 L
.77634 0 L
.77868 0 L
.78124 0 L
.78242 0 L
.78368 0 L
.78476 0 L
.78594 0 L
.78705 0 L
.78824 0 L
.78937 0 L
.7904 0 L
.79301 0 L
.79537 0 L
.79811 0 L
.80069 0 L
.80292 0 L
.80414 0 L
.80528 0 L
.80651 0 L
.80787 0 L
.80902 0 L
.81026 0 L
.83199 0 L
.83464 0 L
.83714 0 L
.83852 0 L
Mistroke
.8393 0 L
.84001 0 L
.84128 0 L
.84262 0 L
.84334 0 L
.8441 0 L
.84549 0 L
.84863 0 L
.85013 0 L
.85155 0 L
.85282 0 L
.85421 0 L
.85552 0 L
.85674 0 L
.85808 0 L
.85884 0 L
.85953 0 L
.86228 0 L
.86366 0 L
.86518 0 L
.86772 0 L
.87043 0 L
.87276 0 L
.87399 0 L
.87531 0 L
.87605 0 L
.87672 0 L
.87804 0 L
.87875 0 L
.87952 0 L
.88025 0 L
.88092 0 L
.88211 0 L
.88342 0 L
.88609 0 L
.8917 0 L
.89323 0 L
.89486 0 L
.89624 0 L
.89702 0 L
.89775 0 L
.89844 0 L
.89917 0 L
.90052 0 L
.90182 0 L
.90303 0 L
.90433 0 L
.90576 0 L
.90867 0 L
.91122 0 L
Mistroke
.91396 0 L
.91892 0 L
.92157 0 L
.92406 0 L
.92544 0 L
.92616 0 L
.92693 0 L
.92829 0 L
.92953 0 L
.93025 0 L
.93101 0 L
.9324 0 L
.93324 0 L
.93404 0 L
.93554 0 L
.94112 0 L
.94366 0 L
.94506 0 L
.94636 0 L
.94748 0 L
.94867 0 L
.95 0 L
.95122 0 L
.95254 0 L
.95378 0 L
.95513 0 L
.95657 0 L
.95931 0 L
.96221 0 L
.96706 0 L
.96922 0 L
.97154 0 L
.97284 0 L
.97403 0 L
.97522 0 L
.97635 0 L
.97767 0 L
.97889 0 L
.98165 0 L
.98385 0 L
.98501 0 L
.98623 0 L
.9873 0 L
.98847 0 L
.98954 0 L
.99054 0 L
.99179 0 L
.99294 0 L
.99426 0 L
.9955 0 L
Mistroke
1 0 L
Mfstroke
0 0 m
.00123 0 L
.00236 0 L
.00365 0 L
.00488 0 L
.00601 0 L
.00706 0 L
.00821 0 L
.00942 0 L
.01065 0 L
.01196 0 L
.0132 0 L
.01434 0 L
.01566 0 L
.01641 0 L
.01711 0 L
.01839 0 L
.01975 0 L
.02043 0 L
.02115 0 L
.02245 0 L
.02317 0 L
.02384 0 L
.02458 0 L
.02537 0 L
.02605 0 L
.02679 0 L
.02814 0 L
.02945 0 L
s
.02945 0 m
.02971 0 L
s
.03647 0 m
.03676 0 L
.03813 0 L
.03929 0 L
s
.03929 0 m
.03967 0 L
s
.04106 0 m
.04131 0 L
s
.04131 0 m
.04193 0 L
s
.04282 0 m
.04355 0 L
s
.04355 0 m
.04482 0 L
s
.04757 0 m
.0477 0 L
.04892 0 L
.04959 0 L
.05032 0 L
.05165 0 L
.05245 0 L
s
.05245 0 m
.05274 0 L
s
.05425 0 m
.05462 0 L
.05543 0 L
s
.05543 0 m
.0556 0 L
s
.05805 0 m
.05854 0 L
.05921 0 L
.06 0 L
s
.06 0 m
.06036 0 L
s
.06163 0 m
.06205 0 L
.0628 0 L
.06349 0 L
.06471 0 L
s
.06471 0 m
.06519 0 L
s
.06826 0 m
.06841 0 L
s
.06841 0 m
.06933 0 L
s
.07238 0 m
.07249 0 L
.07383 0 L
.07457 0 L
.07525 0 L
.076 0 L
.07679 0 L
s
.07679 0 m
.07729 0 L
s
.07847 0 m
.07888 0 L
.07959 0 L
.0809 0 L
.08211 0 L
.08349 0 L
.08481 0 L
.086 0 L
s
.086 0 m
.08704 0 L
s
.08767 0 m
.0885 0 L
.08962 0 L
.09096 0 L
.0922 0 L
s
.0922 0 m
.09332 0 L
s
.09806 0 m
.09885 0 L
.10013 0 L
.10149 0 L
.10277 0 L
.10349 0 L
.10418 0 L
s
.10418 0 m
.10489 0 L
s
.10597 0 m
.10691 0 L
.10801 0 L
.10928 0 L
s
.10928 0 m
.1099 0 L
s
.11353 0 m
.11375 0 L
.11493 0 L
.11613 0 L
.11742 0 L
.11974 0 L
.12042 0 L
s
.12042 0 m
.1209 0 L
s
.12584 0 m
.12626 0 L
.12756 0 L
.12868 0 L
s
.12868 0 m
.12892 0 L
s
.135 0 m
.13514 0 L
.13629 0 L
.13751 0 L
.13855 0 L
.1397 0 L
.14093 0 L
.14225 0 L
s
.14225 0 m
.14327 0 L
s
.1473 0 m
.14739 0 L
.14872 0 L
.14995 0 L
.15065 0 L
.15138 0 L
.15212 0 L
s
.15212 0 m
.15291 0 L
s
.15998 0 m
.16049 0 L
.16119 0 L
.16236 0 L
.16366 0 L
.16501 0 L
.16627 0 L
.16753 0 L
.16888 0 L
.16965 0 L
.17037 0 L
.17172 0 L
.17302 0 L
.17421 0 L
.17552 0 L
.17691 0 L
.17807 0 L
.17931 0 L
.18038 0 L
.18155 0 L
.18292 0 L
.18421 0 L
.18547 0 L
.18664 0 L
.18789 0 L
.18925 0 L
.19052 0 L
.19169 0 L
.19435 0 L
.19508 0 L
.19586 0 L
.1966 0 L
.19727 0 L
.19863 0 L
.19939 0 L
.2001 0 L
.20139 0 L
.20277 0 L
.20419 0 L
.20494 0 L
.20574 0 L
.20651 0 L
.2072 0 L
.20856 0 L
.20984 0 L
.21123 0 L
.21253 0 L
.21373 0 L
.21483 0 L
.21603 0 L
Mistroke
.21729 0 L
.21846 0 L
.22132 0 L
.22201 0 L
.22273 0 L
.22403 0 L
.22519 0 L
.22646 0 L
.22783 0 L
.2291 0 L
.23024 0 L
.23144 0 L
.23246 0 L
.23357 0 L
.23839 0 L
.24088 0 L
.24225 0 L
.24354 0 L
.24475 0 L
.24605 0 L
.24833 0 L
.25081 0 L
.25221 0 L
.25348 0 L
.25466 0 L
.25595 0 L
.25716 0 L
.25829 0 L
.26081 0 L
.26359 0 L
.26502 0 L
.26653 0 L
.26782 0 L
.26855 0 L
.26923 0 L
.27062 0 L
.27188 0 L
.27471 0 L
Mfstroke
.27471 0 m
.27525 0 L
s
.29157 0 m
.29646 0 L
.2977 0 L
.29904 0 L
.2998 0 L
.3005 0 L
.30187 0 L
.3031 0 L
.30425 0 L
.30684 0 L
.30794 0 L
.30911 0 L
.31038 0 L
.31155 0 L
s
.31155 0 m
.31292 0 L
s
.32217 0 m
.32286 0 L
.32361 0 L
.32436 0 L
.32519 0 L
.32657 0 L
.32734 0 L
.32805 0 L
.32947 0 L
.33082 0 L
.33217 0 L
.33341 0 L
.33473 0 L
.33542 0 L
.33614 0 L
.33747 0 L
.33871 0 L
.33982 0 L
.341 0 L
.34231 0 L
.34351 0 L
.34866 0 L
.35138 0 L
.35286 0 L
.35359 0 L
.35426 0 L
.35544 0 L
.35671 0 L
.3581 0 L
.35942 0 L
.3606 0 L
.3617 0 L
.3629 0 L
.36419 0 L
.3654 0 L
.36672 0 L
.36797 0 L
.36911 0 L
.37015 0 L
.37128 0 L
.3724 0 L
.37358 0 L
.37495 0 L
.37621 0 L
.37769 0 L
.37907 0 L
.38026 0 L
.38155 0 L
.38285 0 L
.38354 0 L
Mistroke
.38428 0 L
.38557 0 L
.38676 0 L
.38813 0 L
.38937 0 L
.39164 0 L
.39405 0 L
.39539 0 L
.39686 0 L
.39946 0 L
Mfstroke
.39946 0 m
.4013 0 L
s
.41312 0 m
.4135 0 L
.416 0 L
.4185 0 L
.42117 0 L
.42369 0 L
.42599 0 L
.4273 0 L
.42796 0 L
.42869 0 L
.42948 0 L
.43022 0 L
.43089 0 L
.43162 0 L
.43298 0 L
.43441 0 L
.43696 0 L
s
.43696 0 m
.43885 0 L
s
.45785 0 m
.45908 0 L
.46159 0 L
.46429 0 L
.46667 0 L
.46919 0 L
.46987 0 L
.47059 0 L
.47139 0 L
.47213 0 L
.47286 0 L
.47355 0 L
.47483 0 L
.47611 0 L
.47728 0 L
.47994 0 L
s
.47994 0 m
.48032 0 L
s
.50158 0 m
.5046 0 L
.5076 0 L
.51036 0 L
.51299 0 L
.51427 0 L
.51544 0 L
.51668 0 L
.518 0 L
.51869 0 L
.51944 0 L
.52081 0 L
.52566 0 L
.52821 0 L
.53089 0 L
.53324 0 L
s
.53324 0 m
.53353 0 L
s
.55865 0 m
.55971 0 L
.56111 0 L
.56394 0 L
.56533 0 L
.5666 0 L
.56733 0 L
.56809 0 L
.56886 0 L
.5697 0 L
.5704 0 L
.57115 0 L
.5725 0 L
.57388 0 L
.5746 0 L
.57537 0 L
.57604 0 L
.57678 0 L
.57808 0 L
.57935 0 L
.58071 0 L
.58316 0 L
s
.58316 0 m
.584 0 L
s
.60377 0 m
.60424 0 L
.60551 0 L
.60688 0 L
.60817 0 L
.60935 0 L
.61066 0 L
.6114 0 L
.61209 0 L
.61358 0 L
.61431 0 L
.61499 0 L
.61637 0 L
.6171 0 L
.61788 0 L
.61913 0 L
s
.61913 0 m
.62046 0 L
s
.6337 0 m
.63435 0 L
.63575 0 L
.63706 0 L
.63948 0 L
.64067 0 L
.64176 0 L
.64303 0 L
.6444 0 L
.64557 0 L
.6468 0 L
.64939 0 L
.65075 0 L
.65149 0 L
.65218 0 L
.65344 0 L
.65481 0 L
.65723 0 L
.65873 0 L
.66014 0 L
s
.66014 0 m
.66031 0 L
s
.67881 0 m
.67894 0 L
.68035 0 L
.68109 0 L
.68187 0 L
.68255 0 L
.6833 0 L
.68462 0 L
.6859 0 L
.68728 0 L
.68858 0 L
.68976 0 L
s
.68976 0 m
.69287 0 L
s
.72474 0 m
.72699 0 L
.72923 0 L
.73181 0 L
.73463 0 L
.73592 0 L
.73729 0 L
.73846 0 L
.73975 0 L
.74052 0 L
.74122 0 L
.74199 0 L
.7428 0 L
.74566 0 L
.74699 0 L
.74843 0 L
.74967 0 L
.75104 0 L
.75237 0 L
.75309 0 L
.75377 0 L
.75498 0 L
.75629 0 L
.75757 0 L
.75878 0 L
.75987 0 L
.76106 0 L
.76178 0 L
.76247 0 L
.76375 0 L
.76661 0 L
.7679 0 L
.76911 0 L
.77038 0 L
.77176 0 L
.77298 0 L
.77409 0 L
.77537 0 L
.77659 0 L
.78102 0 L
.78223 0 L
.78352 0 L
.78461 0 L
.78582 0 L
.78712 0 L
.78785 0 L
.78852 0 L
.78975 0 L
.79104 0 L
.80108 0 L
Mistroke
.80247 0 L
Mfstroke
.80247 0 m
.80368 0 L
s
.81225 0 m
.83109 0 L
.83625 0 L
.83751 0 L
.83886 0 L
.83964 0 L
.84035 0 L
.84103 0 L
.84175 0 L
.84247 0 L
.84323 0 L
.84462 0 L
.84627 0 L
.84777 0 L
.84918 0 L
.85067 0 L
.85195 0 L
.85268 0 L
.85335 0 L
.85465 0 L
.85536 0 L
.85604 0 L
.85724 0 L
.85856 0 L
.86129 0 L
.86282 0 L
.86421 0 L
.86695 0 L
.86953 0 L
.87208 0 L
.87333 0 L
.87447 0 L
.87568 0 L
.87683 0 L
.87804 0 L
.87936 0 L
.88071 0 L
.88139 0 L
.88214 0 L
.88472 0 L
.88993 0 L
.89267 0 L
.89416 0 L
.89555 0 L
.89676 0 L
.89804 0 L
.89878 0 L
.89947 0 L
.90077 0 L
.90197 0 L
Mistroke
.90307 0 L
.90428 0 L
.90556 0 L
.91003 0 L
.91257 0 L
.91495 0 L
.92018 0 L
.92294 0 L
.92445 0 L
.92588 0 L
.92724 0 L
.928 0 L
.9287 0 L
.92995 0 L
.93126 0 L
.93249 0 L
.93364 0 L
.93625 0 L
.94108 0 L
.94346 0 L
.94565 0 L
.94688 0 L
.94818 0 L
.94948 0 L
.95023 0 L
.95092 0 L
.95213 0 L
.95323 0 L
.95444 0 L
.95572 0 L
.96577 0 L
.96842 0 L
.96981 0 L
.97129 0 L
.97258 0 L
.97331 0 L
.974 0 L
.9752 0 L
.97649 0 L
.97779 0 L
.97853 0 L
.97921 0 L
.98178 0 L
.98407 0 L
.98529 0 L
.98661 0 L
.9878 0 L
.9889 0 L
.98995 0 L
.99106 0 L
Mistroke
.99223 0 L
.99332 0 L
.99451 0 L
.99579 0 L
1 0 L
Mfstroke
0 0 m
.00123 0 L
.00236 0 L
.00365 0 L
.00488 0 L
.00601 0 L
.00706 0 L
.00821 0 L
.00942 0 L
s
.00942 0 m
.00994 0 L
s
.02971 0 m
.03067 0 L
.03184 0 L
.03295 0 L
.03416 0 L
.03547 0 L
s
.03547 0 m
.03645 0 L
s
.03964 0 m
.04057 0 L
s
.04057 0 m
.04105 0 L
s
.04197 0 m
.042 0 L
.04275 0 L
s
.04275 0 m
.04285 0 L
s
.04476 0 m
.0449 0 L
.04566 0 L
.04637 0 L
s
.04637 0 m
.04754 0 L
s
.05272 0 m
.05321 0 L
.05389 0 L
s
.05389 0 m
.05426 0 L
s
.05562 0 m
.05627 0 L
.057 0 L
.05779 0 L
s
.05779 0 m
.05804 0 L
s
.0604 0 m
.06074 0 L
s
.06074 0 m
.06162 0 L
s
.06518 0 m
.06603 0 L
.06727 0 L
s
.06727 0 m
.06835 0 L
s
.06969 0 m
.07105 0 L
.07175 0 L
s
.07175 0 m
.07238 0 L
s
.0772 0 m
.07812 0 L
s
.07812 0 m
.07853 0 L
s
.08686 0 m
.08729 0 L
s
.08729 0 m
.08787 0 L
s
.09335 0 m
.0935 0 L
.09419 0 L
.09493 0 L
.09566 0 L
.09633 0 L
.09765 0 L
s
.09765 0 m
.09806 0 L
s
.10473 0 m
.10497 0 L
.10569 0 L
s
.10569 0 m
.10614 0 L
s
.11 0 m
.11048 0 L
.1116 0 L
.11262 0 L
s
.11262 0 m
.11358 0 L
s
.12079 0 m
.12116 0 L
.1225 0 L
.12381 0 L
.12502 0 L
s
.12502 0 m
.1261 0 L
s
.12806 0 m
.12868 0 L
.12989 0 L
.13121 0 L
.13193 0 L
.13261 0 L
.13394 0 L
.13514 0 L
s
.13514 0 m
.13534 0 L
s
.14239 0 m
.14349 0 L
.14463 0 L
.14597 0 L
.14672 0 L
.14739 0 L
s
.14739 0 m
.14777 0 L
s
.15251 0 m
.15293 0 L
.1544 0 L
.15574 0 L
.15709 0 L
.15837 0 L
.15972 0 L
.16049 0 L
.16119 0 L
.16236 0 L
s
.16236 0 m
.16276 0 L
s
.16873 0 m
.16888 0 L
.16965 0 L
.17037 0 L
.17172 0 L
.17302 0 L
s
.17302 0 m
.17315 0 L
s
.18189 0 m
.18292 0 L
.18421 0 L
.18547 0 L
.18664 0 L
.18789 0 L
.18925 0 L
.19052 0 L
.19169 0 L
s
.19169 0 m
.19421 0 L
s
.19739 0 m
.19863 0 L
.19939 0 L
.2001 0 L
.20139 0 L
.20277 0 L
.20419 0 L
.20494 0 L
s
.20494 0 m
.20533 0 L
s
.20941 0 m
.20984 0 L
.21123 0 L
.21253 0 L
.21373 0 L
.21483 0 L
.21603 0 L
.21728 0 L
.21846 0 L
.21913 0 L
.21985 0 L
.22112 0 L
s
.22112 0 m
.22201 0 L
s
.22941 0 m
.23023 0 L
.23144 0 L
.23276 0 L
.23399 0 L
.23538 0 L
.23669 0 L
.23787 0 L
.23914 0 L
.24146 0 L
.24273 0 L
.24392 0 L
.24602 0 L
.24833 0 L
.24965 0 L
.25105 0 L
.25225 0 L
.25357 0 L
.25491 0 L
.25558 0 L
.25632 0 L
.25712 0 L
.25786 0 L
.25859 0 L
.25928 0 L
.26063 0 L
.26187 0 L
.26319 0 L
.26394 0 L
.26463 0 L
.26579 0 L
.26707 0 L
.26966 0 L
.27451 0 L
.27718 0 L
.27972 0 L
.28086 0 L
.28207 0 L
.2834 0 L
.28464 0 L
.28585 0 L
.287 0 L
.28802 0 L
.28914 0 L
.29044 0 L
.29163 0 L
.293 0 L
.2943 0 L
.29664 0 L
.29792 0 L
Mistroke
.29912 0 L
.30042 0 L
.30111 0 L
.30185 0 L
.30316 0 L
.30437 0 L
.30715 0 L
.30868 0 L
.31008 0 L
.31144 0 L
.31272 0 L
Mfstroke
.31272 0 m
.31288 0 L
s
.32269 0 m
.32657 0 L
.32949 0 L
.33091 0 L
.3322 0 L
.33347 0 L
.33467 0 L
.33594 0 L
.33731 0 L
.33872 0 L
.33949 0 L
.34021 0 L
.34148 0 L
.34287 0 L
.34404 0 L
.34527 0 L
.34663 0 L
.34788 0 L
.34897 0 L
.35014 0 L
s
.35014 0 m
.35092 0 L
s
.3519 0 m
.35262 0 L
.35333 0 L
.35411 0 L
.35552 0 L
.35689 0 L
.35817 0 L
.35945 0 L
.36061 0 L
.36196 0 L
.36322 0 L
.36587 0 L
.3672 0 L
.36796 0 L
.36867 0 L
.36944 0 L
.37015 0 L
.37174 0 L
.37244 0 L
.37319 0 L
.37456 0 L
.37581 0 L
.37696 0 L
.37825 0 L
.3796 0 L
.38093 0 L
.38216 0 L
.38351 0 L
.38427 0 L
.38496 0 L
.38619 0 L
.38733 0 L
.38858 0 L
.38991 0 L
.39116 0 L
.39235 0 L
.39342 0 L
.39458 0 L
.39592 0 L
.39717 0 L
.39851 0 L
.39926 0 L
.39994 0 L
.40118 0 L
.40252 0 L
.40496 0 L
.40634 0 L
.40712 0 L
.40785 0 L
.40862 0 L
Mistroke
.40933 0 L
.41014 0 L
.41091 0 L
.41637 0 L
.42161 0 L
.42418 0 L
.4253 0 L
.42653 0 L
.42773 0 L
.42899 0 L
.43037 0 L
.43165 0 L
.43239 0 L
.43308 0 L
.43438 0 L
.4373 0 L
Mfstroke
.4373 0 m
.44162 0 L
s
.45642 0 m
.45665 0 L
.46201 0 L
.46502 0 L
.46779 0 L
.46896 0 L
.47022 0 L
.4716 0 L
.47289 0 L
.47358 0 L
.47433 0 L
.4757 0 L
.47826 0 L
s
.47826 0 m
.47961 0 L
s
.50041 0 m
.50891 0 L
.51156 0 L
.51301 0 L
.51436 0 L
.51551 0 L
.51674 0 L
.51811 0 L
.51936 0 L
.52056 0 L
.52167 0 L
.52418 0 L
.52875 0 L
.53129 0 L
s
.53129 0 m
.53247 0 L
s
.55693 0 m
.56009 0 L
.56244 0 L
.56373 0 L
.56496 0 L
.5661 0 L
.56735 0 L
.56848 0 L
.56953 0 L
.57073 0 L
.57183 0 L
.57428 0 L
.57558 0 L
.57698 0 L
.5783 0 L
.57952 0 L
.58074 0 L
.58206 0 L
s
.58206 0 m
.58322 0 L
s
.60836 0 m
.60969 0 L
.61252 0 L
.61408 0 L
.61484 0 L
.61555 0 L
.61692 0 L
.61765 0 L
.61842 0 L
.61966 0 L
.62103 0 L
.62336 0 L
.62464 0 L
.62582 0 L
.62711 0 L
.62779 0 L
.62852 0 L
.62981 0 L
.63099 0 L
.63238 0 L
.63389 0 L
s
.63389 0 m
.63514 0 L
s
.65266 0 m
.65267 0 L
.65333 0 L
.65406 0 L
.65482 0 L
.65553 0 L
.65629 0 L
.65699 0 L
.65857 0 L
s
.65857 0 m
.66165 0 L
s
.69327 0 m
.69451 0 L
.70003 0 L
.70161 0 L
.70239 0 L
.70311 0 L
.70445 0 L
.70515 0 L
.7059 0 L
.70713 0 L
.70846 0 L
.70971 0 L
.71085 0 L
.71345 0 L
.71482 0 L
.71627 0 L
.71749 0 L
.71884 0 L
.72006 0 L
.72121 0 L
.72239 0 L
.72346 0 L
.72473 0 L
.72588 0 L
.72722 0 L
.72865 0 L
.73122 0 L
s
.73122 0 m
.73362 0 L
s
.74406 0 m
.74516 0 L
.74766 0 L
.74886 0 L
.75014 0 L
.75136 0 L
.75247 0 L
.75371 0 L
.75506 0 L
.75575 0 L
.75648 0 L
.75779 0 L
.76069 0 L
.76343 0 L
.76592 0 L
s
.76592 0 m
.76643 0 L
s
.78625 0 m
.78789 0 L
.79855 0 L
.80109 0 L
.80248 0 L
.80377 0 L
.80488 0 L
.80606 0 L
.80738 0 L
.80857 0 L
.80994 0 L
.81071 0 L
.81143 0 L
.81413 0 L
.81698 0 L
.81777 0 L
.81861 0 L
.81934 0 L
.82013 0 L
.82143 0 L
.82278 0 L
.82521 0 L
.82656 0 L
.82801 0 L
.8306 0 L
.83584 0 L
.83711 0 L
.83848 0 L
.83926 0 L
.83998 0 L
.8407 0 L
.84138 0 L
.84211 0 L
.84289 0 L
.84355 0 L
.84429 0 L
.84745 0 L
.84887 0 L
.85037 0 L
.85165 0 L
.85238 0 L
.85305 0 L
.85436 0 L
.85508 0 L
.85576 0 L
.85698 0 L
.85829 0 L
.85897 0 L
.85972 0 L
.86124 0 L
Mistroke
.86396 0 L
.86651 0 L
.86794 0 L
.86925 0 L
.87048 0 L
.87181 0 L
.87306 0 L
.87421 0 L
.87549 0 L
.87684 0 L
.87797 0 L
.87922 0 L
.88198 0 L
.88455 0 L
.88948 0 L
.89191 0 L
.89297 0 L
.89415 0 L
.89543 0 L
.89678 0 L
.89749 0 L
.89826 0 L
.89965 0 L
.90092 0 L
.90226 0 L
.9034 0 L
.90465 0 L
.90747 0 L
.91049 0 L
.91333 0 L
.91591 0 L
.921 0 L
.92379 0 L
.92515 0 L
.92639 0 L
.92753 0 L
.92861 0 L
.92975 0 L
.931 0 L
.93227 0 L
.93362 0 L
.93606 0 L
.9389 0 L
.94196 0 L
.94337 0 L
.94486 0 L
.94613 0 L
.94684 0 L
.94752 0 L
.94888 0 L
Mistroke
.95011 0 L
.95144 0 L
.95219 0 L
.95289 0 L
.95404 0 L
.95532 0 L
.95665 0 L
.9579 0 L
.96825 0 L
.97076 0 L
.97215 0 L
.97345 0 L
.97419 0 L
.97499 0 L
.97572 0 L
.9764 0 L
.97773 0 L
.9784 0 L
.97913 0 L
.98043 0 L
.98167 0 L
.98398 0 L
.98918 0 L
.99155 0 L
.99406 0 L
.99621 0 L
.99858 0 L
1 0 L
Mfstroke
0 0 m
.00123 0 L
.00236 0 L
.00365 0 L
.00488 0 L
.00601 0 L
.00706 0 L
.00821 0 L
.00942 0 L
.01065 0 L
.01196 0 L
.0132 0 L
.01434 0 L
.01566 0 L
.01641 0 L
.01711 0 L
.01839 0 L
.01975 0 L
.02043 0 L
.02115 0 L
.02245 0 L
.02317 0 L
.02384 0 L
.02458 0 L
.02537 0 L
.02605 0 L
.02679 0 L
.02814 0 L
.02945 0 L
s
.02945 0 m
.02971 0 L
s
.03644 0 m
.03676 0 L
.03813 0 L
.03929 0 L
s
.03929 0 m
.0396 0 L
s
.04104 0 m
.04131 0 L
.042 0 L
s
.042 0 m
.04213 0 L
s
.04288 0 m
.04355 0 L
s
.04355 0 m
.04471 0 L
s
.0475 0 m
.0477 0 L
.04892 0 L
.04959 0 L
.05032 0 L
.05165 0 L
.05245 0 L
s
.05245 0 m
.0527 0 L
s
.05427 0 m
.05462 0 L
.05543 0 L
s
.05543 0 m
.05565 0 L
s
.05803 0 m
.05854 0 L
.05921 0 L
.06 0 L
s
.06 0 m
.06044 0 L
s
.0616 0 m
.06205 0 L
.0628 0 L
.06349 0 L
.07383 0 L
.07506 0 L
.07635 0 L
.07702 0 L
s
.07702 0 m
.07708 0 L
s
.07831 0 m
.07905 0 L
.0798 0 L
.08059 0 L
.08134 0 L
.08202 0 L
.08271 0 L
.08346 0 L
.08481 0 L
.08599 0 L
s
.08599 0 m
.08669 0 L
s
.08795 0 m
.08861 0 L
.08989 0 L
.09106 0 L
.09217 0 L
s
.09217 0 m
.09338 0 L
s
.09803 0 m
.09887 0 L
.10025 0 L
.10161 0 L
.1029 0 L
.10405 0 L
s
.10405 0 m
.10489 0 L
s
.10627 0 m
.10671 0 L
.10751 0 L
.10825 0 L
.10902 0 L
.10975 0 L
s
.10975 0 m
.11012 0 L
s
.11351 0 m
.11404 0 L
.11482 0 L
.11556 0 L
.11695 0 L
.11969 0 L
s
.11969 0 m
.12076 0 L
s
.12613 0 m
.12641 0 L
.12715 0 L
.12783 0 L
s
.12783 0 m
.12833 0 L
s
.1353 0 m
.1354 0 L
.13675 0 L
.13751 0 L
.1382 0 L
.13941 0 L
.14056 0 L
.14161 0 L
s
.14161 0 m
.14252 0 L
s
.14775 0 m
.14842 0 L
.14917 0 L
.15054 0 L
.15187 0 L
s
.15187 0 m
.15252 0 L
s
.16214 0 m
.16392 0 L
.16461 0 L
.16535 0 L
.16671 0 L
.16804 0 L
s
.16804 0 m
.16911 0 L
s
.17245 0 m
.17292 0 L
.17414 0 L
.17546 0 L
.1762 0 L
.17687 0 L
.17817 0 L
.1794 0 L
.18056 0 L
.18178 0 L
s
.18178 0 m
.18265 0 L
s
.19209 0 m
.19299 0 L
.19423 0 L
.19494 0 L
.19569 0 L
.19702 0 L
.19776 0 L
.19846 0 L
s
.19846 0 m
.19918 0 L
s
.20191 0 m
.20216 0 L
.20286 0 L
.20414 0 L
.20482 0 L
.20555 0 L
.2068 0 L
.20798 0 L
.20933 0 L
.21056 0 L
.21192 0 L
.21319 0 L
.21434 0 L
.21558 0 L
.21693 0 L
.21767 0 L
.21836 0 L
.21958 0 L
.22092 0 L
.22206 0 L
.2233 0 L
.22448 0 L
.22556 0 L
.22682 0 L
.22816 0 L
.22928 0 L
.23053 0 L
.23316 0 L
.23449 0 L
.23524 0 L
.23594 0 L
.23741 0 L
.23898 0 L
s
.23898 0 m
.24131 0 L
s
.24736 0 m
.2523 0 L
.25357 0 L
.25496 0 L
.25627 0 L
.25749 0 L
.25858 0 L
.25978 0 L
s
.25978 0 m
.2604 0 L
s
.27301 0 m
.27806 0 L
.2793 0 L
.28061 0 L
.28173 0 L
.28296 0 L
.28405 0 L
.28523 0 L
.28735 0 L
.28863 0 L
.28984 0 L
.29212 0 L
s
.29212 0 m
.2938 0 L
s
.31019 0 m
.31292 0 L
.31412 0 L
.31543 0 L
.31666 0 L
.3178 0 L
.31882 0 L
.31995 0 L
.32107 0 L
.32224 0 L
.32354 0 L
.32472 0 L
.32611 0 L
.3274 0 L
s
.3274 0 m
.32807 0 L
s
.34388 0 m
.3444 0 L
.3451 0 L
.34588 0 L
.34751 0 L
.34827 0 L
.349 0 L
.34968 0 L
.35043 0 L
.35173 0 L
.35247 0 L
.35325 0 L
.35465 0 L
s
.35465 0 m
.35549 0 L
s
.36144 0 m
.36218 0 L
.36472 0 L
.36541 0 L
.36617 0 L
.36753 0 L
.36886 0 L
.37009 0 L
.37141 0 L
.37287 0 L
.3736 0 L
.37439 0 L
.37513 0 L
.37581 0 L
s
.37581 0 m
.37979 0 L
s
.38938 0 m
.38955 0 L
.39078 0 L
.39341 0 L
.39583 0 L
.39865 0 L
.4017 0 L
.40434 0 L
.40506 0 L
.40584 0 L
.40658 0 L
.40725 0 L
.40848 0 L
.40983 0 L
.4111 0 L
.41229 0 L
.41762 0 L
s
.41762 0 m
.41905 0 L
s
.43657 0 m
.43919 0 L
.44412 0 L
.44682 0 L
.44814 0 L
.44935 0 L
.4504 0 L
.4515 0 L
.45261 0 L
.45381 0 L
.45505 0 L
.45637 0 L
s
.45637 0 m
.45845 0 L
s
.48003 0 m
.48117 0 L
.48373 0 L
.48642 0 L
.48937 0 L
.49068 0 L
.4914 0 L
.49208 0 L
.49341 0 L
.49462 0 L
.49575 0 L
.49698 0 L
.49977 0 L
s
.49977 0 m
.5015 0 L
s
.53328 0 m
.53817 0 L
.53954 0 L
.54029 0 L
.54101 0 L
.54239 0 L
.54365 0 L
.54489 0 L
.5462 0 L
.54856 0 L
.54978 0 L
.5511 0 L
.55255 0 L
.5539 0 L
.55665 0 L
.55804 0 L
s
.55804 0 m
.55846 0 L
s
.58352 0 m
.58413 0 L
.58682 0 L
.58823 0 L
.58972 0 L
.59103 0 L
.59177 0 L
.59247 0 L
.59368 0 L
.59499 0 L
.59727 0 L
.5997 0 L
.60097 0 L
.60169 0 L
.60236 0 L
.60355 0 L
.60482 0 L
.60633 0 L
.60791 0 L
s
.60791 0 m
.60887 0 L
s
.62545 0 m
.62558 0 L
.62686 0 L
.62821 0 L
.62948 0 L
.63086 0 L
.63163 0 L
.63234 0 L
s
.63234 0 m
.63396 0 L
s
.65882 0 m
.6633 0 L
.66636 0 L
.66786 0 L
.6686 0 L
.66926 0 L
.67056 0 L
.67195 0 L
.67268 0 L
.67346 0 L
.6742 0 L
.67488 0 L
.67733 0 L
.67863 0 L
s
.67863 0 m
.67999 0 L
s
.6931 0 m
.69528 0 L
.69789 0 L
.70073 0 L
.70222 0 L
.70295 0 L
.70362 0 L
.7044 0 L
.70524 0 L
.70595 0 L
.70671 0 L
.70806 0 L
.70932 0 L
.71219 0 L
.71483 0 L
.71614 0 L
.71734 0 L
.71843 0 L
.7196 0 L
.72088 0 L
.72205 0 L
.72468 0 L
s
.72468 0 m
.72709 0 L
s
.76054 0 m
.76117 0 L
.76248 0 L
.76721 0 L
.7696 0 L
.77096 0 L
.77221 0 L
.77358 0 L
.77428 0 L
.77505 0 L
.77644 0 L
.77774 0 L
.7802 0 L
.78278 0 L
.78414 0 L
s
.78414 0 m
.78422 0 L
s
.79405 0 m
.79413 0 L
.79669 0 L
.79903 0 L
.80155 0 L
.80288 0 L
.8043 0 L
.80562 0 L
.80683 0 L
.80804 0 L
.80918 0 L
.81034 0 L
.81141 0 L
.81381 0 L
.82502 0 L
.82784 0 L
s
.82784 0 m
.8297 0 L
s
.85707 0 m
.85741 0 L
.85811 0 L
.86079 0 L
.86362 0 L
.8666 0 L
.87203 0 L
.87327 0 L
.8746 0 L
.87583 0 L
.87698 0 L
.87814 0 L
.87942 0 L
.8807 0 L
.88207 0 L
.8833 0 L
.88459 0 L
.88691 0 L
.88957 0 L
s
.88957 0 m
.89136 0 L
s
.90981 0 m
.9119 0 L
.9168 0 L
.91948 0 L
.92238 0 L
.92371 0 L
.92512 0 L
.92632 0 L
.92763 0 L
.92892 0 L
.93009 0 L
.93144 0 L
.93271 0 L
.93389 0 L
.93499 0 L
.93746 0 L
.94011 0 L
.94297 0 L
.94428 0 L
.94566 0 L
.94684 0 L
.94814 0 L
.94949 0 L
.95024 0 L
.95093 0 L
.95227 0 L
.95353 0 L
.95948 0 L
.96475 0 L
.96969 0 L
s
.96969 0 m
.97039 0 L
s
.98182 0 m
.98541 0 L
.9866 0 L
.98788 0 L
.98929 0 L
.99059 0 L
.99179 0 L
.99309 0 L
.99545 0 L
.99657 0 L
.99775 0 L
.99987 0 L
1 0 L
s
0 0 m
.00123 0 L
.00236 0 L
.00365 0 L
.00488 0 L
.00601 0 L
.00706 0 L
.00821 0 L
.00942 0 L
.01065 0 L
.01196 0 L
s
.01196 0 m
.01201 0 L
s
.02971 0 m
.03067 0 L
.03184 0 L
.03295 0 L
.03416 0 L
.03547 0 L
s
.03547 0 m
.03642 0 L
s
.03956 0 m
.04057 0 L
s
.04057 0 m
.04104 0 L
s
.04228 0 m
.04275 0 L
s
.04275 0 m
.04291 0 L
s
.04465 0 m
.0449 0 L
.04566 0 L
.04637 0 L
s
.04637 0 m
.04748 0 L
s
.05268 0 m
.05321 0 L
.05389 0 L
s
.05389 0 m
.05427 0 L
s
.05567 0 m
.05627 0 L
.057 0 L
.05779 0 L
s
.05779 0 m
.05802 0 L
s
.06047 0 m
.06074 0 L
s
.06074 0 m
.06158 0 L
s
.06516 0 m
.06603 0 L
.06727 0 L
.06841 0 L
s
.06841 0 m
.06874 0 L
s
.06994 0 m
.07105 0 L
.07175 0 L
s
.07175 0 m
.07235 0 L
s
.07712 0 m
.07812 0 L
s
.07812 0 m
.0786 0 L
s
.08653 0 m
.08713 0 L
s
.08713 0 m
.08802 0 L
s
.09343 0 m
.094 0 L
.0953 0 L
.09669 0 L
.09787 0 L
s
.09787 0 m
.09804 0 L
s
.1049 0 m
.1053 0 L
s
.1053 0 m
.10617 0 L
s
.1102 0 m
.11073 0 L
.11204 0 L
.11273 0 L
.11348 0 L
s
.11348 0 m
.11358 0 L
s
.12073 0 m
.1213 0 L
.12262 0 L
.12387 0 L
.12502 0 L
s
.12502 0 m
.12616 0 L
s
.12841 0 m
.1287 0 L
.1298 0 L
.13103 0 L
.13237 0 L
.13305 0 L
.13378 0 L
.13508 0 L
s
.13508 0 m
.13528 0 L
s
.14246 0 m
.1431 0 L
.14439 0 L
.14576 0 L
.14653 0 L
.14723 0 L
s
.14723 0 m
.14782 0 L
s
.15235 0 m
.15435 0 L
.15508 0 L
.15587 0 L
.15661 0 L
.15728 0 L
.15855 0 L
.15992 0 L
.16121 0 L
.16241 0 L
s
.16241 0 m
.16255 0 L
s
.16908 0 m
.1692 0 L
.17047 0 L
.17183 0 L
.1726 0 L
s
.1726 0 m
.17261 0 L
s
.18255 0 m
.18261 0 L
.184 0 L
.18538 0 L
.18616 0 L
.1869 0 L
.18768 0 L
.18839 0 L
.18917 0 L
.18999 0 L
.19131 0 L
.19251 0 L
s
.19251 0 m
.19262 0 L
s
.1989 0 m
.20006 0 L
.20138 0 L
.20261 0 L
s
.20261 0 m
.20272 0 L
s
.23931 0 m
.24151 0 L
.24281 0 L
.24354 0 L
.24422 0 L
.24546 0 L
.24679 0 L
s
.24679 0 m
.24812 0 L
s
.26045 0 m
.26142 0 L
.26278 0 L
.26427 0 L
.26558 0 L
.26696 0 L
.26821 0 L
.26959 0 L
.27084 0 L
.27201 0 L
s
.27201 0 m
.27313 0 L
s
.29346 0 m
.29613 0 L
.29755 0 L
.2989 0 L
.3001 0 L
.30142 0 L
.30256 0 L
.30382 0 L
.30638 0 L
.30861 0 L
.30974 0 L
.31096 0 L
s
.31096 0 m
.31097 0 L
s
.32797 0 m
.32851 0 L
.32998 0 L
.33126 0 L
.33199 0 L
.33266 0 L
.33402 0 L
.33471 0 L
.33545 0 L
.33679 0 L
.33801 0 L
.3387 0 L
.33944 0 L
.34024 0 L
.34098 0 L
.34232 0 L
.34308 0 L
.34379 0 L
.34514 0 L
s
.34514 0 m
.34527 0 L
s
.35411 0 m
.35426 0 L
.35549 0 L
.35664 0 L
.35783 0 L
.35915 0 L
.36028 0 L
.36132 0 L
s
.36132 0 m
.36223 0 L
s
.37912 0 m
.38014 0 L
.38133 0 L
.38265 0 L
.38385 0 L
.38515 0 L
.38587 0 L
.38655 0 L
.38776 0 L
.38908 0 L
s
.38908 0 m
.38958 0 L
s
.41928 0 m
.41931 0 L
.42181 0 L
.42456 0 L
.42589 0 L
.42713 0 L
.42844 0 L
.42913 0 L
.42987 0 L
.43065 0 L
.43138 0 L
.43276 0 L
s
.43276 0 m
.43657 0 L
s
.45844 0 m
.46254 0 L
.46519 0 L
.4681 0 L
.46963 0 L
.47046 0 L
.47126 0 L
.472 0 L
.4728 0 L
.47353 0 L
.4742 0 L
.4755 0 L
.47692 0 L
.4798 0 L
s
.4798 0 m
.48007 0 L
s
.5014 0 m
.51054 0 L
.51329 0 L
.51464 0 L
.51589 0 L
.51702 0 L
.51822 0 L
.51943 0 L
.52076 0 L
.53198 0 L
s
.53198 0 m
.53311 0 L
s
.55701 0 m
.56277 0 L
.56402 0 L
.56521 0 L
.56658 0 L
.56783 0 L
.56921 0 L
.56999 0 L
.57071 0 L
.57341 0 L
.57488 0 L
.57627 0 L
.57751 0 L
.57886 0 L
s
.57886 0 m
.58333 0 L
s
.60887 0 m
.60964 0 L
.61111 0 L
.6126 0 L
.61419 0 L
.61495 0 L
.61568 0 L
.61703 0 L
.61832 0 L
.6197 0 L
.62087 0 L
.62217 0 L
.62346 0 L
s
.62346 0 m
.62477 0 L
s
.63399 0 m
.6355 0 L
.63835 0 L
.63959 0 L
.64076 0 L
.64212 0 L
.64336 0 L
.64453 0 L
.64561 0 L
.64679 0 L
.64806 0 L
.64944 0 L
.6509 0 L
.65166 0 L
.6525 0 L
.65397 0 L
.65666 0 L
.65817 0 L
s
.65817 0 m
.65928 0 L
s
.6798 0 m
.68009 0 L
.68138 0 L
.68205 0 L
.68277 0 L
.68409 0 L
.6853 0 L
.68667 0 L
.68795 0 L
.68868 0 L
.68935 0 L
.69086 0 L
s
.69086 0 m
.69254 0 L
s
.72609 0 m
.73019 0 L
.73297 0 L
.73561 0 L
.73631 0 L
.73706 0 L
.73789 0 L
.73865 0 L
.7394 0 L
.74011 0 L
.74144 0 L
.74272 0 L
.74407 0 L
.7465 0 L
.74784 0 L
.74931 0 L
.75069 0 L
.75197 0 L
.75317 0 L
.75449 0 L
.75587 0 L
.75717 0 L
.75948 0 L
.76064 0 L
s
.76064 0 m
.76109 0 L
s
.78254 0 m
.78259 0 L
.78371 0 L
.7849 0 L
.78622 0 L
.78741 0 L
.78851 0 L
.78969 0 L
.7908 0 L
.79182 0 L
s
.79182 0 m
.79419 0 L
s
.82726 0 m
.83332 0 L
.83592 0 L
.83734 0 L
.83868 0 L
.83994 0 L
.84129 0 L
.84253 0 L
.84367 0 L
.84487 0 L
.84619 0 L
.84886 0 L
.85028 0 L
.8518 0 L
.85254 0 L
.85323 0 L
.85454 0 L
.85566 0 L
.85688 0 L
.85817 0 L
.85937 0 L
.86155 0 L
s
.86155 0 m
.86329 0 L
s
.88897 0 m
.88909 0 L
.89179 0 L
.89327 0 L
.89467 0 L
.89596 0 L
.89669 0 L
.89736 0 L
.89854 0 L
.8998 0 L
.90097 0 L
.90206 0 L
.90326 0 L
.90455 0 L
.90708 0 L
.90947 0 L
s
.90947 0 m
.9115 0 L
s
.95729 0 m
.96413 0 L
.96935 0 L
.97078 0 L
.97156 0 L
.97231 0 L
.973 0 L
.97375 0 L
.97507 0 L
.97636 0 L
.97709 0 L
.97778 0 L
.97916 0 L
.98065 0 L
.98312 0 L
.98582 0 L
.98731 0 L
.9887 0 L
.98947 0 L
.99017 0 L
.99098 0 L
.99174 0 L
.99309 0 L
.99434 0 L
.9958 0 L
.99716 0 L
.99851 0 L
1 0 L
s
0 0 m
.00123 0 L
.00236 0 L
.00365 0 L
.00488 0 L
.00601 0 L
.00706 0 L
.00821 0 L
.00942 0 L
.01065 0 L
.01196 0 L
.0132 0 L
.01434 0 L
.01566 0 L
.01641 0 L
.01711 0 L
.01839 0 L
.01975 0 L
.02043 0 L
.02115 0 L
.02245 0 L
.02317 0 L
.02384 0 L
.02458 0 L
.02537 0 L
.02605 0 L
.02679 0 L
.02814 0 L
.02945 0 L
s
.02945 0 m
.02972 0 L
s
.03641 0 m
.03676 0 L
.03813 0 L
.03929 0 L
s
.03929 0 m
.03953 0 L
s
.04103 0 m
.04131 0 L
.042 0 L
s
.042 0 m
.04233 0 L
s
.04293 0 m
.04355 0 L
s
.04355 0 m
.04462 0 L
s
.04746 0 m
.0477 0 L
.04892 0 L
.04959 0 L
.05032 0 L
.05165 0 L
.05245 0 L
s
.05245 0 m
.05266 0 L
s
.05428 0 m
.05462 0 L
.05543 0 L
s
.05543 0 m
.05569 0 L
s
.05801 0 m
.05854 0 L
.05921 0 L
.06 0 L
s
.06 0 m
.0605 0 L
s
.06157 0 m
.06205 0 L
.0628 0 L
.06349 0 L
.06471 0 L
s
.06471 0 m
.06515 0 L
s
.06879 0 m
.06967 0 L
s
.06967 0 m
.07001 0 L
s
.07234 0 m
.07249 0 L
.07383 0 L
.07457 0 L
.07525 0 L
.076 0 L
.07679 0 L
s
.07679 0 m
.07709 0 L
s
.07863 0 m
.07888 0 L
.07959 0 L
.0809 0 L
.08211 0 L
.08349 0 L
.08481 0 L
.08603 0 L
s
.08603 0 m
.08652 0 L
s
.08814 0 m
.08873 0 L
.09003 0 L
.09125 0 L
.09256 0 L
s
.09256 0 m
.09347 0 L
s
.09801 0 m
.09885 0 L
.10004 0 L
.10135 0 L
.10209 0 L
.10278 0 L
.1035 0 L
.10418 0 L
s
.10418 0 m
.1045 0 L
s
.10617 0 m
.10691 0 L
.10801 0 L
.10928 0 L
s
.10928 0 m
.1102 0 L
s
.11356 0 m
.11375 0 L
.11493 0 L
.11613 0 L
.11742 0 L
.11974 0 L
.12042 0 L
s
.12042 0 m
.1208 0 L
s
.12622 0 m
.12626 0 L
.12756 0 L
s
.12756 0 m
.12866 0 L
s
.1287 0 m
.12989 0 L
s
.12989 0 m
.12999 0 L
s
.13529 0 m
.13629 0 L
.13751 0 L
.13855 0 L
.1397 0 L
.14093 0 L
.14225 0 L
s
.14225 0 m
.14249 0 L
s
.14785 0 m
.14872 0 L
.14995 0 L
.15065 0 L
.15138 0 L
.15212 0 L
s
.15212 0 m
.15255 0 L
s
.16253 0 m
.16366 0 L
.16501 0 L
.16627 0 L
.16753 0 L
.16888 0 L
s
.16888 0 m
.16917 0 L
s
.17253 0 m
.17302 0 L
.17421 0 L
.17552 0 L
.17691 0 L
.17807 0 L
.17931 0 L
.18038 0 L
.18155 0 L
s
.18155 0 m
.18252 0 L
s
.19228 0 m
.19435 0 L
.19508 0 L
.19586 0 L
.1966 0 L
.19727 0 L
.19863 0 L
s
.19863 0 m
.19902 0 L
s
.20249 0 m
.20277 0 L
.20419 0 L
.20494 0 L
.20574 0 L
.20651 0 L
.2072 0 L
.20856 0 L
.21373 0 L
.21493 0 L
.2162 0 L
.21737 0 L
.21846 0 L
.21972 0 L
.2211 0 L
.22259 0 L
.22394 0 L
.22522 0 L
.22644 0 L
.2277 0 L
.22838 0 L
.2291 0 L
.2303 0 L
.23143 0 L
.23271 0 L
.23389 0 L
.23605 0 L
.23832 0 L
s
.23832 0 m
.23891 0 L
s
.24825 0 m
.24833 0 L
.25344 0 L
.25417 0 L
.25485 0 L
.25555 0 L
.25634 0 L
.25762 0 L
.25835 0 L
.25901 0 L
s
.25901 0 m
.26045 0 L
s
.27314 0 m
.27394 0 L
.27611 0 L
.2772 0 L
.2784 0 L
.27964 0 L
.28083 0 L
.28219 0 L
.28344 0 L
.28461 0 L
.28569 0 L
.28697 0 L
.28815 0 L
.28944 0 L
.29011 0 L
.29083 0 L
.29335 0 L
s
.29335 0 m
.29385 0 L
s
.31095 0 m
.31125 0 L
.31273 0 L
.31409 0 L
.31528 0 L
.31655 0 L
.31729 0 L
.31795 0 L
.31925 0 L
.3205 0 L
.32183 0 L
.32252 0 L
.32328 0 L
.32462 0 L
.3262 0 L
.32697 0 L
.32767 0 L
s
.32767 0 m
.32802 0 L
s
.34491 0 m
.34589 0 L
.34713 0 L
.34828 0 L
.34937 0 L
.35053 0 L
.35188 0 L
.35311 0 L
s
.35311 0 m
.35384 0 L
s
.36217 0 m
.36236 0 L
.36371 0 L
.36517 0 L
.36594 0 L
.36677 0 L
.3675 0 L
.36816 0 L
.36946 0 L
.37016 0 L
.37092 0 L
.37231 0 L
.37358 0 L
.37475 0 L
.37604 0 L
.37739 0 L
.37857 0 L
s
.37857 0 m
.37928 0 L
s
.38953 0 m
.39055 0 L
.39305 0 L
.39588 0 L
.39896 0 L
.40168 0 L
.40317 0 L
.40457 0 L
.40595 0 L
.40672 0 L
.40744 0 L
.4087 0 L
.41004 0 L
.41129 0 L
.41245 0 L
.4151 0 L
.41766 0 L
s
.41766 0 m
.41931 0 L
s
.43654 0 m
.44138 0 L
.44411 0 L
.4466 0 L
.44772 0 L
.44892 0 L
.45022 0 L
.45143 0 L
.45255 0 L
.4536 0 L
.45475 0 L
.45599 0 L
s
.45599 0 m
.45812 0 L
s
.47976 0 m
.48844 0 L
.48985 0 L
.49059 0 L
.49138 0 L
.49207 0 L
.49282 0 L
.49416 0 L
.49545 0 L
.49618 0 L
.49684 0 L
.49936 0 L
s
.49936 0 m
.50124 0 L
s
.53332 0 m
.53559 0 L
.53825 0 L
.5397 0 L
.54105 0 L
.54223 0 L
.5435 0 L
.54422 0 L
.5449 0 L
.54618 0 L
.55088 0 L
.55356 0 L
.55503 0 L
.5564 0 L
s
.5564 0 m
.5585 0 L
s
.58368 0 m
.58581 0 L
.5884 0 L
.58975 0 L
.59047 0 L
.59123 0 L
.59258 0 L
.59384 0 L
.59501 0 L
.5963 0 L
.59856 0 L
.59978 0 L
.60092 0 L
.60228 0 L
.603 0 L
.60376 0 L
.60512 0 L
.60636 0 L
.60781 0 L
.60862 0 L
s
.60862 0 m
.60891 0 L
s
.62455 0 m
.62524 0 L
.62662 0 L
.62788 0 L
.62906 0 L
.63015 0 L
.63136 0 L
.63265 0 L
s
.63265 0 m
.63398 0 L
s
.65929 0 m
.66047 0 L
.66311 0 L
.66558 0 L
.66691 0 L
.66763 0 L
.66831 0 L
.66952 0 L
.67084 0 L
.67154 0 L
.67228 0 L
.6736 0 L
.67433 0 L
.67501 0 L
.67656 0 L
.67915 0 L
s
.67915 0 m
.67973 0 L
s
.69315 0 m
.69431 0 L
.69703 0 L
.69924 0 L
.70156 0 L
.70278 0 L
.70411 0 L
.70532 0 L
.70645 0 L
.70718 0 L
.70787 0 L
.70916 0 L
.71205 0 L
.71479 0 L
.71599 0 L
.71732 0 L
.7185 0 L
.71961 0 L
.72078 0 L
.72204 0 L
.72469 0 L
s
.72469 0 m
.72716 0 L
s
.76094 0 m
.76218 0 L
.76466 0 L
.76706 0 L
.76833 0 L
.76967 0 L
.77038 0 L
.77116 0 L
.77253 0 L
.7732 0 L
.77392 0 L
.77523 0 L
.77658 0 L
.77787 0 L
.78028 0 L
.78165 0 L
s
.78165 0 m
.78223 0 L
s
.7949 0 m
.79689 0 L
.79987 0 L
.80262 0 L
.80385 0 L
.80517 0 L
.80642 0 L
.80757 0 L
.80884 0 L
.81023 0 L
.81093 0 L
.81168 0 L
.81302 0 L
.82324 0 L
s
.82324 0 m
.82773 0 L
s
.8626 0 m
.86307 0 L
.86467 0 L
.86615 0 L
.86907 0 L
.87193 0 L
.87317 0 L
.87454 0 L
.87584 0 L
.87704 0 L
.8782 0 L
.87943 0 L
.88011 0 L
.88085 0 L
.88219 0 L
.88349 0 L
.88469 0 L
s
.88469 0 m
.8889 0 L
s
.91144 0 m
.9129 0 L
.91586 0 L
.92101 0 L
.92355 0 L
.92466 0 L
.92588 0 L
.92719 0 L
.92857 0 L
.9293 0 L
.93008 0 L
.93082 0 L
.93149 0 L
.93274 0 L
.93411 0 L
.93659 0 L
.94144 0 L
.94283 0 L
.94414 0 L
.94534 0 L
.9466 0 L
.9477 0 L
.94892 0 L
.95003 0 L
.95106 0 L
.95227 0 L
.95338 0 L
.95466 0 L
.95587 0 L
s
.95587 0 m
.95971 0 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[19]:=",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/B000`400?l00000o`00003oo`3ooolQ
0?ooo`00AP3oool500000340oooo0`00000`0?ooo`<00000<03oool3000002h0oooo0`0000040?oo
o`800000103oool004L0oooo00@000000?ooo`3oool00000<P3oool00`000000oooo0?ooo`0^0?oo
o`050000003oool0oooo0?ooo`000000;P3oool01@000000oooo0?ooo`3oool0000002h0oooo00<0
00000?ooo`3oool00P3oool010000000oooo0?ooo`0000030?ooo`00B03oool00`000000oooo0?oo
o`0_0?ooo`D00000;`3oool01@000000oooo0?ooo`3oool0000002h0oooo00D000000?ooo`3oool0
oooo0000000^0?ooo`030000003oool0oooo0080oooo00@000000?ooo`3oool000000`3oool004T0
oooo00<000000?ooo`3oool0;P3oool010000000oooo0?ooo`00000`0?ooo`@00000<03oool30000
02l0oooo00<000000?ooo`3oool00P3oool010000000oooo0?ooo`0000030?ooo`00AP3oool01@00
0000oooo0?ooo`3oool000000300oooo00<000000?ooo`000000<03oool00`000000oooo0?ooo`0`
0?ooo`050000003oool0oooo0?ooo`000000;P3oool00`000000oooo0?ooo`020?ooo`040000003o
ool0oooo000000<0oooo00160?ooo`050000003oool0oooo0?ooo`000000<@3oool200000340oooo
00<000000?ooo`3oool0;`3oool01@000000oooo0?ooo`3oool0000002d0oooo0P0000040?ooo`04
0000003oool0oooo000000<0oooo00170?ooo`<00000<`3oool00`000000oooo0?ooo`0`0?ooo`80
0000<03oool3000002l0oooo00<000000?ooo`3oool00`3oool2000000@0oooo003o0?ooob40oooo
003o0?ooob40oooo003o0?ooob40oooo003o0?ooob40oooo000E0?ooool000001@0000070?ooo`00
5@3oool00`000000oooo000000030?ooo`D000000P3oool00`000000oooo00000004000000H0oooo
00<000000?ooo`3oool06000000<0?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool0
2P3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool0
2P3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool0
2P3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool0
2P3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool0
2P3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo00D0oooo000E0?ooo`040000003o
ool0oooo000000L0oooo0P0000070?ooo`T000005`3oooo@000000L0oooo000E0?ooo`050000003o
ool0oooo0?ooo`000000203oool2000000h0oooo2000003V0?ooo`005@3oool2000000<0oooo0P00
00080?ooo`<000004`3oool600000>00oooo000E0?ooo`8000001@3oool00`000000oooo0?ooo`08
0?ooo`8000005`3ooolE00000</0oooo000E0?ooo`8000001P3oool00`000000oooo0?ooo`090?oo
o`800000:P3oooo4000000L0oooo000E0?ooo`8000001`3oool00`000000oooo0?ooo`0:0?ooo`<0
0000lP3oool001D0oooo0P0000080?ooo`030000003oool0oooo00`0oooo0`00003_0?ooo`005@3o
ool2000000T0oooo00<000000?ooo`3oool03P3oool400000>/0oooo000E0?ooo`030000003oool0
000000T0oooo00<000000?ooo`3oool04@3oool500000>H0oooo000E0?ooo`030000003oool00000
00X0oooo00<000000?ooo`3oool05@3oool500000>40oooo000E0?ooo`030000003oool0000000/0
oooo00<000000?ooo`3oool06@3oool500000=`0oooo000E0?ooo`030000003oool0000000`0oooo
00<000000?ooo`3oool07@3oool600000=H0oooo000E0?ooo`030000003oool0000000d0oooo0P00
000S0?ooo`/00000b`3oool001D0oooo00@000000?ooo`3oool000003P3oool00`000000oooo0?oo
o`0[0?ooo`l00000_03oool001D0oooo0P0000000`3oool000000?ooo`0>0?ooo`030000003oool0
oooo03T0ooooHP00001J0?ooo`005@3oool010000000oooo0?ooo`00000@0?ooo`030000003oool0
oooo09X0ooooD`0000070?ooo`005@3oool01@000000oooo0?ooo`3oool000000100oooo00<00000
0?ooo`3oool0l`3oool001D0oooo00D000000?ooo`3oool0oooo0000000A0?ooo`800000l`3oool0
01D0oooo00D000000?ooo`3oool0oooo0000000C0?ooo`800000l@3oool001D0oooo00<000000?oo
o`3oool00P3oool00`000000oooo0?ooo`0B0?ooo`800000k`3oool001D0oooo00<000000?ooo`3o
ool00P3oool00`000000oooo0?ooo`0D0?ooo`800000k@3oool001D0oooo00<000000?ooo`3oool0
0P3oool00`000000oooo0?ooo`0F0?ooo`<00000jP3oool001D0oooo0P0000040?ooo`030000003o
ool0oooo01P0oooo0P00003X0?ooo`005@3oool00`000000oooo0?ooo`030?ooo`030000003oool0
oooo01X0oooo0`00003U0?ooo`005@3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo
01`0oooo1000003Q0?ooo`005@3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo0200
oooo1000003M0?ooo`005@3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo02@0oooo
0`00003J0?ooo`000P3oool2000000@0oooo00@000000?ooo`3oool0oooo1@0000040?ooo`030000
003oool0oooo00D0oooo00<000000?ooo`3oool09P3oool400000=H0oooo00001@3oool000000?oo
o`3oool0000000P0oooo00@000000?ooo`3oool00000103oool00`000000oooo0?ooo`050?ooo`03
0000003oool0oooo02X0oooo2`00003;0?ooo`0000D0oooo0000003oool0oooo000000090?ooo`03
0000003oool0oooo00@0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`0d0?ooo`P0
0000``3oool000050?ooo`000000oooo0?ooo`0000002P3oool00`000000oooo0?ooo`030?ooo`<0
00001`3oool00`000000oooo0?ooo`0k0?oooa<00000/03oool000050?ooo`000000oooo0?ooo`00
00001`3oool01@000000oooo0?ooo`3oool0000000@0oooo00<000000?ooo`3oool01`3oool00`00
0000oooo0?ooo`1>0?ooojT000001`3oool000050?ooo`000000oooo0?ooo`0000001`3oool01@00
0000oooo0?ooo`3oool0000000@0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`3m
0?ooo`000P3oool2000000T0oooo0`0000050?ooo`030000003oool0oooo00P0oooo00<000000?oo
o`3oool0o@3oool001D0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`3l0?ooo`00
5@3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo0?/0oooo000E0?ooo`030000003o
ool0oooo00/0oooo0P00003k0?ooo`005@3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0
oooo0?P0oooo000E0?ooo`8000003`3oool00`000000oooo0?ooo`3g0?ooo`005@3oool00`000000
oooo0?ooo`0?0?ooo`030000003oool0oooo0?H0oooo000E0?ooo`030000003oool0oooo0100oooo
0P00003f0?ooo`005@3oool00`000000oooo0?ooo`0B0?ooo`030000003oool0oooo0?<0oooo000E
0?ooo`030000003oool0oooo01<0oooo0`00003b0?ooo`005@3oool00`000000oooo0?ooo`0F0?oo
o`800000l03oool001D0oooo00<000000?ooo`3oool0603oool600000>X0oooo000E0?ooo`030000
003oool0oooo01h0oooo1P00003T0?ooo`005@3oool2000002D0oooo2@00003K0?ooo`005@3oool0
0`000000oooo0?ooo`0]0?oooaX00000`@3oool001D0oooo00<000000?ooo`3oool0A`3ooonj0000
00L0oooo000E0?ooo`030000003oool0oooo05d0oooo6`00002@0?ooo`005@3oool00`000000oooo
0?ooo`1A0?ooo``00000Z`3oool001D0oooo00<000000?ooo`3oool0C03oool500000;L0oooo000E
0?ooo`030000003oool0oooo04L0oooo1@00002l0?ooo`005@3oool00`000000oooo0?ooo`120?oo
o`D00000`@3oool001D0oooo0P00000m0?ooo`H00000aP3oool001D0oooo00<000000?ooo`3oool0
>03oool400000<`0oooo000E0?ooo`030000003oool0oooo03D0oooo0`00003@0?ooo`005@3oool0
0`000000oooo0?ooo`0c0?ooo`800000d`3oool001D0oooo00<000000?ooo`3oool0<@3oool20000
0=D0oooo00020?ooo`800000103oool00`000000oooo0?ooo`030?ooo`<00000103oool00`000000
oooo0?ooo`0^0?ooo`<00000e`3oool000050?ooo`000000oooo0?ooo`0000002P3oool00`000000
oooo0?ooo`030?ooo`030000003oool0oooo02`0oooo0P00003J0?ooo`0000D0oooo0000003oool0
oooo000000070?ooo`D00000103oool00`000000oooo0?ooo`0Z0?ooo`800000g03oool000050?oo
o`000000oooo0?ooo`0000001`3oool010000000oooo0?ooo`0000050?ooo`<00000:03oool20000
0=h0oooo00001@3oool000000?ooo`3oool0000000P0oooo00<000000?ooo`0000001@3oool00`00
0000oooo0?ooo`0W0?ooo`030000003oool0oooo0=h0oooo00001@3oool000000?ooo`3oool00000
00T0oooo0P0000050?ooo`030000003oool0oooo02H0oooo00<000000?ooo`3oool0g`3oool00080
oooo0P00000;0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool09@3oool00`000000
oooo0?ooo`3P0?ooo`005@3oool00`000000oooo0?ooo`0S0?ooo`800000h`3oool001D0oooo00<0
00000?ooo`3oool08P3oool00`000000oooo0?ooo`3S0?ooo`005@3oool00`000000oooo0?ooo`0Q
0?ooo`030000003oool0oooo0>@0oooo000E0?ooo`030000003oool0oooo0200oooo00<000000?oo
o`3oool0i@3oool001D0oooo0P00000P0?ooo`030000003oool0oooo0>H0oooo000E0?ooo`030000
003oool0oooo01h0oooo00<000000?ooo`3oool0i`3oool001D0oooo00<000000?ooo`3oool07P3o
ool00`000000oooo0?ooo`3W0?ooo`005@3oool00`000000oooo0?ooo`0M0?ooo`030000003oool0
oooo0>P0oooo000E0?ooo`030000003oool0oooo01`0oooo00<000000?ooo`3oool0j@3oool001D0
oooo00<000000?ooo`3oool06`3oool00`000000oooo0?ooo`3Z0?ooo`005@3oool00`000000oooo
0?ooo`0J0?ooo`030000003oool0oooo0>/0oooo000E0?ooo`030000003oool0oooo01T0oooo00<0
00000?ooo`3oool0k03oool001D0oooo0P00000I0?ooo`030000003oool0oooo0>d0oooo000E0?oo
o`030000003oool0oooo01P0oooo00<000000?ooo`3oool0k@3oool001D0oooo00<000000?ooo`3o
ool05`3oool00`000000oooo0?ooo`3^0?ooo`005@3oool00`000000oooo0?ooo`0F0?ooo`030000
003oool0oooo0>l0oooo000E0?ooo`030000003oool0oooo01H0oooo00<000000?ooo`3oool0k`3o
ool001D0oooo00<000000?ooo`3oool05@3oool00`000000oooo0?ooo`3`0?ooo`005@3oool00`00
0000oooo0?ooo`0E0?ooo`030000003oool0oooo0?00oooo000E0?ooo`030000003oool0oooo01@0
oooo00<000000?ooo`3oool0l@3oool001D0oooo0P00000D0?ooo`030000003oool0oooo0?80oooo
000E0?ooo`030000003oool0oooo01<0oooo00<000000?ooo`3oool0lP3oool001D0oooo00<00000
0?ooo`3oool04P3oool00`000000oooo0?ooo`3c0?ooo`005@3oool00`000000oooo0?ooo`0B0?oo
o`030000003oool0oooo0?<0oooo000E0?ooo`030000003oool0oooo0140oooo00<000000?ooo`3o
ool0m03oool00080oooo0P0000040?ooo`030000003oool0oooo0080oooo0`0000050?ooo`030000
003oool0oooo0140oooo00<000000?ooo`3oool0m03oool000050?ooo`000000oooo0?ooo`000000
1`3oool01@000000oooo0?ooo`3oool0000000@0oooo00<000000?ooo`3oool0403oool00`000000
oooo0?ooo`3e0?ooo`0000D0oooo0000003oool0oooo000000070?ooo`050000003oool0oooo0?oo
o`000000103oool00`000000oooo0?ooo`0?0?ooo`030000003oool0oooo0?H0oooo00001@3oool0
00000?ooo`3oool0000000L0oooo100000050?ooo`<000003`3oool00`000000oooo0?ooo`3f0?oo
o`0000D0oooo0000003oool0oooo000000070?ooo`030000003oool0oooo00H0oooo00<000000?oo
o`3oool03P3oool00`000000oooo0?ooo`3g0?ooo`0000D0oooo0000003oool0oooo000000080?oo
o`030000003oool0oooo00D0oooo00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`3g0?oo
o`000P3oool2000000X0oooo0P0000050?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3o
ool0n03oool001D0oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`3h0?ooo`005@3o
ool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo0?T0oooo000E0?ooo`030000003oool0
oooo00`0oooo00<000000?ooo`3oool0n@3oool001D0oooo00<000000?ooo`3oool0303oool00`00
0000oooo0?ooo`3i0?ooo`005@3oool2000000`0oooo00<000000?ooo`3oool0nP3oool001D0oooo
00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`3j0?ooo`005@3oool00`000000oooo0?oo
o`0;0?ooo`030000003oool0oooo0?X0oooo000E0?ooo`030000003oool0oooo00X0oooo00<00000
0?ooo`3oool0n`3oool001D0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`3k0?oo
o`005@3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo0?/0oooo000E0?ooo`030000
003oool0oooo00T0oooo00<000000?ooo`3oool0o03oool001D0oooo00<000000?ooo`3oool02@3o
ool00`000000oooo0?ooo`3l0?ooo`005@3oool2000000X0oooo00<000000?ooo`3oool0o03oool0
01D0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`3m0?ooo`005@3oool00`000000
oooo0?ooo`080?ooo`030000003oool0oooo0?d0oooo000E0?ooo`030000003oool0oooo00P0oooo
00<000000?ooo`3oool0o@3oool001D0oooo00<000000?ooo`3oool0203oool00`000000oooo0?oo
o`3m0?ooo`005@3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo0?h0oooo000E0?oo
o`030000003oool0oooo00L0oooo00<000000?ooo`3oool0oP3oool001D0oooo00<000000?ooo`3o
ool01`3oool00`000000oooo0?ooo`3n0?ooo`005@3oool2000000L0oooo00<000000?ooo`3oool0
o`3oool001D0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`3o0?ooo`005@3oool0
0`000000oooo0?ooo`060?ooo`030000003oool0oooo0?l0oooo000E0?ooo`030000003oool0oooo
00D0oooo00<000000?ooo`3oool0o`3oool10?ooo`005@3oool00`000000oooo0?ooo`050?ooo`03
0000003oool0oooo0?l0oooo0@3oool00080oooo0P0000040?ooo`030000003oool0oooo0080oooo
0`0000050?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool0o`3oool10?ooo`0000D0
oooo0000003oool0oooo000000070?ooo`050000003oool0oooo0?ooo`000000103oool00`000000
oooo0?ooo`050?ooo`030000003oool0oooo0?l0oooo0@3oool000050?ooo`000000oooo0?ooo`00
00001`3oool01@000000oooo0?ooo`3oool0000000@0oooo00<000000?ooo`3oool0103oool00`00
0000oooo0?ooo`3o0?ooo`80oooo00001@3oool000000?ooo`3oool0000000P0oooo0`0000050?oo
o`<00000103oool00`000000oooo0?ooo`3o0?ooo`80oooo00001@3oool000000?ooo`3oool00000
00L0oooo00D000000?ooo`3oool0oooo000000040?ooo`030000003oool0oooo00@0oooo00<00000
0?ooo`3oool0o`3oool20?ooo`0000D0oooo0000003oool0oooo000000070?ooo`050000003oool0
oooo0?ooo`000000103oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo0?l0oooo0`3o
ool00080oooo0P0000090?ooo`<000001@3oool00`000000oooo0?ooo`030?ooo`030000003oool0
oooo0?l0oooo0`3oool001D0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`3o0?oo
o`<0oooo000E0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0o`3oool40?ooo`00
5@3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0?l0oooo103oool001D0oooo00<0
00000?ooo`3oool00P3oool00`000000oooo0?ooo`3o0?ooo`@0oooo000E0?ooo`8000000`3oool0
0`000000oooo0?ooo`3o0?ooo`@0oooo000E0?ooo`030000003oool0oooo0080oooo00<000000?oo
o`3oool0o`3oool40?ooo`005@3oool01@000000oooo0?ooo`3oool000000?l0oooo1`3oool001D0
oooo00D000000?ooo`3oool0oooo0000003o0?ooo`L0oooo000E0?ooo`050000003oool0oooo0?oo
o`000000o`3oool70?ooo`005@3oool01@000000oooo0?ooo`3oool000000?l0oooo1`3oool001D0
oooo00D000000?ooo`3oool0oooo0000003o0?ooo`L0oooo000E0?ooo`040000003oool0oooo0000
0?l0oooo203oool001D0oooo0P0000000`3oool000000?ooo`3o0?ooo`L0oooo000E0?ooo`040000
003oool0oooo00000?l0oooo203oool001D0oooo00@000000?ooo`3oool00000o`3oool80?ooo`00
5@3oool010000000oooo0?ooo`00003o0?ooo`P0oooo000E0?ooo`030000003oool000000?l0oooo
2@3oool001D0oooo00<000000?ooo`000000o`3oool90?ooo`005@3oool00`000000oooo0000003o
0?ooo`T0oooo000E0?ooo`030000003oool000000?l0oooo2@3oool001D0oooo0`00003o0?ooo`T0
oooo000E0?ooo`800000o`3oool:0?ooo`005@3oool200000?l0oooo2P3oool001D0oooo0P00003o
0?ooo`X0oooo000E0?ooo`800000o`3oool:0?ooo`003@3oool3000000D0oooo0P00003o0?ooo`X0
oooo000>0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0o`3oool90?ooo`003P3o
ool00`000000oooo0?ooo`040?ooo`030000003oool0oooo0?l0oooo2@3oool000h0oooo00<00000
0?ooo`3oool0103oool300000?l0oooo2@3oool000h0oooo00<000000?ooo`3oool0o`3oool@0?oo
o`003@3oool200000?l0oooo4P3oool000h0oooo00<000000?ooo`3oool0o`3oool@0?ooo`00o`3o
oolQ0?ooo`00\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.830159, -0.0764114, \
0.0385797, 0.00624232}}],

Cell[BoxData[
    \({0.31304529241167073`, 0.31303428645550135`, 0.2086862216749778`, 
      0.10434218713262408`, 0.04173664042690843`, 0.013912159718580437`, 
      0.003974891547434859`, 0.000993720770476875`, 0.0002208264647287338`, 
      0.00004416522651587617`, 8.030037013639096`*^-6, 
      1.3383377024818302`*^-6, 2.058940451535362`*^-7, 
      2.9421465142105753`*^-8, 3.9142903048546455`*^-9, 
      4.940961545261851`*^-10, 5.806695241994569`*^-11, 
      4.03119107794353`*^-12, 
      2.4824359125427413`*^-12, \(-5.37257373620961`*^-13\)}\)], "Output",
  CellLabel->"Out[23]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
    \(tm = 10; R = 2; km = 20;\), "\[IndentingNewLine]", 
    \(\(ss = soln[P, R, km, tm];\)\), "\[IndentingNewLine]", 
    \(\(vv = Array[\(P[#]\)[t] &, {km}];\)\), "\[IndentingNewLine]", 
    \(\(Plot[vv /. ss // Evaluate, {t, 0, tm}, 
        PlotRange \[Rule] {{0, tm}, {0, 0.3}}];\)\), "\[IndentingNewLine]", 
    \(\(vv /. t \[Rule] tm\) /. ss\)}], "Input",
  CellLabel->"In[65]:="],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-2.77556e-17 0.1 0 2.06011 [
[.2 -0.0125 -3 -9 ]
[.2 -0.0125 3 0 ]
[.4 -0.0125 -3 -9 ]
[.4 -0.0125 3 0 ]
[.6 -0.0125 -3 -9 ]
[.6 -0.0125 3 0 ]
[.8 -0.0125 -3 -9 ]
[.8 -0.0125 3 0 ]
[1 -0.0125 -6 -9 ]
[1 -0.0125 6 0 ]
[-0.0125 .10301 -24 -4.5 ]
[-0.0125 .10301 0 4.5 ]
[-0.0125 .20601 -18 -4.5 ]
[-0.0125 .20601 0 4.5 ]
[-0.0125 .30902 -24 -4.5 ]
[-0.0125 .30902 0 4.5 ]
[-0.0125 .41202 -18 -4.5 ]
[-0.0125 .41202 0 4.5 ]
[-0.0125 .51503 -24 -4.5 ]
[-0.0125 .51503 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 0 m
.2 .00625 L
s
[(2)] .2 -0.0125 0 1 Mshowa
.4 0 m
.4 .00625 L
s
[(4)] .4 -0.0125 0 1 Mshowa
.6 0 m
.6 .00625 L
s
[(6)] .6 -0.0125 0 1 Mshowa
.8 0 m
.8 .00625 L
s
[(8)] .8 -0.0125 0 1 Mshowa
1 0 m
1 .00625 L
s
[(10)] 1 -0.0125 0 1 Mshowa
.125 Mabswid
.05 0 m
.05 .00375 L
s
.1 0 m
.1 .00375 L
s
.15 0 m
.15 .00375 L
s
.25 0 m
.25 .00375 L
s
.3 0 m
.3 .00375 L
s
.35 0 m
.35 .00375 L
s
.45 0 m
.45 .00375 L
s
.5 0 m
.5 .00375 L
s
.55 0 m
.55 .00375 L
s
.65 0 m
.65 .00375 L
s
.7 0 m
.7 .00375 L
s
.75 0 m
.75 .00375 L
s
.85 0 m
.85 .00375 L
s
.9 0 m
.9 .00375 L
s
.95 0 m
.95 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .10301 m
.00625 .10301 L
s
[(0.05)] -0.0125 .10301 1 0 Mshowa
0 .20601 m
.00625 .20601 L
s
[(0.1)] -0.0125 .20601 1 0 Mshowa
0 .30902 m
.00625 .30902 L
s
[(0.15)] -0.0125 .30902 1 0 Mshowa
0 .41202 m
.00625 .41202 L
s
[(0.2)] -0.0125 .41202 1 0 Mshowa
0 .51503 m
.00625 .51503 L
s
[(0.25)] -0.0125 .51503 1 0 Mshowa
.125 Mabswid
0 .0206 m
.00375 .0206 L
s
0 .0412 m
.00375 .0412 L
s
0 .0618 m
.00375 .0618 L
s
0 .0824 m
.00375 .0824 L
s
0 .12361 m
.00375 .12361 L
s
0 .14421 m
.00375 .14421 L
s
0 .16481 m
.00375 .16481 L
s
0 .18541 m
.00375 .18541 L
s
0 .22661 m
.00375 .22661 L
s
0 .24721 m
.00375 .24721 L
s
0 .26781 m
.00375 .26781 L
s
0 .28842 m
.00375 .28842 L
s
0 .32962 m
.00375 .32962 L
s
0 .35022 m
.00375 .35022 L
s
0 .37082 m
.00375 .37082 L
s
0 .39142 m
.00375 .39142 L
s
0 .43262 m
.00375 .43262 L
s
0 .45322 m
.00375 .45322 L
s
0 .47383 m
.00375 .47383 L
s
0 .49443 m
.00375 .49443 L
s
0 .53563 m
.00375 .53563 L
s
0 .55623 m
.00375 .55623 L
s
0 .57683 m
.00375 .57683 L
s
0 .59743 m
.00375 .59743 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.08002 .61803 m
.08481 .58312 L
.10491 .47016 L
.12674 .38283 L
.14756 .323 L
.16964 .27704 L
.19016 .24584 L
.20937 .22391 L
.23063 .20575 L
.25008 .19331 L
.27002 .18365 L
.29178 .17579 L
.31243 .17026 L
.33445 .16588 L
.35694 .1626 L
.37812 .16033 L
.3992 .15865 L
.41859 .15749 L
.43836 .15658 L
.46006 .15584 L
.48054 .15532 L
.5025 .1549 L
.5248 .15459 L
.54593 .15438 L
.56683 .15422 L
.58618 .15411 L
.60577 .15402 L
.62741 .15395 L
.64772 .1539 L
.66962 .15386 L
.69066 .15383 L
.71282 .15381 L
.73354 .15379 L
.75283 .15378 L
.77431 .15377 L
.79383 .15377 L
.81397 .15376 L
.82533 .15376 L
.83581 .15376 L
.84611 .15375 L
.85179 .15375 L
.85718 .15375 L
.86763 .15375 L
.87718 .15375 L
.89645 .15375 L
.91696 .15375 L
.9378 .15375 L
.95712 .15375 L
.96774 .15375 L
.97921 .15375 L
Mistroke
1 .15375 L
Mfstroke
0 0 m
.00488 .17051 L
.00942 .28529 L
.01441 .37614 L
.01721 .41482 L
.01975 .44393 L
.02488 .48839 L
.02778 .50668 L
.03045 .52004 L
.03299 .53005 L
.03536 .53741 L
.03784 .54328 L
.03925 .5459 L
.04057 .54791 L
.042 .54965 L
.0433 .55088 L
.04474 .55186 L
.04553 .55225 L
.04627 .55252 L
.04763 .55278 L
.04888 .55279 L
.05025 .55255 L
.05094 .55235 L
.0517 .55205 L
.05303 .55138 L
.05424 .55061 L
.05696 .54836 L
.06188 .54283 L
.07366 .52454 L
.08481 .50405 L
.12505 .43273 L
.14582 .40389 L
.16788 .37971 L
.18832 .36241 L
.20751 .34981 L
.22871 .33914 L
.24814 .3317 L
.26801 .32587 L
.28974 .32108 L
.31033 .31769 L
.33233 .315 L
.35474 .31298 L
.3759 .31158 L
.39692 .31054 L
.41629 .30982 L
.43599 .30926 L
.45767 .3088 L
.47809 .30847 L
.50002 .30821 L
.52226 .30802 L
Mistroke
.54336 .30788 L
.5642 .30779 L
.58352 .30772 L
.60511 .30766 L
.62466 .30762 L
.64491 .30759 L
.66679 .30756 L
.68776 .30754 L
.70989 .30753 L
.73056 .30752 L
.74982 .30751 L
.77123 .30751 L
.79073 .3075 L
.81081 .3075 L
.82214 .3075 L
.83262 .3075 L
.84288 .3075 L
.85393 .3075 L
.85901 .30749 L
.86436 .30749 L
.8739 .30749 L
.89311 .30749 L
.89817 .30749 L
.90365 .30749 L
.90883 .30749 L
.9136 .30749 L
.92449 .30749 L
.93437 .30749 L
.95367 .30749 L
.97341 .30749 L
.99509 .30749 L
1 .30749 L
Mfstroke
0 0 m
.01975 .13125 L
.02981 .20679 L
.04057 .27001 L
.0515 .31678 L
.06168 .34779 L
.06791 .36211 L
.07379 .37308 L
.07903 .38108 L
.08481 .3883 L
.09499 .39778 L
.10056 .40159 L
.10578 .40446 L
.11511 .40827 L
.12035 .40982 L
.12514 .41095 L
.13015 .41187 L
.13548 .41262 L
.14051 .41315 L
.14508 .41351 L
.14788 .41368 L
.15046 .41381 L
.15329 .41392 L
.15628 .414 L
.15754 .41403 L
.15888 .41405 L
.16005 .41407 L
.16131 .41409 L
.16208 .4141 L
.1628 .4141 L
.16348 .41411 L
.1642 .41411 L
.16546 .41411 L
.16684 .41411 L
.16811 .41411 L
.1693 .41411 L
.17061 .4141 L
.172 .41409 L
.17485 .41405 L
.17744 .41402 L
.18715 .41382 L
.20905 .41319 L
.25103 .412 L
.27027 .41157 L
.29142 .41119 L
.31229 .4109 L
.33439 .41066 L
.35481 .4105 L
.37674 .41036 L
.39898 .41026 L
Mistroke
.42008 .41019 L
.44092 .41014 L
.46024 .4101 L
.48183 .41007 L
.50138 .41005 L
.52163 .41004 L
.54351 .41002 L
.56448 .41001 L
.58661 .41001 L
.60728 .41 L
.62654 .41 L
.64795 .41 L
.66745 .40999 L
.68753 .40999 L
.70934 .40999 L
.73014 .40999 L
.75222 .40999 L
.7727 .40999 L
.79191 .40999 L
.80226 .40999 L
.81314 .40999 L
.83259 .40999 L
.87266 .40999 L
.89329 .40999 L
.9153 .40999 L
.95893 .40999 L
1 .40999 L
Mfstroke
0 0 m
.04057 .12363 L
.06168 .20222 L
.07286 .23547 L
.08481 .26511 L
.10632 .30584 L
.12636 .33291 L
.14873 .35454 L
.16988 .36917 L
.19085 .37977 L
.21021 .38704 L
.22987 .39261 L
.25153 .39718 L
.27191 .40037 L
.29383 .40292 L
.31602 .40481 L
.33712 .40613 L
.35791 .4071 L
.37722 .40779 L
.39877 .40836 L
.41831 .40875 L
.43852 .40905 L
.46038 .4093 L
.48131 .40947 L
.50343 .40961 L
.52405 .4097 L
.5433 .40977 L
.56467 .40983 L
.58415 .40986 L
.60419 .40989 L
.62599 .40992 L
.64675 .40994 L
.66881 .40995 L
.68926 .40996 L
.70845 .40996 L
.72964 .40997 L
.74907 .40997 L
.76894 .40998 L
.79068 .40998 L
.81127 .40998 L
.82279 .40998 L
.83327 .40998 L
.84388 .40998 L
.85511 .40998 L
.85973 .40998 L
.8647 .40998 L
.87015 .40998 L
.87525 .40998 L
.89457 .40998 L
.89983 .40998 L
Mistroke
.90478 .40998 L
.91048 .40998 L
.91564 .40998 L
.92717 .40998 L
.93787 .40999 L
.94794 .40999 L
.95898 .40999 L
.96926 .40999 L
.9801 .40999 L
.99951 .40999 L
1 .40999 L
Mfstroke
0 0 m
.00123 0 L
.00236 1e-05 L
.00365 4e-05 L
.00488 .00012 L
.00601 .00025 L
.00706 .00043 L
.00821 .00071 L
.00942 .00112 L
.01065 .00165 L
.01196 .00237 L
.01434 .00408 L
.01716 .00684 L
.01975 .01002 L
.02485 .01802 L
.03042 .02893 L
.04057 .05262 L
.06198 .10754 L
.08481 .16064 L
.10531 .19946 L
.12749 .23228 L
.14997 .25741 L
.17115 .27519 L
.19208 .28843 L
.2142 .29887 L
.23482 .30613 L
.25407 .31127 L
.27544 .31557 L
.29493 .31853 L
.31496 .32084 L
.33676 .32271 L
.35753 .32404 L
.37958 .32509 L
.40003 .32581 L
.41922 .32632 L
.44041 .32675 L
.45984 .32704 L
.47971 .32727 L
.50145 .32746 L
.52204 .32759 L
.54404 .3277 L
.56645 .32778 L
.58761 .32783 L
.60863 .32787 L
.628 .3279 L
.6477 .32792 L
.66937 .32794 L
.68979 .32795 L
.71173 .32796 L
.73396 .32797 L
Mistroke
.75507 .32797 L
.77591 .32798 L
.79523 .32798 L
.80635 .32798 L
.81682 .32798 L
.83637 .32798 L
.84665 .32798 L
.85226 .32798 L
.85749 .32799 L
.86675 .32799 L
.8769 .32799 L
.89651 .32799 L
.90188 .32799 L
.90758 .32799 L
.91245 .32799 L
.91781 .32799 L
.94016 .32799 L
.9613 .32799 L
.97993 .32799 L
1 .32799 L
Mfstroke
0 0 m
.00123 0 L
.00236 0 L
.00365 0 L
.00488 1e-05 L
.00601 3e-05 L
.00706 5e-05 L
.00821 9e-05 L
.00942 .00017 L
.01065 .00027 L
.01196 .00043 L
.0132 .00062 L
.01434 .00084 L
.01711 .00159 L
.01975 .00259 L
.02225 .00382 L
.02491 .00545 L
.0297 .00915 L
.04057 .02084 L
.08481 .08683 L
.10578 .11552 L
.12847 .14103 L
.15038 .16034 L
.17054 .17411 L
.19031 .18458 L
.212 .19334 L
.23249 .19957 L
.25445 .20458 L
.27675 .20833 L
.29788 .21096 L
.31878 .21291 L
.33812 .21427 L
.35772 .21532 L
.37935 .21619 L
.39967 .2168 L
.42157 .21729 L
.44261 .21764 L
.46476 .21791 L
.48549 .2181 L
.50478 .21823 L
.52626 .21834 L
.54577 .21842 L
.56592 .21848 L
.58775 .21852 L
.60862 .21856 L
.63072 .21859 L
.65127 .2186 L
.6705 .21862 L
.6918 .21863 L
.71127 .21864 L
Mistroke
.73124 .21864 L
.75302 .21865 L
.77371 .21865 L
.79575 .21865 L
.80658 .21865 L
.81827 .21865 L
.83946 .21866 L
.85032 .21866 L
.85562 .21866 L
.86044 .21866 L
.86554 .21866 L
.871 .21866 L
.88257 .21866 L
.89314 .21866 L
.89892 .21866 L
.90435 .21866 L
.90895 .21866 L
.91392 .21866 L
.92446 .21866 L
.94411 .21866 L
.96477 .21866 L
.9816 .21866 L
1 .21866 L
Mfstroke
0 0 m
.00123 0 L
.00236 0 L
.00365 0 L
.00488 0 L
.00601 0 L
.00706 1e-05 L
.00821 1e-05 L
.00942 2e-05 L
.01065 4e-05 L
.01196 7e-05 L
.0132 .00012 L
.01434 .00017 L
.01566 .00025 L
.01711 .00036 L
.01975 .00064 L
.02116 .00084 L
.02249 .00106 L
.02497 .00157 L
.03054 .00317 L
.03536 .00509 L
.04057 .0077 L
.06361 .02412 L
.08481 .04215 L
.10625 .0595 L
.12627 .07348 L
.14675 .08523 L
.16614 .09413 L
.18751 .1018 L
.20699 .10718 L
.2279 .1116 L
.24724 .11473 L
.26684 .11716 L
.28847 .11918 L
.30879 .1206 L
.33068 .12174 L
.35173 .12256 L
.37388 .12319 L
.39461 .12363 L
.41389 .12394 L
.43537 .1242 L
.45489 .12438 L
.47504 .12452 L
.49687 .12463 L
.51774 .12471 L
.53984 .12478 L
.56039 .12482 L
.57962 .12485 L
.60092 .12487 L
.62038 .12489 L
Mistroke
.64036 .12491 L
.66213 .12492 L
.68283 .12492 L
.70487 .12493 L
.72739 .12494 L
.74858 .12494 L
.76971 .12494 L
.78912 .12494 L
.80892 .12494 L
.82016 .12494 L
.83063 .12495 L
.85024 .12495 L
.85561 .12495 L
.86131 .12495 L
.86618 .12495 L
.87154 .12495 L
.89389 .12495 L
.89926 .12495 L
.90492 .12495 L
.90975 .12495 L
.91502 .12495 L
.93538 .12495 L
.94687 .12495 L
.95729 .12495 L
.97792 .12495 L
.99994 .12495 L
1 .12495 L
Mfstroke
0 0 m
.00123 0 L
.00236 0 L
.00365 0 L
.00488 0 L
.00601 0 L
.00706 0 L
.00821 0 L
.00942 0 L
.01065 1e-05 L
.01196 1e-05 L
.0132 2e-05 L
.01434 3e-05 L
.01566 5e-05 L
.01711 8e-05 L
.01848 .00011 L
.01975 .00015 L
.02106 .0002 L
.02247 .00027 L
.02503 .00043 L
.02753 .00064 L
.02982 .00087 L
.03505 .0016 L
.04057 .00266 L
.05147 .00556 L
.06166 .00908 L
.08481 .0185 L
.12566 .03442 L
.14796 .04122 L
.16909 .04631 L
.19 .05024 L
.20934 .05305 L
.22894 .05527 L
.25057 .05712 L
.27088 .05843 L
.29278 .05949 L
.31382 .06025 L
.33598 .06084 L
.35671 .06125 L
.37599 .06154 L
.39747 .06178 L
.41699 .06195 L
.43713 .06208 L
.45897 .06218 L
.47984 .06225 L
.50193 .06231 L
.52249 .06235 L
.54172 .06238 L
.56302 .06241 L
.58248 .06242 L
Mistroke
.60246 .06243 L
.62423 .06244 L
.64493 .06245 L
.66696 .06246 L
.68949 .06246 L
.71068 .06247 L
.7318 .06247 L
.75121 .06247 L
.77102 .06247 L
.79273 .06247 L
.81325 .06247 L
.82476 .06247 L
.83523 .06247 L
.84579 .06247 L
.85158 .06247 L
.857 .06247 L
.86657 .06247 L
.87712 .06247 L
.89677 .06247 L
.90154 .06247 L
.90664 .06247 L
.91223 .06247 L
.91742 .06247 L
.93866 .06247 L
.9581 .06247 L
.96845 .06247 L
.97967 .06247 L
1 .06247 L
Mfstroke
0 0 m
.00123 0 L
.00236 0 L
.00365 0 L
.00488 0 L
.00601 0 L
.00706 0 L
.00821 0 L
.00942 0 L
.01065 0 L
.01196 0 L
.0132 0 L
.01434 1e-05 L
.01566 1e-05 L
.01641 1e-05 L
.01711 2e-05 L
.01839 2e-05 L
.01975 3e-05 L
.02115 5e-05 L
.02245 7e-05 L
.02384 9e-05 L
.02537 .00012 L
.02795 .00019 L
.03067 .00028 L
.03579 .00053 L
.04057 .00086 L
.0463 .00138 L
.05174 .00199 L
.06192 .00341 L
.08481 .0074 L
.12505 .0145 L
.14541 .01741 L
.16788 .02 L
.18914 .0219 L
.20911 .02329 L
.2303 .02441 L
.24973 .0252 L
.2696 .02581 L
.29133 .02632 L
.31192 .02668 L
.33392 .02697 L
.35634 .02718 L
.37749 .02733 L
.39851 .02744 L
.41788 .02752 L
.43759 .02758 L
.45926 .02763 L
.47968 .02766 L
.50161 .02769 L
.52385 .02771 L
Mistroke
.54495 .02772 L
.56579 .02773 L
.58511 .02774 L
.6067 .02775 L
.62625 .02775 L
.6465 .02776 L
.66838 .02776 L
.68935 .02776 L
.71149 .02776 L
.73215 .02776 L
.75141 .02776 L
.77282 .02776 L
.79232 .02776 L
.8124 .02777 L
.82374 .02777 L
.83421 .02777 L
.84447 .02777 L
.84986 .02777 L
.85552 .02777 L
.86595 .02777 L
.8755 .02777 L
.8947 .02777 L
.89976 .02777 L
.90525 .02777 L
.91042 .02777 L
.91519 .02777 L
.92608 .02777 L
.93596 .02777 L
.95526 .02777 L
.96546 .02777 L
.975 .02777 L
.99669 .02777 L
1 .02777 L
Mfstroke
0 0 m
.00123 0 L
.00236 0 L
.00365 0 L
.00488 0 L
.00601 0 L
.00706 0 L
.00821 0 L
.00942 0 L
.01065 0 L
.01196 0 L
.0132 0 L
.01434 0 L
.01566 0 L
.01641 0 L
.01711 0 L
.01839 1e-05 L
.01975 1e-05 L
.02115 1e-05 L
.02245 2e-05 L
.02387 2e-05 L
.02537 3e-05 L
.0279 5e-05 L
.03067 8e-05 L
.03314 .00011 L
.03579 .00015 L
.04057 .00026 L
.04626 .00044 L
.05245 .00068 L
.06371 .00128 L
.08481 .00271 L
.12763 .00574 L
.1489 .00696 L
.16886 .0079 L
.18817 .00862 L
.2085 .00921 L
.22969 .00969 L
.24912 .01002 L
.26985 .01029 L
.28913 .01048 L
.31061 .01064 L
.33013 .01075 L
.35028 .01084 L
.37211 .01091 L
.39298 .01096 L
.41508 .011 L
.43563 .01103 L
.45486 .01104 L
.47616 .01106 L
.49562 .01107 L
Mistroke
.5156 .01108 L
.53737 .01109 L
.55807 .01109 L
.58011 .0111 L
.60263 .0111 L
.62382 .0111 L
.64494 .0111 L
.66435 .0111 L
.68416 .0111 L
.70587 .0111 L
.7264 .01111 L
.74837 .01111 L
.77072 .01111 L
.79186 .01111 L
.80202 .01111 L
.8128 .01111 L
.83216 .01111 L
.84226 .01111 L
.85288 .01111 L
.85726 .01111 L
.86194 .01111 L
.86708 .01111 L
.87185 .01111 L
.8922 .01111 L
.89775 .01111 L
.90361 .01111 L
.90862 .01111 L
.91412 .01111 L
.9249 .01111 L
.93657 .01111 L
.94764 .01111 L
.95774 .01111 L
.97813 .01111 L
1 .01111 L
Mfstroke
0 0 m
.00123 0 L
.00236 0 L
.00365 0 L
.00488 0 L
.00601 0 L
.00706 0 L
.00821 0 L
.00942 0 L
.01065 0 L
.01196 0 L
.0132 0 L
.01434 0 L
.01566 0 L
.01641 0 L
.01711 0 L
.01839 0 L
.01975 0 L
.02043 0 L
.02115 0 L
.02245 0 L
.02317 0 L
.02384 0 L
.02537 1e-05 L
.02793 1e-05 L
.02936 2e-05 L
.03067 2e-05 L
.0331 3e-05 L
.03575 4e-05 L
.04057 7e-05 L
.04586 .00012 L
.05171 .0002 L
.06355 .00041 L
.08481 .00092 L
.12702 .00201 L
.16764 .00281 L
.18869 .00311 L
.21084 .00335 L
.23157 .00352 L
.25085 .00364 L
.27233 .00374 L
.29185 .00381 L
.312 .00387 L
.33383 .00391 L
.3547 .00394 L
.3768 .00397 L
.39735 .00399 L
.41658 .004 L
.43788 .00401 L
.45734 .00402 L
Mistroke
.47732 .00402 L
.49909 .00403 L
.51979 .00403 L
.54183 .00403 L
.56435 .00403 L
.58554 .00403 L
.60667 .00404 L
.62608 .00404 L
.64588 .00404 L
.66759 .00404 L
.68812 .00404 L
.71009 .00404 L
.73244 .00404 L
.75358 .00404 L
.77452 .00404 L
.79388 .00404 L
.81351 .00404 L
.82469 .00404 L
.83516 .00404 L
.87584 .00404 L
.89692 .00404 L
.90205 .00404 L
.90752 .00404 L
.91066 .00404 L
.91352 .00404 L
.91909 .00404 L
.94097 .00404 L
.96113 .00404 L
.98002 .00404 L
1 .00404 L
Mfstroke
0 0 m
.00123 0 L
.00236 0 L
.00365 0 L
.00488 0 L
.00601 0 L
.00706 0 L
.00821 0 L
.00942 0 L
.01065 0 L
.01196 0 L
.0132 0 L
.01434 0 L
.01566 0 L
.01641 0 L
.01711 0 L
.01848 0 L
.01975 0 L
.02106 0 L
.02174 0 L
.02247 0 L
.02369 0 L
.02503 0 L
.02623 0 L
.02751 0 L
.02872 0 L
.02982 0 L
.03111 1e-05 L
.03247 1e-05 L
.03318 1e-05 L
.03396 1e-05 L
.03534 1e-05 L
.04057 2e-05 L
.04336 3e-05 L
.0463 4e-05 L
.05155 6e-05 L
.06339 .00012 L
.08481 .00029 L
.12482 .00064 L
.14714 .0008 L
.16741 .00092 L
.18874 .00103 L
.20841 .0011 L
.22855 .00116 L
.25039 .00121 L
.27009 .00124 L
.29176 .00127 L
.31218 .00129 L
.33412 .0013 L
.35635 .00131 L
Mistroke
.37746 .00132 L
.3983 .00133 L
.41762 .00133 L
.43921 .00134 L
.45876 .00134 L
.47901 .00134 L
.50088 .00134 L
.52186 .00134 L
.53242 .00134 L
.54399 .00134 L
.56624 .00134 L
.58649 .00134 L
.60751 .00135 L
.6274 .00135 L
.64835 .00135 L
.6677 .00135 L
.68734 .00135 L
.70899 .00135 L
.72934 .00135 L
.75125 .00135 L
.77234 .00135 L
.79451 .00135 L
.80455 .00135 L
.81528 .00135 L
.83457 .00135 L
.84536 .00135 L
.85103 .00135 L
.85703 .00135 L
.86228 .00135 L
.86805 .00135 L
.8782 .00135 L
.88959 .00135 L
.90038 .00135 L
.90507 .00135 L
.91007 .00135 L
.91554 .00135 L
.92061 .00135 L
.94166 .00135 L
.96143 .00135 L
.97999 .00135 L
1 .00135 L
Mfstroke
0 0 m
.00123 0 L
.00236 0 L
.00365 0 L
.00488 0 L
.00601 0 L
.00706 0 L
.00821 0 L
.00942 0 L
.01065 0 L
.01196 0 L
.0132 0 L
.01434 0 L
.01566 0 L
.01641 0 L
.01711 0 L
.01839 0 L
.01975 0 L
.02106 0 L
.02245 0 L
s
.02245 0 m
.02307 0 L
s
.02472 0 m
.02537 0 L
.02671 0 L
.02793 0 L
.0286 0 L
.02933 0 L
.03067 0 L
.03185 0 L
.03316 0 L
.03453 0 L
.03581 0 L
.03692 0 L
.0381 0 L
.03939 0 L
.04057 1e-05 L
.04586 1e-05 L
.05151 2e-05 L
.05685 2e-05 L
.0617 3e-05 L
.08481 8e-05 L
.12679 .0002 L
.16718 .00028 L
.18805 .00031 L
.21014 .00034 L
.2307 .00036 L
.24993 .00037 L
.27123 .00038 L
.29069 .00039 L
.31067 .0004 L
.33244 .0004 L
.35314 .0004 L
.37517 .00041 L
.3977 .00041 L
.41889 .00041 L
.44001 .00041 L
.44939 .00041 L
.45942 .00041 L
.46967 .00041 L
.47923 .00041 L
.49051 .00041 L
.49547 .00041 L
.49829 .00041 L
.50094 .00041 L
.50613 .00041 L
.51165 .00041 L
.51772 .00041 L
.52038 .00041 L
.52188 .00041 L
.52328 .00041 L
.52825 .00041 L
Mistroke
.53346 .00041 L
.53917 .00041 L
.54442 .00041 L
.54701 .00041 L
.54831 .00041 L
.54974 .00041 L
.5555 .00041 L
.56594 .00041 L
.58547 .00041 L
.60593 .00041 L
.62789 .00041 L
.63855 .00041 L
.64418 .00041 L
.65016 .00041 L
.65537 .00041 L
.66113 .00041 L
.67128 .00041 L
.69328 .00041 L
.71346 .00041 L
.73322 .00041 L
.75405 .00041 L
.77475 .00041 L
.79403 .00041 L
.80506 .00041 L
.81548 .00041 L
.83499 .00041 L
.84425 .00041 L
.8542 .00041 L
.85713 .00041 L
.85991 .00041 L
.86512 .00041 L
.87535 .00041 L
.89619 .00041 L
.91828 .00041 L
.93933 .00041 L
.9584 .00041 L
.97854 .00041 L
1 .00041 L
Mfstroke
0 0 m
.00123 0 L
.00236 0 L
.00365 0 L
.00488 0 L
.00601 0 L
.00706 0 L
.00821 0 L
.00942 0 L
.01065 0 L
.01196 0 L
.0132 0 L
.01434 0 L
.01566 0 L
.01641 0 L
.01711 0 L
s
.01711 0 m
.01712 0 L
s
.02253 0 m
.02317 0 L
.02384 0 L
.02458 0 L
s
.02458 0 m
.02509 0 L
s
.02745 0 m
.02814 0 L
.02945 0 L
s
.02945 0 m
.03043 0 L
s
.03287 0 m
.03295 0 L
.03426 0 L
.03547 0 L
s
.03547 0 m
.03654 0 L
s
.03804 0 m
.03918 0 L
.04057 0 L
.04355 0 L
.04637 0 L
.05165 0 L
.05733 1e-05 L
.06349 1e-05 L
.08481 2e-05 L
.12777 6e-05 L
.14915 7e-05 L
.16915 8e-05 L
.18955 9e-05 L
.20893 .0001 L
.23023 .0001 L
.24969 .00011 L
.27053 .00011 L
.28985 .00011 L
.31144 .00011 L
.33099 .00011 L
.35124 .00012 L
.37312 .00012 L
.39409 .00012 L
.41622 .00012 L
.4262 .00012 L
.43169 .00012 L
.43689 .00012 L
.44697 .00012 L
.45615 .00012 L
.49645 .00012 L
.50627 .00012 L
.51685 .00012 L
.5198 .00012 L
.52052 .00012 L
.52128 .00012 L
.52212 .00012 L
.5229 .00012 L
.52362 .00012 L
.5244 .00012 L
.52513 .00012 L
.52581 .00012 L
.52717 .00012 L
.52845 .00012 L
.52966 .00012 L
.53097 .00012 L
.53171 .00012 L
.53242 .00012 L
.53374 .00012 L
.53441 .00012 L
.53513 .00012 L
Mistroke
.53641 .00012 L
.5378 .00012 L
.53859 .00012 L
.53933 .00012 L
.54194 .00012 L
.54321 .00012 L
.54437 .00012 L
.5456 .00012 L
.54691 .00012 L
.54759 .00012 L
.54833 .00012 L
.54968 .00012 L
.55208 .00012 L
.5534 .00012 L
.55463 .00012 L
.55567 .00012 L
.5568 .00012 L
.55919 .00012 L
.58061 .00012 L
.58575 .00012 L
.58857 .00012 L
.59123 .00012 L
.59275 .00012 L
.59354 .00012 L
.59438 .00012 L
.59587 .00012 L
.59724 .00012 L
.60282 .00012 L
.62392 .00012 L
.66381 .00012 L
.67434 .00012 L
.67685 .00012 L
.67952 .00012 L
.6818 .00012 L
.68309 .00012 L
.68431 .00012 L
.68569 .00012 L
.68696 .00012 L
.68982 .00012 L
.69273 .00012 L
.6942 .00012 L
.6958 .00012 L
.70628 .00012 L
.71776 .00012 L
.72861 .00012 L
.73834 .00012 L
.74889 .00012 L
.76842 .00012 L
.77378 .00012 L
.77952 .00012 L
Mistroke
.7899 .00012 L
.81079 .00012 L
.82226 .00012 L
.83289 .00012 L
.84354 .00012 L
.85514 .00012 L
.87625 .00012 L
.88739 .00012 L
.89786 .00012 L
.90243 .00012 L
.90726 .00012 L
.90979 .00012 L
.91255 .00012 L
.91741 .00012 L
.93967 .00012 L
.95993 .00012 L
.96981 .00012 L
.98053 .00012 L
1 .00012 L
Mfstroke
0 0 m
.00123 0 L
.00236 0 L
.00365 0 L
.00488 0 L
.00601 0 L
.00706 0 L
.00821 0 L
.00942 0 L
.01065 0 L
.01196 0 L
.0132 0 L
.01434 0 L
.01566 0 L
.01641 0 L
.01711 0 L
.01839 0 L
.01975 0 L
.02043 0 L
.02115 0 L
.02245 0 L
s
.02245 0 m
.02256 0 L
s
.02503 0 m
.02537 0 L
.02605 0 L
.02679 0 L
s
.02679 0 m
.02757 0 L
s
.03018 0 m
.03067 0 L
.03184 0 L
.03295 0 L
s
.03295 0 m
.03332 0 L
s
.03591 0 m
.03676 0 L
.03813 0 L
.03929 0 L
.04057 0 L
.0419 0 L
.04257 0 L
.0433 0 L
.0441 0 L
.04484 0 L
.04627 0 L
.05165 0 L
.05785 0 L
.06349 0 L
.08481 1e-05 L
.12557 1e-05 L
.14631 2e-05 L
.16891 2e-05 L
.19058 2e-05 L
.21066 3e-05 L
.23225 3e-05 L
.2518 3e-05 L
.27205 3e-05 L
.29393 3e-05 L
.31491 3e-05 L
.33704 3e-05 L
.3577 3e-05 L
.37696 3e-05 L
.39837 3e-05 L
.40783 3e-05 L
.41787 3e-05 L
.42284 3e-05 L
.42831 3e-05 L
.43334 3e-05 L
.43554 3e-05 L
.43679 3e-05 L
.43795 3e-05 L
.44059 3e-05 L
.44337 3e-05 L
.44921 3e-05 L
.45184 3e-05 L
.45313 3e-05 L
.45432 3e-05 L
.45569 3e-05 L
.45641 3e-05 L
.45717 3e-05 L
.45841 3e-05 L
.45976 3e-05 L
.46239 3e-05 L
.46378 3e-05 L
Mistroke
.46526 3e-05 L
.46796 3e-05 L
.47046 3e-05 L
.47155 3e-05 L
.47269 3e-05 L
.47395 3e-05 L
.4751 3e-05 L
.47636 3e-05 L
.47774 3e-05 L
.47903 3e-05 L
.48022 3e-05 L
.49083 3e-05 L
.4937 3e-05 L
.49526 3e-05 L
.49673 3e-05 L
.49798 3e-05 L
.49932 3e-05 L
.50009 3e-05 L
.50081 3e-05 L
.50218 3e-05 L
.51291 3e-05 L
.51584 3e-05 L
.51744 3e-05 L
.51896 3e-05 L
.51964 3e-05 L
.52037 3e-05 L
.52116 3e-05 L
.5219 3e-05 L
.52317 3e-05 L
.52389 3e-05 L
.52456 3e-05 L
.53468 3e-05 L
.53997 3e-05 L
.54275 3e-05 L
.54343 3e-05 L
.54416 3e-05 L
.54496 3e-05 L
.54571 3e-05 L
.54641 3e-05 L
.54716 3e-05 L
.54796 3e-05 L
.54869 3e-05 L
.55142 3e-05 L
.55273 3e-05 L
.55397 3e-05 L
.55466 3e-05 L
.5554 3e-05 L
.5567 3e-05 L
.55795 3e-05 L
.55933 3e-05 L
Mistroke
.56002 3e-05 L
.56077 3e-05 L
.56211 3e-05 L
.56345 3e-05 L
.56472 3e-05 L
.56597 3e-05 L
.5671 3e-05 L
.56831 3e-05 L
.56944 3e-05 L
.57064 3e-05 L
.57194 3e-05 L
.57408 3e-05 L
.57521 3e-05 L
.57643 3e-05 L
.57776 3e-05 L
.579 3e-05 L
.57974 3e-05 L
.58043 3e-05 L
.58172 3e-05 L
.58294 3e-05 L
.58406 3e-05 L
.58529 3e-05 L
.58659 3e-05 L
.58785 3e-05 L
.58923 3e-05 L
.59053 3e-05 L
.59175 3e-05 L
.59294 3e-05 L
.59403 3e-05 L
.59528 3e-05 L
.59646 3e-05 L
.60709 3e-05 L
.61158 3e-05 L
.61403 3e-05 L
.61632 3e-05 L
.61751 3e-05 L
.6188 3e-05 L
.61953 3e-05 L
.62022 3e-05 L
.62152 3e-05 L
.62271 3e-05 L
.62381 3e-05 L
.6263 3e-05 L
.62754 3e-05 L
.62884 3e-05 L
.62995 3e-05 L
.63116 3e-05 L
.63248 3e-05 L
.63321 3e-05 L
.63388 3e-05 L
Mistroke
.63518 3e-05 L
.6364 3e-05 L
.64096 3e-05 L
.64589 3e-05 L
.64714 3e-05 L
.64849 3e-05 L
.64927 3e-05 L
.64997 3e-05 L
.65136 3e-05 L
.65209 3e-05 L
.65278 3e-05 L
.65353 3e-05 L
.65432 3e-05 L
.65714 3e-05 L
.65849 3e-05 L
.65995 3e-05 L
.66132 3e-05 L
.66259 3e-05 L
.66373 3e-05 L
.66499 3e-05 L
.6663 3e-05 L
.66752 3e-05 L
.66885 3e-05 L
.66952 3e-05 L
.67026 3e-05 L
.67156 3e-05 L
.67279 3e-05 L
.67423 3e-05 L
.67555 3e-05 L
.67708 3e-05 L
.67852 3e-05 L
.67969 3e-05 L
.68094 3e-05 L
.68233 3e-05 L
.68359 3e-05 L
.6849 3e-05 L
.68633 3e-05 L
.68892 3e-05 L
.69147 3e-05 L
.69272 3e-05 L
.69385 3e-05 L
.69505 3e-05 L
.69634 3e-05 L
.69907 3e-05 L
.70842 3e-05 L
.71101 3e-05 L
.71228 3e-05 L
.71345 3e-05 L
.71467 3e-05 L
.71599 3e-05 L
Mistroke
.71736 3e-05 L
.71805 3e-05 L
.7188 3e-05 L
.72004 3e-05 L
.72121 3e-05 L
.72256 3e-05 L
.72378 3e-05 L
.72494 3e-05 L
.72601 3e-05 L
.72842 3e-05 L
.73384 3e-05 L
.73967 3e-05 L
.74249 3e-05 L
.74388 3e-05 L
.74517 3e-05 L
.74634 3e-05 L
.74758 3e-05 L
.74896 3e-05 L
.75021 3e-05 L
.76987 3e-05 L
.77122 3e-05 L
.77248 3e-05 L
.77379 3e-05 L
.77449 3e-05 L
.77523 3e-05 L
.77681 3e-05 L
.77825 3e-05 L
.78103 3e-05 L
.78612 3e-05 L
.78869 3e-05 L
.79153 3e-05 L
.80195 3e-05 L
.80697 3e-05 L
.80917 3e-05 L
.81158 3e-05 L
.81421 3e-05 L
.81565 3e-05 L
.81699 3e-05 L
.81775 3e-05 L
.81847 3e-05 L
.81981 3e-05 L
.82126 3e-05 L
.82282 3e-05 L
.8242 3e-05 L
.82549 3e-05 L
.82684 3e-05 L
.82831 3e-05 L
.83076 3e-05 L
.83338 3e-05 L
.84343 3e-05 L
Mistroke
.84904 3e-05 L
.85412 3e-05 L
.85553 3e-05 L
.85703 3e-05 L
.85781 3e-05 L
.85866 3e-05 L
.85944 3e-05 L
.86017 3e-05 L
.8609 3e-05 L
.8616 3e-05 L
.86291 3e-05 L
.86364 3e-05 L
.86432 3e-05 L
.86506 3e-05 L
.86585 3e-05 L
.87109 3e-05 L
.8726 3e-05 L
.87334 3e-05 L
.87403 3e-05 L
.87532 3e-05 L
.876 3e-05 L
.87673 3e-05 L
.87806 3e-05 L
.8788 3e-05 L
.87949 3e-05 L
.88076 3e-05 L
.8821 3e-05 L
.88698 3e-05 L
.89659 3e-05 L
.91848 3e-05 L
.93908 3e-05 L
.95833 3e-05 L
.97968 3e-05 L
.989 3e-05 L
.99428 3e-05 L
.99916 3e-05 L
1 3e-05 L
Mfstroke
0 0 m
.00123 0 L
.00236 0 L
.00365 0 L
.00488 0 L
.00601 0 L
.00706 0 L
.00821 0 L
.00942 0 L
.01065 0 L
.01196 0 L
.0132 0 L
s
.0132 0 m
.0134 0 L
s
.02253 0 m
.02317 0 L
.02384 0 L
.02458 0 L
s
.02458 0 m
.02503 0 L
s
.02754 0 m
.02814 0 L
.02945 0 L
s
.02945 0 m
.0302 0 L
s
.03322 0 m
.03416 0 L
.03547 0 L
s
.03547 0 m
.03597 0 L
s
.03925 0 m
.0393 0 L
.04057 0 L
.04131 0 L
.04199 0 L
.04334 0 L
.04456 0 L
.04586 0 L
.04653 0 L
.04725 0 L
.04855 0 L
.04935 0 L
.0501 0 L
.05078 0 L
.05151 0 L
.05286 0 L
.05407 0 L
.05475 0 L
.05548 0 L
.0568 0 L
.0617 0 L
.07374 0 L
.08481 0 L
.12633 0 L
.16625 1e-05 L
.18678 1e-05 L
.20875 1e-05 L
.2311 1e-05 L
.25223 1e-05 L
.27318 1e-05 L
.29254 1e-05 L
.31217 1e-05 L
.33382 1e-05 L
.35417 1e-05 L
.37609 1e-05 L
.39717 1e-05 L
.4023 1e-05 L
.40777 1e-05 L
.41377 1e-05 L
.41642 1e-05 L
.41793 1e-05 L
.41934 1e-05 L
.42066 1e-05 L
.42207 1e-05 L
.42495 1e-05 L
.43012 1e-05 L
.43326 1e-05 L
.4348 1e-05 L
.43548 1e-05 L
.43623 1e-05 L
Mistroke
.43752 1e-05 L
.43889 1e-05 L
.43961 1e-05 L
.44039 1e-05 L
.4418 1e-05 L
.44458 1e-05 L
.44717 1e-05 L
.44848 1e-05 L
.44988 1e-05 L
.4513 1e-05 L
.45204 1e-05 L
.45284 1e-05 L
.45351 1e-05 L
.45426 1e-05 L
.45556 1e-05 L
.4569 1e-05 L
.45814 1e-05 L
.46297 1e-05 L
.46819 1e-05 L
.47094 1e-05 L
.47245 1e-05 L
.4732 1e-05 L
.47388 1e-05 L
.47523 1e-05 L
.47595 1e-05 L
.4767 1e-05 L
.47792 1e-05 L
.47925 1e-05 L
.48424 1e-05 L
.48674 1e-05 L
.4891 1e-05 L
.49183 1e-05 L
.49431 1e-05 L
.49649 1e-05 L
.49759 1e-05 L
.49881 1e-05 L
.50012 1e-05 L
.50135 1e-05 L
.50248 1e-05 L
.5037 1e-05 L
.51461 1e-05 L
.51735 1e-05 L
.51869 1e-05 L
.51993 1e-05 L
.52105 1e-05 L
.52225 1e-05 L
.52344 1e-05 L
.52476 1e-05 L
.52603 1e-05 L
.5274 1e-05 L
Mistroke
.52859 1e-05 L
.52988 1e-05 L
.53064 1e-05 L
.53134 1e-05 L
.53202 1e-05 L
.53273 1e-05 L
.53534 1e-05 L
.53685 1e-05 L
.53847 1e-05 L
.54142 1e-05 L
.54281 1e-05 L
.54357 1e-05 L
.54428 1e-05 L
.54554 1e-05 L
.54692 1e-05 L
.54825 1e-05 L
.54892 1e-05 L
.54966 1e-05 L
.5522 1e-05 L
.55293 1e-05 L
.55362 1e-05 L
.55442 1e-05 L
.55516 1e-05 L
.55648 1e-05 L
.55723 1e-05 L
.55793 1e-05 L
.55918 1e-05 L
.56053 1e-05 L
.5618 1e-05 L
.56297 1e-05 L
.56579 1e-05 L
.56702 1e-05 L
.56834 1e-05 L
.56957 1e-05 L
.57068 1e-05 L
.5718 1e-05 L
.57286 1e-05 L
.57411 1e-05 L
.57544 1e-05 L
.57657 1e-05 L
.57783 1e-05 L
.57902 1e-05 L
.5803 1e-05 L
.58151 1e-05 L
.58262 1e-05 L
.58517 1e-05 L
.58785 1e-05 L
.58914 1e-05 L
.59054 1e-05 L
.59187 1e-05 L
Mistroke
.59309 1e-05 L
.5942 1e-05 L
.59541 1e-05 L
.59668 1e-05 L
.59786 1e-05 L
.59924 1e-05 L
.60056 1e-05 L
.60174 1e-05 L
.60302 1e-05 L
.60452 1e-05 L
.60593 1e-05 L
.6072 1e-05 L
.60857 1e-05 L
.60979 1e-05 L
.61109 1e-05 L
.61341 1e-05 L
.6146 1e-05 L
.61587 1e-05 L
.6166 1e-05 L
.61727 1e-05 L
.61857 1e-05 L
.61976 1e-05 L
.62085 1e-05 L
.62206 1e-05 L
.62334 1e-05 L
.62549 1e-05 L
.62785 1e-05 L
.62915 1e-05 L
.63036 1e-05 L
.63163 1e-05 L
.63299 1e-05 L
.63426 1e-05 L
.63546 1e-05 L
.63654 1e-05 L
.63771 1e-05 L
.64039 1e-05 L
.64323 1e-05 L
.64569 1e-05 L
.64704 1e-05 L
.64832 1e-05 L
.64951 1e-05 L
.6508 1e-05 L
.65197 1e-05 L
.65305 1e-05 L
.65407 1e-05 L
.65519 1e-05 L
.65747 1e-05 L
.65997 1e-05 L
.66137 1e-05 L
.66266 1e-05 L
Mistroke
.66379 1e-05 L
.66503 1e-05 L
.66753 1e-05 L
.66999 1e-05 L
.6726 1e-05 L
.67546 1e-05 L
.6781 1e-05 L
.67928 1e-05 L
.68055 1e-05 L
.68175 1e-05 L
.68285 1e-05 L
.68413 1e-05 L
.68486 1e-05 L
.68553 1e-05 L
.68808 1e-05 L
.68946 1e-05 L
.69095 1e-05 L
.69164 1e-05 L
.69236 1e-05 L
.69366 1e-05 L
.69443 1e-05 L
.69514 1e-05 L
.69593 1e-05 L
.69677 1e-05 L
.69753 1e-05 L
.69825 1e-05 L
.6996 1e-05 L
.70086 1e-05 L
.7022 1e-05 L
.70335 1e-05 L
.70461 1e-05 L
.70597 1e-05 L
.70743 1e-05 L
.70881 1e-05 L
.71007 1e-05 L
.71137 1e-05 L
.71259 1e-05 L
.71388 1e-05 L
.71461 1e-05 L
.71528 1e-05 L
.71763 1e-05 L
.72012 1e-05 L
.72265 1e-05 L
.72406 1e-05 L
.72536 1e-05 L
.72609 1e-05 L
.72689 1e-05 L
.72764 1e-05 L
.72833 1e-05 L
.72968 1e-05 L
Mistroke
.73044 1e-05 L
.73112 1e-05 L
.73178 1e-05 L
.73251 1e-05 L
.73327 1e-05 L
.73398 1e-05 L
.73525 1e-05 L
.73661 1e-05 L
.73965 1e-05 L
.74115 1e-05 L
.74254 1e-05 L
.74384 1e-05 L
.74523 1e-05 L
.74595 1e-05 L
.74662 1e-05 L
.74736 1e-05 L
.74816 1e-05 L
.75327 1e-05 L
.75877 1e-05 L
.76387 1e-05 L
.76681 1e-05 L
.76947 1e-05 L
.77258 1e-05 L
.77395 1e-05 L
.77467 1e-05 L
.77545 1e-05 L
.77676 1e-05 L
.77798 1e-05 L
.7787 1e-05 L
.77938 1e-05 L
.78066 1e-05 L
.78359 1e-05 L
.78488 1e-05 L
.78556 1e-05 L
.7863 1e-05 L
.78753 1e-05 L
.78868 1e-05 L
.78999 1e-05 L
.7912 1e-05 L
.79399 1e-05 L
.79653 1e-05 L
.79776 1e-05 L
.79909 1e-05 L
.80034 1e-05 L
.8015 1e-05 L
.80273 1e-05 L
.80408 1e-05 L
.80551 1e-05 L
.80681 1e-05 L
.80804 1e-05 L
Mistroke
.8092 1e-05 L
.81042 1e-05 L
.81176 1e-05 L
.81292 1e-05 L
.81416 1e-05 L
.81639 1e-05 L
.82189 1e-05 L
.8249 1e-05 L
.82637 1e-05 L
.82771 1e-05 L
.82885 1e-05 L
.8301 1e-05 L
.83142 1e-05 L
.83267 1e-05 L
.83404 1e-05 L
.83473 1e-05 L
.8355 1e-05 L
.83685 1e-05 L
.83811 1e-05 L
.83944 1e-05 L
.84083 1e-05 L
.84332 1e-05 L
.846 1e-05 L
.84893 1e-05 L
.85184 1e-05 L
.85458 1e-05 L
.8561 1e-05 L
.85696 1e-05 L
.85775 1e-05 L
.85841 1e-05 L
.85914 1e-05 L
.8599 1e-05 L
.86062 1e-05 L
.8613 1e-05 L
.86204 1e-05 L
.86339 1e-05 L
.8647 1e-05 L
.86591 1e-05 L
.8716 1e-05 L
.87415 1e-05 L
.87654 1e-05 L
.87787 1e-05 L
.8793 1e-05 L
.88061 1e-05 L
.8818 1e-05 L
.89138 1e-05 L
.89665 1e-05 L
.90163 1e-05 L
.90445 1e-05 L
.90523 1e-05 L
Mistroke
.90605 1e-05 L
.90675 1e-05 L
.90752 1e-05 L
.90883 1e-05 L
.91007 1e-05 L
.91082 1e-05 L
.91153 1e-05 L
.91287 1e-05 L
.91413 1e-05 L
.91547 1e-05 L
.91663 1e-05 L
.91788 1e-05 L
.91865 1e-05 L
.91936 1e-05 L
.92003 1e-05 L
.92075 1e-05 L
.92199 1e-05 L
.92335 1e-05 L
.92472 1e-05 L
.92598 1e-05 L
.92885 1e-05 L
.93406 1e-05 L
.94383 1e-05 L
.94932 1e-05 L
.95448 1e-05 L
.95985 1e-05 L
.96579 1e-05 L
1 1e-05 L
Mfstroke
0 0 m
.00123 0 L
.00236 0 L
.00365 0 L
.00488 0 L
.00601 0 L
.00706 0 L
.00821 0 L
.00942 0 L
.01065 0 L
.01196 0 L
.0132 0 L
.01434 0 L
.01566 0 L
.01641 0 L
.01711 0 L
.01839 0 L
.01975 0 L
.02043 0 L
.02115 0 L
.02245 0 L
s
.02245 0 m
.02251 0 L
s
.02501 0 m
.02537 0 L
.02605 0 L
.02679 0 L
s
.02679 0 m
.02752 0 L
s
.03017 0 m
.03067 0 L
.03184 0 L
.03295 0 L
s
.03295 0 m
.0332 0 L
s
.03592 0 m
.03676 0 L
.03813 0 L
.0393 0 L
.04057 0 L
.04131 0 L
.04199 0 L
.04334 0 L
.04456 0 L
.04586 0 L
.04653 0 L
.04725 0 L
.04855 0 L
.04935 0 L
.0501 0 L
.05078 0 L
.05151 0 L
.05286 0 L
.05407 0 L
.05475 0 L
.05548 0 L
.0568 0 L
.05804 0 L
.05935 0 L
.06047 0 L
.0617 0 L
.08481 0 L
.12731 0 L
.16822 0 L
.19056 0 L
.2117 0 L
.23265 0 L
.252 0 L
.27164 0 L
.29329 0 L
.31364 0 L
.33556 0 L
.35664 0 L
.37881 0 L
.384 0 L
.38962 0 L
.39457 0 L
.39728 0 L
.39861 0 L
.39981 0 L
.40209 0 L
.40454 0 L
.40974 0 L
.41448 0 L
.41657 0 L
Mistroke
.41776 0 L
.41888 0 L
.42006 0 L
.42133 0 L
.4227 0 L
.42395 0 L
.42658 0 L
.42798 0 L
.42947 0 L
.43079 0 L
.432 0 L
.43322 0 L
.43436 0 L
.43563 0 L
.437 0 L
.43822 0 L
.43951 0 L
.44492 0 L
.44998 0 L
.45135 0 L
.45207 0 L
.45284 0 L
.45357 0 L
.45424 0 L
.45554 0 L
.45632 0 L
.45715 0 L
.45866 0 L
.46152 0 L
.46401 0 L
.46669 0 L
.46921 0 L
.47151 0 L
.47282 0 L
.47348 0 L
.47421 0 L
.47499 0 L
.47573 0 L
.47641 0 L
.47714 0 L
.4785 0 L
.47992 0 L
.48247 0 L
.49304 0 L
.49593 0 L
.49677 0 L
.49755 0 L
.49826 0 L
.49903 0 L
.4997 0 L
Mistroke
.50043 0 L
.5012 0 L
.50192 0 L
.50459 0 L
.50983 0 L
.51125 0 L
.51259 0 L
.51414 0 L
.51553 0 L
.51812 0 L
.51948 0 L
.52023 0 L
.52092 0 L
.52216 0 L
.52352 0 L
.52468 0 L
.52591 0 L
.52842 0 L
.52911 0 L
.52984 0 L
.53115 0 L
.53237 0 L
.53351 0 L
.53484 0 L
.5361 0 L
.53844 0 L
.54057 0 L
.54288 0 L
.54418 0 L
.54538 0 L
.5467 0 L
.54737 0 L
.5481 0 L
.54942 0 L
.55065 0 L
.55184 0 L
.55296 0 L
.55426 0 L
.55544 0 L
.55673 0 L
.55811 0 L
.5593 0 L
.56058 0 L
.56195 0 L
.56323 0 L
.56475 0 L
.56617 0 L
.5673 0 L
.56851 0 L
.56985 0 L
Mistroke
.57107 0 L
.57234 0 L
.57373 0 L
.57492 0 L
.57623 0 L
.57744 0 L
.57857 0 L
.57976 0 L
.58104 0 L
.58223 0 L
.58335 0 L
.58547 0 L
.58797 0 L
.58928 0 L
.59067 0 L
.59188 0 L
.59321 0 L
.59443 0 L
.59556 0 L
.59828 0 L
.59977 0 L
.60051 0 L
.60119 0 L
.60247 0 L
.60386 0 L
.60504 0 L
.6063 0 L
.6086 0 L
.61075 0 L
.6131 0 L
.61443 0 L
.61567 0 L
.61689 0 L
.6182 0 L
.61892 0 L
.61959 0 L
.62086 0 L
.62205 0 L
.62314 0 L
.62561 0 L
.62682 0 L
.62814 0 L
.62938 0 L
.63053 0 L
.63187 0 L
.63255 0 L
.63329 0 L
.63459 0 L
.63581 0 L
.6382 0 L
Mistroke
.6404 0 L
.64535 0 L
.6466 0 L
.64778 0 L
.64914 0 L
.65038 0 L
.65175 0 L
.65253 0 L
.65324 0 L
.65453 0 L
.6559 0 L
.65845 0 L
.65986 0 L
.6612 0 L
.66195 0 L
.66277 0 L
.66352 0 L
.66421 0 L
.66557 0 L
.66703 0 L
.66977 0 L
.67114 0 L
.67266 0 L
.67783 0 L
.67855 0 L
.67933 0 L
.68002 0 L
.68075 0 L
.6816 0 L
.68239 0 L
.68309 0 L
.68388 0 L
.68461 0 L
.68528 0 L
.68679 0 L
.68952 0 L
.69075 0 L
.69207 0 L
.69332 0 L
.69445 0 L
.69578 0 L
.69653 0 L
.69722 0 L
.69849 0 L
.69984 0 L
.70251 0 L
.70501 0 L
.70796 0 L
.7094 0 L
.7107 0 L
Mistroke
.712 0 L
.71323 0 L
.71453 0 L
.71526 0 L
.71593 0 L
.71725 0 L
.7187 0 L
.72024 0 L
.72163 0 L
.72296 0 L
.72422 0 L
.72555 0 L
.72631 0 L
.727 0 L
.72816 0 L
.72943 0 L
.73076 0 L
.73201 0 L
.73651 0 L
.74131 0 L
.74273 0 L
.74407 0 L
.74528 0 L
.74658 0 L
.74782 0 L
.74913 0 L
.75147 0 L
.75397 0 L
.75538 0 L
.75666 0 L
.75738 0 L
.75817 0 L
.75961 0 L
.76091 0 L
.76236 0 L
.7637 0 L
.76496 0 L
.76773 0 L
.77016 0 L
.77148 0 L
.77271 0 L
.77384 0 L
.77504 0 L
.77638 0 L
.77759 0 L
.77869 0 L
.77989 0 L
.78207 0 L
.78461 0 L
.78601 0 L
Mistroke
.78731 0 L
.78843 0 L
.78962 0 L
.79094 0 L
.79216 0 L
.80182 0 L
.80437 0 L
.80712 0 L
.80839 0 L
.80972 0 L
.81086 0 L
.81211 0 L
.81289 0 L
.81359 0 L
.81441 0 L
.81518 0 L
.81655 0 L
.81804 0 L
.8234 0 L
.82604 0 L
.82738 0 L
.82814 0 L
.82885 0 L
.83011 0 L
.83127 0 L
.83254 0 L
.83388 0 L
.8364 0 L
.83767 0 L
.83906 0 L
.84199 0 L
.84468 0 L
.84959 0 L
.8523 0 L
.85487 0 L
.85606 0 L
.85733 0 L
.85806 0 L
.85872 0 L
.86001 0 L
.86118 0 L
.86244 0 L
.86362 0 L
.86471 0 L
.86948 0 L
.87181 0 L
.87392 0 L
.87503 0 L
.87624 0 L
.87751 0 L
Mistroke
.87871 0 L
.88003 0 L
.8807 0 L
.88144 0 L
.88274 0 L
.88396 0 L
.88521 0 L
.88655 0 L
.88732 0 L
.88802 0 L
.88938 0 L
.89065 0 L
.89203 0 L
.89334 0 L
.89453 0 L
.89723 0 L
.8987 0 L
.90007 0 L
.90124 0 L
.90248 0 L
.90387 0 L
.90514 0 L
.90584 0 L
.90659 0 L
.90794 0 L
.90939 0 L
.91099 0 L
.91654 0 L
.91921 0 L
.9217 0 L
.92296 0 L
.9243 0 L
.92578 0 L
.92714 0 L
.92953 0 L
.93213 0 L
.93685 0 L
.94728 0 L
.95013 0 L
.95174 0 L
.9532 0 L
.95875 0 L
.97878 0 L
.98399 0 L
.98674 0 L
.98753 0 L
.98828 0 L
.98894 0 L
.98967 0 L
.99103 0 L
Mistroke
.99171 0 L
.99246 0 L
.99379 0 L
.99503 0 L
.99629 0 L
.99743 0 L
.99875 0 L
1 0 L
Mfstroke
0 0 m
.00123 0 L
.00236 0 L
.00365 0 L
.00488 0 L
.00601 0 L
.00706 0 L
.00821 0 L
.00942 0 L
s
.00942 0 m
.01022 0 L
s
.02247 0 m
.02317 0 L
.02384 0 L
.02458 0 L
s
.02458 0 m
.025 0 L
s
.0275 0 m
.02814 0 L
.02945 0 L
s
.02945 0 m
.03014 0 L
s
.03315 0 m
.03416 0 L
.03547 0 L
s
.03547 0 m
.03589 0 L
s
.03928 0 m
.03929 0 L
s
.03929 0 m
.03971 0 L
s
.04119 0 m
.04131 0 L
s
.04131 0 m
.04172 0 L
s
.04205 0 m
.04275 0 L
s
.04275 0 m
.04342 0 L
s
.04426 0 m
.0449 0 L
.04566 0 L
.04637 0 L
.0477 0 L
.04892 0 L
.04959 0 L
.05032 0 L
.05165 0 L
.05245 0 L
.05321 0 L
.05389 0 L
.05462 0 L
.05543 0 L
.05627 0 L
.057 0 L
.05779 0 L
.06349 0 L
.08481 0 L
.12731 0 L
.16822 0 L
.19056 0 L
.2117 0 L
.23265 0 L
.252 0 L
.27164 0 L
.28294 0 L
.28789 0 L
.2905 0 L
.29193 0 L
.29329 0 L
.29598 0 L
.29843 0 L
.30321 0 L
.30822 0 L
.31364 0 L
.32505 0 L
.33556 0 L
.3553 0 L
.37698 0 L
.38749 0 L
.39266 0 L
.39744 0 L
.39882 0 L
.40011 0 L
.40145 0 L
.40217 0 L
.40294 0 L
.40366 0 L
.40446 0 L
Mistroke
.40529 0 L
.40606 0 L
.40753 0 L
.40892 0 L
.41019 0 L
.41157 0 L
.41283 0 L
.41398 0 L
.41534 0 L
.41661 0 L
.41794 0 L
.41864 0 L
.41939 0 L
.42012 0 L
.42079 0 L
.42206 0 L
.4249 0 L
.42739 0 L
.43002 0 L
.43292 0 L
.4342 0 L
.43558 0 L
.43636 0 L
.43707 0 L
.43845 0 L
.43923 0 L
.44007 0 L
.4416 0 L
.44434 0 L
.44692 0 L
.4496 0 L
.45105 0 L
.45256 0 L
.45378 0 L
.45511 0 L
.45632 0 L
.45744 0 L
.45878 0 L
.45999 0 L
.4627 0 L
.46534 0 L
.4678 0 L
.47037 0 L
.47182 0 L
.47319 0 L
.47436 0 L
.47563 0 L
.47678 0 L
.47785 0 L
.47913 0 L
Mistroke
.48028 0 L
.48286 0 L
.48827 0 L
.49132 0 L
.49412 0 L
.49541 0 L
.49678 0 L
.49809 0 L
.49927 0 L
.5006 0 L
.50186 0 L
.50322 0 L
.5047 0 L
.51461 0 L
.51753 0 L
.51897 0 L
.52031 0 L
.52151 0 L
.5228 0 L
.52354 0 L
.52423 0 L
.52552 0 L
.52691 0 L
.52838 0 L
.52964 0 L
.53101 0 L
.53172 0 L
.53248 0 L
.53385 0 L
.53692 0 L
.53961 0 L
.54247 0 L
.54364 0 L
.54491 0 L
.54563 0 L
.5463 0 L
.5476 0 L
.54889 0 L
.55008 0 L
.55151 0 L
.5528 0 L
.55416 0 L
.55545 0 L
.5568 0 L
.55757 0 L
.55828 0 L
.55957 0 L
.56096 0 L
.56249 0 L
.56392 0 L
Mistroke
.56552 0 L
.56631 0 L
.56704 0 L
.5684 0 L
.56912 0 L
.56989 0 L
.57059 0 L
.57132 0 L
.57264 0 L
.57417 0 L
.5756 0 L
.57684 0 L
.57817 0 L
.57892 0 L
.57964 0 L
.58098 0 L
.58219 0 L
.58348 0 L
.58579 0 L
.58834 0 L
.58973 0 L
.59102 0 L
.59221 0 L
.59348 0 L
.5942 0 L
.59488 0 L
.59616 0 L
.59845 0 L
.59971 0 L
.60088 0 L
.60214 0 L
.60353 0 L
.60597 0 L
.60736 0 L
.60864 0 L
.61149 0 L
.61378 0 L
.61503 0 L
.61621 0 L
.61748 0 L
.61815 0 L
.61888 0 L
.62017 0 L
.62135 0 L
.62247 0 L
.62352 0 L
.6259 0 L
.62709 0 L
.62822 0 L
.62952 0 L
Mistroke
.6307 0 L
.6319 0 L
.6332 0 L
.63442 0 L
.63554 0 L
.63685 0 L
.63828 0 L
.64088 0 L
.64611 0 L
.64761 0 L
.64835 0 L
.64903 0 L
.6503 0 L
.65168 0 L
.65288 0 L
.654 0 L
.65524 0 L
.65656 0 L
.65921 0 L
.66051 0 L
.66172 0 L
.66285 0 L
.66405 0 L
.66526 0 L
.66659 0 L
.6689 0 L
.67104 0 L
.67351 0 L
.6762 0 L
.67767 0 L
.67905 0 L
.68029 0 L
.68164 0 L
.68283 0 L
.68409 0 L
.68516 0 L
.68634 0 L
.68892 0 L
.69136 0 L
.69272 0 L
.6935 0 L
.69421 0 L
.69547 0 L
.69682 0 L
.69758 0 L
.6984 0 L
.69989 0 L
.70134 0 L
.70268 0 L
.70779 0 L
Mistroke
.70914 0 L
.70985 0 L
.7106 0 L
.71198 0 L
.71326 0 L
.71458 0 L
.71581 0 L
.71717 0 L
.71863 0 L
.72096 0 L
.7222 0 L
.72351 0 L
.72484 0 L
.72607 0 L
.72735 0 L
.7285 0 L
.72963 0 L
.73086 0 L
.73307 0 L
.73569 0 L
.73857 0 L
.74137 0 L
.74218 0 L
.74294 0 L
.74363 0 L
.74438 0 L
.74573 0 L
.74642 0 L
.74717 0 L
.74851 0 L
.74976 0 L
.75236 0 L
.75363 0 L
.75479 0 L
.75716 0 L
.75847 0 L
.75971 0 L
.76251 0 L
.7651 0 L
.76763 0 L
.77031 0 L
.77303 0 L
.77381 0 L
.77456 0 L
.77523 0 L
.77596 0 L
.77716 0 L
.77843 0 L
.77964 0 L
.78073 0 L
Mistroke
.78306 0 L
.7852 0 L
.78643 0 L
.78772 0 L
.78902 0 L
.78976 0 L
.79045 0 L
.79169 0 L
.79283 0 L
.79415 0 L
.79538 0 L
.79654 0 L
.79779 0 L
.80044 0 L
.80324 0 L
.8058 0 L
.80689 0 L
.80805 0 L
.80932 0 L
.8105 0 L
.81183 0 L
.81309 0 L
.81422 0 L
.81544 0 L
.82045 0 L
.82321 0 L
.82583 0 L
.82731 0 L
.82808 0 L
.82891 0 L
.82968 0 L
.83038 0 L
.83173 0 L
.8331 0 L
.83387 0 L
.83457 0 L
.83588 0 L
.83725 0 L
.83974 0 L
.84241 0 L
.84722 0 L
.85245 0 L
.85521 0 L
.85661 0 L
.8574 0 L
.85814 0 L
.85892 0 L
.85963 0 L
.86045 0 L
.86123 0 L
Mistroke
.8626 0 L
.86337 0 L
.86409 0 L
.86971 0 L
.87234 0 L
.87481 0 L
.87618 0 L
.8769 0 L
.87766 0 L
.879 0 L
.88024 0 L
.88152 0 L
.88224 0 L
.88291 0 L
.88545 0 L
.89019 0 L
.89536 0 L
.89801 0 L
.90086 0 L
.90206 0 L
.90332 0 L
.9044 0 L
.90558 0 L
.90669 0 L
.90787 0 L
.90899 0 L
.91001 0 L
.9113 0 L
.9125 0 L
.9152 0 L
.91772 0 L
.92011 0 L
.92133 0 L
.92267 0 L
.92389 0 L
.92501 0 L
.92635 0 L
.92756 0 L
.92824 0 L
.92897 0 L
.93028 0 L
.9398 0 L
.9448 0 L
.95014 0 L
.95321 0 L
.95601 0 L
.95735 0 L
.95882 0 L
.96019 0 L
.96147 0 L
Mistroke
.96372 0 L
.9662 0 L
.96738 0 L
.96862 0 L
.96997 0 L
.97122 0 L
.9723 0 L
.97345 0 L
.97453 0 L
.97552 0 L
.97668 0 L
.97794 0 L
.97913 0 L
.98022 0 L
.98262 0 L
.98519 0 L
.98644 0 L
.98762 0 L
.98868 0 L
.98983 0 L
.99105 0 L
.99235 0 L
.99468 0 L
1 0 L
Mfstroke
0 0 m
.00123 0 L
.00236 0 L
.00365 0 L
.00488 0 L
.00601 0 L
.00706 0 L
s
.00706 0 m
.00722 0 L
s
.01224 0 m
.0132 0 L
.01434 0 L
.01566 0 L
.01641 0 L
.01711 0 L
.01839 0 L
.01975 0 L
.02043 0 L
.02115 0 L
s
.02115 0 m
.02244 0 L
s
.02499 0 m
.02537 0 L
.02605 0 L
.02679 0 L
s
.02679 0 m
.02748 0 L
s
.03012 0 m
.03067 0 L
.03184 0 L
.03295 0 L
s
.03295 0 m
.03312 0 L
s
.03585 0 m
.03676 0 L
.03813 0 L
s
.03813 0 m
.03927 0 L
s
.03971 0 m
.04057 0 L
s
.04057 0 m
.04126 0 L
s
.04144 0 m
.042 0 L
s
.042 0 m
.04213 0 L
s
.04333 0 m
.04355 0 L
s
.04355 0 m
.04482 0 L
s
.04499 0 m
.04566 0 L
.04637 0 L
.0477 0 L
s
.0477 0 m
.04865 0 L
s
.05059 0 m
.05165 0 L
s
.05165 0 m
.05226 0 L
s
.05332 0 m
.05389 0 L
.05462 0 L
.05543 0 L
.05627 0 L
.057 0 L
.05779 0 L
.05854 0 L
.05921 0 L
.06 0 L
.06074 0 L
.06205 0 L
.0628 0 L
.06349 0 L
.06471 0 L
.06603 0 L
.06841 0 L
.07383 0 L
.08481 0 L
.12806 0 L
.14966 0 L
.16972 0 L
.19034 0 L
.20979 0 L
.23131 0 L
.25084 0 L
.26108 0 L
.2719 0 L
.27419 0 L
.27635 0 L
.27755 0 L
.27886 0 L
.28004 0 L
.28114 0 L
.28368 0 L
.28507 0 L
.28638 0 L
.2875 0 L
.28871 0 L
.29006 0 L
.29129 0 L
.29258 0 L
.2938 0 L
.29648 0 L
.30132 0 L
.30388 0 L
.30455 0 L
.30528 0 L
.30659 0 L
.30733 0 L
Mistroke
.308 0 L
.3088 0 L
.30956 0 L
.31087 0 L
.31161 0 L
.3123 0 L
.33445 0 L
.35601 0 L
.37556 0 L
.37822 0 L
.38107 0 L
.38246 0 L
.38377 0 L
.38622 0 L
.38879 0 L
.39012 0 L
.39159 0 L
.39236 0 L
.39308 0 L
.39383 0 L
.39465 0 L
.39537 0 L
.39613 0 L
.39748 0 L
.39875 0 L
.3999 0 L
.40122 0 L
.40247 0 L
.40363 0 L
.4047 0 L
.40712 0 L
.41765 0 L
.41885 0 L
.42013 0 L
.42086 0 L
.42153 0 L
.42283 0 L
.42774 0 L
.43066 0 L
.4334 0 L
.43461 0 L
.43589 0 L
.43656 0 L
.43729 0 L
.43858 0 L
.43989 0 L
.44114 0 L
.44347 0 L
.44619 0 L
.44871 0 L
Mistroke
.45086 0 L
.452 0 L
.45323 0 L
.45446 0 L
.45562 0 L
.45694 0 L
.45815 0 L
.46757 0 L
.47014 0 L
.47139 0 L
.47255 0 L
.47389 0 L
.47459 0 L
.47534 0 L
.47654 0 L
.47786 0 L
.47861 0 L
.4793 0 L
.48084 0 L
.48217 0 L
.48362 0 L
.48637 0 L
.48897 0 L
.49442 0 L
.49572 0 L
.49709 0 L
.49826 0 L
.49954 0 L
.50073 0 L
.502 0 L
.5032 0 L
.50429 0 L
.5094 0 L
.51209 0 L
.51361 0 L
.515 0 L
.51774 0 L
.51907 0 L
.52029 0 L
.52155 0 L
.52275 0 L
.52402 0 L
.52539 0 L
.52834 0 L
.52962 0 L
.531 0 L
.53177 0 L
.53247 0 L
.53385 0 L
.5353 0 L
Mistroke
.53689 0 L
.53826 0 L
.53955 0 L
.54091 0 L
.54235 0 L
.54365 0 L
.54439 0 L
.54509 0 L
.54631 0 L
.54762 0 L
.54831 0 L
.54907 0 L
.55061 0 L
.55204 0 L
.55334 0 L
.55469 0 L
.55595 0 L
.55729 0 L
.55804 0 L
.55874 0 L
.56 0 L
.56117 0 L
.5624 0 L
.56375 0 L
.56496 0 L
.56627 0 L
.56752 0 L
.56867 0 L
.5697 0 L
.57084 0 L
.57203 0 L
.57315 0 L
.57552 0 L
.5767 0 L
.57801 0 L
.57869 0 L
.57942 0 L
.58074 0 L
.58205 0 L
.58324 0 L
.58832 0 L
.58966 0 L
.5904 0 L
.5911 0 L
.59246 0 L
.5937 0 L
.59484 0 L
.5959 0 L
.5983 0 L
.59956 0 L
Mistroke
.60074 0 L
.60211 0 L
.60335 0 L
.60601 0 L
.60735 0 L
.60882 0 L
.61141 0 L
.61384 0 L
.61531 0 L
.61603 0 L
.6167 0 L
.61795 0 L
.61931 0 L
.62066 0 L
.62143 0 L
.62216 0 L
.62518 0 L
.62756 0 L
.6289 0 L
.63011 0 L
.6308 0 L
.63155 0 L
.63291 0 L
.63426 0 L
.63551 0 L
.63681 0 L
.63802 0 L
.64079 0 L
.64365 0 L
.64638 0 L
.64751 0 L
.64872 0 L
.65004 0 L
.65127 0 L
.65248 0 L
.65362 0 L
.65464 0 L
.65575 0 L
.6583 0 L
.65969 0 L
.66099 0 L
.6621 0 L
.66329 0 L
.66461 0 L
.66581 0 L
.67555 0 L
.67792 0 L
.67923 0 L
.68047 0 L
.68117 0 L
Mistroke
.68193 0 L
.68327 0 L
.68463 0 L
.68589 0 L
.68872 0 L
.69138 0 L
.69285 0 L
.69368 0 L
.69445 0 L
.6958 0 L
.69648 0 L
.69723 0 L
.70771 0 L
.70898 0 L
.71034 0 L
.71105 0 L
.71183 0 L
.7132 0 L
.71449 0 L
.71522 0 L
.71589 0 L
.71712 0 L
.71841 0 L
.72066 0 L
.7219 0 L
.72307 0 L
.72446 0 L
.72571 0 L
.72689 0 L
.72817 0 L
.72954 0 L
.73081 0 L
.73372 0 L
.73655 0 L
.73959 0 L
.74094 0 L
.74242 0 L
.74309 0 L
.74381 0 L
.7451 0 L
.74646 0 L
.74774 0 L
.74889 0 L
.75013 0 L
.76097 0 L
.77109 0 L
.77234 0 L
.7737 0 L
.77499 0 L
.77618 0 L
Mistroke
.77756 0 L
.77826 0 L
.77904 0 L
.78038 0 L
.78164 0 L
.78435 0 L
.78583 0 L
.78721 0 L
.78793 0 L
.78871 0 L
.78956 0 L
.79034 0 L
.79182 0 L
.79321 0 L
.79556 0 L
.79808 0 L
.80085 0 L
.80343 0 L
.80633 0 L
.80776 0 L
.80909 0 L
.81028 0 L
.81156 0 L
.81228 0 L
.81297 0 L
.81425 0 L
.81538 0 L
.81661 0 L
.81911 0 L
.82357 0 L
.82608 0 L
.82749 0 L
.82878 0 L
.82997 0 L
.83127 0 L
.8325 0 L
.83363 0 L
.83485 0 L
.83615 0 L
.83757 0 L
.8389 0 L
.8439 0 L
.84693 0 L
.84968 0 L
.85243 0 L
.85496 0 L
.8562 0 L
.85736 0 L
.85857 0 L
.8599 0 L
Mistroke
.86125 0 L
.86248 0 L
.86316 0 L
.8639 0 L
.86525 0 L
.87025 0 L
.8727 0 L
.87494 0 L
.87606 0 L
.87723 0 L
.87841 0 L
.8797 0 L
.88101 0 L
.88175 0 L
.88242 0 L
.88372 0 L
.88495 0 L
.88742 0 L
.89005 0 L
.89292 0 L
.89557 0 L
.89996 0 L
.90122 0 L
.90242 0 L
.90349 0 L
.90466 0 L
.90596 0 L
.90734 0 L
.90865 0 L
.90983 0 L
.91232 0 L
.91466 0 L
.91723 0 L
.91998 0 L
.92132 0 L
.92258 0 L
.92371 0 L
.92494 0 L
.92625 0 L
.92763 0 L
.92881 0 L
.93011 0 L
.93578 0 L
.95519 0 L
.95658 0 L
.95789 0 L
.9594 0 L
.96077 0 L
.96197 0 L
.96325 0 L
Mistroke
.96392 0 L
.96465 0 L
.96595 0 L
.96729 0 L
.96805 0 L
.96874 0 L
.97008 0 L
.97135 0 L
.97418 0 L
.97725 0 L
.98234 0 L
.98512 0 L
.98649 0 L
.98774 0 L
.98882 0 L
.98996 0 L
.99111 0 L
.99236 0 L
.995 0 L
.99628 0 L
.99746 0 L
.99869 0 L
1 0 L
Mfstroke
0 0 m
.00123 0 L
.00236 0 L
.00365 0 L
.00488 0 L
.00601 0 L
.00706 0 L
.00821 0 L
.00942 0 L
.01065 0 L
.01196 0 L
.0132 0 L
.01434 0 L
.01566 0 L
s
.01566 0 m
.01577 0 L
s
.02243 0 m
.02245 0 L
.02317 0 L
.02397 0 L
.02469 0 L
s
.02469 0 m
.025 0 L
s
.02744 0 m
.02793 0 L
.0286 0 L
.02933 0 L
s
.02933 0 m
.03005 0 L
s
.03278 0 m
.03316 0 L
.03453 0 L
s
.03453 0 m
.03546 0 L
s
.03928 0 m
.0393 0 L
s
.0393 0 m
.03977 0 L
s
.04121 0 m
.04125 0 L
s
.04125 0 m
.04137 0 L
s
.04282 0 m
.04334 0 L
.04465 0 L
s
.04465 0 m
.04547 0 L
s
.047 0 m
.04717 0 L
.04791 0 L
.04861 0 L
.04932 0 L
.05001 0 L
.05079 0 L
s
.05079 0 m
.05097 0 L
s
.05201 0 m
.05274 0 L
s
.05274 0 m
.0535 0 L
s
.05494 0 m
.05527 0 L
.05638 0 L
.0577 0 L
.05844 0 L
.05912 0 L
.06037 0 L
.0617 0 L
.06244 0 L
.06314 0 L
.06445 0 L
.06519 0 L
.06587 0 L
.0674 0 L
.07272 0 L
.08481 0 L
.12609 0 L
.16579 0 L
.18614 0 L
.20805 0 L
.22914 0 L
.25131 0 L
.27231 0 L
.28147 0 L
.28628 0 L
.28891 0 L
.2902 0 L
.29137 0 L
.29265 0 L
.29401 0 L
.2969 0 L
.30199 0 L
.30319 0 L
.30445 0 L
.30512 0 L
.30585 0 L
.30713 0 L
.31201 0 L
.31747 0 L
.32336 0 L
.33402 0 L
.35462 0 L
.36027 0 L
.3663 0 L
.372 0 L
.37718 0 L
.38743 0 L
.39322 0 L
.39598 0 L
.39732 0 L
Mistroke
.39856 0 L
.39971 0 L
.40081 0 L
.40196 0 L
.40322 0 L
.40451 0 L
.40589 0 L
.40836 0 L
.40971 0 L
.41117 0 L
.41255 0 L
.41381 0 L
.41503 0 L
.41635 0 L
.4176 0 L
.41875 0 L
.42001 0 L
.42134 0 L
.42369 0 L
.42899 0 L
.43358 0 L
.43484 0 L
.43617 0 L
.4373 0 L
.43853 0 L
.43987 0 L
.44129 0 L
.44386 0 L
.44885 0 L
.45033 0 L
.45192 0 L
.45265 0 L
.45343 0 L
.45409 0 L
.45482 0 L
.45617 0 L
.45693 0 L
.45762 0 L
.46024 0 L
.46992 0 L
.47126 0 L
.47197 0 L
.47271 0 L
.47407 0 L
.47533 0 L
.47654 0 L
.47767 0 L
.4789 0 L
.48023 0 L
.49153 0 L
Mistroke
.49415 0 L
.49544 0 L
.49661 0 L
.49785 0 L
.49918 0 L
.49987 0 L
.50063 0 L
.50201 0 L
.5049 0 L
.50758 0 L
.51273 0 L
.51587 0 L
.51883 0 L
.52012 0 L
.52149 0 L
.5222 0 L
.52299 0 L
.52437 0 L
.5257 0 L
.52692 0 L
.52823 0 L
.52966 0 L
.53098 0 L
.53219 0 L
.5346 0 L
.53711 0 L
.53854 0 L
.53989 0 L
.5413 0 L
.5428 0 L
.54353 0 L
.54422 0 L
.54551 0 L
.54674 0 L
.54787 0 L
.54912 0 L
.55044 0 L
.55167 0 L
.553 0 L
.55377 0 L
.55446 0 L
.55583 0 L
.55721 0 L
.55849 0 L
.56002 0 L
.5614 0 L
.56396 0 L
.56529 0 L
.56669 0 L
.56789 0 L
Mistroke
.5692 0 L
.57039 0 L
.5715 0 L
.57282 0 L
.57401 0 L
.57541 0 L
.5767 0 L
.57783 0 L
.57902 0 L
.58022 0 L
.58154 0 L
.58268 0 L
.5839 0 L
.58612 0 L
.58864 0 L
.59003 0 L
.59134 0 L
.59256 0 L
.59388 0 L
.59508 0 L
.59619 0 L
.60143 0 L
.60421 0 L
.60574 0 L
.60719 0 L
.60859 0 L
.6101 0 L
.61276 0 L
.61523 0 L
.61591 0 L
.61664 0 L
.61797 0 L
.61869 0 L
.61946 0 L
.62083 0 L
.62158 0 L
.62229 0 L
.62388 0 L
.62673 0 L
.62798 0 L
.62936 0 L
.63068 0 L
.63192 0 L
.63324 0 L
.63397 0 L
.63465 0 L
.63537 0 L
.63605 0 L
.63759 0 L
.64038 0 L
Mistroke
.6432 0 L
.64585 0 L
.64701 0 L
.64823 0 L
.64957 0 L
.6508 0 L
.65193 0 L
.65313 0 L
.65427 0 L
.6553 0 L
.65787 0 L
.66024 0 L
.66145 0 L
.66272 0 L
.664 0 L
.66473 0 L
.66541 0 L
.66778 0 L
.67031 0 L
.67286 0 L
.67524 0 L
.67783 0 L
.67919 0 L
.67994 0 L
.68064 0 L
.68136 0 L
.68216 0 L
.68284 0 L
.68357 0 L
.68431 0 L
.68501 0 L
.68633 0 L
.68884 0 L
.69021 0 L
.69151 0 L
.69272 0 L
.69404 0 L
.69523 0 L
.69633 0 L
.69737 0 L
.69851 0 L
.7008 0 L
.70213 0 L
.70334 0 L
.70605 0 L
.70857 0 L
.70981 0 L
.71094 0 L
.7121 0 L
.71335 0 L
Mistroke
.71471 0 L
.716 0 L
.71734 0 L
.71857 0 L
.72138 0 L
.72264 0 L
.72383 0 L
.72489 0 L
.72605 0 L
.72731 0 L
.72864 0 L
.72977 0 L
.73102 0 L
.73647 0 L
.73946 0 L
.74094 0 L
.7423 0 L
.74358 0 L
.74494 0 L
.74631 0 L
.74708 0 L
.74781 0 L
.74907 0 L
.75042 0 L
.75168 0 L
.75284 0 L
.75405 0 L
.75537 0 L
.75661 0 L
.75776 0 L
.75901 0 L
.76038 0 L
.76315 0 L
.76585 0 L
.76876 0 L
.77127 0 L
.7726 0 L
.77401 0 L
.77474 0 L
.77543 0 L
.77671 0 L
.77791 0 L
.77921 0 L
.78047 0 L
.78179 0 L
.78416 0 L
.78526 0 L
.78645 0 L
.78756 0 L
.78858 0 L
Mistroke
.78978 0 L
.79107 0 L
.79343 0 L
.79472 0 L
.79589 0 L
.79853 0 L
.80087 0 L
.80332 0 L
.80584 0 L
.80722 0 L
.80853 0 L
.80927 0 L
.81007 0 L
.8108 0 L
.81148 0 L
.81281 0 L
.81348 0 L
.81422 0 L
.81493 0 L
.81569 0 L
.81709 0 L
.81972 0 L
.82258 0 L
.82562 0 L
.82712 0 L
.82853 0 L
.82979 0 L
.83116 0 L
.83246 0 L
.83383 0 L
.835 0 L
.83629 0 L
.83766 0 L
.83894 0 L
.84181 0 L
.84435 0 L
.84704 0 L
.85176 0 L
.85436 0 L
.85564 0 L
.85683 0 L
.85818 0 L
.85889 0 L
.85965 0 L
.86101 0 L
.86223 0 L
.86348 0 L
.86484 0 L
.86729 0 L
.87017 0 L
Mistroke
.87325 0 L
.87474 0 L
.87616 0 L
.87743 0 L
.87881 0 L
.88001 0 L
.88133 0 L
.884 0 L
.88879 0 L
.89444 0 L
.89975 0 L
.90245 0 L
.90381 0 L
.90458 0 L
.9053 0 L
.90659 0 L
.90776 0 L
.90911 0 L
.91039 0 L
.91178 0 L
.91325 0 L
.91589 0 L
.91896 0 L
.92046 0 L
.92186 0 L
.92306 0 L
.92434 0 L
.92507 0 L
.92576 0 L
.92704 0 L
.92822 0 L
.92931 0 L
.93177 0 L
.93305 0 L
.93424 0 L
.93695 0 L
.93959 0 L
.94241 0 L
.94489 0 L
.9462 0 L
.94758 0 L
.94879 0 L
.95013 0 L
.95134 0 L
.95248 0 L
.9536 0 L
.95478 0 L
.95579 0 L
.95689 0 L
.96164 0 L
Mistroke
.96404 0 L
.96665 0 L
.96784 0 L
.9691 0 L
.9702 0 L
.97137 0 L
.97354 0 L
.97558 0 L
.9802 0 L
.98551 0 L
.98678 0 L
.98813 0 L
.98928 0 L
.99055 0 L
.99167 0 L
.99288 0 L
.99507 0 L
1 0 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[65]:=",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/B000`400?l00000o`00003oo`3ooolQ
0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00BP3oool5
00000300oooo0`00000_0?ooo`<00000<03oool3000002d0oooo0`0000040?ooo`8000000`3oool0
04/0oooo00@000000?ooo`3oool00000<@3oool00`000000oooo0?ooo`0]0?ooo`050000003oool0
oooo0?ooo`000000;P3oool01@000000oooo0?ooo`3oool0000002d0oooo00<000000?ooo`3oool0
0P3oool010000000oooo0?ooo`0000020?ooo`00C03oool00`000000oooo0?ooo`0^0?ooo`D00000
;P3oool01@000000oooo0?ooo`3oool0000002h0oooo00D000000?ooo`3oool0oooo0000000]0?oo
o`030000003oool0oooo0080oooo00@000000?ooo`3oool000000P3oool004d0oooo00<000000?oo
o`3oool0;@3oool010000000oooo0?ooo`00000_0?ooo`@00000<03oool3000002h0oooo00<00000
0?ooo`3oool00P3oool010000000oooo0?ooo`0000020?ooo`00BP3oool01@000000oooo0?ooo`3o
ool0000002l0oooo00<000000?ooo`000000;`3oool00`000000oooo0?ooo`0`0?ooo`050000003o
ool0oooo0?ooo`000000;@3oool00`000000oooo0?ooo`020?ooo`040000003oool0oooo00000080
oooo001:0?ooo`050000003oool0oooo0?ooo`000000<03oool200000300oooo00<000000?ooo`3o
ool0;`3oool01@000000oooo0?ooo`3oool0000002`0oooo0P0000040?ooo`040000003oool0oooo
00000080oooo001;0?ooo`<00000<P3oool00`000000oooo0?ooo`0_0?ooo`800000<03oool30000
02h0oooo00<000000?ooo`3oool00`3oool2000000<0oooo003o0?ooob40oooo003o0?ooob40oooo
003o0?ooob40oooo000O0?ooo`060000003oool000000?ooo`000000oooo0P0000000`3oool00000
0?ooo`3f0?ooo`006`3ooooo000000H0oooo000K0?ooo`030000003oool0oooo00@000000P3oool0
0`000000oooo0?ooo`07000000H0oooo00<000000?ooo`3oool03@0000090?ooo`030000003oool0
00000<X000001P3oool001/0oooo00<000000?ooo`3oool00P3oool00`000000oooo000000020?oo
o`8000000`3oool3000000030?ooo`000000000000H000003P3ooon>000004h0oooo000K0?ooo`80
00000`3oool010000000oooo0?ooo`0000030?ooo`030000003oool0oooo00<0oooo0`0000060?oo
o`P00000U03ooom8000000H0oooo000K0?ooo`800000103oool010000000oooo0?ooo`0000030?oo
o`8000001P3oool2000000`0oooo1P00003L0?ooo`006`3oool2000000@0oooo00D000000?ooo`3o
ool0oooo000000040?ooo`030000003oool0oooo00D0oooo0`00000?0?ooo`/00000d@3oool001/0
oooo0`0000040?ooo`040000003oool0oooo000000D0oooo0P0000080?ooo`<000005`3ooolO0000
0;80oooo000K0?ooo`<00000103oool01@000000oooo0?ooo`3oool0000000H0oooo00<000000?oo
o`3oool0203oool3000003<0oooo[00000060?ooo`006`3oool3000000@0oooo00<000000?ooo`3o
ool00P3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00X0oooo0P00003S0?ooo`00
6`3oool2000000030?ooo`000000oooo00<0oooo00D000000?ooo`3oool0oooo000000070?ooo`03
0000003oool0oooo00/0oooo0`00003P0?ooo`006`3oool2000000030?ooo`000000oooo00<0oooo
00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`050?ooo`8000003P3oool400000=`0oooo
000K0?ooo`040000003oool00000000000D0oooo00<000000?ooo`3oool00P3oool00`000000oooo
0?ooo`060?ooo`030000003oool0oooo00l0oooo1P00003F0?ooo`006`3oool01@000000oooo0000
003oool0000000@0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`070?ooo`030000
003oool0oooo01@0oooo1@00003A0?ooo`006`3oool01@000000oooo0000003oool0000000D0oooo
00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo01P0oooo
1@00003<0?ooo`006`3oool01@000000oooo0000003oool0000000D0oooo00<000000?ooo`3oool0
0`3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo01`0oooo2P0000320?ooo`006`3o
ool300000080oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`020?ooo`030000003o
ool0oooo00P0oooo0P00000V0?oood000000PP3oool001/0oooo00<000000?ooo`0000000P3oool0
0`000000oooo0?ooo`030?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool02@3oool2
000006@0ooooO00000060?ooo`006`3oool01P000000oooo0?ooo`000000oooo000000D0oooo00<0
00000?ooo`3oool00`3oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo0><0oooo000K
0?ooo`040000003oool0oooo00000080oooo00<000000?ooo`3oool00`3oool00`000000oooo0?oo
o`030?ooo`030000003oool0oooo00/0oooo0P00003S0?ooo`006`3oool010000000oooo0?ooo`00
00020?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0103oool00`000000oooo0?oo
o`0<0?ooo`800000h@3oool001/0oooo00@000000?ooo`3oool000000P3oool00`000000oooo0?oo
o`030?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool03P3oool00`000000oooo0?oo
o`3N0?ooo`006`3oool2000000030?ooo`000000oooo0080oooo00<000000?ooo`3oool00`3oool0
0`000000oooo0?ooo`040?ooo`030000003oool0oooo00h0oooo0P00003N0?ooo`006`3oool20000
00030?ooo`000000oooo0080oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`050?oo
o`030000003oool0oooo00l0oooo0P00003L0?ooo`000P3oool2000000@0oooo00<000000?ooo`3o
ool00`3oool2000000<0oooo0`0000050?ooo`80000000<0oooo0000003oool00P3oool00`000000
oooo0?ooo`030?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool04@3oool00`000000
oooo0?ooo`3I0?ooo`0000D0oooo0000003oool0oooo000000080?ooo`060000003oool0oooo0000
003oool000000`3oool00`000000oooo0?ooo`020?ooo`8000000P3oool01@000000oooo0?ooo`3o
ool0000000D0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`0A0?ooo`800000f@3o
ool000050?ooo`000000oooo0?ooo`000000203oool010000000oooo0?ooo`0000050?ooo`030000
003oool0oooo0080oooo0P0000020?ooo`050000003oool0oooo0?ooo`0000001@3oool00`000000
oooo0?ooo`060?ooo`030000003oool0oooo0180oooo0`00003F0?ooo`0000D0oooo0000003oool0
oooo000000080?ooo`040000003oool0oooo000000D0oooo00<000000?ooo`3oool00P3oool20000
0080oooo00D000000?ooo`3oool0oooo000000050?ooo`030000003oool0oooo00L0oooo00<00000
0?ooo`3oool0503oool400000=80oooo00001@3oool000000?ooo`3oool0000000P0oooo00D00000
0?ooo`3oool000000?ooo`04000000D0oooo0P0000020?ooo`030000003oool0oooo0080oooo00<0
00000?ooo`3oool00`3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo01L0oooo1@00
003=0?ooo`0000D0oooo0000003oool0oooo000000080?ooo`060000003oool0oooo0000003oool0
0000203oool200000080oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`030?ooo`03
0000003oool0oooo00P0oooo00<000000?ooo`3oool06`3oool500000<P0oooo00020?ooo`800000
2P3oool200000080oooo1@0000040?ooo`8000000P3oool00`000000oooo0?ooo`020?ooo`030000
003oool0oooo00@0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`0O0?ooo`X00000
_P3oool001/0oooo0P0000020?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool00`3o
ool00`000000oooo0?ooo`080?ooo`030000003oool0oooo02T0oooo2`00002c0?ooo`006`3oool2
000000<0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`040?ooo`030000003oool0
oooo00P0oooo00<000000?ooo`3oool0<`3ooon]000000H0oooo000K0?ooo`8000000`3oool00`00
0000oooo0?ooo`020?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool02@3oool00`00
0000oooo0?ooo`3U0?ooo`006`3oool2000000<0oooo00<000000?ooo`3oool00P3oool00`000000
oooo0?ooo`050?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool0i03oool001/0oooo
0P0000030?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0103oool00`000000oooo
0?ooo`0:0?ooo`030000003oool0oooo0><0oooo000K0?ooo`8000000`3oool00`000000oooo0?oo
o`030?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool02`3oool200000><0oooo000K
0?ooo`8000000`3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00D0oooo00<00000
0?ooo`3oool0303oool00`000000oooo0?ooo`3P0?ooo`006`3oool2000000<0oooo00<000000?oo
o`3oool00`3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00d0oooo00<000000?oo
o`3oool0g`3oool001/0oooo0P0000030?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3o
ool01@3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo0=h0oooo000K0?ooo`800000
103oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool0
3P3oool00`000000oooo0?ooo`150?oooi8000001P3oool001/0oooo0P0000040?ooo`030000003o
ool0oooo00<0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`0>0?ooo`800000=@3o
ool@000009P0oooo000K0?ooo`800000103oool00`000000oooo0?ooo`030?ooo`030000003oool0
oooo00H0oooo00<000000?ooo`3oool0403oool00`000000oooo0?ooo`0]0?ooo`D00000Z03oool0
01/0oooo0P0000040?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool01P3oool00`00
0000oooo0?ooo`0@0?ooo`030000003oool0oooo02H0oooo1P00002]0?ooo`006`3oool2000000@0
oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo0140
oooo00<000000?ooo`3oool0803oool500000;<0oooo000K0?ooo`800000103oool00`000000oooo
0?ooo`040?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool04@3oool2000001`0oooo
1000002h0?ooo`006`3oool2000000@0oooo00<000000?ooo`3oool0103oool00`000000oooo0?oo
o`070?ooo`030000003oool0oooo01<0oooo0P00000G0?ooo`<00000_03oool001/0oooo0P000004
0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`0D
0?ooo`030000003oool0oooo0140oooo0`00002o0?ooo`006`3oool2000000@0oooo00<000000?oo
o`3oool01@3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo01D0oooo0P00000?0?oo
o`800000`P3oool001/0oooo0P0000050?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3o
ool0203oool00`000000oooo0?ooo`0F0?ooo`<000002`3oool00`000000oooo0?ooo`320?ooo`00
203oool2000000@0oooo00<000000?ooo`3oool00P3oool3000000D0oooo0P0000050?ooo`030000
003oool0oooo00@0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`0I0?ooo`@00000
1@3oool200000<D0oooo00070?ooo`040000003oool0oooo000000T0oooo00<000000?ooo`3oool0
103oool2000000D0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`080?ooo`030000
003oool0oooo01`0oooo1@0000370?ooo`001`3oool010000000oooo0?ooo`0000090?ooo`030000
003oool0oooo00@0oooo0P0000050?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool0
203oool00`000000oooo0?ooo`0N0?ooo`030000003oool0000000800000a@3oool000L0oooo00@0
00000?ooo`3oool000002@3oool00`000000oooo0?ooo`040?ooo`8000001@3oool00`000000oooo
0?ooo`050?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool0703oool00`000000oooo
0?ooo`030?ooo`@00000`@3oool000L0oooo00@000000?ooo`3oool000002@3oool00`000000oooo
0?ooo`040?ooo`8000001@3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00T0oooo
00<000000?ooo`3oool06P3oool00`000000oooo0?ooo`080?ooo`/00000]P3oool000L0oooo00@0
00000?ooo`3oool00000203oool2000000H0oooo0P0000050?ooo`030000003oool0oooo00H0oooo
00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`0I0?ooo`030000003oool0oooo01@0oooo
3`00002W0?ooo`00203oool2000000X0oooo00<000000?ooo`3oool0103oool2000000D0oooo00<0
00000?ooo`3oool01P3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo01L0oooo00<0
00000?ooo`3oool0903ooonQ000000H0oooo000K0?ooo`8000001P3oool00`000000oooo0?ooo`06
0?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool05@3oool00`000000oooo0?ooo`3<
0?ooo`006`3oool2000000H0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`0:0?oo
o`030000003oool0oooo01@0oooo00<000000?ooo`3oool0c@3oool001/0oooo00<000000?ooo`00
00001@3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3o
ool04P3oool00`000000oooo0?ooo`3>0?ooo`006`3oool00`000000oooo000000050?ooo`030000
003oool0oooo00L0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`0@0?ooo`030000
003oool0oooo0<l0oooo000K0?ooo`030000003oool0000000D0oooo00<000000?ooo`3oool01`3o
ool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3oool0d03o
ool001/0oooo00<000000?ooo`0000001P3oool00`000000oooo0?ooo`070?ooo`030000003oool0
oooo00`0oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`3A0?ooo`006`3oool30000
00H0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo
00X0oooo00<000000?ooo`3oool0dP3oool001/0oooo00<000000?ooo`0000001P3oool00`000000
oooo0?ooo`070?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3oool02@3oool00`000000
oooo0?ooo`3B0?ooo`006`3oool00`000000oooo000000060?ooo`030000003oool0oooo00P0oooo
00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo0=<0oooo
000K0?ooo`030000003oool0000000H0oooo00<000000?ooo`3oool0203oool00`000000oooo0?oo
o`0?0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool0e03oool001/0oooo00<00000
0?ooo`0000001`3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo0100oooo00<00000
0?ooo`3oool0103oool00`000000oooo0?ooo`3D0?ooo`006`3oool00`000000oooo000000070?oo
o`030000003oool0oooo00P0oooo00<000000?ooo`3oool0403oool00`000000oooo0?ooo`020?oo
o`030000003oool0oooo0=D0oooo000K0?ooo`<000001`3oool00`000000oooo0?ooo`080?ooo`03
0000003oool0oooo0140oooo00D000000?ooo`3oool0oooo0000003G0?ooo`006`3oool00`000000
oooo000000070?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool04@3oool00`000000
oooo0000003H0?ooo`006`3oool00`000000oooo000000070?ooo`030000003oool0oooo00X0oooo
00<000000?ooo`3oool04@3oool200000=P0oooo000K0?ooo`030000003oool0000000P0oooo00<0
00000?ooo`3oool02@3oool00`000000oooo0?ooo`0A0?ooo`040000003oool0000000000=H0oooo
000K0?ooo`030000003oool0000000P0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?oo
o`0?0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0d`3oool001/0oooo0`000008
0?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool03`3oool00`000000oooo0?ooo`03
0?ooo`800000d`3oool001/0oooo00<000000?ooo`000000203oool00`000000oooo0?ooo`0;0?oo
o`030000003oool0oooo00d0oooo00<000000?ooo`3oool01P3oool200000=40oooo000K0?ooo`03
0000003oool0000000T0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`0<0?ooo`03
0000003oool0oooo00P0oooo0P00003?0?ooo`000P3oool2000000@0oooo00<000000?ooo`3oool0
0P3oool3000000<0oooo0`0000050?ooo`030000003oool0000000T0oooo00<000000?ooo`3oool0
2`3oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo00/0oooo1000003;0?ooo`0000D0
oooo0000003oool0oooo000000090?ooo`050000003oool0oooo0?ooo`0000000`3oool00`000000
oooo0?ooo`020?ooo`030000003oool0000000T0oooo00<000000?ooo`3oool0303oool00`000000
oooo0?ooo`0:0?ooo`030000003oool0oooo00l0oooo0`0000380?ooo`0000D0oooo0000003oool0
oooo000000090?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool00P3oool3000000T0
oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo01<0
oooo0`00000W0?oooiP000001P3oool000050?ooo`000000oooo0?ooo`0000002@3oool00`000000
oooo0?ooo`050?ooo`030000003oool0oooo0080oooo00<000000?ooo`0000002P3oool00`000000
oooo0?ooo`0<0?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool05P3oool4000001<0
oooo4000002N0?ooo`0000D0oooo0000003oool0oooo000000090?ooo`040000003oool0oooo0?oo
o`@000001@3oool00`000000oooo0000000:0?ooo`030000003oool0oooo00d0oooo00<000000?oo
o`3oool01P3oool00`000000oooo0?ooo`0K0?ooo`H000000P3oool;00000:h0oooo00001@3oool0
00000?ooo`3oool0000000P0oooo0P0000030?ooo`030000003oool0oooo00H0oooo00<000000?oo
o`0000002P3oool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo00D0oooo00<000000?oo
o`3oool07P3oool=00000;40oooo00020?ooo`8000002P3oool010000000oooo0?ooo`3oool50000
00@0oooo00<000000?ooo`0000002P3oool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo
00@0oooo00<000000?ooo`3oool06`3oool4000000d0oooo5@00002L0?ooo`006`3oool3000000/0
oooo00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo01P0
oooo0`00000V0?oooiH000001P3oool001/0oooo00@000000?ooo`3oool000002P3oool00`000000
oooo0?ooo`0?0?ooo`050000003oool0oooo0?ooo`0000006@3oool200000<D0oooo000K0?ooo`04
0000003oool0oooo000000X0oooo00<000000?ooo`3oool03`3oool01@000000oooo0?ooo`3oool0
000001H0oooo0`0000370?ooo`006`3oool010000000oooo0?ooo`00000:0?ooo`030000003oool0
oooo0100oooo00@000000?ooo`3oool00000503oool200000<X0oooo000K0?ooo`040000003oool0
oooo000000/0oooo00<000000?ooo`3oool0403oool200000180oooo0`00003<0?ooo`006`3oool0
10000000oooo0?ooo`00000;0?ooo`030000003oool0oooo0140oooo00<000000?ooo`3oool03@3o
ool300000<l0oooo000K0?ooo`80000000<0oooo0000003oool02P3oool00`000000oooo0?ooo`0A
0?ooo`8000003@3oool00`000000oooo0?ooo`3@0?ooo`006`3oool010000000oooo0?ooo`00000<
0?ooo`030000003oool0oooo00l0oooo00<000000?ooo`3oool00P00000:0?ooo`030000003oool0
oooo0=40oooo000K0?ooo`040000003oool0oooo000000`0oooo00<000000?ooo`3oool03`3oool0
0`000000oooo0?ooo`020?ooo`8000001`3oool00`000000oooo0?ooo`3B0?ooo`006`3oool01000
0000oooo0?ooo`00000=0?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3oool0103oool2
000000<0oooo0P00003E0?ooo`006`3oool010000000oooo0?ooo`00000=0?ooo`030000003oool0
oooo00d0oooo00<000000?ooo`3oool01`3oool300000=L0oooo000K0?ooo`80000000<0oooo0000
003oool03@3oool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo00P0oooo0`00003F0?oo
o`006`3oool010000000oooo0?ooo`00000?0?ooo`030000003oool0oooo00/0oooo00<000000?oo
o`3oool01`3oool01@000000oooo0?ooo`3oool000000=D0oooo000K0?ooo`040000003oool0oooo
00000100oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`070?ooo`030000003oool0
oooo00<0oooo0P00003C0?ooo`006`3oool010000000oooo0?ooo`00000@0?ooo`030000003oool0
oooo00T0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`050?ooo`<00000d03oool0
01/0oooo00@000000?ooo`3oool000004@3oool00`000000oooo0?ooo`080?ooo`030000003oool0
oooo00H0oooo00<000000?ooo`3oool02@3oool400000<`0oooo000K0?ooo`80000000<0oooo0000
003oool04@3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00D0oooo00<000000?oo
o`3oool03P3oool500000<L0oooo000K0?ooo`040000003oool0oooo000001<0oooo00<000000?oo
o`3oool01@3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo01@0oooo1P0000310?oo
o`006`3oool01@000000oooo0?ooo`3oool0000001<0oooo00<000000?ooo`3oool0103oool00`00
0000oooo0?ooo`040?ooo`030000003oool0oooo01/0oooo1@00002l0?ooo`00203oool2000000@0
oooo00@000000?ooo`3oool0oooo1@0000040?ooo`050000003oool0oooo0?ooo`000000503oool4
00000080oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`0Q0?ooo`/00000/@3oool0
00L0oooo00@000000?ooo`3oool00000203oool010000000oooo0?ooo`0000040?ooo`050000003o
ool0oooo0?ooo`000000603oool2000000H0oooo00<000000?ooo`3oool0;03ooolJ000009L0oooo
00070?ooo`040000003oool0oooo000000T0oooo00<000000?ooo`3oool0103oool200000080oooo
00<000000?ooo`3oool05`3oool5000000030?ooo`000000oooo01@0ooooa@0000060?ooo`001`3o
ool010000000oooo0?ooo`00000:0?ooo`030000003oool0oooo00<0oooo00D000000?ooo`3oool0
oooo0000000I0?ooo`030000003oool0oooo0080oooo5`00003;0?ooo`001`3oool010000000oooo
0?ooo`0000070?ooo`050000003oool0oooo0?ooo`000000103oool01@000000oooo0?ooo`3oool0
000001T0oooo00D000000?ooo`3oool0oooo0000003R0?ooo`001`3oool010000000oooo0?ooo`00
00070?ooo`050000003oool0oooo0?ooo`000000103oool01@000000oooo0?ooo`3oool0000001P0
oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`3P0?ooo`00203oool2000000T0oooo
0`0000050?ooo`050000003oool0oooo0?ooo`000000603oool01@000000oooo0?ooo`3oool00000
0><0oooo000K0?ooo`8000000`3oool00`000000oooo0?ooo`0E0?ooo`040000003oool0oooo0000
0>@0oooo000K0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool05@3oool00`000000
oooo0000003U0?ooo`006`3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo01@0oooo
00@000000?ooo`3oool00000i@3oool001/0oooo00<000000?ooo`3oool00P3oool00`000000oooo
0?ooo`0D0?ooo`030000003oool000000>H0oooo000K0?ooo`030000003oool0oooo0080oooo00<0
00000?ooo`3oool0503oool00`000000oooo0000003V0?ooo`006`3oool00`000000oooo0?ooo`02
0?ooo`030000003oool0oooo01<0oooo00<000000?ooo`000000i`3oool001/0oooo0P0000030?oo
o`030000003oool0oooo01<0oooo0P00003X0?ooo`006`3oool00`000000oooo0?ooo`020?ooo`03
0000003oool0oooo01<0oooo0P00003X0?ooo`006`3oool00`000000oooo0?ooo`020?ooo`030000
003oool0oooo01<0oooo00<000000?ooo`3oool0i`3oool001/0oooo00<000000?ooo`3oool00P3o
ool00`000000oooo0?ooo`0B0?ooo`800000j@3oool001/0oooo00<000000?ooo`3oool00`3oool0
0`000000oooo0?ooo`0A0?ooo`030000003oool0oooo0>P0oooo000K0?ooo`800000103oool00`00
0000oooo0?ooo`0A0?ooo`030000003oool0oooo0>P0oooo000K0?ooo`030000003oool0oooo00<0
oooo00<000000?ooo`3oool0403oool200000>X0oooo000K0?ooo`030000003oool0oooo00<0oooo
00<000000?ooo`3oool0403oool200000>X0oooo000K0?ooo`030000003oool0oooo00<0oooo00<0
00000?ooo`3oool03`3oool200000>/0oooo000K0?ooo`030000003oool0oooo00<0oooo00<00000
0?ooo`3oool03P3oool00`000000oooo0000003[0?ooo`006`3oool2000000@0oooo00<000000?oo
o`3oool03P3oool00`000000oooo0000003[0?ooo`006`3oool00`000000oooo0?ooo`030?ooo`03
0000003oool0oooo00d0oooo00@000000?ooo`3oool00000j`3oool001/0oooo00<000000?ooo`3o
ool0103oool00`000000oooo0?ooo`0<0?ooo`040000003oool0oooo00000>/0oooo00020?ooo`80
0000103oool010000000oooo0?ooo`3oool500000080oooo0`0000050?ooo`030000003oool0oooo
00@0oooo00<000000?ooo`3oool02`3oool01@000000oooo0?ooo`3oool000000>/0oooo00001@3o
ool000000?ooo`3oool0000000P0oooo00H000000?ooo`3oool000000?ooo`0000030?ooo`030000
003oool0oooo0080oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`0;0?ooo`040000
003oool0oooo00000>`0oooo00001@3oool000000?ooo`3oool0000000T0oooo00<000000?ooo`3o
ool01@3oool00`000000oooo0?ooo`020?ooo`8000001@3oool00`000000oooo0?ooo`0:0?ooo`05
0000003oool0oooo0?ooo`000000k03oool000050?ooo`000000oooo0?ooo`0000002P3oool00`00
0000oooo0?ooo`040?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0103oool00`00
0000oooo0?ooo`090?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0jP3oool00005
0?ooo`000000oooo0?ooo`0000001`3oool01P000000oooo0?ooo`3oool000000?ooo`@000001@3o
ool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool00P3o
ool00`000000oooo0?ooo`3Z0?ooo`0000D0oooo0000003oool0oooo000000070?ooo`070000003o
ool0oooo0?ooo`000000oooo000000080?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3o
ool0203oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo0>X0oooo00020?ooo`800000
2@3oool300000080oooo1@0000040?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool0
1`3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0>/0oooo000K0?ooo`030000003o
ool0oooo00D0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`030?ooo`030000003o
ool0oooo0>/0oooo000K0?ooo`8000001`3oool00`000000oooo0?ooo`040?ooo`030000003oool0
oooo00@0oooo00<000000?ooo`3oool0j`3oool001/0oooo00<000000?ooo`3oool01P3oool00`00
0000oooo0?ooo`030?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool0j`3oool001/0
oooo00<000000?ooo`3oool01P3oool2000000@0oooo00<000000?ooo`3oool01@3oool00`000000
oooo0?ooo`3[0?ooo`006`3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00800000
203oool00`000000oooo0?ooo`3[0?ooo`006`3oool00`000000oooo0?ooo`080?ooo`<00000203o
ool00`000000oooo0?ooo`3/0?ooo`006`3oool2000001@0oooo00<000000?ooo`3oool0k03oool0
01/0oooo00<000000?ooo`3oool04`3oool00`000000oooo0?ooo`3/0?ooo`006`3oool00`000000
oooo0?ooo`0C0?ooo`030000003oool0oooo0>`0oooo000K0?ooo`030000003oool0oooo01<0oooo
00<000000?ooo`3oool0k03oool001/0oooo00<000000?ooo`3oool04`3oool00`000000oooo0?oo
o`3/0?ooo`006`3oool2000001<0oooo00<000000?ooo`3oool0k@3oool001/0oooo00<000000?oo
o`3oool04P3oool00`000000oooo0?ooo`3]0?ooo`006`3oool00`000000oooo0?ooo`0B0?ooo`03
0000003oool0oooo0>d0oooo000K0?ooo`030000003oool0oooo0180oooo00<000000?ooo`3oool0
k@3oool001/0oooo00<000000?ooo`3oool04P3oool00`000000oooo0?ooo`3]0?ooo`006`3oool2
000001<0oooo00<000000?ooo`3oool0k@3oool001/0oooo00<000000?ooo`3oool04P3oool00`00
0000oooo0?ooo`3]0?ooo`006`3oool00`000000oooo0?ooo`0A0?ooo`030000003oool0oooo0>h0
oooo000K0?ooo`030000003oool0oooo0140oooo00<000000?ooo`3oool0kP3oool001/0oooo00<0
00000?ooo`3oool04@3oool00`000000oooo0?ooo`3^0?ooo`006`3oool00`000000oooo0?ooo`0A
0?ooo`030000003oool0oooo0>h0oooo000K0?ooo`030000003oool0oooo0140oooo00<000000?oo
o`3oool0kP3oool00?l0oooo8@3oool00?l0oooo8@3oool00?l0oooo8@3oool00001\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-1.07059, -0.0308268, \
0.0393973, 0.00191239}}],

Cell[BoxData[
    \({0.0746299513712568`, 0.14925897926614026`, 0.1990114709815182`, 
      0.19901120339736514`, 0.1592088267232851`, 0.10613915133640398`, 
      0.06065091113830697`, 0.030325438692454028`, 0.013477962841342983`, 
      0.005391178434547927`, 0.001960423461330987`, 0.00065347040369933`, 
      0.0002010644002847587`, 0.00005744405375819938`, 
      0.000015315888410915114`, 3.826762409448957`*^-6, 
      8.984652196720133`*^-7, 1.9792603527767523`*^-7, 
      4.011818279182859`*^-8, 6.628221494293235`*^-9}\)], "Output",
  CellLabel->"Out[69]="]
}, Open  ]],

Cell[BoxData[
    \(\(<< DiscreteMath`RSolve`;\)\)], "Input",
  CellLabel->"In[24]:="],

Cell[CellGroupData[{

Cell[BoxData[
    \(RSolve[
      0 \[Equal] \(k\/2\) \((\((k + 1)\) P[k + 1] - \((k - 1)\) P[k])\) + 
          R \((\((k - 1)\) P[k - 1] - k\ P[k])\), \ P[k], \ k]\)], "Input",
  CellLabel->"In[26]:="],

Cell[BoxData[
    \({{P[k] \[Rule] $Failed}}\)], "Output",
  CellLabel->"Out[26]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(Solve[
        0 \[Equal] \(\(k - 1\)\/2\) \((k\ P[k] - \((k - 2)\) P[k - 1])\) + 
            R \((\((k - 2)\) P[k - 2] - \((k - 1)\)\ P[k - 1])\), P[k]] // 
      Simplify\)], "Input",
  CellLabel->"In[29]:="],

Cell[BoxData[
    \({{P[
            k] \[Rule] \(\(-2\)\ \((\(-2\) + k)\)\ R\ P[\(-2\) + k] + \((\(-1\
\) + k)\)\ \((\(-2\) + k + 2\ R)\)\ P[\(-1\) + k]\)\/\(\((\(-1\) + k)\)\ \
k\)}}\)], "Output",
  CellLabel->"Out[29]="]
}, Open  ]],

Cell[BoxData[{
    \(Clear[R, p]\), "\n", 
    \(p[1] = p1; p[0] = 0;\), "\[IndentingNewLine]", 
    \(\(p[
          k_] := \(p[
            k] = \(\(-2\)\ \((\(-2\) + k)\)\ R\ p[\(-2\) + k] + \((\(-1\) + \
k)\)\ \((\(-2\) + k + 2\ R)\)\ p[\(-1\) + k]\)\/\(\((\(-1\) + k)\)\ k\) // 
            Simplify\);\)\)}], "Input",
  CellLabel->"In[44]:="],

Cell[CellGroupData[{

Cell[BoxData[
    \(Array[p, 10]\)], "Input",
  CellLabel->"In[48]:="],

Cell[BoxData[
    \({p1, 
      p1\ R, \(2\ p1\ R\^2\)\/3, \(p1\ R\^3\)\/3, \(2\ p1\ R\^4\)\/15, \(2\ \
p1\ R\^5\)\/45, \(4\ p1\ R\^6\)\/315, \(p1\ R\^7\)\/315, \(2\ p1\ \
R\^8\)\/2835, \(2\ p1\ R\^9\)\/14175}\)], "Output",
  CellLabel->"Out[48]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(Sum[\(k \((2  R)\)\^k\)\/\(\(k!\) \((Exp[2  R] - 1)\)\), {k, 
        1, \[Infinity]}]\)], "Input",
  CellLabel->"In[52]:="],

Cell[BoxData[
    \(\(2\ \[ExponentialE]\^\(2\ R\)\ R\)\/\(\(-1\) + \[ExponentialE]\^\(2\ R\
\)\)\)], "Output",
  CellLabel->"Out[52]="]
}, Open  ]]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["Analysis", "SubsectionIcon"],

Cell[CellGroupData[{

Cell["The branching process", "SubsubsectionIcon"],

Cell["\<\
As for the standard coalescent, the times of events can be \
separated from the topology of changes.  The distribution of # of lineages is \
governed by:\
\>", "Text"],

Cell[BoxData[
    \(TextForm\`\[PartialD]\_t P\_k = \(k\/2\) \((\((k + 1)\) 
                P\_\(k + 1\) - \((k - 1)\) P\_k)\) + 
        R \((\((k - 1)\) P\_\(k - 1\) - 
              k\[VeryThinSpace]P\_k)\)\)], "NumberedEquation"],

Cell["\<\
This does not seem to have an explicit solution.  However, the \
stationary distribution is:\
\>", "Text"],

Cell[BoxData[
    \(TextForm\`P\_k = \(\((2  R)\)\^\(\(k\)\(\ \)\)\/\(\(k!\) \((Exp[2  R] - \
1)\)\)\ \ \ E[k] = \(2  R\)\/\(1 - Exp[\(-2\) R]\)\)\)], "NumberedEquation"],

Cell[TextData[{
  "The mean tends to 1 for small R, and to 2R for large R.  The left panel \
shows the distributions for R=",
  StyleBox["0.5",
    FontColor->RGBColor[0, 1, 0]],
  ", ",
  StyleBox["1",
    FontColor->RGBColor[0, 0, 1]],
  ", ",
  StyleBox["2",
    FontColor->RGBColor[1, 0, 0]],
  " and the right panel, the mean as a function of R; the asymptotic 2R is \
also shownn."
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(gr[R_, c_] := 
        ListPlot[
          Table[\((2  R)\)\^\(\(k\)\(\ \)\)\/\(\(k!\) \((Exp[2  R] - 1)\)\), \
{k, 1, 10}], PlotStyle \[Rule] {PointSize[0.02], c}, PlotJoined \[Rule] True, 
          PlotRange \[Rule] {{0, 10}, {0, 
                0.5}}];\)\), "\[IndentingNewLine]", 
    \(\(Show[
        GraphicsArray[{Show[gr[0.5, Green], gr[1, Blue], gr[2, Red]], 
            Plot[{2  R, \(2  R\)\/\(1 - Exp[\(-2\) R]\)}, {R, 0, 2}, 
              PlotStyle \[Rule] {{Dashing[{0.01, 
                        0.01\ }]}, {}}]}]];\)\)}], "Input",
  CellLabel->"In[85]:=",
  CellOpen->False],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .2943 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.47619 0.00700719 0.47619 [
[ 0 0 0 0 ]
[ 1 .2943 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .2943 L
0 .2943 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.00700719 0.477324 0.287295 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-2.77556e-17 0.1 0 1.23607 [
[.2 -0.0125 -3 -9 ]
[.2 -0.0125 3 0 ]
[.4 -0.0125 -3 -9 ]
[.4 -0.0125 3 0 ]
[.6 -0.0125 -3 -9 ]
[.6 -0.0125 3 0 ]
[.8 -0.0125 -3 -9 ]
[.8 -0.0125 3 0 ]
[1 -0.0125 -6 -9 ]
[1 -0.0125 6 0 ]
[-0.0125 .12361 -18 -4.5 ]
[-0.0125 .12361 0 4.5 ]
[-0.0125 .24721 -18 -4.5 ]
[-0.0125 .24721 0 4.5 ]
[-0.0125 .37082 -18 -4.5 ]
[-0.0125 .37082 0 4.5 ]
[-0.0125 .49443 -18 -4.5 ]
[-0.0125 .49443 0 4.5 ]
[-0.0125 .61803 -18 -4.5 ]
[-0.0125 .61803 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 0 m
.2 .00625 L
s
[(2)] .2 -0.0125 0 1 Mshowa
.4 0 m
.4 .00625 L
s
[(4)] .4 -0.0125 0 1 Mshowa
.6 0 m
.6 .00625 L
s
[(6)] .6 -0.0125 0 1 Mshowa
.8 0 m
.8 .00625 L
s
[(8)] .8 -0.0125 0 1 Mshowa
1 0 m
1 .00625 L
s
[(10)] 1 -0.0125 0 1 Mshowa
.125 Mabswid
.05 0 m
.05 .00375 L
s
.1 0 m
.1 .00375 L
s
.15 0 m
.15 .00375 L
s
.25 0 m
.25 .00375 L
s
.3 0 m
.3 .00375 L
s
.35 0 m
.35 .00375 L
s
.45 0 m
.45 .00375 L
s
.5 0 m
.5 .00375 L
s
.55 0 m
.55 .00375 L
s
.65 0 m
.65 .00375 L
s
.7 0 m
.7 .00375 L
s
.75 0 m
.75 .00375 L
s
.85 0 m
.85 .00375 L
s
.9 0 m
.9 .00375 L
s
.95 0 m
.95 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .12361 m
.00625 .12361 L
s
[(0.1)] -0.0125 .12361 1 0 Mshowa
0 .24721 m
.00625 .24721 L
s
[(0.2)] -0.0125 .24721 1 0 Mshowa
0 .37082 m
.00625 .37082 L
s
[(0.3)] -0.0125 .37082 1 0 Mshowa
0 .49443 m
.00625 .49443 L
s
[(0.4)] -0.0125 .49443 1 0 Mshowa
0 .61803 m
.00625 .61803 L
s
[(0.5)] -0.0125 .61803 1 0 Mshowa
.125 Mabswid
0 .02472 m
.00375 .02472 L
s
0 .04944 m
.00375 .04944 L
s
0 .07416 m
.00375 .07416 L
s
0 .09889 m
.00375 .09889 L
s
0 .14833 m
.00375 .14833 L
s
0 .17305 m
.00375 .17305 L
s
0 .19777 m
.00375 .19777 L
s
0 .22249 m
.00375 .22249 L
s
0 .27193 m
.00375 .27193 L
s
0 .29666 m
.00375 .29666 L
s
0 .32138 m
.00375 .32138 L
s
0 .3461 m
.00375 .3461 L
s
0 .39554 m
.00375 .39554 L
s
0 .42026 m
.00375 .42026 L
s
0 .44498 m
.00375 .44498 L
s
0 .46971 m
.00375 .46971 L
s
0 .51915 m
.00375 .51915 L
s
0 .54387 m
.00375 .54387 L
s
0 .56859 m
.00375 .56859 L
s
0 .59331 m
.00375 .59331 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
0 1 0 r
.5 Mabswid
.12817 .61803 m
.2 .35968 L
.3 .11989 L
.4 .02997 L
.5 .00599 L
.6 .001 L
.7 .00014 L
.8 2e-05 L
.9 0 L
1 0 L
s
0 0 1 r
.1 .38693 m
.2 .38693 L
.3 .25796 L
.4 .12898 L
.5 .05159 L
.6 .0172 L
.7 .00491 L
.8 .00123 L
.9 .00027 L
1 5e-05 L
s
1 0 0 r
.1 .09225 m
.2 .18449 L
.3 .24599 L
.4 .24599 L
.5 .19679 L
.6 .1312 L
.7 .07497 L
.8 .03748 L
.9 .01666 L
1 .00666 L
s
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.522676 0.00700719 0.97619 0.287295 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.47619 0.0147151 0.144456 [
[.2619 .00222 -9 -9 ]
[.2619 .00222 9 0 ]
[.5 .00222 -3 -9 ]
[.5 .00222 3 0 ]
[.7381 .00222 -9 -9 ]
[.7381 .00222 9 0 ]
[.97619 .00222 -3 -9 ]
[.97619 .00222 3 0 ]
[.01131 .15917 -6 -4.5 ]
[.01131 .15917 0 4.5 ]
[.01131 .30363 -6 -4.5 ]
[.01131 .30363 0 4.5 ]
[.01131 .44808 -6 -4.5 ]
[.01131 .44808 0 4.5 ]
[.01131 .59254 -6 -4.5 ]
[.01131 .59254 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2619 .01472 m
.2619 .02097 L
s
[(0.5)] .2619 .00222 0 1 Mshowa
.5 .01472 m
.5 .02097 L
s
[(1)] .5 .00222 0 1 Mshowa
.7381 .01472 m
.7381 .02097 L
s
[(1.5)] .7381 .00222 0 1 Mshowa
.97619 .01472 m
.97619 .02097 L
s
[(2)] .97619 .00222 0 1 Mshowa
.125 Mabswid
.07143 .01472 m
.07143 .01847 L
s
.11905 .01472 m
.11905 .01847 L
s
.16667 .01472 m
.16667 .01847 L
s
.21429 .01472 m
.21429 .01847 L
s
.30952 .01472 m
.30952 .01847 L
s
.35714 .01472 m
.35714 .01847 L
s
.40476 .01472 m
.40476 .01847 L
s
.45238 .01472 m
.45238 .01847 L
s
.54762 .01472 m
.54762 .01847 L
s
.59524 .01472 m
.59524 .01847 L
s
.64286 .01472 m
.64286 .01847 L
s
.69048 .01472 m
.69048 .01847 L
s
.78571 .01472 m
.78571 .01847 L
s
.83333 .01472 m
.83333 .01847 L
s
.88095 .01472 m
.88095 .01847 L
s
.92857 .01472 m
.92857 .01847 L
s
.25 Mabswid
0 .01472 m
1 .01472 L
s
.02381 .15917 m
.03006 .15917 L
s
[(1)] .01131 .15917 1 0 Mshowa
.02381 .30363 m
.03006 .30363 L
s
[(2)] .01131 .30363 1 0 Mshowa
.02381 .44808 m
.03006 .44808 L
s
[(3)] .01131 .44808 1 0 Mshowa
.02381 .59254 m
.03006 .59254 L
s
[(4)] .01131 .59254 1 0 Mshowa
.125 Mabswid
.02381 .04361 m
.02756 .04361 L
s
.02381 .0725 m
.02756 .0725 L
s
.02381 .10139 m
.02756 .10139 L
s
.02381 .13028 m
.02756 .13028 L
s
.02381 .18806 m
.02756 .18806 L
s
.02381 .21695 m
.02756 .21695 L
s
.02381 .24584 m
.02756 .24584 L
s
.02381 .27474 m
.02756 .27474 L
s
.02381 .33252 m
.02756 .33252 L
s
.02381 .36141 m
.02756 .36141 L
s
.02381 .3903 m
.02756 .3903 L
s
.02381 .41919 m
.02756 .41919 L
s
.02381 .47697 m
.02756 .47697 L
s
.02381 .50586 m
.02756 .50586 L
s
.02381 .53476 m
.02756 .53476 L
s
.02381 .56365 m
.02756 .56365 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
[ .01 .01 ] 0 setdash
.02381 .01472 m
.06244 .03816 L
.10458 .06372 L
.14415 .08773 L
.18221 .11082 L
.22272 .13539 L
.26171 .15905 L
.30316 .1842 L
.34309 .20842 L
.3815 .23173 L
.42237 .25652 L
.46172 .2804 L
.49955 .30335 L
.53984 .3278 L
.57861 .35132 L
.61984 .37633 L
.65954 .40042 L
.69774 .4236 L
.73838 .44826 L
.77751 .472 L
.81909 .49723 L
.85916 .52153 L
.89771 .54492 L
.93871 .5698 L
.97619 .59254 L
s
[ ] 0 setdash
.02381 .15917 m
.06244 .17121 L
.10458 .18506 L
.14415 .19874 L
.18221 .21251 L
.22272 .22782 L
.26171 .24316 L
.30316 .26011 L
.34309 .27705 L
.3815 .29388 L
.42237 .31233 L
.46172 .33061 L
.49955 .34863 L
.53984 .36827 L
.57861 .38759 L
.61984 .40855 L
.65954 .42912 L
.69774 .44923 L
.73838 .47094 L
.77751 .49214 L
.81909 .51495 L
.85916 .53718 L
.89771 .55878 L
.93871 .58196 L
.97619 .60332 L
s
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[85]:=",
  ImageSize->{696, 204.812},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`4000:h0000c1000`40O003h00Oogooogoo^Woo003o
OoooOonjOol00?mooomookYoo`00ogooogoo^Woo003oOoooOonjOol00?mooomookYoo`00GGoo1@00
=Woo0`00=Woo0`00=Woo0`00<goo0`0017oo0P00LGoo0P0017oo00<007ooOol00Woo0`00?goo0`00
?goo0`0017oo00<007ooOol00Woo0`00?Goo1@007Woo001NOol01000Oomoo`00=goo00<007ooOol0
=7oo00D007ooOomoo`0003Aoo`05001oogooOol0000cOol00`00Oomoo`02Ool01000Oomoo`00Kgoo
00@007ooOol000Moo`05001oogooOol0000oOol00`00Oomoo`0oOol00`00Oomoo`07Ool01@00Oomo
ogoo0000?Goo00@007ooOol001ioo`00Ggoo00<007ooOol0=7oo1@00=Goo00D007ooOomoo`0003Ao
o`05001oogooOol0000cOol00`00Oomoo`02Ool01000Oomoo`00Kgoo00@007ooOol000]oo`03001o
ogoo03eoo`03001oogoo03moo`03001oogoo00]oo`03001oogoo03aoo`03001oogoo01ioo`00H7oo
00<007ooOol0<goo00@007ooOol003Ioo`@003Ioo`<003Aoo`03001oogoo009oo`04001oogoo001_
Ool01000Oomoo`002goo00<007ooOol0?Goo00<007ooOol0?goo00<007ooOol02goo00<007ooOol0
?Goo00<007ooOol07Goo001MOol01@00Oomoogoo0000=Goo00<007oo0000=Woo00<007ooOol0=Woo
00D007ooOomoo`0003=oo`03001oogoo009oo`04001oogoo001_Ool01000Oomoo`001goo1000@7oo
00<007ooOol0?goo00<007ooOol01goo1000?Goo00D007ooOomoo`0001ioo`00GGoo00D007ooOomo
o`0003Ioo`8003Moo`03001oogoo03Eoo`05001oogooOol0000bOol20004Ool01000Oomoo`00Kgoo
00@007ooOol000Moo`03001oogoo041oo`80041oo`8000Uoo`03001oogoo03ioo`05001oogooOol0
000NOol005ioo`<003Qoo`03001oogoo03Ioo`8003Ioo`<003Aoo`03001oogoo00=oo`80075oo`80
00Qoo`D003moo`03001oogoo03moo`03001oogoo00Moo`D003eoo`<001moo`00ogooNgoo00<007oo
Ool0ogoo?7oo003oOomkOol00`00Oomoo`3oOollOol00?moog]oo`03001oogoo0?moocaoo`00ogoo
Ngoo00<007ooOol0ogoo?7oo000WOonU000i0n1101l]Oooo000^000HOol002Moo`03001oogoo00]o
o`03001oogoo00]oo`03001oogoo00aoo`03001oogoo00]oo`03001oogoo00]oo`03001oogoo00ao
o`03001oogoo00]oo`03001oogoo00]oo`03001oogoo00aoo`03001oogoo00]oo`03001oogoo00Ao
o`l3h0Moo`03001oogoo00]oo`03001oogoo00]oo`03001oogoo00Aoo`l07`Moo`03001oogoo00]o
o`03001oogoo00aoo`03001oogoo00]oo`03001oogoo00]oo`03001oogoo039oo`8000aoo`03001o
ogoo00aoo`03001oogoo00]oo`03001oogoo00]oo`03001oogoo00]oo`03001oogoo00aoo`03001o
ogoo00]oo`03001oogoo00]oo`03001oogoo00aoo`03001oogoo00]oo`03001oogoo00]oo`03001o
ogoo00aoo`03001oogoo00]oo`03001oogoo00]oo`03001oogoo00aoo`03001oogoo00]oo`03001o
ogoo00]oo`03001oogoo00aoo`03001oogoo00]oo`03001oogoo00]oo`03001oogoo01eoo`009goo
00<007ooOol0=Woo00<007ooOol0=Woo00<007ooOol067oo2@?P5Woo00<007ooOol057oo300O5Woo
00<007ooOol0<Goo1W`0=7oo00<007oo0000A7oo00<007ooOol0AGoo00<007ooOol0AGoo00<007oo
Ool0A7oo00<007ooOol07Goo000WOol00`00Oomoo`26Ool40n0]Ool901m=Ool9O00jOol00`00Oomo
o`02Ool2003oOolhOol002Moo`03001oogoo089oo`@3h2Qoo`T07deoo`Ul04=oo`03001oogoo00Ao
o`03001oogoo0?moocEoo`009goo00<007ooOol0OGoo1@?P9Woo1P0OCgoo1g`0C7oo00<007ooOol0
1Goo00<007ooOol0ogoo=7oo000WOol00`00Oomoo`1iOol40n0XOol301m@Ool5O01COol00`00Oomo
o`3oOollOol002Moo`8007Ioo`@3h2Uoo`<07dioo`El05Qoo`03001oogoo00Moo`<00?mooc9oo`00
9goo00<007ooOol0LGoo10?P:Woo0`0OC7oo1G`0GGoo00<007ooOol02Woo00<007ooOol0ogoo;goo
000WOol00`00Oomoo`1^Ool30n0[Ool301m:Ool5O01ROol2003oOolmOol002Moo`03001oogoo06eo
o`030n1oogoo02Uoo`<07dQoo`El06Moo`03001oogoo00aoo`<00?moobeoo`009goo00<007ooOol0
K7oo00<3h7ooOol09goo0`0OB7oo0g`0K7oo00<007ooOol03goo00<007ooOol0ogoo:Woo000WOol0
0`00Oomoo`1[Ool00`?POomoo`0UOol301m8Ool3O01_Ool00`00Oomoo`3oOollOol002Moo`03001o
ogoo06Yoo`030n1oogoo02=oo`<07dQoo`=l079oo`03001oogoo015oo`<00?moobQoo`009goo0P00
JWoo00<3h7ooOol08Goo0`0OBGoo0W`0MGoo00<007ooOol057oo00<007ooOol0ogoo9Goo000WOol0
0`00Oomoo`1XOol00`?POomoo`0POol201m9Ool3O01gOol00`00Oomoo`3oOollOol002Moo`03001o
ogoo06Moo`030n1oogoo021oo`0301moogoo04Ioo`=l07Yoo`03001oogoo01Moo`800?moob=oo`00
9goo00<007ooOol0IGoo0P?P8Woo00<07gooOol0AGoo0W`0OGoo00<007ooOol06Goo00<007ooOol0
ogoo87oo000WOol00`00Oomoo`1TOol00`?POomoo`0POol201m5Ool3O01oOol2003oOolmOol002Mo
o`03001oogoo06=oo`030n1oogoo021oo`0301moogoo04=oo`9l089oo`03001oogoo01aoo`03001o
ogoo0?mooaeoo`009goo00<007ooOol0HWoo00<3h7ooOol087oo00<07gooOol0@Goo0g`0Q7oo00<0
07ooOol07Goo00<007ooOol0ogoo77oo000WOol2001ROol00`?POomoo`0OOol201m1Ool3O027Ool0
0`00Oomoo`0NOol00`00Oomoo`3oOolKOol002Moo`03001oogoo061oo`030n1oogoo01moo`0301mo
ogoo03moo`9l08Yoo`03001oogoo025oo`03001oogoo0?mooaQoo`009goo00<007ooOol0Ggoo00<3
h7ooOol07goo00<07gooOol0?Woo0W`0S7oo00<007ooOol08Woo00<007ooOol0ogoo5goo000WOol0
0`00Oomoo`1NOol00`?POomoo`0NOol201m0Ool00g`0Oomoo`2<Ool00`00Oomoo`0SOol00`00Oomo
o`3oOolFOol002Moo`03001oogoo05eoo`030n1oogoo01ioo`0301moogoo03ioo`9l08moo`03001o
ogoo02Ioo`800?mooaAoo`009goo00<007ooOol0Fgoo0P?P87oo00<07gooOol0?Goo0W`0TGoo0P00
:Goo00<007ooOol0ogoo4Goo000WOol00`00Oomoo`0IOol2O00oOol00`?POomoo`0OOol00`0OOomo
o`0lOol2O02COol00`00Oomoo`0YOol00`00Oomoo`3oOol@Ool002Moo`8001aoo`03O01oogoo03]o
o`030n1oogoo01ioo`807cioo`03O01oogoo09=oo`03001oogoo02]oo`03001oogoo0?moo`ioo`00
9goo00<007ooOol077oo00=l07ooOol0>Goo00<3h7ooOol07Woo00<07gooOol0?7oo0W`0UWoo00<0
07ooOol0;7oo0P00ogoo3Woo000WOol00`00Oomoo`0MOol00g`0Oomoo`0gOol00`?POomoo`0NOol0
0`0OOomoo`0kOol2O02HOol00`00Oomoo`0^Ool00`00Oomoo`3oOol;Ool002Moo`03001oogoo01io
o`03O01oogoo03Eoo`030n1oogoo01eoo`807caoo`9l09Yoo`03001oogoo0?moocaoo`009goo00<0
07ooOol07goo00=l07ooOol0<goo00<3h7ooOol07Goo00<07gooOol0>goo00=l07ooOol0VWoo00<0
07ooOol0<7oo0`00ogoo2Goo000COol20004Ool00`00Oomoo`02Ool30006Ool00`00Oomoo`0POol0
0g`0Oomoo`0aOol00`?POomoo`0MOol00`0OOomoo`0jOol2O02MOol00`00Oomoo`0cOol00`00Oomo
o`3oOol6Ool0019oo`04001oogoo0009Ool00`00Oomoo`05Ool00`00Oomoo`0QOol00g`0Oomoo`0_
Ool00`?POomoo`0LOol201lkOol2O02OOol00`00Oomoo`3oOollOol0019oo`04001oogoo0009Ool0
0`00Oomoo`05Ool00`00Oomoo`0ROol00g`0Oomoo`0^Ool00`?POomoo`0KOol00`0OOomoo`0iOol2
O02QOol2000fOol3003oOol4Ool0019oo`04001oogoo0009Ool00`00Oomoo`05Ool3000SOol2O00]
Ool00`?POomoo`0KOol00`0OOomoo`0iOol00g`0Oomoo`2QOol00`00Oomoo`0hOol00`00Oomoo`3o
Ool1Ool0019oo`04001oogoo0009Ool00`00Oomoo`05Ool00`00Oomoo`0UOol00g`0Oomoo`0ZOol0
0`?POomoo`0JOol00`0OOomoo`0hOol2O02TOol00`00Oomoo`3oOollOol0019oo`04001oogoo0008
Ool20007Ool00`00Oomoo`0VOol00g`0Oomoo`0YOol00`?POomoo`0JOol00`0OOomoo`0fOol2O02V
Ool00`00Oomoo`0kOol2003nOol001=oo`8000Yoo`03001oogoo00Eoo`03001oogoo02Moo`03O01o
ogoo02Moo`030n1oogoo01Yoo`0301moogoo03Ioo`03O01oogoo0:Ioo`03001oogoo03eoo`03001o
ogoo0?]oo`009goo00<007ooOol0:7oo00=l07ooOol09Woo00<3h7ooOol06Goo00<07gooOol0=Goo
0W`0ZGoo00<007ooOol0ogoo?7oo000WOol00`00Oomoo`0YOol00g`0Oomoo`0TOol00`?POomoo`0I
Ool00`0OOomoo`0eOol00g`0Oomoo`2POol30006Ool00`00Oomoo`10Ool2003iOol002Moo`03001o
ogoo02Yoo`03O01oogoo02=oo`030n1oogoo01Uoo`0301moogoo03=oo`9l0:Aoo`03001oogoo00Eo
o`03001oogoo049oo`03001oogoo0?Ioo`009goo0P00;7oo00=l07ooOol08Goo00<3h7ooOol06Goo
00<07gooOol0<goo00=l07ooOol0Y7oo00<007ooOol01Goo00<007ooOol0ogoo?7oo000WOol00`00
Oomoo`0/Ool2O00QOol00`?POomoo`0HOol00`0OOomoo`0bOol2O02WOol00`00Oomoo`05Ool30015
Ool00`00Oomoo`3cOol002Moo`03001oogoo02ioo`03O01oogoo01ioo`030n1oogoo01Moo`0301mo
ogoo039oo`03O01oogoo0:Moo`03001oogoo00Eoo`03001oogoo00@0049oo`03001oogoo0?9oo`00
9goo00<007ooOol0;goo00=l07ooOol077oo00<3h7ooOol067oo00<07gooOol0<7oo0W`0ZGoo0P00
1goo00<007ooOol017oo0`00@7oo00<007ooOol0lGoo000WOol00`00Oomoo`0`Ool00g`0Oomoo`0K
Ool00`?POomoo`0GOol00`0OOomoo`0_Ool2O02/Ool00`00Oomoo`05Ool00`00Oomoo`07Ool30010
Ool2003_Ool002Moo`03001oogoo035oo`03O01oogoo01Uoo`030n1oogoo01Moo`0301moogoo02mo
o`03O01oogoo0;Aoo`03001oogoo00Yoo`<003moo`03001oogoo0>aoo`009goo00<007ooOol0<Woo
00=l07ooOol067oo00<3h7ooOol05Woo00<07gooOol0;Woo0W`0]goo00<007ooOol03Goo0`00?Goo
00<007ooOol0jgoo000WOol2000dOol00g`0Oomoo`0FOol00`?POomoo`0GOol00`0OOomoo`0]Ool0
0g`0Oomoo`2gOol00`00Oomoo`0@Ool2000mOol2003ZOol002Moo`03001oogoo03Aoo`03O01oogoo
01Eoo`030n1oogoo01Ioo`0301moogoo02aoo`9l0;Yoo`03001oogoo019oo`<003aoo`03001oogoo
0>Moo`009goo00<007ooOol0=Goo00=l07ooOol057oo00<3h7ooOol05Goo00<07gooOol0;7oo00=l
07ooOol0^Woo0P005Woo0`00>Woo00<007ooOol0iWoo000WOol00`00Oomoo`0fOol2O00COol00`?P
Oomoo`0EOol00`0OOomoo`0[Ool2O02mOol00`00Oomoo`0HOol3000iOol2003UOol002Moo`03001o
ogoo03Qoo`03O01oogoo011oo`030n1oogoo01Eoo`0301moogoo02Yoo`03O01oogoo0;eoo`03001o
ogoo01]oo`<003Qoo`03001oogoo0>9oo`009goo00<007ooOol0>Goo0W`03goo00<3h7ooOol05Goo
00<07gooOol0:Goo0W`0`7oo00<007ooOol07Woo0`00=Woo00<007ooOol0hGoo000WOol00`00Oomo
o`0kOol2O00=Ool00`?POomoo`0DOol00`0OOomoo`0YOol00g`0Oomoo`30Ool00`00Oomoo`0QOol2
000fOol2003POol002Moo`8003ioo`03O01oogoo00Yoo`030n1oogoo01=oo`0301moogoo02Qoo`9l
0<=oo`03001oogoo02=oo`<003Eoo`03001oogoo0=eoo`009goo00<007ooOol0?Woo0W`02Goo00<3
h7ooOol04goo00<07gooOol09goo0W`0aGoo00<007ooOol09Woo0`00<goo00<007ooOol0g7oo000W
Ool00`00Oomoo`10Ool00g`0Oomoo`06Ool00`?POomoo`0COol00`0OOomoo`0UOol2O037Ool00`00
Oomoo`0YOol3003oOol@Ool002Moo`03001oogoo045oo`9l00Eoo`030n1oogoo01=oo`0301moogoo
02Aoo`9l0<Uoo`03001oogoo02aoo`<0031oo`800=Yoo`009goo00<007ooOol0@goo0W`00goo00<3
h7ooOol04Woo00<07gooOol08goo0W`0bgoo0P00<7oo0`00;goo00<007ooOol0egoo000WOol00`00
Oomoo`15Ool00g`0Ool3h00DOol00`0OOomoo`0ROol2O03=Ool00`00Oomoo`0bOol3003oOol7Ool0
02Moo`03001oogoo04Ioo`9l01Aoo`0301moogoo021oo`9l0<moo`03001oogoo03Eoo`<002aoo`80
0=Eoo`009goo0P00B7oo00<3h7`0O0004Goo00<07gooOol07Woo0g`0dGoo00<007ooOol0>7oo0`00
:goo00<007ooOol0dWoo000WOol00`00Oomoo`16Ool01@?POomoogooO0003goo00<07gooOol07Goo
0W`0e7oo00<007ooOol0>goo0P00oWoo000WOol00`00Oomoo`16Ool00`?POomoo`02Ool2O00<Ool0
0`0OOomoo`0LOol2O03FOol00`00Oomoo`0mOol3000YOol2003@Ool002Moo`03001oogoo04Eoo`03
0n1oogoo00Eoo`03O01oogoo00Uoo`0301moogoo01Yoo`9l0=Qoo`03001oogoo041oo`8002Uoo`03
001oogoo0<eoo`004goo0P0017oo00@007ooOomoo`D000Eoo`03001oogoo04Eoo`030n1oogoo00Io
o`9l00Qoo`0301moogoo01Uoo`9l0=Yoo`03001oogoo049oo`800?Moo`004Woo00@007ooOol000Qo
o`04001oogoo0005Ool00`00Oomoo`14Ool00`?POomoo`09Ool2O005Ool00`0OOomoo`0HOol2O03L
Ool00`00Oomoo`14Ool2000XOol00`00Oomoo`3:Ool0019oo`04001oogoo0009Ool00`00Oomoo`05
Ool00`00Oomoo`14Ool00`?POomoo`0;Ool01G`0Oomoogoo01l06Goo0W`0gWoo0P00Agoo0`009Woo
00<007ooOol0bGoo000BOol01000Oomoo`002Woo00<007ooOol017oo0`00A7oo00<3h7ooOol037oo
7G`0h7oo00<007ooOol0BGoo0`0097oo00<007ooOol0b7oo000BOol01000Oomoo`001goo00D007oo
Oomoo`0000Eoo`03001oogoo04=oo`030n1oogoo00moo`0301moogoo0?Qoo`03001oogoo04aoo`80
02Eoo`800<Ioo`004Woo00@007ooOol000Moo`05001oogooOol00005Ool00`00Oomoo`13Ool00`?P
Oomoo`0>Ool00`0OOomoo`3iOol00`00Oomoo`1>Ool3000TOol00`00Oomoo`33Ool001=oo`8000Uo
o`<000Ioo`03001oogoo049oo`030n1oogoo00ioo`0301moogoo0?Yoo`03001oogoo055oo`8002=o
o`03001oogoo0<9oo`009goo00<007ooOol0@Woo00<3h7ooOol03Woo00<07gooOol0nWoo00<007oo
Ool0Dgoo0`008Woo0P00`Goo000WOol00`00Oomoo`12Ool00`?POomoo`0=Ool00`0OOomoo`3kOol0
0`00Oomoo`1FOol2000ROol00`00Oomoo`2nOol002Moo`03001oogoo045oo`030n1oogoo00eoo`03
01moogoo0?aoo`03001oogoo05Qoo`80025oo`03001oogoo0;eoo`009goo0P00@Woo00<3h7ooOol0
37oo00<07gooOol0oGoo0P00Fgoo0`0087oo0P00_7oo000WOol00`00Oomoo`10Ool00`?POomoo`0<
Ool00`0OOomoo`3nOol00`00Oomoo`1MOol2000POol00`00Oomoo`2iOol002Moo`03001oogoo041o
o`030n1oogoo00aoo`0301moogoo0?ioo`03001oogoo05moo`8001moo`03001oogoo0;Qoo`009goo
00<007ooOol0?goo00<3h7ooOol037oo00<07gooOol0ogoo00<007ooOol0HGoo0`007Woo0P00]goo
000WOol00`00Oomoo`0oOol00`?POomoo`0;Ool00`0OOomoo`3oOol1Ool00`00Oomoo`1TOol2000N
Ool00`00Oomoo`2dOol002Moo`03001oogoo03moo`030n1oogoo00Yoo`0301moogoo0?moo`9oo`03
001oogoo06Ioo`8001eoo`03001oogoo0;=oo`009goo00<007ooOol0?Woo00<3h7ooOol02goo00<0
7gooOol0ogoo0Woo00<007ooOol0J7oo0P00dGoo000WOol2000oOol00`?POomoo`0:Ool00`0OOomo
o`3hOol50005Ool00`00Oomoo`1ZOol2000LOol2002aOol002Moo`03001oogoo03eoo`030n1oogoo
00Yoo`0301moogoo0?Yoo`04001oogoo0005Ool00`00Oomoo`1/Ool2000LOol00`00Oomoo`2^Ool0
02Moo`03001oogoo03eoo`030n1oogoo00Uoo`0301moogoo0?aoo`03001oogoo00Eoo`<006ioo`<0
0<Yoo`009goo00<007ooOol0?Goo00<3h7ooOol027oo00<07gooOol0oWoo00<007ooOol017oo00<0
07ooOol0LGoo0P006Woo0P00[7oo000WOol00`00Oomoo`0lOol00`?POomoo`09Ool00`0OOomoo`3k
Ool01@00Oomoogoo00001Goo00<007ooOol0Lgoo0P006Woo00<007ooOol0ZGoo000WOol00`00Oomo
o`0lOol00`?POomoo`08Ool00`0OOomoo`3lOol01@00Oomoogoo00001Goo00<007ooOol0MGoo0P00
a7oo000WOol00`00Oomoo`0kOol00`?POomoo`08Ool00`0OOomoo`3nOol30006Ool00`00Oomoo`1g
Ool3000HOol2002WOol002Moo`8003aoo`030n1oogoo00Moo`0301moogoo0?moo`Uoo`03001oogoo
07Yoo`8001Qoo`03001oogoo0:Aoo`009goo00<007ooOol0>Woo00<3h7ooOol01goo00<07gooOol0
ogoo2Woo00<007ooOol0O7oo0P00_Goo000WOol00`00Oomoo`0jOol00`?POomoo`07Ool00`0OOomo
o`3oOol:Ool00`00Oomoo`1nOol3000FOol3002QOol002Moo`03001oogoo03Yoo`030n1oogoo00Io
o`0301moogoo0?moo`]oo`03001oogoo085oo`8001Moo`03001oogoo09ioo`009goo00<007ooOol0
>Goo00<3h7ooOol01Woo00<07gooOol0ogoo37oo0P00Q7oo0P00]Woo000WOol00`00Oomoo`0iOol0
0`?POomoo`05Ool00`0OOomoo`3oOol=Ool00`00Oomoo`25Ool2000EOol2002MOol002Moo`03001o
ogoo03Qoo`030n1oogoo00Ioo`0301moogoo0?moo`eoo`03001oogoo08Moo`03001oogoo01Aoo`03
001oogoo09Yoo`009goo0P00>Goo00<3h7ooOol01Goo00<07gooOol0ogoo3Woo00<007ooOol0R7oo
0P005Goo00<007ooOol0VGoo000WOol00`00Oomoo`0gOol00`?POomoo`05Ool00`0OOomoo`3oOol?
Ool00`00Oomoo`2:Ool2000EOol2002HOol002Moo`03001oogoo03Moo`030n1oogoo00Aoo`0301mo
ogoo0?mooa1oo`03001oogoo08aoo`8001Eoo`03001oogoo09Eoo`009goo00<007ooOol0=goo00<3
h7ooOol00goo00<07gooOol0ogoo4Goo00<007ooOol0SWoo0P0057oo00<007ooOol0U7oo000WOol0
0`00Oomoo`0fOol00`?POomoo`04Ool00`0OOomoo`3oOolAOol00`00Oomoo`2@Ool2000DOol2002C
Ool001=oo`8000Aoo`03001oogoo009oo`<000Ioo`03001oogoo03Ioo`030n1oogoo00=oo`0301mo
ogoo0?mooa9oo`03001oogoo099oo`8001Aoo`03001oogoo091oo`004Woo00@007ooOol000Moo`05
001oogooOol00005Ool00`00Oomoo`0fOol00`?POomoo`02Ool00`0OOomoo`3oOolCOol2002EOol2
000COol00`00Oomoo`2?Ool0019oo`04001oogoo000;Ool00`00Oomoo`03Ool3000eOol00`?POomo
o`02Ool00`0OOomoo`3oOolDOol00`00Oomoo`2FOol2000DOol00`00Oomoo`2<Ool0019oo`04001o
ogoo0009Ool20006Ool00`00Oomoo`0eOol00`?POomoo`02Ool00`0OOomoo`3oOolDOol00`00Oomo
o`2HOol2000COol00`00Oomoo`2;Ool0019oo`04001oogoo000;Ool00`00Oomoo`03Ool00`00Oomo
o`0eOol01@?POomoogoo01l0ogoo5goo00<007ooOol0VWoo0`004Goo00<007ooOol0RWoo000BOol0
1000Oomoo`001goo00D007ooOomoo`0000Eoo`03001oogoo03Aoo`050n1oogooOol07`3oOolHOol0
0`00Oomoo`2MOol2002LOol001=oo`8000Uoo`<000Ioo`03001oogoo03Aoo`040n1oogoo01ooOolI
Ool00`00Oomoo`2OOol2000@Ool20028Ool002Moo`03001oogoo01Uooah07omooaYoo`03001oogoo
0:5oo`<000moo`03001oogoo08Eoo`009goo00<007ooOol0=7oo00<3h7ooOol0ogoo6Woo00<007oo
Ool0Y7oo0P00UGoo000WOol2000dOol00`?POomoo`3oOolKOol2002WOol2000>Ool20023Ool002Mo
o`03001oogoo03=oo`030n1oogoo0?mooa]oo`03001oogoo0:Qoo`03001oogoo00eoo`03001oogoo
081oo`009goo00<007ooOol0<goo00<3h7ooOol0ogoo6goo00<007ooOol0ZGoo0P00T7oo000WOol0
0`00Oomoo`0bOol00`?POomoo`3oOolLOol00`00Oomoo`2[Ool2000>Ool3001mOol002Moo`03001o
ogoo039oo`030n1oogoo0?mooaaoo`03001oogoo0:eoo`03001oogoo00ioo`03001oogoo07Yoo`00
9goo00<007ooOol0<Woo00<3h7ooOol0ogoo77oo00<007ooOol0[Woo0P00Rgoo000WOol00`00Oomo
o`0bOol00`?POomoo`3oOolLOol00`00Oomoo`2`Ool2000>Ool3001hOol002Moo`03001oogoo035o
o`030n1oogoo0?mooaeoo`03001oogoo0;9oo`8000moo`03001oogoo07Eoo`009goo0P00<Woo00<3
h7ooOol0ogoo7Goo00<007ooOol0]7oo0P00QGoo000WOol00`00Oomoo`0aOol00`?POomoo`3oOolM
Ool2002gOol2000=Ool2001dOol002Moo`03001oogoo031oo`030n1oogoo0?mooaioo`03001oogoo
0;Qoo`8000eoo`03001oogoo075oo`009goo00<007ooOol0<7oo00<3h7ooOol0ogoo7Woo00<007oo
Ool0^Woo0P0037oo00<007ooOol0L7oo000WOol00`00Oomoo`0`Ool00`?POomoo`3oOolNOol00`00
Oomoo`2lOol2000<Ool2001_Ool002Moo`03001oogoo031oo`030n1oogoo0?mooaioo`03001oogoo
0;ioo`8000aoo`03001oogoo06aoo`009goo00<007ooOol0;goo00<3h7ooOol0ogoo7goo00<007oo
Ool0`7oo0P002goo00<007ooOol0Jgoo000WOol2000`Ool00`?POomoo`3oOolFOol30006Ool00`00
Oomoo`32Ool00`00Oomoo`0;Ool00`00Oomoo`1XOol002Moo`03001oogoo02moo`030n1oogoo0?mo
oaEoo`05001oogooOol00005Ool00`00Oomoo`33Ool2000<Ool00`00Oomoo`1WOol002Moo`03001o
ogoo02ioo`030n1oogoo0?mooaYoo`03001oogoo00=oo`03001oogoo0<Eoo`8000]oo`03001oogoo
06Ioo`009goo00<007ooOol0;Woo00<3h7ooOol0ogoo67oo0P001Woo0`00agoo0P0037oo00<007oo
Ool0Hgoo000WOol00`00Oomoo`0^Ool00`?POomoo`3oOolJOol00`00Oomoo`03Ool00`00Oomoo`39
Ool2000;Ool00`00Oomoo`1ROol002Moo`03001oogoo02ioo`030n1oogoo0?mooaIoo`05001oogoo
Ool00005Ool00`00Oomoo`3;Ool2000:Ool00`00Oomoo`1QOol002Moo`03001oogoo02eoo`030n1o
ogoo0?mooaQoo`<000Ioo`03001oogoo0<eoo`<000Yoo`03001oogoo05ioo`009goo0P00;Woo00<3
h7ooOol0ogoo8Goo00<007ooOol0d7oo0P002Goo00<007ooOol0GGoo000WOol00`00Oomoo`0]Ool0
0`?POomoo`3oOolQOol00`00Oomoo`3BOol20008Ool00`00Oomoo`1LOol002Moo`03001oogoo02ao
o`030n1oogoo0?moob9oo`03001oogoo0=Aoo`8006Eoo`009goo00<007ooOol0;7oo00<3h7ooOol0
ogoo8Woo00<007ooOol0eWoo00<007ooOol01Woo0`00FGoo000COol20004Ool00`00Oomoo`03Ool3
0005Ool00`00Oomoo`0/Ool00`?POomoo`3oOolROol2003HOol20009Ool00`00Oomoo`1FOol0019o
o`04001oogoo000:Ool00`00Oomoo`04Ool00`00Oomoo`0/Ool00`?POomoo`3oOolROol00`00Oomo
o`3IOol2001POol0019oo`04001oogoo0007Ool50005Ool00`00Oomoo`0[Ool00`?POomoo`3oOolS
Ool00`00Oomoo`3KOol00`00Oomoo`06Ool3001DOol0019oo`04001oogoo0007Ool01000Oomoo`00
1Woo0`00:goo00<3h7ooOol0ogoo8goo00<007ooOol0g7oo0P002Goo00<007ooOol0DGoo000BOol0
1000Oomoo`0027oo00<007oo00001Woo00<007ooOol0:goo00<3h7ooOol0ogoo8goo00<007ooOol0
gWoo00<007ooOol0FWoo000BOol01000Oomoo`002Goo0P001Woo00<007ooOol0:goo00<3h7ooOol0
ogoo8goo00<007ooOol0ggoo0P0027oo0`00Cgoo000COol2000;Ool00`00Oomoo`04Ool00`00Oomo
o`0ZOol00`?POomoo`3oOolTOol00`00Oomoo`3QOol20009Ool00`00Oomoo`1<Ool002Moo`03001o
ogoo02Yoo`030n1oogoo0?moobAoo`03001oogoo0>=oo`8005Ioo`009goo00<007ooOol0:Woo00<3
h7ooOol0ogoo97oo00<007ooOol0iGoo0P001goo0`00BWoo000WOol00`00Oomoo`0YOol00`?POomo
o`3oOolUOol2003XOol00`00Oomoo`07Ool00`00Oomoo`17Ool002Moo`8002Yoo`030n1oogoo0?mo
obEoo`03001oogoo0>Qoo`80055oo`009goo00<007ooOol0:Goo00<3h7ooOol0ogoo9Goo00<007oo
Ool0jWoo0P0027oo00<007ooOol0A7oo000WOol00`00Oomoo`0YOol00`?POomoo`3oOolUOol00`00
Oomoo`3/Ool20007Ool00`00Oomoo`13Ool002Moo`03001oogoo02Qoo`030n1oogoo0?moobIoo`03
001oogoo0>ioo`8000Ioo`03001oogoo049oo`009goo00<007ooOol0:7oo00<3h7ooOol0ogoo9Woo
00<007ooOol0l7oo0P001goo00<007ooOol0?goo000WOol00`00Oomoo`0XOol00`?POomoo`3oOolV
Ool00`00Oomoo`3bOol20006Ool00`00Oomoo`0nOol002Moo`03001oogoo02Moo`030n1oogoo0?mo
obMoo`03001oogoo0?Aoo`8000Eoo`03001oogoo03eoo`009goo0P00:7oo00<3h7ooOol0ogoo9goo
00<007ooOol0mWoo0P001Woo00<007ooOol0>Woo000WOol00`00Oomoo`0WOol00`?POomoo`3oOolW
Ool2003iOol20005Ool00`00Oomoo`0iOol002Moo`03001oogoo02Moo`030n1oogoo0?moobMoo`03
001oogoo0?Yoo`8000Aoo`03001oogoo03Qoo`009goo00<007ooOol09Woo00<3h7ooOol0ogoo:7oo
00<007ooOol0o7oo00<007ooOol017oo00<007ooOol0=Goo000WOol00`00Oomoo`0VOol00`?POomo
o`3oOolXOol00`00Oomoo`3mOol20005Ool2000eOol002Moo`03001oogoo02Ioo`030n1oogoo0?mo
obQoo`03001oogoo0?moo`8000Eoo`03001oogoo039oo`009goo00<007ooOol09Goo00<3h7ooOol0
ogoo:Goo00<007ooOol0ogoo0Woo00<007ooOol0=goo000WOol2000VOol00`?POomoo`3oOolYOol0
0`00Oomoo`3oOol3Ool20004Ool3000`Ool002Moo`03001oogoo02Eoo`030n1oogoo0?moobUoo`03
001oogoo0?moo`Eoo`8000Eoo`03001oogoo02eoo`009goo00<007ooOol09Goo00<3h7ooOol0ogoo
:Goo0P00ogoo27oo0P00<goo000WOol00`00Oomoo`0TOol00`?POomoo`3oOolZOol00`00Oomoo`3o
Ool9Ool00`00Oomoo`02Ool3000[Ool002Moo`03001oogoo02Aoo`030n1oogoo0?moobYoo`03001o
ogoo0?moo`Yoo`8000Eoo`03001oogoo02Qoo`009goo00<007ooOol097oo00<3h7ooOol0ogoo:Woo
00<007ooOol0ogoo37oo0P00;Woo000WOol00`00Oomoo`0SOol00`?POomoo`3oOol[Ool00`00Oomo
o`3oOol>Ool00`00Oomoo`02Ool3000VOol002Moo`8002Aoo`030n1oogoo0?moob]oo`03001oogoo
0?moo`moo`8000Eoo`03001oogoo02=oo`009goo00<007ooOol08goo00<3h7ooOol0ogoo:goo00<0
07ooOol0ogoo4Goo0P00:Goo000WOol00`00Oomoo`0SOol00`?POomoo`3oOolSOol30005Ool00`00
Oomoo`3oOolCOol20004Ool2000QOol002Moo`03001oogoo029oo`030n1oogoo0?moobEoo`03001o
ogoo00Aoo`03001oogoo0?mooaEoo`8000Aoo`03001oogoo01ioo`009goo00<007ooOol08Woo00<3
h7ooOol0ogoo8Woo1@001Goo0`00ogoo5goo00<007ooOol08Woo000COol20004Ool00`00Oomoo`02
Ool30006Ool00`00Oomoo`0ROol00`?POomoo`3oOolROol01000Oomoo`001Woo00<007ooOol0ogoo
67oo0P008Woo000BOol01000Oomoo`001goo00D007ooOomoo`0000Eoo`03001oogoo025oo`030n1o
ogoo0?moobAoo`03001oo`0000Ioo`03001oogoo0?mooaYoo`80021oo`004Woo00@007ooOol000]o
o`03001oogoo00=oo`<0025oo`030n1oogoo0?moobEoo`8000Ioo`03001oogoo0?mooaaoo`03001o
ogoo01eoo`004Woo00@007ooOol000]oo`03001oogoo0?mooe1oo`03001oogoo00Aoo`03001oogoo
0?moocaoo`004Woo00@007ooOol000Moo`@00?mooeYoo`03001oogoo0?moocaoo`004Woo00@007oo
Ool000Moo`03001oogoo0?mooe]oo`03001oogoo0?moocaoo`004goo0P0027oo1@00ogooFGoo00<0
07ooOol0ogoo?7oo003oOomkOol00`00Oomoo`3oOollOol00?mooomookYoo`00ogooogoo^Woo003o
OoooOonjOol00?mooomookYoo`00\
\>"],
  ImageRangeCache->{{{0, 695}, {203.812, 0}} -> {-0.0537507, -0.0147182, \
0.00303238, 0.00303238}, {{17.6875, 331.75}, {198.938, 4.8125}} -> {-1.37114, \
-0.0493005, 0.0349086, 0.00282416}, {{363.188, 677.25}, {198.938, 4.8125}} -> \
{-2.64314, -0.406028, 0.00698563, 0.0230277}}]
}, Open  ]],

Cell[TextData[{
  "One might try using generating functions to get the solution.  Let ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          RowBox[{
            
            FormBox[\(P\&~[
                  z] \[Congruent] \[Sum]\+\(k = 0\)\%\[Infinity]\( z\^k\) 
                    P\_k\),
              "TraditionalForm"], ";", \(P\&~[1] = 1\)}], 
          ",", \(P\&~[0] = 0\)}], TraditionalForm]]],
  ":"
}], "Text"],

Cell[BoxData[
    \(TextForm\`\[PartialD]\_t P\&~ = \(\[Sum]\+\(k = 0\)\%\[Infinity]\(\( 
                    k \((k + 1)\)\)\/2\) \(z\^k\) 
              P\_\(k + 1\) - \[Sum]\+\(k = 0\)\%\[Infinity]\(\( 
                    k \((k - 1)\)\)\/2\) \(z\^k\) P\_k + 
          R \(\[Sum]\+\(k = 0\)\%\[Infinity]\((k - 1)\) \(z\^k\) 
                P\_\(k - 1\)\) - 
          R \(\[Sum]\+\(k = 0\)\%\[Infinity]\( kz\^k\) 
                P\_k\)\[IndentingNewLine] = \(\((z\^\(-1\) - 
                1)\) \((\[Sum]\+\(k = 0\)\%\[Infinity]\(\( 
                          k \((k - 1)\)\)\/2\) \(z\^k\) P\_k - 
                z\ R \(\[Sum]\+\(k = 0\)\%\[Infinity] k\ \(z\^k\) 
                      P\_k\))\)\[IndentingNewLine] = 
          z \((1 - z)\) \((\[PartialD]\_\(z, z\)P\&~\/2 - \ 
                R \[PartialD]\_z P\&~)\)\)\)\)], "NumberedEquation"],

Cell[TextData[{
  "This is consistent with the stationary solution, but again seems not to \
have an explicit dynamic solution.  Interestingly, it is just the diffusion \
equation for drift and ",
  Cell[BoxData[
      \(TraditionalForm\`selection\ \((\(~\)\(R\))\)\)]],
  ", which Kimura solved as a sum of eigenvalues.  There may be a close \
analogy here, since the coalescent with selection also involves an ancestral \
graph."
}], "Text"],

Cell["This shows convergence to the stationary solution for R=2:", \
"MathCaption"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-2.77556e-17 0.1 0 2.06011 [
[.2 -0.0125 -3 -9 ]
[.2 -0.0125 3 0 ]
[.4 -0.0125 -3 -9 ]
[.4 -0.0125 3 0 ]
[.6 -0.0125 -3 -9 ]
[.6 -0.0125 3 0 ]
[.8 -0.0125 -3 -9 ]
[.8 -0.0125 3 0 ]
[1 -0.0125 -6 -9 ]
[1 -0.0125 6 0 ]
[-0.0125 .10301 -24 -4.5 ]
[-0.0125 .10301 0 4.5 ]
[-0.0125 .20601 -18 -4.5 ]
[-0.0125 .20601 0 4.5 ]
[-0.0125 .30902 -24 -4.5 ]
[-0.0125 .30902 0 4.5 ]
[-0.0125 .41202 -18 -4.5 ]
[-0.0125 .41202 0 4.5 ]
[-0.0125 .51503 -24 -4.5 ]
[-0.0125 .51503 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 0 m
.2 .00625 L
s
[(2)] .2 -0.0125 0 1 Mshowa
.4 0 m
.4 .00625 L
s
[(4)] .4 -0.0125 0 1 Mshowa
.6 0 m
.6 .00625 L
s
[(6)] .6 -0.0125 0 1 Mshowa
.8 0 m
.8 .00625 L
s
[(8)] .8 -0.0125 0 1 Mshowa
1 0 m
1 .00625 L
s
[(10)] 1 -0.0125 0 1 Mshowa
.125 Mabswid
.05 0 m
.05 .00375 L
s
.1 0 m
.1 .00375 L
s
.15 0 m
.15 .00375 L
s
.25 0 m
.25 .00375 L
s
.3 0 m
.3 .00375 L
s
.35 0 m
.35 .00375 L
s
.45 0 m
.45 .00375 L
s
.5 0 m
.5 .00375 L
s
.55 0 m
.55 .00375 L
s
.65 0 m
.65 .00375 L
s
.7 0 m
.7 .00375 L
s
.75 0 m
.75 .00375 L
s
.85 0 m
.85 .00375 L
s
.9 0 m
.9 .00375 L
s
.95 0 m
.95 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .10301 m
.00625 .10301 L
s
[(0.05)] -0.0125 .10301 1 0 Mshowa
0 .20601 m
.00625 .20601 L
s
[(0.1)] -0.0125 .20601 1 0 Mshowa
0 .30902 m
.00625 .30902 L
s
[(0.15)] -0.0125 .30902 1 0 Mshowa
0 .41202 m
.00625 .41202 L
s
[(0.2)] -0.0125 .41202 1 0 Mshowa
0 .51503 m
.00625 .51503 L
s
[(0.25)] -0.0125 .51503 1 0 Mshowa
.125 Mabswid
0 .0206 m
.00375 .0206 L
s
0 .0412 m
.00375 .0412 L
s
0 .0618 m
.00375 .0618 L
s
0 .0824 m
.00375 .0824 L
s
0 .12361 m
.00375 .12361 L
s
0 .14421 m
.00375 .14421 L
s
0 .16481 m
.00375 .16481 L
s
0 .18541 m
.00375 .18541 L
s
0 .22661 m
.00375 .22661 L
s
0 .24721 m
.00375 .24721 L
s
0 .26781 m
.00375 .26781 L
s
0 .28842 m
.00375 .28842 L
s
0 .32962 m
.00375 .32962 L
s
0 .35022 m
.00375 .35022 L
s
0 .37082 m
.00375 .37082 L
s
0 .39142 m
.00375 .39142 L
s
0 .43262 m
.00375 .43262 L
s
0 .45322 m
.00375 .45322 L
s
0 .47383 m
.00375 .47383 L
s
0 .49443 m
.00375 .49443 L
s
0 .53563 m
.00375 .53563 L
s
0 .55623 m
.00375 .55623 L
s
0 .57683 m
.00375 .57683 L
s
0 .59743 m
.00375 .59743 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.08002 .61803 m
.08481 .58312 L
.10491 .47016 L
.12674 .38283 L
.14756 .323 L
.16964 .27704 L
.19016 .24584 L
.20937 .22391 L
.23063 .20575 L
.25008 .19331 L
.27002 .18365 L
.29178 .17579 L
.31243 .17026 L
.33445 .16588 L
.35694 .1626 L
.37812 .16033 L
.3992 .15865 L
.41859 .15749 L
.43836 .15658 L
.46006 .15584 L
.48054 .15532 L
.5025 .1549 L
.5248 .15459 L
.54593 .15438 L
.56683 .15422 L
.58618 .15411 L
.60577 .15402 L
.62741 .15395 L
.64772 .1539 L
.66962 .15386 L
.69066 .15383 L
.71282 .15381 L
.73354 .15379 L
.75283 .15378 L
.77431 .15377 L
.79383 .15377 L
.81397 .15376 L
.82533 .15376 L
.83581 .15376 L
.84611 .15375 L
.85179 .15375 L
.85718 .15375 L
.86763 .15375 L
.87718 .15375 L
.89645 .15375 L
.91696 .15375 L
.9378 .15375 L
.95712 .15375 L
.96774 .15375 L
.97921 .15375 L
Mistroke
1 .15375 L
Mfstroke
0 0 m
.00488 .17051 L
.00942 .28529 L
.01441 .37614 L
.01721 .41482 L
.01975 .44393 L
.02488 .48839 L
.02778 .50668 L
.03045 .52004 L
.03299 .53005 L
.03536 .53741 L
.03784 .54328 L
.03925 .5459 L
.04057 .54791 L
.042 .54965 L
.0433 .55088 L
.04474 .55186 L
.04553 .55225 L
.04627 .55252 L
.04763 .55278 L
.04888 .55279 L
.05025 .55255 L
.05094 .55235 L
.0517 .55205 L
.05303 .55138 L
.05424 .55061 L
.05696 .54836 L
.06188 .54283 L
.07366 .52454 L
.08481 .50405 L
.12505 .43273 L
.14582 .40389 L
.16788 .37971 L
.18832 .36241 L
.20751 .34981 L
.22871 .33914 L
.24814 .3317 L
.26801 .32587 L
.28974 .32108 L
.31033 .31769 L
.33233 .315 L
.35474 .31298 L
.3759 .31158 L
.39692 .31054 L
.41629 .30982 L
.43599 .30926 L
.45767 .3088 L
.47809 .30847 L
.50002 .30821 L
.52226 .30802 L
Mistroke
.54336 .30788 L
.5642 .30779 L
.58352 .30772 L
.60511 .30766 L
.62466 .30762 L
.64491 .30759 L
.66679 .30756 L
.68776 .30754 L
.70989 .30753 L
.73056 .30752 L
.74982 .30751 L
.77123 .30751 L
.79073 .3075 L
.81081 .3075 L
.82214 .3075 L
.83262 .3075 L
.84288 .3075 L
.85393 .3075 L
.85901 .30749 L
.86436 .30749 L
.8739 .30749 L
.89311 .30749 L
.89817 .30749 L
.90365 .30749 L
.90883 .30749 L
.9136 .30749 L
.92449 .30749 L
.93437 .30749 L
.95367 .30749 L
.97341 .30749 L
.99509 .30749 L
1 .30749 L
Mfstroke
0 0 m
.01975 .13125 L
.02981 .20679 L
.04057 .27001 L
.0515 .31678 L
.06168 .34779 L
.06791 .36211 L
.07379 .37308 L
.07903 .38108 L
.08481 .3883 L
.09499 .39778 L
.10056 .40159 L
.10578 .40446 L
.11511 .40827 L
.12035 .40982 L
.12514 .41095 L
.13015 .41187 L
.13548 .41262 L
.14051 .41315 L
.14508 .41351 L
.14788 .41368 L
.15046 .41381 L
.15329 .41392 L
.15628 .414 L
.15754 .41403 L
.15888 .41405 L
.16005 .41407 L
.16131 .41409 L
.16208 .4141 L
.1628 .4141 L
.16348 .41411 L
.1642 .41411 L
.16546 .41411 L
.16684 .41411 L
.16811 .41411 L
.1693 .41411 L
.17061 .4141 L
.172 .41409 L
.17485 .41405 L
.17744 .41402 L
.18715 .41382 L
.20905 .41319 L
.25103 .412 L
.27027 .41157 L
.29142 .41119 L
.31229 .4109 L
.33439 .41066 L
.35481 .4105 L
.37674 .41036 L
.39898 .41026 L
Mistroke
.42008 .41019 L
.44092 .41014 L
.46024 .4101 L
.48183 .41007 L
.50138 .41005 L
.52163 .41004 L
.54351 .41002 L
.56448 .41001 L
.58661 .41001 L
.60728 .41 L
.62654 .41 L
.64795 .41 L
.66745 .40999 L
.68753 .40999 L
.70934 .40999 L
.73014 .40999 L
.75222 .40999 L
.7727 .40999 L
.79191 .40999 L
.80226 .40999 L
.81314 .40999 L
.83259 .40999 L
.87266 .40999 L
.89329 .40999 L
.9153 .40999 L
.95893 .40999 L
1 .40999 L
Mfstroke
0 0 m
.04057 .12363 L
.06168 .20222 L
.07286 .23547 L
.08481 .26511 L
.10632 .30584 L
.12636 .33291 L
.14873 .35454 L
.16988 .36917 L
.19085 .37977 L
.21021 .38704 L
.22987 .39261 L
.25153 .39718 L
.27191 .40037 L
.29383 .40292 L
.31602 .40481 L
.33712 .40613 L
.35791 .4071 L
.37722 .40779 L
.39877 .40836 L
.41831 .40875 L
.43852 .40905 L
.46038 .4093 L
.48131 .40947 L
.50343 .40961 L
.52405 .4097 L
.5433 .40977 L
.56467 .40983 L
.58415 .40986 L
.60419 .40989 L
.62599 .40992 L
.64675 .40994 L
.66881 .40995 L
.68926 .40996 L
.70845 .40996 L
.72964 .40997 L
.74907 .40997 L
.76894 .40998 L
.79068 .40998 L
.81127 .40998 L
.82279 .40998 L
.83327 .40998 L
.84388 .40998 L
.85511 .40998 L
.85973 .40998 L
.8647 .40998 L
.87015 .40998 L
.87525 .40998 L
.89457 .40998 L
.89983 .40998 L
Mistroke
.90478 .40998 L
.91048 .40998 L
.91564 .40998 L
.92717 .40998 L
.93787 .40999 L
.94794 .40999 L
.95898 .40999 L
.96926 .40999 L
.9801 .40999 L
.99951 .40999 L
1 .40999 L
Mfstroke
0 0 m
.00123 0 L
.00236 1e-05 L
.00365 4e-05 L
.00488 .00012 L
.00601 .00025 L
.00706 .00043 L
.00821 .00071 L
.00942 .00112 L
.01065 .00165 L
.01196 .00237 L
.01434 .00408 L
.01716 .00684 L
.01975 .01002 L
.02485 .01802 L
.03042 .02893 L
.04057 .05262 L
.06198 .10754 L
.08481 .16064 L
.10531 .19946 L
.12749 .23228 L
.14997 .25741 L
.17115 .27519 L
.19208 .28843 L
.2142 .29887 L
.23482 .30613 L
.25407 .31127 L
.27544 .31557 L
.29493 .31853 L
.31496 .32084 L
.33676 .32271 L
.35753 .32404 L
.37958 .32509 L
.40003 .32581 L
.41922 .32632 L
.44041 .32675 L
.45984 .32704 L
.47971 .32727 L
.50145 .32746 L
.52204 .32759 L
.54404 .3277 L
.56645 .32778 L
.58761 .32783 L
.60863 .32787 L
.628 .3279 L
.6477 .32792 L
.66937 .32794 L
.68979 .32795 L
.71173 .32796 L
.73396 .32797 L
Mistroke
.75507 .32797 L
.77591 .32798 L
.79523 .32798 L
.80635 .32798 L
.81682 .32798 L
.83637 .32798 L
.84665 .32798 L
.85226 .32798 L
.85749 .32799 L
.86675 .32799 L
.8769 .32799 L
.89651 .32799 L
.90188 .32799 L
.90758 .32799 L
.91245 .32799 L
.91781 .32799 L
.94016 .32799 L
.9613 .32799 L
.97993 .32799 L
1 .32799 L
Mfstroke
0 0 m
.00123 0 L
.00236 0 L
.00365 0 L
.00488 1e-05 L
.00601 3e-05 L
.00706 5e-05 L
.00821 9e-05 L
.00942 .00017 L
.01065 .00027 L
.01196 .00043 L
.0132 .00062 L
.01434 .00084 L
.01711 .00159 L
.01975 .00259 L
.02225 .00382 L
.02491 .00545 L
.0297 .00915 L
.04057 .02084 L
.08481 .08683 L
.10578 .11552 L
.12847 .14103 L
.15038 .16034 L
.17054 .17411 L
.19031 .18458 L
.212 .19334 L
.23249 .19957 L
.25445 .20458 L
.27675 .20833 L
.29788 .21096 L
.31878 .21291 L
.33812 .21427 L
.35772 .21532 L
.37935 .21619 L
.39967 .2168 L
.42157 .21729 L
.44261 .21764 L
.46476 .21791 L
.48549 .2181 L
.50478 .21823 L
.52626 .21834 L
.54577 .21842 L
.56592 .21848 L
.58775 .21852 L
.60862 .21856 L
.63072 .21859 L
.65127 .2186 L
.6705 .21862 L
.6918 .21863 L
.71127 .21864 L
Mistroke
.73124 .21864 L
.75302 .21865 L
.77371 .21865 L
.79575 .21865 L
.80658 .21865 L
.81827 .21865 L
.83946 .21866 L
.85032 .21866 L
.85562 .21866 L
.86044 .21866 L
.86554 .21866 L
.871 .21866 L
.88257 .21866 L
.89314 .21866 L
.89892 .21866 L
.90435 .21866 L
.90895 .21866 L
.91392 .21866 L
.92446 .21866 L
.94411 .21866 L
.96477 .21866 L
.9816 .21866 L
1 .21866 L
Mfstroke
0 0 m
.00123 0 L
.00236 0 L
.00365 0 L
.00488 0 L
.00601 0 L
.00706 1e-05 L
.00821 1e-05 L
.00942 2e-05 L
.01065 4e-05 L
.01196 7e-05 L
.0132 .00012 L
.01434 .00017 L
.01566 .00025 L
.01711 .00036 L
.01975 .00064 L
.02116 .00084 L
.02249 .00106 L
.02497 .00157 L
.03054 .00317 L
.03536 .00509 L
.04057 .0077 L
.06361 .02412 L
.08481 .04215 L
.10625 .0595 L
.12627 .07348 L
.14675 .08523 L
.16614 .09413 L
.18751 .1018 L
.20699 .10718 L
.2279 .1116 L
.24724 .11473 L
.26684 .11716 L
.28847 .11918 L
.30879 .1206 L
.33068 .12174 L
.35173 .12256 L
.37388 .12319 L
.39461 .12363 L
.41389 .12394 L
.43537 .1242 L
.45489 .12438 L
.47504 .12452 L
.49687 .12463 L
.51774 .12471 L
.53984 .12478 L
.56039 .12482 L
.57962 .12485 L
.60092 .12487 L
.62038 .12489 L
Mistroke
.64036 .12491 L
.66213 .12492 L
.68283 .12492 L
.70487 .12493 L
.72739 .12494 L
.74858 .12494 L
.76971 .12494 L
.78912 .12494 L
.80892 .12494 L
.82016 .12494 L
.83063 .12495 L
.85024 .12495 L
.85561 .12495 L
.86131 .12495 L
.86618 .12495 L
.87154 .12495 L
.89389 .12495 L
.89926 .12495 L
.90492 .12495 L
.90975 .12495 L
.91502 .12495 L
.93538 .12495 L
.94687 .12495 L
.95729 .12495 L
.97792 .12495 L
.99994 .12495 L
1 .12495 L
Mfstroke
0 0 m
.00123 0 L
.00236 0 L
.00365 0 L
.00488 0 L
.00601 0 L
.00706 0 L
.00821 0 L
.00942 0 L
.01065 1e-05 L
.01196 1e-05 L
.0132 2e-05 L
.01434 3e-05 L
.01566 5e-05 L
.01711 8e-05 L
.01848 .00011 L
.01975 .00015 L
.02106 .0002 L
.02247 .00027 L
.02503 .00043 L
.02753 .00064 L
.02982 .00087 L
.03505 .0016 L
.04057 .00266 L
.05147 .00556 L
.06166 .00908 L
.08481 .0185 L
.12566 .03442 L
.14796 .04122 L
.16909 .04631 L
.19 .05024 L
.20934 .05305 L
.22894 .05527 L
.25057 .05712 L
.27088 .05843 L
.29278 .05949 L
.31382 .06025 L
.33598 .06084 L
.35671 .06125 L
.37599 .06154 L
.39747 .06178 L
.41699 .06195 L
.43713 .06208 L
.45897 .06218 L
.47984 .06225 L
.50193 .06231 L
.52249 .06235 L
.54172 .06238 L
.56302 .06241 L
.58248 .06242 L
Mistroke
.60246 .06243 L
.62423 .06244 L
.64493 .06245 L
.66696 .06246 L
.68949 .06246 L
.71068 .06247 L
.7318 .06247 L
.75121 .06247 L
.77102 .06247 L
.79273 .06247 L
.81325 .06247 L
.82476 .06247 L
.83523 .06247 L
.84579 .06247 L
.85158 .06247 L
.857 .06247 L
.86657 .06247 L
.87712 .06247 L
.89677 .06247 L
.90154 .06247 L
.90664 .06247 L
.91223 .06247 L
.91742 .06247 L
.93866 .06247 L
.9581 .06247 L
.96845 .06247 L
.97967 .06247 L
1 .06247 L
Mfstroke
0 0 m
.00123 0 L
.00236 0 L
.00365 0 L
.00488 0 L
.00601 0 L
.00706 0 L
.00821 0 L
.00942 0 L
.01065 0 L
.01196 0 L
.0132 0 L
.01434 1e-05 L
.01566 1e-05 L
.01641 1e-05 L
.01711 2e-05 L
.01839 2e-05 L
.01975 3e-05 L
.02115 5e-05 L
.02245 7e-05 L
.02384 9e-05 L
.02537 .00012 L
.02795 .00019 L
.03067 .00028 L
.03579 .00053 L
.04057 .00086 L
.0463 .00138 L
.05174 .00199 L
.06192 .00341 L
.08481 .0074 L
.12505 .0145 L
.14541 .01741 L
.16788 .02 L
.18914 .0219 L
.20911 .02329 L
.2303 .02441 L
.24973 .0252 L
.2696 .02581 L
.29133 .02632 L
.31192 .02668 L
.33392 .02697 L
.35634 .02718 L
.37749 .02733 L
.39851 .02744 L
.41788 .02752 L
.43759 .02758 L
.45926 .02763 L
.47968 .02766 L
.50161 .02769 L
.52385 .02771 L
Mistroke
.54495 .02772 L
.56579 .02773 L
.58511 .02774 L
.6067 .02775 L
.62625 .02775 L
.6465 .02776 L
.66838 .02776 L
.68935 .02776 L
.71149 .02776 L
.73215 .02776 L
.75141 .02776 L
.77282 .02776 L
.79232 .02776 L
.8124 .02777 L
.82374 .02777 L
.83421 .02777 L
.84447 .02777 L
.84986 .02777 L
.85552 .02777 L
.86595 .02777 L
.8755 .02777 L
.8947 .02777 L
.89976 .02777 L
.90525 .02777 L
.91042 .02777 L
.91519 .02777 L
.92608 .02777 L
.93596 .02777 L
.95526 .02777 L
.96546 .02777 L
.975 .02777 L
.99669 .02777 L
1 .02777 L
Mfstroke
0 0 m
.00123 0 L
.00236 0 L
.00365 0 L
.00488 0 L
.00601 0 L
.00706 0 L
.00821 0 L
.00942 0 L
.01065 0 L
.01196 0 L
.0132 0 L
.01434 0 L
.01566 0 L
.01641 0 L
.01711 0 L
.01839 1e-05 L
.01975 1e-05 L
.02115 1e-05 L
.02245 2e-05 L
.02387 2e-05 L
.02537 3e-05 L
.0279 5e-05 L
.03067 8e-05 L
.03314 .00011 L
.03579 .00015 L
.04057 .00026 L
.04626 .00044 L
.05245 .00068 L
.06371 .00128 L
.08481 .00271 L
.12763 .00574 L
.1489 .00696 L
.16886 .0079 L
.18817 .00862 L
.2085 .00921 L
.22969 .00969 L
.24912 .01002 L
.26985 .01029 L
.28913 .01048 L
.31061 .01064 L
.33013 .01075 L
.35028 .01084 L
.37211 .01091 L
.39298 .01096 L
.41508 .011 L
.43563 .01103 L
.45486 .01104 L
.47616 .01106 L
.49562 .01107 L
Mistroke
.5156 .01108 L
.53737 .01109 L
.55807 .01109 L
.58011 .0111 L
.60263 .0111 L
.62382 .0111 L
.64494 .0111 L
.66435 .0111 L
.68416 .0111 L
.70587 .0111 L
.7264 .01111 L
.74837 .01111 L
.77072 .01111 L
.79186 .01111 L
.80202 .01111 L
.8128 .01111 L
.83216 .01111 L
.84226 .01111 L
.85288 .01111 L
.85726 .01111 L
.86194 .01111 L
.86708 .01111 L
.87185 .01111 L
.8922 .01111 L
.89775 .01111 L
.90361 .01111 L
.90862 .01111 L
.91412 .01111 L
.9249 .01111 L
.93657 .01111 L
.94764 .01111 L
.95774 .01111 L
.97813 .01111 L
1 .01111 L
Mfstroke
0 0 m
.00123 0 L
.00236 0 L
.00365 0 L
.00488 0 L
.00601 0 L
.00706 0 L
.00821 0 L
.00942 0 L
.01065 0 L
.01196 0 L
.0132 0 L
.01434 0 L
.01566 0 L
.01641 0 L
.01711 0 L
.01839 0 L
.01975 0 L
.02043 0 L
.02115 0 L
.02245 0 L
.02317 0 L
.02384 0 L
.02537 1e-05 L
.02793 1e-05 L
.02936 2e-05 L
.03067 2e-05 L
.0331 3e-05 L
.03575 4e-05 L
.04057 7e-05 L
.04586 .00012 L
.05171 .0002 L
.06355 .00041 L
.08481 .00092 L
.12702 .00201 L
.16764 .00281 L
.18869 .00311 L
.21084 .00335 L
.23157 .00352 L
.25085 .00364 L
.27233 .00374 L
.29185 .00381 L
.312 .00387 L
.33383 .00391 L
.3547 .00394 L
.3768 .00397 L
.39735 .00399 L
.41658 .004 L
.43788 .00401 L
.45734 .00402 L
Mistroke
.47732 .00402 L
.49909 .00403 L
.51979 .00403 L
.54183 .00403 L
.56435 .00403 L
.58554 .00403 L
.60667 .00404 L
.62608 .00404 L
.64588 .00404 L
.66759 .00404 L
.68812 .00404 L
.71009 .00404 L
.73244 .00404 L
.75358 .00404 L
.77452 .00404 L
.79388 .00404 L
.81351 .00404 L
.82469 .00404 L
.83516 .00404 L
.87584 .00404 L
.89692 .00404 L
.90205 .00404 L
.90752 .00404 L
.91066 .00404 L
.91352 .00404 L
.91909 .00404 L
.94097 .00404 L
.96113 .00404 L
.98002 .00404 L
1 .00404 L
Mfstroke
0 0 m
.00123 0 L
.00236 0 L
.00365 0 L
.00488 0 L
.00601 0 L
.00706 0 L
.00821 0 L
.00942 0 L
.01065 0 L
.01196 0 L
.0132 0 L
.01434 0 L
.01566 0 L
.01641 0 L
.01711 0 L
.01848 0 L
.01975 0 L
.02106 0 L
.02174 0 L
.02247 0 L
.02369 0 L
.02503 0 L
.02623 0 L
.02751 0 L
.02872 0 L
.02982 0 L
.03111 1e-05 L
.03247 1e-05 L
.03318 1e-05 L
.03396 1e-05 L
.03534 1e-05 L
.04057 2e-05 L
.04336 3e-05 L
.0463 4e-05 L
.05155 6e-05 L
.06339 .00012 L
.08481 .00029 L
.12482 .00064 L
.14714 .0008 L
.16741 .00092 L
.18874 .00103 L
.20841 .0011 L
.22855 .00116 L
.25039 .00121 L
.27009 .00124 L
.29176 .00127 L
.31218 .00129 L
.33412 .0013 L
.35635 .00131 L
Mistroke
.37746 .00132 L
.3983 .00133 L
.41762 .00133 L
.43921 .00134 L
.45876 .00134 L
.47901 .00134 L
.50088 .00134 L
.52186 .00134 L
.53242 .00134 L
.54399 .00134 L
.56624 .00134 L
.58649 .00134 L
.60751 .00135 L
.6274 .00135 L
.64835 .00135 L
.6677 .00135 L
.68734 .00135 L
.70899 .00135 L
.72934 .00135 L
.75125 .00135 L
.77234 .00135 L
.79451 .00135 L
.80455 .00135 L
.81528 .00135 L
.83457 .00135 L
.84536 .00135 L
.85103 .00135 L
.85703 .00135 L
.86228 .00135 L
.86805 .00135 L
.8782 .00135 L
.88959 .00135 L
.90038 .00135 L
.90507 .00135 L
.91007 .00135 L
.91554 .00135 L
.92061 .00135 L
.94166 .00135 L
.96143 .00135 L
.97999 .00135 L
1 .00135 L
Mfstroke
0 0 m
.00123 0 L
.00236 0 L
.00365 0 L
.00488 0 L
.00601 0 L
.00706 0 L
.00821 0 L
.00942 0 L
.01065 0 L
.01196 0 L
.0132 0 L
.01434 0 L
.01566 0 L
.01641 0 L
.01711 0 L
.01839 0 L
.01975 0 L
.02106 0 L
.02245 0 L
s
.02245 0 m
.02307 0 L
s
.02472 0 m
.02537 0 L
.02671 0 L
.02793 0 L
.0286 0 L
.02933 0 L
.03067 0 L
.03185 0 L
.03316 0 L
.03453 0 L
.03581 0 L
.03692 0 L
.0381 0 L
.03939 0 L
.04057 1e-05 L
.04586 1e-05 L
.05151 2e-05 L
.05685 2e-05 L
.0617 3e-05 L
.08481 8e-05 L
.12679 .0002 L
.16718 .00028 L
.18805 .00031 L
.21014 .00034 L
.2307 .00036 L
.24993 .00037 L
.27123 .00038 L
.29069 .00039 L
.31067 .0004 L
.33244 .0004 L
.35314 .0004 L
.37517 .00041 L
.3977 .00041 L
.41889 .00041 L
.44001 .00041 L
.44939 .00041 L
.45942 .00041 L
.46967 .00041 L
.47923 .00041 L
.49051 .00041 L
.49547 .00041 L
.49829 .00041 L
.50094 .00041 L
.50613 .00041 L
.51165 .00041 L
.51772 .00041 L
.52038 .00041 L
.52188 .00041 L
.52328 .00041 L
.52825 .00041 L
Mistroke
.53346 .00041 L
.53917 .00041 L
.54442 .00041 L
.54701 .00041 L
.54831 .00041 L
.54974 .00041 L
.5555 .00041 L
.56594 .00041 L
.58547 .00041 L
.60593 .00041 L
.62789 .00041 L
.63855 .00041 L
.64418 .00041 L
.65016 .00041 L
.65537 .00041 L
.66113 .00041 L
.67128 .00041 L
.69328 .00041 L
.71346 .00041 L
.73322 .00041 L
.75405 .00041 L
.77475 .00041 L
.79403 .00041 L
.80506 .00041 L
.81548 .00041 L
.83499 .00041 L
.84425 .00041 L
.8542 .00041 L
.85713 .00041 L
.85991 .00041 L
.86512 .00041 L
.87535 .00041 L
.89619 .00041 L
.91828 .00041 L
.93933 .00041 L
.9584 .00041 L
.97854 .00041 L
1 .00041 L
Mfstroke
0 0 m
.00123 0 L
.00236 0 L
.00365 0 L
.00488 0 L
.00601 0 L
.00706 0 L
.00821 0 L
.00942 0 L
.01065 0 L
.01196 0 L
.0132 0 L
.01434 0 L
.01566 0 L
.01641 0 L
.01711 0 L
s
.01711 0 m
.01712 0 L
s
.02253 0 m
.02317 0 L
.02384 0 L
.02458 0 L
s
.02458 0 m
.02509 0 L
s
.02745 0 m
.02814 0 L
.02945 0 L
s
.02945 0 m
.03043 0 L
s
.03287 0 m
.03295 0 L
.03426 0 L
.03547 0 L
s
.03547 0 m
.03654 0 L
s
.03804 0 m
.03918 0 L
.04057 0 L
.04355 0 L
.04637 0 L
.05165 0 L
.05733 1e-05 L
.06349 1e-05 L
.08481 2e-05 L
.12777 6e-05 L
.14915 7e-05 L
.16915 8e-05 L
.18955 9e-05 L
.20893 .0001 L
.23023 .0001 L
.24969 .00011 L
.27053 .00011 L
.28985 .00011 L
.31144 .00011 L
.33099 .00011 L
.35124 .00012 L
.37312 .00012 L
.39409 .00012 L
.41622 .00012 L
.4262 .00012 L
.43169 .00012 L
.43689 .00012 L
.44697 .00012 L
.45615 .00012 L
.49645 .00012 L
.50627 .00012 L
.51685 .00012 L
.5198 .00012 L
.52052 .00012 L
.52128 .00012 L
.52212 .00012 L
.5229 .00012 L
.52362 .00012 L
.5244 .00012 L
.52513 .00012 L
.52581 .00012 L
.52717 .00012 L
.52845 .00012 L
.52966 .00012 L
.53097 .00012 L
.53171 .00012 L
.53242 .00012 L
.53374 .00012 L
.53441 .00012 L
.53513 .00012 L
Mistroke
.53641 .00012 L
.5378 .00012 L
.53859 .00012 L
.53933 .00012 L
.54194 .00012 L
.54321 .00012 L
.54437 .00012 L
.5456 .00012 L
.54691 .00012 L
.54759 .00012 L
.54833 .00012 L
.54968 .00012 L
.55208 .00012 L
.5534 .00012 L
.55463 .00012 L
.55567 .00012 L
.5568 .00012 L
.55919 .00012 L
.58061 .00012 L
.58575 .00012 L
.58857 .00012 L
.59123 .00012 L
.59275 .00012 L
.59354 .00012 L
.59438 .00012 L
.59587 .00012 L
.59724 .00012 L
.60282 .00012 L
.62392 .00012 L
.66381 .00012 L
.67434 .00012 L
.67685 .00012 L
.67952 .00012 L
.6818 .00012 L
.68309 .00012 L
.68431 .00012 L
.68569 .00012 L
.68696 .00012 L
.68982 .00012 L
.69273 .00012 L
.6942 .00012 L
.6958 .00012 L
.70628 .00012 L
.71776 .00012 L
.72861 .00012 L
.73834 .00012 L
.74889 .00012 L
.76842 .00012 L
.77378 .00012 L
.77952 .00012 L
Mistroke
.7899 .00012 L
.81079 .00012 L
.82226 .00012 L
.83289 .00012 L
.84354 .00012 L
.85514 .00012 L
.87625 .00012 L
.88739 .00012 L
.89786 .00012 L
.90243 .00012 L
.90726 .00012 L
.90979 .00012 L
.91255 .00012 L
.91741 .00012 L
.93967 .00012 L
.95993 .00012 L
.96981 .00012 L
.98053 .00012 L
1 .00012 L
Mfstroke
0 0 m
.00123 0 L
.00236 0 L
.00365 0 L
.00488 0 L
.00601 0 L
.00706 0 L
.00821 0 L
.00942 0 L
.01065 0 L
.01196 0 L
.0132 0 L
.01434 0 L
.01566 0 L
.01641 0 L
.01711 0 L
.01839 0 L
.01975 0 L
.02043 0 L
.02115 0 L
.02245 0 L
s
.02245 0 m
.02256 0 L
s
.02503 0 m
.02537 0 L
.02605 0 L
.02679 0 L
s
.02679 0 m
.02757 0 L
s
.03018 0 m
.03067 0 L
.03184 0 L
.03295 0 L
s
.03295 0 m
.03332 0 L
s
.03591 0 m
.03676 0 L
.03813 0 L
.03929 0 L
.04057 0 L
.0419 0 L
.04257 0 L
.0433 0 L
.0441 0 L
.04484 0 L
.04627 0 L
.05165 0 L
.05785 0 L
.06349 0 L
.08481 1e-05 L
.12557 1e-05 L
.14631 2e-05 L
.16891 2e-05 L
.19058 2e-05 L
.21066 3e-05 L
.23225 3e-05 L
.2518 3e-05 L
.27205 3e-05 L
.29393 3e-05 L
.31491 3e-05 L
.33704 3e-05 L
.3577 3e-05 L
.37696 3e-05 L
.39837 3e-05 L
.40783 3e-05 L
.41787 3e-05 L
.42284 3e-05 L
.42831 3e-05 L
.43334 3e-05 L
.43554 3e-05 L
.43679 3e-05 L
.43795 3e-05 L
.44059 3e-05 L
.44337 3e-05 L
.44921 3e-05 L
.45184 3e-05 L
.45313 3e-05 L
.45432 3e-05 L
.45569 3e-05 L
.45641 3e-05 L
.45717 3e-05 L
.45841 3e-05 L
.45976 3e-05 L
.46239 3e-05 L
.46378 3e-05 L
Mistroke
.46526 3e-05 L
.46796 3e-05 L
.47046 3e-05 L
.47155 3e-05 L
.47269 3e-05 L
.47395 3e-05 L
.4751 3e-05 L
.47636 3e-05 L
.47774 3e-05 L
.47903 3e-05 L
.48022 3e-05 L
.49083 3e-05 L
.4937 3e-05 L
.49526 3e-05 L
.49673 3e-05 L
.49798 3e-05 L
.49932 3e-05 L
.50009 3e-05 L
.50081 3e-05 L
.50218 3e-05 L
.51291 3e-05 L
.51584 3e-05 L
.51744 3e-05 L
.51896 3e-05 L
.51964 3e-05 L
.52037 3e-05 L
.52116 3e-05 L
.5219 3e-05 L
.52317 3e-05 L
.52389 3e-05 L
.52456 3e-05 L
.53468 3e-05 L
.53997 3e-05 L
.54275 3e-05 L
.54343 3e-05 L
.54416 3e-05 L
.54496 3e-05 L
.54571 3e-05 L
.54641 3e-05 L
.54716 3e-05 L
.54796 3e-05 L
.54869 3e-05 L
.55142 3e-05 L
.55273 3e-05 L
.55397 3e-05 L
.55466 3e-05 L
.5554 3e-05 L
.5567 3e-05 L
.55795 3e-05 L
.55933 3e-05 L
Mistroke
.56002 3e-05 L
.56077 3e-05 L
.56211 3e-05 L
.56345 3e-05 L
.56472 3e-05 L
.56597 3e-05 L
.5671 3e-05 L
.56831 3e-05 L
.56944 3e-05 L
.57064 3e-05 L
.57194 3e-05 L
.57408 3e-05 L
.57521 3e-05 L
.57643 3e-05 L
.57776 3e-05 L
.579 3e-05 L
.57974 3e-05 L
.58043 3e-05 L
.58172 3e-05 L
.58294 3e-05 L
.58406 3e-05 L
.58529 3e-05 L
.58659 3e-05 L
.58785 3e-05 L
.58923 3e-05 L
.59053 3e-05 L
.59175 3e-05 L
.59294 3e-05 L
.59403 3e-05 L
.59528 3e-05 L
.59646 3e-05 L
.60709 3e-05 L
.61158 3e-05 L
.61403 3e-05 L
.61632 3e-05 L
.61751 3e-05 L
.6188 3e-05 L
.61953 3e-05 L
.62022 3e-05 L
.62152 3e-05 L
.62271 3e-05 L
.62381 3e-05 L
.6263 3e-05 L
.62754 3e-05 L
.62884 3e-05 L
.62995 3e-05 L
.63116 3e-05 L
.63248 3e-05 L
.63321 3e-05 L
.63388 3e-05 L
Mistroke
.63518 3e-05 L
.6364 3e-05 L
.64096 3e-05 L
.64589 3e-05 L
.64714 3e-05 L
.64849 3e-05 L
.64927 3e-05 L
.64997 3e-05 L
.65136 3e-05 L
.65209 3e-05 L
.65278 3e-05 L
.65353 3e-05 L
.65432 3e-05 L
.65714 3e-05 L
.65849 3e-05 L
.65995 3e-05 L
.66132 3e-05 L
.66259 3e-05 L
.66373 3e-05 L
.66499 3e-05 L
.6663 3e-05 L
.66752 3e-05 L
.66885 3e-05 L
.66952 3e-05 L
.67026 3e-05 L
.67156 3e-05 L
.67279 3e-05 L
.67423 3e-05 L
.67555 3e-05 L
.67708 3e-05 L
.67852 3e-05 L
.67969 3e-05 L
.68094 3e-05 L
.68233 3e-05 L
.68359 3e-05 L
.6849 3e-05 L
.68633 3e-05 L
.68892 3e-05 L
.69147 3e-05 L
.69272 3e-05 L
.69385 3e-05 L
.69505 3e-05 L
.69634 3e-05 L
.69907 3e-05 L
.70842 3e-05 L
.71101 3e-05 L
.71228 3e-05 L
.71345 3e-05 L
.71467 3e-05 L
.71599 3e-05 L
Mistroke
.71736 3e-05 L
.71805 3e-05 L
.7188 3e-05 L
.72004 3e-05 L
.72121 3e-05 L
.72256 3e-05 L
.72378 3e-05 L
.72494 3e-05 L
.72601 3e-05 L
.72842 3e-05 L
.73384 3e-05 L
.73967 3e-05 L
.74249 3e-05 L
.74388 3e-05 L
.74517 3e-05 L
.74634 3e-05 L
.74758 3e-05 L
.74896 3e-05 L
.75021 3e-05 L
.76987 3e-05 L
.77122 3e-05 L
.77248 3e-05 L
.77379 3e-05 L
.77449 3e-05 L
.77523 3e-05 L
.77681 3e-05 L
.77825 3e-05 L
.78103 3e-05 L
.78612 3e-05 L
.78869 3e-05 L
.79153 3e-05 L
.80195 3e-05 L
.80697 3e-05 L
.80917 3e-05 L
.81158 3e-05 L
.81421 3e-05 L
.81565 3e-05 L
.81699 3e-05 L
.81775 3e-05 L
.81847 3e-05 L
.81981 3e-05 L
.82126 3e-05 L
.82282 3e-05 L
.8242 3e-05 L
.82549 3e-05 L
.82684 3e-05 L
.82831 3e-05 L
.83076 3e-05 L
.83338 3e-05 L
.84343 3e-05 L
Mistroke
.84904 3e-05 L
.85412 3e-05 L
.85553 3e-05 L
.85703 3e-05 L
.85781 3e-05 L
.85866 3e-05 L
.85944 3e-05 L
.86017 3e-05 L
.8609 3e-05 L
.8616 3e-05 L
.86291 3e-05 L
.86364 3e-05 L
.86432 3e-05 L
.86506 3e-05 L
.86585 3e-05 L
.87109 3e-05 L
.8726 3e-05 L
.87334 3e-05 L
.87403 3e-05 L
.87532 3e-05 L
.876 3e-05 L
.87673 3e-05 L
.87806 3e-05 L
.8788 3e-05 L
.87949 3e-05 L
.88076 3e-05 L
.8821 3e-05 L
.88698 3e-05 L
.89659 3e-05 L
.91848 3e-05 L
.93908 3e-05 L
.95833 3e-05 L
.97968 3e-05 L
.989 3e-05 L
.99428 3e-05 L
.99916 3e-05 L
1 3e-05 L
Mfstroke
0 0 m
.00123 0 L
.00236 0 L
.00365 0 L
.00488 0 L
.00601 0 L
.00706 0 L
.00821 0 L
.00942 0 L
.01065 0 L
.01196 0 L
.0132 0 L
s
.0132 0 m
.0134 0 L
s
.02253 0 m
.02317 0 L
.02384 0 L
.02458 0 L
s
.02458 0 m
.02503 0 L
s
.02754 0 m
.02814 0 L
.02945 0 L
s
.02945 0 m
.0302 0 L
s
.03322 0 m
.03416 0 L
.03547 0 L
s
.03547 0 m
.03597 0 L
s
.03925 0 m
.0393 0 L
.04057 0 L
.04131 0 L
.04199 0 L
.04334 0 L
.04456 0 L
.04586 0 L
.04653 0 L
.04725 0 L
.04855 0 L
.04935 0 L
.0501 0 L
.05078 0 L
.05151 0 L
.05286 0 L
.05407 0 L
.05475 0 L
.05548 0 L
.0568 0 L
.0617 0 L
.07374 0 L
.08481 0 L
.12633 0 L
.16625 1e-05 L
.18678 1e-05 L
.20875 1e-05 L
.2311 1e-05 L
.25223 1e-05 L
.27318 1e-05 L
.29254 1e-05 L
.31217 1e-05 L
.33382 1e-05 L
.35417 1e-05 L
.37609 1e-05 L
.39717 1e-05 L
.4023 1e-05 L
.40777 1e-05 L
.41377 1e-05 L
.41642 1e-05 L
.41793 1e-05 L
.41934 1e-05 L
.42066 1e-05 L
.42207 1e-05 L
.42495 1e-05 L
.43012 1e-05 L
.43326 1e-05 L
.4348 1e-05 L
.43548 1e-05 L
.43623 1e-05 L
Mistroke
.43752 1e-05 L
.43889 1e-05 L
.43961 1e-05 L
.44039 1e-05 L
.4418 1e-05 L
.44458 1e-05 L
.44717 1e-05 L
.44848 1e-05 L
.44988 1e-05 L
.4513 1e-05 L
.45204 1e-05 L
.45284 1e-05 L
.45351 1e-05 L
.45426 1e-05 L
.45556 1e-05 L
.4569 1e-05 L
.45814 1e-05 L
.46297 1e-05 L
.46819 1e-05 L
.47094 1e-05 L
.47245 1e-05 L
.4732 1e-05 L
.47388 1e-05 L
.47523 1e-05 L
.47595 1e-05 L
.4767 1e-05 L
.47792 1e-05 L
.47925 1e-05 L
.48424 1e-05 L
.48674 1e-05 L
.4891 1e-05 L
.49183 1e-05 L
.49431 1e-05 L
.49649 1e-05 L
.49759 1e-05 L
.49881 1e-05 L
.50012 1e-05 L
.50135 1e-05 L
.50248 1e-05 L
.5037 1e-05 L
.51461 1e-05 L
.51735 1e-05 L
.51869 1e-05 L
.51993 1e-05 L
.52105 1e-05 L
.52225 1e-05 L
.52344 1e-05 L
.52476 1e-05 L
.52603 1e-05 L
.5274 1e-05 L
Mistroke
.52859 1e-05 L
.52988 1e-05 L
.53064 1e-05 L
.53134 1e-05 L
.53202 1e-05 L
.53273 1e-05 L
.53534 1e-05 L
.53685 1e-05 L
.53847 1e-05 L
.54142 1e-05 L
.54281 1e-05 L
.54357 1e-05 L
.54428 1e-05 L
.54554 1e-05 L
.54692 1e-05 L
.54825 1e-05 L
.54892 1e-05 L
.54966 1e-05 L
.5522 1e-05 L
.55293 1e-05 L
.55362 1e-05 L
.55442 1e-05 L
.55516 1e-05 L
.55648 1e-05 L
.55723 1e-05 L
.55793 1e-05 L
.55918 1e-05 L
.56053 1e-05 L
.5618 1e-05 L
.56297 1e-05 L
.56579 1e-05 L
.56702 1e-05 L
.56834 1e-05 L
.56957 1e-05 L
.57068 1e-05 L
.5718 1e-05 L
.57286 1e-05 L
.57411 1e-05 L
.57544 1e-05 L
.57657 1e-05 L
.57783 1e-05 L
.57902 1e-05 L
.5803 1e-05 L
.58151 1e-05 L
.58262 1e-05 L
.58517 1e-05 L
.58785 1e-05 L
.58914 1e-05 L
.59054 1e-05 L
.59187 1e-05 L
Mistroke
.59309 1e-05 L
.5942 1e-05 L
.59541 1e-05 L
.59668 1e-05 L
.59786 1e-05 L
.59924 1e-05 L
.60056 1e-05 L
.60174 1e-05 L
.60302 1e-05 L
.60452 1e-05 L
.60593 1e-05 L
.6072 1e-05 L
.60857 1e-05 L
.60979 1e-05 L
.61109 1e-05 L
.61341 1e-05 L
.6146 1e-05 L
.61587 1e-05 L
.6166 1e-05 L
.61727 1e-05 L
.61857 1e-05 L
.61976 1e-05 L
.62085 1e-05 L
.62206 1e-05 L
.62334 1e-05 L
.62549 1e-05 L
.62785 1e-05 L
.62915 1e-05 L
.63036 1e-05 L
.63163 1e-05 L
.63299 1e-05 L
.63426 1e-05 L
.63546 1e-05 L
.63654 1e-05 L
.63771 1e-05 L
.64039 1e-05 L
.64323 1e-05 L
.64569 1e-05 L
.64704 1e-05 L
.64832 1e-05 L
.64951 1e-05 L
.6508 1e-05 L
.65197 1e-05 L
.65305 1e-05 L
.65407 1e-05 L
.65519 1e-05 L
.65747 1e-05 L
.65997 1e-05 L
.66137 1e-05 L
.66266 1e-05 L
Mistroke
.66379 1e-05 L
.66503 1e-05 L
.66753 1e-05 L
.66999 1e-05 L
.6726 1e-05 L
.67546 1e-05 L
.6781 1e-05 L
.67928 1e-05 L
.68055 1e-05 L
.68175 1e-05 L
.68285 1e-05 L
.68413 1e-05 L
.68486 1e-05 L
.68553 1e-05 L
.68808 1e-05 L
.68946 1e-05 L
.69095 1e-05 L
.69164 1e-05 L
.69236 1e-05 L
.69366 1e-05 L
.69443 1e-05 L
.69514 1e-05 L
.69593 1e-05 L
.69677 1e-05 L
.69753 1e-05 L
.69825 1e-05 L
.6996 1e-05 L
.70086 1e-05 L
.7022 1e-05 L
.70335 1e-05 L
.70461 1e-05 L
.70597 1e-05 L
.70743 1e-05 L
.70881 1e-05 L
.71007 1e-05 L
.71137 1e-05 L
.71259 1e-05 L
.71388 1e-05 L
.71461 1e-05 L
.71528 1e-05 L
.71763 1e-05 L
.72012 1e-05 L
.72265 1e-05 L
.72406 1e-05 L
.72536 1e-05 L
.72609 1e-05 L
.72689 1e-05 L
.72764 1e-05 L
.72833 1e-05 L
.72968 1e-05 L
Mistroke
.73044 1e-05 L
.73112 1e-05 L
.73178 1e-05 L
.73251 1e-05 L
.73327 1e-05 L
.73398 1e-05 L
.73525 1e-05 L
.73661 1e-05 L
.73965 1e-05 L
.74115 1e-05 L
.74254 1e-05 L
.74384 1e-05 L
.74523 1e-05 L
.74595 1e-05 L
.74662 1e-05 L
.74736 1e-05 L
.74816 1e-05 L
.75327 1e-05 L
.75877 1e-05 L
.76387 1e-05 L
.76681 1e-05 L
.76947 1e-05 L
.77258 1e-05 L
.77395 1e-05 L
.77467 1e-05 L
.77545 1e-05 L
.77676 1e-05 L
.77798 1e-05 L
.7787 1e-05 L
.77938 1e-05 L
.78066 1e-05 L
.78359 1e-05 L
.78488 1e-05 L
.78556 1e-05 L
.7863 1e-05 L
.78753 1e-05 L
.78868 1e-05 L
.78999 1e-05 L
.7912 1e-05 L
.79399 1e-05 L
.79653 1e-05 L
.79776 1e-05 L
.79909 1e-05 L
.80034 1e-05 L
.8015 1e-05 L
.80273 1e-05 L
.80408 1e-05 L
.80551 1e-05 L
.80681 1e-05 L
.80804 1e-05 L
Mistroke
.8092 1e-05 L
.81042 1e-05 L
.81176 1e-05 L
.81292 1e-05 L
.81416 1e-05 L
.81639 1e-05 L
.82189 1e-05 L
.8249 1e-05 L
.82637 1e-05 L
.82771 1e-05 L
.82885 1e-05 L
.8301 1e-05 L
.83142 1e-05 L
.83267 1e-05 L
.83404 1e-05 L
.83473 1e-05 L
.8355 1e-05 L
.83685 1e-05 L
.83811 1e-05 L
.83944 1e-05 L
.84083 1e-05 L
.84332 1e-05 L
.846 1e-05 L
.84893 1e-05 L
.85184 1e-05 L
.85458 1e-05 L
.8561 1e-05 L
.85696 1e-05 L
.85775 1e-05 L
.85841 1e-05 L
.85914 1e-05 L
.8599 1e-05 L
.86062 1e-05 L
.8613 1e-05 L
.86204 1e-05 L
.86339 1e-05 L
.8647 1e-05 L
.86591 1e-05 L
.8716 1e-05 L
.87415 1e-05 L
.87654 1e-05 L
.87787 1e-05 L
.8793 1e-05 L
.88061 1e-05 L
.8818 1e-05 L
.89138 1e-05 L
.89665 1e-05 L
.90163 1e-05 L
.90445 1e-05 L
.90523 1e-05 L
Mistroke
.90605 1e-05 L
.90675 1e-05 L
.90752 1e-05 L
.90883 1e-05 L
.91007 1e-05 L
.91082 1e-05 L
.91153 1e-05 L
.91287 1e-05 L
.91413 1e-05 L
.91547 1e-05 L
.91663 1e-05 L
.91788 1e-05 L
.91865 1e-05 L
.91936 1e-05 L
.92003 1e-05 L
.92075 1e-05 L
.92199 1e-05 L
.92335 1e-05 L
.92472 1e-05 L
.92598 1e-05 L
.92885 1e-05 L
.93406 1e-05 L
.94383 1e-05 L
.94932 1e-05 L
.95448 1e-05 L
.95985 1e-05 L
.96579 1e-05 L
1 1e-05 L
Mfstroke
0 0 m
.00123 0 L
.00236 0 L
.00365 0 L
.00488 0 L
.00601 0 L
.00706 0 L
.00821 0 L
.00942 0 L
.01065 0 L
.01196 0 L
.0132 0 L
.01434 0 L
.01566 0 L
.01641 0 L
.01711 0 L
.01839 0 L
.01975 0 L
.02043 0 L
.02115 0 L
.02245 0 L
s
.02245 0 m
.02251 0 L
s
.02501 0 m
.02537 0 L
.02605 0 L
.02679 0 L
s
.02679 0 m
.02752 0 L
s
.03017 0 m
.03067 0 L
.03184 0 L
.03295 0 L
s
.03295 0 m
.0332 0 L
s
.03592 0 m
.03676 0 L
.03813 0 L
.0393 0 L
.04057 0 L
.04131 0 L
.04199 0 L
.04334 0 L
.04456 0 L
.04586 0 L
.04653 0 L
.04725 0 L
.04855 0 L
.04935 0 L
.0501 0 L
.05078 0 L
.05151 0 L
.05286 0 L
.05407 0 L
.05475 0 L
.05548 0 L
.0568 0 L
.05804 0 L
.05935 0 L
.06047 0 L
.0617 0 L
.08481 0 L
.12731 0 L
.16822 0 L
.19056 0 L
.2117 0 L
.23265 0 L
.252 0 L
.27164 0 L
.29329 0 L
.31364 0 L
.33556 0 L
.35664 0 L
.37881 0 L
.384 0 L
.38962 0 L
.39457 0 L
.39728 0 L
.39861 0 L
.39981 0 L
.40209 0 L
.40454 0 L
.40974 0 L
.41448 0 L
.41657 0 L
Mistroke
.41776 0 L
.41888 0 L
.42006 0 L
.42133 0 L
.4227 0 L
.42395 0 L
.42658 0 L
.42798 0 L
.42947 0 L
.43079 0 L
.432 0 L
.43322 0 L
.43436 0 L
.43563 0 L
.437 0 L
.43822 0 L
.43951 0 L
.44492 0 L
.44998 0 L
.45135 0 L
.45207 0 L
.45284 0 L
.45357 0 L
.45424 0 L
.45554 0 L
.45632 0 L
.45715 0 L
.45866 0 L
.46152 0 L
.46401 0 L
.46669 0 L
.46921 0 L
.47151 0 L
.47282 0 L
.47348 0 L
.47421 0 L
.47499 0 L
.47573 0 L
.47641 0 L
.47714 0 L
.4785 0 L
.47992 0 L
.48247 0 L
.49304 0 L
.49593 0 L
.49677 0 L
.49755 0 L
.49826 0 L
.49903 0 L
.4997 0 L
Mistroke
.50043 0 L
.5012 0 L
.50192 0 L
.50459 0 L
.50983 0 L
.51125 0 L
.51259 0 L
.51414 0 L
.51553 0 L
.51812 0 L
.51948 0 L
.52023 0 L
.52092 0 L
.52216 0 L
.52352 0 L
.52468 0 L
.52591 0 L
.52842 0 L
.52911 0 L
.52984 0 L
.53115 0 L
.53237 0 L
.53351 0 L
.53484 0 L
.5361 0 L
.53844 0 L
.54057 0 L
.54288 0 L
.54418 0 L
.54538 0 L
.5467 0 L
.54737 0 L
.5481 0 L
.54942 0 L
.55065 0 L
.55184 0 L
.55296 0 L
.55426 0 L
.55544 0 L
.55673 0 L
.55811 0 L
.5593 0 L
.56058 0 L
.56195 0 L
.56323 0 L
.56475 0 L
.56617 0 L
.5673 0 L
.56851 0 L
.56985 0 L
Mistroke
.57107 0 L
.57234 0 L
.57373 0 L
.57492 0 L
.57623 0 L
.57744 0 L
.57857 0 L
.57976 0 L
.58104 0 L
.58223 0 L
.58335 0 L
.58547 0 L
.58797 0 L
.58928 0 L
.59067 0 L
.59188 0 L
.59321 0 L
.59443 0 L
.59556 0 L
.59828 0 L
.59977 0 L
.60051 0 L
.60119 0 L
.60247 0 L
.60386 0 L
.60504 0 L
.6063 0 L
.6086 0 L
.61075 0 L
.6131 0 L
.61443 0 L
.61567 0 L
.61689 0 L
.6182 0 L
.61892 0 L
.61959 0 L
.62086 0 L
.62205 0 L
.62314 0 L
.62561 0 L
.62682 0 L
.62814 0 L
.62938 0 L
.63053 0 L
.63187 0 L
.63255 0 L
.63329 0 L
.63459 0 L
.63581 0 L
.6382 0 L
Mistroke
.6404 0 L
.64535 0 L
.6466 0 L
.64778 0 L
.64914 0 L
.65038 0 L
.65175 0 L
.65253 0 L
.65324 0 L
.65453 0 L
.6559 0 L
.65845 0 L
.65986 0 L
.6612 0 L
.66195 0 L
.66277 0 L
.66352 0 L
.66421 0 L
.66557 0 L
.66703 0 L
.66977 0 L
.67114 0 L
.67266 0 L
.67783 0 L
.67855 0 L
.67933 0 L
.68002 0 L
.68075 0 L
.6816 0 L
.68239 0 L
.68309 0 L
.68388 0 L
.68461 0 L
.68528 0 L
.68679 0 L
.68952 0 L
.69075 0 L
.69207 0 L
.69332 0 L
.69445 0 L
.69578 0 L
.69653 0 L
.69722 0 L
.69849 0 L
.69984 0 L
.70251 0 L
.70501 0 L
.70796 0 L
.7094 0 L
.7107 0 L
Mistroke
.712 0 L
.71323 0 L
.71453 0 L
.71526 0 L
.71593 0 L
.71725 0 L
.7187 0 L
.72024 0 L
.72163 0 L
.72296 0 L
.72422 0 L
.72555 0 L
.72631 0 L
.727 0 L
.72816 0 L
.72943 0 L
.73076 0 L
.73201 0 L
.73651 0 L
.74131 0 L
.74273 0 L
.74407 0 L
.74528 0 L
.74658 0 L
.74782 0 L
.74913 0 L
.75147 0 L
.75397 0 L
.75538 0 L
.75666 0 L
.75738 0 L
.75817 0 L
.75961 0 L
.76091 0 L
.76236 0 L
.7637 0 L
.76496 0 L
.76773 0 L
.77016 0 L
.77148 0 L
.77271 0 L
.77384 0 L
.77504 0 L
.77638 0 L
.77759 0 L
.77869 0 L
.77989 0 L
.78207 0 L
.78461 0 L
.78601 0 L
Mistroke
.78731 0 L
.78843 0 L
.78962 0 L
.79094 0 L
.79216 0 L
.80182 0 L
.80437 0 L
.80712 0 L
.80839 0 L
.80972 0 L
.81086 0 L
.81211 0 L
.81289 0 L
.81359 0 L
.81441 0 L
.81518 0 L
.81655 0 L
.81804 0 L
.8234 0 L
.82604 0 L
.82738 0 L
.82814 0 L
.82885 0 L
.83011 0 L
.83127 0 L
.83254 0 L
.83388 0 L
.8364 0 L
.83767 0 L
.83906 0 L
.84199 0 L
.84468 0 L
.84959 0 L
.8523 0 L
.85487 0 L
.85606 0 L
.85733 0 L
.85806 0 L
.85872 0 L
.86001 0 L
.86118 0 L
.86244 0 L
.86362 0 L
.86471 0 L
.86948 0 L
.87181 0 L
.87392 0 L
.87503 0 L
.87624 0 L
.87751 0 L
Mistroke
.87871 0 L
.88003 0 L
.8807 0 L
.88144 0 L
.88274 0 L
.88396 0 L
.88521 0 L
.88655 0 L
.88732 0 L
.88802 0 L
.88938 0 L
.89065 0 L
.89203 0 L
.89334 0 L
.89453 0 L
.89723 0 L
.8987 0 L
.90007 0 L
.90124 0 L
.90248 0 L
.90387 0 L
.90514 0 L
.90584 0 L
.90659 0 L
.90794 0 L
.90939 0 L
.91099 0 L
.91654 0 L
.91921 0 L
.9217 0 L
.92296 0 L
.9243 0 L
.92578 0 L
.92714 0 L
.92953 0 L
.93213 0 L
.93685 0 L
.94728 0 L
.95013 0 L
.95174 0 L
.9532 0 L
.95875 0 L
.97878 0 L
.98399 0 L
.98674 0 L
.98753 0 L
.98828 0 L
.98894 0 L
.98967 0 L
.99103 0 L
Mistroke
.99171 0 L
.99246 0 L
.99379 0 L
.99503 0 L
.99629 0 L
.99743 0 L
.99875 0 L
1 0 L
Mfstroke
0 0 m
.00123 0 L
.00236 0 L
.00365 0 L
.00488 0 L
.00601 0 L
.00706 0 L
.00821 0 L
.00942 0 L
s
.00942 0 m
.01022 0 L
s
.02247 0 m
.02317 0 L
.02384 0 L
.02458 0 L
s
.02458 0 m
.025 0 L
s
.0275 0 m
.02814 0 L
.02945 0 L
s
.02945 0 m
.03014 0 L
s
.03315 0 m
.03416 0 L
.03547 0 L
s
.03547 0 m
.03589 0 L
s
.03928 0 m
.03929 0 L
s
.03929 0 m
.03971 0 L
s
.04119 0 m
.04131 0 L
s
.04131 0 m
.04172 0 L
s
.04205 0 m
.04275 0 L
s
.04275 0 m
.04342 0 L
s
.04426 0 m
.0449 0 L
.04566 0 L
.04637 0 L
.0477 0 L
.04892 0 L
.04959 0 L
.05032 0 L
.05165 0 L
.05245 0 L
.05321 0 L
.05389 0 L
.05462 0 L
.05543 0 L
.05627 0 L
.057 0 L
.05779 0 L
.06349 0 L
.08481 0 L
.12731 0 L
.16822 0 L
.19056 0 L
.2117 0 L
.23265 0 L
.252 0 L
.27164 0 L
.28294 0 L
.28789 0 L
.2905 0 L
.29193 0 L
.29329 0 L
.29598 0 L
.29843 0 L
.30321 0 L
.30822 0 L
.31364 0 L
.32505 0 L
.33556 0 L
.3553 0 L
.37698 0 L
.38749 0 L
.39266 0 L
.39744 0 L
.39882 0 L
.40011 0 L
.40145 0 L
.40217 0 L
.40294 0 L
.40366 0 L
.40446 0 L
Mistroke
.40529 0 L
.40606 0 L
.40753 0 L
.40892 0 L
.41019 0 L
.41157 0 L
.41283 0 L
.41398 0 L
.41534 0 L
.41661 0 L
.41794 0 L
.41864 0 L
.41939 0 L
.42012 0 L
.42079 0 L
.42206 0 L
.4249 0 L
.42739 0 L
.43002 0 L
.43292 0 L
.4342 0 L
.43558 0 L
.43636 0 L
.43707 0 L
.43845 0 L
.43923 0 L
.44007 0 L
.4416 0 L
.44434 0 L
.44692 0 L
.4496 0 L
.45105 0 L
.45256 0 L
.45378 0 L
.45511 0 L
.45632 0 L
.45744 0 L
.45878 0 L
.45999 0 L
.4627 0 L
.46534 0 L
.4678 0 L
.47037 0 L
.47182 0 L
.47319 0 L
.47436 0 L
.47563 0 L
.47678 0 L
.47785 0 L
.47913 0 L
Mistroke
.48028 0 L
.48286 0 L
.48827 0 L
.49132 0 L
.49412 0 L
.49541 0 L
.49678 0 L
.49809 0 L
.49927 0 L
.5006 0 L
.50186 0 L
.50322 0 L
.5047 0 L
.51461 0 L
.51753 0 L
.51897 0 L
.52031 0 L
.52151 0 L
.5228 0 L
.52354 0 L
.52423 0 L
.52552 0 L
.52691 0 L
.52838 0 L
.52964 0 L
.53101 0 L
.53172 0 L
.53248 0 L
.53385 0 L
.53692 0 L
.53961 0 L
.54247 0 L
.54364 0 L
.54491 0 L
.54563 0 L
.5463 0 L
.5476 0 L
.54889 0 L
.55008 0 L
.55151 0 L
.5528 0 L
.55416 0 L
.55545 0 L
.5568 0 L
.55757 0 L
.55828 0 L
.55957 0 L
.56096 0 L
.56249 0 L
.56392 0 L
Mistroke
.56552 0 L
.56631 0 L
.56704 0 L
.5684 0 L
.56912 0 L
.56989 0 L
.57059 0 L
.57132 0 L
.57264 0 L
.57417 0 L
.5756 0 L
.57684 0 L
.57817 0 L
.57892 0 L
.57964 0 L
.58098 0 L
.58219 0 L
.58348 0 L
.58579 0 L
.58834 0 L
.58973 0 L
.59102 0 L
.59221 0 L
.59348 0 L
.5942 0 L
.59488 0 L
.59616 0 L
.59845 0 L
.59971 0 L
.60088 0 L
.60214 0 L
.60353 0 L
.60597 0 L
.60736 0 L
.60864 0 L
.61149 0 L
.61378 0 L
.61503 0 L
.61621 0 L
.61748 0 L
.61815 0 L
.61888 0 L
.62017 0 L
.62135 0 L
.62247 0 L
.62352 0 L
.6259 0 L
.62709 0 L
.62822 0 L
.62952 0 L
Mistroke
.6307 0 L
.6319 0 L
.6332 0 L
.63442 0 L
.63554 0 L
.63685 0 L
.63828 0 L
.64088 0 L
.64611 0 L
.64761 0 L
.64835 0 L
.64903 0 L
.6503 0 L
.65168 0 L
.65288 0 L
.654 0 L
.65524 0 L
.65656 0 L
.65921 0 L
.66051 0 L
.66172 0 L
.66285 0 L
.66405 0 L
.66526 0 L
.66659 0 L
.6689 0 L
.67104 0 L
.67351 0 L
.6762 0 L
.67767 0 L
.67905 0 L
.68029 0 L
.68164 0 L
.68283 0 L
.68409 0 L
.68516 0 L
.68634 0 L
.68892 0 L
.69136 0 L
.69272 0 L
.6935 0 L
.69421 0 L
.69547 0 L
.69682 0 L
.69758 0 L
.6984 0 L
.69989 0 L
.70134 0 L
.70268 0 L
.70779 0 L
Mistroke
.70914 0 L
.70985 0 L
.7106 0 L
.71198 0 L
.71326 0 L
.71458 0 L
.71581 0 L
.71717 0 L
.71863 0 L
.72096 0 L
.7222 0 L
.72351 0 L
.72484 0 L
.72607 0 L
.72735 0 L
.7285 0 L
.72963 0 L
.73086 0 L
.73307 0 L
.73569 0 L
.73857 0 L
.74137 0 L
.74218 0 L
.74294 0 L
.74363 0 L
.74438 0 L
.74573 0 L
.74642 0 L
.74717 0 L
.74851 0 L
.74976 0 L
.75236 0 L
.75363 0 L
.75479 0 L
.75716 0 L
.75847 0 L
.75971 0 L
.76251 0 L
.7651 0 L
.76763 0 L
.77031 0 L
.77303 0 L
.77381 0 L
.77456 0 L
.77523 0 L
.77596 0 L
.77716 0 L
.77843 0 L
.77964 0 L
.78073 0 L
Mistroke
.78306 0 L
.7852 0 L
.78643 0 L
.78772 0 L
.78902 0 L
.78976 0 L
.79045 0 L
.79169 0 L
.79283 0 L
.79415 0 L
.79538 0 L
.79654 0 L
.79779 0 L
.80044 0 L
.80324 0 L
.8058 0 L
.80689 0 L
.80805 0 L
.80932 0 L
.8105 0 L
.81183 0 L
.81309 0 L
.81422 0 L
.81544 0 L
.82045 0 L
.82321 0 L
.82583 0 L
.82731 0 L
.82808 0 L
.82891 0 L
.82968 0 L
.83038 0 L
.83173 0 L
.8331 0 L
.83387 0 L
.83457 0 L
.83588 0 L
.83725 0 L
.83974 0 L
.84241 0 L
.84722 0 L
.85245 0 L
.85521 0 L
.85661 0 L
.8574 0 L
.85814 0 L
.85892 0 L
.85963 0 L
.86045 0 L
.86123 0 L
Mistroke
.8626 0 L
.86337 0 L
.86409 0 L
.86971 0 L
.87234 0 L
.87481 0 L
.87618 0 L
.8769 0 L
.87766 0 L
.879 0 L
.88024 0 L
.88152 0 L
.88224 0 L
.88291 0 L
.88545 0 L
.89019 0 L
.89536 0 L
.89801 0 L
.90086 0 L
.90206 0 L
.90332 0 L
.9044 0 L
.90558 0 L
.90669 0 L
.90787 0 L
.90899 0 L
.91001 0 L
.9113 0 L
.9125 0 L
.9152 0 L
.91772 0 L
.92011 0 L
.92133 0 L
.92267 0 L
.92389 0 L
.92501 0 L
.92635 0 L
.92756 0 L
.92824 0 L
.92897 0 L
.93028 0 L
.9398 0 L
.9448 0 L
.95014 0 L
.95321 0 L
.95601 0 L
.95735 0 L
.95882 0 L
.96019 0 L
.96147 0 L
Mistroke
.96372 0 L
.9662 0 L
.96738 0 L
.96862 0 L
.96997 0 L
.97122 0 L
.9723 0 L
.97345 0 L
.97453 0 L
.97552 0 L
.97668 0 L
.97794 0 L
.97913 0 L
.98022 0 L
.98262 0 L
.98519 0 L
.98644 0 L
.98762 0 L
.98868 0 L
.98983 0 L
.99105 0 L
.99235 0 L
.99468 0 L
1 0 L
Mfstroke
0 0 m
.00123 0 L
.00236 0 L
.00365 0 L
.00488 0 L
.00601 0 L
.00706 0 L
s
.00706 0 m
.00722 0 L
s
.01224 0 m
.0132 0 L
.01434 0 L
.01566 0 L
.01641 0 L
.01711 0 L
.01839 0 L
.01975 0 L
.02043 0 L
.02115 0 L
s
.02115 0 m
.02244 0 L
s
.02499 0 m
.02537 0 L
.02605 0 L
.02679 0 L
s
.02679 0 m
.02748 0 L
s
.03012 0 m
.03067 0 L
.03184 0 L
.03295 0 L
s
.03295 0 m
.03312 0 L
s
.03585 0 m
.03676 0 L
.03813 0 L
s
.03813 0 m
.03927 0 L
s
.03971 0 m
.04057 0 L
s
.04057 0 m
.04126 0 L
s
.04144 0 m
.042 0 L
s
.042 0 m
.04213 0 L
s
.04333 0 m
.04355 0 L
s
.04355 0 m
.04482 0 L
s
.04499 0 m
.04566 0 L
.04637 0 L
.0477 0 L
s
.0477 0 m
.04865 0 L
s
.05059 0 m
.05165 0 L
s
.05165 0 m
.05226 0 L
s
.05332 0 m
.05389 0 L
.05462 0 L
.05543 0 L
.05627 0 L
.057 0 L
.05779 0 L
.05854 0 L
.05921 0 L
.06 0 L
.06074 0 L
.06205 0 L
.0628 0 L
.06349 0 L
.06471 0 L
.06603 0 L
.06841 0 L
.07383 0 L
.08481 0 L
.12806 0 L
.14966 0 L
.16972 0 L
.19034 0 L
.20979 0 L
.23131 0 L
.25084 0 L
.26108 0 L
.2719 0 L
.27419 0 L
.27635 0 L
.27755 0 L
.27886 0 L
.28004 0 L
.28114 0 L
.28368 0 L
.28507 0 L
.28638 0 L
.2875 0 L
.28871 0 L
.29006 0 L
.29129 0 L
.29258 0 L
.2938 0 L
.29648 0 L
.30132 0 L
.30388 0 L
.30455 0 L
.30528 0 L
.30659 0 L
.30733 0 L
Mistroke
.308 0 L
.3088 0 L
.30956 0 L
.31087 0 L
.31161 0 L
.3123 0 L
.33445 0 L
.35601 0 L
.37556 0 L
.37822 0 L
.38107 0 L
.38246 0 L
.38377 0 L
.38622 0 L
.38879 0 L
.39012 0 L
.39159 0 L
.39236 0 L
.39308 0 L
.39383 0 L
.39465 0 L
.39537 0 L
.39613 0 L
.39748 0 L
.39875 0 L
.3999 0 L
.40122 0 L
.40247 0 L
.40363 0 L
.4047 0 L
.40712 0 L
.41765 0 L
.41885 0 L
.42013 0 L
.42086 0 L
.42153 0 L
.42283 0 L
.42774 0 L
.43066 0 L
.4334 0 L
.43461 0 L
.43589 0 L
.43656 0 L
.43729 0 L
.43858 0 L
.43989 0 L
.44114 0 L
.44347 0 L
.44619 0 L
.44871 0 L
Mistroke
.45086 0 L
.452 0 L
.45323 0 L
.45446 0 L
.45562 0 L
.45694 0 L
.45815 0 L
.46757 0 L
.47014 0 L
.47139 0 L
.47255 0 L
.47389 0 L
.47459 0 L
.47534 0 L
.47654 0 L
.47786 0 L
.47861 0 L
.4793 0 L
.48084 0 L
.48217 0 L
.48362 0 L
.48637 0 L
.48897 0 L
.49442 0 L
.49572 0 L
.49709 0 L
.49826 0 L
.49954 0 L
.50073 0 L
.502 0 L
.5032 0 L
.50429 0 L
.5094 0 L
.51209 0 L
.51361 0 L
.515 0 L
.51774 0 L
.51907 0 L
.52029 0 L
.52155 0 L
.52275 0 L
.52402 0 L
.52539 0 L
.52834 0 L
.52962 0 L
.531 0 L
.53177 0 L
.53247 0 L
.53385 0 L
.5353 0 L
Mistroke
.53689 0 L
.53826 0 L
.53955 0 L
.54091 0 L
.54235 0 L
.54365 0 L
.54439 0 L
.54509 0 L
.54631 0 L
.54762 0 L
.54831 0 L
.54907 0 L
.55061 0 L
.55204 0 L
.55334 0 L
.55469 0 L
.55595 0 L
.55729 0 L
.55804 0 L
.55874 0 L
.56 0 L
.56117 0 L
.5624 0 L
.56375 0 L
.56496 0 L
.56627 0 L
.56752 0 L
.56867 0 L
.5697 0 L
.57084 0 L
.57203 0 L
.57315 0 L
.57552 0 L
.5767 0 L
.57801 0 L
.57869 0 L
.57942 0 L
.58074 0 L
.58205 0 L
.58324 0 L
.58832 0 L
.58966 0 L
.5904 0 L
.5911 0 L
.59246 0 L
.5937 0 L
.59484 0 L
.5959 0 L
.5983 0 L
.59956 0 L
Mistroke
.60074 0 L
.60211 0 L
.60335 0 L
.60601 0 L
.60735 0 L
.60882 0 L
.61141 0 L
.61384 0 L
.61531 0 L
.61603 0 L
.6167 0 L
.61795 0 L
.61931 0 L
.62066 0 L
.62143 0 L
.62216 0 L
.62518 0 L
.62756 0 L
.6289 0 L
.63011 0 L
.6308 0 L
.63155 0 L
.63291 0 L
.63426 0 L
.63551 0 L
.63681 0 L
.63802 0 L
.64079 0 L
.64365 0 L
.64638 0 L
.64751 0 L
.64872 0 L
.65004 0 L
.65127 0 L
.65248 0 L
.65362 0 L
.65464 0 L
.65575 0 L
.6583 0 L
.65969 0 L
.66099 0 L
.6621 0 L
.66329 0 L
.66461 0 L
.66581 0 L
.67555 0 L
.67792 0 L
.67923 0 L
.68047 0 L
.68117 0 L
Mistroke
.68193 0 L
.68327 0 L
.68463 0 L
.68589 0 L
.68872 0 L
.69138 0 L
.69285 0 L
.69368 0 L
.69445 0 L
.6958 0 L
.69648 0 L
.69723 0 L
.70771 0 L
.70898 0 L
.71034 0 L
.71105 0 L
.71183 0 L
.7132 0 L
.71449 0 L
.71522 0 L
.71589 0 L
.71712 0 L
.71841 0 L
.72066 0 L
.7219 0 L
.72307 0 L
.72446 0 L
.72571 0 L
.72689 0 L
.72817 0 L
.72954 0 L
.73081 0 L
.73372 0 L
.73655 0 L
.73959 0 L
.74094 0 L
.74242 0 L
.74309 0 L
.74381 0 L
.7451 0 L
.74646 0 L
.74774 0 L
.74889 0 L
.75013 0 L
.76097 0 L
.77109 0 L
.77234 0 L
.7737 0 L
.77499 0 L
.77618 0 L
Mistroke
.77756 0 L
.77826 0 L
.77904 0 L
.78038 0 L
.78164 0 L
.78435 0 L
.78583 0 L
.78721 0 L
.78793 0 L
.78871 0 L
.78956 0 L
.79034 0 L
.79182 0 L
.79321 0 L
.79556 0 L
.79808 0 L
.80085 0 L
.80343 0 L
.80633 0 L
.80776 0 L
.80909 0 L
.81028 0 L
.81156 0 L
.81228 0 L
.81297 0 L
.81425 0 L
.81538 0 L
.81661 0 L
.81911 0 L
.82357 0 L
.82608 0 L
.82749 0 L
.82878 0 L
.82997 0 L
.83127 0 L
.8325 0 L
.83363 0 L
.83485 0 L
.83615 0 L
.83757 0 L
.8389 0 L
.8439 0 L
.84693 0 L
.84968 0 L
.85243 0 L
.85496 0 L
.8562 0 L
.85736 0 L
.85857 0 L
.8599 0 L
Mistroke
.86125 0 L
.86248 0 L
.86316 0 L
.8639 0 L
.86525 0 L
.87025 0 L
.8727 0 L
.87494 0 L
.87606 0 L
.87723 0 L
.87841 0 L
.8797 0 L
.88101 0 L
.88175 0 L
.88242 0 L
.88372 0 L
.88495 0 L
.88742 0 L
.89005 0 L
.89292 0 L
.89557 0 L
.89996 0 L
.90122 0 L
.90242 0 L
.90349 0 L
.90466 0 L
.90596 0 L
.90734 0 L
.90865 0 L
.90983 0 L
.91232 0 L
.91466 0 L
.91723 0 L
.91998 0 L
.92132 0 L
.92258 0 L
.92371 0 L
.92494 0 L
.92625 0 L
.92763 0 L
.92881 0 L
.93011 0 L
.93578 0 L
.95519 0 L
.95658 0 L
.95789 0 L
.9594 0 L
.96077 0 L
.96197 0 L
.96325 0 L
Mistroke
.96392 0 L
.96465 0 L
.96595 0 L
.96729 0 L
.96805 0 L
.96874 0 L
.97008 0 L
.97135 0 L
.97418 0 L
.97725 0 L
.98234 0 L
.98512 0 L
.98649 0 L
.98774 0 L
.98882 0 L
.98996 0 L
.99111 0 L
.99236 0 L
.995 0 L
.99628 0 L
.99746 0 L
.99869 0 L
1 0 L
Mfstroke
0 0 m
.00123 0 L
.00236 0 L
.00365 0 L
.00488 0 L
.00601 0 L
.00706 0 L
.00821 0 L
.00942 0 L
.01065 0 L
.01196 0 L
.0132 0 L
.01434 0 L
.01566 0 L
s
.01566 0 m
.01577 0 L
s
.02243 0 m
.02245 0 L
.02317 0 L
.02397 0 L
.02469 0 L
s
.02469 0 m
.025 0 L
s
.02744 0 m
.02793 0 L
.0286 0 L
.02933 0 L
s
.02933 0 m
.03005 0 L
s
.03278 0 m
.03316 0 L
.03453 0 L
s
.03453 0 m
.03546 0 L
s
.03928 0 m
.0393 0 L
s
.0393 0 m
.03977 0 L
s
.04121 0 m
.04125 0 L
s
.04125 0 m
.04137 0 L
s
.04282 0 m
.04334 0 L
.04465 0 L
s
.04465 0 m
.04547 0 L
s
.047 0 m
.04717 0 L
.04791 0 L
.04861 0 L
.04932 0 L
.05001 0 L
.05079 0 L
s
.05079 0 m
.05097 0 L
s
.05201 0 m
.05274 0 L
s
.05274 0 m
.0535 0 L
s
.05494 0 m
.05527 0 L
.05638 0 L
.0577 0 L
.05844 0 L
.05912 0 L
.06037 0 L
.0617 0 L
.06244 0 L
.06314 0 L
.06445 0 L
.06519 0 L
.06587 0 L
.0674 0 L
.07272 0 L
.08481 0 L
.12609 0 L
.16579 0 L
.18614 0 L
.20805 0 L
.22914 0 L
.25131 0 L
.27231 0 L
.28147 0 L
.28628 0 L
.28891 0 L
.2902 0 L
.29137 0 L
.29265 0 L
.29401 0 L
.2969 0 L
.30199 0 L
.30319 0 L
.30445 0 L
.30512 0 L
.30585 0 L
.30713 0 L
.31201 0 L
.31747 0 L
.32336 0 L
.33402 0 L
.35462 0 L
.36027 0 L
.3663 0 L
.372 0 L
.37718 0 L
.38743 0 L
.39322 0 L
.39598 0 L
.39732 0 L
Mistroke
.39856 0 L
.39971 0 L
.40081 0 L
.40196 0 L
.40322 0 L
.40451 0 L
.40589 0 L
.40836 0 L
.40971 0 L
.41117 0 L
.41255 0 L
.41381 0 L
.41503 0 L
.41635 0 L
.4176 0 L
.41875 0 L
.42001 0 L
.42134 0 L
.42369 0 L
.42899 0 L
.43358 0 L
.43484 0 L
.43617 0 L
.4373 0 L
.43853 0 L
.43987 0 L
.44129 0 L
.44386 0 L
.44885 0 L
.45033 0 L
.45192 0 L
.45265 0 L
.45343 0 L
.45409 0 L
.45482 0 L
.45617 0 L
.45693 0 L
.45762 0 L
.46024 0 L
.46992 0 L
.47126 0 L
.47197 0 L
.47271 0 L
.47407 0 L
.47533 0 L
.47654 0 L
.47767 0 L
.4789 0 L
.48023 0 L
.49153 0 L
Mistroke
.49415 0 L
.49544 0 L
.49661 0 L
.49785 0 L
.49918 0 L
.49987 0 L
.50063 0 L
.50201 0 L
.5049 0 L
.50758 0 L
.51273 0 L
.51587 0 L
.51883 0 L
.52012 0 L
.52149 0 L
.5222 0 L
.52299 0 L
.52437 0 L
.5257 0 L
.52692 0 L
.52823 0 L
.52966 0 L
.53098 0 L
.53219 0 L
.5346 0 L
.53711 0 L
.53854 0 L
.53989 0 L
.5413 0 L
.5428 0 L
.54353 0 L
.54422 0 L
.54551 0 L
.54674 0 L
.54787 0 L
.54912 0 L
.55044 0 L
.55167 0 L
.553 0 L
.55377 0 L
.55446 0 L
.55583 0 L
.55721 0 L
.55849 0 L
.56002 0 L
.5614 0 L
.56396 0 L
.56529 0 L
.56669 0 L
.56789 0 L
Mistroke
.5692 0 L
.57039 0 L
.5715 0 L
.57282 0 L
.57401 0 L
.57541 0 L
.5767 0 L
.57783 0 L
.57902 0 L
.58022 0 L
.58154 0 L
.58268 0 L
.5839 0 L
.58612 0 L
.58864 0 L
.59003 0 L
.59134 0 L
.59256 0 L
.59388 0 L
.59508 0 L
.59619 0 L
.60143 0 L
.60421 0 L
.60574 0 L
.60719 0 L
.60859 0 L
.6101 0 L
.61276 0 L
.61523 0 L
.61591 0 L
.61664 0 L
.61797 0 L
.61869 0 L
.61946 0 L
.62083 0 L
.62158 0 L
.62229 0 L
.62388 0 L
.62673 0 L
.62798 0 L
.62936 0 L
.63068 0 L
.63192 0 L
.63324 0 L
.63397 0 L
.63465 0 L
.63537 0 L
.63605 0 L
.63759 0 L
.64038 0 L
Mistroke
.6432 0 L
.64585 0 L
.64701 0 L
.64823 0 L
.64957 0 L
.6508 0 L
.65193 0 L
.65313 0 L
.65427 0 L
.6553 0 L
.65787 0 L
.66024 0 L
.66145 0 L
.66272 0 L
.664 0 L
.66473 0 L
.66541 0 L
.66778 0 L
.67031 0 L
.67286 0 L
.67524 0 L
.67783 0 L
.67919 0 L
.67994 0 L
.68064 0 L
.68136 0 L
.68216 0 L
.68284 0 L
.68357 0 L
.68431 0 L
.68501 0 L
.68633 0 L
.68884 0 L
.69021 0 L
.69151 0 L
.69272 0 L
.69404 0 L
.69523 0 L
.69633 0 L
.69737 0 L
.69851 0 L
.7008 0 L
.70213 0 L
.70334 0 L
.70605 0 L
.70857 0 L
.70981 0 L
.71094 0 L
.7121 0 L
.71335 0 L
Mistroke
.71471 0 L
.716 0 L
.71734 0 L
.71857 0 L
.72138 0 L
.72264 0 L
.72383 0 L
.72489 0 L
.72605 0 L
.72731 0 L
.72864 0 L
.72977 0 L
.73102 0 L
.73647 0 L
.73946 0 L
.74094 0 L
.7423 0 L
.74358 0 L
.74494 0 L
.74631 0 L
.74708 0 L
.74781 0 L
.74907 0 L
.75042 0 L
.75168 0 L
.75284 0 L
.75405 0 L
.75537 0 L
.75661 0 L
.75776 0 L
.75901 0 L
.76038 0 L
.76315 0 L
.76585 0 L
.76876 0 L
.77127 0 L
.7726 0 L
.77401 0 L
.77474 0 L
.77543 0 L
.77671 0 L
.77791 0 L
.77921 0 L
.78047 0 L
.78179 0 L
.78416 0 L
.78526 0 L
.78645 0 L
.78756 0 L
.78858 0 L
Mistroke
.78978 0 L
.79107 0 L
.79343 0 L
.79472 0 L
.79589 0 L
.79853 0 L
.80087 0 L
.80332 0 L
.80584 0 L
.80722 0 L
.80853 0 L
.80927 0 L
.81007 0 L
.8108 0 L
.81148 0 L
.81281 0 L
.81348 0 L
.81422 0 L
.81493 0 L
.81569 0 L
.81709 0 L
.81972 0 L
.82258 0 L
.82562 0 L
.82712 0 L
.82853 0 L
.82979 0 L
.83116 0 L
.83246 0 L
.83383 0 L
.835 0 L
.83629 0 L
.83766 0 L
.83894 0 L
.84181 0 L
.84435 0 L
.84704 0 L
.85176 0 L
.85436 0 L
.85564 0 L
.85683 0 L
.85818 0 L
.85889 0 L
.85965 0 L
.86101 0 L
.86223 0 L
.86348 0 L
.86484 0 L
.86729 0 L
.87017 0 L
Mistroke
.87325 0 L
.87474 0 L
.87616 0 L
.87743 0 L
.87881 0 L
.88001 0 L
.88133 0 L
.884 0 L
.88879 0 L
.89444 0 L
.89975 0 L
.90245 0 L
.90381 0 L
.90458 0 L
.9053 0 L
.90659 0 L
.90776 0 L
.90911 0 L
.91039 0 L
.91178 0 L
.91325 0 L
.91589 0 L
.91896 0 L
.92046 0 L
.92186 0 L
.92306 0 L
.92434 0 L
.92507 0 L
.92576 0 L
.92704 0 L
.92822 0 L
.92931 0 L
.93177 0 L
.93305 0 L
.93424 0 L
.93695 0 L
.93959 0 L
.94241 0 L
.94489 0 L
.9462 0 L
.94758 0 L
.94879 0 L
.95013 0 L
.95134 0 L
.95248 0 L
.9536 0 L
.95478 0 L
.95579 0 L
.95689 0 L
.96164 0 L
Mistroke
.96404 0 L
.96665 0 L
.96784 0 L
.9691 0 L
.9702 0 L
.97137 0 L
.97354 0 L
.97558 0 L
.9802 0 L
.98551 0 L
.98678 0 L
.98813 0 L
.98928 0 L
.99055 0 L
.99167 0 L
.99288 0 L
.99507 0 L
1 0 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[65]:=",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/A000`40O003h00Oogoo8Goo003oOolQ
Ool00?moob5oo`00ogoo8Goo003oOolQOol004Yoo`D0031oo`<002moo`<0031oo`<002eoo`<000Ao
o`8000=oo`00Bgoo00@007ooOol0035oo`03001oogoo02eoo`05001oogooOol0000^Ool01@00Oomo
ogoo0000;Goo00<007ooOol00Woo00@007ooOol0009oo`00C7oo00<007ooOol0;Woo1@00;Woo00D0
07ooOomoo`0002ioo`05001oogooOol0000]Ool00`00Oomoo`02Ool01000Oomoo`000Woo001=Ool0
0`00Oomoo`0]Ool01000Oomoo`00;goo1000<7oo0`00;Woo00<007ooOol00Woo00@007ooOol0009o
o`00BWoo00D007ooOomoo`0002moo`03001oo`0002moo`03001oogoo031oo`05001oogooOol0000]
Ool00`00Oomoo`02Ool01000Oomoo`000Woo001:Ool01@00Oomoogoo0000<7oo0P00<7oo00<007oo
Ool0;goo00D007ooOomoo`0002aoo`8000Aoo`04001oogoo0002Ool004]oo`<0039oo`03001oogoo
02moo`80031oo`<002ioo`03001oogoo00=oo`8000=oo`00ogoo8Goo003oOolQOol00?moob5oo`00
7goo00H007oo001oo`00Ool200000goo001oo`3fOol001]oool000Ioo`006goo00<007ooOol01000
0Woo00<007ooOol01`001Woo00<007ooOol03@002Goo00<007oo0000bP001Woo000KOol00`00Oomo
o`02Ool00`00Ool00002Ool20003Ool300000goo00000006000>Oon>001>Ool001]oo`8000=oo`04
001oogoo0003Ool00`00Oomoo`03Ool30006Ool8002DOom80006Ool001]oo`8000Aoo`04001oogoo
0003Ool20006Ool2000<Ool6003LOol001]oo`8000Aoo`05001oogooOol00004Ool00`00Oomoo`05
Ool3000?Ool;003AOol001]oo`<000Aoo`04001oogoo0005Ool20008Ool3000GOolO002bOol001]o
o`<000Aoo`05001oogooOol00006Ool00`00Oomoo`08Ool3000cOon/0006Ool001]oo`<000Aoo`03
001oogoo009oo`03001oogoo00Aoo`03001oogoo00Yoo`800>=oo`006goo0P0000=oo`00Ool00goo
00D007ooOomoo`0000Moo`03001oogoo00]oo`<00>1oo`006goo0P0000=oo`00Ool00goo00<007oo
Ool00Woo00<007ooOol01Goo0P003Woo1000g7oo000KOol01000Ool000001Goo00<007ooOol00Woo
00<007ooOol01Woo00<007ooOol03goo1P00eWoo000KOol01@00Ool007oo000017oo00<007ooOol0
0Woo00<007ooOol01goo00<007ooOol057oo1@00dGoo000KOol01@00Ool007oo00001Goo00<007oo
Ool00Woo00<007ooOol01goo00<007ooOol067oo1@00c7oo000KOol01@00Ool007oo00001Goo00<0
07ooOol00goo00<007ooOol01goo00<007ooOol077oo2P00`Woo000KOol30002Ool00`00Oomoo`03
Ool00`00Oomoo`02Ool00`00Oomoo`08Ool2000VOom00022Ool001]oo`03001oo`00009oo`03001o
ogoo00=oo`03001oogoo00=oo`03001oogoo00Uoo`8006Aoog`000Ioo`006goo00H007ooOol007oo
0005Ool00`00Oomoo`03Ool00`00Oomoo`0;Ool00`00Oomoo`3SOol001]oo`04001oogoo0002Ool0
0`00Oomoo`03Ool00`00Oomoo`03Ool00`00Oomoo`0;Ool2003SOol001]oo`04001oogoo0002Ool0
0`00Oomoo`03Ool00`00Oomoo`04Ool00`00Oomoo`0<Ool2003QOol001]oo`04001oogoo0002Ool0
0`00Oomoo`03Ool00`00Oomoo`04Ool00`00Oomoo`0>Ool00`00Oomoo`3NOol001]oo`800003Ool0
07oo009oo`03001oogoo00=oo`03001oogoo00Aoo`03001oogoo00ioo`800=ioo`006goo0P0000=o
o`00Ool00Woo00<007ooOol00goo00<007ooOol01Goo00<007ooOol03goo0P00g7oo0002Ool20004
Ool00`00Oomoo`03Ool20003Ool30005Ool200000goo001oo`02Ool00`00Oomoo`03Ool00`00Oomo
o`05Ool00`00Oomoo`0AOol00`00Oomoo`3IOol00005Ool007ooOol00008Ool01P00Oomoo`00Ool0
00=oo`03001oogoo009oo`80009oo`05001oogooOol00005Ool00`00Oomoo`05Ool00`00Oomoo`0A
Ool2003IOol00005Ool007ooOol00008Ool01000Oomoo`001Goo00<007ooOol00Woo0P000Woo00D0
07ooOomoo`0000Eoo`03001oogoo00Ioo`03001oogoo019oo`<00=Ioo`0000Eoo`00Oomoo`0000Qo
o`04001oogoo0005Ool00`00Oomoo`02Ool20002Ool01@00Oomoogoo00001Goo00<007ooOol01goo
00<007ooOol057oo1000dWoo00001Goo001oogoo000027oo00D007ooOol007oo00@000Eoo`80009o
o`03001oogoo009oo`03001oogoo00=oo`03001oogoo00Moo`03001oogoo01Moo`D00<eoo`0000Eo
o`00Oomoo`0000Qoo`06001oogoo001oo`0027oo0P000Woo00<007ooOol00Woo00<007ooOol00goo
00<007ooOol027oo00<007ooOol06goo1@00b7oo0002Ool2000:Ool20002Ool50004Ool20002Ool0
0`00Oomoo`02Ool00`00Oomoo`04Ool00`00Oomoo`08Ool00`00Oomoo`0OOol:002nOol001]oo`80
009oo`03001oogoo00=oo`03001oogoo00=oo`03001oogoo00Qoo`03001oogoo02Uoo`/00;=oo`00
6goo0P000goo00<007ooOol00Woo00<007ooOol017oo00<007ooOol027oo00<007ooOol0<goo[@00
1Woo000KOol20003Ool00`00Oomoo`02Ool00`00Oomoo`04Ool00`00Oomoo`09Ool00`00Oomoo`3U
Ool001]oo`8000=oo`03001oogoo009oo`03001oogoo00Eoo`03001oogoo00Uoo`03001oogoo0>Ao
o`006goo0P000goo00<007ooOol00goo00<007ooOol017oo00<007ooOol02Woo00<007ooOol0hgoo
000KOol20003Ool00`00Oomoo`03Ool00`00Oomoo`04Ool00`00Oomoo`0;Ool2003SOol001]oo`80
00=oo`03001oogoo00=oo`03001oogoo00Eoo`03001oogoo00aoo`03001oogoo0>1oo`006goo0P00
0goo00<007ooOol00goo00<007ooOol01Goo00<007ooOol03Goo00<007ooOol0ggoo000KOol20003
Ool00`00Oomoo`04Ool00`00Oomoo`05Ool00`00Oomoo`0=Ool00`00Oomoo`3NOol001]oo`8000Ao
o`03001oogoo00=oo`03001oogoo00Eoo`03001oogoo00ioo`03001oogoo04Eooi8000Ioo`006goo
0P0017oo00<007ooOol00goo00<007ooOol01Woo00<007ooOol03Woo0P00=Goo4000V7oo000KOol2
0004Ool00`00Oomoo`03Ool00`00Oomoo`06Ool00`00Oomoo`0@Ool00`00Oomoo`0]Ool5002XOol0
01]oo`8000Aoo`03001oogoo00Aoo`03001oogoo00Ioo`03001oogoo011oo`03001oogoo02Ioo`H0
0:eoo`006goo0P0017oo00<007ooOol017oo00<007ooOol01Woo00<007ooOol04Goo00<007ooOol0
87oo1@00/goo000KOol20004Ool00`00Oomoo`04Ool00`00Oomoo`07Ool00`00Oomoo`0AOol2000L
Ool4002hOol001]oo`8000Aoo`03001oogoo00Aoo`03001oogoo00Moo`03001oogoo01=oo`8001Mo
o`<00;aoo`006goo0P0017oo00<007ooOol01Goo00<007ooOol01goo00<007ooOol057oo00<007oo
Ool04Goo0`00_goo000KOol20004Ool00`00Oomoo`05Ool00`00Oomoo`07Ool00`00Oomoo`0EOol2
000?Ool20032Ool001]oo`8000Eoo`03001oogoo00Aoo`03001oogoo00Qoo`03001oogoo01Ioo`<0
00]oo`03001oogoo0<9oo`0027oo0P0017oo00<007ooOol00Woo0`001Goo0P001Goo00<007ooOol0
17oo00<007ooOol027oo00<007ooOol06Goo10001Goo0P00aGoo0007Ool01000Oomoo`002Goo00<0
07ooOol017oo0P001Goo00<007ooOol01Goo00<007ooOol027oo00<007ooOol077oo1@00agoo0007
Ool01000Oomoo`002Goo00<007ooOol017oo0P001Goo00<007ooOol01Goo00<007ooOol027oo00<0
07ooOol07Woo00<007oo00000P00aGoo0007Ool01000Oomoo`002Goo00<007ooOol017oo0P001Goo
00<007ooOol01Goo00<007ooOol02Goo00<007ooOol077oo00<007ooOol00goo1000`Goo0007Ool0
1000Oomoo`002Goo00<007ooOol017oo0P001Goo00<007ooOol01Woo00<007ooOol02Goo00<007oo
Ool06Woo00<007ooOol027oo2`00]Woo0007Ool01000Oomoo`0027oo0P001Woo0P001Goo00<007oo
Ool01Woo00<007ooOol02Goo00<007ooOol06Goo00<007ooOol057oo3`00Ygoo0008Ool2000:Ool0
0`00Oomoo`04Ool20005Ool00`00Oomoo`06Ool00`00Oomoo`0:Ool00`00Oomoo`0GOol00`00Oomo
o`0TOonQ0006Ool001]oo`8000Ioo`03001oogoo00Ioo`03001oogoo00Yoo`03001oogoo01Eoo`03
001oogoo0<aoo`006goo0P001Woo00<007ooOol01Woo00<007ooOol02Woo00<007ooOol057oo00<0
07ooOol0cGoo000KOol00`00Ool00005Ool00`00Oomoo`06Ool00`00Oomoo`0;Ool00`00Oomoo`0B
Ool00`00Oomoo`3>Ool001]oo`03001oo`0000Eoo`03001oogoo00Moo`03001oogoo00]oo`03001o
ogoo011oo`03001oogoo0<moo`006goo00<007oo00001Goo00<007ooOol01goo00<007ooOol037oo
00<007ooOol03Woo00<007ooOol0d7oo000KOol00`00Ool00006Ool00`00Oomoo`07Ool00`00Oomo
o`0<Ool00`00Oomoo`0<Ool00`00Oomoo`3AOol001]oo`<000Ioo`03001oogoo00Moo`03001oogoo
00eoo`03001oogoo00Yoo`03001oogoo0=9oo`006goo00<007oo00001Woo00<007ooOol01goo00<0
07ooOol03Woo00<007ooOol02Goo00<007ooOol0dWoo000KOol00`00Ool00006Ool00`00Oomoo`08
Ool00`00Oomoo`0>Ool00`00Oomoo`07Ool00`00Oomoo`3COol001]oo`03001oo`0000Ioo`03001o
ogoo00Qoo`03001oogoo00moo`03001oogoo00Eoo`03001oogoo0=Aoo`006goo00<007oo00001goo
00<007ooOol01goo00<007ooOol047oo00<007ooOol017oo00<007ooOol0e7oo000KOol00`00Ool0
0007Ool00`00Oomoo`08Ool00`00Oomoo`0@Ool00`00Oomoo`02Ool00`00Oomoo`3EOol001]oo`<0
00Moo`03001oogoo00Qoo`03001oogoo015oo`05001oogooOol0003GOol001]oo`03001oo`0000Mo
o`03001oogoo00Uoo`03001oogoo015oo`03001oo`000=Qoo`006goo00<007oo00001goo00<007oo
Ool02Woo00<007ooOol04Goo0P00f7oo000KOol00`00Ool00008Ool00`00Oomoo`09Ool00`00Oomo
o`0AOol01000Ool00000eWoo000KOol00`00Ool00008Ool00`00Oomoo`0:Ool00`00Oomoo`0?Ool0
0`00Oomoo`02Ool00`00Oomoo`3COol001]oo`<000Qoo`03001oogoo00Yoo`03001oogoo00moo`03
001oogoo00=oo`800==oo`006goo00<007oo000027oo00<007ooOol02goo00<007ooOol03Goo00<0
07ooOol01Woo0P00dGoo000KOol00`00Ool00009Ool00`00Oomoo`0;Ool00`00Oomoo`0<Ool00`00
Oomoo`08Ool2003?Ool0009oo`8000Aoo`03001oogoo009oo`<000=oo`<000Eoo`03001oo`0000Uo
o`03001oogoo00]oo`03001oogoo00]oo`03001oogoo00]oo`@00<]oo`0000Eoo`00Oomoo`0000Uo
o`05001oogooOol00003Ool00`00Oomoo`02Ool00`00Ool00009Ool00`00Oomoo`0<Ool00`00Oomo
o`0:Ool00`00Oomoo`0?Ool30038Ool00005Ool007ooOol00009Ool00`00Oomoo`05Ool00`00Oomo
o`02Ool30009Ool00`00Oomoo`0<Ool00`00Oomoo`09Ool00`00Oomoo`0COol3000WOonH0006Ool0
0005Ool007ooOol00009Ool00`00Oomoo`05Ool00`00Oomoo`02Ool00`00Ool0000:Ool00`00Oomo
o`0<Ool00`00Oomoo`08Ool00`00Oomoo`0FOol4000COol@002NOol00005Ool007ooOol00009Ool0
1000Oomoogoo10001Goo00<007oo00002Woo00<007ooOol03Goo00<007ooOol01Woo00<007ooOol0
6goo1P000Woo2`00[Woo00001Goo001oogoo000027oo0P000goo00<007ooOol01Woo00<007oo0000
2Woo00<007ooOol03Woo00<007ooOol01Goo00<007ooOol07Woo3@00/Goo0002Ool2000:Ool01000
Oomoogoo1@0017oo00<007oo00002Woo00<007ooOol03Woo00<007ooOol017oo00<007ooOol06goo
10003Goo5@00W7oo000KOol3000;Ool00`00Oomoo`0>Ool00`00Oomoo`03Ool00`00Oomoo`0HOol3
000VOonF0006Ool001]oo`04001oogoo000:Ool00`00Oomoo`0?Ool01@00Oomoogoo00006Goo0P00
aGoo000KOol01000Oomoo`002Woo00<007ooOol03goo00D007ooOomoo`0001Ioo`<00<Moo`006goo
00@007ooOol000Yoo`03001oogoo011oo`04001oogoo000DOol2003:Ool001]oo`04001oogoo000;
Ool00`00Oomoo`0@Ool2000BOol3003<Ool001]oo`04001oogoo000;Ool00`00Oomoo`0AOol00`00
Oomoo`0=Ool3003?Ool001]oo`800003Ool007oo00Yoo`03001oogoo015oo`8000eoo`03001oogoo
0=1oo`006goo00@007ooOol000aoo`03001oogoo00moo`03001oogoo008000Yoo`03001oogoo0=5o
o`006goo00@007ooOol000aoo`03001oogoo00moo`03001oogoo009oo`8000Moo`03001oogoo0=9o
o`006goo00@007ooOol000eoo`03001oogoo00ioo`03001oogoo00Aoo`8000=oo`800=Eoo`006goo
00@007ooOol000eoo`03001oogoo00eoo`03001oogoo00Moo`<00=Moo`006goo0P0000=oo`00Ool0
3Goo00<007ooOol037oo00<007ooOol027oo0`00eWoo000KOol01000Oomoo`003goo00<007ooOol0
2goo00<007ooOol01goo00D007ooOomoo`000=Eoo`006goo00@007ooOol0011oo`03001oogoo00Uo
o`03001oogoo00Moo`03001oogoo00=oo`800==oo`006goo00@007ooOol0011oo`03001oogoo00Uo
o`03001oogoo00Moo`03001oogoo00Eoo`<00=1oo`006goo00@007ooOol0015oo`03001oogoo00Qo
o`03001oogoo00Ioo`03001oogoo00Uoo`@00<aoo`006goo0P0000=oo`00Ool04Goo00<007ooOol0
1goo00<007ooOol01Goo00<007ooOol03Woo1@00agoo000KOol01000Oomoo`004goo00<007ooOol0
1Goo00<007ooOol01Goo00<007ooOol057oo1P00`Goo000KOol01@00Oomoogoo00004goo00<007oo
Ool017oo00<007ooOol017oo00<007ooOol06goo1@00_7oo0008Ool20004Ool01000Oomoogoo1@00
17oo00D007ooOomoo`0001Aoo`@0009oo`03001oogoo00=oo`03001oogoo025oo`/00;5oo`001goo
00@007ooOol000Qoo`04001oogoo0004Ool01@00Oomoogoo000067oo0P001Woo00<007ooOol0;7oo
6P00Ugoo0007Ool01000Oomoo`002Goo00<007ooOol017oo0P000Woo00<007ooOol05goo1@0000=o
o`00Ool057ooa@001Woo0007Ool01000Oomoo`002Woo00<007ooOol00goo00D007ooOomoo`0001Uo
o`03001oogoo009ooaL00<]oo`001goo00@007ooOol000Moo`05001oogooOol00004Ool01@00Oomo
ogoo00006Goo00D007ooOomoo`000>9oo`001goo00@007ooOol000Moo`05001oogooOol00004Ool0
1@00Oomoogoo000067oo00<007ooOol00Woo00<007ooOol0h7oo0008Ool20009Ool30005Ool01@00
Oomoogoo000067oo00D007ooOomoo`000>=oo`006goo0P000goo00<007ooOol05Goo00@007ooOol0
0>Aoo`006goo00<007ooOol00Woo00<007ooOol05Goo00<007oo0000iGoo000KOol00`00Oomoo`02
Ool00`00Oomoo`0DOol01000Oomoo`00iGoo000KOol00`00Oomoo`02Ool00`00Oomoo`0DOol00`00
Ool0003VOol001]oo`03001oogoo009oo`03001oogoo01Aoo`03001oo`000>Ioo`006goo00<007oo
Ool00Woo00<007ooOol04goo00<007oo0000igoo000KOol20003Ool00`00Oomoo`0COol2003XOol0
01]oo`03001oogoo009oo`03001oogoo01=oo`800>Qoo`006goo00<007ooOol00Woo00<007ooOol0
4goo00<007ooOol0igoo000KOol00`00Oomoo`02Ool00`00Oomoo`0BOol2003YOol001]oo`03001o
ogoo00=oo`03001oogoo015oo`03001oogoo0>Qoo`006goo0P0017oo00<007ooOol04Goo00<007oo
Ool0j7oo000KOol00`00Oomoo`03Ool00`00Oomoo`0@Ool2003ZOol001]oo`03001oogoo00=oo`03
001oogoo011oo`800>Yoo`006goo00<007ooOol00goo00<007ooOol03goo0P00jgoo000KOol00`00
Oomoo`03Ool00`00Oomoo`0>Ool00`00Ool0003[Ool001]oo`8000Aoo`03001oogoo00ioo`03001o
o`000>]oo`006goo00<007ooOol00goo00<007ooOol03Goo00@007ooOol00>]oo`006goo00<007oo
Ool017oo00<007ooOol037oo00@007ooOol00>]oo`000Woo0P0017oo00@007ooOomoo`D0009oo`<0
00Eoo`03001oogoo00Aoo`03001oogoo00]oo`05001oogooOol0003[Ool00005Ool007ooOol00008
Ool01P00Oomoo`00Ool000=oo`03001oogoo009oo`03001oogoo00Aoo`03001oogoo00]oo`04001o
ogoo003/Ool00005Ool007ooOol00009Ool00`00Oomoo`05Ool00`00Oomoo`02Ool20005Ool00`00
Oomoo`0:Ool01@00Oomoogoo0000k7oo00001Goo001oogoo00002Woo00<007ooOol017oo00<007oo
Ool00Woo00<007ooOol017oo00<007ooOol02Goo00<007ooOol00Woo00<007ooOol0jWoo00001Goo
001oogoo00001goo00H007ooOomoo`00Ool40005Ool00`00Oomoo`04Ool00`00Oomoo`09Ool00`00
Oomoo`02Ool00`00Oomoo`3ZOol00005Ool007ooOol00007Ool01`00Oomoogoo001oo`0000Qoo`03
001oogoo00Aoo`03001oogoo00Qoo`03001oogoo00=oo`03001oogoo0>Yoo`000Woo0P002Goo0`00
0Woo1@0017oo00<007ooOol01Goo00<007ooOol01goo00<007ooOol00Woo00<007ooOol0jgoo000K
Ool00`00Oomoo`05Ool00`00Oomoo`06Ool00`00Oomoo`03Ool00`00Oomoo`3[Ool001]oo`8000Mo
o`03001oogoo00Aoo`03001oogoo00Aoo`03001oogoo0>]oo`006goo00<007ooOol01Woo00<007oo
Ool00goo00<007ooOol01Goo00<007ooOol0jgoo000KOol00`00Oomoo`06Ool20004Ool00`00Oomo
o`05Ool00`00Oomoo`3[Ool001]oo`03001oogoo00Moo`03001oogoo008000Qoo`03001oogoo0>]o
o`006goo00<007ooOol027oo0`0027oo00<007ooOol0k7oo000KOol2000DOol00`00Oomoo`3/Ool0
01]oo`03001oogoo01=oo`03001oogoo0>aoo`006goo00<007ooOol04goo00<007ooOol0k7oo000K
Ool00`00Oomoo`0COol00`00Oomoo`3/Ool001]oo`03001oogoo01=oo`03001oogoo0>aoo`006goo
0P004goo00<007ooOol0kGoo000KOol00`00Oomoo`0BOol00`00Oomoo`3]Ool001]oo`03001oogoo
019oo`03001oogoo0>eoo`006goo00<007ooOol04Woo00<007ooOol0kGoo000KOol00`00Oomoo`0B
Ool00`00Oomoo`3]Ool001]oo`8001=oo`03001oogoo0>eoo`006goo00<007ooOol04Woo00<007oo
Ool0kGoo000KOol00`00Oomoo`0AOol00`00Oomoo`3^Ool001]oo`03001oogoo015oo`03001oogoo
0>ioo`006goo00<007ooOol04Goo00<007ooOol0kWoo000KOol00`00Oomoo`0AOol00`00Oomoo`3^
Ool001]oo`03001oogoo015oo`03001oogoo0>ioo`00ogoo8Goo003oOolQOol00?moob5oo`00\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-1.07059, -0.0308268, \
0.0393973, 0.00191239}}],

Cell[BoxData[
    \({0.0746299513712568`, 0.14925897926614026`, 0.1990114709815182`, 
      0.19901120339736514`, 0.1592088267232851`, 0.10613915133640398`, 
      0.06065091113830697`, 0.030325438692454028`, 0.013477962841342983`, 
      0.005391178434547927`, 0.001960423461330987`, 0.00065347040369933`, 
      0.0002010644002847587`, 0.00005744405375819938`, 
      0.000015315888410915114`, 3.826762409448957`*^-6, 
      8.984652196720133`*^-7, 1.9792603527767523`*^-7, 
      4.011818279182859`*^-8, 6.628221494293235`*^-9}\)], "Output",
  CellLabel->"Out[69]="],

Cell["\<\
There is only a 7.5% chance that a single genome will cary the \
entire ancestry of a segment 2Nr=R=2 long\
\>", "Text"]
}, Closed]],

Cell[CellGroupData[{

Cell["# of junctions", "SubsubsectionIcon"],

Cell["\<\
Each recombination event which occurs within ancestral material \
generates a new pair of junctions.  Each coalescence event destroys any pair \
that meets up, but preserves other junctions.  Now, it should be possible to \
use a simple argument to find the distribution of the number of junctions, \
and hence of the number of segments.\
\>", "Text"],

Cell["\<\
The total length of ancestral material is conserved at R.  Hence, \
the net rate of generation of junction pairs is always R.  Each pair then \
follows the coalescent process, and has an exponentially distributed \
lifespan.  The recursion for the distribution of the # of junction pairs \
is:\
\>", "Text"],

Cell[BoxData[
    \(TextForm\`\[PartialD]\_t P\_k = \(-\((R + k)\)\) P\_k + 
        R\ P\_\(k - 1\) + \((k + 1)\) P\_\(k + 1\)\)], "NumberedEquation"],

Cell["\<\
At equilibrium, this is Poisson with expectation R.  The number of \
segments overall is just equal to the number of junction pairs, plus 1.  \
\
\>", "Text"],

Cell["\<\
** This argument conflicts with Wiuf & Hein 1997 and Derrida & JM \
1999 (admittedly, those conflict with eachother).  Any one pair of junctions \
does coalesce at the standard rate, and so the argument is correct for the \
mean.  However, a pair of chromosomes may carry many junction pairs, and \
these will coalesce simoultaneously.  The full solution therefore depends on \
the frequencywith which sets of 2, 3, \[Ellipsis] junction pairs meet up - a \
much harder problem.\
\>", "Text"]
}, Closed]],

Cell[CellGroupData[{

Cell["Segment lengths", "SubsubsectionIcon"],

Cell["\<\
It is much harder to work out the distribution of numbers of \
ancestors,  since that depends on associations among segments. Working \
backwards in time, we can consider associations between any particular pair \
of junctions.  Two junctions may be separated by recombination, and brought \
together by coalescence.  It might be helpful to separate the problem into \
two parts: the distribution of block lengths, and the associations between \
blocks.\
\>", "Text"],

Cell["\<\
A block of given length can get longer through the annihilation of \
one of the junctions at either end; it can get shorter by recombination.  If \
we make the dubious assumption that the blocks associated with sister \
junctions are uncorrelated in length, then we have:\
\>", "Text"],

Cell[BoxData[
    \(TextForm\`\[PartialD]\_t \[Psi][y] = \(-\((2 + y)\)\) \[Psi][y] + 
        2 \(\[Integral]\_y\%\[Infinity] \[Psi][
                z] \[DifferentialD]z\) + \[Integral]\_0\%y \[Psi][z] \[Psi][
              y - z] \[DifferentialD]z\)], "NumberedEquation"],

Cell[TextData[{
  "Necessarily, ",
  Cell[BoxData[
      \(TraditionalForm\`\[Integral]\_0\%\[Infinity] 
            y\ \[Psi][y] \[DifferentialD]y = R\)]],
  " is conserved.    Taking LTs:"
}], "Text"],

Cell[BoxData[
    \(TextForm\`\[PartialD]\_t\( \[Psi]\&~\)[\[Omega]] = \(-2\) \((1 + 
              1\/\[Omega])\) \(\[Psi]\&~\)[\[Omega]] - \
\[PartialD]\_\[Omega]\( \[Psi]\&~\)[\[Omega]] + \(2\/\[Omega]\) \(\[Psi]\&~\)[
            0] + \(\[Psi]\&~\)[\[Omega]]\^2\)], "NumberedEquation"],

Cell["\<\
The equilibrium solution for the LT is:\
\>", "Text"],

Cell[BoxData[
    FormBox[
      RowBox[{\(\[Psi]\&~[\[Omega]]\), "=", 
        RowBox[{
          RowBox[{
            FractionBox[
              RowBox[{" ", 
                TagBox[
                  TagBox[
                    RowBox[{
                      RowBox[{
                        SubscriptBox["\[InvisiblePrefixScriptBase]", 
                          FormBox["1",
                            "TraditionalForm"]], 
                        SubscriptBox["F", 
                          FormBox["1",
                            "TraditionalForm"]]}], "\[InvisibleApplication]", 
                      
                      RowBox[{"(", 
                        RowBox[{
                          TagBox[
                            TagBox[
                              TagBox[\(\[Psi]\&~[0] + 1\),
                                Hypergeometric1F1,
                                Editable->True],
                              InterpretTemplate[ {
                                SlotSequence[ 1]}&]],
                            Hypergeometric1F1,
                            Editable->False], ";", 
                          TagBox[
                            TagBox[
                              TagBox["3",
                                Hypergeometric1F1,
                                Editable->True],
                              InterpretTemplate[ {
                                SlotSequence[ 1]}&]],
                            Hypergeometric1F1,
                            Editable->False], ";", 
                          TagBox[\(\(-2\)\ \[Omega]\),
                            Hypergeometric1F1,
                            Editable->True]}], ")"}]}],
                    InterpretTemplate[ HypergeometricPFQ[ #, #2, #3]&],
                    Editable->False],
                  Hypergeometric1F1]}], 
              TagBox[
                TagBox[
                  RowBox[{
                    RowBox[{
                      SubscriptBox["\[InvisiblePrefixScriptBase]", 
                        FormBox["1",
                          "TraditionalForm"]], 
                      SubscriptBox["F", 
                        FormBox["1",
                          "TraditionalForm"]]}], "\[InvisibleApplication]", 
                    RowBox[{"(", 
                      RowBox[{
                        TagBox[
                          TagBox[
                            TagBox[\(\[Psi]\&~[0]\),
                              Hypergeometric1F1,
                              Editable->True],
                            InterpretTemplate[ {
                              SlotSequence[ 1]}&]],
                          Hypergeometric1F1,
                          Editable->False], ";", 
                        TagBox[
                          TagBox[
                            TagBox["2",
                              Hypergeometric1F1,
                              Editable->True],
                            InterpretTemplate[ {
                              SlotSequence[ 1]}&]],
                          Hypergeometric1F1,
                          Editable->False], ";", 
                        TagBox[\(\(-2\)\ \[Omega]\),
                          Hypergeometric1F1,
                          Editable->True]}], ")"}]}],
                  InterpretTemplate[ HypergeometricPFQ[ #, #2, #3]&],
                  Editable->False],
                Hypergeometric1F1]], "  ", "with", " ", \(\[Psi]\&~[0]\)}], 
          "=", \(2 - 3  R\)}]}], TraditionalForm]], "NumberedEquation"],

Cell[TextData[{
  "This has the unfortunate property that for ",
  Cell[BoxData[
      \(TraditionalForm\`R < 1\/2\)]],
  ", the variance is negative.  Presumably the approximation breaks down \
then??"
}], "Text"]
}, Closed]],

Cell[CellGroupData[{

Cell["Working", "SubsubsectionIcon"],

Cell["BlockDistribution", "Text"],

Cell[BoxData[
    \(\(BlockDistributionLT[w_, R_] := 
        Module[{f0 = 
              2 - 3  R}, \(\(\ \ \)\(Hypergeometric1F1[1 + f0, 3, \(-2\)\ \
w]\)\)\/\(\(\ \ \)\(Hypergeometric1F1[f0, 2, \(-2\)\ w]\)\)];\)\)], "Input",
  CellLabel->"In[387]:="],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(Plot[{BlockDistributionLT[w, 0.1], BlockDistributionLT[w, 1], 
          BlockDistributionLT[w, 10]}, {w, 0, 10}, 
        PlotStyle \[Rule] {Red, Blue, Black}];\)\)], "Input",
  CellLabel->"In[383]:="],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.0952381 0.0147151 0.588604 [
[.21429 .00222 -3 -9 ]
[.21429 .00222 3 0 ]
[.40476 .00222 -3 -9 ]
[.40476 .00222 3 0 ]
[.59524 .00222 -3 -9 ]
[.59524 .00222 3 0 ]
[.78571 .00222 -3 -9 ]
[.78571 .00222 3 0 ]
[.97619 .00222 -6 -9 ]
[.97619 .00222 6 0 ]
[.01131 .13244 -18 -4.5 ]
[.01131 .13244 0 4.5 ]
[.01131 .25016 -18 -4.5 ]
[.01131 .25016 0 4.5 ]
[.01131 .36788 -18 -4.5 ]
[.01131 .36788 0 4.5 ]
[.01131 .4856 -18 -4.5 ]
[.01131 .4856 0 4.5 ]
[.01131 .60332 -6 -4.5 ]
[.01131 .60332 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.21429 .01472 m
.21429 .02097 L
s
[(2)] .21429 .00222 0 1 Mshowa
.40476 .01472 m
.40476 .02097 L
s
[(4)] .40476 .00222 0 1 Mshowa
.59524 .01472 m
.59524 .02097 L
s
[(6)] .59524 .00222 0 1 Mshowa
.78571 .01472 m
.78571 .02097 L
s
[(8)] .78571 .00222 0 1 Mshowa
.97619 .01472 m
.97619 .02097 L
s
[(10)] .97619 .00222 0 1 Mshowa
.125 Mabswid
.07143 .01472 m
.07143 .01847 L
s
.11905 .01472 m
.11905 .01847 L
s
.16667 .01472 m
.16667 .01847 L
s
.2619 .01472 m
.2619 .01847 L
s
.30952 .01472 m
.30952 .01847 L
s
.35714 .01472 m
.35714 .01847 L
s
.45238 .01472 m
.45238 .01847 L
s
.5 .01472 m
.5 .01847 L
s
.54762 .01472 m
.54762 .01847 L
s
.64286 .01472 m
.64286 .01847 L
s
.69048 .01472 m
.69048 .01847 L
s
.7381 .01472 m
.7381 .01847 L
s
.83333 .01472 m
.83333 .01847 L
s
.88095 .01472 m
.88095 .01847 L
s
.92857 .01472 m
.92857 .01847 L
s
.25 Mabswid
0 .01472 m
1 .01472 L
s
.02381 .13244 m
.03006 .13244 L
s
[(0.2)] .01131 .13244 1 0 Mshowa
.02381 .25016 m
.03006 .25016 L
s
[(0.4)] .01131 .25016 1 0 Mshowa
.02381 .36788 m
.03006 .36788 L
s
[(0.6)] .01131 .36788 1 0 Mshowa
.02381 .4856 m
.03006 .4856 L
s
[(0.8)] .01131 .4856 1 0 Mshowa
.02381 .60332 m
.03006 .60332 L
s
[(1)] .01131 .60332 1 0 Mshowa
.125 Mabswid
.02381 .04415 m
.02756 .04415 L
s
.02381 .07358 m
.02756 .07358 L
s
.02381 .10301 m
.02756 .10301 L
s
.02381 .16187 m
.02756 .16187 L
s
.02381 .1913 m
.02756 .1913 L
s
.02381 .22073 m
.02756 .22073 L
s
.02381 .27959 m
.02756 .27959 L
s
.02381 .30902 m
.02756 .30902 L
s
.02381 .33845 m
.02756 .33845 L
s
.02381 .39731 m
.02756 .39731 L
s
.02381 .42674 m
.02756 .42674 L
s
.02381 .45617 m
.02756 .45617 L
s
.02381 .51503 m
.02756 .51503 L
s
.02381 .54446 m
.02756 .54446 L
s
.02381 .57389 m
.02756 .57389 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
1 0 0 r
.5 Mabswid
.02381 .60332 m
.06244 .57581 L
.10458 .53666 L
.14415 .49093 L
.18221 .44037 L
.22272 .3833 L
.26171 .33 L
.30316 .27954 L
.34309 .23919 L
.3815 .20812 L
.42237 .18227 L
.46172 .16292 L
.49955 .14817 L
.53984 .13554 L
.57861 .1256 L
.61984 .1168 L
.65954 .10963 L
.69774 .10368 L
.73838 .09815 L
.77751 .09347 L
.81909 .08905 L
.85916 .08525 L
.89771 .08195 L
.93871 .07876 L
.97619 .07611 L
s
0 0 1 r
.02381 .60332 m
.04262 .50625 L
.06244 .43345 L
.08255 .37877 L
.10458 .33321 L
.12579 .29895 L
.14509 .27362 L
.18408 .23411 L
.22401 .20446 L
.26243 .18263 L
.30329 .16431 L
.34264 .1501 L
.38048 .13876 L
.42077 .12861 L
.45954 .12029 L
.50076 .11269 L
.54047 .10633 L
.57866 .10095 L
.61931 .09587 L
.65844 .09152 L
.70002 .08738 L
.74009 .08379 L
.77864 .08066 L
.81964 .07763 L
.85913 .07496 L
.8971 .07259 L
.93752 .07028 L
.97619 .06822 L
s
0 0 0 r
.02381 .60332 m
.02499 .54159 L
.02605 .49937 L
.02721 .46355 L
.02846 .43242 L
.03068 .3901 L
.03279 .36004 L
.03527 .33246 L
.0379 .3094 L
.04262 .27814 L
.04749 .25438 L
.05205 .23701 L
.06244 .2081 L
.06788 .19673 L
.07305 .18753 L
.08274 .17331 L
.09331 .16103 L
.10458 .15048 L
.12439 .13613 L
.14277 .12596 L
.16275 .11716 L
.18435 .10946 L
.22442 .0985 L
.26542 .09015 L
.30491 .08385 L
.34288 .0789 L
.38331 .07451 L
.42222 .07092 L
.46358 .06763 L
.50342 .06488 L
.54175 .06253 L
.58253 .0603 L
.6218 .05838 L
.65955 .0567 L
.69975 .05507 L
.73844 .05363 L
.77958 .05223 L
.81921 .05099 L
.85731 .04988 L
.89788 .04878 L
.93692 .04779 L
.97619 .04687 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[383]:=",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/B000`400?l00000o`00003oo`3ooolQ
0?ooo`00AP3oool500000340oooo0`00000_0?ooo`<00000<@3oool3000002h0oooo0`0000040?oo
o`800000103oool004L0oooo00@000000?ooo`3oool00000<P3oool00`000000oooo0?ooo`0]0?oo
o`050000003oool0oooo0?ooo`000000;`3oool01@000000oooo0?ooo`3oool0000002h0oooo00<0
00000?ooo`3oool00P3oool010000000oooo0?ooo`0000030?ooo`00B03oool00`000000oooo0?oo
o`0_0?ooo`D00000;P3oool01@000000oooo0?ooo`3oool0000002l0oooo00D000000?ooo`3oool0
oooo0000000^0?ooo`030000003oool0oooo0080oooo00@000000?ooo`3oool000000`3oool004T0
oooo00<000000?ooo`3oool0;P3oool010000000oooo0?ooo`00000_0?ooo`@00000<@3oool30000
02l0oooo00<000000?ooo`3oool00P3oool010000000oooo0?ooo`0000030?ooo`00AP3oool01@00
0000oooo0?ooo`3oool000000300oooo00<000000?ooo`000000;`3oool00`000000oooo0?ooo`0a
0?ooo`050000003oool0oooo0?ooo`000000;P3oool00`000000oooo0?ooo`020?ooo`040000003o
ool0oooo000000<0oooo00160?ooo`050000003oool0oooo0?ooo`000000<@3oool200000300oooo
00<000000?ooo`3oool0<03oool01@000000oooo0?ooo`3oool0000002d0oooo0P0000040?ooo`04
0000003oool0oooo000000<0oooo00170?ooo`<00000<`3oool00`000000oooo0?ooo`0_0?ooo`80
0000<@3oool3000002l0oooo00<000000?ooo`3oool00`3oool2000000@0oooo000E0?ooo`030000
003oool0oooo0?l0oooo2@3oool001D0oooo00<000000?ooo`3oool0o`3oool90?ooo`005@3oool0
0`000000oooo0?ooo`3o0?ooo`T0oooo000E0?ooo`030000003oool0oooo0?l0oooo2@3oool000l0
ooooo`00000A00000040oooo000E0?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool0
2P3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool0
2P3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool0
2P3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool0
2P3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool0
2P3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool0
2P3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool0
2P3oool00`000000oooo0?ooo`050?ooo`005@3oool00`000000oooo0?ooo`0a0?ooo`030000003o
ool0oooo0340oooo00<000000?ooo`3oool0<03oool00`000000oooo0?ooo`0a0?ooo`030000003o
ool0oooo0340oooo00<000000?ooo`3oool01@3oool001D0oooo00<000000?ooo`3oool0o`3oool9
0?ooo`005@3oool00`000000oooo0?ooo`3o0?ooo`T0oooo000E0?ooo`030000003oool0oooo0?l0
oooo2@3oool001D0oooo00<000000?ooo`3oool0o`3oool90?ooo`005@3oool00`000000oooo0?oo
o`3o0?ooo`T0oooo000E0?ooo`800000o`3oool:0?ooo`005@3oool00`000000oooo0?ooo`3V0?oo
oa/000001`3oool001D0oooo00<000000?ooo`3oool0a@3ooolQ00000280oooo000E0?ooo`030000
003oool0oooo0:D0oooo800000130?ooo`005@3oool00`000000oooo0?ooo`2@0?oooaD00000H`3o
ool001D0oooo00<000000?ooo`3oool0Q@3oool;000007P0oooo000E0?ooo`030000003oool0oooo
06l0oooo5P0000230?ooo`005@3oool00`000000oooo0?ooo`1T0?ooo`/00000P@3ooolA0000o`L0
oooo000E0?ooo`800000F`3oool:000007L0oooo5@000?lH0?ooo`005@3oool00`000000oooo0?oo
o`1A0?ooo`T00000MP3oool;0000oaH0oooo403o00070?ooo`005@3oool00`000000oooo0?ooo`1<
0?ooo`D00000M03oool;0000oaH0oooo2`3o000G0?ooo`005@3oool00`000000oooo0?ooo`140?oo
o`P00000K`3oool:0000oaH0oooo2`3o000R0?ooo`005@3oool00`000000oooo0?ooo`0m0?ooo`L0
0000K03oool;0000oaD0oooo2`3o000]0?ooo`005@3oool00`000000oooo0?ooo`0i0?ooo`@00000
J03oool;0000oaL0oooo2@3o000h0?ooo`005@3oool00`000000oooo0?ooo`0f0?ooo`<00000H@3o
ool;0000oad0oooo1@3o00110?ooo`005@3oool00`000000oooo0?ooo`0b0?ooo`@00000F`3oool9
0000ob00oooo203o00160?ooo`005@3oool2000002l0oooo1000001J0?ooo`D0003o8@3oool80?l0
04h0oooo000E0?ooo`030000003oool0oooo02/0oooo0`00001I0?ooo`D0003o8@3oool50?l005H0
oooo000E0?ooo`030000003oool0oooo02P0oooo0`00001G0?ooo`D0003o803oool60?l005/0oooo
000E0?ooo`030000003oool0oooo02D0oooo0`00001D0?ooo`H0003o803oool50?l00640oooo000E
0?ooo`030000003oool0oooo0280oooo0`00001A0?ooo`H0003o803oool60?l006H0oooo00020?oo
o`800000103oool010000000oooo0?ooo`3oool5000000@0oooo00<000000?ooo`3oool07`3oool3
000004l0oooo1@000?lQ0?ooo`D0o`00K03oool000050?ooo`000000oooo0?ooo`000000203oool0
10000000oooo0?ooo`0000040?ooo`030000003oool0oooo01`0oooo0`00001=0?ooo`D0003o8@3o
ool50?l00740oooo00001@3oool000000?ooo`3oool0000000T0oooo00<000000?ooo`3oool0103o
ool00`000000oooo0?ooo`0J0?ooo`800000B`3oool50000ob80oooo103o001f0?ooo`0000D0oooo
0000003oool0oooo0000000:0?ooo`030000003oool0oooo00<0oooo0`00000I0?ooo`030000003o
ool0oooo04L0oooo10000?lT0?ooo`<0o`00NP3oool000050?ooo`000000oooo0?ooo`0000001`3o
ool01@000000oooo0?ooo`3oool0000000@0oooo00<000000?ooo`3oool05`3oool2000004L0oooo
0`000?lT0?ooo`@0o`00O@3oool000050?ooo`000000oooo0?ooo`0000001`3oool01@000000oooo
0?ooo`3oool0000000@0oooo00<000000?ooo`3oool05P3oool00`000000oooo0?ooo`130?ooo`@0
003o8`3oool40?l00840oooo00020?ooo`8000002@3oool3000000D0oooo00<000000?ooo`3oool0
5@3oool00`000000oooo0?ooo`110?ooo`<0003o903oool30?l008D0oooo000E0?ooo`030000003o
ool0oooo01@0oooo00<000000?ooo`3oool0?`3oool30000ob@0oooo0`3o00280?ooo`005@3oool0
0`000000oooo0?ooo`0C0?ooo`030000003oool0oooo03d0oooo0`000?lT0?ooo`<0o`00R`3oool0
01D0oooo00<000000?ooo`3oool04P3oool00`000000oooo0?ooo`0k0?ooo`<0003o9@3oool20?l0
08h0oooo000E0?ooo`030000003oool0oooo0140oooo00<000000?ooo`3oool0>@3oool30000obD0
oooo0`3o002@0?ooo`005@3oool200000140oooo00<000000?ooo`3oool0=`3oool30000obH0oooo
0P3o002C0?ooo`005@3oool00`000000oooo0?ooo`0?0?ooo`030000003oool0oooo03H0oooo0P00
0?lW0?ooo`80o`00U@3oool001D0oooo00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`0e
0?ooo`80003o9`3oool20?l009L0oooo000E0?ooo`030000003oool0oooo00d0oooo00<000000?oo
o`3oool0<`3oool30000obP0oooo00<0o`000?ooo`3oool0U`3oool001D0oooo00<000000?ooo`3o
ool03@3oool00`000000oooo0?ooo`0a0?ooo`80003o:@3oool20?l009X0oooo000E0?ooo`030000
003oool0oooo00`0oooo00<000000?ooo`3oool0<03oool20000obT0oooo0P3o002L0?ooo`005@3o
ool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo02l0oooo0P000?lY0?ooo`80o`00WP3o
ool001D0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`0^0?ooo`80003o:P3oool0
0`3o0000oooo0?ooo`2N0?ooo`005@3oool2000000/0oooo00<000000?ooo`3oool0;03oool20000
obX0oooo0P3o002Q0?ooo`005@3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo02`0
oooo00<0003o0?ooo`3oool0:03oool20?l00:<0oooo000E0?ooo`030000003oool0oooo00T0oooo
00<000000?ooo`3oool0:P3oool20000obX0oooo00<0o`000?ooo`3oool0X`3oool001D0oooo00<0
00000?ooo`3oool0203oool00`000000oooo0?ooo`0Y0?ooo`80003o:P3oool20?l00:H0oooo000E
0?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool09`3oool20000ob/0oooo00<0o`00
0?ooo`3oool0YP3oool001D0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`0W0?oo
o`030000o`3oool0oooo02T0oooo0P3o002Y0?ooo`005@3oool00`000000oooo0?ooo`070?ooo`03
0000003oool0oooo02H0oooo00<0003o0?ooo`3oool0:@3oool00`3o0000oooo0?ooo`2Y0?ooo`00
5@3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo02D0oooo00<0003o0?ooo`3oool0
:@3oool00`3o0000oooo0?ooo`2Z0?ooo`005@3oool2000000L0oooo00<000000?ooo`3oool0903o
ool20000ob/0oooo00<0o`000?ooo`3oool0Z`3oool001D0oooo00<000000?ooo`3oool01P3oool0
0`000000oooo0?ooo`0S0?ooo`030000o`3oool0oooo02T0oooo0P3o002^0?ooo`005@3oool00`00
0000oooo0?ooo`060?ooo`030000003oool0oooo0280oooo00<0003o0?ooo`3oool0:@3oool00`3o
0000oooo0?ooo`2^0?ooo`005@3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo0280
oooo00<0003o0?ooo`3oool0:@3oool00`3o0000oooo0?ooo`2_0?ooo`005@3oool00`000000oooo
0?ooo`050?ooo`030000003oool0oooo0200oooo0P000?l[0?ooo`030?l0003oool0oooo0;00oooo
00020?ooo`800000103oool00`000000oooo0?ooo`030?ooo`<00000103oool00`000000oooo0?oo
o`050?ooo`030000003oool0oooo01l0oooo00<0003o0?ooo`3oool0:P3oool00`3o0000oooo0?oo
o`2a0?ooo`0000D0oooo0000003oool0oooo0000000:0?ooo`030000003oool0oooo00<0oooo00<0
00000?ooo`3oool0103oool00`000000oooo0?ooo`0O0?ooo`030000o`3oool0oooo02X0oooo00<0
o`000?ooo`3oool0/P3oool000050?ooo`000000oooo0?ooo`0000001`3oool5000000@0oooo00<0
00000?ooo`3oool0103oool00`000000oooo0?ooo`0N0?ooo`030000o`3oool0oooo02X0oooo00<0
o`000?ooo`3oool0/`3oool000050?ooo`000000oooo0?ooo`0000001`3oool010000000oooo0?oo
o`0000050?ooo`<00000103oool00`000000oooo0?ooo`0M0?ooo`030000o`3oool0oooo02X0oooo
00<0o`000?ooo`3oool0]03oool000050?ooo`000000oooo0?ooo`000000203oool00`000000oooo
000000050?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool07@3oool00`000?l0oooo
0?ooo`0Z0?ooo`030?l0003oool0oooo0;D0oooo00001@3oool000000?ooo`3oool0000000T0oooo
0P0000050?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0703oool00`000?l0oooo
0?ooo`0Z0?ooo`030?l0003oool0oooo0;H0oooo00020?ooo`8000002`3oool00`000000oooo0?oo
o`030?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool06`3oool00`000?l0oooo0?oo
o`0Z0?ooo`030?l0003oool0oooo0;L0oooo000E0?ooo`030000003oool0oooo00<0oooo00<00000
0?ooo`3oool06P3oool00`000?l0oooo0?ooo`0Z0?ooo`030?l0003oool0oooo0;P0oooo000E0?oo
o`030000003oool0oooo0080oooo00<000000?ooo`3oool06P3oool00`000?l0oooo0?ooo`0Z0?oo
o`030?l0003oool0oooo0;T0oooo000E0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3o
ool06@3oool00`000?l0oooo0?ooo`0Z0?ooo`030?l0003oool0oooo0;X0oooo000E0?ooo`030000
003oool0oooo0080oooo00<000000?ooo`3oool06@3oool00`000?l0oooo0?ooo`0Y0?ooo`030?l0
003oool0oooo0;/0oooo000E0?ooo`8000000`3oool00`000000oooo0?ooo`0H0?ooo`030000o`3o
ool0oooo02T0oooo00<0o`000?ooo`3oool0_03oool001D0oooo00<000000?ooo`3oool00P3oool0
0`000000oooo0?ooo`0G0?ooo`030000o`3oool0oooo02X0oooo00<0o`000?ooo`3oool0_03oool0
01D0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0F0?ooo`030000o`3oool0oooo
02X0oooo00<0o`000?ooo`3oool0_@3oool001D0oooo00<000000?ooo`3oool00P3oool00`000000
oooo0?ooo`0F0?ooo`030000o`3oool0oooo02T0oooo00<0o`000?ooo`3oool0_P3oool001D0oooo
00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0E0?ooo`030000o`3oool0oooo02T0oooo
00<0o`000?ooo`3oool0_`3oool001D0oooo00D000000?ooo`3oool0oooo0000000G0?ooo`030000
o`3oool0oooo02T0oooo00<0o`000?ooo`3oool0`03oool001D0oooo00D000000?ooo`3oool0oooo
0000000G0?ooo`030000o`3oool0oooo02T0oooo00<0o`000?ooo`3oool0`03oool001D0oooo00D0
00000?ooo`3oool0oooo0000000F0?ooo`030000o`3oool0oooo02T0oooo00<0o`000?ooo`3oool0
`@3oool001D0oooo0P0000020?ooo`030000003oool0oooo01<0oooo00<0003o0?ooo`3oool0:@3o
ool00`3o0000oooo0?ooo`320?ooo`005@3oool01@000000oooo0?ooo`3oool0000001D0oooo00<0
003o0?ooo`3oool0:03oool00`3o0000oooo0?ooo`330?ooo`005@3oool01@000000oooo0?ooo`3o
ool0000001@0oooo00<0003o0?ooo`3oool0:@3oool00`3o0000oooo0?ooo`330?ooo`005@3oool0
1@000000oooo0?ooo`3oool0000001@0oooo00<0003o0?ooo`3oool0:03oool00`3o0000oooo0?oo
o`340?ooo`005@3oool010000000oooo0?ooo`00000D0?ooo`030000o`3oool0oooo02P0oooo00<0
o`000?ooo`3oool0a@3oool001D0oooo00@000000?ooo`3oool000004`3oool00`000?l0oooo0?oo
o`0X0?ooo`030?l0003oool0oooo0<H0oooo000E0?ooo`040000003oool0oooo000001<0oooo00<0
003o0?ooo`3oool09`3oool00`3o0000oooo0?ooo`370?ooo`005@3oool010000000oooo0?ooo`00
000B0?ooo`030000o`3oool0oooo02P0oooo00<0o`000?ooo`3oool0a`3oool001D0oooo0P000000
0`3oool000000?ooo`0A0?ooo`030000o`3oool0oooo02L0oooo00<0o`000?ooo`3oool0b03oool0
01D0oooo00@000000?ooo`3oool000004@3oool00`000?l0oooo0?ooo`0W0?ooo`030?l0003oool0
oooo0<T0oooo000E0?ooo`040000003oool0oooo00000140oooo00<0003o0?ooo`3oool09P3oool0
0`3o0000oooo0?ooo`3:0?ooo`005@3oool00`000000oooo0000000A0?ooo`030000o`3oool0oooo
02H0oooo00<0o`000?ooo`3oool0b`3oool001D0oooo00<000000?ooo`0000004@3oool00`000?l0
oooo0?ooo`0V0?ooo`030?l0003oool0oooo0</0oooo00020?ooo`800000103oool00`000000oooo
0?ooo`020?ooo`<000001@3oool00`000000oooo0000000@0?ooo`030000o`3oool0oooo02H0oooo
00<0o`000?ooo`3oool0c03oool000050?ooo`000000oooo0?ooo`0000001`3oool01@000000oooo
0?ooo`3oool0000000@0oooo00<000000?ooo`000000403oool00`000?l0oooo0?ooo`0U0?ooo`03
0?l0003oool0oooo0<d0oooo00001@3oool000000?ooo`3oool0000000L0oooo00D000000?ooo`3o
ool0oooo000000040?ooo`030000003oool0000000l0oooo00<0003o0?ooo`3oool09@3oool00`3o
0000oooo0?ooo`3>0?ooo`0000D0oooo0000003oool0oooo000000070?ooo`@000001@3oool30000
00l0oooo00<0003o0?ooo`3oool09@3oool00`3o0000oooo0?ooo`3>0?ooo`0000D0oooo0000003o
ool0oooo000000070?ooo`030000003oool0oooo00H0oooo00<000000?ooo`0000003P3oool00`00
0?l0oooo0?ooo`0U0?ooo`030?l0003oool0oooo0<l0oooo00001@3oool000000?ooo`3oool00000
00P0oooo00<000000?ooo`3oool01@3oool00`000000oooo0000000>0?ooo`030000o`3oool0oooo
02@0oooo00<0o`000?ooo`3oool0d03oool00080oooo0P00000:0?ooo`8000001@3oool00`000000
oooo0000000=0?ooo`030000o`3oool0oooo02@0oooo00<0o`000?ooo`3oool0d@3oool001D0oooo
00<000000?ooo`0000003@3oool00`000?l0oooo0?ooo`0S0?ooo`030?l0003oool0oooo0=80oooo
000E0?ooo`030000003oool0000000`0oooo00<0003o0?ooo`3oool0903oool00`3o0000oooo0?oo
o`3B0?ooo`005@3oool00`000000oooo0000000<0?ooo`030000o`3oool0oooo02<0oooo00<0o`00
0?ooo`3oool0d`3oool001D0oooo00<000000?ooo`000000303oool00`000?l0oooo0?ooo`0R0?oo
o`030?l0003oool0oooo0=@0oooo000E0?ooo`<000002`3oool00`000?l0oooo0?ooo`0S0?ooo`03
0?l0003oool0oooo0=@0oooo000E0?ooo`030000003oool0000000/0oooo00<0003o0?ooo`3oool0
8P3oool00`3o0000oooo0?ooo`3E0?ooo`005@3oool00`000000oooo0000000:0?ooo`030000o`3o
ool0oooo0280oooo00<0o`000?ooo`3oool0eP3oool001D0oooo00<000000?ooo`0000002P3oool0
0`000?l0oooo0?ooo`0R0?ooo`030?l0003oool0oooo0=H0oooo000E0?ooo`030000003oool00000
00X0oooo00<0003o0?ooo`3oool08@3oool00`3o0000oooo0?ooo`3G0?ooo`005@3oool2000000X0
oooo00<0003o0?ooo`3oool08@3oool00`3o0000oooo0?ooo`3H0?ooo`005@3oool2000000X0oooo
00<0003o0?ooo`3oool0803oool00`3o0000oooo0?ooo`3I0?ooo`005@3oool2000000T0oooo00<0
003o0?ooo`3oool08@3oool00`3o0000oooo0?ooo`3I0?ooo`005@3oool2000000T0oooo00<0003o
0?ooo`3oool0803oool00`3o0000oooo0?ooo`3J0?ooo`005@3oool2000000T0oooo00<0003o0?oo
o`3oool07`3oool00`3o0000oooo0?ooo`3K0?ooo`005@3oool2000000P0oooo00<0003o0?ooo`3o
ool0803oool00`3o0000oooo0?ooo`3K0?ooo`005@3oool2000000P0oooo00<0003o0?ooo`3oool0
7`3oool00`3o0000oooo0?ooo`3L0?ooo`005@3oool2000000P0oooo00<0003o0?ooo`3oool07P3o
ool00`3o0000oooo0?ooo`3M0?ooo`005@3oool2000000L0oooo00<0003o0?ooo`3oool07`3oool0
0`3o0000oooo0?ooo`3M0?ooo`005@3oool2000000L0oooo00<0003o0?ooo`3oool07P3oool00`3o
0000oooo0?ooo`3N0?ooo`005@3oool2000000L0oooo00<0003o0?ooo`3oool07@3oool00`3o0000
oooo0?ooo`3O0?ooo`005@3oool2000000L0oooo00<0003o0?ooo`3oool0703oool00`3o0000oooo
0?ooo`3P0?ooo`005@3oool2000000H0oooo00<0003o0?ooo`3oool07@3oool00`3o0000oooo0?oo
o`3P0?ooo`005@3oool2000000H0oooo00<0003o0?ooo`3oool0703oool00`3o0000oooo0?ooo`3Q
0?ooo`005@3oool2000000H0oooo00<0003o0?ooo`3oool06`3oool00`3o0000oooo0?ooo`3R0?oo
o`005@3oool2000000H0oooo00<0003o0?ooo`3oool06P3oool00`3o0000oooo0?ooo`3S0?ooo`00
0P3oool2000000@0oooo00<000000?ooo`3oool00P3oool3000000D0oooo0P0000050?ooo`030000
o`3oool0oooo01X0oooo00<0o`000?ooo`3oool0i03oool000050?ooo`000000oooo0?ooo`000000
1`3oool01@000000oooo0?ooo`3oool0000000@0oooo0P0000050?ooo`030000o`3oool0oooo01X0
oooo00<0o`000?ooo`3oool0i03oool000050?ooo`000000oooo0?ooo`0000001`3oool01@000000
oooo0?ooo`3oool0000000@0oooo0P0000050?ooo`030000o`3oool0oooo01T0oooo00<0o`000?oo
o`3oool0i@3oool000050?ooo`000000oooo0?ooo`000000203oool3000000D0oooo0`0000040?oo
o`030000o`3oool0oooo01P0oooo00<0o`000?ooo`3oool0iP3oool000050?ooo`000000oooo0?oo
o`0000001`3oool01@000000oooo0?ooo`3oool0000000@0oooo0P0000040?ooo`030000o`3oool0
oooo01P0oooo00<0o`000?ooo`3oool0i`3oool000050?ooo`000000oooo0?ooo`0000001`3oool0
1@000000oooo0?ooo`3oool0000000@0oooo0P0000040?ooo`030000o`3oool0oooo01P0oooo00<0
o`000?ooo`3oool0i`3oool00080oooo0P0000090?ooo`<000001@3oool2000000@0oooo00<0003o
0?ooo`3oool05`3oool00`3o0000oooo0?ooo`3X0?ooo`005@3oool2000000@0oooo00<0003o0?oo
o`3oool05P3oool00`3o0000oooo0?ooo`3Y0?ooo`005@3oool2000000<0oooo00<0003o0?ooo`3o
ool05P3oool00`3o0000oooo0?ooo`3Z0?ooo`005@3oool2000000<0oooo00<0003o0?ooo`3oool0
5@3oool00`3o0000oooo0?ooo`3[0?ooo`005@3oool2000000<0oooo00<0003o0?ooo`3oool0503o
ool00`3o0000oooo0?ooo`3/0?ooo`005@3oool2000000<0oooo00<0003o0?ooo`3oool04`3oool0
0`3o0000oooo0?ooo`3]0?ooo`005@3oool2000000<0oooo00<0003o0?ooo`3oool04`3oool00`3o
0000oooo0?ooo`3]0?ooo`005@3oool01@000000oooo0?ooo`3oool0003o01D0oooo00<0o`000?oo
o`3oool0kP3oool001D0oooo00D000000?ooo`3oool0oooo0000o`0D0?ooo`030?l0003oool0oooo
0>l0oooo000E0?ooo`050000003oool0oooo0?ooo`000?l04`3oool00`3o0000oooo0?ooo`3`0?oo
o`005@3oool01@000000oooo0?ooo`3oool0003o0180oooo00<0o`000?ooo`3oool0l@3oool001D0
oooo00D000000?ooo`3oool0oooo0000o`0@0?ooo`80o`00m03oool001D0oooo00@000000?ooo`3o
ool0003o403oool00`3o0000oooo0?ooo`3d0?ooo`005@3oool2000000030?ooo`000?l0oooo00h0
oooo00<0o`000?ooo`3oool0m@3oool001D0oooo00@000000?ooo`3oool0003o3P3oool00`3o0000
oooo0?ooo`3f0?ooo`005@3oool010000000oooo0?ooo`000?l=0?ooo`030?l0003oool0oooo0?L0
oooo000E0?ooo`040000003oool0oooo0000o``0oooo00<0o`000?ooo`3oool0n03oool001D0oooo
00<000000?ooo`000?l0303oool00`3o0000oooo0?ooo`3i0?ooo`005@3oool00`000000oooo0000
o`0;0?ooo`030?l0003oool0oooo0?X0oooo000E0?ooo`030000003oool0003o00X0oooo00<0o`00
0?ooo`3oool0n`3oool001D0oooo00<000000?ooo`000?l02@3oool00`3o0000oooo0?ooo`3l0?oo
o`005@3oool2000000030000o`3oool0oooo00H0oooo00<0o`000?ooo`3oool0o@3oool001D0oooo
00<000000000o`3oool01P3oool20?l00?l0oooo0@3oool001D0oooo00<000000000o`3oool01@3o
ool00`3o0000oooo0?ooo`3o0?ooo`40oooo000E0?ooo`03000000000?l0oooo00<0oooo0P3o003o
0?ooo`@0oooo000E0?ooo`03000000000?l0oooo0080oooo00<0o`000?ooo`3oool0o`3oool40?oo
o`003@3oool3000000D0oooo00D000000000o`3oool0oooo0?l0003o0?ooo`L0oooo000>0?ooo`03
0000003oool0oooo00@0oooo00@000000?ooo`3o0000o`00o`3oool80?ooo`003P3oool00`000000
oooo0?ooo`040?ooo`030000003o0000oooo0?l0oooo2@3oool000h0oooo00<000000?ooo`3oool0
103oool300000?l0oooo2@3oool000h0oooo00<000000?ooo`3oool0103oool00`000000oooo0?oo
o`3o0?ooo`T0oooo000=0?ooo`8000001P3oool00`000000oooo0?ooo`3o0?ooo`T0oooo000>0?oo
o`030000003oool0oooo00@0oooo00<000000?ooo`3oool0o`3oool90?ooo`005@3oool00`000000
oooo0?ooo`3o0?ooo`T0oooo0000\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.829852, -0.07747, \
0.0386179, 0.00624851}}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(D[BlockDistributionLT[w, R] // Log, {w, 2}] /. w \[Rule] 0 // 
      Simplify\)], "Input",
  CellLabel->"In[389]:="],

Cell[BoxData[
    \(R\ \((\(-1\) + 2\ R)\)\)], "Output",
  CellLabel->"Out[389]="]
}, Open  ]],

Cell[BoxData[""], "Input"],

Cell[BoxData[
    \(\(soln[f0_, wm_, 
          e_] := \(NDSolve[{f[e] == f0 \((1 - \(e\/3\) \((2 - f0)\))\), 
              0 == \(-2\) \((1 + w)\) f[w] - w\ \(f'\)[w] + 2  f0 + 
                  w\ f[w]\^2}, 
            f, {w, e, 
              wm}]\)\[LeftDoubleBracket]1\[RightDoubleBracket];\)\)], "Input",\

  CellLabel->"In[302]:="],

Cell[CellGroupData[{

Cell[BoxData[
    \(f[2] /. soln[1, 10, 0.001]\)], "Input",
  CellLabel->"In[214]:="],

Cell[BoxData[
    \(0.4626853001180025`\)], "Output",
  CellLabel->"Out[214]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
    \(ss = soln[0.2, 20, 0.001]; 
    ss2 = soln[1.9, 20, 0.001];\), "\[IndentingNewLine]", 
    \(\(Plot[{f[w]\/0.2 /. ss, f[w]\/1.9 /. ss2, ff[w, 0.2]\/0.2, 
            ff[w, 1.9]\/1.9} // Evaluate, {w, 0.001, 20}, 
        PlotStyle -> {Blue, Black, Red, Green}];\)\)}], "Input",
  CellLabel->"In[250]:="],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.047619 0.0147151 0.588623 [
[.2619 .00222 -3 -9 ]
[.2619 .00222 3 0 ]
[.5 .00222 -6 -9 ]
[.5 .00222 6 0 ]
[.7381 .00222 -6 -9 ]
[.7381 .00222 6 0 ]
[.97619 .00222 -6 -9 ]
[.97619 .00222 6 0 ]
[.01131 .13244 -18 -4.5 ]
[.01131 .13244 0 4.5 ]
[.01131 .25016 -18 -4.5 ]
[.01131 .25016 0 4.5 ]
[.01131 .36789 -18 -4.5 ]
[.01131 .36789 0 4.5 ]
[.01131 .48561 -18 -4.5 ]
[.01131 .48561 0 4.5 ]
[.01131 .60334 -6 -4.5 ]
[.01131 .60334 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2619 .01472 m
.2619 .02097 L
s
[(5)] .2619 .00222 0 1 Mshowa
.5 .01472 m
.5 .02097 L
s
[(10)] .5 .00222 0 1 Mshowa
.7381 .01472 m
.7381 .02097 L
s
[(15)] .7381 .00222 0 1 Mshowa
.97619 .01472 m
.97619 .02097 L
s
[(20)] .97619 .00222 0 1 Mshowa
.125 Mabswid
.07143 .01472 m
.07143 .01847 L
s
.11905 .01472 m
.11905 .01847 L
s
.16667 .01472 m
.16667 .01847 L
s
.21429 .01472 m
.21429 .01847 L
s
.30952 .01472 m
.30952 .01847 L
s
.35714 .01472 m
.35714 .01847 L
s
.40476 .01472 m
.40476 .01847 L
s
.45238 .01472 m
.45238 .01847 L
s
.54762 .01472 m
.54762 .01847 L
s
.59524 .01472 m
.59524 .01847 L
s
.64286 .01472 m
.64286 .01847 L
s
.69048 .01472 m
.69048 .01847 L
s
.78571 .01472 m
.78571 .01847 L
s
.83333 .01472 m
.83333 .01847 L
s
.88095 .01472 m
.88095 .01847 L
s
.92857 .01472 m
.92857 .01847 L
s
.25 Mabswid
0 .01472 m
1 .01472 L
s
.02381 .13244 m
.03006 .13244 L
s
[(0.2)] .01131 .13244 1 0 Mshowa
.02381 .25016 m
.03006 .25016 L
s
[(0.4)] .01131 .25016 1 0 Mshowa
.02381 .36789 m
.03006 .36789 L
s
[(0.6)] .01131 .36789 1 0 Mshowa
.02381 .48561 m
.03006 .48561 L
s
[(0.8)] .01131 .48561 1 0 Mshowa
.02381 .60334 m
.03006 .60334 L
s
[(1)] .01131 .60334 1 0 Mshowa
.125 Mabswid
.02381 .04415 m
.02756 .04415 L
s
.02381 .07358 m
.02756 .07358 L
s
.02381 .10301 m
.02756 .10301 L
s
.02381 .16187 m
.02756 .16187 L
s
.02381 .1913 m
.02756 .1913 L
s
.02381 .22073 m
.02756 .22073 L
s
.02381 .2796 m
.02756 .2796 L
s
.02381 .30903 m
.02756 .30903 L
s
.02381 .33846 m
.02756 .33846 L
s
.02381 .39732 m
.02756 .39732 L
s
.02381 .42675 m
.02756 .42675 L
s
.02381 .45618 m
.02756 .45618 L
s
.02381 .51505 m
.02756 .51505 L
s
.02381 .54448 m
.02756 .54448 L
s
.02381 .57391 m
.02756 .57391 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
0 0 1 r
.5 Mabswid
.02386 .60299 m
.04266 .48348 L
.06249 .39205 L
.0826 .32471 L
.10462 .27102 L
.12419 .23543 L
.14513 .20611 L
.16643 .18289 L
.18657 .16537 L
.22499 .14013 L
.26585 .121 L
.3052 .10733 L
.34303 .09711 L
.38332 .08843 L
.42209 .08164 L
.46331 .07566 L
.50302 .07083 L
.54121 .06686 L
.58185 .0632 L
.62098 .06013 L
.66256 .05727 L
.70262 .05483 L
.74117 .05274 L
.78217 .05074 L
.82166 .049 L
.85963 .04748 L
.90005 .046 L
.93896 .0447 L
.97619 .04355 L
s
0 0 0 r
.02386 .60332 m
.03283 .59928 L
.04266 .59399 L
.06249 .57968 L
.07303 .56953 L
.0843 .5562 L
.10462 .52433 L
.12593 .4785 L
.14607 .42419 L
.18448 .30968 L
.20392 .25866 L
.22534 .21378 L
.24566 .18206 L
.26469 .1601 L
.28494 .14273 L
.30346 .13064 L
.32405 .1201 L
.34317 .11222 L
.38136 .10001 L
.42049 .0906 L
.46207 .08276 L
.50213 .07664 L
.54068 .07173 L
.58168 .0673 L
.62117 .06365 L
.65914 .06059 L
.69956 .05773 L
.73847 .05529 L
.77983 .05299 L
.81967 .05101 L
.858 .04929 L
.89878 .04763 L
.93804 .04618 L
.97579 .04489 L
.97619 .04488 L
s
1 0 0 r
.02386 .60299 m
.04266 .48348 L
.06249 .39205 L
.0826 .32471 L
.10462 .27102 L
.12419 .23543 L
.14513 .20611 L
.16643 .18289 L
.18657 .16536 L
.22499 .14013 L
.26585 .121 L
.3052 .10733 L
.34303 .09711 L
.38332 .08843 L
.42209 .08164 L
.46331 .07566 L
.50302 .07083 L
.54121 .06686 L
.58185 .0632 L
.62098 .06013 L
.66256 .05727 L
.70262 .05483 L
.74117 .05274 L
.78217 .05074 L
.82166 .049 L
.85963 .04748 L
.90005 .046 L
.93896 .0447 L
.97619 .04355 L
s
0 1 0 r
.02386 .60332 m
.03283 .59928 L
.04266 .59399 L
.06249 .57968 L
.07303 .56953 L
.0843 .5562 L
.10462 .52433 L
.12593 .4785 L
.14607 .42419 L
.18448 .30968 L
.20392 .25867 L
.22534 .21378 L
.24566 .18206 L
.26469 .1601 L
.28494 .14273 L
.30346 .13064 L
.32405 .1201 L
.34317 .11222 L
.38136 .10001 L
.42049 .0906 L
.46207 .08276 L
.50213 .07664 L
.54068 .07173 L
.58168 .0673 L
.62117 .06365 L
.65914 .06059 L
.69956 .05773 L
.73847 .05529 L
.77983 .05299 L
.81967 .05101 L
.858 .04929 L
.89878 .04763 L
.93804 .04618 L
.97579 .04489 L
.97619 .04488 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[250]:=",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/B000`400?l00000o`00003oo`3ooolQ
0?ooo`00E03oool3000003X0oooo0`0000040?ooo`800000>03oool3000000<0oooo0`00000g0?oo
o`D000000`3oool2000000@0oooo001C0?ooo`050000003oool0oooo0?ooo`000000>P3oool00`00
0000oooo0?ooo`020?ooo`040000003oool0oooo000003P0oooo00D000000?ooo`3oool0oooo0000
00030?ooo`030000003oool0oooo03D0oooo00@000000?ooo`3oool000000P3oool010000000oooo
0?ooo`0000030?ooo`00E`3oool00`000000oooo0?ooo`0h0?ooo`030000003oool0oooo0080oooo
00@000000?ooo`3oool00000>03oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo03H0
oooo00<000000?ooo`3oool00P3oool010000000oooo0?ooo`0000030?ooo`00E`3oool00`000000
oooo0?ooo`0h0?ooo`030000003oool0oooo0080oooo00@000000?ooo`3oool00000>03oool00`00
0000oooo0?ooo`050?ooo`030000003oool0oooo03L0oooo00D000000?ooo`3oool0oooo00000002
0?ooo`030000003oool0oooo0040oooo001C0?ooo`@00000>`3oool00`000000oooo0?ooo`020?oo
o`040000003oool0oooo000003P0oooo00@000000?ooo`3oool0oooo1000000g0?ooo`050000003o
ool0oooo0?ooo`0000000P3oool010000000oooo0?ooo`0000030?ooo`00D`3oool00`000000oooo
0?ooo`0k0?ooo`800000103oool010000000oooo0?ooo`00000g0?ooo`8000000`3oool00`000000
oooo0?ooo`0h0?ooo`050000003oool0oooo0?ooo`0000000P3oool010000000oooo0?ooo`000003
0?ooo`00D`3oool5000003X0oooo00<000000?ooo`3oool00`3oool2000003T0oooo00@000000?oo
o`3oool0oooo1@00000g0?ooo`<00000103oool2000000@0oooo000E0?ooo`030000003oool0oooo
0?l0oooo2@3oool001D0oooo00<000000?ooo`3oool0o`3oool90?ooo`005@3oool00`000000oooo
0?ooo`3o0?ooo`T0oooo000E0?ooo`030000003oool0oooo0?l0oooo2@3oool000l0ooooo`00000A
00000040oooo000E0?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool02P3oool00`00
0000oooo0?ooo`0:0?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool02P3oool00`00
0000oooo0?ooo`0:0?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool02P3oool00`00
0000oooo0?ooo`0:0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool02P3oool00`00
0000oooo0?ooo`0:0?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool02P3oool00`00
0000oooo0?ooo`0:0?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool02P3oool00`00
0000oooo0?ooo`0:0?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool02P3oool00`00
0000oooo0?ooo`050?ooo`005@3oool00`000000oooo0?ooo`0n0?ooo`030000003oool0oooo03d0
oooo00<000000?ooo`3oool0?P3oool00`000000oooo0?ooo`0n0?ooo`030000003oool0oooo00D0
oooo000E0?ooo`030000003oool0oooo0?l0oooo2@3oool001D0oooo00<000000?ooo`3oool0o`3o
ool90?ooo`005@3oool00`000000oooo0?ooo`3o0?ooo`T0oooo000E0?ooo`030000003oool0oooo
0?l0oooo2@3oool001D0oooo00<000000?ooo`3oool0o`3oool90?ooo`005@3oool200000>L0oooo
5@3o0006003o00L0oooo000E0?ooo`030000003oool0oooo0=40oooo2P3o000P003o00d0oooo000E
0?ooo`030000003oool0oooo0;/0oooo2P3o000F003o02d0oooo000E0?ooo`030000003oool0oooo
0;40oooo2@3o000;003o04<0oooo000E0?ooo`030000003oool0oooo09X0oooo2`3o000E003o04h0
oooo000E0?ooo`030000003oool0oooo0900oooo2P3o000;003o06<0oooo000E0?ooo`030000003o
ool0oooo08D0oooo2`3o000:003o06h0oooo000E0?ooo`030000003oool0oooo07`0oooo2@3o0002
0?ooo`T00?l0N03oool001D0oooo0P00001h0?ooo`D0o`001P3oool5003o0840oooo000E0?ooo`03
0000003oool0oooo06l0oooo203o00030?ooo`P00?l0QP3oool001D0oooo00<000000?ooo`3oool0
I`3oool80?l000<0oooo2000o`2>0?ooo`005@3oool00`000000oooo0?ooo`1R0?ooo`D0o`001`3o
ool4003o09H0oooo000E0?ooo`030000003oool0oooo05`0oooo1P3o00090?ooo`<00?l0VP3oool0
01D0oooo00<000000?ooo`3oool0E`3oool50?l000X0oooo1@00o`2M0?ooo`005@3oool00`000000
oooo0?ooo`1B0?ooo`D0o`002P3oool5003o0:80oooo000E0?ooo`030000003oool0oooo04l0oooo
0`3o000:0?ooo`D00?l0Y`3oool001D0oooo0P00001=0?ooo`<0o`002P3oool3003o0:`0oooo000E
0?ooo`030000003oool0oooo04T0oooo0`3o000:0?ooo`<00?l0[`3oool001D0oooo00<000000?oo
o`3oool0AP3oool30?l000X0oooo0`00o`2b0?ooo`005@3oool00`000000oooo0?ooo`130?ooo`<0
o`002`3oool2003o0;D0oooo000E0?ooo`030000003oool0oooo0400oooo0`3o000=0?ooo`03003o
003oool0oooo0;D0oooo00020?ooo`800000103oool010000000oooo0?ooo`3oool5000000@0oooo
00<000000?ooo`3oool0?P3oool20?l000h0oooo0P00o`2h0?ooo`0000D0oooo0000003oool0oooo
000000080?ooo`040000003oool0oooo000000@0oooo00<000000?ooo`3oool0?03oool20?l000d0
oooo0`00o`2j0?ooo`0000D0oooo0000003oool0oooo000000090?ooo`030000003oool0oooo00@0
oooo00<000000?ooo`3oool0>@3oool30?l000`0oooo0`00o`2m0?ooo`0000D0oooo0000003oool0
oooo0000000:0?ooo`030000003oool0oooo00<0oooo0`00000g0?ooo`80o`003P3oool00`00o`00
oooo0?ooo`2n0?ooo`0000D0oooo0000003oool0oooo000000070?ooo`050000003oool0oooo0?oo
o`000000103oool00`000000oooo0?ooo`0e0?ooo`80o`003`3oool00`00o`00oooo0?ooo`2o0?oo
o`0000D0oooo0000003oool0oooo000000070?ooo`050000003oool0oooo0?ooo`000000103oool0
0`000000oooo0?ooo`0c0?ooo`80o`00403oool00`00o`00oooo0?ooo`300?ooo`000P3oool20000
00T0oooo0`0000050?ooo`030000003oool0oooo0380oooo00<0o`000?ooo`3oool03P3oool2003o
0<<0oooo000E0?ooo`030000003oool0oooo0300oooo0P3o000@0?ooo`03003o003oool0oooo0<<0
oooo000E0?ooo`030000003oool0oooo02h0oooo0P3o000@0?ooo`800?l0aP3oool001D0oooo00<0
00000?ooo`3oool0;@3oool00`3o0000oooo0?ooo`0?0?ooo`03003o003oool0oooo0<H0oooo000E
0?ooo`030000003oool0oooo02/0oooo0P3o000A0?ooo`03003o003oool0oooo0<L0oooo000E0?oo
o`800000:`3oool00`3o0000oooo0?ooo`0A0?ooo`03003o003oool0oooo0<L0oooo000E0?ooo`03
0000003oool0oooo02T0oooo00<0o`000?ooo`3oool04@3oool00`00o`00oooo0?ooo`380?ooo`00
5@3oool00`000000oooo0?ooo`0X0?ooo`030?l0003oool0oooo0140oooo00<00?l00?ooo`3oool0
b@3oool001D0oooo00<000000?ooo`3oool09`3oool00`3o0000oooo0?ooo`0A0?ooo`03003o003o
ool0oooo0<X0oooo000E0?ooo`030000003oool0oooo02H0oooo00<0o`000?ooo`3oool04@3oool0
0`00o`00oooo0?ooo`3;0?ooo`005@3oool00`000000oooo0?ooo`0U0?ooo`030?l0003oool0oooo
0140oooo00<00?l00?ooo`3oool0c03oool001D0oooo00<000000?ooo`3oool0903oool00`3o0000
oooo0?ooo`0B0?ooo`03003o003oool0oooo0<`0oooo000E0?ooo`030000003oool0oooo02<0oooo
00<0o`000?ooo`3oool04P3oool00`00o`00oooo0?ooo`3=0?ooo`005@3oool2000002<0oooo00<0
o`000?ooo`3oool04`3oool00`00o`00oooo0?ooo`3=0?ooo`005@3oool00`000000oooo0?ooo`0Q
0?ooo`030?l0003oool0oooo01<0oooo00<00?l00?ooo`3oool0cP3oool001D0oooo00<000000?oo
o`3oool0803oool00`3o0000oooo0?ooo`0C0?ooo`03003o003oool0oooo0<l0oooo000E0?ooo`03
0000003oool0oooo01l0oooo00<0o`000?ooo`3oool0503oool00`00o`00oooo0?ooo`3?0?ooo`00
5@3oool00`000000oooo0?ooo`0N0?ooo`030?l0003oool0oooo01@0oooo00<00?l00?ooo`3oool0
d03oool001D0oooo00<000000?ooo`3oool07P3oool00`3o0000oooo0?ooo`0D0?ooo`03003o003o
ool0oooo0=00oooo000E0?ooo`030000003oool0oooo01d0oooo00<0o`000?ooo`3oool0503oool0
0`00o`00oooo0?ooo`3A0?ooo`005@3oool00`000000oooo0?ooo`0L0?ooo`030?l0003oool0oooo
01D0oooo00<00?l00?ooo`3oool0d@3oool001D0oooo0P00000L0?ooo`030?l0003oool0oooo01D0
oooo00<00?l00?ooo`3oool0dP3oool001D0oooo00<000000?ooo`3oool06`3oool00`3o0000oooo
0?ooo`0E0?ooo`03003o003oool0oooo0=80oooo000E0?ooo`030000003oool0oooo01X0oooo00<0
o`000?ooo`3oool05@3oool00`00o`00oooo0?ooo`3C0?ooo`005@3oool00`000000oooo0?ooo`0I
0?ooo`030?l0003oool0oooo01H0oooo00<00?l00?ooo`3oool0d`3oool001D0oooo00<000000?oo
o`3oool0603oool00`3o0000oooo0?ooo`0F0?ooo`03003o003oool0oooo0=@0oooo00020?ooo`80
0000103oool00`000000oooo0?ooo`030?ooo`<00000103oool00`000000oooo0?ooo`0H0?ooo`03
0?l0003oool0oooo01H0oooo00<00?l00?ooo`3oool0e03oool000050?ooo`000000oooo0?ooo`00
00002P3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo01L0oooo00<0o`000?ooo`3o
ool05P3oool00`00o`00oooo0?ooo`3E0?ooo`0000D0oooo0000003oool0oooo000000070?ooo`D0
0000103oool00`000000oooo0?ooo`0G0?ooo`030?l0003oool0oooo01H0oooo00<00?l00?ooo`3o
ool0e@3oool000050?ooo`000000oooo0?ooo`0000001`3oool010000000oooo0?ooo`0000050?oo
o`<000005P3oool00`3o0000oooo0?ooo`0F0?ooo`03003o003oool0oooo0=H0oooo00001@3oool0
00000?ooo`3oool0000000P0oooo00<000000?ooo`0000001@3oool00`000000oooo0?ooo`0F0?oo
o`030?l0003oool0oooo01H0oooo00<00?l00?ooo`3oool0eP3oool000050?ooo`000000oooo0?oo
o`0000002@3oool2000000D0oooo00<000000?ooo`3oool05@3oool00`3o0000oooo0?ooo`0F0?oo
o`03003o003oool0oooo0=L0oooo00020?ooo`8000002`3oool00`000000oooo0?ooo`030?ooo`03
0000003oool0oooo01D0oooo00<0o`000?ooo`3oool05P3oool00`00o`00oooo0?ooo`3G0?ooo`00
5@3oool00`000000oooo0?ooo`0D0?ooo`030?l0003oool0oooo01H0oooo00<00?l00?ooo`3oool0
f03oool001D0oooo00<000000?ooo`3oool0503oool00`3o0000oooo0?ooo`0F0?ooo`03003o003o
ool0oooo0=P0oooo000E0?ooo`030000003oool0oooo01<0oooo00<0o`000?ooo`3oool05`3oool0
0`00o`00oooo0?ooo`3H0?ooo`005@3oool00`000000oooo0?ooo`0C0?ooo`030?l0003oool0oooo
01H0oooo00<00?l00?ooo`3oool0f@3oool001D0oooo0P00000C0?ooo`030?l0003oool0oooo01L0
oooo00<00?l00?ooo`3oool0f@3oool001D0oooo00<000000?ooo`3oool04P3oool00`3o0000oooo
0?ooo`0G0?ooo`03003o003oool0oooo0=T0oooo000E0?ooo`030000003oool0oooo0140oooo00<0
o`000?ooo`3oool05`3oool00`00o`00oooo0?ooo`3J0?ooo`005@3oool00`000000oooo0?ooo`0A
0?ooo`030?l0003oool0oooo01L0oooo00<00?l00?ooo`3oool0fP3oool001D0oooo00<000000?oo
o`3oool04@3oool00`3o0000oooo0?ooo`0G0?ooo`03003o003oool0oooo0=X0oooo000E0?ooo`03
0000003oool0oooo0100oooo00<0o`000?ooo`3oool05`3oool00`00o`00oooo0?ooo`3K0?ooo`00
5@3oool00`000000oooo0?ooo`0@0?ooo`030?l0003oool0oooo01L0oooo00<00?l00?ooo`3oool0
f`3oool001D0oooo00<000000?ooo`3oool03`3oool00`3o0000oooo0?ooo`0H0?ooo`03003o003o
ool0oooo0=/0oooo000E0?ooo`800000403oool00`3o0000oooo0?ooo`0G0?ooo`03003o003oool0
oooo0=`0oooo000E0?ooo`030000003oool0oooo00h0oooo00<0o`000?ooo`3oool0603oool00`00
o`00oooo0?ooo`3L0?ooo`005@3oool00`000000oooo0?ooo`0>0?ooo`030?l0003oool0oooo01L0
oooo00<00?l00?ooo`3oool0g@3oool001D0oooo00<000000?ooo`3oool03P3oool00`3o0000oooo
0?ooo`0G0?ooo`03003o003oool0oooo0=d0oooo000E0?ooo`030000003oool0oooo00d0oooo00<0
o`000?ooo`3oool0603oool00`00o`00oooo0?ooo`3M0?ooo`005@3oool00`000000oooo0?ooo`0=
0?ooo`030?l0003oool0oooo01L0oooo00<00?l00?ooo`3oool0gP3oool001D0oooo00<000000?oo
o`3oool03@3oool00`3o0000oooo0?ooo`0G0?ooo`03003o003oool0oooo0=h0oooo000E0?ooo`03
0000003oool0oooo00`0oooo00<0o`000?ooo`3oool0603oool00`00o`00oooo0?ooo`3N0?ooo`00
5@3oool2000000d0oooo00<0o`000?ooo`3oool05`3oool00`00o`00oooo0?ooo`3O0?ooo`005@3o
ool00`000000oooo0?ooo`0<0?ooo`030?l0003oool0oooo01L0oooo00<00?l00?ooo`3oool0g`3o
ool001D0oooo00<000000?ooo`3oool0303oool00`3o0000oooo0?ooo`0G0?ooo`03003o003oool0
oooo0=l0oooo000E0?ooo`030000003oool0oooo00/0oooo00<0o`000?ooo`3oool05`3oool00`00
o`00oooo0?ooo`3P0?ooo`005@3oool00`000000oooo0?ooo`0;0?ooo`030?l0003oool0oooo01L0
oooo00<00?l00?ooo`3oool0h03oool00080oooo0P0000040?ooo`030000003oool0oooo0080oooo
0`0000050?ooo`030000003oool0oooo00/0oooo00<0o`000?ooo`3oool05`3oool00`00o`00oooo
0?ooo`3P0?ooo`0000D0oooo0000003oool0oooo000000070?ooo`050000003oool0oooo0?ooo`00
0000103oool00`000000oooo0?ooo`0:0?ooo`030?l0003oool0oooo01L0oooo00<00?l00?ooo`3o
ool0h@3oool000050?ooo`000000oooo0?ooo`0000001`3oool01@000000oooo0?ooo`3oool00000
00@0oooo00<000000?ooo`3oool02P3oool00`3o0000oooo0?ooo`0G0?ooo`03003o003oool0oooo
0>40oooo00001@3oool000000?ooo`3oool0000000L0oooo100000050?ooo`<000002P3oool00`3o
0000oooo0?ooo`0F0?ooo`03003o003oool0oooo0>80oooo00001@3oool000000?ooo`3oool00000
00L0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`0:0?ooo`030?l0003oool0oooo
01H0oooo00<00?l00?ooo`3oool0hP3oool000050?ooo`000000oooo0?ooo`000000203oool00`00
0000oooo0?ooo`050?ooo`030000003oool0oooo00T0oooo00<0o`000?ooo`3oool05`3oool00`00
o`00oooo0?ooo`3R0?ooo`000P3oool2000000X0oooo0P0000050?ooo`030000003oool0oooo00T0
oooo00<0o`000?ooo`3oool05P3oool00`00o`00oooo0?ooo`3S0?ooo`005@3oool00`000000oooo
0?ooo`090?ooo`030?l0003oool0oooo01H0oooo00<00?l00?ooo`3oool0h`3oool001D0oooo00<0
00000?ooo`3oool02@3oool00`3o0000oooo0?ooo`0F0?ooo`03003o003oool0oooo0><0oooo000E
0?ooo`030000003oool0oooo00P0oooo00<0o`000?ooo`3oool05P3oool00`00o`00oooo0?ooo`3T
0?ooo`005@3oool00`000000oooo0?ooo`080?ooo`030?l0003oool0oooo01H0oooo00<00?l00?oo
o`3oool0i03oool001D0oooo0P0000090?ooo`030?l0003oool0oooo01H0oooo00<00?l00?ooo`3o
ool0i03oool001D0oooo00<000000?ooo`3oool0203oool00`3o0000oooo0?ooo`0E0?ooo`03003o
003oool0oooo0>D0oooo000E0?ooo`030000003oool0oooo00L0oooo00<0o`000?ooo`3oool05P3o
ool00`00o`00oooo0?ooo`3U0?ooo`005@3oool00`000000oooo0?ooo`070?ooo`030?l0003oool0
oooo01H0oooo00<00?l00?ooo`3oool0i@3oool001D0oooo00<000000?ooo`3oool01`3oool00`3o
0000oooo0?ooo`0E0?ooo`03003o003oool0oooo0>H0oooo000E0?ooo`030000003oool0oooo00L0
oooo00<0o`000?ooo`3oool05@3oool00`00o`00oooo0?ooo`3V0?ooo`005@3oool00`000000oooo
0?ooo`060?ooo`030?l0003oool0oooo01H0oooo00<00?l00?ooo`3oool0iP3oool001D0oooo00<0
00000?ooo`3oool01P3oool00`3o0000oooo0?ooo`0E0?ooo`03003o003oool0oooo0>L0oooo000E
0?ooo`8000001`3oool00`3o0000oooo0?ooo`0E0?ooo`03003o003oool0oooo0>L0oooo000E0?oo
o`030000003oool0oooo00H0oooo00<0o`000?ooo`3oool0503oool00`00o`00oooo0?ooo`3X0?oo
o`005@3oool00`000000oooo0?ooo`050?ooo`030?l0003oool0oooo01D0oooo00<00?l00?ooo`3o
ool0j03oool001D0oooo00<000000?ooo`3oool01@3oool00`3o0000oooo0?ooo`0E0?ooo`03003o
003oool0oooo0>P0oooo000E0?ooo`030000003oool0oooo00D0oooo00<0o`000?ooo`3oool0503o
ool00`00o`00oooo0?ooo`3Y0?ooo`005@3oool00`000000oooo0?ooo`050?ooo`030?l0003oool0
oooo01@0oooo00<00?l00?ooo`3oool0j@3oool001D0oooo00<000000?ooo`3oool0103oool00`3o
0000oooo0?ooo`0E0?ooo`03003o003oool0oooo0>T0oooo000E0?ooo`030000003oool0oooo00@0
oooo00<0o`000?ooo`3oool0503oool00`00o`00oooo0?ooo`3Z0?ooo`005@3oool2000000D0oooo
00<0o`000?ooo`3oool0503oool00`00o`00oooo0?ooo`3Z0?ooo`005@3oool00`000000oooo0?oo
o`040?ooo`030?l0003oool0oooo01@0oooo00<00?l00?ooo`3oool0jP3oool001D0oooo00<00000
0?ooo`3oool00`3oool00`3o0000oooo0?ooo`0D0?ooo`03003o003oool0oooo0>/0oooo000E0?oo
o`030000003oool0oooo00<0oooo00<0o`000?ooo`3oool0503oool00`00o`00oooo0?ooo`3[0?oo
o`005@3oool00`000000oooo0?ooo`030?ooo`030?l0003oool0oooo01@0oooo00<00?l00?ooo`3o
ool0j`3oool00080oooo0P0000040?ooo`030000003oool0oooo0080oooo0`0000050?ooo`030000
003oool0oooo00<0oooo00<0o`000?ooo`3oool04`3oool00`00o`00oooo0?ooo`3/0?ooo`0000D0
oooo0000003oool0oooo000000070?ooo`050000003oool0oooo0?ooo`000000103oool00`000000
oooo0?ooo`020?ooo`030?l0003oool0oooo01@0oooo00<00?l00?ooo`3oool0k03oool000050?oo
o`000000oooo0?ooo`0000001`3oool01@000000oooo0?ooo`3oool0000000@0oooo00<000000?oo
o`3oool00P3oool00`3o0000oooo0?ooo`0D0?ooo`03003o003oool0oooo0>`0oooo00001@3oool0
00000?ooo`3oool0000000P0oooo0`0000050?ooo`<000000P3oool00`3o0000oooo0?ooo`0C0?oo
o`03003o003oool0oooo0>d0oooo00001@3oool000000?ooo`3oool0000000L0oooo00D000000?oo
o`3oool0oooo000000040?ooo`030000003oool0oooo0080oooo00<0o`000?ooo`3oool04`3oool0
0`00o`00oooo0?ooo`3]0?ooo`0000D0oooo0000003oool0oooo000000070?ooo`050000003oool0
oooo0?ooo`000000103oool00`000000oooo0?ooo`020?ooo`030?l0003oool0oooo0180oooo00<0
0?l00?ooo`3oool0kP3oool00080oooo0P0000090?ooo`<000001@3oool01@000000oooo0?ooo`3o
ool0o`0001D0oooo00<00?l00?ooo`3oool0kP3oool001D0oooo00D000000?ooo`3oool0oooo0?l0
000D0?ooo`03003o003oool0oooo0>l0oooo000E0?ooo`050000003oool0oooo0?ooo`3o0000503o
ool00`00o`00oooo0?ooo`3_0?ooo`005@3oool01@000000oooo0?ooo`3oool0o`0001@0oooo00<0
0?l00?ooo`3oool0k`3oool001D0oooo00D000000?ooo`3oool0oooo0?l0000C0?ooo`03003o003o
ool0oooo0?00oooo000E0?ooo`8000000P3oool00`3o0000oooo0?ooo`0A0?ooo`03003o003oool0
oooo0?00oooo000E0?ooo`050000003oool0oooo0?ooo`3o00004P3oool00`00o`00oooo0?ooo`3a
0?ooo`005@3oool010000000oooo0?ooo`3o000C0?ooo`03003o003oool0oooo0?40oooo000E0?oo
o`040000003oool0oooo0?l00180oooo00<00?l00?ooo`3oool0lP3oool001D0oooo00@000000?oo
o`3oool0o`004P3oool00`00o`00oooo0?ooo`3b0?ooo`005@3oool010000000oooo0?ooo`3o000A
0?ooo`03003o003oool0oooo0?<0oooo000E0?ooo`040000003oool0oooo0?l00100oooo00<00?l0
0?ooo`3oool0m03oool001D0oooo00@000000?ooo`3oool0o`003`3oool00`00o`00oooo0?ooo`3e
0?ooo`005@3oool2000000030?l0003oool0oooo00h0oooo00<00?l00?ooo`3oool0m@3oool001D0
oooo00<000000?ooo`3o00003`3oool00`00o`00oooo0?ooo`3f0?ooo`005@3oool00`000000oooo
0?l0000>0?ooo`03003o003oool0oooo0?L0oooo000E0?ooo`030000003oool0o`0000d0oooo00<0
0?l00?ooo`3oool0n03oool001D0oooo00<000000?ooo`3o00003@3oool00`00o`00oooo0?ooo`3h
0?ooo`005@3oool00`000000oooo0?l0000<0?ooo`03003o003oool0oooo0?T0oooo000E0?ooo`03
0000003oool0o`0000/0oooo00<00?l00?ooo`3oool0nP3oool001D0oooo00<000000?l0003oool0
2P3oool00`00o`00oooo0?ooo`3k0?ooo`005@3oool00`000000o`000?ooo`0:0?ooo`03003o003o
ool0oooo0?/0oooo000E0?ooo`030000003o0000oooo00T0oooo00<00?l00?ooo`3oool0o03oool0
01D0oooo00<000000?l0003oool01`3oool2003o0?l0oooo000E0?ooo`030000003o0000oooo00D0
oooo0P00o`3o0?ooo`80oooo000E0?ooo`030000003o0000oooo00<0oooo0P00o`3o0?ooo`@0oooo
000=0?ooo`<000001@3oool010000000o`000?ooo`3oool2003o0?l0oooo1P3oool000h0oooo00<0
00000?ooo`3oool0103oool0103o0000oooo0?ooo`00o`3o0?ooo`P0oooo000>0?ooo`030000003o
ool0oooo00@0oooo00<0o`00003o0000o`00o`3oool90?ooo`003P3oool00`000000oooo0?ooo`04
0?ooo`03003o0000000000000?l0oooo2@3oool000h0oooo00<000000?ooo`3oool0103oool00`00
0000oooo0?ooo`3o0?ooo`T0oooo000=0?ooo`8000001P3oool00`000000oooo0?ooo`3o0?ooo`T0
oooo000>0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0o`3oool90?ooo`005@3o
ool00`000000oooo0?ooo`3o0?ooo`T0oooo0000\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-1.6601, -0.0774694, \
0.0772384, 0.00624851}}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(zz = 
      f[w] /. \(DSolve[
            0 == \(-2\) \((1 + w)\) f[w] - w\ \(f'\)[w] + 2  f0 + w\ f[w]\^2, 
            f, w]\)\[LeftDoubleBracket]1\[RightDoubleBracket]\)], "Input",
  CellLabel->"In[221]:="],

Cell[BoxData[
    \(\(f0\ C[1]\ Hypergeometric1F1[1 + f0, 3, \(-2\)\ w] + 2\ MeijerG[{{}, {\
\(-f0\)}}, {{\(-2\), 0}, {}}, 2\ w]\)\/\(C[1]\ Hypergeometric1F1[f0, 2, \
\(-2\)\ w] + MeijerG[{{}, {1 - f0}}, {{\(-1\), 0}, {}}, 2\ w]\)\)], "Output",
  CellLabel->"Out[221]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(\(\ \)\(C[1]\ Hypergeometric1F1[1 + f0, 3, \(-2\)\ w] + 2\ \
MeijerG[{{}, {\(-f0\)}}, {{\(-2\), 0}, {}}, 2\ w]/f0\)\)\/\(C[1]\ \
Hypergeometric1F1[f0, 2, \(-2\)\ w] + MeijerG[{{}, {1 - f0}}, {{\(-1\), 0}, \
{}}, 2\ w]\) /. {w \[Rule] 0.0000001, f0 \[Rule] 1.2}\)], "Input",
  CellLabel->"In[374]:="],

Cell[BoxData[
    \(\(3.578904389925806`*^13 + 0.9999998533333448`\ \
C[1]\)\/\(4.294687026244884`*^6 + 0.9999998800000088`\ C[1]\)\)], "Output",
  CellLabel->"Out[374]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(?MeijerG\)\)], "Input",
  CellLabel->"In[363]:="],

Cell[BoxData[
    \("MeijerG[{{a1, ... , an}, {an+1, ... , ap}}, {{b1, ... , bm}, {bm+1, \
... , bq}}, z] is the Meijer G function."\)], "Print",
  CellLabel->"From In[363]:="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(MeijerG[{{}, {\(-1.2`\)}}, {{\(-2\), 0}, {}}, 0]\)], "Input",
  CellLabel->"In[362]:="],

Cell[BoxData[
    \(MeijerG[{{}, {\(-1.2`\)}}, {{\(-2\), 0}, {}}, 0]\)], "Output",
  CellLabel->"Out[362]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(BlockDistributionLT[0, 0.3333]\)], "Input",
  CellLabel->"In[369]:="],

Cell[BoxData[
    \(0.9900000000000005`\)], "Output",
  CellLabel->"Out[369]="]
}, Open  ]],

Cell[BoxData[
    \(\(\(ff[w_, 
            f0__] := \(\(\ \ \)\(Hypergeometric1F1[1 + f0, 3, \(-2\)\ \
w]\)\)\/\(\(\ \ \)\(Hypergeometric1F1[f0, 2, \(-2\)\ w]\)\);\);\)\)], "Input",\

  CellLabel->"In[375]:="],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(-D[ff[w, f0], w]\) /. w -> 0 // Simplify\)], "Input",
  CellLabel->"In[376]:="],

Cell[BoxData[
    \(\(2 - f0\)\/3\)], "Output",
  CellLabel->"Out[376]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(Solve[3  R == \((2 - f0)\), f0] // Simplify\)], "Input",
  CellLabel->"In[377]:="],

Cell[BoxData[
    \({{f0 \[Rule] 2 - 3\ R}}\)], "Output",
  CellLabel->"Out[377]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(ff[0.000001, 0.5]\)], "Input",
  CellLabel->"In[243]:="],

Cell[BoxData[
    \(0.4999997500000624`\)], "Output",
  CellLabel->"Out[243]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(-D[BlockDistributionLT[w, R], w]\) /. w \[Rule] 0 // 
      Simplify\)], "Input",
  CellLabel->"In[359]:="],

Cell[BoxData[
    \(R\)], "Output",
  CellLabel->"Out[359]="]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["Junction pairs", "SubsubsectionIcon"],

Cell[TextData[{
  "In fact, sister junctions may be correlated because a large block is \
likely to break up into two large blocks; the correlation between lengths \
then decays as further recombinations and coalescences occur.  One could \
track the joint density of sister blocks, but this would involve higher and \
higher moments.  However, the approach may well converge rapidly.  Let the \
density of the two adjacent blocks associated with sister junctions be ",
  Cell[BoxData[
      \(TraditionalForm\`\[Psi][y\_1, y\_2]\)]],
  ".  Then:"
}], "Text"],

Cell[BoxData[
    \(TextForm\`\[PartialD]\_t \[Psi][y\_1, 
          y\_2] = \(-\((3 + y\_1 + y\_2)\)\) \[Psi][y\_1, y\_2] + 
        2 \((\[Integral]\_y\_1\%\[Infinity] \[Psi][z, 
                    y\_2] \[DifferentialD]z + \[Integral]\_y\_2\%\[Infinity] \
\[Psi][y\_1, z] \[DifferentialD]z)\) + \((\[Integral]\_0\%y\_1 \[Psi][z, 
                  y\_2] \[Psi][y\_1 - z, 
                  y\_2] \[DifferentialD]z + \[Integral]\_0\%y\_2 \[Psi][y\_1, 
                  z] \[Psi][y\_1, y\_2 - z] \[DifferentialD]z)\) + \((y\_1 + 
              y\_2)\) \[Psi][y\_1 + y\_2]\)], "NumberedEquation"],

Cell[TextData[{
  "The 3 arises because there are three kinds of coalescence that could \
terminate the block-pair.  the last term is the contribution from generation \
of new junctions within blocks of length ",
  Cell[BoxData[
      \(TraditionalForm\`y\_1 + \(\(y\_2\)\(.\)\)\)]],
  "  I have not checked that this conserves material."
}], "Text"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Example: starting from one genome, R=50 T=9.5", "SubsectionIcon"],

Cell[CellGroupData[{

Cell["Setting up", "SubsubsectionIcon"],

Cell["Run for 10,000 events to T=9.505", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(Timing[\(ng3 = 
            RandomGenealogy[{a}, 10000, 50, 
              DeleteNullLineages \[Rule] True];\)];\)\)], "Input",
  CellLabel->"In[163]:="],

Cell[BoxData[
    TagBox[\({906.5166666666664`\ Second, \[LeftSkeleton]1\[RightSkeleton]}\),
      
      Short]], "Output",
  CellLabel->"Out[163]//Short="]
}, Open  ]],

Cell[TextData[{
  "This lists all the lineages present at each timepoint (",
  StyleBox["slow",
    FontSlant->"Italic"],
  ")",
  ":"
}], "MathCaption"],

Cell[BoxData[{
    \(\[Epsilon] = 10\^\(-5\); 
    te = Drop[TimesOfEvents[ng3] + \[Epsilon], \(-1\)];\), "\n", 
    \(\(lpList = 
        Table[\((\(ExtractLineage[ng3, #] &\) /@ 
              LineagesPresent[ng3, 
                te\[LeftDoubleBracket]j\[RightDoubleBracket]])\), {j, 
            Length[te]}];\)\)}], "Input",
  CellLabel->"In[119]:="],

Cell[BoxData[
    \(\(ng3 >> "\<ng3Store\>";\)\)], "Input",
  CellLabel->"In[164]:="],

Cell[BoxData[
    \(\(lpList >> "\<lpListStore\>";\)\)], "Input",
  CellLabel->"In[188]:="],

Cell[BoxData[{
    \(\(ng3 = \(Get["\<ng3Store\>"]\)\[LeftDoubleBracket]2\
\[RightDoubleBracket];\)\), "\n", 
    \(\(lpList = Get["\<lpListStore\>"];\)\)}], "Input",
  CellLabel->"In[115]:="]
}, Closed]],

Cell[CellGroupData[{

Cell["\<\
Mean # of junction pairs is 52.6 (expect 50); fair fit to a Poisson\
\
\>", "SubsubsectionIcon"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(njunctions = \(Length[
                Flatten[# /. 
                    AncestralLineage[_, {_, _}, _, j_, _] :> 
                      Drop[j, \(-1\)]]]/2 &\) /@ 
          lpList;\)\), "\[IndentingNewLine]", 
    \(\(ListPlot[Transpose[{te, njunctions}], PlotJoined -> True, 
        PlotRange -> {{0, 10}, {0, 80}}];\)\), "\[IndentingNewLine]", 
    \(Mean[Drop[njunctions, 500]] // N\)}], "Input",
  CellLabel->"In[193]:="],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-2.77556e-17 0.1 0 0.00772542 [
[.2 -0.0125 -3 -9 ]
[.2 -0.0125 3 0 ]
[.4 -0.0125 -3 -9 ]
[.4 -0.0125 3 0 ]
[.6 -0.0125 -3 -9 ]
[.6 -0.0125 3 0 ]
[.8 -0.0125 -3 -9 ]
[.8 -0.0125 3 0 ]
[1 -0.0125 -6 -9 ]
[1 -0.0125 6 0 ]
[-0.0125 .07725 -12 -4.5 ]
[-0.0125 .07725 0 4.5 ]
[-0.0125 .15451 -12 -4.5 ]
[-0.0125 .15451 0 4.5 ]
[-0.0125 .23176 -12 -4.5 ]
[-0.0125 .23176 0 4.5 ]
[-0.0125 .30902 -12 -4.5 ]
[-0.0125 .30902 0 4.5 ]
[-0.0125 .38627 -12 -4.5 ]
[-0.0125 .38627 0 4.5 ]
[-0.0125 .46353 -12 -4.5 ]
[-0.0125 .46353 0 4.5 ]
[-0.0125 .54078 -12 -4.5 ]
[-0.0125 .54078 0 4.5 ]
[-0.0125 .61803 -12 -4.5 ]
[-0.0125 .61803 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 0 m
.2 .00625 L
s
[(2)] .2 -0.0125 0 1 Mshowa
.4 0 m
.4 .00625 L
s
[(4)] .4 -0.0125 0 1 Mshowa
.6 0 m
.6 .00625 L
s
[(6)] .6 -0.0125 0 1 Mshowa
.8 0 m
.8 .00625 L
s
[(8)] .8 -0.0125 0 1 Mshowa
1 0 m
1 .00625 L
s
[(10)] 1 -0.0125 0 1 Mshowa
.125 Mabswid
.05 0 m
.05 .00375 L
s
.1 0 m
.1 .00375 L
s
.15 0 m
.15 .00375 L
s
.25 0 m
.25 .00375 L
s
.3 0 m
.3 .00375 L
s
.35 0 m
.35 .00375 L
s
.45 0 m
.45 .00375 L
s
.5 0 m
.5 .00375 L
s
.55 0 m
.55 .00375 L
s
.65 0 m
.65 .00375 L
s
.7 0 m
.7 .00375 L
s
.75 0 m
.75 .00375 L
s
.85 0 m
.85 .00375 L
s
.9 0 m
.9 .00375 L
s
.95 0 m
.95 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .07725 m
.00625 .07725 L
s
[(10)] -0.0125 .07725 1 0 Mshowa
0 .15451 m
.00625 .15451 L
s
[(20)] -0.0125 .15451 1 0 Mshowa
0 .23176 m
.00625 .23176 L
s
[(30)] -0.0125 .23176 1 0 Mshowa
0 .30902 m
.00625 .30902 L
s
[(40)] -0.0125 .30902 1 0 Mshowa
0 .38627 m
.00625 .38627 L
s
[(50)] -0.0125 .38627 1 0 Mshowa
0 .46353 m
.00625 .46353 L
s
[(60)] -0.0125 .46353 1 0 Mshowa
0 .54078 m
.00625 .54078 L
s
[(70)] -0.0125 .54078 1 0 Mshowa
0 .61803 m
.00625 .61803 L
s
[(80)] -0.0125 .61803 1 0 Mshowa
.125 Mabswid
0 .01545 m
.00375 .01545 L
s
0 .0309 m
.00375 .0309 L
s
0 .04635 m
.00375 .04635 L
s
0 .0618 m
.00375 .0618 L
s
0 .09271 m
.00375 .09271 L
s
0 .10816 m
.00375 .10816 L
s
0 .12361 m
.00375 .12361 L
s
0 .13906 m
.00375 .13906 L
s
0 .16996 m
.00375 .16996 L
s
0 .18541 m
.00375 .18541 L
s
0 .20086 m
.00375 .20086 L
s
0 .21631 m
.00375 .21631 L
s
0 .24721 m
.00375 .24721 L
s
0 .26266 m
.00375 .26266 L
s
0 .27812 m
.00375 .27812 L
s
0 .29357 m
.00375 .29357 L
s
0 .32447 m
.00375 .32447 L
s
0 .33992 m
.00375 .33992 L
s
0 .35537 m
.00375 .35537 L
s
0 .37082 m
.00375 .37082 L
s
0 .40172 m
.00375 .40172 L
s
0 .41717 m
.00375 .41717 L
s
0 .43262 m
.00375 .43262 L
s
0 .44807 m
.00375 .44807 L
s
0 .47898 m
.00375 .47898 L
s
0 .49443 m
.00375 .49443 L
s
0 .50988 m
.00375 .50988 L
s
0 .52533 m
.00375 .52533 L
s
0 .55623 m
.00375 .55623 L
s
0 .57168 m
.00375 .57168 L
s
0 .58713 m
.00375 .58713 L
s
0 .60258 m
.00375 .60258 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
0 0 m
.00481 .00773 L
.00758 .01545 L
.00806 .02318 L
.00884 .0309 L
.00902 .03863 L
.01302 .03863 L
.01559 .04635 L
.01569 .04635 L
.01603 .03863 L
.0163 .04635 L
.01643 .05408 L
.01689 .0618 L
.02046 .06953 L
.02092 .06953 L
.02171 .06953 L
.02259 .06953 L
.02283 .07725 L
.02328 .08498 L
.02596 .08498 L
.02607 .08498 L
.02615 .09271 L
.0269 .09271 L
.02768 .09271 L
.02847 .10043 L
.03047 .10043 L
.03068 .10043 L
.03113 .10816 L
.03156 .10816 L
.03188 .11588 L
.0323 .11588 L
.0323 .11588 L
.03285 .10816 L
.03299 .11588 L
.03463 .11588 L
.03586 .12361 L
.03674 .13133 L
.03756 .12361 L
.03837 .11588 L
.03843 .11588 L
.03876 .12361 L
.03921 .12361 L
.04051 .12361 L
.04168 .13133 L
.04275 .13906 L
.04284 .14678 L
.04373 .14678 L
.04459 .14678 L
.04523 .14678 L
.04537 .14678 L
Mistroke
.04561 .14678 L
.04566 .15451 L
.04568 .15451 L
.04626 .15451 L
.0483 .15451 L
.04857 .15451 L
.04874 .15451 L
.04939 .16223 L
.05049 .16223 L
.05058 .16223 L
.05078 .16996 L
.05172 .16223 L
.05209 .16223 L
.05277 .16223 L
.05294 .16223 L
.05305 .15451 L
.05306 .15451 L
.05378 .16223 L
.05429 .16223 L
.0551 .16223 L
.0573 .16223 L
.05767 .16223 L
.05831 .16223 L
.0596 .16223 L
.0598 .15451 L
.06169 .16223 L
.06223 .16223 L
.0628 .16223 L
.06349 .16223 L
.06423 .16996 L
.06483 .16996 L
.06495 .16996 L
.06496 .17768 L
.06513 .17768 L
.06524 .18541 L
.06638 .17768 L
.0668 .17768 L
.06734 .18541 L
.06778 .18541 L
.06784 .18541 L
.06812 .19314 L
.06841 .19314 L
.06858 .19314 L
.06877 .19314 L
.06888 .18541 L
.06899 .18541 L
.06947 .18541 L
.07012 .19314 L
.07021 .19314 L
.07026 .18541 L
Mistroke
.07063 .19314 L
.07081 .19314 L
.07086 .18541 L
.0716 .18541 L
.07183 .18541 L
.07254 .17768 L
.07271 .18541 L
.07517 .18541 L
.07528 .18541 L
.07531 .19314 L
.07565 .19314 L
.07705 .19314 L
.07734 .19314 L
.07789 .19314 L
.07818 .19314 L
.07821 .19314 L
.07889 .19314 L
.07904 .20086 L
.08003 .19314 L
.08031 .20086 L
.0809 .20859 L
.08091 .20859 L
.08134 .20859 L
.08203 .20859 L
.0824 .20859 L
.0828 .20859 L
.08305 .20859 L
.08368 .20859 L
.08374 .20859 L
.08415 .19314 L
.08431 .19314 L
.08462 .19314 L
.08515 .18541 L
.08536 .18541 L
.08575 .18541 L
.08772 .19314 L
.08893 .19314 L
.08994 .19314 L
.09103 .19314 L
.09249 .19314 L
.09278 .19314 L
.09286 .19314 L
.0945 .19314 L
.09498 .19314 L
.09534 .19314 L
.09587 .19314 L
.09648 .19314 L
.09717 .19314 L
.09787 .19314 L
.09806 .19314 L
Mistroke
.09808 .18541 L
.09822 .18541 L
.09843 .18541 L
.09849 .18541 L
.09924 .19314 L
.09976 .19314 L
.09984 .18541 L
.09991 .17768 L
.10119 .17768 L
.10166 .18541 L
.10192 .18541 L
.10301 .19314 L
.10332 .20086 L
.10348 .20086 L
.10379 .18541 L
.10543 .18541 L
.11 .18541 L
.11019 .17768 L
.11164 .17768 L
.11195 .18541 L
.11209 .19314 L
.11216 .20086 L
.11249 .18541 L
.11273 .18541 L
.11295 .17768 L
.11372 .18541 L
.11516 .19314 L
.1153 .19314 L
.11592 .20086 L
.11664 .20086 L
.11711 .19314 L
.11712 .19314 L
.1172 .18541 L
.11725 .19314 L
.11789 .19314 L
.11805 .20086 L
.11831 .20086 L
.11861 .20086 L
.12009 .20859 L
.12028 .20086 L
.12074 .20859 L
.12101 .20859 L
.12114 .20859 L
.12117 .20859 L
.12247 .21631 L
.12258 .21631 L
.12271 .21631 L
.12345 .21631 L
.12378 .21631 L
.12401 .21631 L
Mistroke
.12417 .17768 L
.1245 .18541 L
.12492 .16996 L
.12503 .16996 L
.1253 .17768 L
.12562 .18541 L
.12563 .18541 L
.12609 .18541 L
.12637 .18541 L
.12846 .19314 L
.12899 .19314 L
.12969 .19314 L
.1299 .19314 L
.13105 .19314 L
.13115 .17768 L
.13149 .18541 L
.13269 .18541 L
.13274 .18541 L
.13327 .19314 L
.13379 .20086 L
.13481 .20086 L
.13485 .20086 L
.13509 .20086 L
.13616 .20086 L
.13625 .20086 L
.1366 .20859 L
.13662 .20859 L
.13672 .20859 L
.13693 .20859 L
.13693 .20859 L
.13811 .20859 L
.13853 .20859 L
.14054 .20859 L
.14097 .20859 L
.14116 .21631 L
.14174 .19314 L
.14247 .19314 L
.14346 .19314 L
.1439 .19314 L
.144 .19314 L
.14416 .19314 L
.14464 .19314 L
.14485 .19314 L
.14495 .19314 L
.1452 .17768 L
.14528 .17768 L
.14585 .17768 L
.14608 .17768 L
.14669 .17768 L
.14825 .17768 L
Mistroke
.14827 .17768 L
.14829 .18541 L
.14834 .18541 L
.14836 .18541 L
.14837 .17768 L
.14892 .18541 L
.14949 .18541 L
.14968 .18541 L
.15022 .17768 L
.15046 .17768 L
.15134 .17768 L
.15146 .17768 L
.15286 .17768 L
.15307 .17768 L
.1543 .17768 L
.15445 .17768 L
.15606 .17768 L
.15731 .16223 L
.15747 .16223 L
.15768 .16996 L
.15816 .17768 L
.15832 .17768 L
.15879 .17768 L
.15967 .17768 L
.1606 .17768 L
.16159 .18541 L
.16208 .18541 L
.16241 .19314 L
.16295 .20086 L
.16369 .20086 L
.16373 .20086 L
.16435 .20086 L
.16525 .20086 L
.16583 .20859 L
.16642 .20859 L
.16655 .20859 L
.16727 .20859 L
.16738 .20859 L
.16751 .20859 L
.16765 .20859 L
.16773 .20859 L
.16849 .21631 L
.16887 .21631 L
.16892 .21631 L
.16964 .22404 L
.16966 .22404 L
.16978 .22404 L
.16988 .22404 L
.17038 .23176 L
.17085 .23949 L
Mistroke
.1709 .23949 L
.17126 .23949 L
.17134 .23949 L
.17234 .23949 L
.17448 .24721 L
.17449 .24721 L
.17498 .24721 L
.17545 .25494 L
.17564 .25494 L
.17606 .25494 L
.17643 .25494 L
.17652 .25494 L
.17676 .25494 L
.17777 .25494 L
.178 .26266 L
.17816 .26266 L
.1783 .27039 L
.17833 .27039 L
.17865 .27039 L
.17902 .27039 L
.17919 .27812 L
.1793 .27812 L
.17949 .27812 L
.17953 .27812 L
.18007 .27812 L
.18028 .27812 L
.18092 .27812 L
.18149 .27812 L
.1815 .28584 L
.18164 .28584 L
.18233 .28584 L
.18233 .28584 L
.18245 .28584 L
.18257 .28584 L
.18313 .28584 L
.18395 .28584 L
.18405 .28584 L
.18419 .28584 L
.18426 .28584 L
.1844 .28584 L
.18446 .28584 L
.18485 .28584 L
.18486 .28584 L
.18515 .28584 L
.18538 .29357 L
.18603 .29357 L
.18659 .29357 L
.18692 .29357 L
.18721 .30129 L
.18762 .30902 L
Mistroke
.18762 .30902 L
.18771 .30902 L
.18876 .31674 L
.1891 .31674 L
.18925 .31674 L
.18944 .31674 L
.18952 .31674 L
.18957 .31674 L
.18965 .31674 L
.18983 .31674 L
.18994 .31674 L
.19016 .31674 L
.19047 .31674 L
.19069 .32447 L
.19086 .32447 L
.19127 .32447 L
.19247 .32447 L
.19311 .32447 L
.19392 .32447 L
.19402 .32447 L
.19422 .32447 L
.19432 .32447 L
.19438 .32447 L
.19457 .31674 L
.19476 .31674 L
.19524 .31674 L
.19607 .31674 L
.19619 .31674 L
.19626 .31674 L
.19693 .31674 L
.19742 .31674 L
.1976 .32447 L
.19766 .33219 L
.19834 .30902 L
.19852 .30902 L
.19869 .30902 L
.19936 .30902 L
.1994 .31674 L
.20054 .31674 L
.20058 .31674 L
.2006 .31674 L
.20063 .31674 L
.20104 .31674 L
.2022 .31674 L
.20269 .31674 L
.20298 .31674 L
.20312 .31674 L
.20337 .31674 L
.20376 .31674 L
.20388 .31674 L
Mistroke
.20433 .30902 L
.20462 .30902 L
.20498 .31674 L
.20503 .31674 L
.20526 .31674 L
.20603 .31674 L
.20627 .32447 L
.20699 .30902 L
.20714 .31674 L
.20731 .31674 L
.20799 .31674 L
.20886 .31674 L
.20898 .31674 L
.20899 .32447 L
.20919 .32447 L
.20932 .33219 L
.20961 .33219 L
.21058 .33219 L
.21079 .33219 L
.2113 .33219 L
.21147 .33219 L
.21152 .33219 L
.21203 .32447 L
.21203 .33219 L
.21219 .33219 L
.2123 .33992 L
.21246 .33992 L
.21254 .33992 L
.21311 .34764 L
.21339 .33992 L
.21349 .34764 L
.21438 .34764 L
.21482 .34764 L
.21501 .33219 L
.2151 .33219 L
.21614 .33219 L
.21649 .33992 L
.21688 .34764 L
.21693 .34764 L
.21755 .34764 L
.21834 .34764 L
.21835 .34764 L
.21839 .34764 L
.21853 .34764 L
.21854 .34764 L
.21879 .32447 L
.21889 .33219 L
.21935 .33219 L
.21941 .31674 L
.21941 .31674 L
Mistroke
.21977 .32447 L
.21988 .32447 L
.22038 .32447 L
.22105 .32447 L
.22106 .32447 L
.22108 .32447 L
.22175 .32447 L
.22217 .32447 L
.22226 .33219 L
.22278 .33219 L
.22306 .33219 L
.22364 .33992 L
.22397 .33992 L
.22399 .34764 L
.22409 .34764 L
.22446 .34764 L
.225 .34764 L
.22533 .34764 L
.22541 .34764 L
.2255 .34764 L
.22582 .33992 L
.22595 .33992 L
.22619 .33219 L
.22646 .33219 L
.22744 .33219 L
.22762 .33219 L
.22801 .33219 L
.22846 .33992 L
.22911 .33992 L
.22911 .30902 L
.22916 .30902 L
.22918 .31674 L
.2304 .31674 L
.23058 .31674 L
.23069 .32447 L
.23093 .32447 L
.23099 .32447 L
.23108 .32447 L
.2315 .32447 L
.23171 .32447 L
.23193 .32447 L
.23203 .32447 L
.23254 .32447 L
.23256 .33219 L
.23272 .33219 L
.23272 .33219 L
.23297 .33992 L
.23315 .33992 L
.23318 .34764 L
.23401 .34764 L
Mistroke
.2341 .34764 L
.23421 .34764 L
.23489 .34764 L
.23501 .33992 L
.23549 .34764 L
.23598 .34764 L
.23599 .34764 L
.23601 .33992 L
.23647 .33992 L
.23654 .33992 L
.23664 .33992 L
.23669 .34764 L
.23672 .34764 L
.23675 .34764 L
.23812 .34764 L
.23826 .34764 L
.23834 .34764 L
.23856 .33992 L
.23872 .33992 L
.23915 .33992 L
.23919 .33992 L
.23933 .33992 L
.24022 .33992 L
.24038 .33992 L
.24044 .33992 L
.24058 .34764 L
.24169 .34764 L
.24171 .33992 L
.24193 .33992 L
.24209 .33992 L
.24216 .33992 L
.24249 .33992 L
.24272 .33992 L
.24282 .33992 L
.24343 .33992 L
.2435 .33992 L
.24405 .33992 L
.24415 .33992 L
.2443 .33992 L
.24458 .33992 L
.24461 .33992 L
.24467 .33992 L
.24468 .34764 L
.24482 .33992 L
.24492 .33992 L
.24512 .33992 L
.24536 .33992 L
.24592 .33992 L
.24606 .33992 L
.24692 .34764 L
Mistroke
.24694 .34764 L
.24745 .34764 L
.2475 .35537 L
.24808 .36309 L
.24813 .36309 L
.2482 .35537 L
.24828 .35537 L
.24845 .35537 L
.24855 .35537 L
.24881 .35537 L
.24902 .35537 L
.2496 .35537 L
.25102 .33992 L
.25232 .34764 L
.25233 .34764 L
.25237 .34764 L
.25249 .34764 L
.25251 .35537 L
.2533 .36309 L
.25379 .36309 L
.25419 .36309 L
.25426 .36309 L
.25443 .36309 L
.25478 .35537 L
.25516 .35537 L
.25527 .35537 L
.25541 .35537 L
.25621 .36309 L
.25655 .37082 L
.25675 .37082 L
.25693 .36309 L
.25718 .37082 L
.25731 .37082 L
.25747 .37082 L
.25756 .37082 L
.25785 .37082 L
.25787 .37082 L
.25831 .37082 L
.25906 .37082 L
.25918 .37082 L
.2595 .36309 L
.25954 .36309 L
.25972 .36309 L
.25996 .36309 L
.26237 .36309 L
.26276 .36309 L
.26283 .36309 L
.26383 .37082 L
.2645 .37082 L
.26451 .37082 L
Mistroke
.26494 .37855 L
.26505 .37855 L
.26562 .37855 L
.26645 .38627 L
.26666 .38627 L
.26683 .38627 L
.26734 .38627 L
.26772 .394 L
.26782 .394 L
.26786 .394 L
.26895 .38627 L
.26915 .38627 L
.26925 .38627 L
.26952 .394 L
.26952 .394 L
.26956 .38627 L
.26997 .38627 L
.27003 .394 L
.27035 .394 L
.27126 .394 L
.27181 .40172 L
.27217 .40945 L
.27218 .40945 L
.27234 .40945 L
.27244 .40945 L
.27277 .41717 L
.27299 .41717 L
.27321 .41717 L
.27322 .41717 L
.2747 .41717 L
.27497 .4249 L
.275 .4249 L
.27505 .4249 L
.27597 .4249 L
.27607 .4249 L
.27614 .4249 L
.27618 .43262 L
.27685 .43262 L
.27687 .43262 L
.27726 .40945 L
.27784 .37855 L
.27842 .37855 L
.2785 .38627 L
.27866 .38627 L
.27933 .38627 L
.27953 .37855 L
.27962 .37855 L
.27969 .37082 L
.28057 .37082 L
.28119 .37082 L
Mistroke
.28206 .37082 L
.28262 .35537 L
.28268 .34764 L
.28383 .34764 L
.28402 .34764 L
.28466 .34764 L
.28473 .34764 L
.28509 .34764 L
.28512 .34764 L
.28575 .34764 L
.28577 .34764 L
.28601 .34764 L
.28616 .34764 L
.28632 .34764 L
.28657 .35537 L
.28704 .35537 L
.28747 .35537 L
.28786 .36309 L
.28788 .36309 L
.28817 .36309 L
.28853 .36309 L
.28929 .37082 L
.28998 .37082 L
.29007 .37082 L
.29067 .37855 L
.29079 .37855 L
.29098 .36309 L
.29185 .36309 L
.29216 .36309 L
.29258 .37082 L
.29343 .37855 L
.29437 .37855 L
.29461 .37855 L
.29463 .37855 L
.29474 .38627 L
.29496 .394 L
.29547 .394 L
.29561 .394 L
.29661 .40172 L
.29663 .40172 L
.29726 .40172 L
.29764 .40172 L
.29773 .40172 L
.29847 .40172 L
.29917 .40945 L
.29944 .40945 L
.29946 .40945 L
.29961 .41717 L
.30002 .4249 L
.30015 .43262 L
Mistroke
.30023 .43262 L
.30026 .43262 L
.30034 .43262 L
.30047 .43262 L
.30047 .43262 L
.30101 .43262 L
.30117 .43262 L
.30207 .44035 L
.30234 .44035 L
.30234 .4249 L
.30235 .4249 L
.30304 .4249 L
.30332 .43262 L
.3035 .43262 L
.30446 .43262 L
.305 .43262 L
.30507 .44035 L
.30509 .44035 L
.30556 .44035 L
.30562 .44035 L
.30582 .44807 L
.30617 .44807 L
.3066 .44807 L
.30671 .44807 L
.30677 .44807 L
.30681 .44807 L
.30782 .44807 L
.30782 .44807 L
.3086 .4558 L
.309 .4558 L
.30956 .4558 L
.30979 .4558 L
.31035 .4558 L
.31044 .4558 L
.3105 .46353 L
.3114 .47125 L
.3115 .47898 L
.31153 .47898 L
.31211 .47898 L
.31271 .47898 L
.31292 .47898 L
.31359 .47898 L
.31369 .47898 L
.31377 .47898 L
.31386 .47898 L
.31414 .4867 L
.31423 .4867 L
.31478 .4867 L
.31495 .49443 L
.31518 .49443 L
Mistroke
.31518 .49443 L
.31536 .49443 L
.31553 .49443 L
.31605 .50215 L
.31636 .50215 L
.31652 .50215 L
.31659 .50215 L
.3166 .50215 L
.31673 .50215 L
.31674 .50215 L
.31703 .50215 L
.3172 .50215 L
.31755 .50988 L
.31772 .50988 L
.3178 .50988 L
.31813 .50988 L
.31813 .50988 L
.31833 .50988 L
.31851 .50988 L
.31851 .50988 L
.31851 .50988 L
.3188 .50988 L
.31882 .50988 L
.31905 .50988 L
.31908 .50988 L
.31943 .50988 L
.31966 .50988 L
.31983 .50988 L
.32042 .50988 L
.32113 .50988 L
.32116 .50988 L
.3213 .50988 L
.3214 .50988 L
.32145 .50988 L
.32169 .50988 L
.32188 .50988 L
.322 .50988 L
.32221 .50988 L
.32236 .50988 L
.32246 .50988 L
.32271 .50988 L
.32283 .50988 L
.32302 .5176 L
.32306 .5176 L
.32357 .5176 L
.32443 .5176 L
.32453 .5176 L
.32502 .5176 L
.3252 .5176 L
.32593 .5176 L
Mistroke
.32625 .5176 L
.32664 .5176 L
.32675 .5176 L
.32687 .50988 L
.32747 .50988 L
.32811 .4867 L
.32823 .4867 L
.32859 .4867 L
.32874 .4867 L
.32874 .4867 L
.32886 .4867 L
.32898 .4867 L
.329 .4867 L
.32918 .4867 L
.32954 .4867 L
.32966 .4867 L
.3298 .47898 L
.33009 .47898 L
.33038 .47898 L
.33066 .4558 L
.33069 .4558 L
.33076 .4558 L
.33079 .44807 L
.33082 .44807 L
.33206 .44807 L
.33212 .44035 L
.33239 .4249 L
.33248 .4249 L
.33285 .43262 L
.3329 .44035 L
.3335 .44035 L
.33365 .44807 L
.33374 .44807 L
.3338 .44807 L
.33395 .44807 L
.33409 .44807 L
.33443 .44807 L
.33566 .4558 L
.33576 .46353 L
.33619 .47125 L
.33636 .47125 L
.33657 .47125 L
.33689 .47125 L
.3376 .46353 L
.33776 .46353 L
.33777 .46353 L
.33784 .4558 L
.33807 .4558 L
.33811 .4558 L
.33829 .4558 L
Mistroke
.33864 .4558 L
.33957 .4558 L
.34 .44035 L
.34029 .44035 L
.3404 .4249 L
.34111 .4249 L
.3413 .43262 L
.34162 .44035 L
.34331 .44807 L
.34346 .44807 L
.34435 .41717 L
.34494 .41717 L
.34511 .4249 L
.34514 .4249 L
.34529 .4249 L
.34532 .4249 L
.34572 .4249 L
.34616 .4249 L
.34634 .4249 L
.34657 .4249 L
.34662 .4249 L
.34712 .4249 L
.34735 .4249 L
.34738 .4249 L
.34767 .4249 L
.34786 .4249 L
.34816 .40945 L
.34876 .41717 L
.34955 .41717 L
.34987 .41717 L
.34988 .41717 L
.35084 .41717 L
.35154 .41717 L
.35236 .41717 L
.35292 .41717 L
.35332 .40945 L
.35371 .40945 L
.35377 .40945 L
.3538 .37855 L
.35444 .37855 L
.35449 .37855 L
.35609 .37855 L
.35612 .37855 L
.35615 .37855 L
.35694 .37855 L
.35717 .37855 L
.35732 .37855 L
.35778 .37855 L
.35814 .37855 L
.35847 .37082 L
Mistroke
.35932 .36309 L
.35935 .35537 L
.35936 .35537 L
.35995 .35537 L
.35998 .35537 L
.36061 .35537 L
.36074 .35537 L
.36257 .36309 L
.36276 .35537 L
.36298 .35537 L
.36307 .35537 L
.36392 .35537 L
.36436 .36309 L
.36437 .36309 L
.36505 .36309 L
.36521 .33992 L
.36565 .32447 L
.3658 .32447 L
.36595 .31674 L
.36647 .30902 L
.36709 .29357 L
.36742 .30129 L
.36744 .30129 L
.36799 .30902 L
.36819 .30902 L
.36829 .31674 L
.36836 .31674 L
.36884 .31674 L
.37055 .31674 L
.37056 .31674 L
.37156 .31674 L
.37198 .31674 L
.37384 .30129 L
.37391 .30129 L
.37464 .30902 L
.37566 .30902 L
.37585 .30129 L
.37607 .30902 L
.37627 .30902 L
.3765 .30902 L
.37726 .31674 L
.3782 .31674 L
.37879 .31674 L
.37898 .31674 L
.37962 .32447 L
.38138 .33219 L
.38175 .33992 L
.38195 .34764 L
.38215 .35537 L
.3827 .36309 L
Mistroke
.3838 .36309 L
.38386 .37082 L
.38437 .37082 L
.3848 .37082 L
.385 .37855 L
.3852 .37855 L
.38526 .37855 L
.38529 .37855 L
.38537 .37855 L
.38579 .37855 L
.38634 .37855 L
.38655 .37855 L
.38672 .37855 L
.38721 .37855 L
.38721 .37855 L
.38727 .38627 L
.3873 .38627 L
.38734 .394 L
.38747 .394 L
.38762 .394 L
.38814 .40172 L
.38837 .40172 L
.38893 .40172 L
.38909 .40172 L
.38913 .40172 L
.38935 .40945 L
.38958 .40945 L
.38996 .35537 L
.39032 .35537 L
.39056 .36309 L
.39084 .37082 L
.39093 .37855 L
.39118 .37082 L
.39121 .37082 L
.39133 .36309 L
.39185 .36309 L
.39193 .36309 L
.39197 .37082 L
.39204 .37082 L
.39272 .37082 L
.39306 .37855 L
.39313 .37855 L
.39411 .37855 L
.3942 .37855 L
.39433 .37855 L
.39449 .37855 L
.39482 .37855 L
.39483 .37855 L
.39519 .37855 L
.39563 .37855 L
Mistroke
.39571 .37855 L
.39584 .37855 L
.39722 .37855 L
.39743 .38627 L
.39773 .38627 L
.3984 .38627 L
.3986 .38627 L
.39866 .38627 L
.39867 .38627 L
.39884 .394 L
.39934 .40172 L
.39948 .40172 L
.3996 .40172 L
.39996 .40172 L
.40005 .40172 L
.40013 .40172 L
.40068 .40172 L
.40079 .40172 L
.40163 .40945 L
.40185 .40945 L
.40257 .40945 L
.40322 .40945 L
.40342 .40945 L
.40359 .41717 L
.40387 .4249 L
.40388 .4249 L
.40414 .43262 L
.40415 .43262 L
.40419 .43262 L
.40454 .43262 L
.40488 .43262 L
.40522 .43262 L
.40527 .43262 L
.40574 .43262 L
.40631 .44035 L
.40652 .44035 L
.40682 .43262 L
.40692 .43262 L
.40716 .4249 L
.40725 .4249 L
.40782 .4249 L
.40785 .4249 L
.40864 .4249 L
.40891 .4249 L
.40956 .4249 L
.41025 .4249 L
.41027 .4249 L
.41044 .4249 L
.41045 .43262 L
.41072 .43262 L
Mistroke
.41095 .43262 L
.4112 .43262 L
.41136 .44035 L
.41137 .44035 L
.4117 .44035 L
.41203 .44035 L
.41314 .44035 L
.41343 .40945 L
.41362 .40945 L
.41385 .40945 L
.41396 .40945 L
.41447 .37855 L
.41462 .37082 L
.41463 .37082 L
.41468 .37082 L
.41492 .37082 L
.41505 .37082 L
.41551 .35537 L
.41618 .35537 L
.41686 .35537 L
.41719 .35537 L
.41765 .32447 L
.41924 .32447 L
.41943 .33219 L
.41961 .33219 L
.41975 .31674 L
.41988 .31674 L
.4205 .32447 L
.42085 .32447 L
.42086 .32447 L
.42151 .33219 L
.42161 .33992 L
.4223 .32447 L
.42344 .32447 L
.42429 .32447 L
.4246 .31674 L
.4249 .31674 L
.425 .31674 L
.42566 .31674 L
.42588 .31674 L
.42597 .31674 L
.42616 .31674 L
.42691 .31674 L
.42795 .31674 L
.42842 .31674 L
.42893 .32447 L
.42935 .32447 L
.42959 .31674 L
.42989 .31674 L
.43004 .31674 L
Mistroke
.43014 .31674 L
.4302 .31674 L
.43022 .31674 L
.43074 .32447 L
.43082 .31674 L
.43129 .32447 L
.43145 .32447 L
.43145 .31674 L
.43179 .31674 L
.43182 .31674 L
.43216 .31674 L
.43217 .32447 L
.43236 .32447 L
.43248 .32447 L
.43286 .32447 L
.43286 .31674 L
.43333 .30902 L
.43337 .30902 L
.4347 .30902 L
.4352 .31674 L
.43586 .32447 L
.43592 .32447 L
.43798 .32447 L
.43801 .32447 L
.43803 .32447 L
.43826 .29357 L
.43827 .29357 L
.43828 .29357 L
.43835 .29357 L
.43849 .29357 L
.43853 .29357 L
.43888 .29357 L
.43907 .29357 L
.44021 .29357 L
.44022 .30129 L
.44116 .30902 L
.44183 .31674 L
.4423 .31674 L
.44234 .31674 L
.44285 .32447 L
.44303 .33219 L
.44355 .33219 L
.44384 .33219 L
.44422 .33219 L
.44445 .33219 L
.44449 .33219 L
.44467 .33992 L
.44485 .33992 L
.44548 .33992 L
.44687 .33992 L
Mistroke
.44699 .33992 L
.44722 .33992 L
.44753 .33992 L
.44757 .33992 L
.4476 .33992 L
.4477 .33219 L
.44789 .33219 L
.44803 .33992 L
.44876 .34764 L
.44886 .34764 L
.44902 .34764 L
.44903 .34764 L
.44938 .34764 L
.45098 .34764 L
.45108 .34764 L
.45119 .33992 L
.45133 .33219 L
.45166 .33219 L
.45311 .33219 L
.45507 .32447 L
.45519 .32447 L
.45528 .33219 L
.4554 .33219 L
.45567 .33219 L
.45621 .33992 L
.45651 .33992 L
.45683 .34764 L
.45733 .34764 L
.45766 .34764 L
.45788 .34764 L
.45801 .34764 L
.45834 .34764 L
.45846 .34764 L
.4591 .35537 L
.45936 .35537 L
.45948 .35537 L
.45952 .36309 L
.45969 .37082 L
.45985 .37855 L
.45991 .37855 L
.46 .37855 L
.46006 .37855 L
.46007 .37855 L
.46025 .37855 L
.46034 .37855 L
.46079 .37855 L
.46091 .37855 L
.46133 .37855 L
.46196 .37855 L
.46204 .37855 L
Mistroke
.46212 .37855 L
.46218 .38627 L
.46221 .37855 L
.46227 .37855 L
.46296 .37855 L
.46361 .37855 L
.46395 .37855 L
.46461 .37855 L
.46461 .37855 L
.46476 .37082 L
.4651 .37082 L
.4651 .37082 L
.46521 .37082 L
.46566 .37855 L
.46568 .37855 L
.46624 .37855 L
.46715 .37855 L
.46742 .37855 L
.46818 .37855 L
.4683 .37855 L
.4683 .38627 L
.46837 .38627 L
.46868 .38627 L
.46895 .38627 L
.46898 .38627 L
.46962 .38627 L
.47018 .38627 L
.47029 .38627 L
.47053 .38627 L
.47199 .37855 L
.47249 .37855 L
.47257 .37855 L
.47263 .37082 L
.473 .37082 L
.47304 .37082 L
.47316 .37082 L
.47359 .37082 L
.47369 .35537 L
.47474 .36309 L
.47485 .36309 L
.47503 .36309 L
.47554 .36309 L
.47558 .36309 L
.47574 .37082 L
.47618 .37082 L
.47683 .37082 L
.47686 .37082 L
.47689 .37082 L
.47701 .37082 L
.47711 .37082 L
Mistroke
.47741 .37855 L
.47763 .37855 L
.47785 .37855 L
.478 .37855 L
.47857 .37855 L
.47859 .37855 L
.47869 .37855 L
.48056 .37855 L
.48069 .37082 L
.48079 .37082 L
.4811 .37855 L
.48147 .37855 L
.48159 .37855 L
.48255 .37855 L
.48274 .38627 L
.48275 .38627 L
.48281 .38627 L
.48344 .394 L
.48347 .394 L
.48373 .38627 L
.48384 .394 L
.4839 .38627 L
.48425 .394 L
.48435 .40172 L
.48501 .40172 L
.48515 .40172 L
.4859 .40945 L
.486 .41717 L
.48621 .4249 L
.48622 .4249 L
.48647 .41717 L
.48658 .4249 L
.48707 .4249 L
.48752 .41717 L
.48758 .41717 L
.48764 .41717 L
.48823 .41717 L
.48831 .41717 L
.48847 .41717 L
.48879 .41717 L
.48934 .41717 L
.48959 .41717 L
.48986 .41717 L
.48998 .4249 L
.49117 .4249 L
.49128 .4249 L
.492 .37855 L
.49206 .38627 L
.49219 .35537 L
.49259 .35537 L
Mistroke
.49314 .36309 L
.49323 .35537 L
.49409 .35537 L
.49412 .35537 L
.49417 .35537 L
.49508 .35537 L
.49532 .35537 L
.49566 .35537 L
.49569 .35537 L
.49607 .35537 L
.4966 .35537 L
.49665 .35537 L
.49742 .35537 L
.49791 .35537 L
.49826 .35537 L
.4984 .35537 L
.49857 .36309 L
.49869 .36309 L
.49965 .36309 L
.49967 .37082 L
.49972 .37082 L
.50016 .37082 L
.5003 .37855 L
.50106 .37855 L
.50149 .37082 L
.50159 .37082 L
.50184 .37082 L
.50223 .37082 L
.50281 .37082 L
.50325 .37082 L
.50443 .37082 L
.50459 .37082 L
.50473 .37082 L
.50494 .37082 L
.50498 .34764 L
.50503 .34764 L
.50508 .33992 L
.50526 .33992 L
.50531 .33992 L
.5054 .33992 L
.50565 .33992 L
.50607 .33992 L
.50621 .33992 L
.50647 .33992 L
.5068 .33992 L
.50708 .33992 L
.5072 .33992 L
.50721 .33992 L
.50768 .33992 L
.508 .33992 L
Mistroke
.50864 .33992 L
.5087 .33992 L
.50872 .33992 L
.50887 .33992 L
.50968 .33992 L
.50975 .33992 L
.50978 .34764 L
.50986 .34764 L
.51058 .34764 L
.51088 .34764 L
.51101 .34764 L
.51103 .34764 L
.51111 .35537 L
.51112 .36309 L
.51115 .36309 L
.51265 .36309 L
.51307 .36309 L
.51323 .37082 L
.51328 .37082 L
.51341 .37082 L
.5136 .37082 L
.51393 .37082 L
.51416 .36309 L
.51449 .36309 L
.51459 .36309 L
.51529 .36309 L
.51558 .36309 L
.5157 .36309 L
.51617 .35537 L
.51636 .35537 L
.51669 .36309 L
.51688 .36309 L
.51723 .36309 L
.51723 .36309 L
.51745 .37082 L
.51776 .37082 L
.51789 .37082 L
.51802 .37082 L
.51878 .37082 L
.51912 .37082 L
.5192 .37082 L
.51951 .37082 L
.5196 .37855 L
.51961 .37855 L
.5201 .38627 L
.52033 .37082 L
.52034 .37082 L
.52038 .37082 L
.52041 .37082 L
.52053 .37855 L
Mistroke
.52075 .37082 L
.52124 .37082 L
.52189 .37082 L
.52249 .37082 L
.52353 .37855 L
.52356 .38627 L
.52376 .37855 L
.52441 .37855 L
.52446 .37855 L
.52479 .37082 L
.52533 .37082 L
.52541 .37082 L
.52568 .37082 L
.52573 .37082 L
.52592 .37855 L
.52602 .37855 L
.52606 .37855 L
.52621 .37855 L
.52621 .36309 L
.52661 .36309 L
.52698 .37082 L
.52748 .37082 L
.52768 .37855 L
.52874 .38627 L
.52875 .38627 L
.52895 .38627 L
.52902 .394 L
.5299 .394 L
.52996 .394 L
.53007 .394 L
.53038 .394 L
.53057 .394 L
.53062 .394 L
.53066 .394 L
.53113 .394 L
.53125 .394 L
.53144 .394 L
.53184 .394 L
.53198 .394 L
.5324 .394 L
.53241 .40172 L
.53283 .40172 L
.53287 .40172 L
.53353 .40172 L
.53398 .40945 L
.5346 .40945 L
.53525 .40945 L
.5353 .40945 L
.53557 .40945 L
.53583 .40945 L
Mistroke
.53638 .40945 L
.53639 .40945 L
.53659 .40945 L
.5368 .40945 L
.53705 .40945 L
.53738 .40945 L
.53768 .40945 L
.53782 .40945 L
.53899 .41717 L
.53937 .41717 L
.5394 .41717 L
.53945 .41717 L
.53961 .41717 L
.53968 .4249 L
.53994 .41717 L
.54033 .41717 L
.54033 .41717 L
.54048 .41717 L
.54049 .40945 L
.54058 .41717 L
.5407 .41717 L
.54075 .41717 L
.54088 .41717 L
.54098 .41717 L
.54132 .41717 L
.54163 .40945 L
.5419 .40945 L
.54214 .41717 L
.54216 .41717 L
.54284 .41717 L
.54285 .41717 L
.54311 .4249 L
.5434 .4249 L
.54361 .43262 L
.54371 .43262 L
.54399 .43262 L
.54429 .43262 L
.54431 .44035 L
.54448 .44035 L
.54478 .44035 L
.54514 .44035 L
.54538 .44035 L
.54594 .44035 L
.54594 .44035 L
.54643 .44035 L
.5465 .44035 L
.54656 .44035 L
.54723 .44035 L
.54729 .44035 L
.54743 .44807 L
Mistroke
.54851 .44807 L
.5488 .44807 L
.54909 .44807 L
.54923 .44807 L
.54935 .4558 L
.54947 .4558 L
.54958 .4558 L
.55014 .46353 L
.55025 .44807 L
.55059 .44807 L
.5511 .44807 L
.55179 .44807 L
.5521 .44807 L
.55217 .44807 L
.55315 .40172 L
.55327 .40172 L
.55422 .40172 L
.55436 .40945 L
.55524 .40945 L
.55532 .40945 L
.55533 .40945 L
.55545 .40945 L
.55632 .41717 L
.55653 .41717 L
.5568 .41717 L
.55738 .41717 L
.55762 .41717 L
.5578 .41717 L
.55823 .41717 L
.55927 .41717 L
.55943 .41717 L
.55956 .41717 L
.55968 .4249 L
.55993 .43262 L
.56014 .43262 L
.56032 .43262 L
.56034 .43262 L
.5605 .43262 L
.56076 .4249 L
.56084 .36309 L
.56084 .36309 L
.56098 .33992 L
.56136 .33992 L
.56139 .34764 L
.56157 .34764 L
.5616 .34764 L
.56192 .34764 L
.56225 .34764 L
.56302 .34764 L
.5636 .34764 L
Mistroke
.56399 .34764 L
.56404 .34764 L
.56422 .34764 L
.56442 .34764 L
.56473 .34764 L
.56494 .34764 L
.56548 .35537 L
.56553 .36309 L
.56667 .36309 L
.5668 .36309 L
.56701 .36309 L
.56701 .35537 L
.5672 .35537 L
.56778 .35537 L
.56785 .36309 L
.56802 .36309 L
.56837 .36309 L
.5691 .36309 L
.56913 .36309 L
.56923 .36309 L
.5693 .37082 L
.57012 .37082 L
.57036 .37082 L
.57036 .37855 L
.5708 .38627 L
.5712 .38627 L
.57171 .394 L
.57207 .394 L
.57256 .394 L
.57259 .394 L
.57268 .394 L
.57273 .40172 L
.57294 .40172 L
.57314 .40172 L
.57354 .40945 L
.5736 .40945 L
.57363 .40945 L
.57453 .41717 L
.57459 .41717 L
.57521 .41717 L
.57579 .41717 L
.5759 .41717 L
.57596 .41717 L
.57633 .41717 L
.57641 .41717 L
.57648 .4249 L
.57684 .4249 L
.57731 .4249 L
.5774 .4249 L
.57757 .4249 L
Mistroke
.57769 .4249 L
.57795 .4249 L
.57868 .4249 L
.5794 .4249 L
.57963 .43262 L
.57983 .43262 L
.57985 .43262 L
.58005 .43262 L
.58012 .44035 L
.58027 .43262 L
.58077 .43262 L
.58085 .43262 L
.58121 .43262 L
.58139 .43262 L
.58141 .43262 L
.5815 .44035 L
.58153 .44035 L
.58166 .44035 L
.58167 .44035 L
.58176 .44035 L
.58224 .44035 L
.58241 .44035 L
.58251 .44035 L
.58252 .44807 L
.58269 .44807 L
.58286 .44807 L
.58295 .4558 L
.58303 .4558 L
.58304 .4558 L
.58325 .4558 L
.58336 .4558 L
.58369 .44035 L
.58456 .44035 L
.58487 .44035 L
.5849 .44035 L
.58524 .44035 L
.58531 .44035 L
.58535 .44035 L
.58552 .44035 L
.58585 .44035 L
.58593 .44035 L
.58599 .44035 L
.586 .43262 L
.58634 .43262 L
.58639 .43262 L
.58644 .43262 L
.58669 .43262 L
.58673 .44035 L
.58697 .44035 L
.58711 .44035 L
Mistroke
.58735 .44035 L
.58761 .44807 L
.58762 .4558 L
.58821 .4558 L
.58858 .4558 L
.58869 .4558 L
.58883 .46353 L
.5889 .46353 L
.58891 .4249 L
.58901 .4249 L
.58913 .4249 L
.58918 .43262 L
.58947 .43262 L
.58953 .4249 L
.58958 .43262 L
.59002 .44035 L
.5904 .44035 L
.59057 .43262 L
.59058 .43262 L
.59095 .43262 L
.59109 .43262 L
.59145 .4249 L
.59155 .4249 L
.59157 .4249 L
.59175 .43262 L
.59175 .44035 L
.59201 .44035 L
.59209 .44807 L
.59246 .44807 L
.59261 .44807 L
.59267 .4558 L
.59268 .4558 L
.59279 .4558 L
.59298 .4558 L
.59325 .4558 L
.59419 .4558 L
.59455 .4558 L
.59468 .4558 L
.59474 .4558 L
.5951 .44807 L
.59517 .44807 L
.59518 .44807 L
.59594 .44807 L
.59605 .44807 L
.59642 .44807 L
.59683 .44035 L
.59702 .44035 L
.59707 .44035 L
.59709 .44035 L
.59709 .44035 L
Mistroke
.59781 .44035 L
.59793 .44035 L
.59805 .44035 L
.59842 .44035 L
.59883 .44035 L
.59915 .44807 L
.59966 .44807 L
.59974 .44807 L
.60001 .4558 L
.60015 .4558 L
.60035 .4558 L
.60044 .4558 L
.60045 .4558 L
.60106 .4558 L
.60106 .4558 L
.6014 .4558 L
.60199 .4558 L
.60257 .4558 L
.603 .4558 L
.60333 .44807 L
.60413 .44807 L
.60478 .44807 L
.60514 .44807 L
.60543 .44807 L
.60561 .44807 L
.60571 .44035 L
.60611 .44035 L
.60625 .44035 L
.60626 .44035 L
.60662 .44035 L
.6067 .44807 L
.60671 .44807 L
.60708 .44807 L
.60726 .44807 L
.60727 .4558 L
.60762 .44807 L
.60772 .44807 L
.60818 .44807 L
.60828 .4558 L
.60863 .4558 L
.60876 .4558 L
.60883 .4558 L
.60929 .4558 L
.60954 .4558 L
.6096 .4558 L
.60976 .4558 L
.60979 .4558 L
.61011 .4558 L
.61151 .44807 L
.61178 .44807 L
Mistroke
.61183 .44807 L
.61194 .44807 L
.61224 .44807 L
.61236 .44807 L
.61238 .44807 L
.61277 .44807 L
.61373 .44807 L
.614 .4558 L
.61423 .4558 L
.61437 .4558 L
.61444 .46353 L
.61458 .46353 L
.61495 .46353 L
.61509 .46353 L
.61519 .46353 L
.61521 .46353 L
.61587 .46353 L
.61596 .46353 L
.61634 .46353 L
.61636 .46353 L
.61672 .46353 L
.61698 .46353 L
.61724 .4558 L
.61742 .44807 L
.61746 .44807 L
.6175 .44807 L
.61757 .44807 L
.61759 .44807 L
.6177 .44807 L
.61782 .44807 L
.6181 .44807 L
.62031 .44807 L
.62051 .4558 L
.62053 .4558 L
.62058 .4558 L
.62078 .46353 L
.62095 .47125 L
.62101 .4558 L
.62121 .4558 L
.62161 .44807 L
.62206 .44807 L
.62222 .44035 L
.62256 .44035 L
.62274 .44035 L
.62301 .44035 L
.62305 .44807 L
.62334 .44807 L
.62343 .44807 L
.62361 .44807 L
.62406 .44807 L
Mistroke
.62415 .44807 L
.62471 .44807 L
.62483 .44807 L
.62484 .44807 L
.62499 .44807 L
.6258 .44807 L
.62593 .4558 L
.62593 .4558 L
.62607 .4558 L
.6261 .4558 L
.62626 .4558 L
.62654 .4558 L
.62674 .4558 L
.62738 .4558 L
.62753 .4558 L
.62801 .4558 L
.62826 .44807 L
.62828 .44807 L
.6286 .4558 L
.62865 .4558 L
.6288 .46353 L
.62897 .46353 L
.62897 .46353 L
.629 .47125 L
.6292 .47125 L
.62951 .47125 L
.62994 .47125 L
.63038 .47898 L
.63051 .47898 L
.63083 .44807 L
.63125 .44807 L
.6317 .44807 L
.63172 .44807 L
.63186 .44807 L
.63191 .44035 L
.63195 .44035 L
.63204 .44035 L
.63211 .44035 L
.63212 .44035 L
.63298 .44035 L
.63337 .44035 L
.63419 .44035 L
.63423 .44035 L
.63479 .44035 L
.63483 .44035 L
.6349 .44035 L
.63527 .44035 L
.63549 .44035 L
.63576 .44035 L
.6359 .44035 L
Mistroke
.63591 .44035 L
.63659 .44035 L
.63671 .44035 L
.63683 .44035 L
.63729 .44035 L
.63771 .44035 L
.63773 .44035 L
.63783 .44035 L
.63836 .44035 L
.63981 .44035 L
.64031 .44035 L
.64081 .44035 L
.64099 .44807 L
.64136 .4558 L
.64138 .4558 L
.64144 .44807 L
.64187 .44807 L
.64203 .4558 L
.64248 .4558 L
.64255 .4558 L
.64269 .4558 L
.64294 .4558 L
.64324 .44807 L
.64333 .44807 L
.64428 .44807 L
.64434 .4558 L
.64461 .4558 L
.64481 .4558 L
.64492 .4558 L
.645 .44035 L
.6453 .44035 L
.64534 .44035 L
.64543 .44035 L
.64566 .44035 L
.64576 .44035 L
.64584 .44035 L
.64622 .44035 L
.64633 .44035 L
.64634 .44035 L
.64714 .44035 L
.6472 .43262 L
.64744 .44035 L
.64747 .44807 L
.64749 .44807 L
.6478 .4558 L
.64794 .4558 L
.64795 .4558 L
.64834 .4558 L
.64848 .43262 L
.64858 .44035 L
Mistroke
.64863 .44035 L
.64863 .44035 L
.64866 .44035 L
.6488 .44035 L
.64896 .44035 L
.64956 .44035 L
.6498 .44035 L
.6501 .44035 L
.65015 .44035 L
.65049 .44035 L
.65061 .44807 L
.6508 .44807 L
.65104 .44807 L
.65105 .44807 L
.65105 .44807 L
.65107 .44807 L
.65107 .44807 L
.65123 .44035 L
.65125 .44035 L
.65162 .44035 L
.65179 .43262 L
.65199 .4249 L
.65235 .4249 L
.65244 .4249 L
.65246 .43262 L
.65274 .43262 L
.6528 .43262 L
.6528 .43262 L
.65302 .43262 L
.65309 .43262 L
.65322 .43262 L
.65342 .43262 L
.65372 .44035 L
.65377 .44035 L
.65378 .44035 L
.65391 .44035 L
.65399 .44035 L
.6541 .44035 L
.65422 .44035 L
.65432 .44035 L
.65442 .44035 L
.65445 .44035 L
.65478 .44035 L
.65526 .44035 L
.65541 .44035 L
.65548 .44035 L
.6555 .43262 L
.65557 .44035 L
.65598 .44035 L
.65623 .44035 L
Mistroke
.65632 .44035 L
.65632 .44035 L
.65637 .44035 L
.65644 .44035 L
.65647 .44807 L
.6565 .44807 L
.65674 .44807 L
.65682 .44807 L
.65687 .44807 L
.65706 .44807 L
.6572 .43262 L
.65729 .43262 L
.65745 .44035 L
.65775 .44035 L
.65837 .44035 L
.65851 .43262 L
.65854 .4249 L
.65854 .4249 L
.65873 .4249 L
.65881 .4249 L
.65894 .4249 L
.65902 .4249 L
.65911 .4249 L
.65915 .43262 L
.65945 .43262 L
.66007 .4249 L
.66074 .4249 L
.66075 .4249 L
.66122 .4249 L
.66149 .4249 L
.6618 .4249 L
.66181 .4249 L
.66188 .40945 L
.66207 .40945 L
.66246 .40945 L
.66263 .40945 L
.66267 .40945 L
.6631 .40945 L
.66326 .40945 L
.66419 .41717 L
.66444 .41717 L
.66463 .4249 L
.66472 .4249 L
.66485 .4249 L
.66485 .4249 L
.6653 .4249 L
.66563 .43262 L
.66576 .43262 L
.66673 .43262 L
.6672 .43262 L
Mistroke
.66738 .4249 L
.66738 .4249 L
.66752 .4249 L
.66754 .40945 L
.66864 .41717 L
.66878 .41717 L
.66882 .4249 L
.66981 .4249 L
.67004 .4249 L
.67021 .4249 L
.67037 .4249 L
.67038 .4249 L
.67041 .4249 L
.67141 .43262 L
.67147 .43262 L
.67183 .43262 L
.67351 .43262 L
.67439 .43262 L
.67451 .43262 L
.67452 .44035 L
.67455 .44035 L
.67541 .43262 L
.67542 .43262 L
.67561 .43262 L
.67647 .43262 L
.677 .43262 L
.67729 .43262 L
.67739 .43262 L
.67803 .43262 L
.67814 .43262 L
.67822 .43262 L
.67899 .43262 L
.67987 .43262 L
.68 .43262 L
.6803 .43262 L
.68052 .43262 L
.68053 .44035 L
.68072 .44035 L
.68085 .44035 L
.68163 .44035 L
.68168 .44807 L
.68192 .44807 L
.68224 .44807 L
.68249 .43262 L
.6829 .44035 L
.68301 .44035 L
.68351 .44035 L
.68367 .44035 L
.68383 .43262 L
.6839 .43262 L
Mistroke
.68411 .44035 L
.68461 .44035 L
.68463 .44035 L
.68498 .44807 L
.68502 .44807 L
.68509 .44807 L
.68519 .44035 L
.68547 .44035 L
.68579 .44035 L
.68602 .44035 L
.68636 .44035 L
.6866 .44035 L
.68682 .44807 L
.68752 .4558 L
.68763 .4558 L
.68774 .4558 L
.68786 .4558 L
.68812 .4558 L
.68829 .4558 L
.68868 .4558 L
.68896 .46353 L
.68936 .46353 L
.6895 .46353 L
.68954 .46353 L
.68974 .46353 L
.68978 .46353 L
.68987 .46353 L
.68997 .46353 L
.69026 .47125 L
.69078 .47125 L
.69079 .47125 L
.69082 .47898 L
.69088 .47898 L
.69127 .47898 L
.69171 .4867 L
.69178 .4867 L
.69228 .47125 L
.69239 .47125 L
.6925 .47125 L
.69299 .47125 L
.69307 .47125 L
.69316 .47125 L
.69318 .47898 L
.69327 .47898 L
.69349 .47898 L
.69395 .47898 L
.69404 .4867 L
.6942 .4867 L
.69428 .4867 L
.69449 .4867 L
Mistroke
.6947 .4867 L
.69483 .4867 L
.69507 .4867 L
.69521 .47898 L
.69556 .47898 L
.69571 .47898 L
.69571 .47898 L
.6961 .47898 L
.69627 .47898 L
.69631 .47898 L
.69638 .47125 L
.69683 .47125 L
.69687 .47125 L
.69705 .46353 L
.69708 .46353 L
.69747 .47125 L
.69835 .47125 L
.6986 .47125 L
.69868 .47125 L
.69894 .47125 L
.69936 .47125 L
.69954 .47125 L
.69965 .47125 L
.69966 .47125 L
.70015 .47125 L
.70018 .47125 L
.70082 .47125 L
.70119 .47125 L
.70122 .47898 L
.7015 .47898 L
.70184 .47898 L
.70184 .47898 L
.70195 .47898 L
.70251 .47898 L
.70257 .47898 L
.70266 .47898 L
.70272 .4867 L
.7028 .4867 L
.70284 .4867 L
.70285 .4867 L
.70296 .4867 L
.70309 .4867 L
.70325 .4867 L
.70327 .4867 L
.70332 .4867 L
.70339 .4867 L
.70354 .4867 L
.70406 .49443 L
.70424 .49443 L
.70471 .49443 L
Mistroke
.70473 .4867 L
.70538 .4867 L
.70601 .47898 L
.70611 .47898 L
.7062 .47898 L
.70639 .47898 L
.70709 .4867 L
.70718 .49443 L
.70739 .49443 L
.70755 .49443 L
.7076 .49443 L
.70765 .49443 L
.70774 .49443 L
.70785 .49443 L
.7079 .49443 L
.70817 .49443 L
.70842 .49443 L
.70843 .49443 L
.7092 .49443 L
.7092 .49443 L
.7094 .49443 L
.70948 .49443 L
.70972 .49443 L
.70984 .49443 L
.7101 .49443 L
.71057 .49443 L
.71067 .49443 L
.71077 .49443 L
.71186 .4867 L
.7119 .4867 L
.71205 .4867 L
.71213 .4867 L
.71236 .4867 L
.71253 .49443 L
.71277 .49443 L
.71283 .49443 L
.71293 .49443 L
.71308 .49443 L
.71329 .49443 L
.7133 .50215 L
.71348 .50215 L
.71348 .50215 L
.71385 .50988 L
.71399 .50988 L
.71453 .50988 L
.71501 .50988 L
.71503 .50988 L
.7157 .50988 L
.71581 .5176 L
.71622 .5176 L
Mistroke
.71639 .5176 L
.71663 .5176 L
.71664 .5176 L
.71687 .5176 L
.71695 .5176 L
.71704 .5176 L
.71719 .50988 L
.71728 .50988 L
.7174 .50988 L
.71775 .50988 L
.71789 .50215 L
.71805 .50215 L
.71858 .50215 L
.71917 .46353 L
.71922 .46353 L
.71923 .46353 L
.7193 .47125 L
.71986 .47125 L
.71987 .47125 L
.7203 .47125 L
.72038 .47898 L
.72054 .47898 L
.72065 .47898 L
.72141 .47898 L
.72143 .47898 L
.72198 .47898 L
.72199 .4867 L
.72234 .49443 L
.7228 .49443 L
.72286 .49443 L
.72311 .50215 L
.72326 .50215 L
.72348 .49443 L
.72365 .49443 L
.72374 .50215 L
.7238 .50215 L
.72421 .50215 L
.72465 .50215 L
.72465 .50215 L
.7248 .50215 L
.72491 .50215 L
.72508 .50215 L
.7255 .50215 L
.72587 .50215 L
.72612 .50215 L
.72672 .50215 L
.727 .50215 L
.72705 .50215 L
.72794 .50215 L
.72801 .50215 L
Mistroke
.72816 .50988 L
.72817 .50988 L
.72818 .5176 L
.7284 .5176 L
.72842 .5176 L
.729 .50988 L
.72914 .50988 L
.72982 .50988 L
.72987 .50988 L
.73012 .5176 L
.73013 .5176 L
.73026 .5176 L
.73066 .5176 L
.73085 .5176 L
.73124 .5176 L
.73135 .5176 L
.73135 .50988 L
.73146 .50988 L
.73195 .50988 L
.73204 .50988 L
.73211 .5176 L
.73221 .50988 L
.73226 .5176 L
.73228 .5176 L
.73235 .50988 L
.73245 .49443 L
.73264 .49443 L
.73313 .50215 L
.73321 .4867 L
.73355 .4867 L
.73374 .49443 L
.73383 .49443 L
.73412 .4867 L
.73468 .49443 L
.73488 .49443 L
.7351 .49443 L
.73512 .49443 L
.73531 .49443 L
.73532 .49443 L
.73551 .49443 L
.73561 .49443 L
.73566 .4867 L
.73616 .4867 L
.73724 .4867 L
.73725 .4867 L
.73732 .4867 L
.7386 .4867 L
.73872 .47898 L
.73875 .47898 L
.73906 .47898 L
Mistroke
.73916 .47898 L
.73976 .47898 L
.73996 .4867 L
.7404 .49443 L
.7405 .49443 L
.74059 .49443 L
.74079 .47125 L
.74083 .47125 L
.74088 .47125 L
.74102 .47125 L
.74119 .47125 L
.74127 .47125 L
.74151 .47125 L
.74233 .47125 L
.74324 .47125 L
.74327 .47898 L
.74342 .38627 L
.74427 .38627 L
.74474 .38627 L
.74576 .38627 L
.74584 .38627 L
.74584 .394 L
.74605 .394 L
.74623 .394 L
.74636 .38627 L
.74662 .394 L
.74665 .35537 L
.74674 .35537 L
.74812 .34764 L
.74885 .33992 L
.74901 .33992 L
.74911 .33992 L
.74991 .33992 L
.75002 .33992 L
.75035 .33219 L
.751 .33992 L
.75116 .34764 L
.75165 .33992 L
.75194 .33992 L
.75203 .33992 L
.7533 .33992 L
.75335 .34764 L
.75354 .34764 L
.75357 .34764 L
.75381 .35537 L
.75392 .35537 L
.75438 .35537 L
.75444 .35537 L
.75493 .35537 L
.75572 .35537 L
Mistroke
.75597 .36309 L
.75613 .36309 L
.75622 .36309 L
.75625 .36309 L
.7569 .36309 L
.75742 .36309 L
.75754 .37082 L
.758 .37082 L
.75831 .37082 L
.75836 .37082 L
.75873 .37855 L
.7588 .37855 L
.75895 .37855 L
.75902 .37855 L
.75956 .37855 L
.76038 .37855 L
.76054 .38627 L
.76081 .38627 L
.76192 .38627 L
.76196 .38627 L
.76214 .38627 L
.76241 .38627 L
.76254 .38627 L
.76271 .38627 L
.76301 .38627 L
.76383 .38627 L
.76431 .38627 L
.76448 .37855 L
.76488 .37855 L
.76501 .37855 L
.76556 .37855 L
.76565 .37855 L
.76581 .37855 L
.76581 .37855 L
.76588 .37855 L
.76589 .37082 L
.76594 .37082 L
.76596 .37082 L
.766 .37855 L
.76622 .37855 L
.76651 .37855 L
.76675 .37855 L
.76689 .37855 L
.76782 .37855 L
.76801 .37082 L
.76802 .36309 L
.76825 .36309 L
.76836 .36309 L
.76884 .36309 L
.76898 .37082 L
Mistroke
.76946 .37082 L
.7698 .37082 L
.77042 .37082 L
.77126 .37082 L
.77185 .37082 L
.77257 .37082 L
.7726 .37082 L
.77433 .37082 L
.77443 .37082 L
.7745 .37082 L
.77497 .37855 L
.77501 .37855 L
.77524 .37855 L
.77537 .37855 L
.77582 .37855 L
.77615 .37855 L
.77625 .37855 L
.77677 .38627 L
.77703 .37082 L
.77736 .36309 L
.77767 .34764 L
.77832 .35537 L
.77977 .34764 L
.78022 .34764 L
.78067 .35537 L
.78098 .35537 L
.78112 .35537 L
.78197 .35537 L
.78231 .35537 L
.78313 .35537 L
.78321 .36309 L
.78327 .36309 L
.78337 .37082 L
.78374 .37855 L
.78374 .37855 L
.78424 .37855 L
.78444 .37855 L
.78447 .37855 L
.7853 .37855 L
.78571 .38627 L
.78587 .38627 L
.78645 .38627 L
.78647 .38627 L
.78667 .38627 L
.78672 .38627 L
.78687 .38627 L
.7874 .38627 L
.78746 .37855 L
.78747 .37855 L
.78769 .37855 L
Mistroke
.7884 .37855 L
.78857 .37855 L
.78885 .38627 L
.78902 .38627 L
.78916 .38627 L
.78923 .394 L
.78939 .40172 L
.79046 .40172 L
.79047 .40172 L
.79074 .40172 L
.79119 .394 L
.7914 .394 L
.79169 .394 L
.79222 .40172 L
.79236 .40172 L
.79241 .40945 L
.79245 .40172 L
.79267 .40172 L
.79275 .40172 L
.79318 .40172 L
.79386 .40172 L
.79444 .40172 L
.79449 .40945 L
.79514 .40945 L
.79534 .40945 L
.7954 .40945 L
.79584 .40945 L
.79588 .40945 L
.79594 .40945 L
.79638 .40945 L
.79646 .40945 L
.79689 .40945 L
.79737 .38627 L
.79779 .38627 L
.79785 .38627 L
.79796 .394 L
.79802 .394 L
.79833 .394 L
.79898 .394 L
.79916 .40172 L
.79917 .40172 L
.79981 .40172 L
.79991 .40172 L
.80024 .40172 L
.80024 .40172 L
.80033 .40172 L
.8004 .40172 L
.80048 .40172 L
.80114 .40172 L
.80115 .394 L
Mistroke
.80131 .40172 L
.80186 .40172 L
.80203 .394 L
.80218 .394 L
.80228 .394 L
.80234 .394 L
.80302 .40172 L
.80302 .40172 L
.80316 .40172 L
.80318 .40172 L
.80318 .40172 L
.80325 .40172 L
.80344 .40172 L
.80357 .40172 L
.804 .40945 L
.80438 .40945 L
.80461 .40945 L
.80474 .41717 L
.80484 .4249 L
.80503 .4249 L
.80522 .4249 L
.80607 .41717 L
.80608 .4249 L
.80614 .4249 L
.80694 .4249 L
.80789 .4249 L
.80802 .4249 L
.80823 .4249 L
.80828 .4249 L
.80842 .4249 L
.8094 .4249 L
.80944 .4249 L
.8102 .38627 L
.8103 .38627 L
.81033 .38627 L
.81047 .38627 L
.8107 .38627 L
.81129 .38627 L
.81134 .38627 L
.81176 .38627 L
.81201 .38627 L
.81208 .394 L
.81323 .38627 L
.81448 .38627 L
.81483 .394 L
.81556 .394 L
.81649 .394 L
.81678 .394 L
.817 .394 L
.81712 .394 L
Mistroke
.81736 .394 L
.81755 .394 L
.81785 .394 L
.81788 .394 L
.81788 .394 L
.81816 .394 L
.81822 .394 L
.81843 .394 L
.81879 .394 L
.81982 .394 L
.82007 .394 L
.82014 .394 L
.82023 .394 L
.82055 .394 L
.82066 .394 L
.82092 .40172 L
.82095 .40172 L
.82102 .40945 L
.8211 .41717 L
.8217 .41717 L
.82176 .41717 L
.82198 .41717 L
.82215 .41717 L
.82276 .38627 L
.82297 .36309 L
.8233 .36309 L
.82352 .36309 L
.82353 .36309 L
.82392 .36309 L
.82405 .37082 L
.82407 .37855 L
.82446 .37855 L
.82608 .38627 L
.82623 .38627 L
.82825 .38627 L
.82876 .38627 L
.82904 .38627 L
.82943 .394 L
.82953 .394 L
.82983 .394 L
.83009 .38627 L
.83052 .394 L
.83078 .394 L
.83102 .394 L
.83103 .394 L
.83107 .37082 L
.83121 .37082 L
.83159 .37082 L
.8323 .37855 L
.8324 .37082 L
Mistroke
.83247 .37082 L
.83248 .37082 L
.83285 .37082 L
.83305 .37082 L
.83369 .37082 L
.83396 .37082 L
.83445 .37082 L
.83558 .37855 L
.8357 .38627 L
.83581 .38627 L
.8361 .38627 L
.83679 .38627 L
.83686 .394 L
.83856 .394 L
.8387 .40172 L
.83899 .394 L
.83944 .394 L
.83962 .38627 L
.84067 .38627 L
.84148 .38627 L
.84153 .38627 L
.84162 .38627 L
.84203 .38627 L
.84203 .38627 L
.84209 .394 L
.84237 .40172 L
.84243 .40172 L
.84258 .40945 L
.84291 .40945 L
.84317 .40172 L
.84321 .40172 L
.84333 .40172 L
.84336 .40172 L
.84382 .40172 L
.84393 .40172 L
.84403 .40172 L
.84435 .40172 L
.84441 .40172 L
.84444 .40945 L
.84463 .40945 L
.84482 .40945 L
.84499 .40945 L
.84502 .41717 L
.84504 .41717 L
.84507 .41717 L
.84532 .41717 L
.84533 .41717 L
.84539 .41717 L
.84542 .41717 L
.84551 .41717 L
Mistroke
.84586 .41717 L
.84588 .41717 L
.84597 .40945 L
.84627 .40945 L
.84628 .40945 L
.84629 .40945 L
.84631 .40945 L
.84672 .40945 L
.84696 .40945 L
.84763 .41717 L
.84763 .41717 L
.84781 .41717 L
.84798 .41717 L
.84838 .41717 L
.8487 .41717 L
.84897 .41717 L
.84905 .41717 L
.84961 .41717 L
.84974 .41717 L
.8499 .4249 L
.84996 .4249 L
.84997 .4249 L
.85003 .4249 L
.85026 .41717 L
.8504 .41717 L
.85087 .41717 L
.85088 .4249 L
.85124 .4249 L
.85155 .4249 L
.85205 .394 L
.85219 .40172 L
.85258 .40172 L
.85312 .40172 L
.85348 .40172 L
.85469 .40172 L
.85497 .394 L
.85562 .394 L
.85566 .394 L
.85592 .394 L
.85607 .394 L
.85641 .394 L
.85668 .37855 L
.85691 .37855 L
.85715 .37855 L
.85777 .37855 L
.85809 .37855 L
.85827 .37855 L
.85854 .37855 L
.85948 .37855 L
.86006 .37855 L
Mistroke
.86034 .37855 L
.86035 .37082 L
.86039 .37082 L
.86104 .37082 L
.86111 .37855 L
.86179 .37855 L
.86225 .37855 L
.86299 .37855 L
.86317 .37855 L
.86347 .37855 L
.86373 .34764 L
.86374 .35537 L
.86412 .35537 L
.86665 .35537 L
.86665 .35537 L
.86683 .34764 L
.86689 .34764 L
.86696 .34764 L
.86718 .34764 L
.86773 .34764 L
.86793 .34764 L
.8687 .35537 L
.86876 .35537 L
.86883 .35537 L
.86925 .35537 L
.8693 .35537 L
.86932 .35537 L
.86952 .35537 L
.86988 .35537 L
.87081 .36309 L
.87084 .36309 L
.87128 .37082 L
.87128 .37082 L
.87187 .37082 L
.87294 .37082 L
.87321 .37082 L
.87339 .37082 L
.87492 .35537 L
.87501 .36309 L
.87569 .36309 L
.87575 .36309 L
.87609 .36309 L
.87641 .37082 L
.87757 .37082 L
.87767 .37082 L
.87817 .37082 L
.87822 .37082 L
.87822 .35537 L
.87833 .35537 L
.87889 .35537 L
Mistroke
.87919 .36309 L
.87934 .36309 L
.87968 .36309 L
.88086 .36309 L
.88087 .36309 L
.88103 .36309 L
.88132 .36309 L
.88157 .35537 L
.88298 .36309 L
.88314 .36309 L
.88315 .36309 L
.8833 .36309 L
.88381 .36309 L
.88403 .36309 L
.88406 .36309 L
.88516 .36309 L
.88567 .37082 L
.88615 .37082 L
.88639 .37082 L
.8864 .37082 L
.88666 .37082 L
.88696 .37082 L
.8874 .37082 L
.88752 .37082 L
.88769 .37082 L
.88838 .37082 L
.88848 .37082 L
.88856 .37082 L
.8888 .37082 L
.88904 .37082 L
.88911 .37082 L
.88923 .37082 L
.88935 .37082 L
.88947 .37082 L
.88957 .37082 L
.88988 .37082 L
.88991 .37082 L
.88999 .37082 L
.89045 .37082 L
.89068 .37082 L
.89087 .37082 L
.89096 .37082 L
.89138 .37082 L
.89141 .37082 L
.89148 .37082 L
.89151 .37082 L
.89154 .37082 L
.89186 .37082 L
.89264 .37082 L
.89299 .35537 L
Mistroke
.89347 .35537 L
.89533 .36309 L
.89542 .36309 L
.89555 .36309 L
.89592 .35537 L
.89649 .34764 L
.89721 .34764 L
.89796 .34764 L
.89804 .34764 L
.89829 .34764 L
.89907 .35537 L
.89921 .35537 L
.89997 .35537 L
.90001 .35537 L
.90034 .36309 L
.90067 .36309 L
.90114 .34764 L
.90116 .34764 L
.90126 .34764 L
.90134 .34764 L
.90146 .34764 L
.90168 .34764 L
.90186 .35537 L
.90232 .35537 L
.90278 .35537 L
.90316 .36309 L
.90372 .36309 L
.90465 .35537 L
.90481 .35537 L
.90534 .35537 L
.90547 .35537 L
.90575 .36309 L
.90614 .36309 L
.90699 .37082 L
.90761 .37855 L
.90778 .37855 L
.9082 .37855 L
.9083 .37855 L
.9083 .37855 L
.90869 .37855 L
.90889 .38627 L
.91023 .38627 L
.91135 .38627 L
.91252 .38627 L
.91261 .38627 L
.91309 .38627 L
.91323 .38627 L
.91325 .38627 L
.91331 .37855 L
.91356 .37855 L
Mistroke
.91373 .37855 L
.91419 .38627 L
.91433 .394 L
.91466 .394 L
.91476 .394 L
.91478 .40172 L
.9148 .40172 L
.91562 .40945 L
.91571 .40945 L
.91583 .40945 L
.91637 .40945 L
.91647 .40945 L
.91719 .40945 L
.91736 .40945 L
.91771 .40945 L
.91803 .40945 L
.91808 .40945 L
.91813 .40945 L
.91819 .40945 L
.91887 .40945 L
.91954 .40945 L
.91963 .40945 L
.91967 .40945 L
.91975 .394 L
.92013 .394 L
.92021 .38627 L
.92044 .37855 L
.92083 .37855 L
.92099 .37855 L
.92108 .37855 L
.92125 .37855 L
.92146 .38627 L
.92152 .38627 L
.9218 .38627 L
.92182 .38627 L
.92185 .38627 L
.92197 .38627 L
.92214 .394 L
.92227 .394 L
.9225 .40172 L
.92314 .35537 L
.92342 .35537 L
.92344 .35537 L
.9235 .35537 L
.92366 .35537 L
.92383 .35537 L
.92411 .35537 L
.92453 .32447 L
.92459 .32447 L
.92511 .33219 L
Mistroke
.92536 .33992 L
.92559 .33992 L
.92663 .33992 L
.92678 .33992 L
.92699 .33992 L
.92724 .33992 L
.92781 .34764 L
.92783 .35537 L
.92807 .36309 L
.92814 .36309 L
.92817 .36309 L
.92856 .36309 L
.9289 .36309 L
.92891 .35537 L
.92945 .34764 L
.92974 .34764 L
.93086 .35537 L
.93163 .35537 L
.93232 .35537 L
.93233 .35537 L
.93269 .34764 L
.93276 .35537 L
.93316 .35537 L
.93326 .35537 L
.9335 .35537 L
.93386 .35537 L
.93394 .35537 L
.93404 .35537 L
.93408 .35537 L
.93445 .35537 L
.93464 .35537 L
.93465 .35537 L
.93486 .35537 L
.93523 .35537 L
.93538 .35537 L
.9354 .35537 L
.93552 .35537 L
.93561 .35537 L
.93618 .35537 L
.93663 .35537 L
.93674 .36309 L
.93684 .37082 L
.9371 .37855 L
.93722 .37855 L
.93724 .37855 L
.93727 .37855 L
.93741 .37855 L
.93747 .37082 L
.93781 .37855 L
.93785 .37855 L
Mistroke
.9379 .37855 L
.93802 .38627 L
.93811 .38627 L
.93819 .38627 L
.93851 .38627 L
.93852 .37855 L
.93873 .37855 L
.93901 .37082 L
.93942 .37855 L
.94049 .37855 L
.94076 .37855 L
.94106 .37855 L
.9412 .37855 L
.94131 .37855 L
.9416 .37855 L
.94193 .37855 L
.94213 .37855 L
.94237 .37855 L
.94244 .37855 L
.94253 .37855 L
.9428 .37855 L
.94299 .37855 L
.94429 .37082 L
.94429 .37082 L
.9444 .37082 L
.94471 .33992 L
.94503 .33992 L
.94509 .33992 L
.94519 .33992 L
.94644 .33992 L
.94661 .33992 L
.94679 .33992 L
.94705 .33992 L
.94731 .33992 L
.94739 .33992 L
.94742 .33992 L
.94745 .33992 L
.94811 .33992 L
.94827 .33992 L
.94939 .33992 L
.94949 .33992 L
.95047 .33992 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[193]:=",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/B000`400?l00000o`00003oo`3ooolQ
0?ooo`00@`3oool500000340oooo0`00000`0?ooo`<00000<03oool3000002h0oooo0`0000040?oo
o`8000001`3oool004@0oooo00@000000?ooo`3oool00000<P3oool00`000000oooo0?ooo`0^0?oo
o`050000003oool0oooo0?ooo`000000;P3oool01@000000oooo0?ooo`3oool0000002h0oooo00<0
00000?ooo`3oool00P3oool010000000oooo0?ooo`0000060?ooo`00A@3oool00`000000oooo0?oo
o`0_0?ooo`D00000;`3oool01@000000oooo0?ooo`3oool0000002h0oooo00D000000?ooo`3oool0
oooo0000000^0?ooo`030000003oool0oooo0080oooo00@000000?ooo`3oool000001P3oool004H0
oooo00<000000?ooo`3oool0;P3oool010000000oooo0?ooo`00000`0?ooo`@00000<03oool30000
02l0oooo00<000000?ooo`3oool00P3oool010000000oooo0?ooo`0000060?ooo`00@`3oool01@00
0000oooo0?ooo`3oool000000300oooo00<000000?ooo`000000<03oool00`000000oooo0?ooo`0`
0?ooo`050000003oool0oooo0?ooo`000000;P3oool00`000000oooo0?ooo`020?ooo`040000003o
ool0oooo000000H0oooo00130?ooo`050000003oool0oooo0?ooo`000000<@3oool200000340oooo
00<000000?ooo`3oool0;`3oool01@000000oooo0?ooo`3oool0000002d0oooo0P0000040?ooo`04
0000003oool0oooo000000H0oooo00140?ooo`<00000<`3oool00`000000oooo0?ooo`0`0?ooo`80
0000<03oool3000002l0oooo00<000000?ooo`3oool00`3oool2000000L0oooo003o0?ooob40oooo
003o0?ooob40oooo003o0?ooob40oooo003o0?ooob40oooo000B0?ooool000001@00000:0?ooo`00
4P3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool0
2P3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool0
2P3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool0
2P3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool0
2P3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool0
2P3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool0
2P3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool0
203oool00180oooo0P00003o0?ooo`d0oooo000B0?ooo`800000o`3oool=0?ooo`004P3oool30000
0?l0oooo303oool00180oooo00<000000?ooo`000000o`3oool<0?ooo`004P3oool00`000000oooo
0000003o0?ooo``0oooo000B0?ooo`030000003oool000000?l0oooo303oool00180oooo0`00003o
0?ooo``0oooo000B0?ooo`030000003oool000000?l0oooo303oool00180oooo00<000000?ooo`00
00000P00003o0?ooo`X0oooo000B0?ooo`030000003oool0oooo00800000o`3oool:0?ooo`004P3o
ool200000080oooo00<000000?ooo`3oool0o`3oool80?ooo`004P3oool01@000000oooo0?ooo`3o
ool000000?l0oooo2P3oool00180oooo00D000000?ooo`3oool0oooo0000003o0?ooo`X0oooo000B
0?ooo`050000003oool0oooo0?ooo`000000o`3oool:0?ooo`004P3oool200000080oooo00<00000
0?ooo`3oool0o`3oool80?ooo`00103oool3000000@0oooo0P0000050?ooo`050000003oool0oooo
0?ooo`000000o`3oool:0?ooo`001@3oool00`000000oooo0?ooo`020?ooo`040000003oool0oooo
000000@0oooo00<000000?ooo`3oool00P3oool200000?l0oooo203oool000D0oooo00<000000?oo
o`3oool00P3oool010000000oooo0?ooo`0000040?ooo`030000003oool0oooo00<0oooo00<00000
0?ooo`3oool0o`3oool60?ooo`001@3oool00`000000oooo0?ooo`020?ooo`040000003oool0oooo
000000@0oooo0`0000030?ooo`030000003oool0oooo0?l0oooo1P3oool000D0oooo00<000000?oo
o`3oool00P3oool010000000oooo0?ooo`0000040?ooo`030000003oool0oooo00<0oooo00<00000
0?ooo`3oool0o`3oool60?ooo`00103oool2000000@0oooo00@000000?ooo`3oool00000103oool0
0`000000oooo0?ooo`030?ooo`800000o`3oool70?ooo`001@3oool00`000000oooo0?ooo`030?oo
o`8000001@3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo0?l0oooo1@3oool00180
oooo0P0000050?ooo`030000003oool0oooo0?l0oooo1@3oool00180oooo00<000000?ooo`3oool0
103oool00`000000oooo0?ooo`3o0?ooo`D0oooo000B0?ooo`030000003oool0oooo00@0oooo0P00
003o0?ooo`H0oooo000B0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool0o`3oool4
0?ooo`004P3oool2000000H0oooo0P00003o0?ooo`D0oooo000B0?ooo`030000003oool0oooo00D0
oooo0P00003o0?ooo`D0oooo000B0?ooo`030000003oool0oooo00D0oooo0`00003o0?ooo`@0oooo
000B0?ooo`030000003oool0oooo00H0oooo0P00003o0?ooo`@0oooo000B0?ooo`8000001`3oool3
00000?l0oooo0`3oool00180oooo00<000000?ooo`3oool01P3oool300000?l0oooo0`3oool00180
oooo00<000000?ooo`3oool01`3oool200000?l0oooo0`3oool00180oooo00<000000?ooo`3oool0
203oool00`000000oooo0?ooo`3o0?ooo`40oooo000B0?ooo`8000002@3oool00`000000oooo0?oo
o`3o0?ooo`40oooo00030?ooo`D000000`3oool2000000D0oooo00<000000?ooo`3oool0203oool0
0`000000oooo0?ooo`3o0?ooo`40oooo00040?ooo`040000003oool0oooo00000080oooo00@00000
0?ooo`3oool00000103oool00`000000oooo0?ooo`080?ooo`800000o`3oool20?ooo`001@3oool0
0`000000oooo0?ooo`020?ooo`040000003oool0oooo000000@0oooo00<000000?ooo`3oool02@3o
ool00`000000oooo0?ooo`3o0?ooo`001P3oool01@000000oooo0?ooo`3oool000000080oooo00<0
00000?ooo`3oool00P3oool3000000T0oooo0`0000000`3oool000000?ooo`3l0?ooo`000`3oool0
1@000000oooo0?ooo`3oool000000080oooo00@000000?ooo`3oool00000103oool00`000000oooo
0?ooo`0:0?ooo`80000000<0oooo0000003oool0o03oool000<0oooo00D000000?ooo`3oool0oooo
000000020?ooo`040000003oool0oooo000000@0oooo00<000000?ooo`3oool02P3oool4000001P0
oooo00<000000?ooo`3oool0hP3oool000@0oooo0`0000040?ooo`8000001@3oool00`000000oooo
0?ooo`0:0?ooo`040000003oool0oooo000001P0oooo00<000000?ooo`3oool0hP3oool00180oooo
0P00000;0?ooo`050000003oool0oooo0?ooo`0000003P3oool2000000L0oooo00<000000?ooo`3o
ool0hP3oool00180oooo00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`0<0?ooo`030000
003oool0oooo00D0oooo0P00003T0?ooo`004P3oool00`000000oooo0?ooo`0>0?ooo`030000003o
ool0000000H0oooo00@000000?ooo`3oool000000P3oool00`000000oooo000000030?ooo`D00000
h`3oool00180oooo00<000000?ooo`3oool03P3oool00`000000oooo000000060?ooo`040000003o
ool0oooo00000080oooo00<000000?ooo`0000000`3oool200000080oooo00<000000?ooo`3oool0
h@3oool00180oooo0P00000?0?ooo`@0000000@0oooo0000003oool0oooo1P0000000`3oool00000
0000000200000080oooo0P0000020?ooo`030000003oool0oooo0>40oooo000B0?ooo`030000003o
ool0oooo00l0oooo00D000000?ooo`000000oooo000000020?ooo`<0000000@0oooo000000000000
oooo0`0000030?ooo`050000003oool0oooo0?ooo`000000h`3oool00180oooo00<000000?ooo`3o
ool03`3oool:000000030?ooo`000000000000D0000000<0oooo0000000000000`3oool00`000000
oooo0?ooo`3Q0?ooo`004P3oool00`000000oooo0?ooo`0A0?ooo`<00000103oool00`000000oooo
0000000300000080oooo00<000000?ooo`000000103oool00`000000oooo0?ooo`3Q0?ooo`004P3o
ool2000001<0oooo0P0000040?ooo`030000003oool0000000<000000P3oool3000000@0oooo0P00
003R0?ooo`004P3oool00`000000oooo0?ooo`0B0?ooo`800000203oool200000080oooo00<00000
0?ooo`0000001@3oool00`000000oooo0?ooo`3P0?ooo`004P3oool00`000000oooo0?ooo`0B0?oo
o`800000203oool200000080oooo0`0000050?ooo`800000h@3oool00180oooo00<000000?ooo`3o
ool0703oool2000000@0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`3P0?ooo`00
4P3oool2000001h0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`040?ooo`030000
003oool0oooo0=l0oooo00040?ooo`<00000103oool2000000D0oooo00<000000?ooo`3oool0:@3o
ool00`000000oooo0?ooo`3O0?ooo`000`3oool01@000000oooo0?ooo`3oool000000080oooo00@0
00000?ooo`3oool00000103oool00`000000oooo0?ooo`0Y0?ooo`030000003oool0oooo0=l0oooo
00070?ooo`040000003oool0oooo00000080oooo00<000000?ooo`3oool00P3oool00`000000oooo
0?ooo`0Y0?ooo`030000003oool0oooo0=l0oooo00050?ooo`8000000`3oool010000000oooo0?oo
o`0000040?ooo`<00000:@3oool00`000000oooo0?ooo`3O0?ooo`001`3oool010000000oooo0?oo
o`0000020?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0:@3oool00`000000oooo
0?ooo`3O0?ooo`000`3oool01@000000oooo0?ooo`3oool000000080oooo00@000000?ooo`3oool0
0000103oool00`000000oooo0?ooo`0Y0?ooo`800000h03oool000@0oooo0`0000040?ooo`800000
1@3oool00`000000oooo0?ooo`0Z0?ooo`030000003oool0oooo0=h0oooo000B0?ooo`800000:`3o
ool00`000000oooo0?ooo`3N0?ooo`004P3oool00`000000oooo0?ooo`0Z0?ooo`030000003oool0
oooo0=h0oooo000B0?ooo`030000003oool0oooo02X0oooo0P00003O0?ooo`004P3oool00`000000
oooo0?ooo`0[0?ooo`030000003oool0oooo0=d0oooo000B0?ooo`800000;03oool00`000000oooo
0?ooo`3M0?ooo`004P3oool00`000000oooo0?ooo`0[0?ooo`030000003oool0oooo0=d0oooo000B
0?ooo`030000003oool0oooo02/0oooo00<000000?ooo`3oool0g@3oool00180oooo00<000000?oo
o`3oool0:`3oool00`000000oooo0?ooo`3M0?ooo`004P3oool2000002`0oooo0P00003N0?ooo`00
4P3oool00`000000oooo0?ooo`0/0?ooo`030000003oool0oooo0=`0oooo000B0?ooo`030000003o
ool0oooo02`0oooo0P00003M0?ooo`004P3oool00`000000oooo0?ooo`0]0?ooo`030000003oool0
oooo0=/0oooo000B0?ooo`800000;P3oool00`000000oooo0?ooo`0/0?ooo`030000003oool0oooo
0100oooo00<000000?ooo`3oool0V@3oool000D0oooo0`0000030?ooo`8000001@3oool00`000000
oooo0?ooo`0]0?ooo`030000003oool0oooo02`0oooo00<000000?ooo`3oool0403oool00`000000
oooo0?ooo`2I0?ooo`001P3oool01@000000oooo0?ooo`3oool000000080oooo00<000000?ooo`3o
ool00P3oool00`000000oooo0?ooo`0^0?ooo`030000003oool0oooo02/0oooo0`00000@0?ooo`03
0000003oool0oooo09T0oooo00030?ooo`D000000P3oool010000000oooo0?ooo`0000040?ooo`03
0000003oool0oooo02h0oooo00<000000?ooo`3oool0:`3oool00`000000oooo0000000@0?ooo`03
0000003oool0oooo09T0oooo00030?ooo`040000003oool0oooo000000<0oooo00@000000?ooo`3o
ool00000103oool3000002h0oooo00<000000?ooo`0000000`0000040?ooo`8000008P3oool01000
0000oooo00000000000=0?ooo`<00000V`3oool000@0oooo00<000000?ooo`0000000`3oool01000
0000oooo0?ooo`0000040?ooo`030000003oool0oooo02h0oooo00<000000?ooo`0000000`000004
0?ooo`030000003oool0oooo0240oooo0P0000000`3oool000000?ooo`0<0?ooo`<00000V`3oool0
00D0oooo0P0000030?ooo`040000003oool0oooo000000@0oooo00<000000?ooo`3oool0;P3oool6
00000080oooo00@000000?ooo`00000000008P3oool2000000030?ooo`000000oooo00T0oooo1`00
002J0?ooo`001P3oool00`000000oooo0?ooo`020?ooo`8000001@3oool00`000000oooo0?ooo`0^
0?ooo`<0000000<0oooo0000000000000P3oool010000000oooo00000000000R0?ooo`040000003o
ool0oooo000000X0oooo1`00002J0?ooo`004P3oool2000002l0oooo0`0000001@3oool000000000
00000000oooo00@000008P3oool010000000oooo0?ooo`0000090?ooo`P000000P3oool00`000000
oooo0?ooo`1g0?ooo`030000003oool0oooo01/0oooo000B0?ooo`030000003oool0oooo0300oooo
00<000000?ooo`3oool00P0000000`3oool000000000000200000280oooo00@000000?ooo`3oool0
00002@3oool2000000D0oooo00@000000?ooo`3oool00000N@3oool00`000000oooo0?ooo`0K0?oo
o`004P3oool00`000000oooo0?ooo`0`0?ooo`030000003oool0oooo00P000008@3oool01@000000
oooo0?ooo`3oool0000000P0oooo0P0000050?ooo`@00000C03oool00`000000oooo0?ooo`0Z0?oo
o`030000003oool0oooo01/0oooo000B0?ooo`030000003oool0oooo03@0oooo1P00000R0?ooo`05
0000003oool0oooo0?ooo`000000203oool2000000D0oooo1000001<0?ooo`030000003oool0oooo
02X0oooo00<000000?ooo`3oool06`3oool00180oooo0P00000e0?ooo`/000007@3oool01@000000
oooo0?ooo`3oool0000000P0oooo0P0000050?ooo`@00000303oool2000000`0oooo0P00000_0?oo
o`800000;03oool00`000000oooo0?ooo`020?ooo`8000005`3oool00180oooo00<000000?ooo`3o
ool0=03oool;000001d0oooo00D000000?ooo`3oool0oooo000000080?ooo`030000003oool0oooo
00D0oooo0`00000<0?ooo`800000303oool2000002l0oooo0P00000/0?ooo`030000003oool0oooo
0080oooo00<000000?ooo`3oool05P3oool00180oooo00<000000?ooo`3oool0=03oool<000000H0
oooo0P00000D0?ooo`050000003oool0oooo0?ooo`000000203oool00`000000oooo0?ooo`050?oo
o`@000002`3oool3000000/0oooo0P00000_0?ooo`<000001@3oool00`000000oooo0?ooo`0C0?oo
o`8000001P3oool3000000D0oooo0`0000020?ooo`030000003oool0oooo01H0oooo000B0?ooo`03
0000003oool0oooo03d0oooo0P0000070?ooo`800000503oool01@000000oooo0?ooo`3oool00000
00P0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`090?ooo`800000303oool20000
02l0oooo0P0000060?ooo`030000003oool0oooo01<0oooo0P0000060?ooo`<000001@3oool30000
0080oooo00<000000?ooo`3oool05P3oool00180oooo0P00000n0?ooo`<000001P3oool300000140
oooo0`0000030?ooo`030000003oool0000000H0oooo00<000000?ooo`3oool0203oool01@000000
oooo0?ooo`3oool0000000@0oooo0P0000000`3oool000000?ooo`02000000X0oooo00<000000?oo
o`000000;P3oool3000000D0oooo0P00000D0?ooo`H0000000<0oooo0000000000000`0000030?oo
o`D0000000<0oooo0000003oool05`3oool00180oooo00<000000?ooo`3oool0?@3oool3000000H0
oooo00<000000?ooo`0000004@3oool3000000<0oooo00<000000?ooo`0000001P3oool00`000000
oooo0?ooo`080?ooo`050000003oool0oooo0?ooo`000000103oool2000000030?ooo`000000oooo
008000002P3oool00`000000oooo0000000^0?ooo`030000003oool0000000D0oooo0P00000D0?oo
o`80000000D0oooo00000000000000000?ooo`05000000<0oooo00L000000?ooo`000000oooo0000
003oool0000001P0oooo000B0?ooo`030000003oool0oooo03d0oooo1@0000040?ooo`040000003o
ool0000000000100oooo0`0000030?ooo`@000001@3oool00`000000oooo0?ooo`080?ooo`040000
003oool0oooo0?ooo`8000000`3oool4000000040?ooo`00000000000?ooo`8000001`3oool40000
02d0oooo00<000000?ooo`0000000P3oool00`000000oooo0?ooo`02000000T0oooo0P0000090?oo
o`030000003oool0000000<0000000<0oooo0000000000000`0000030?ooo`070000003oool00000
0?ooo`000000oooo0000000H0?ooo`004P3oool00`000000oooo0?ooo`0o0?ooo`<00000103oool0
10000000oooo00000000000@0?ooo`030000003oool0oooo00@0oooo0`0000050?ooo`030000003o
ool0oooo00P0oooo00D000000?ooo`3oool0oooo000000040?ooo`050000003oool000000000003o
ool00P0000000`3oool00000000000070?ooo`040000003oool0oooo000002d0oooo00<000000?oo
o`0000000P3oool00`000000oooo0?ooo`02000000T0oooo0P0000090?ooo`030000003oool00000
00<0000000<0oooo0000003oool00P3oool01@000000oooo0?ooo`3oool0000000<0oooo00<00000
0?ooo`000000603oool00180oooo0P0000110?ooo`<000000`3oool010000000oooo00000000000@
0?ooo`030000003oool0oooo00@0oooo0`0000040?ooo`8000002P3oool3000000040?ooo`000000
000000000080oooo00D000000?ooo`00000000000?ooo`05000000L0oooo00@000000?ooo`3oool0
0000;@3oool01@000000oooo000000000000oooo00<0000000<0oooo0000003oool0203oool40000
00H0oooo0P0000001@3oool00000000000000000oooo008000000`3oool01@000000oooo0?ooo`3o
ool0000000<0oooo00<000000?ooo`000000603oool000@0oooo0`0000040?ooo`8000001@3oool0
0`000000oooo0?ooo`120?ooo`060000003oool0oooo0?ooo`000000oooo0P00000@0?ooo`030000
003oool0oooo00@0oooo0`0000040?ooo`030000003oool0oooo00T0oooo0`000000103oool00000
0000000000020?ooo`030000003oool0000000@0oooo0`0000070?ooo`040000003oool0oooo0000
02d0oooo00X000000?ooo`3oool000000?ooo`000000oooo0000003oool000002@3oool4000000H0
oooo0P00000:0?ooo`050000003oool0oooo0?ooo`0000000`3oool00`000000oooo0000000H0?oo
o`000`3oool01@000000oooo0?ooo`3oool000000080oooo00@000000?ooo`3oool00000103oool0
0`000000oooo0?ooo`120?ooo`030000003oool0oooo0080000000@0oooo00000000000000003P3o
ool2000000H0oooo100000030?ooo`030000003oool0oooo00T0oooo1`0000020?ooo`030000003o
ool0000000@0oooo0`0000070?ooo`040000003oool0oooo000002d0oooo00<000000?ooo`3oool0
0`0000000`3oool000000?ooo`03000000L0oooo1@0000040?ooo`<000002P3oool3000000030?oo
o`000000oooo0080oooo0`00000H0?ooo`001`3oool010000000oooo0?ooo`0000020?ooo`030000
003oool0oooo0080oooo00<000000?ooo`3oool0@P3oool010000000oooo0?ooo`0000030?ooo`03
0000003oool0oooo00d0oooo00<000000?ooo`3oool01@3oool2000000030?ooo`000000oooo0080
oooo00<000000?ooo`3oool02P3oool300000080oooo00@000000?ooo`3oool000001P3oool30000
00L0oooo00@000000?ooo`3oool00000;@3oool00`000000oooo0?ooo`0200000080oooo00@00000
0?ooo`3oool00000203oool3000000030?ooo`000000oooo00<0oooo00<000000?ooo`3oool02`3o
ool2000000030?ooo`000000oooo0080oooo00<000000?ooo`3oool0603oool000L0oooo00@00000
0?ooo`3oool000000P3oool00`000000oooo0?ooo`020?ooo`<00000@P3oool2000000030?ooo`00
0000oooo0080oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`050?ooo`80000000<0
oooo0000000000000P3oool00`000000oooo0?ooo`0:0?ooo`<000000P3oool010000000oooo0?oo
o`0000060?ooo`<000001`3oool010000000oooo0?ooo`00000/0?ooo`8000000P3oool200000080
oooo00<000000?ooo`3oool00P000000103oool000000?ooo`3oool2000000050?ooo`0000000000
0000003oool00`0000020?ooo`030000003oool0oooo00/0oooo0P0000000`3oool000000?ooo`02
0?ooo`030000003oool0oooo01P0oooo00030?ooo`@000000`3oool010000000oooo0?ooo`000004
0?ooo`030000003oool0oooo0480oooo0P0000000`3oool000000?ooo`020?ooo`030000003oool0
oooo00d0oooo00<000000?ooo`3oool01@3oool2000000030?ooo`000000oooo0080oooo00<00000
0?ooo`3oool03`3oool010000000oooo0?ooo`0000080?ooo`030000003oool0oooo00D0oooo00@0
00000?ooo`3oool00000;03oool2000000X0oooo00<000000?ooo`0000000P3oool2000000050?oo
o`000000oooo0000003oool00P0000030?ooo`030000003oool0oooo00`0oooo00<000000?ooo`00
00007P3oool000<0oooo00<000000?ooo`3oool0103oool010000000oooo0?ooo`0000040?ooo`03
0000003oool0oooo0480oooo0P0000000`3oool000000?ooo`020?ooo`8000003P3oool00`000000
oooo0?ooo`050?ooo`80000000<0oooo0000003oool00P3oool00`000000oooo0?ooo`0?0?ooo`80
000000<0oooo0000003oool01`3oool2000000H0oooo00<000000?ooo`3oool00P00000[0?ooo`80
00002P3oool01@000000oooo000000000000oooo00@0000000<0oooo0000000000000P0000020?oo
o`8000003P3oool3000001h0oooo00030?ooo`D000000`3oool2000000D0oooo00<000000?ooo`3o
ool0@`3oool00`000000oooo000000040?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3o
ool01@3oool2000000030?ooo`000000oooo0080oooo00<000000?ooo`3oool0403oool00`000000
oooo000000090?ooo`030000003oool0oooo00@0oooo00@000000?ooo`3oool00000;03oool00`00
0000oooo0?ooo`090?ooo`060000003oool000000000003oool000000P3oool010000000oooo0?oo
o`3oool200000080oooo0P00000>0?ooo`<000007P3oool00180oooo0P0000140?ooo`030000003o
ool0000000@0oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`060?ooo`040000003o
ool0oooo00000080oooo00<000000?ooo`3oool0403oool00`000000oooo000000090?ooo`030000
003oool0oooo0080oooo0`0000020?ooo`800000:`3oool00`000000oooo0?ooo`090?ooo`H00000
0P3oool010000000oooo0?ooo`3oool3000000030?ooo`000000000000h0oooo0`00000N0?ooo`00
4P3oool00`000000oooo0?ooo`130?ooo`030000003oool0000000@0oooo00<000000?ooo`3oool0
303oool00`000000oooo0?ooo`060?ooo`040000003oool0oooo00000080oooo00<000000?ooo`3o
ool0403oool2000000X0oooo00<000000?ooo`3oool00P3oool3000000<0oooo00<000000?ooo`3o
ool0:@3oool00`000000oooo0?ooo`090?ooo`@0000000D0oooo0000003oool0oooo000000040?oo
o`80000000<0oooo0000003oool03P3oool2000001l0oooo000B0?ooo`030000003oool0oooo04@0
oooo0P0000050?ooo`030000003oool0oooo00T0oooo00<000000?ooo`000000203oool00`000000
oooo0?ooo`02000000030?ooo`000000oooo0140oooo0P00000:0?ooo`<000000P3oool3000000<0
oooo00<000000?ooo`3oool0503oool2000001<0oooo00<000000?ooo`3oool02@3oool600000080
oooo00<000000?ooo`3oool00P3oool4000000l0oooo0`00000N0?ooo`004P3oool00`000000oooo
0?ooo`140?ooo`8000001@3oool00`000000oooo0?ooo`090?ooo`030000003oool0000000`0oooo
00<000000?ooo`0000004P3oool2000000/0oooo0P0000020?ooo`<000000`3oool00`000000oooo
0?ooo`0D0?ooo`8000004`3oool00`000000oooo0?ooo`0=0?ooo`8000000P3oool00`000000oooo
0?ooo`030?ooo`<00000<03oool00180oooo0P0000150?ooo`8000001@3oool00`000000oooo0?oo
o`080?ooo`<000003@3oool00`000000oooo0000000B0?ooo`800000303oool2000000040?ooo`00
00000000000000<0oooo0P00000E0?ooo`<000004P3oool00`000000oooo0?ooo`0=0?ooo`800000
0P3oool00`000000oooo0?ooo`030?ooo`<00000<03oool00180oooo00<000000?ooo`3oool0A03o
ool2000000D0oooo00<000000?ooo`3oool0203oool2000000h0oooo00<000000?ooo`0000004P3o
ool2000000`0oooo0P000000103oool000000?ooo`0000030?ooo`030000003oool0oooo01@0oooo
0P00000C0?ooo`030000003oool0oooo00d0oooo0P0000090?ooo`800000<03oool00180oooo00<0
00000?ooo`3oool0A03oool2000000D0oooo0P0000060?ooo`030000003oool00000008000003P3o
ool300000180oooo0`00000;0?ooo`80000000@0oooo0000003oool000000`3oool200000080oooo
0P00000>0?ooo`030000003oool0000000<000004P3oool00`000000oooo0?ooo`0=0?ooo`800000
2@3oool200000300oooo000B0?ooo`030000003oool0oooo04D0oooo00<000000?ooo`3oool00`3o
ool2000000H0oooo00@000000?ooo`00000000003`3oool300000240oooo00D000000?ooo`000000
oooo000000040?ooo`040000003oool0oooo000000l0oooo00<000000?ooo`0000000`00000B0?oo
o`030000003oool0oooo04X0oooo000B0?ooo`800000AP3oool00`000000oooo0?ooo`030?ooo`80
00001P3oool010000000oooo00000000000?0?ooo`<000008@3oool010000000oooo0000003oool2
000000<0oooo1000000>0?ooo`@0000000<0oooo0000000000001000000>0?ooo`030000003oool0
oooo04X0oooo000B0?ooo`030000003oool0oooo04/0oooo0P0000060?ooo`040000003oool00000
000000l0oooo00<000000?ooo`0000008@3oool00`000000oooo000000060?ooo`@000003P3oool4
000000<0oooo0`00000?0?ooo`030000003oool0oooo04X0oooo000B0?ooo`030000003oool0oooo
04/0oooo0P0000060?ooo`040000003oool00000000000l0oooo00<000000?ooo`0000008@3oool3
000000H0oooo10000000103oool000000?ooo`0000030?ooo`80000000<0oooo0000000000001P00
00030?ooo`@000003P3oool00`000000oooo0?ooo`1:0?ooo`004P3oool00`000000oooo0?ooo`1<
0?ooo`030000003oool0oooo00@0oooo00@000000?ooo`0000000000=03oool2000000L0oooo0`00
0000103oool000000?ooo`0000030?ooo`80000000<0oooo0000003oool01@0000060?ooo`800000
3P3oool00`000000oooo0?ooo`1:0?ooo`004P3oool2000004d0oooo0P0000050?ooo`@00000=03o
ool2000000L0oooo3P0000000`3oool0000000000004000000D0oooo0P00000>0?ooo`030000003o
ool0oooo04X0oooo00040?ooo`<00000103oool2000000D0oooo00<000000?ooo`3oool0C@3oool0
0`000000oooo0?ooo`030?ooo`<00000=@3oool2000000L0oooo3P000000103oool0000000000000
00090?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool0BP3oool000<0oooo00D00000
0?ooo`3oool0oooo000000020?ooo`040000003oool0oooo000000@0oooo00<000000?ooo`3oool0
C@3oool2000000@0oooo0`00000e0?ooo`8000001`3oool4000000030?ooo`000000000000L00000
00@0oooo00000000000000002@3oool2000000d0oooo00<000000?ooo`3oool0BP3oool000<0oooo
00D000000?ooo`3oool0oooo000000020?ooo`040000003oool0oooo000000@0oooo00<000000?oo
o`3oool0C@3oool00`000000oooo0?ooo`030?ooo`<00000=@3oool2000000T0oooo00<000000?oo
o`3oool00`3oool3000000030?ooo`000000000000h0oooo00<000000?ooo`3oool02`3oool00`00
0000oooo0?ooo`1:0?ooo`000`3oool4000000<0oooo00@000000?ooo`3oool00000103oool30000
04h0oooo00<000000?ooo`3oool00P3oool3000003H0oooo00<000000?ooo`3oool01`3oool00`00
0000oooo0?ooo`030?ooo`<0000000<0oooo0000000000003P3oool00`000000oooo000000040?oo
o`8000001@3oool00`000000oooo0?ooo`1:0?ooo`000`3oool00`000000oooo0?ooo`040?ooo`04
0000003oool0oooo000000@0oooo00<000000?ooo`3oool0CP3oool00`000000oooo0?ooo`020?oo
o`<00000B03oool00`000000oooo0000000?0?ooo`030000003oool0000000@0oooo00<000000?oo
o`3oool0103oool00`000000oooo0?ooo`1:0?ooo`00103oool00`000000oooo0?ooo`030?ooo`04
0000003oool0oooo000000@0oooo00<000000?ooo`3oool0CP3oool00`000000oooo0?ooo`020?oo
o`800000B@3oool00`000000oooo0000000?0?ooo`@000000`3oool2000000@0oooo0P00001<0?oo
o`001@3oool2000000@0oooo0P0000050?ooo`030000003oool0oooo04h0oooo00<000000?ooo`3o
ool00P3oool00`000000oooo0?ooo`1:0?ooo`030000003oool0oooo00d0oooo100000030?ooo`80
0000103oool2000004`0oooo000B0?ooo`800000C`3oool2000000<0oooo00<000000?ooo`3oool0
BP3oool00`000000oooo0?ooo`0=0?ooo`D000000P3oool2000000<0oooo0`00001<0?ooo`004P3o
ool00`000000oooo0?ooo`1>0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0FP3o
ool2000000030?ooo`00000000000080oooo0P0000030?ooo`800000C@3oool00180oooo00<00000
0?ooo`3oool0CP3oool200000080oooo0P00001L0?ooo`80000000@0oooo000000000000oooo0`00
00020?ooo`<00000C@3oool00180oooo00<000000?ooo`3oool0C`3oool010000000oooo0?ooo`00
001P0?ooo`80000000@0oooo00000000000000000P3oool3000004d0oooo000B0?ooo`800000D03o
ool010000000oooo0?ooo`00001Q0?ooo`H0000000@0oooo0000000000000000C@3oool00180oooo
00<000000?ooo`3oool0C`3oool010000000oooo0?ooo`00001S0?ooo`@0000000<0oooo0000003o
ool0CP3oool00180oooo00<000000?ooo`3oool0C`3oool010000000oooo0?ooo`00001S0?ooo`H0
0000C`3oool00180oooo00<000000?ooo`3oool0C`3oool010000000oooo0?ooo`00001S0?ooo`80
00000P3oool2000004l0oooo000B0?ooo`800000D03oool4000006<0oooo0P0000020?ooo`800000
C`3oool00180oooo00<000000?ooo`3oool0D@3oool2000006@0oooo00<000000?ooo`3oool00P00
001?0?ooo`004P3oool00`000000oooo0?ooo`1A0?ooo`800000I03oool00`000000oooo0?ooo`02
000004l0oooo000B0?ooo`030000003oool0oooo0?l0oooo303oool00180oooo0P00003o0?ooo`d0
oooo00050?ooo`030000003oool0oooo00<0oooo0P0000050?ooo`030000003oool0oooo0?l0oooo
303oool000D0oooo00<000000?ooo`3oool00P3oool010000000oooo0?ooo`0000040?ooo`030000
003oool0oooo0?l0oooo303oool000H0oooo00D000000?ooo`3oool0oooo000000020?ooo`030000
003oool0oooo0080oooo00<000000?ooo`3oool0o`3oool<0?ooo`001P3oool01@000000oooo0?oo
o`3oool000000080oooo00<000000?ooo`3oool00P3oool300000?l0oooo303oool000L0oooo00@0
00000?ooo`3oool000000P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0?l0oooo
303oool000<0oooo00D000000?ooo`3oool0oooo000000020?ooo`040000003oool0oooo000000@0
oooo00<000000?ooo`3oool0o`3oool<0?ooo`000`3oool5000000<0oooo0P0000050?ooo`030000
003oool0oooo0?l0oooo303oool00180oooo0P00003o0?ooo`d0oooo000B0?ooo`030000003oool0
oooo0?l0oooo303oool00180oooo00<000000?ooo`3oool0o`3oool<0?ooo`004P3oool00`000000
oooo0?ooo`3o0?ooo``0oooo000B0?ooo`800000o`3oool=0?ooo`004P3oool00`000000oooo0?oo
o`3o0?ooo``0oooo000B0?ooo`030000003oool0oooo0?l0oooo303oool00180oooo00<000000?oo
o`3oool0o`3oool<0?ooo`004P3oool200000?l0oooo3@3oool00180oooo00<000000?ooo`3oool0
o`3oool<0?ooo`004P3oool00`000000oooo0?ooo`3o0?ooo``0oooo000B0?ooo`030000003oool0
oooo0?l0oooo303oool00180oooo0P00003o0?ooo`d0oooo00040?ooo`<00000103oool2000000D0
oooo00<000000?ooo`3oool0o`3oool<0?ooo`000`3oool01@000000oooo0?ooo`3oool000000080
oooo00@000000?ooo`3oool00000103oool00`000000oooo0?ooo`3o0?ooo``0oooo00030?ooo`05
0000003oool0oooo0?ooo`0000000P3oool010000000oooo0?ooo`0000040?ooo`030000003oool0
oooo0?l0oooo303oool000@0oooo0`0000030?ooo`040000003oool0oooo000000@0oooo0`00003o
0?ooo``0oooo00030?ooo`050000003oool0oooo0?ooo`0000000P3oool010000000oooo0?ooo`00
003o0?oooa<0oooo00030?ooo`050000003oool0oooo0?ooo`0000000P3oool010000000oooo0?oo
o`00003o0?oooa<0oooo00040?ooo`<00000103oool200000?l0oooo503oool00?l0oooo8@3oool0
0001\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.71442, -6.11292, \
0.0385797, 0.499386}}],

Cell[BoxData[
    \(52.637239165329056`\)], "Output",
  CellLabel->"Out[197]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(Show[Plot[\(\[ExponentialE]\^\(-50\)\) 50\^k\/\(k!\), {k, 0, 100}], 
        ListPlot[Transpose[{Range[0.5, 99.5], bc/Plus @@ bc}], 
          PlotJoined -> True], 
        PlotRange -> {{0, 100}, {0, 0.08}}];\)\)], "Input",
  CellLabel->"In[320]:="],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.04083e-17 0.01 0 7.72542 [
[.2 -0.0125 -6 -9 ]
[.2 -0.0125 6 0 ]
[.4 -0.0125 -6 -9 ]
[.4 -0.0125 6 0 ]
[.6 -0.0125 -6 -9 ]
[.6 -0.0125 6 0 ]
[.8 -0.0125 -6 -9 ]
[.8 -0.0125 6 0 ]
[1 -0.0125 -9 -9 ]
[1 -0.0125 9 0 ]
[-0.0125 .07725 -24 -4.5 ]
[-0.0125 .07725 0 4.5 ]
[-0.0125 .15451 -24 -4.5 ]
[-0.0125 .15451 0 4.5 ]
[-0.0125 .23176 -24 -4.5 ]
[-0.0125 .23176 0 4.5 ]
[-0.0125 .30902 -24 -4.5 ]
[-0.0125 .30902 0 4.5 ]
[-0.0125 .38627 -24 -4.5 ]
[-0.0125 .38627 0 4.5 ]
[-0.0125 .46353 -24 -4.5 ]
[-0.0125 .46353 0 4.5 ]
[-0.0125 .54078 -24 -4.5 ]
[-0.0125 .54078 0 4.5 ]
[-0.0125 .61803 -24 -4.5 ]
[-0.0125 .61803 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 0 m
.2 .00625 L
s
[(20)] .2 -0.0125 0 1 Mshowa
.4 0 m
.4 .00625 L
s
[(40)] .4 -0.0125 0 1 Mshowa
.6 0 m
.6 .00625 L
s
[(60)] .6 -0.0125 0 1 Mshowa
.8 0 m
.8 .00625 L
s
[(80)] .8 -0.0125 0 1 Mshowa
1 0 m
1 .00625 L
s
[(100)] 1 -0.0125 0 1 Mshowa
.125 Mabswid
.05 0 m
.05 .00375 L
s
.1 0 m
.1 .00375 L
s
.15 0 m
.15 .00375 L
s
.25 0 m
.25 .00375 L
s
.3 0 m
.3 .00375 L
s
.35 0 m
.35 .00375 L
s
.45 0 m
.45 .00375 L
s
.5 0 m
.5 .00375 L
s
.55 0 m
.55 .00375 L
s
.65 0 m
.65 .00375 L
s
.7 0 m
.7 .00375 L
s
.75 0 m
.75 .00375 L
s
.85 0 m
.85 .00375 L
s
.9 0 m
.9 .00375 L
s
.95 0 m
.95 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .07725 m
.00625 .07725 L
s
[(0.01)] -0.0125 .07725 1 0 Mshowa
0 .15451 m
.00625 .15451 L
s
[(0.02)] -0.0125 .15451 1 0 Mshowa
0 .23176 m
.00625 .23176 L
s
[(0.03)] -0.0125 .23176 1 0 Mshowa
0 .30902 m
.00625 .30902 L
s
[(0.04)] -0.0125 .30902 1 0 Mshowa
0 .38627 m
.00625 .38627 L
s
[(0.05)] -0.0125 .38627 1 0 Mshowa
0 .46353 m
.00625 .46353 L
s
[(0.06)] -0.0125 .46353 1 0 Mshowa
0 .54078 m
.00625 .54078 L
s
[(0.07)] -0.0125 .54078 1 0 Mshowa
0 .61803 m
.00625 .61803 L
s
[(0.08)] -0.0125 .61803 1 0 Mshowa
.125 Mabswid
0 .01545 m
.00375 .01545 L
s
0 .0309 m
.00375 .0309 L
s
0 .04635 m
.00375 .04635 L
s
0 .0618 m
.00375 .0618 L
s
0 .09271 m
.00375 .09271 L
s
0 .10816 m
.00375 .10816 L
s
0 .12361 m
.00375 .12361 L
s
0 .13906 m
.00375 .13906 L
s
0 .16996 m
.00375 .16996 L
s
0 .18541 m
.00375 .18541 L
s
0 .20086 m
.00375 .20086 L
s
0 .21631 m
.00375 .21631 L
s
0 .24721 m
.00375 .24721 L
s
0 .26266 m
.00375 .26266 L
s
0 .27812 m
.00375 .27812 L
s
0 .29357 m
.00375 .29357 L
s
0 .32447 m
.00375 .32447 L
s
0 .33992 m
.00375 .33992 L
s
0 .35537 m
.00375 .35537 L
s
0 .37082 m
.00375 .37082 L
s
0 .40172 m
.00375 .40172 L
s
0 .41717 m
.00375 .41717 L
s
0 .43262 m
.00375 .43262 L
s
0 .44807 m
.00375 .44807 L
s
0 .47898 m
.00375 .47898 L
s
0 .49443 m
.00375 .49443 L
s
0 .50988 m
.00375 .50988 L
s
0 .52533 m
.00375 .52533 L
s
0 .55623 m
.00375 .55623 L
s
0 .57168 m
.00375 .57168 L
s
0 .58713 m
.00375 .58713 L
s
0 .60258 m
.00375 .60258 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
0 0 m
.00123 0 L
.00236 0 L
.00365 0 L
.00488 0 L
.00601 0 L
.00706 0 L
.00821 0 L
.00942 0 L
.01065 0 L
.01196 0 L
.0132 0 L
.01434 0 L
.01566 0 L
.01641 0 L
.01711 0 L
.01839 0 L
.01975 0 L
.02043 0 L
.02115 0 L
.02245 0 L
.02317 0 L
.02384 0 L
.02463 0 L
.02537 0 L
.02671 0 L
.02793 0 L
.02924 0 L
.02998 0 L
.03067 0 L
.03184 0 L
.03295 0 L
.03416 0 L
.03547 0 L
.03676 0 L
.03813 0 L
.03929 0 L
.04057 0 L
.042 0 L
.04355 0 L
.04502 0 L
.04637 0 L
.04759 0 L
.04894 0 L
.05034 0 L
.05165 0 L
.05318 0 L
.05463 0 L
.05593 0 L
.05735 0 L
Mistroke
.0589 0 L
.06054 0 L
.06208 0 L
.06349 0 L
.06483 0 L
.06624 0 L
.06744 0 L
.06877 0 L
.07019 0 L
.07172 0 L
.07316 0 L
.07447 0 L
.07702 0 L
.07846 0 L
.07978 0 L
.08222 0 L
.08345 0 L
.08481 0 L
.08728 0 L
.08869 0 L
.08999 0 L
.09262 0 L
.0941 0 L
.09543 0 L
.09784 0 L
.09919 0 L
.10044 0 L
.10274 0 L
.10516 0 L
.10653 0 L
.10777 0 L
.10911 0 L
.11056 0 L
.11315 0 L
.11561 0 L
.11698 0 L
.11849 0 L
.11997 0 L
.12156 0 L
.12304 0 L
.12441 0 L
.12708 0 L
.12968 0 L
.13204 0 L
.13477 0 L
.13735 0 L
.13974 0 L
.14194 0 L
.14436 0 L
.14692 0 L
Mistroke
.1495 0 L
.15226 0 L
.15488 0 L
.15726 0 L
.16006 0 L
.1631 0 L
.16598 0 L
.16865 0 L
.17143 0 L
.17399 0 L
.17679 0 L
.17976 0 L
.18233 0 L
.18474 0 L
.18738 0 L
.19021 0 L
.19273 0 L
.19546 0 L
.19788 0 L
.20044 1e-05 L
.20274 1e-05 L
.20528 1e-05 L
.20976 1e-05 L
.21222 2e-05 L
.21492 2e-05 L
.21755 3e-05 L
.22036 3e-05 L
.2254 5e-05 L
.23009 7e-05 L
.23292 9e-05 L
.23599 .00011 L
.2387 .00013 L
.24156 .00016 L
.24699 .00023 L
.25199 .00033 L
.25717 .00046 L
.26191 .00062 L
.26737 .00087 L
.27256 .00119 L
.27734 .00157 L
.28176 .00201 L
.28662 .00262 L
.29179 .00345 L
.29744 .00461 L
.30263 .00595 L
.30833 .00781 L
.31433 .01028 L
.32445 .01592 L
.33018 .02012 L
.33553 .02481 L
Mistroke
.34654 .03722 L
.35696 .0529 L
.37646 .09433 L
.39742 .15718 L
.41678 .22857 L
.4381 .31154 L
.44854 .3491 L
.45809 .37936 L
.46723 .40328 L
.47206 .41354 L
.47722 .42249 L
.48008 .42654 L
.48269 .42961 L
.48533 .43215 L
.48777 .43394 L
.48895 .43463 L
.49025 .43524 L
.49155 .43571 L
.49293 .43604 L
.49415 .43619 L
.49545 .43621 L
.49668 .4361 L
.4978 .43588 L
.49904 .43551 L
.5002 .43505 L
.50284 .43356 L
.50542 .43154 L
.5082 .42874 L
.51322 .42213 L
.51783 .41438 L
.52845 .39098 L
.53962 .35947 L
.57963 .22122 L
.60193 .14966 L
.6222 .09771 L
.63231 .07707 L
.64328 .05851 L
.66319 .03385 L
.67312 .02519 L
.68405 .0179 L
.69546 .0123 L
.70614 .00851 L
.71706 .00574 L
.72743 .00389 L
.73674 .00271 L
.74689 .00181 L
.75248 .00143 L
.75775 .00115 L
.76758 .00075 L
.7731 .00059 L
Mistroke
.77817 .00047 L
.78369 .00037 L
.78961 .00028 L
.79497 .00022 L
.79985 .00017 L
.80941 .00011 L
.81475 8e-05 L
.82056 6e-05 L
.82604 5e-05 L
.83111 4e-05 L
.83599 3e-05 L
.84124 2e-05 L
.8462 2e-05 L
.85074 1e-05 L
.85578 1e-05 L
.86129 1e-05 L
.86704 1e-05 L
.87239 0 L
.8777 0 L
.88346 0 L
.88889 0 L
.8939 0 L
.89842 0 L
.90339 0 L
.90858 0 L
.91342 0 L
.91867 0 L
.92437 0 L
.92977 0 L
.93476 0 L
.93924 0 L
.9442 0 L
.94937 0 L
.95423 0 L
.95915 0 L
.96453 0 L
.96725 0 L
.97015 0 L
.97539 0 L
.98062 0 L
.98556 0 L
.98999 0 L
.99481 0 L
1 0 L
Mfstroke
.005 0 m
.015 0 L
.025 0 L
.035 0 L
.045 0 L
.055 0 L
.065 0 L
.075 0 L
.085 0 L
.095 0 L
.105 0 L
.115 0 L
.125 0 L
.135 0 L
.145 0 L
.155 0 L
.165 0 L
.175 0 L
.185 0 L
.195 0 L
.205 0 L
.215 0 L
.225 0 L
.235 0 L
.245 0 L
.255 0 L
.265 0 L
.275 0 L
.285 0 L
.295 0 L
.305 0 L
.315 0 L
.325 0 L
.335 0 L
.345 0 L
.355 0 L
.365 0 L
.375 .031 L
.385 .0186 L
.395 .0372 L
.405 .124 L
.415 .093 L
.425 .062 L
.435 .32861 L
.445 .31001 L
.455 .43401 L
.465 .39061 L
.475 .57972 L
s
.475 .57972 m
.48227 .61803 L
s
.48559 .61803 m
.495 .38751 L
.505 .31931 L
.515 .26971 L
.525 .31311 L
.535 .31001 L
.545 .37201 L
.555 .33481 L
.565 .54252 L
.575 .38751 L
.585 .31621 L
.595 .1147 L
.605 .1488 L
.615 .1612 L
.625 .1643 L
.635 .1705 L
.645 .1054 L
.655 .1674 L
.665 .0992 L
.675 0 L
.685 0 L
.695 0 L
.705 0 L
.715 0 L
.725 0 L
.735 0 L
.745 0 L
.755 0 L
.765 0 L
.775 0 L
.785 0 L
.795 0 L
.805 0 L
.815 0 L
.825 0 L
.835 0 L
.845 0 L
.855 0 L
.865 0 L
.875 0 L
.885 0 L
.895 0 L
.905 0 L
.915 0 L
.925 0 L
.935 0 L
.945 0 L
.955 0 L
.965 0 L
.975 0 L
Mistroke
.985 0 L
.995 0 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[320]:=",
  ImageSize->{588.75, 363.875},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40009<0001Jb000`400?l00000o`00003oo`3ooooo
0?ooodh0oooo003o0?ooool0ooooCP3oool00?l0ooooo`3ooom>0?ooo`00QP3oool5000000<0oooo
0P00001V0?ooo`<000000`3oool2000006@0oooo0`0000040?ooo`800000I@3oool3000000@0oooo
0P00001Q0?ooo`<00000103oool2000000@0oooo0P0000030?ooo`00Q`3oool010000000oooo0?oo
o`0000020?ooo`040000003oool0oooo000006H0oooo00D000000?ooo`3oool0oooo000000020?oo
o`030000003oool0oooo0600oooo00D000000?ooo`3oool0oooo000000020?ooo`040000003oool0
oooo000006<0oooo00D000000?ooo`3oool0oooo000000020?ooo`040000003oool0oooo00000640
oooo00<000000?ooo`3oool00P3oool010000000oooo0?ooo`0000020?ooo`040000003oool0oooo
00000080oooo00280?ooo`030000003oool0oooo0080oooo00@000000?ooo`3oool00000H`3oool5
00000080oooo00@000000?ooo`3oool00000HP3oool01@000000oooo0?ooo`3oool000000080oooo
00@000000?ooo`3oool00000H`3oool01@000000oooo0?ooo`3oool000000080oooo00@000000?oo
o`3oool00000H@3oool00`000000oooo0?ooo`020?ooo`040000003oool0oooo00000080oooo00@0
00000?ooo`3oool000000P3oool008T0oooo00D000000?ooo`3oool0oooo000000020?ooo`030000
003oool0oooo0640oooo00@000000?ooo`3oool000000`3oool010000000oooo0?ooo`00001R0?oo
o`@000000`3oool010000000oooo0?ooo`00001T0?ooo`<000000`3oool010000000oooo0?ooo`00
001Q0?ooo`030000003oool0oooo0080oooo00@000000?ooo`3oool000000P3oool010000000oooo
0?ooo`0000020?ooo`00QP3oool01@000000oooo0?ooo`3oool000000080oooo00@000000?ooo`3o
ool00000I03oool00`000000oooo000000030?ooo`040000003oool0oooo00000680oooo00<00000
0?ooo`3oool0103oool010000000oooo0?ooo`00001S0?ooo`050000003oool0oooo0?ooo`000000
0P3oool010000000oooo0?ooo`00001Q0?ooo`030000003oool0oooo0080oooo00@000000?ooo`3o
ool000000P3oool010000000oooo0?ooo`0000020?ooo`00QP3oool01@000000oooo0?ooo`3oool0
00000080oooo00@000000?ooo`3oool00000I@3oool2000000<0oooo00@000000?ooo`3oool00000
H`3oool00`000000oooo0?ooo`030?ooo`040000003oool0oooo000006<0oooo00D000000?ooo`3o
ool0oooo000000020?ooo`040000003oool0oooo00000600oooo0P0000040?ooo`040000003oool0
oooo00000080oooo00@000000?ooo`3oool000000P3oool008L0oooo0`0000040?ooo`800000I`3o
ool00`000000oooo0?ooo`020?ooo`800000I@3oool2000000@0oooo0P00001U0?ooo`<00000103o
ool200000680oooo00<000000?ooo`3oool00`3oool2000000@0oooo0P0000030?ooo`00o`3ooooo
0?ooodh0oooo003o0?ooool0ooooCP3oool00?l0ooooo`3ooom>0?ooo`00o`3ooooo0?ooodh0oooo
003o0?ooool0ooooCP3oool00?l0ooooo`3ooom>0?ooo`00o`3ooooo0?ooodh0oooo000N0?ooool0
0000o`00000W000000T0oooo000N0?ooo`030000003oool0oooo01T0oooo00<000000?ooo`3oool0
603oool00`000000oooo0?ooo`0I0?ooo`030000003oool0oooo01P0oooo00<000000?ooo`3oool0
503ooolF000000X0oooo00<000000?ooo`3oool0603oool00`000000oooo0?ooo`050?ooo`030000
003oool0oooo0140oooo00<000000?ooo`3oool0603oool00`000000oooo0?ooo`0H0?ooo`030000
003oool0oooo01T0oooo00<000000?ooo`3oool0603oool00`000000oooo0?ooo`0H0?ooo`030000
003oool0oooo00/0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`0D0?ooob<00000
603oool00`000000oooo0?ooo`0H0?ooo`030000003oool0oooo01T0oooo00<000000?ooo`3oool0
603oool00`000000oooo0?ooo`070?ooo`007P3oool00`000000oooo0?ooo`0I0?ooo`030000003o
ool0oooo01P0oooo00<000000?ooo`3oool06@3oool00`000000oooo0?ooo`0H0?ooo`030000003o
ool0oooo01P0oooo00<000000?ooo`3oool03`3oool800000080oooo00<000000?ooo`3oool0603o
ool00`000000oooo0?ooo`060?ooo`030000003oool0oooo0100oooo00<000000?ooo`3oool0603o
ool00`000000oooo0?ooo`0H0?ooo`030000003oool0oooo01T0oooo00<000000?ooo`3oool0603o
ool00`000000oooo0?ooo`0H0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool02`3o
ool00`000000oooo0?ooo`0?0?ooo`D00000103oool00`000000oooo0?ooo`0I0?ooo`030000003o
ool0oooo01P0oooo00<000000?ooo`3oool0603oool00`000000oooo0?ooo`0I0?ooo`030000003o
ool0oooo01P0oooo00<000000?ooo`3oool01`3oool001h0oooo00<000000?ooo`3oool0J`3oool0
0`000000oooo0?ooo`0b0?ooo`<000008`3oool00`000000oooo0?ooo`0@0?ooo`030000003oool0
oooo06X0oooo00<000000?ooo`3oool09P3oool00`000000oooo0?ooo`0G0?ooo`H000009@3oool0
0`000000oooo0?ooo`1Z0?ooo`030000003oool0oooo00L0oooo000N0?ooo`030000003oool0oooo
06/0oooo00<000000?ooo`3oool0=@3oool300000200oooo00<000000?ooo`3oool0403oool00`00
0000oooo0?ooo`1Z0?ooo`030000003oool0oooo02H0oooo00<000000?ooo`3oool04@3oool60000
02/0oooo00<000000?ooo`3oool0JP3oool00`000000oooo0?ooo`070?ooo`007P3oool00`000000
oooo0?ooo`2V0?ooo`<000007P3oool00`000000oooo0?ooo`2U0?ooo`030000003oool0oooo00d0
oooo1000002X0?ooo`007P3oool00`000000oooo0?ooo`2Y0?ooo`<000006`3oool00`000000oooo
0?ooo`2T0?ooo`030000003oool0oooo00/0oooo0`00002/0?ooo`007P3oool00`000000oooo0?oo
o`2/0?ooo`8000006@3oool00`000000oooo0?ooo`2T0?ooo`030000003oool0oooo00P0oooo0`00
002_0?ooo`007P3oool00`000000oooo0?ooo`2^0?ooo`030000003oool0oooo01L0oooo00<00000
0?ooo`3oool0X`3oool00`000000oooo0?ooo`060?ooo`800000/P3oool001h0oooo0`00002_0?oo
o`8000005`3oool00`000000oooo0?ooo`2S0?ooo`030000003oool0oooo00@0oooo0P00002d0?oo
o`007P3oool00`000000oooo0?ooo`2a0?ooo`030000003oool0oooo01@0oooo00<000000?ooo`3o
ool0X`3oool00`000000oooo0?ooo`020?ooo`800000]P3oool001h0oooo00<000000?ooo`3oool0
/P3oool00`000000oooo0?ooo`0D0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0
V`3oool01@000000oooo0?ooo`3oool000000;P0oooo000N0?ooo`030000003oool0oooo0;<0oooo
00<000000?ooo`3oool04`3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo09/0oooo
00@000000?ooo`0000000000^@3oool001h0oooo00<000000?ooo`3oool0]03oool00`000000oooo
0?ooo`0B0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`000000W03oool200000;/0oooo
000N0?ooo`030000003oool0oooo0;D0oooo00<000000?ooo`3oool04P3oool01@000000oooo0?oo
o`3oool0000000<0oooo00<000000?ooo`3oool0V@3oool00`000000oooo0?ooo`2j0?ooo`007P3o
ool00`000000oooo0?ooo`2e0?ooo`030000003oool0oooo0180oooo00@000000?ooo`3oool00000
103oool00`000000oooo0?ooo`2H0?ooo`800000_03oool001h0oooo00<000000?ooo`3oool0]P3o
ool00`000000oooo0?ooo`0A0?ooo`030000003oool0000000H0oooo00<000000?ooo`3oool0UP3o
ool00`000000oooo0000002l0?ooo`007P3oool300000;L0oooo00<000000?ooo`3oool04@3oool0
0`000000oooo0?ooo`050?ooo`030000003oool0oooo09D0oooo00<000000?ooo`000000_@3oool0
01h0oooo00<000000?ooo`3oool0^03oool00`000000oooo0?ooo`0I0?ooo`030000003oool0oooo
09<0oooo00@000000?ooo`3oool00000_@3oool001h0oooo00<000000?ooo`3oool0^@3oool00`00
0000oooo0?ooo`0I0?ooo`030000003oool0oooo0940oooo00D000000?ooo`3oool0oooo0000002m
0?ooo`007P3oool00`000000oooo0?ooo`2j0?ooo`030000003oool0oooo01P0oooo00<000000?oo
o`3oool0T@3oool01@000000oooo0?ooo`3oool000000;d0oooo000N0?ooo`030000003oool0oooo
0;/0oooo00<000000?ooo`3oool0603oool00`000000oooo0?ooo`2?0?ooo`030000003oool0oooo
0080oooo00<000000?ooo`3oool0^`3oool001h0oooo00<000000?ooo`3oool0^`3oool00`000000
oooo0?ooo`0H0?ooo`030000003oool0oooo08h0oooo00<000000?ooo`3oool00`3oool00`000000
oooo0?ooo`2k0?ooo`007P3oool00`000000oooo0?ooo`2l0?ooo`030000003oool0oooo01L0oooo
00<000000?ooo`3oool0S@3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo0;/0oooo
000N0?ooo`030000003oool0oooo0;d0oooo00<000000?ooo`3oool05P3oool00`000000oooo0?oo
o`2<0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool0^`3oool001h0oooo00<00000
0?ooo`3oool0_P3oool00`000000oooo0?ooo`0E0?ooo`030000003oool0oooo08/0oooo00<00000
0?ooo`3oool01P3oool00`000000oooo0?ooo`2k0?ooo`007P3oool300000;h0oooo00<000000?oo
o`3oool05@3oool00`000000oooo0?ooo`2:0?ooo`030000003oool0oooo00L0oooo00<000000?oo
o`3oool0^`3oool001h0oooo00<000000?ooo`3oool0_`3oool00`000000oooo0?ooo`0E0?ooo`03
0000003oool0oooo08T0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`2k0?ooo`00
7P3oool00`000000oooo0?ooo`300?ooo`030000003oool0oooo01@0oooo00<000000?ooo`3oool0
R03oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo0;`0oooo000N0?ooo`030000003o
ool0oooo0<40oooo00<000000?ooo`3oool04`3oool00`000000oooo0?ooo`270?ooo`030000003o
ool0oooo00P0oooo00<000000?ooo`3oool0_03oool001h0oooo00<000000?ooo`3oool0`@3oool0
0`000000oooo0?ooo`0C0?ooo`030000003oool0oooo08H0oooo00<000000?ooo`3oool02@3oool0
0`000000oooo0?ooo`2l0?ooo`007P3oool00`000000oooo0?ooo`320?ooo`030000003oool0oooo
0180oooo00<000000?ooo`3oool0Q@3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo
0;`0oooo000N0?ooo`030000003oool0oooo0<80oooo00<000000?ooo`3oool04P3oool00`000000
oooo0?ooo`240?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool0_03oool001h0oooo
00<000000?ooo`3oool0``3oool00`000000oooo0?ooo`0A0?ooo`030000003oool0oooo08@0oooo
00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`2l0?ooo`007P3oool300000<<0oooo00<0
00000?ooo`3oool04@3oool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo07@0oooo00<0
00000?ooo`3oool0303oool00`000000oooo0?ooo`2l0?ooo`007P3oool00`000000oooo0?ooo`34
0?ooo`030000003oool0oooo0100oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`1d
0?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool0_03oool001h0oooo00<000000?oo
o`3oool0a03oool00`000000oooo0?ooo`0A0?ooo`030000003oool0oooo00/0oooo00<000000?oo
o`3oool0L`3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo0;`0oooo000N0?ooo`03
0000003oool0oooo0<D0oooo00<000000?ooo`3oool0403oool00`000000oooo0?ooo`0:0?ooo`80
0000M@3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo0;`0oooo000N0?ooo`030000
003oool0oooo0<D0oooo00<000000?ooo`3oool0403oool00`000000oooo0?ooo`0:0?ooo`800000
M03oool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo0;`0oooo000N0?ooo`030000003o
ool0oooo0<H0oooo00<000000?ooo`3oool03`3oool00`000000oooo0?ooo`0:0?ooo`800000L`3o
ool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo0;d0oooo00020?ooo`800000103oool0
0`000000oooo0?ooo`030?ooo`8000000`3oool3000000P0oooo00<000000?ooo`3oool0aP3oool0
0`000000oooo0?ooo`0?0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`000000L`3oool0
0`000000oooo0?ooo`0>0?ooo`030000003oool0oooo0;d0oooo00001@3oool000000?ooo`3oool0
000000P0oooo00@000000?ooo`3oool000000`3oool00`000000oooo0?ooo`070?ooo`030000003o
ool0oooo0<L0oooo00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`090?ooo`030000003o
ool000000780oooo00<000000?ooo`3oool03`3oool00`000000oooo0?ooo`2m0?ooo`0000D0oooo
0000003oool0oooo000000080?ooo`040000003oool0oooo000000<0oooo00<000000?ooo`3oool0
1`3oool00`000000oooo0?ooo`370?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3oool0
2@3oool00`000000oooo0000001b0?ooo`030000003oool0oooo00l0oooo00<000000?ooo`3oool0
_@3oool000050?ooo`000000oooo0?ooo`000000203oool010000000oooo0?ooo`0000030?ooo`03
0000003oool0oooo00L0oooo1@0000350?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3o
ool0203oool010000000oooo0?ooo`00001a0?ooo`030000003oool0oooo0100oooo00<000000?oo
o`3oool0_@3oool000050?ooo`000000oooo0?ooo`000000203oool010000000oooo0?ooo`000003
0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool0b03oool00`000000oooo0?ooo`0=
0?ooo`030000003oool0oooo00P0oooo00@000000?ooo`3oool00000L@3oool00`000000oooo0?oo
o`0@0?ooo`030000003oool0oooo0;d0oooo00001@3oool000000?ooo`3oool0000000P0oooo00@0
00000?ooo`3oool000000P3oool2000000T0oooo00<000000?ooo`3oool0b03oool00`000000oooo
0?ooo`0>0?ooo`030000003oool0oooo00L0oooo00@000000?ooo`3oool00000L03oool00`000000
oooo0?ooo`0A0?ooo`030000003oool0oooo0;d0oooo00020?ooo`8000002P3oool2000000@0oooo
00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`390?ooo`030000003oool0oooo00d0oooo
00<000000?ooo`3oool01`3oool010000000oooo0?ooo`00001`0?ooo`030000003oool0oooo0140
oooo00<000000?ooo`3oool0_@3oool001h0oooo00<000000?ooo`3oool0b@3oool00`000000oooo
0?ooo`0=0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool00P3oool00`000000oooo
0?ooo`1/0?ooo`030000003oool0oooo0180oooo00<000000?ooo`3oool0_@3oool001h0oooo00<0
00000?ooo`3oool0bP3oool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo00H0oooo00<0
00000?ooo`3oool00P3oool00`000000oooo0?ooo`1/0?ooo`030000003oool0oooo0180oooo00<0
00000?ooo`3oool0_@3oool001h0oooo00<000000?ooo`3oool0bP3oool00`000000oooo0?ooo`0<
0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`1[
0?ooo`030000003oool0oooo01<0oooo00<000000?ooo`3oool0_@3oool001h0oooo00<000000?oo
o`3oool0b`3oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo00D0oooo00<000000?oo
o`3oool00`3oool00`000000oooo0?ooo`1Z0?ooo`030000003oool0oooo01<0oooo00<000000?oo
o`3oool0_P3oool001h0oooo0`00003;0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3o
ool01@3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo06X0oooo00<000000?ooo`3o
ool04`3oool00`000000oooo0?ooo`2n0?ooo`007P3oool00`000000oooo0?ooo`3<0?ooo`030000
003oool0oooo00X0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`030?ooo`030000
003oool0oooo06T0oooo00<000000?ooo`3oool0503oool00`000000oooo0?ooo`2n0?ooo`007P3o
ool00`000000oooo0?ooo`3<0?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool0103o
ool00`000000oooo0?ooo`040?ooo`030000003oool0oooo06T0oooo00<000000?ooo`3oool0503o
ool00`000000oooo0?ooo`2n0?ooo`007P3oool00`000000oooo0?ooo`3<0?ooo`030000003oool0
oooo00X0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`040?ooo`030000003oool0
oooo06P0oooo00<000000?ooo`3oool05@3oool00`000000oooo0?ooo`2n0?ooo`007P3oool00`00
0000oooo0?ooo`3=0?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool00`3oool00`00
0000oooo0?ooo`040?ooo`030000003oool0oooo06P0oooo00<000000?ooo`3oool05@3oool00`00
0000oooo0?ooo`2n0?ooo`007P3oool00`000000oooo0?ooo`3=0?ooo`030000003oool0oooo00X0
oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo06L0
oooo00<000000?ooo`3oool05P3oool00`000000oooo0?ooo`2n0?ooo`007P3oool00`000000oooo
0?ooo`3=0?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool00P3oool00`000000oooo
0?ooo`050?ooo`030000003oool0oooo06L0oooo00<000000?ooo`3oool05P3oool00`000000oooo
0?ooo`2n0?ooo`007P3oool00`000000oooo0?ooo`3>0?ooo`030000003oool0oooo00T0oooo00<0
00000?ooo`3oool00P3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo06L0oooo00<0
00000?ooo`3oool02`3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo0;h0oooo000N
0?ooo`030000003oool0oooo0<h0oooo00<000000?ooo`3oool02@3oool01@000000oooo0?ooo`3o
ool0000000P0oooo00<000000?ooo`3oool0IP3oool00`000000oooo0?ooo`0<0?ooo`030000003o
ool0oooo00L0oooo00<000000?ooo`3oool0_`3oool001h0oooo0`00003>0?ooo`030000003oool0
oooo00T0oooo00D000000?ooo`3oool0oooo000000080?ooo`030000003oool0oooo06H0oooo00<0
00000?ooo`3oool0303oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo0;l0oooo000N
0?ooo`030000003oool0oooo0<l0oooo00<000000?ooo`3oool0203oool01@000000oooo0?ooo`3o
ool0000000P0oooo00<000000?ooo`3oool0I@3oool00`000000oooo0?ooo`0=0?ooo`030000003o
ool0oooo00L0oooo00<000000?ooo`3oool0_`3oool001h0oooo00<000000?ooo`3oool0c`3oool0
0`000000oooo0?ooo`080?ooo`040000003oool0oooo000000T0oooo00<000000?ooo`3oool0I@3o
ool00`000000oooo0?ooo`0<0?ooo`030000003oool0000000P0oooo00<000000?ooo`3oool0_`3o
ool001h0oooo00<000000?ooo`3oool0c`3oool00`000000oooo0?ooo`080?ooo`040000003oool0
oooo000000T0oooo00<000000?ooo`3oool0F@3oool00`000000oooo0?ooo`090?ooo`030000003o
ool0oooo00`0oooo00<000000?ooo`000000203oool00`000000oooo0?ooo`2o0?ooo`007P3oool0
0`000000oooo0?ooo`3@0?ooo`030000003oool0oooo00P0oooo00<000000?ooo`0000002@3oool0
0`000000oooo0?ooo`1I0?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool03@3oool0
0`000000oooo000000080?ooo`030000003oool0oooo0;l0oooo000N0?ooo`030000003oool0oooo
0=00oooo00<000000?ooo`3oool0203oool2000000X0oooo00<000000?ooo`3oool0F@3oool00`00
0000oooo0?ooo`080?ooo`030000003oool0oooo00d0oooo00<000000?ooo`0000001`3oool00`00
0000oooo0?ooo`300?ooo`007P3oool00`000000oooo0?ooo`3@0?ooo`030000003oool0oooo00P0
oooo0P00000:0?ooo`030000003oool0oooo05T0oooo0P0000080?ooo`030000003oool0oooo00h0
oooo00<000000?ooo`0000001`3oool00`000000oooo0?ooo`300?ooo`007P3oool00`000000oooo
0?ooo`3A0?ooo`030000003oool0oooo00L0oooo0P00000:0?ooo`030000003oool0oooo05T0oooo
0P0000080?ooo`030000003oool0oooo00h0oooo00<000000?ooo`0000001`3oool00`000000oooo
0?ooo`300?ooo`007P3oool300000=40oooo00<000000?ooo`3oool01`3oool00`000000oooo0?oo
o`090?ooo`030000003oool0oooo05T0oooo0P0000080?ooo`030000003oool0oooo00d0oooo00@0
00000?ooo`3oool000001`3oool00`000000oooo0?ooo`300?ooo`007P3oool00`000000oooo0?oo
o`3A0?ooo`030000003oool0oooo01<0oooo00<000000?ooo`3oool0F@3oool00`000000oooo0000
00060?ooo`030000003oool0oooo00h0oooo00D000000?ooo`3oool0oooo000000060?ooo`030000
003oool0oooo0<00oooo000N0?ooo`030000003oool0oooo0=80oooo00<000000?ooo`3oool04P3o
ool00`000000oooo0?ooo`1I0?ooo`030000003oool0000000H0oooo00<000000?ooo`3oool03P3o
ool01@000000oooo0?ooo`3oool0000000H0oooo00<000000?ooo`3oool0`03oool001h0oooo00<0
00000?ooo`3oool0dP3oool00`000000oooo0?ooo`0C0?ooo`030000003oool0oooo05P0oooo00<0
00000?ooo`0000001P3oool00`000000oooo0?ooo`0>0?ooo`050000003oool0oooo0?ooo`000000
1@3oool00`000000oooo0?ooo`310?ooo`007P3oool00`000000oooo0?ooo`3B0?ooo`030000003o
ool0oooo01<0oooo00<000000?ooo`3oool0F03oool010000000oooo0?ooo`0000040?ooo`030000
003oool0oooo00l0oooo00D000000?ooo`3oool0oooo000000050?ooo`030000003oool0oooo0<40
oooo000N0?ooo`030000003oool0oooo0=80oooo00<000000?ooo`3oool04`3oool00`000000oooo
0?ooo`1H0?ooo`040000003oool0oooo000000@0oooo00<000000?ooo`3oool03`3oool01@000000
oooo0?ooo`3oool0000000D0oooo00<000000?ooo`3oool0`@3oool001h0oooo00<000000?ooo`3o
ool0d`3oool00`000000oooo0?ooo`0B0?ooo`030000003oool0oooo05P0oooo00@000000?ooo`3o
ool000000`3oool00`000000oooo0?ooo`0?0?ooo`030000003oool0oooo0080oooo00<000000?oo
o`3oool00`3oool00`000000oooo0?ooo`310?ooo`007P3oool00`000000oooo0?ooo`3C0?ooo`03
0000003oool0oooo0180oooo00<000000?ooo`3oool0E`3oool00`000000oooo0?ooo`020?ooo`04
0000003oool0oooo00000140oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`030?oo
o`030000003oool0oooo0<40oooo000N0?ooo`030000003oool0oooo0=<0oooo00<000000?ooo`3o
ool04P3oool00`000000oooo0?ooo`1G0?ooo`030000003oool0oooo0080oooo00@000000?ooo`3o
ool000004@3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo0080oooo00<000000?oo
o`3oool0`@3oool001h0oooo0`00003D0?ooo`030000003oool0oooo0140oooo00<000000?ooo`3o
ool0E`3oool00`000000oooo0?ooo`020?ooo`030000003oool000000180oooo00<000000?ooo`3o
ool00`3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0<40oooo000N0?ooo`030000
003oool0oooo0=@0oooo00<000000?ooo`3oool04@3oool00`000000oooo0?ooo`1G0?ooo`030000
003oool0oooo00<0oooo0P00000B0?ooo`030000003oool0oooo00<0oooo00D000000?ooo`3oool0
oooo000000340?ooo`007P3oool00`000000oooo0?ooo`3D0?ooo`030000003oool0oooo0140oooo
00<000000?ooo`3oool0E`3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo0140oooo
00<000000?ooo`3oool00`3oool01@000000oooo0?ooo`3oool000000<@0oooo000N0?ooo`030000
003oool0oooo0=D0oooo00<000000?ooo`3oool0403oool00`000000oooo0?ooo`1G0?ooo`030000
003oool0oooo00<0oooo00<000000?ooo`3oool0403oool00`000000oooo0?ooo`040?ooo`050000
003oool0oooo0?ooo`000000a03oool001h0oooo00<000000?ooo`3oool0e@3oool00`000000oooo
0?ooo`0@0?ooo`030000003oool0oooo05L0oooo00<000000?ooo`3oool00`3oool200000140oooo
00<000000?ooo`3oool0103oool01@000000oooo0?ooo`3oool000000<@0oooo000N0?ooo`030000
003oool0oooo0=D0oooo00<000000?ooo`3oool0403oool00`000000oooo0?ooo`1G0?ooo`030000
003oool0oooo0080oooo00<000000?ooo`0000004@3oool00`000000oooo0?ooo`040?ooo`050000
003oool0oooo0?ooo`000000a03oool00080oooo0P0000040?ooo`030000003oool0oooo00<0oooo
0P0000020?ooo`D000001`3oool00`000000oooo0?ooo`3F0?ooo`030000003oool0oooo00l0oooo
00<000000?ooo`3oool0E`3oool00`000000oooo0?ooo`020?ooo`030000003oool000000140oooo
00<000000?ooo`3oool01@3oool010000000oooo0?ooo`0000340?ooo`0000D0oooo0000003oool0
oooo000000080?ooo`040000003oool0oooo00000080oooo00@000000?ooo`3oool000001`3oool0
0`000000oooo0?ooo`3F0?ooo`030000003oool0oooo00l0oooo00<000000?ooo`3oool0E`3oool0
0`000000oooo0?ooo`020?ooo`040000003oool0oooo00000100oooo00<000000?ooo`3oool01@3o
ool00`000000oooo000000350?ooo`0000D0oooo0000003oool0oooo000000080?ooo`040000003o
ool0oooo000000<0oooo00<000000?ooo`3oool01`3oool500000=@0oooo00<000000?ooo`3oool0
3`3oool00`000000oooo0?ooo`1G0?ooo`050000003oool0oooo0?ooo`000000103oool00`000000
oooo0?ooo`0=0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`000000a@3oool000050?oo
o`000000oooo0?ooo`000000203oool010000000oooo0?ooo`0000040?ooo`030000003oool0oooo
00H0oooo00<000000?ooo`3oool0e`3oool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo
05L0oooo00D000000?ooo`3oool0oooo000000050?ooo`030000003oool0oooo00/0oooo00<00000
0?ooo`3oool01P3oool00`000000oooo000000350?ooo`0000D0oooo0000003oool0oooo00000008
0?ooo`060000003oool0oooo0000003oool000000`3oool00`000000oooo0?ooo`050?ooo`030000
003oool0oooo0=L0oooo00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`1G0?ooo`050000
003oool0oooo0?ooo`0000001@3oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo00H0
oooo00<000000?ooo`000000a@3oool000050?ooo`000000oooo0?ooo`000000203oool01P000000
oooo0?ooo`000000oooo000000<0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`3G
0?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3oool0E`3oool010000000oooo0?ooo`00
00070?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool01P3oool00`000000oooo0000
00350?ooo`000P3oool2000000X0oooo0P0000030?ooo`<00000203oool00`000000oooo0?ooo`3G
0?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3oool0E`3oool010000000oooo0?ooo`00
00080?ooo`@00000203oool00`000000oooo0?ooo`060?ooo`030000003oool000000<D0oooo000N
0?ooo`030000003oool0oooo0=P0oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`1G
0?ooo`040000003oool0oooo000000`0oooo100000040?ooo`030000003oool0oooo00L0oooo00<0
00000?ooo`3oool0a03oool001h0oooo00<000000?ooo`3oool0f03oool00`000000oooo0?ooo`0=
0?ooo`030000003oool0oooo05L0oooo00<000000?ooo`0000004@3oool01@000000oooo0?ooo`3o
ool0000000T0oooo00<000000?ooo`3oool0a03oool001h0oooo00<000000?ooo`3oool0f03oool0
0`000000oooo0?ooo`0=0?ooo`030000003oool0oooo05L0oooo00<000000?ooo`0000004P3oool0
0`000000oooo0000000:0?ooo`030000003oool0oooo0<@0oooo000N0?ooo`030000003oool0oooo
0=T0oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`1G0?ooo`030000003oool00000
01<0oooo0P00003A0?ooo`007P3oool300000=T0oooo00<000000?ooo`3oool0303oool00`000000
oooo0?ooo`1G0?ooo`030000003oool0000001@0oooo00<000000?ooo`3oool0c`3oool001h0oooo
00<000000?ooo`3oool0f@3oool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo05L0oooo
0P00003W0?ooo`007P3oool00`000000oooo0?ooo`3I0?ooo`030000003oool0oooo00d0oooo00<0
00000?ooo`3oool0EP3oool200000>L0oooo000N0?ooo`030000003oool0oooo0=X0oooo00<00000
0?ooo`3oool0303oool00`000000oooo0?ooo`1E0?ooo`030000003oool000000>L0oooo000N0?oo
o`030000003oool0oooo0=X0oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`1E0?oo
o`800000j03oool001h0oooo00<000000?ooo`3oool0fP3oool00`000000oooo0?ooo`0<0?ooo`03
0000003oool0oooo05D0oooo0P00003X0?ooo`007P3oool00`000000oooo0?ooo`3K0?ooo`030000
003oool0oooo00/0oooo00<000000?ooo`3oool0E@3oool200000>P0oooo000N0?ooo`030000003o
ool0oooo0=/0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`1E0?ooo`030000003o
ool0oooo0>L0oooo000N0?ooo`<00000f`3oool00`000000oooo0?ooo`0;0?ooo`030000003oool0
oooo05D0oooo00<000000?ooo`3oool0i`3oool001h0oooo00<000000?ooo`3oool0f`3oool00`00
0000oooo0?ooo`0;0?ooo`030000003oool0oooo05D0oooo00<000000?ooo`3oool0i`3oool001h0
oooo00<000000?ooo`3oool0g03oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo05D0
oooo00<000000?ooo`3oool0i`3oool001h0oooo00<000000?ooo`3oool0g03oool00`000000oooo
0?ooo`0:0?ooo`030000003oool0oooo05@0oooo0P00003Y0?ooo`007P3oool00`000000oooo0?oo
o`3L0?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool0E03oool200000>T0oooo000N
0?ooo`030000003oool0oooo0=d0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`1D
0?ooo`800000j@3oool001h0oooo00<000000?ooo`3oool0g@3oool00`000000oooo0?ooo`090?oo
o`030000003oool0oooo05<0oooo00<000000?ooo`000000j@3oool001h0oooo00<000000?ooo`3o
ool0g@3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo05<0oooo00<000000?ooo`00
0000j@3oool001h0oooo0`00003M0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool0
D`3oool00`000000oooo0000003Y0?ooo`007P3oool00`000000oooo0?ooo`3N0?ooo`030000003o
ool0oooo00P0oooo00<000000?ooo`3oool0DP3oool010000000oooo0?ooo`00003Y0?ooo`007P3o
ool00`000000oooo0?ooo`3N0?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool0DP3o
ool010000000oooo0?ooo`00003Y0?ooo`007P3oool00`000000oooo0?ooo`3N0?ooo`030000003o
ool0oooo00P0oooo00<000000?ooo`3oool0DP3oool010000000oooo0?ooo`00003Y0?ooo`007P3o
ool00`000000oooo0?ooo`3N0?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool0DP3o
ool010000000oooo0?ooo`00003Y0?ooo`007P3oool00`000000oooo0?ooo`3O0?ooo`030000003o
ool0oooo00L0oooo00<000000?ooo`3oool0D@3oool01@000000oooo0?ooo`3oool000000>T0oooo
000N0?ooo`030000003oool0oooo0=l0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?oo
o`1A0?ooo`050000003oool0oooo0?ooo`000000j@3oool001h0oooo00<000000?ooo`3oool0g`3o
ool00`000000oooo0?ooo`070?ooo`030000003oool0oooo0540oooo00D000000?ooo`3oool0oooo
0000003Y0?ooo`007P3oool00`000000oooo0?ooo`3P0?ooo`030000003oool0oooo00H0oooo00<0
00000?ooo`3oool0D03oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0>L0oooo000N
0?ooo`<00000h03oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo0500oooo00D00000
0?ooo`3oool0oooo0000003Z0?ooo`007P3oool00`000000oooo0?ooo`3P0?ooo`030000003oool0
oooo00L0oooo00<000000?ooo`3oool0C`3oool01@000000oooo0?ooo`3oool000000>X0oooo000N
0?ooo`030000003oool0oooo0>00oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`1>
0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0j03oool001h0oooo00<000000?oo
o`3oool0h@3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo04h0oooo00<000000?oo
o`3oool00P3oool00`000000oooo0?ooo`3X0?ooo`007P3oool00`000000oooo0?ooo`3Q0?ooo`03
0000003oool0oooo00H0oooo00<000000?ooo`3oool0CP3oool00`000000oooo0?ooo`020?ooo`03
0000003oool0oooo0>P0oooo000N0?ooo`030000003oool0oooo0>40oooo00<000000?ooo`3oool0
1P3oool00`000000oooo0?ooo`1>0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0
j03oool00080oooo0P0000040?ooo`030000003oool0oooo00<0oooo0P0000030?ooo`<00000203o
ool00`000000oooo0?ooo`3R0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool0C@3o
ool00`000000oooo0?ooo`030?ooo`030000003oool0oooo0>P0oooo00001@3oool000000?ooo`3o
ool0000000P0oooo00H000000?ooo`3oool000000?ooo`0000030?ooo`030000003oool0oooo00D0
oooo00<000000?ooo`3oool0hP3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo04d0
oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`3X0?ooo`0000D0oooo0000003oool0
oooo000000080?ooo`040000003oool0oooo000000D0oooo00<000000?ooo`3oool01@3oool50000
0>00oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`1=0?ooo`030000003oool0oooo
00<0oooo00<000000?ooo`3oool0j03oool000050?ooo`000000oooo0?ooo`000000203oool01000
0000oooo0?ooo`0000030?ooo`800000203oool00`000000oooo0?ooo`3R0?ooo`030000003oool0
oooo00D0oooo00<000000?ooo`3oool0C03oool00`000000oooo0?ooo`040?ooo`030000003oool0
oooo0>P0oooo00001@3oool000000?ooo`3oool0000000P0oooo00@000000?ooo`3oool000001@3o
ool00`000000oooo0?ooo`050?ooo`030000003oool0oooo0><0oooo00<000000?ooo`3oool0103o
ool00`000000oooo0?ooo`1<0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0j03o
ool000050?ooo`000000oooo0?ooo`000000203oool01P000000oooo0?ooo`000000oooo000000<0
oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`3S0?ooo`030000003oool0oooo00@0
oooo00<000000?ooo`3oool0C03oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo0>P0
oooo00020?ooo`8000002P3oool2000000<0oooo0`0000080?ooo`030000003oool0oooo0><0oooo
00<000000?ooo`3oool0103oool00`000000oooo0?ooo`1<0?ooo`030000003oool0oooo00@0oooo
00<000000?ooo`3oool0j03oool001h0oooo00<000000?ooo`3oool0h`3oool00`000000oooo0?oo
o`040?ooo`030000003oool0oooo04/0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?oo
o`3X0?ooo`007P3oool00`000000oooo0?ooo`3T0?ooo`030000003oool0oooo00<0oooo00<00000
0?ooo`3oool0B`3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo0>P0oooo000N0?oo
o`030000003oool0oooo0>@0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`1;0?oo
o`030000003oool0oooo00D0oooo00<000000?ooo`3oool0j03oool001h0oooo00<000000?ooo`3o
ool0i03oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo04X0oooo00<000000?ooo`3o
ool01P3oool00`000000oooo0?ooo`3X0?ooo`007P3oool300000>@0oooo00<000000?ooo`3oool0
0`3oool00`000000oooo0?ooo`1:0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool0
j03oool001h0oooo00<000000?ooo`3oool0i@3oool00`000000oooo0?ooo`020?ooo`030000003o
ool0oooo04X0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`3X0?ooo`007P3oool0
0`000000oooo0?ooo`3U0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0B@3oool0
0`000000oooo0?ooo`070?ooo`030000003oool0oooo0>P0oooo000N0?ooo`030000003oool0oooo
0>D0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`190?ooo`030000003oool0oooo
00L0oooo00<000000?ooo`3oool0j03oool001h0oooo00<000000?ooo`3oool0i@3oool00`000000
oooo0?ooo`020?ooo`030000003oool0oooo04T0oooo00<000000?ooo`3oool01`3oool00`000000
oooo0?ooo`3X0?ooo`007P3oool00`000000oooo0?ooo`3V0?ooo`050000003oool0oooo0?ooo`00
0000B`3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo0>P0oooo000N0?ooo`030000
003oool0oooo0>H0oooo00D000000?ooo`3oool0oooo0000001:0?ooo`030000003oool0oooo00L0
oooo00<000000?ooo`3oool0j@3oool001h0oooo00<000000?ooo`3oool0iP3oool01@000000oooo
0?ooo`3oool0000004X0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`3Y0?ooo`00
7P3oool300000>H0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`170?ooo`030000
003oool0oooo00L0oooo00<000000?ooo`3oool0j@3oool001h0oooo00<000000?ooo`3oool0i`3o
ool01@000000oooo0?ooo`3oool0000004P0oooo00<000000?ooo`3oool0203oool00`000000oooo
0?ooo`3Y0?ooo`007P3oool00`000000oooo0?ooo`3W0?ooo`050000003oool0oooo0?ooo`000000
B03oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo0>T0oooo000N0?ooo`030000003o
ool0oooo0>L0oooo00D000000?ooo`3oool0oooo000000180?ooo`030000003oool0oooo00P0oooo
00<000000?ooo`3oool0j@3oool001h0oooo00<000000?ooo`3oool0i`3oool01@000000oooo0?oo
o`3oool0000002`0oooo00<000000?ooo`3oool06@3oool00`000000oooo0?ooo`080?ooo`030000
003oool0oooo0>T0oooo000N0?ooo`030000003oool0oooo0>P0oooo00@000000?ooo`3oool00000
;03oool00`000000oooo0?ooo`0H0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool0
j@3oool001h0oooo00<000000?ooo`3oool0j03oool010000000oooo0?ooo`00000/0?ooo`030000
003oool0oooo01P0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`3Y0?ooo`007P3o
ool00`000000oooo0?ooo`3X0?ooo`040000003oool0oooo000002/0oooo00<000000?ooo`000000
6@3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo0>T0oooo000N0?ooo`030000003o
ool0oooo0>P0oooo00@000000?ooo`3oool00000:`3oool00`000000oooo0000000H0?ooo`030000
003oool0oooo00X0oooo00<000000?ooo`3oool0j@3oool001h0oooo0`00003X0?ooo`040000003o
ool0oooo000002/0oooo00<000000?ooo`000000603oool00`000000oooo0?ooo`0:0?ooo`030000
003oool0oooo0>T0oooo000N0?ooo`030000003oool0oooo0>T0oooo00<000000?ooo`000000:`3o
ool00`000000oooo0000000H0?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool0j@3o
ool001h0oooo00<000000?ooo`3oool0j@3oool00`000000oooo0000000[0?ooo`030000003oool0
000001L0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`3Y0?ooo`007P3oool00`00
0000oooo0?ooo`3Y0?ooo`030000003oool0000002X0oooo00D000000?ooo`3oool0oooo0000000F
0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool0j@3oool001h0oooo00<000000?oo
o`3oool0j@3oool00`000000oooo0000000Z0?ooo`050000003oool0oooo0?ooo`0000005P3oool0
0`000000oooo0?ooo`0;0?ooo`030000003oool0oooo0>T0oooo000N0?ooo`030000003oool0oooo
0>X0oooo0P00000Z0?ooo`050000003oool0oooo0?ooo`0000005P3oool00`000000oooo0?ooo`0;
0?ooo`030000003oool0oooo0>T0oooo000N0?ooo`030000003oool0oooo0>X0oooo0P00000Z0?oo
o`050000003oool0oooo0?ooo`0000005@3oool00`000000oooo0?ooo`0<0?ooo`030000003oool0
oooo0>T0oooo000N0?ooo`030000003oool0oooo0>X0oooo0P00000Y0?ooo`030000003oool0oooo
0080oooo00<000000?ooo`3oool04`3oool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo
0>T0oooo000N0?ooo`<00000jP3oool2000002T0oooo00<000000?ooo`3oool00`3oool00`000000
oooo0?ooo`0B0?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool0j@3oool001h0oooo
00<000000?ooo`3oool0j`3oool00`000000oooo0?ooo`0W0?ooo`030000003oool0oooo00<0oooo
00<000000?ooo`3oool04@3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo0>T0oooo
000N0?ooo`030000003oool0oooo0>/0oooo00<000000?ooo`3oool09`3oool00`000000oooo0?oo
o`030?ooo`030000003oool0oooo0140oooo00<000000?ooo`3oool03@3oool00`000000oooo0?oo
o`3Y0?ooo`007P3oool00`000000oooo0?ooo`3[0?ooo`030000003oool0oooo02L0oooo00<00000
0?ooo`3oool00`3oool00`000000oooo0?ooo`0A0?ooo`030000003oool0oooo00`0oooo00<00000
0?ooo`3oool0jP3oool001h0oooo00<000000?ooo`3oool0j`3oool00`000000oooo0?ooo`0V0?oo
o`030000003oool0oooo00@0oooo00<000000?ooo`3oool04@3oool00`000000oooo0?ooo`0<0?oo
o`030000003oool0oooo0>X0oooo000N0?ooo`030000003oool0oooo0>/0oooo0P00000W0?ooo`03
0000003oool0oooo00D0oooo00<000000?ooo`3oool03`3oool00`000000oooo0?ooo`0=0?ooo`03
0000003oool0oooo0>X0oooo00020?ooo`800000103oool00`000000oooo0?ooo`030?ooo`800000
103oool3000000L0oooo00<000000?ooo`3oool0j`3oool2000002L0oooo00<000000?ooo`3oool0
1@3oool00`000000oooo0?ooo`0?0?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool0
jP3oool000050?ooo`000000oooo0?ooo`000000203oool010000000oooo0?ooo`0000040?ooo`03
0000003oool0oooo00H0oooo00<000000?ooo`3oool0j`3oool2000002L0oooo00<000000?ooo`3o
ool01@3oool00`000000oooo0?ooo`0?0?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3o
ool0jP3oool000050?ooo`000000oooo0?ooo`000000203oool01@000000oooo0?ooo`000000oooo
00D000001`3oool00`000000oooo0?ooo`3/0?ooo`030000003oool0oooo02@0oooo00<000000?oo
o`3oool01P3oool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo00h0oooo00<000000?oo
o`3oool0jP3oool000050?ooo`000000oooo0?ooo`000000203oool01P000000oooo0?ooo`000000
oooo00000080oooo00<000000?ooo`3oool01P3oool500000>X0oooo0P0000030?ooo`030000003o
ool0oooo01l0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`020?ooo`8000002P3o
ool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo0>X0oooo00001@3oool000000?ooo`3o
ool0000000P0oooo00@000000?ooo`3oool000000P3oool00`000000oooo000000080?ooo`030000
003oool0oooo0>`0oooo0P0000030?ooo`030000003oool0oooo01l0oooo00<000000?ooo`3oool0
1`3oool4000000030?ooo`000000oooo00T0oooo00<000000?ooo`3oool03P3oool00`000000oooo
0?ooo`3Z0?ooo`0000D0oooo0000003oool0oooo000000080?ooo`040000003oool0oooo000000<0
oooo0P0000080?ooo`030000003oool0oooo0>`0oooo0P0000020?ooo`8000008@3oool00`000000
oooo0?ooo`070?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool01`3oool00`000000
oooo0?ooo`0?0?ooo`030000003oool0oooo0>X0oooo00020?ooo`8000002P3oool2000000D0oooo
00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`3/0?ooo`8000000P3oool200000240oooo
00<000000?ooo`3oool0303oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00l0oooo
00<000000?ooo`3oool0jP3oool001h0oooo00<000000?ooo`3oool0k03oool01P000000oooo0000
00000000oooo00000200oooo00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`060?ooo`03
0000003oool0oooo00l0oooo00<000000?ooo`3oool0jP3oool001h0oooo00<000000?ooo`3oool0
k03oool01P000000oooo000000000000oooo00000200oooo00<000000?ooo`3oool03P3oool00`00
0000oooo0?ooo`060?ooo`030000003oool0oooo00l0oooo00<000000?ooo`3oool0jP3oool001h0
oooo00<000000?ooo`3oool0k03oool00`000000oooo000000020?ooo`030000003oool0oooo01h0
oooo00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo0100
oooo00<000000?ooo`3oool0jP3oool001h0oooo00<000000?ooo`3oool0k03oool010000000oooo
0000000000020?ooo`030000003oool0oooo01d0oooo00<000000?ooo`3oool03P3oool00`000000
oooo0?ooo`050?ooo`030000003oool0oooo0100oooo00<000000?ooo`3oool0jP3oool001h0oooo
0`00003/0?ooo`80000000D0oooo0000003oool0oooo0000000O0?ooo`030000003oool0oooo00h0
oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`0?0?ooo`030000003oool0oooo0>/0
oooo000N0?ooo`030000003oool0oooo0>`0oooo0P0000001@3oool000000?ooo`3oool0000001l0
oooo00<000000?ooo`3oool03`3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo0100
oooo00<000000?ooo`3oool0j`3oool001h0oooo00<000000?ooo`3oool0k03oool010000000oooo
0?ooo`0000020?ooo`030000003oool0oooo01`0oooo00<000000?ooo`3oool0403oool00`000000
oooo0?ooo`030?ooo`030000003oool0oooo0100oooo00<000000?ooo`3oool0j`3oool001h0oooo
00<000000?ooo`3oool0l03oool00`000000oooo0000000N0?ooo`030000003oool0oooo0100oooo
00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`0@0?ooo`030000003oool0oooo0>/0oooo
000N0?ooo`030000003oool0oooo0?00oooo00<000000?ooo`0000007P3oool00`000000oooo0?oo
o`0@0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0403oool00`000000oooo0?oo
o`3[0?ooo`007P3oool00`000000oooo0?ooo`3`0?ooo`030000003oool0000001h0oooo00<00000
0?ooo`3oool0403oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0140oooo00<00000
0?ooo`3oool0j`3oool001h0oooo00<000000?ooo`3oool0l@3oool2000001h0oooo00<000000?oo
o`3oool0403oool00`000000oooo0?ooo`020?ooo`050000003oool0oooo0?ooo`0000003`3oool0
0`000000oooo0?ooo`3[0?ooo`007P3oool00`000000oooo0?ooo`3a0?ooo`8000007P3oool00`00
0000oooo0?ooo`0A0?ooo`050000003oool0oooo0?ooo`0000000`3oool00`000000oooo0?ooo`0<
0?ooo`030000003oool0oooo0>`0oooo000N0?ooo`030000003oool0oooo0?40oooo0P00000N0?oo
o`030000003oool0oooo0140oooo00@000000?ooo`3oool00000103oool00`000000oooo0?ooo`0<
0?ooo`030000003oool0oooo0>`0oooo000N0?ooo`<00000l@3oool2000001d0oooo00<000000?oo
o`3oool04P3oool010000000oooo0?ooo`0000030?ooo`8000003P3oool00`000000oooo0?ooo`3/
0?ooo`007P3oool00`000000oooo0?ooo`3b0?ooo`800000703oool00`000000oooo0?ooo`0B0?oo
o`040000003oool0oooo000000<0oooo0P00000>0?ooo`030000003oool0oooo0>`0oooo000N0?oo
o`030000003oool0oooo0?80oooo0P00000L0?ooo`030000003oool0oooo0180oooo00<000000?oo
o`000000103oool2000000h0oooo00<000000?ooo`3oool0k03oool001h0oooo00<000000?ooo`3o
ool0lP3oool2000001`0oooo00<000000?ooo`3oool04P3oool00`000000oooo000000040?ooo`80
00003P3oool00`000000oooo0?ooo`3/0?ooo`007P3oool00`000000oooo0?ooo`3c0?ooo`030000
003oool0oooo01X0oooo00<000000?ooo`3oool04`3oool2000000<0oooo00<000000?ooo`000000
3@3oool00`000000oooo0?ooo`3]0?ooo`007P3oool00`000000oooo0?ooo`3c0?ooo`030000003o
ool0oooo01X0oooo00<000000?ooo`3oool04`3oool2000000<0oooo00<000000?ooo`0000003@3o
ool00`000000oooo0?ooo`3]0?ooo`007P3oool00`000000oooo0?ooo`3c0?ooo`030000003oool0
oooo01X0oooo00<000000?ooo`3oool04`3oool00`000000oooo0?ooo`020?ooo`030000003oool0
000000d0oooo00<000000?ooo`3oool0k@3oool001h0oooo00<000000?ooo`3oool0l`3oool00`00
0000oooo0?ooo`0J0?ooo`030000003oool0oooo01<0oooo00<000000?ooo`3oool00P3oool01000
0000oooo0?ooo`00000<0?ooo`030000003oool0oooo0>d0oooo000N0?ooo`<00000l`3oool20000
01X0oooo00<000000?ooo`3oool0503oool01@000000oooo0?ooo`3oool0000000<0oooo00<00000
0?ooo`3oool02P3oool00`000000oooo0?ooo`3]0?ooo`007P3oool00`000000oooo0?ooo`3c0?oo
o`8000006P3oool00`000000oooo0?ooo`0C0?ooo`030000003oool000000080oooo00D000000?oo
o`3oool0oooo0000000<0?ooo`030000003oool0oooo0>d0oooo000N0?ooo`030000003oool0oooo
0?<0oooo0P00000J0?ooo`030000003oool0oooo01<0oooo00<000000?ooo`0000000P3oool01@00
0000oooo0?ooo`3oool0000000`0oooo00<000000?ooo`3oool0k@3oool001h0oooo00<000000?oo
o`3oool0l`3oool00`000000oooo0000000I0?ooo`030000003oool0oooo01<0oooo00<000000?oo
o`0000000P3oool01@000000oooo0?ooo`3oool0000000/0oooo00<000000?ooo`3oool0kP3oool0
01h0oooo00<000000?ooo`3oool0m03oool2000001T0oooo00<000000?ooo`3oool04P3oool01P00
0000oooo0?ooo`000000oooo000000@0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?oo
o`3^0?ooo`007P3oool00`000000oooo0?ooo`3d0?ooo`8000006@3oool00`000000oooo0?ooo`0B
0?ooo`060000003oool0oooo0000003oool00000103oool00`000000oooo0?ooo`090?ooo`030000
003oool0oooo0>h0oooo000N0?ooo`030000003oool0oooo0?@0oooo00<000000?ooo`000000603o
ool00`000000oooo0?ooo`0B0?ooo`060000003oool0oooo0000003oool00000103oool00`000000
oooo0?ooo`090?ooo`030000003oool0oooo0>h0oooo000N0?ooo`030000003oool0oooo0?@0oooo
00<000000?ooo`000000603oool00`000000oooo0?ooo`0A0?ooo`030000003oool0oooo0080oooo
0P0000040?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool0kP3oool001h0oooo00<0
00000?ooo`3oool0m03oool00`000000oooo0000000G0?ooo`030000003oool0oooo0180oooo00<0
00000?ooo`3oool00P3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00T0oooo00<0
00000?ooo`3oool0kP3oool001h0oooo0`00003d0?ooo`040000003oool0oooo000001H0oooo00<0
00000?ooo`3oool04P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00<0oooo00<0
00000?ooo`3oool0203oool00`000000oooo0?ooo`3_0?ooo`007P3oool00`000000oooo0?ooo`3d
0?ooo`040000003oool0oooo000001H0oooo00<000000?ooo`3oool04@3oool00`000000oooo0?oo
o`090?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool0k`3oool001h0oooo00<00000
0?ooo`3oool0m03oool010000000oooo0?ooo`00000F0?ooo`030000003oool0oooo0140oooo00<0
00000?ooo`3oool02@3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo0>l0oooo000N
0?ooo`030000003oool0oooo0?@0oooo00D000000?ooo`3oool0oooo0000000E0?ooo`030000003o
ool0oooo0140oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`080?ooo`030000003o
ool0oooo0>l0oooo000N0?ooo`030000003oool0oooo0?@0oooo00D000000?ooo`3oool0oooo0000
000E0?ooo`030000003oool0oooo0100oooo00<000000?ooo`3oool02P3oool00`000000oooo0?oo
o`080?ooo`030000003oool0oooo0>l0oooo000N0?ooo`030000003oool0oooo0?@0oooo00D00000
0?ooo`3oool0oooo0000000E0?ooo`030000003oool0oooo0100oooo00<000000?ooo`3oool02P3o
ool00`000000oooo0?ooo`080?ooo`030000003oool0oooo0>l0oooo00020?ooo`800000103oool0
0`000000oooo0?ooo`030?ooo`8000000`3oool3000000P0oooo00<000000?ooo`3oool0m03oool0
0`000000oooo0?ooo`020?ooo`030000003oool0oooo0140oooo00<000000?ooo`3oool04@3oool0
0`000000oooo0?ooo`0:0?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool0k`3oool0
00050?ooo`000000oooo0?ooo`000000203oool01P000000oooo0?ooo`000000oooo000000<0oooo
00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`3e0?ooo`050000003oool0oooo0?ooo`00
00004`3oool00`000000oooo0?ooo`0@0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3o
ool01`3oool00`000000oooo0?ooo`3`0?ooo`0000D0oooo0000003oool0oooo000000080?ooo`04
0000003oool0oooo000000D0oooo00<000000?ooo`3oool01@3oool500000?<0oooo00D000000?oo
o`3oool0oooo0000000C0?ooo`030000003oool0oooo0100oooo00<000000?ooo`3oool02`3oool0
0`000000oooo0?ooo`070?ooo`030000003oool0oooo0?00oooo00001@3oool000000?ooo`3oool0
000000P0oooo00@000000?ooo`3oool000001@3oool00`000000oooo0?ooo`050?ooo`030000003o
ool0oooo0?D0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0@0?ooo`030000003o
ool0oooo0100oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`060?ooo`030000003o
ool0oooo0?00oooo00001@3oool000000?ooo`3oool0000000P0oooo00D000000?ooo`3oool00000
0?ooo`04000000P0oooo00<000000?ooo`3oool0m@3oool00`000000oooo0?ooo`020?ooo`030000
003oool000000100oooo00<000000?ooo`3oool03`3oool00`000000oooo0?ooo`0=0?ooo`030000
003oool0oooo00H0oooo00<000000?ooo`3oool0l03oool000050?ooo`000000oooo0?ooo`000000
203oool01P000000oooo0?ooo`000000oooo000000/0oooo00<000000?ooo`3oool0m@3oool00`00
0000oooo0?ooo`030?ooo`800000403oool00`000000oooo0?ooo`0?0?ooo`030000003oool0oooo
00d0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`3`0?ooo`000P3oool2000000X0
oooo0P0000020?ooo`D000001`3oool00`000000oooo0?ooo`3e0?ooo`030000003oool0oooo00<0
oooo0P00000@0?ooo`030000003oool0oooo00l0oooo00<000000?ooo`3oool03@3oool00`000000
oooo0?ooo`060?ooo`030000003oool0oooo0?00oooo000N0?ooo`030000003oool0oooo0?D0oooo
00<000000?ooo`3oool00`3oool200000100oooo00<000000?ooo`3oool03P3oool00`000000oooo
0?ooo`0>0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool0l03oool001h0oooo00<0
00000?ooo`3oool0m@3oool00`000000oooo0?ooo`030?ooo`800000403oool00`000000oooo0?oo
o`0>0?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?oo
o`3`0?ooo`007P3oool00`000000oooo0?ooo`3e0?ooo`030000003oool0oooo00<0oooo0P00000@
0?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool03`3oool00`000000oooo0?ooo`06
0?ooo`030000003oool0oooo0?00oooo000N0?ooo`030000003oool0oooo0?D0oooo00<000000?oo
o`3oool00`3oool200000100oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`0?0?oo
o`030000003oool0oooo00H0oooo00<000000?ooo`3oool0l03oool001h0oooo0`00003e0?ooo`03
0000003oool0oooo00<0oooo0`00000?0?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3o
ool0403oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo0?00oooo000N0?ooo`030000
003oool0oooo0?H0oooo00H000000?ooo`3oool0oooo0000003oool2000000l0oooo00<000000?oo
o`3oool0303oool00`000000oooo0?ooo`0@0?ooo`030000003oool0oooo00D0oooo00<000000?oo
o`3oool0l@3oool001h0oooo00<000000?ooo`3oool0mP3oool02@000000oooo0?ooo`3oool00000
0?ooo`000000oooo0000000>0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool04@3o
ool00`000000oooo0?ooo`050?ooo`030000003oool0oooo0?40oooo000N0?ooo`030000003oool0
oooo0?H0oooo00D000000?ooo`3oool0oooo000000020?ooo`8000003@3oool00`000000oooo0?oo
o`0<0?ooo`030000003oool0oooo0140oooo00<000000?ooo`3oool01@3oool00`000000oooo0?oo
o`3a0?ooo`007P3oool00`000000oooo0?ooo`3f0?ooo`050000003oool0oooo0?ooo`0000000P3o
ool00`000000oooo0000000<0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool04P3o
ool00`000000oooo0?ooo`050?ooo`030000003oool0oooo0?40oooo000N0?ooo`030000003oool0
oooo0?H0oooo00D000000?ooo`3oool0oooo000000020?ooo`030000003oool0000000`0oooo00<0
00000?ooo`3oool02`3oool00`000000oooo0?ooo`0B0?ooo`030000003oool0oooo00D0oooo00<0
00000?ooo`3oool0l@3oool001h0oooo00<000000?ooo`3oool0mP3oool010000000oooo0?ooo`00
00030?ooo`040000003oool0oooo000000/0oooo00<000000?ooo`3oool02P3oool00`000000oooo
0?ooo`0C0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool0l@3oool001h0oooo00<0
00000?ooo`3oool0mP3oool010000000oooo0?ooo`0000030?ooo`040000003oool0oooo000000/0
oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`0C0?ooo`030000003oool0oooo00D0
oooo00<000000?ooo`3oool0l@3oool001h0oooo0`00003f0?ooo`040000003oool0oooo000000<0
oooo00D000000?ooo`3oool0oooo0000000:0?ooo`030000003oool0oooo00T0oooo00<000000?oo
o`3oool0503oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo0?40oooo000N0?ooo`03
0000003oool0oooo0?H0oooo00@000000?ooo`3oool000000`3oool00`000000oooo0?ooo`020?oo
o`030000003oool0oooo00L0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`0D0?oo
o`030000003oool0oooo00D0oooo00<000000?ooo`3oool0l@3oool001h0oooo00<000000?ooo`3o
ool0mP3oool010000000oooo0?ooo`0000030?ooo`030000003oool0oooo0080oooo00<000000?oo
o`3oool01`3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo01@0oooo00<000000?oo
o`3oool01@3oool00`000000oooo0?ooo`3a0?ooo`007P3oool00`000000oooo0?ooo`3f0?ooo`03
0000003oool0000000@0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`060?ooo`03
0000003oool0oooo00P0oooo00<000000?ooo`3oool05P3oool00`000000oooo0?ooo`040?ooo`03
0000003oool0oooo0?40oooo000N0?ooo`030000003oool0oooo0?L0oooo0P0000040?ooo`030000
003oool0oooo00<0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`070?ooo`030000
003oool0oooo01L0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`3a0?ooo`007P3o
ool00`000000oooo0?ooo`3g0?ooo`800000103oool00`000000oooo0?ooo`040?ooo`030000003o
ool0oooo00D0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`0H0?ooo`030000003o
ool0oooo00@0oooo00<000000?ooo`3oool0l@3oool001h0oooo00<000000?ooo`3oool0m`3oool2
000000@0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`040?ooo`030000003oool0
oooo00D0oooo00<000000?ooo`3oool06@3oool00`000000oooo0?ooo`040?ooo`030000003oool0
oooo0?40oooo000N0?ooo`030000003oool0oooo0?L0oooo0P0000040?ooo`030000003oool0oooo
00H0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo
01X0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`3a0?ooo`007P3oool300000?L0
oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`070?ooo`8000000`3oool00`000000
oooo0?ooo`030?ooo`030000003oool0oooo01/0oooo00<000000?ooo`3oool0103oool00`000000
oooo0?ooo`3a0?ooo`007P3oool00`000000oooo0?ooo`3g0?ooo`030000003oool0oooo00<0oooo
00<000000?ooo`3oool02@3oool010000000oooo0?ooo`0000030?ooo`8000007P3oool00`000000
oooo0?ooo`040?ooo`030000003oool0oooo0?40oooo000N0?ooo`030000003oool0oooo0?d0oooo
00<000000?ooo`3oool02@3oool700000200oooo00<000000?ooo`3oool00`3oool00`000000oooo
0?ooo`3b0?ooo`007P3oool00`000000oooo0?ooo`3m0?ooo`030000003oool0oooo00`0oooo00<0
00000?ooo`3oool08@3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo0?80oooo000N
0?ooo`030000003oool0oooo0?h0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`0Q
0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0lP3oool001h0oooo00<000000?oo
o`3oool0oP3oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo0240oooo00<000000?oo
o`3oool00`3oool00`000000oooo0?ooo`3b0?ooo`007P3oool00`000000oooo0?ooo`3n0?ooo`03
0000003oool0oooo00/0oooo00<000000?ooo`3oool08@3oool00`000000oooo0?ooo`030?ooo`03
0000003oool0oooo0?80oooo000N0?ooo`030000003oool0oooo0?h0oooo00<000000?ooo`3oool0
2`3oool00`000000oooo0?ooo`0Q0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0
lP3oool001h0oooo00<000000?ooo`3oool0oP3oool00`000000oooo0?ooo`0:0?ooo`030000003o
ool0oooo0280oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`3b0?ooo`007P3oool3
00000?h0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`0R0?ooo`030000003oool0
oooo00<0oooo00<000000?ooo`3oool0lP3oool001h0oooo00<000000?ooo`3oool0oP3oool00`00
0000oooo0?ooo`0:0?ooo`030000003oool0oooo0280oooo00<000000?ooo`3oool00`3oool00`00
0000oooo0?ooo`3b0?ooo`007P3oool00`000000oooo0?ooo`3n0?ooo`030000003oool0oooo00X0
oooo00<000000?ooo`3oool08P3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo0?80
oooo000N0?ooo`030000003oool0oooo0?h0oooo00<000000?ooo`3oool02P3oool00`000000oooo
0?ooo`0R0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0lP3oool001h0oooo00<0
00000?ooo`3oool0oP3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo0280oooo00<0
00000?ooo`3oool00`3oool00`000000oooo0?ooo`3b0?ooo`007P3oool00`000000oooo0?ooo`3n
0?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool08`3oool00`000000oooo0?ooo`02
0?ooo`030000003oool0oooo0?80oooo00020?ooo`800000103oool00`000000oooo0?ooo`030?oo
o`8000000`3oool3000000P0oooo00<000000?ooo`3oool0oP3oool00`000000oooo0?ooo`0:0?oo
o`030000003oool0oooo02<0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`3b0?oo
o`0000D0oooo0000003oool0oooo000000080?ooo`060000003oool0oooo0000003oool000000`3o
ool00`000000oooo0?ooo`050?ooo`030000003oool0oooo0?h0oooo00<000000?ooo`3oool02P3o
ool00`000000oooo0?ooo`0S0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0lP3o
ool000050?ooo`000000oooo0?ooo`000000203oool01P000000oooo0?ooo`000000oooo000000<0
oooo00<000000?ooo`3oool01@3oool500000?`0oooo00<000000?ooo`3oool02P3oool00`000000
oooo0?ooo`0S0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0lP3oool000050?oo
o`000000oooo0?ooo`000000203oool01@000000oooo0?ooo`000000oooo00@00000203oool00`00
0000oooo0?ooo`3n0?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool08`3oool00`00
0000oooo0?ooo`020?ooo`030000003oool0oooo0?80oooo00001@3oool000000?ooo`3oool00000
00P0oooo00H000000?ooo`3oool000000?ooo`00000;0?ooo`030000003oool0oooo0?h0oooo00<0
00000?ooo`3oool02P3oool00`000000oooo0?ooo`0S0?ooo`050000003oool0oooo0?ooo`000000
m@3oool000050?ooo`000000oooo0?ooo`000000203oool010000000oooo0?ooo`0000020?ooo`03
0000003oool0oooo00P0oooo00<000000?ooo`3oool0oP3oool00`000000oooo0?ooo`0:0?ooo`03
0000003oool0oooo02<0oooo00D000000?ooo`3oool0oooo0000003e0?ooo`000P3oool2000000X0
oooo0P0000040?ooo`800000203oool00`000000oooo0?ooo`3o0?ooo`030000003oool0oooo00T0
oooo00<000000?ooo`3oool08`3oool01@000000oooo0?ooo`3oool000000?D0oooo000N0?ooo`03
0000003oool0oooo0?l0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`0S0?ooo`05
0000003oool0oooo0?ooo`000000m@3oool001h0oooo00<000000?ooo`3oool0o`3oool00`000000
oooo0?ooo`090?ooo`030000003oool0oooo02<0oooo00D000000?ooo`3oool0oooo0000003e0?oo
o`007P3oool00`000000oooo0?ooo`3o0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3o
ool08`3oool01@000000oooo0?ooo`3oool000000?D0oooo000N0?ooo`030000003oool0oooo0?l0
oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`0S0?ooo`050000003oool0oooo0?oo
o`000000m@3oool001h0oooo0`00003o0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3o
ool08`3oool01@000000oooo0?ooo`3oool000000?D0oooo000N0?ooo`030000003oool0oooo0?l0
oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`0S0?ooo`050000003oool0oooo0?oo
o`000000m@3oool001h0oooo00<000000?ooo`3oool0o`3oool00`000000oooo0?ooo`090?ooo`03
0000003oool0oooo02<0oooo00D000000?ooo`3oool0oooo0000003e0?ooo`007P3oool00`000000
oooo0?ooo`3o0?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool0903oool01@000000
oooo0?ooo`3oool000000?D0oooo000N0?ooo`030000003oool0oooo0?l0oooo00<000000?ooo`3o
ool0203oool00`000000oooo0?ooo`0T0?ooo`050000003oool0oooo0?ooo`000000m@3oool001h0
oooo00<000000?ooo`3oool0o`3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo02@0
oooo00D000000?ooo`3oool0oooo0000003e0?ooo`007P3oool00`000000oooo0?ooo`3o0?ooo`03
0000003oool0oooo00P0oooo00<000000?ooo`3oool0903oool01@000000oooo0?ooo`3oool00000
0?D0oooo000N0?ooo`030000003oool0oooo0?l0oooo00<000000?ooo`3oool0203oool00`000000
oooo0?ooo`0U0?ooo`040000003oool0oooo00000?D0oooo000N0?ooo`<00000o`3oool00`000000
oooo0?ooo`080?ooo`030000003oool0oooo02D0oooo00@000000?ooo`3oool00000m@3oool001h0
oooo00<000000?ooo`3oool0o`3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo02D0
oooo00@000000?ooo`3oool00000m@3oool001h0oooo00<000000?ooo`3oool0o`3oool00`000000
oooo0?ooo`080?ooo`030000003oool0oooo02D0oooo00<000000?ooo`000000mP3oool001h0oooo
00<000000?ooo`3oool0o`3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo02D0oooo
00<000000?ooo`000000mP3oool001h0oooo00<000000?ooo`3oool0o`3oool00`000000oooo0?oo
o`080?ooo`030000003oool0oooo02D0oooo00<000000?ooo`000000mP3oool001h0oooo00<00000
0?ooo`3oool0o`3oool10?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool09@3oool0
0`000000oooo0000003f0?ooo`007P3oool00`000000oooo0?ooo`3o0?ooo`40oooo00<000000?oo
o`3oool01`3oool00`000000oooo0?ooo`0U0?ooo`030000003oool000000?H0oooo000N0?ooo`03
0000003oool0oooo0?l0oooo0@3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo02D0
oooo00<000000?ooo`000000mP3oool001h0oooo00<000000?ooo`3oool0o`3oool10?ooo`030000
003oool0oooo00L0oooo00<000000?ooo`3oool09@3oool00`000000oooo0000003f0?ooo`007P3o
ool300000?l0oooo0@3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo02D0oooo00<0
00000?ooo`000000mP3oool001h0oooo00<000000?ooo`3oool0o`3oool10?ooo`030000003oool0
oooo00L0oooo00<000000?ooo`3oool09@3oool00`000000oooo0000003f0?ooo`007P3oool00`00
0000oooo0?ooo`3o0?ooo`40oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`0U0?oo
o`030000003oool000000?H0oooo000N0?ooo`030000003oool0oooo0?l0oooo0@3oool00`000000
oooo0?ooo`070?ooo`030000003oool0oooo02D0oooo00<000000?ooo`000000mP3oool001h0oooo
00<000000?ooo`3oool0o`3oool10?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool0
9@3oool00`000000oooo0000003f0?ooo`007P3oool00`000000oooo0?ooo`3o0?ooo`40oooo00<0
00000?ooo`3oool01`3oool00`000000oooo0?ooo`0U0?ooo`030000003oool000000?H0oooo000N
0?ooo`030000003oool0oooo0?l0oooo0@3oool00`000000oooo0?ooo`070?ooo`030000003oool0
oooo02D0oooo00<000000?ooo`000000mP3oool001h0oooo00<000000?ooo`3oool0o`3oool10?oo
o`030000003oool0oooo00H0oooo00<000000?ooo`3oool09P3oool00`000000oooo0000003f0?oo
o`007P3oool300000?l0oooo0@3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo02H0
oooo00<000000?ooo`000000mP3oool001h0oooo00<000000?ooo`3oool0o`3oool10?ooo`030000
003oool0oooo00H0oooo00<000000?ooo`3oool09`3oool200000?H0oooo000N0?ooo`030000003o
ool0oooo0?l0oooo0@3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo02L0oooo00<0
00000?ooo`3oool0m@3oool001h0oooo00<000000?ooo`3oool0o`3oool10?ooo`030000003oool0
oooo00H0oooo00<000000?ooo`3oool09`3oool00`000000oooo0?ooo`3e0?ooo`007P3oool00`00
0000oooo0?ooo`3o0?ooo`40oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`0W0?oo
o`030000003oool0oooo0?D0oooo000N0?ooo`030000003oool0oooo0?l0oooo0P3oool00`000000
oooo0?ooo`050?ooo`030000003oool0oooo02L0oooo00<000000?ooo`3oool0m@3oool00080oooo
0P0000040?ooo`030000003oool0oooo00<0oooo0P0000040?ooo`030000003oool0oooo00L0oooo
00<000000?ooo`3oool0o`3oool20?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool0
9`3oool00`000000oooo0?ooo`3e0?ooo`0000D0oooo0000003oool0oooo000000080?ooo`040000
003oool0oooo000000<0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`3o0?ooo`80
oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`0W0?ooo`030000003oool0oooo0?D0
oooo00001@3oool000000?ooo`3oool0000000P0oooo00@000000?ooo`3oool00000103oool00`00
0000oooo0?ooo`060?ooo`030000003oool0oooo0?l0oooo0P3oool00`000000oooo0?ooo`050?oo
o`030000003oool0oooo02L0oooo00<000000?ooo`3oool0m@3oool000050?ooo`000000oooo0?oo
o`000000203oool010000000oooo0?ooo`0000040?ooo`030000003oool0oooo00H0oooo1@00003o
0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool09`3oool00`000000oooo0?ooo`3e
0?ooo`0000D0oooo0000003oool0oooo000000080?ooo`040000003oool0oooo000000D0oooo00<0
00000?ooo`3oool01@3oool00`000000oooo0?ooo`3o0?ooo`80oooo00<000000?ooo`3oool01@3o
ool00`000000oooo0?ooo`0W0?ooo`030000003oool0oooo0?D0oooo00001@3oool000000?ooo`3o
ool0000000P0oooo00H000000?ooo`3oool000000?ooo`0000030?ooo`030000003oool0oooo00D0
oooo00<000000?ooo`3oool0o`3oool20?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3o
ool0o`3ooolP0?ooo`000P3oool2000000X0oooo0P0000020?ooo`D000001`3oool00`000000oooo
0?ooo`3o0?ooo`80oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`3o0?ooob00oooo
000N0?ooo`030000003oool0oooo0?l0oooo0P3oool00`000000oooo0?ooo`050?ooo`030000003o
ool0oooo0?l0oooo803oool001h0oooo00<000000?ooo`3oool0o`3oool20?ooo`030000003oool0
oooo00D0oooo00<000000?ooo`3oool0o`3ooolP0?ooo`007P3oool00`000000oooo0?ooo`3o0?oo
o`80oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`3o0?ooob00oooo000N0?ooo`03
0000003oool0oooo0?l0oooo0P3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo0?l0
oooo803oool001h0oooo0`00003o0?ooo`80oooo00<000000?ooo`3oool01@3oool00`000000oooo
0?ooo`3o0?ooob00oooo000N0?ooo`030000003oool0oooo0?l0oooo0P3oool00`000000oooo0?oo
o`050?ooo`030000003oool0oooo0?l0oooo803oool001h0oooo00<000000?ooo`3oool0o`3oool2
0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool0o`3ooolP0?ooo`007P3oool00`00
0000oooo0?ooo`3o0?ooo`80oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`3o0?oo
ob40oooo000N0?ooo`030000003oool0oooo0?l0oooo0P3oool00`000000oooo0?ooo`040?ooo`03
0000003oool0oooo0?l0oooo8@3oool001h0oooo00<000000?ooo`3oool0o`3oool30?ooo`030000
003oool0oooo00<0oooo00<000000?ooo`3oool0o`3ooolQ0?ooo`007P3oool00`000000oooo0?oo
o`3o0?ooo`<0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`3o0?ooob40oooo000N
0?ooo`030000003oool0oooo0?l0oooo0`3oool00`000000oooo0?ooo`030?ooo`030000003oool0
oooo0?l0oooo8@3oool001h0oooo00<000000?ooo`3oool0o`3oool30?ooo`030000003oool0oooo
00<0oooo00<000000?ooo`3oool0o`3ooolQ0?ooo`007P3oool300000?l0oooo0`3oool00`000000
oooo0?ooo`030?ooo`030000003oool0oooo0?l0oooo8@3oool001h0oooo00<000000?ooo`3oool0
o`3oool30?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0o`3ooolQ0?ooo`007P3o
ool00`000000oooo0?ooo`3o0?ooo`<0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?oo
o`3o0?ooob40oooo000N0?ooo`030000003oool0oooo0?l0oooo0`3oool00`000000oooo0?ooo`03
0?ooo`030000003oool0oooo0?l0oooo8@3oool001h0oooo00<000000?ooo`3oool0o`3oool30?oo
o`030000003oool0oooo00<0oooo00<000000?ooo`3oool0o`3ooolQ0?ooo`007P3oool00`000000
oooo0?ooo`3o0?ooo`<0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`3o0?ooob40
oooo000N0?ooo`030000003oool0oooo0?l0oooo0`3oool00`000000oooo0?ooo`030?ooo`030000
003oool0oooo0?l0oooo8@3oool001h0oooo00<000000?ooo`3oool0o`3oool30?ooo`030000003o
ool0oooo00<0oooo00<000000?ooo`3oool0o`3ooolQ0?ooo`007P3oool300000?l0oooo103oool0
0`000000oooo0?ooo`020?ooo`030000003oool0oooo0?l0oooo8@3oool001h0oooo00<000000?oo
o`3oool0o`3oool40?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0o`3ooolQ0?oo
o`007P3oool00`000000oooo0?ooo`3o0?ooo`@0oooo00<000000?ooo`3oool00P3oool00`000000
oooo0?ooo`3o0?ooob40oooo000N0?ooo`030000003oool0oooo0?l0oooo103oool00`000000oooo
0?ooo`020?ooo`030000003oool0oooo0?l0oooo8@3oool001h0oooo00<000000?ooo`3oool0o`3o
ool40?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0o`3ooolQ0?ooo`007P3oool0
0`000000oooo0?ooo`3o0?ooo`D0oooo00D000000?ooo`3oool0oooo0000003o0?ooob<0oooo000N
0?ooo`030000003oool0oooo0?l0oooo1@3oool01@000000oooo0?ooo`3oool000000?l0oooo8`3o
ool001h0oooo00<000000?ooo`3oool0o`3oool50?ooo`040000003oool0oooo00000?l0oooo903o
ool001h0oooo00<000000?ooo`3oool0o`3oool50?ooo`040000003oool0oooo00000?l0oooo903o
ool001h0oooo0`00003o0?ooo`D0oooo00@000000?ooo`3oool00000o`3ooolT0?ooo`007P3oool0
0`000000oooo0?ooo`3o0?ooo`H0oooo00<000000?ooo`000000o`3ooolT0?ooo`007P3oool00`00
0000oooo0?ooo`3o0?ooo`H0oooo00<000000?ooo`000000o`3ooolT0?ooo`007P3oool00`000000
oooo0?ooo`3o0?ooo`H0oooo00<000000?ooo`000000o`3ooolT0?ooo`007P3oool00`000000oooo
0?ooo`3o0?ooo`H0oooo00<000000?ooo`000000o`3ooolT0?ooo`007P3oool00`000000oooo0?oo
o`3o0?ooo`H0oooo00<000000?ooo`000000o`3ooolT0?ooo`000P3oool2000000@0oooo00<00000
0?ooo`3oool00`3oool2000000<0oooo0`0000080?ooo`030000003oool0oooo0?l0oooo1`3oool2
00000?l0oooo903oool000050?ooo`000000oooo0?ooo`000000203oool01P000000oooo0?ooo`00
0000oooo000000<0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`3o0?ooo`L0oooo
0P00003o0?ooob@0oooo00001@3oool000000?ooo`3oool0000000P0oooo00H000000?ooo`3oool0
00000?ooo`0000030?ooo`030000003oool0oooo00D0oooo1@00003o0?ooo`D0oooo0P00003o0?oo
ob@0oooo00001@3oool000000?ooo`3oool0000000P0oooo00@000000?ooo`3oool000000P3oool3
00000?l0ooooo`3ooolh0?ooo`0000D0oooo0000003oool0oooo000000080?ooo`060000003oool0
oooo0000003oool000000`3oool00`000000oooo0?ooo`3o0?ooool0oooo=@3oool000050?ooo`00
0000oooo0?ooo`000000203oool01P000000oooo0?ooo`000000oooo000000<0oooo00<000000?oo
o`3oool0o`3ooooo0?ooocD0oooo00020?ooo`8000002P3oool2000000<0oooo0`00003o0?ooool0
oooo>03oool00?l0ooooo`3ooom>0?ooo`00o`3ooooo0?ooodh0oooo0000\
\>"],
  ImageRangeCache->{{{0, 587.75}, {362.875, 0}} -> {-5.6309, -0.00420624, \
0.182516, 0.000236254}}]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["Mean # of lineages is 19.67", "SubsubsectionIcon"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(nlineages = Length /@ lpList;\)\), "\n", 
    \(\(ListPlot[Transpose[{te, nlineages}], 
        PlotJoined -> True];\)\), "\[IndentingNewLine]", 
    \(Mean[Drop[nlineages, 500]] // N\)}], "Input",
  CellLabel->"In[198]:="],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.100201 0.0147151 0.0202967 [
[.22421 .00222 -3 -9 ]
[.22421 .00222 3 0 ]
[.42461 .00222 -3 -9 ]
[.42461 .00222 3 0 ]
[.62501 .00222 -3 -9 ]
[.62501 .00222 3 0 ]
[.82542 .00222 -3 -9 ]
[.82542 .00222 3 0 ]
[.01131 .1162 -6 -4.5 ]
[.01131 .1162 0 4.5 ]
[.01131 .21768 -12 -4.5 ]
[.01131 .21768 0 4.5 ]
[.01131 .31917 -12 -4.5 ]
[.01131 .31917 0 4.5 ]
[.01131 .42065 -12 -4.5 ]
[.01131 .42065 0 4.5 ]
[.01131 .52213 -12 -4.5 ]
[.01131 .52213 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.22421 .01472 m
.22421 .02097 L
s
[(2)] .22421 .00222 0 1 Mshowa
.42461 .01472 m
.42461 .02097 L
s
[(4)] .42461 .00222 0 1 Mshowa
.62501 .01472 m
.62501 .02097 L
s
[(6)] .62501 .00222 0 1 Mshowa
.82542 .01472 m
.82542 .02097 L
s
[(8)] .82542 .00222 0 1 Mshowa
.125 Mabswid
.07391 .01472 m
.07391 .01847 L
s
.12401 .01472 m
.12401 .01847 L
s
.17411 .01472 m
.17411 .01847 L
s
.27431 .01472 m
.27431 .01847 L
s
.32441 .01472 m
.32441 .01847 L
s
.37451 .01472 m
.37451 .01847 L
s
.47471 .01472 m
.47471 .01847 L
s
.52481 .01472 m
.52481 .01847 L
s
.57491 .01472 m
.57491 .01847 L
s
.67511 .01472 m
.67511 .01847 L
s
.72521 .01472 m
.72521 .01847 L
s
.77532 .01472 m
.77532 .01847 L
s
.87552 .01472 m
.87552 .01847 L
s
.92562 .01472 m
.92562 .01847 L
s
.97572 .01472 m
.97572 .01847 L
s
.25 Mabswid
0 .01472 m
1 .01472 L
s
.02381 .1162 m
.03006 .1162 L
s
[(5)] .01131 .1162 1 0 Mshowa
.02381 .21768 m
.03006 .21768 L
s
[(10)] .01131 .21768 1 0 Mshowa
.02381 .31917 m
.03006 .31917 L
s
[(15)] .01131 .31917 1 0 Mshowa
.02381 .42065 m
.03006 .42065 L
s
[(20)] .01131 .42065 1 0 Mshowa
.02381 .52213 m
.03006 .52213 L
s
[(25)] .01131 .52213 1 0 Mshowa
.125 Mabswid
.02381 .03501 m
.02756 .03501 L
s
.02381 .05531 m
.02756 .05531 L
s
.02381 .07561 m
.02756 .07561 L
s
.02381 .0959 m
.02756 .0959 L
s
.02381 .1365 m
.02756 .1365 L
s
.02381 .15679 m
.02756 .15679 L
s
.02381 .17709 m
.02756 .17709 L
s
.02381 .19739 m
.02756 .19739 L
s
.02381 .23798 m
.02756 .23798 L
s
.02381 .25828 m
.02756 .25828 L
s
.02381 .27857 m
.02756 .27857 L
s
.02381 .29887 m
.02756 .29887 L
s
.02381 .33946 m
.02756 .33946 L
s
.02381 .35976 m
.02756 .35976 L
s
.02381 .38006 m
.02756 .38006 L
s
.02381 .40035 m
.02756 .40035 L
s
.02381 .44095 m
.02756 .44095 L
s
.02381 .46124 m
.02756 .46124 L
s
.02381 .48154 m
.02756 .48154 L
s
.02381 .50184 m
.02756 .50184 L
s
.02381 .54243 m
.02756 .54243 L
s
.02381 .56273 m
.02756 .56273 L
s
.02381 .58302 m
.02756 .58302 L
s
.02381 .60332 m
.02756 .60332 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .03501 m
.02863 .05531 L
.0314 .07561 L
.03188 .0959 L
.03267 .1162 L
.03285 .1365 L
.03685 .1162 L
.03944 .1365 L
.03953 .1162 L
.03988 .0959 L
.04014 .1162 L
.04027 .1365 L
.04073 .15679 L
.04431 .17709 L
.04477 .19739 L
.04556 .17709 L
.04644 .19739 L
.04669 .21768 L
.04713 .23798 L
.04982 .21768 L
.04994 .23798 L
.05001 .25828 L
.05076 .23798 L
.05155 .25828 L
.05234 .27857 L
.05434 .25828 L
.05455 .23798 L
.055 .25828 L
.05543 .27857 L
.05575 .29887 L
.05618 .27857 L
.05618 .29887 L
.05673 .27857 L
.05687 .29887 L
.05851 .27857 L
.05974 .29887 L
.06062 .31917 L
.06144 .29887 L
.06225 .27857 L
.06232 .29887 L
.06264 .31917 L
.0631 .29887 L
.0644 .31917 L
.06558 .33946 L
.06664 .35976 L
.06673 .38006 L
.06763 .35976 L
.06849 .33946 L
.06913 .31917 L
.06927 .29887 L
Mistroke
.06951 .31917 L
.06956 .33946 L
.06958 .31917 L
.07016 .29887 L
.07221 .31917 L
.07248 .29887 L
.07265 .31917 L
.0733 .33946 L
.0744 .31917 L
.07449 .29887 L
.07469 .31917 L
.07563 .29887 L
.07601 .27857 L
.07668 .25828 L
.07685 .27857 L
.07697 .25828 L
.07698 .27857 L
.0777 .29887 L
.07821 .31917 L
.07903 .33946 L
.08122 .35976 L
.08159 .33946 L
.08223 .31917 L
.08353 .29887 L
.08373 .27857 L
.08562 .29887 L
.08616 .31917 L
.08673 .33946 L
.08742 .31917 L
.08817 .33946 L
.08877 .31917 L
.08889 .29887 L
.0889 .31917 L
.08907 .33946 L
.08918 .35976 L
.09032 .33946 L
.09075 .31917 L
.09129 .33946 L
.09172 .35976 L
.09179 .38006 L
.09207 .40035 L
.09235 .42065 L
.09253 .40035 L
.09272 .38006 L
.09283 .35976 L
.09294 .33946 L
.09342 .31917 L
.09407 .33946 L
.09416 .31917 L
.09421 .29887 L
Mistroke
.09458 .31917 L
.09476 .33946 L
.09481 .31917 L
.09555 .29887 L
.09578 .27857 L
.0965 .25828 L
.09667 .27857 L
.09913 .25828 L
.09924 .23798 L
.09927 .25828 L
.09961 .27857 L
.10102 .25828 L
.10131 .23798 L
.10185 .21768 L
.10215 .23798 L
.10218 .25828 L
.10286 .27857 L
.103 .29887 L
.104 .27857 L
.10429 .29887 L
.10487 .31917 L
.10488 .29887 L
.10531 .31917 L
.106 .33946 L
.10637 .35976 L
.10677 .33946 L
.10702 .31917 L
.10765 .33946 L
.10771 .31917 L
.10813 .29887 L
.10829 .27857 L
.1086 .29887 L
.10913 .27857 L
.10934 .25828 L
.10973 .23798 L
.1117 .25828 L
.11292 .27857 L
.11393 .29887 L
.11503 .27857 L
.11649 .25828 L
.11678 .23798 L
.11686 .21768 L
.1185 .19739 L
.11898 .17709 L
.11934 .19739 L
.11987 .21768 L
.12048 .23798 L
.12118 .25828 L
.12187 .23798 L
.12206 .25828 L
Mistroke
.12208 .23798 L
.12223 .25828 L
.12244 .23798 L
.1225 .21768 L
.12325 .23798 L
.12377 .21768 L
.12385 .19739 L
.12392 .17709 L
.1252 .19739 L
.12567 .21768 L
.12594 .23798 L
.12703 .25828 L
.12734 .27857 L
.1275 .29887 L
.12781 .27857 L
.12945 .25828 L
.13403 .27857 L
.13422 .25828 L
.13568 .23798 L
.13599 .25828 L
.13612 .27857 L
.1362 .29887 L
.13653 .27857 L
.13677 .25828 L
.13699 .23798 L
.13775 .25828 L
.1392 .27857 L
.13934 .29887 L
.13996 .31917 L
.14068 .29887 L
.14116 .27857 L
.14116 .25828 L
.14124 .23798 L
.1413 .25828 L
.14194 .23798 L
.1421 .25828 L
.14236 .23798 L
.14266 .25828 L
.14414 .27857 L
.14433 .25828 L
.14479 .27857 L
.14506 .25828 L
.14519 .27857 L
.14522 .25828 L
.14652 .27857 L
.14664 .25828 L
.14676 .27857 L
.1475 .25828 L
.14783 .23798 L
.14806 .25828 L
Mistroke
.14823 .23798 L
.14856 .25828 L
.14898 .23798 L
.14909 .25828 L
.14936 .27857 L
.14969 .29887 L
.14969 .31917 L
.15016 .29887 L
.15044 .31917 L
.15252 .33946 L
.15306 .31917 L
.15376 .29887 L
.15397 .27857 L
.15512 .25828 L
.15523 .23798 L
.15556 .25828 L
.15677 .27857 L
.15681 .25828 L
.15735 .27857 L
.15787 .29887 L
.15889 .27857 L
.15893 .29887 L
.15917 .31917 L
.16024 .29887 L
.16033 .31917 L
.16068 .33946 L
.16071 .31917 L
.1608 .29887 L
.16101 .31917 L
.16101 .33946 L
.1622 .31917 L
.16261 .29887 L
.16464 .31917 L
.16507 .29887 L
.16525 .31917 L
.16583 .29887 L
.16657 .27857 L
.16756 .25828 L
.168 .23798 L
.1681 .25828 L
.16826 .27857 L
.16874 .29887 L
.16896 .31917 L
.16905 .29887 L
.1693 .27857 L
.16938 .29887 L
.16995 .31917 L
.17018 .29887 L
.17079 .27857 L
.17236 .29887 L
Mistroke
.17238 .27857 L
.1724 .29887 L
.17245 .27857 L
.17247 .25828 L
.17247 .23798 L
.17303 .25828 L
.1736 .27857 L
.17379 .29887 L
.17433 .27857 L
.17457 .29887 L
.17546 .31917 L
.17557 .29887 L
.17698 .27857 L
.17719 .25828 L
.17842 .23798 L
.17857 .25828 L
.18019 .27857 L
.18143 .25828 L
.1816 .23798 L
.1818 .25828 L
.18228 .27857 L
.18245 .25828 L
.18292 .27857 L
.1838 .25828 L
.18474 .23798 L
.18572 .25828 L
.18622 .23798 L
.18654 .25828 L
.18708 .27857 L
.18783 .29887 L
.18787 .27857 L
.18848 .29887 L
.18939 .27857 L
.18997 .29887 L
.19056 .31917 L
.1907 .29887 L
.19141 .31917 L
.19152 .29887 L
.19166 .27857 L
.1918 .29887 L
.19188 .31917 L
.19264 .33946 L
.19302 .31917 L
.19307 .33946 L
.19379 .35976 L
.19381 .33946 L
.19393 .35976 L
.19403 .38006 L
.19454 .40035 L
.195 .42065 L
Mistroke
.19505 .40035 L
.19541 .42065 L
.19549 .40035 L
.19649 .42065 L
.19864 .44095 L
.19865 .42065 L
.19914 .40035 L
.19962 .42065 L
.1998 .40035 L
.20023 .42065 L
.20059 .40035 L
.20069 .38006 L
.20092 .35976 L
.20193 .38006 L
.20217 .40035 L
.20233 .42065 L
.20247 .44095 L
.2025 .42065 L
.20282 .44095 L
.20319 .46124 L
.20336 .48154 L
.20347 .46124 L
.20366 .48154 L
.2037 .46124 L
.20424 .44095 L
.20445 .42065 L
.20509 .44095 L
.20566 .46124 L
.20568 .48154 L
.20581 .46124 L
.2065 .44095 L
.20651 .46124 L
.20663 .44095 L
.20675 .42065 L
.20731 .44095 L
.20813 .42065 L
.20822 .40035 L
.20837 .38006 L
.20844 .35976 L
.20858 .33946 L
.20864 .35976 L
.20903 .38006 L
.20904 .40035 L
.20933 .38006 L
.20956 .40035 L
.21021 .38006 L
.21077 .35976 L
.2111 .38006 L
.21139 .40035 L
.21181 .42065 L
Mistroke
.21181 .44095 L
.2119 .42065 L
.21295 .44095 L
.21329 .42065 L
.21344 .44095 L
.21363 .42065 L
.21371 .40035 L
.21376 .42065 L
.21384 .40035 L
.21402 .38006 L
.21413 .40035 L
.21435 .42065 L
.21466 .44095 L
.21488 .46124 L
.21506 .44095 L
.21546 .42065 L
.21666 .40035 L
.2173 .38006 L
.21812 .35976 L
.21822 .33946 L
.21842 .35976 L
.21852 .38006 L
.21858 .35976 L
.21877 .33946 L
.21896 .35976 L
.21944 .33946 L
.22027 .31917 L
.22039 .33946 L
.22046 .31917 L
.22114 .33946 L
.22163 .31917 L
.2218 .33946 L
.22187 .35976 L
.22254 .33946 L
.22273 .31917 L
.2229 .33946 L
.22357 .31917 L
.22361 .33946 L
.22475 .35976 L
.22479 .33946 L
.22481 .31917 L
.22484 .33946 L
.22525 .35976 L
.22641 .33946 L
.2269 .35976 L
.2272 .38006 L
.22734 .40035 L
.22759 .42065 L
.22798 .40035 L
.2281 .42065 L
Mistroke
.22855 .40035 L
.22884 .38006 L
.2292 .40035 L
.22925 .42065 L
.22948 .40035 L
.23026 .42065 L
.23049 .44095 L
.23122 .42065 L
.23136 .44095 L
.23153 .42065 L
.23222 .44095 L
.23309 .42065 L
.23321 .40035 L
.23322 .42065 L
.23342 .40035 L
.23355 .42065 L
.23384 .44095 L
.23481 .42065 L
.23503 .40035 L
.23553 .38006 L
.2357 .35976 L
.23576 .38006 L
.23627 .35976 L
.23627 .38006 L
.23643 .40035 L
.23653 .42065 L
.23669 .44095 L
.23678 .42065 L
.23734 .44095 L
.23763 .42065 L
.23772 .44095 L
.23862 .42065 L
.23906 .40035 L
.23926 .38006 L
.23934 .40035 L
.24038 .42065 L
.24073 .44095 L
.24113 .46124 L
.24118 .44095 L
.24179 .46124 L
.24259 .44095 L
.2426 .42065 L
.24264 .44095 L
.24278 .46124 L
.24279 .48154 L
.24304 .46124 L
.24314 .48154 L
.2436 .46124 L
.24366 .42065 L
.24366 .42065 L
Mistroke
.24402 .44095 L
.24413 .42065 L
.24463 .40035 L
.24531 .38006 L
.24532 .35976 L
.24533 .33946 L
.246 .31917 L
.24643 .33946 L
.24652 .35976 L
.24704 .33946 L
.24732 .35976 L
.2479 .38006 L
.24823 .35976 L
.24824 .38006 L
.24835 .35976 L
.24872 .33946 L
.24926 .31917 L
.24959 .33946 L
.24967 .35976 L
.24976 .38006 L
.25009 .35976 L
.25022 .33946 L
.25046 .31917 L
.25073 .29887 L
.25171 .27857 L
.25188 .29887 L
.25228 .31917 L
.25273 .33946 L
.25338 .31917 L
.25338 .29887 L
.25343 .31917 L
.25345 .33946 L
.25467 .31917 L
.25485 .33946 L
.25496 .35976 L
.2552 .38006 L
.25526 .40035 L
.25535 .42065 L
.25578 .40035 L
.25599 .38006 L
.25621 .40035 L
.25631 .42065 L
.25682 .44095 L
.25684 .46124 L
.25699 .42065 L
.25699 .42065 L
.25724 .44095 L
.25743 .42065 L
.25746 .44095 L
.25829 .42065 L
Mistroke
.25838 .44095 L
.25849 .42065 L
.25917 .44095 L
.25929 .42065 L
.25977 .44095 L
.26026 .42065 L
.26027 .40035 L
.26029 .38006 L
.26075 .40035 L
.26082 .42065 L
.26092 .40035 L
.26097 .42065 L
.261 .40035 L
.26103 .42065 L
.26241 .40035 L
.26255 .42065 L
.26262 .44095 L
.26285 .42065 L
.26301 .44095 L
.26344 .46124 L
.26348 .48154 L
.26362 .46124 L
.26451 .48154 L
.26467 .46124 L
.26473 .44095 L
.26487 .46124 L
.26598 .44095 L
.266 .42065 L
.26623 .44095 L
.26639 .46124 L
.26646 .44095 L
.26679 .46124 L
.26702 .48154 L
.26712 .46124 L
.26772 .44095 L
.2678 .42065 L
.26835 .40035 L
.26845 .38006 L
.2686 .35976 L
.26888 .38006 L
.26891 .40035 L
.26897 .42065 L
.26898 .44095 L
.26913 .42065 L
.26922 .44095 L
.26942 .46124 L
.26966 .48154 L
.27022 .46124 L
.27036 .44095 L
.27123 .46124 L
Mistroke
.27124 .44095 L
.27176 .42065 L
.27181 .44095 L
.27239 .46124 L
.27244 .44095 L
.27251 .42065 L
.27259 .44095 L
.27276 .42065 L
.27286 .40035 L
.27312 .38006 L
.27333 .35976 L
.27391 .33946 L
.27533 .31917 L
.27664 .33946 L
.27665 .31917 L
.27668 .33946 L
.27681 .31917 L
.27682 .33946 L
.27762 .35976 L
.27811 .33946 L
.27851 .31917 L
.27858 .29887 L
.27875 .31917 L
.2791 .29887 L
.27948 .31917 L
.2796 .33946 L
.27974 .31917 L
.28053 .33946 L
.28087 .35976 L
.28107 .33946 L
.28126 .31917 L
.28151 .33946 L
.28163 .31917 L
.28179 .33946 L
.28188 .31917 L
.28217 .33946 L
.28219 .35976 L
.28264 .33946 L
.28339 .35976 L
.28351 .38006 L
.28383 .35976 L
.28387 .33946 L
.28405 .35976 L
.28429 .38006 L
.28671 .35976 L
.28709 .38006 L
.28717 .35976 L
.28817 .38006 L
.28884 .35976 L
.28885 .33946 L
Mistroke
.28928 .35976 L
.28939 .33946 L
.28996 .31917 L
.2908 .33946 L
.29101 .35976 L
.29117 .38006 L
.29168 .35976 L
.29207 .38006 L
.29217 .35976 L
.29221 .38006 L
.2933 .35976 L
.2935 .33946 L
.2936 .35976 L
.29387 .35976 L
.29387 .35976 L
.29391 .33946 L
.29432 .35976 L
.29438 .38006 L
.2947 .35976 L
.29562 .33946 L
.29617 .35976 L
.29653 .38006 L
.29653 .40035 L
.2967 .38006 L
.29679 .40035 L
.29713 .42065 L
.29735 .40035 L
.29757 .38006 L
.29758 .35976 L
.29906 .38006 L
.29933 .40035 L
.29936 .38006 L
.29941 .35976 L
.30033 .38006 L
.30043 .40035 L
.3005 .38006 L
.30054 .40035 L
.30121 .42065 L
.30123 .40035 L
.30163 .38006 L
.30221 .35976 L
.30279 .38006 L
.30286 .40035 L
.30303 .42065 L
.3037 .40035 L
.3039 .38006 L
.30399 .35976 L
.30406 .33946 L
.30494 .31917 L
.30557 .29887 L
Mistroke
.30643 .31917 L
.307 .29887 L
.30706 .27857 L
.30821 .29887 L
.3084 .31917 L
.30904 .29887 L
.30911 .31917 L
.30947 .33946 L
.3095 .31917 L
.31013 .29887 L
.31016 .27857 L
.31039 .29887 L
.31054 .31917 L
.3107 .29887 L
.31096 .31917 L
.31143 .29887 L
.31186 .31917 L
.31225 .33946 L
.31227 .35976 L
.31256 .33946 L
.31292 .35976 L
.31368 .38006 L
.31437 .40035 L
.31447 .38006 L
.31507 .40035 L
.31518 .38006 L
.31538 .35976 L
.31625 .33946 L
.31656 .31917 L
.31697 .33946 L
.31783 .35976 L
.31877 .38006 L
.31901 .40035 L
.31903 .38006 L
.31914 .40035 L
.31936 .42065 L
.31987 .44095 L
.32001 .46124 L
.32102 .48154 L
.32103 .46124 L
.32166 .48154 L
.32205 .46124 L
.32213 .44095 L
.32288 .42065 L
.32358 .44095 L
.32385 .46124 L
.32387 .44095 L
.32402 .46124 L
.32444 .48154 L
.32456 .50184 L
Mistroke
.32464 .48154 L
.32467 .46124 L
.32475 .48154 L
.32488 .50184 L
.32488 .52213 L
.32543 .54243 L
.32558 .52213 L
.32649 .54243 L
.32675 .52213 L
.32676 .50184 L
.32676 .48154 L
.32746 .50184 L
.32774 .52213 L
.32792 .50184 L
.32888 .48154 L
.32942 .46124 L
.32949 .48154 L
.32952 .46124 L
.32998 .44095 L
.33004 .46124 L
.33024 .48154 L
.33059 .46124 L
.33102 .48154 L
.33113 .50184 L
.3312 .48154 L
.33123 .46124 L
.33225 .50184 L
.33225 .50184 L
.33303 .52213 L
.33343 .54243 L
.33399 .52213 L
.33422 .50184 L
.33479 .48154 L
.33487 .46124 L
.33494 .48154 L
.33583 .50184 L
.33593 .52213 L
.33597 .50184 L
.33654 .48154 L
.33715 .46124 L
.33735 .44095 L
.33803 .42065 L
.33813 .44095 L
.33821 .46124 L
.3383 .44095 L
.33858 .46124 L
.33867 .44095 L
.33922 .46124 L
.3394 .48154 L
.33962 .50184 L
Mistroke
.33962 .52213 L
.33981 .50184 L
.33998 .48154 L
.3405 .50184 L
.34081 .48154 L
.34096 .46124 L
.34103 .48154 L
.34105 .46124 L
.34118 .44095 L
.34119 .42065 L
.34148 .44095 L
.34165 .46124 L
.342 .48154 L
.34217 .46124 L
.34225 .48154 L
.34258 .44095 L
.34258 .44095 L
.34278 .46124 L
.34295 .44095 L
.34296 .46124 L
.34296 .44095 L
.34325 .42065 L
.34327 .44095 L
.3435 .42065 L
.34353 .40035 L
.34388 .42065 L
.34411 .44095 L
.34428 .42065 L
.34487 .44095 L
.34558 .46124 L
.34561 .48154 L
.34576 .46124 L
.34585 .44095 L
.3459 .42065 L
.34614 .44095 L
.34634 .42065 L
.34646 .40035 L
.34667 .42065 L
.34682 .44095 L
.34691 .42065 L
.34717 .44095 L
.34729 .42065 L
.34748 .44095 L
.34752 .42065 L
.34803 .44095 L
.3489 .46124 L
.34899 .48154 L
.34948 .50184 L
.34966 .48154 L
.35039 .46124 L
Mistroke
.35071 .48154 L
.35111 .50184 L
.35122 .52213 L
.35134 .50184 L
.35193 .48154 L
.35257 .46124 L
.3527 .48154 L
.35306 .46124 L
.3532 .44095 L
.35321 .42065 L
.35333 .44095 L
.35345 .46124 L
.35347 .48154 L
.35365 .46124 L
.35401 .44095 L
.35413 .46124 L
.35427 .44095 L
.35456 .42065 L
.35486 .44095 L
.35513 .42065 L
.35516 .44095 L
.35524 .42065 L
.35526 .40035 L
.3553 .42065 L
.35654 .40035 L
.35659 .38006 L
.35687 .35976 L
.35696 .33946 L
.35733 .35976 L
.35738 .38006 L
.35798 .35976 L
.35813 .38006 L
.35822 .35976 L
.35828 .33946 L
.35843 .31917 L
.35857 .29887 L
.35891 .27857 L
.36015 .29887 L
.36025 .31917 L
.36068 .33946 L
.36085 .35976 L
.36106 .38006 L
.36138 .35976 L
.36208 .33946 L
.36225 .35976 L
.36226 .38006 L
.36233 .35976 L
.36256 .38006 L
.3626 .35976 L
.36278 .38006 L
Mistroke
.36313 .35976 L
.36406 .38006 L
.36449 .35976 L
.36479 .33946 L
.36489 .31917 L
.36561 .29887 L
.36579 .31917 L
.36612 .33946 L
.36781 .35976 L
.36796 .33946 L
.36885 .31917 L
.36944 .33946 L
.36962 .35976 L
.36964 .33946 L
.3698 .35976 L
.36982 .38006 L
.37022 .40035 L
.37066 .38006 L
.37084 .35976 L
.37108 .38006 L
.37112 .35976 L
.37162 .33946 L
.37186 .35976 L
.37188 .38006 L
.37218 .40035 L
.37237 .38006 L
.37267 .35976 L
.37327 .38006 L
.37406 .40035 L
.37438 .38006 L
.37439 .35976 L
.37535 .38006 L
.37606 .35976 L
.37688 .38006 L
.37743 .40035 L
.37784 .38006 L
.37823 .35976 L
.37829 .33946 L
.37832 .31917 L
.37896 .33946 L
.37901 .31917 L
.38062 .33946 L
.38065 .31917 L
.38068 .33946 L
.38147 .31917 L
.3817 .33946 L
.38185 .31917 L
.38231 .33946 L
.38267 .35976 L
.383 .33946 L
Mistroke
.38385 .31917 L
.38388 .29887 L
.38389 .31917 L
.38448 .29887 L
.38451 .27857 L
.38515 .25828 L
.38528 .27857 L
.3871 .29887 L
.3873 .27857 L
.38751 .29887 L
.38761 .31917 L
.38846 .29887 L
.3889 .31917 L
.38891 .33946 L
.3896 .31917 L
.38975 .29887 L
.39019 .27857 L
.39034 .29887 L
.39049 .27857 L
.39102 .25828 L
.39164 .23798 L
.39196 .25828 L
.39198 .23798 L
.39254 .25828 L
.39274 .27857 L
.39284 .29887 L
.39291 .27857 L
.39339 .25828 L
.3951 .27857 L
.39511 .29887 L
.39611 .27857 L
.39653 .29887 L
.3984 .27857 L
.39847 .29887 L
.3992 .31917 L
.40022 .33946 L
.40041 .31917 L
.40063 .33946 L
.40083 .35976 L
.40106 .33946 L
.40183 .35976 L
.40277 .33946 L
.40336 .35976 L
.40355 .33946 L
.4042 .35976 L
.40596 .38006 L
.40632 .40035 L
.40653 .42065 L
.40673 .44095 L
.40727 .46124 L
Mistroke
.40838 .44095 L
.40844 .46124 L
.40895 .44095 L
.40938 .42065 L
.40959 .44095 L
.40979 .42065 L
.40984 .44095 L
.40987 .42065 L
.40995 .40035 L
.41038 .38006 L
.41092 .35976 L
.41113 .33946 L
.4113 .35976 L
.41179 .33946 L
.4118 .31917 L
.41185 .33946 L
.41189 .31917 L
.41192 .33946 L
.41206 .35976 L
.41221 .33946 L
.41273 .35976 L
.41296 .33946 L
.41352 .35976 L
.41368 .38006 L
.41372 .35976 L
.41394 .38006 L
.41417 .40035 L
.41455 .38006 L
.41491 .35976 L
.41515 .38006 L
.41544 .40035 L
.41552 .42065 L
.41578 .40035 L
.41581 .42065 L
.41593 .40035 L
.41644 .38006 L
.41653 .40035 L
.41657 .42065 L
.41664 .40035 L
.41732 .42065 L
.41766 .44095 L
.41772 .46124 L
.41871 .48154 L
.41881 .46124 L
.41893 .44095 L
.41909 .46124 L
.41942 .44095 L
.41943 .42065 L
.41979 .44095 L
.42024 .42065 L
Mistroke
.42031 .40035 L
.42044 .42065 L
.42183 .40035 L
.42204 .42065 L
.42234 .40035 L
.42301 .38006 L
.4232 .35976 L
.42327 .33946 L
.42328 .35976 L
.42345 .38006 L
.42395 .40035 L
.4241 .42065 L
.42421 .44095 L
.42457 .42065 L
.42467 .40035 L
.42474 .42065 L
.42529 .40035 L
.4254 .38006 L
.42625 .40035 L
.42646 .38006 L
.42719 .40035 L
.42784 .42065 L
.42804 .44095 L
.42821 .46124 L
.42849 .48154 L
.42851 .46124 L
.42876 .48154 L
.42877 .46124 L
.42881 .48154 L
.42917 .46124 L
.4295 .48154 L
.42984 .50184 L
.42989 .48154 L
.43037 .46124 L
.43094 .48154 L
.43115 .46124 L
.43144 .44095 L
.43154 .42065 L
.43178 .40035 L
.43188 .42065 L
.43244 .44095 L
.43248 .42065 L
.43327 .44095 L
.43354 .42065 L
.43419 .40035 L
.43488 .42065 L
.4349 .40035 L
.43507 .42065 L
.43509 .44095 L
.43535 .42065 L
Mistroke
.43558 .40035 L
.43583 .38006 L
.436 .40035 L
.436 .38006 L
.43634 .40035 L
.43667 .42065 L
.43778 .44095 L
.43807 .42065 L
.43826 .40035 L
.43849 .42065 L
.4386 .40035 L
.43911 .38006 L
.43926 .35976 L
.43927 .38006 L
.43932 .35976 L
.43956 .38006 L
.4397 .35976 L
.44015 .33946 L
.44082 .31917 L
.44151 .29887 L
.44184 .27857 L
.4423 .25828 L
.44389 .27857 L
.44408 .29887 L
.44426 .27857 L
.4444 .25828 L
.44453 .27857 L
.44516 .29887 L
.44551 .31917 L
.44551 .29887 L
.44617 .31917 L
.44626 .33946 L
.44696 .31917 L
.4481 .29887 L
.44895 .31917 L
.44926 .29887 L
.44957 .31917 L
.44966 .29887 L
.45032 .31917 L
.45055 .29887 L
.45064 .31917 L
.45083 .33946 L
.45157 .31917 L
.45262 .33946 L
.45309 .35976 L
.4536 .38006 L
.45402 .35976 L
.45426 .33946 L
.45456 .31917 L
.45472 .29887 L
Mistroke
.45481 .27857 L
.45487 .29887 L
.45489 .27857 L
.45541 .29887 L
.45549 .27857 L
.45596 .29887 L
.45612 .31917 L
.45613 .29887 L
.45647 .31917 L
.4565 .33946 L
.45684 .35976 L
.45685 .38006 L
.45704 .35976 L
.45715 .38006 L
.45754 .40035 L
.45754 .38006 L
.45801 .35976 L
.45805 .33946 L
.45938 .31917 L
.45988 .33946 L
.46055 .35976 L
.46061 .33946 L
.46267 .35976 L
.4627 .33946 L
.46272 .31917 L
.46295 .29887 L
.46296 .31917 L
.46297 .29887 L
.46304 .31917 L
.46318 .33946 L
.46322 .35976 L
.46357 .38006 L
.46376 .35976 L
.46491 .38006 L
.46491 .40035 L
.46585 .42065 L
.46653 .44095 L
.467 .42065 L
.46703 .40035 L
.46755 .42065 L
.46773 .44095 L
.46825 .46124 L
.46854 .44095 L
.46892 .46124 L
.46915 .48154 L
.46919 .46124 L
.46937 .48154 L
.46955 .46124 L
.47018 .48154 L
.47157 .46124 L
Mistroke
.4717 .48154 L
.47193 .50184 L
.47223 .48154 L
.47228 .46124 L
.47231 .44095 L
.47241 .42065 L
.4726 .40035 L
.47274 .42065 L
.47347 .44095 L
.47357 .46124 L
.47373 .44095 L
.47374 .46124 L
.47409 .48154 L
.4757 .50184 L
.4758 .48154 L
.4759 .46124 L
.47604 .44095 L
.47638 .42065 L
.47783 .40035 L
.47979 .38006 L
.47991 .35976 L
.48 .38006 L
.48012 .35976 L
.48039 .33946 L
.48094 .35976 L
.48123 .33946 L
.48156 .35976 L
.48206 .33946 L
.48239 .31917 L
.48261 .33946 L
.48274 .35976 L
.48307 .38006 L
.48319 .40035 L
.48383 .42065 L
.48409 .44095 L
.48421 .42065 L
.48425 .44095 L
.48442 .46124 L
.48459 .48154 L
.48464 .46124 L
.48474 .44095 L
.4848 .42065 L
.4848 .44095 L
.48498 .46124 L
.48507 .44095 L
.48552 .42065 L
.48565 .44095 L
.48607 .42065 L
.48669 .44095 L
.48678 .46124 L
Mistroke
.48685 .44095 L
.48691 .46124 L
.48694 .44095 L
.48701 .42065 L
.4877 .40035 L
.48835 .38006 L
.48869 .40035 L
.48936 .40035 L
.48936 .40035 L
.4895 .38006 L
.48984 .35976 L
.48984 .38006 L
.48995 .35976 L
.49041 .38006 L
.49042 .40035 L
.49098 .38006 L
.4919 .35976 L
.49217 .33946 L
.49293 .35976 L
.49304 .33946 L
.49305 .35976 L
.49312 .33946 L
.49343 .31917 L
.4937 .29887 L
.49373 .31917 L
.49437 .33946 L
.49493 .31917 L
.49504 .33946 L
.49528 .35976 L
.49675 .33946 L
.49724 .35976 L
.49733 .38006 L
.49739 .35976 L
.49776 .38006 L
.4978 .40035 L
.49792 .38006 L
.49835 .40035 L
.49845 .38006 L
.49951 .40035 L
.49961 .38006 L
.4998 .40035 L
.5003 .38006 L
.50035 .35976 L
.50051 .38006 L
.50094 .40035 L
.5016 .38006 L
.50162 .40035 L
.50166 .38006 L
.50178 .40035 L
.50188 .38006 L
Mistroke
.50217 .40035 L
.5024 .38006 L
.50262 .35976 L
.50277 .33946 L
.50334 .35976 L
.50336 .38006 L
.50346 .40035 L
.50533 .38006 L
.50546 .35976 L
.50556 .38006 L
.50588 .40035 L
.50625 .38006 L
.50637 .35976 L
.50733 .38006 L
.50752 .40035 L
.50753 .38006 L
.50759 .35976 L
.50822 .38006 L
.50825 .35976 L
.50852 .33946 L
.50862 .35976 L
.50868 .33946 L
.50903 .35976 L
.50913 .38006 L
.50979 .40035 L
.50993 .38006 L
.51069 .40035 L
.51079 .42065 L
.51099 .44095 L
.51101 .46124 L
.51126 .44095 L
.51137 .46124 L
.51186 .48154 L
.51231 .46124 L
.51237 .44095 L
.51243 .42065 L
.51302 .44095 L
.5131 .46124 L
.51326 .44095 L
.51359 .42065 L
.51413 .40035 L
.51438 .42065 L
.51465 .40035 L
.51477 .42065 L
.51597 .44095 L
.51608 .42065 L
.5168 .40035 L
.51686 .42065 L
.51699 .40035 L
.51739 .38006 L
Mistroke
.51794 .40035 L
.51803 .38006 L
.51889 .40035 L
.51892 .38006 L
.51897 .35976 L
.51988 .38006 L
.52012 .40035 L
.52046 .38006 L
.5205 .35976 L
.52087 .38006 L
.52141 .35976 L
.52145 .38006 L
.52222 .35976 L
.52272 .33946 L
.52307 .35976 L
.52321 .38006 L
.52338 .40035 L
.5235 .42065 L
.52447 .44095 L
.52449 .46124 L
.52453 .48154 L
.52498 .46124 L
.52512 .48154 L
.52588 .50184 L
.52631 .48154 L
.5264 .46124 L
.52666 .44095 L
.52705 .42065 L
.52763 .44095 L
.52807 .42065 L
.52925 .44095 L
.52941 .46124 L
.52956 .44095 L
.52977 .42065 L
.52981 .40035 L
.52985 .42065 L
.52991 .40035 L
.53009 .42065 L
.53013 .40035 L
.53022 .38006 L
.53048 .35976 L
.53089 .33946 L
.53104 .35976 L
.5313 .38006 L
.53163 .35976 L
.53191 .38006 L
.53203 .35976 L
.53204 .38006 L
.53251 .40035 L
.53283 .38006 L
Mistroke
.53347 .40035 L
.53353 .42065 L
.53355 .40035 L
.5337 .38006 L
.53451 .40035 L
.53459 .42065 L
.53461 .44095 L
.53469 .42065 L
.53542 .40035 L
.53571 .38006 L
.53585 .35976 L
.53587 .38006 L
.53595 .40035 L
.53596 .42065 L
.53598 .44095 L
.53748 .46124 L
.53791 .44095 L
.53807 .46124 L
.53812 .44095 L
.53825 .46124 L
.53844 .44095 L
.53877 .46124 L
.539 .44095 L
.53934 .42065 L
.53943 .40035 L
.54014 .42065 L
.54042 .40035 L
.54055 .38006 L
.54102 .35976 L
.54121 .33946 L
.54154 .35976 L
.54173 .33946 L
.54207 .35976 L
.54208 .38006 L
.5423 .40035 L
.54261 .38006 L
.54274 .35976 L
.54287 .33946 L
.54363 .35976 L
.54397 .38006 L
.54406 .35976 L
.54437 .38006 L
.54446 .40035 L
.54447 .38006 L
.54495 .40035 L
.54519 .38006 L
.54519 .35976 L
.54523 .33946 L
.54526 .35976 L
.54539 .38006 L
Mistroke
.5456 .35976 L
.5461 .33946 L
.54675 .35976 L
.54734 .38006 L
.54839 .40035 L
.54842 .42065 L
.54862 .40035 L
.54927 .42065 L
.54932 .44095 L
.54965 .42065 L
.5502 .40035 L
.55027 .42065 L
.55054 .40035 L
.5506 .38006 L
.55079 .40035 L
.55089 .38006 L
.55092 .40035 L
.55107 .42065 L
.55108 .40035 L
.55147 .38006 L
.55185 .40035 L
.55235 .38006 L
.55255 .40035 L
.55361 .42065 L
.55362 .44095 L
.55382 .42065 L
.55389 .44095 L
.55478 .46124 L
.55483 .48154 L
.55495 .46124 L
.55525 .44095 L
.55545 .42065 L
.5555 .40035 L
.55553 .38006 L
.55601 .40035 L
.55613 .38006 L
.55631 .40035 L
.55671 .42065 L
.55686 .40035 L
.55728 .38006 L
.55729 .40035 L
.55771 .42065 L
.55775 .40035 L
.55841 .38006 L
.55887 .40035 L
.55948 .42065 L
.56013 .44095 L
.56019 .42065 L
.56045 .44095 L
.56072 .46124 L
Mistroke
.56126 .48154 L
.56127 .50184 L
.56147 .52213 L
.56169 .54243 L
.56193 .52213 L
.56227 .50184 L
.56257 .52213 L
.56271 .50184 L
.56388 .52213 L
.56426 .50184 L
.56429 .52213 L
.56435 .50184 L
.5645 .52213 L
.56457 .54243 L
.56483 .52213 L
.56523 .52213 L
.56523 .52213 L
.56537 .50184 L
.56538 .48154 L
.56547 .50184 L
.56559 .48154 L
.56564 .46124 L
.56578 .48154 L
.56587 .46124 L
.56622 .44095 L
.56653 .42065 L
.5668 .40035 L
.56704 .42065 L
.56705 .44095 L
.56773 .42065 L
.56775 .44095 L
.56801 .46124 L
.5683 .44095 L
.56851 .46124 L
.56861 .48154 L
.5689 .46124 L
.56919 .44095 L
.56922 .46124 L
.56938 .48154 L
.56969 .46124 L
.57004 .44095 L
.57029 .42065 L
.57084 .44095 L
.57084 .42065 L
.57134 .40035 L
.57141 .42065 L
.57147 .40035 L
.57213 .42065 L
.5722 .40035 L
.57233 .42065 L
Mistroke
.57342 .40035 L
.57371 .38006 L
.574 .35976 L
.57414 .33946 L
.57427 .35976 L
.57439 .33946 L
.57449 .31917 L
.57505 .33946 L
.57516 .31917 L
.57551 .33946 L
.57601 .35976 L
.5767 .38006 L
.57702 .40035 L
.57709 .38006 L
.57807 .35976 L
.57819 .38006 L
.57914 .35976 L
.57928 .38006 L
.58016 .35976 L
.58024 .33946 L
.58026 .35976 L
.58038 .33946 L
.58124 .35976 L
.58146 .38006 L
.58172 .40035 L
.58231 .42065 L
.58255 .40035 L
.58273 .38006 L
.58316 .35976 L
.58421 .33946 L
.58437 .35976 L
.58449 .33946 L
.58462 .35976 L
.58486 .38006 L
.58507 .35976 L
.58525 .33946 L
.58528 .31917 L
.58543 .33946 L
.5857 .31917 L
.58577 .29887 L
.58578 .27857 L
.58592 .25828 L
.5863 .27857 L
.58633 .29887 L
.58651 .27857 L
.58654 .29887 L
.58685 .31917 L
.58718 .29887 L
.58796 .27857 L
.58854 .29887 L
Mistroke
.58893 .31917 L
.58898 .29887 L
.58917 .31917 L
.58936 .33946 L
.58967 .31917 L
.58989 .29887 L
.59043 .31917 L
.59047 .33946 L
.59161 .35976 L
.59175 .38006 L
.59196 .35976 L
.59196 .33946 L
.59214 .35976 L
.59273 .33946 L
.5928 .35976 L
.59297 .38006 L
.59332 .40035 L
.59406 .38006 L
.59409 .40035 L
.59419 .38006 L
.59426 .40035 L
.59508 .38006 L
.59531 .40035 L
.59531 .42065 L
.59575 .44095 L
.59616 .46124 L
.59667 .48154 L
.59703 .46124 L
.59752 .44095 L
.59754 .46124 L
.59764 .48154 L
.59769 .50184 L
.5979 .48154 L
.5981 .50184 L
.5985 .52213 L
.59856 .54243 L
.59859 .56273 L
.5995 .58302 L
.59955 .56273 L
.60018 .54243 L
.60075 .52213 L
.60087 .50184 L
.60093 .52213 L
.6013 .50184 L
.60138 .48154 L
.60144 .50184 L
.60181 .52213 L
.60228 .50184 L
.60237 .52213 L
.60254 .50184 L
Mistroke
.60266 .52213 L
.60292 .50184 L
.60365 .52213 L
.60438 .50184 L
.6046 .52213 L
.6048 .50184 L
.60482 .48154 L
.60502 .50184 L
.60509 .52213 L
.60524 .50184 L
.60574 .48154 L
.60583 .46124 L
.60618 .44095 L
.60637 .42065 L
.60639 .44095 L
.60648 .46124 L
.60651 .44095 L
.60664 .46124 L
.60665 .44095 L
.60674 .46124 L
.60722 .48154 L
.60739 .46124 L
.60749 .48154 L
.6075 .50184 L
.60767 .48154 L
.60783 .50184 L
.60793 .52213 L
.60801 .50184 L
.60802 .48154 L
.60823 .50184 L
.60834 .48154 L
.60868 .46124 L
.60954 .44095 L
.60986 .46124 L
.60988 .48154 L
.61022 .46124 L
.6103 .44095 L
.61034 .42065 L
.6105 .44095 L
.61083 .46124 L
.61091 .44095 L
.61097 .42065 L
.61098 .40035 L
.61132 .38006 L
.61138 .40035 L
.61143 .38006 L
.61167 .40035 L
.61172 .42065 L
.61196 .40035 L
.6121 .42065 L
Mistroke
.61234 .44095 L
.6126 .46124 L
.61261 .48154 L
.6132 .50184 L
.61357 .48154 L
.61368 .50184 L
.61382 .52213 L
.61389 .50184 L
.6139 .48154 L
.61401 .46124 L
.61412 .44095 L
.61417 .46124 L
.61446 .44095 L
.61452 .42065 L
.61457 .44095 L
.61502 .46124 L
.6154 .44095 L
.61557 .42065 L
.61558 .40035 L
.61594 .38006 L
.61609 .35976 L
.61645 .33946 L
.61655 .35976 L
.61657 .33946 L
.61675 .35976 L
.61675 .38006 L
.61701 .35976 L
.61709 .38006 L
.61746 .40035 L
.61761 .42065 L
.61767 .44095 L
.61768 .42065 L
.61779 .44095 L
.61798 .42065 L
.61825 .44095 L
.6192 .46124 L
.61956 .48154 L
.61968 .46124 L
.61974 .44095 L
.6201 .42065 L
.62018 .40035 L
.62019 .42065 L
.62094 .40035 L
.62106 .42065 L
.62143 .40035 L
.62184 .38006 L
.62203 .35976 L
.62208 .38006 L
.62209 .40035 L
.6221 .38006 L
Mistroke
.62282 .35976 L
.62294 .38006 L
.62306 .40035 L
.62343 .42065 L
.62384 .40035 L
.62416 .42065 L
.62468 .40035 L
.62475 .42065 L
.62502 .44095 L
.62516 .46124 L
.62537 .48154 L
.62545 .50184 L
.62546 .52213 L
.62607 .54243 L
.62608 .52213 L
.62642 .50184 L
.62701 .48154 L
.62759 .46124 L
.62802 .48154 L
.62835 .46124 L
.62915 .48154 L
.6298 .46124 L
.63016 .44095 L
.63046 .46124 L
.63063 .48154 L
.63074 .46124 L
.63113 .48154 L
.63127 .46124 L
.63129 .44095 L
.63165 .42065 L
.63173 .44095 L
.63174 .46124 L
.63211 .44095 L
.63229 .46124 L
.6323 .48154 L
.63265 .46124 L
.63275 .48154 L
.63321 .46124 L
.63331 .48154 L
.63367 .46124 L
.6338 .44095 L
.63386 .42065 L
.63433 .44095 L
.63457 .42065 L
.63463 .44095 L
.63479 .42065 L
.63482 .44095 L
.63515 .42065 L
.63655 .40035 L
.63682 .42065 L
Mistroke
.63687 .40035 L
.63697 .38006 L
.63728 .35976 L
.63739 .33946 L
.63742 .35976 L
.63781 .33946 L
.63877 .35976 L
.63904 .38006 L
.63927 .40035 L
.63942 .42065 L
.63949 .44095 L
.63963 .42065 L
.63999 .44095 L
.64014 .46124 L
.64024 .48154 L
.64026 .50184 L
.64092 .48154 L
.641 .46124 L
.64139 .44095 L
.64141 .42065 L
.64176 .40035 L
.64203 .42065 L
.64229 .40035 L
.64247 .38006 L
.6425 .40035 L
.64255 .42065 L
.64262 .44095 L
.64264 .42065 L
.64275 .44095 L
.64287 .42065 L
.64315 .40035 L
.64537 .38006 L
.64557 .40035 L
.64559 .38006 L
.64564 .40035 L
.64584 .42065 L
.64601 .44095 L
.64607 .42065 L
.64626 .44095 L
.64667 .42065 L
.64711 .40035 L
.64728 .38006 L
.64762 .35976 L
.6478 .38006 L
.64807 .35976 L
.64811 .38006 L
.6484 .40035 L
.64849 .38006 L
.64867 .40035 L
.64912 .42065 L
Mistroke
.64921 .40035 L
.64977 .42065 L
.64989 .44095 L
.64991 .46124 L
.65005 .44095 L
.65087 .46124 L
.65099 .48154 L
.651 .50184 L
.65114 .52213 L
.65117 .54243 L
.65133 .52213 L
.65161 .50184 L
.65181 .52213 L
.65245 .54243 L
.65259 .52213 L
.65308 .50184 L
.65333 .48154 L
.65335 .46124 L
.65367 .48154 L
.65373 .46124 L
.65388 .48154 L
.65404 .46124 L
.65404 .44095 L
.65407 .46124 L
.65427 .44095 L
.65458 .42065 L
.65501 .40035 L
.65546 .42065 L
.65558 .40035 L
.65591 .38006 L
.65633 .35976 L
.65678 .38006 L
.6568 .35976 L
.65694 .38006 L
.65699 .35976 L
.65702 .38006 L
.65711 .40035 L
.65719 .42065 L
.65719 .44095 L
.65806 .46124 L
.65845 .48154 L
.65927 .46124 L
.65931 .44095 L
.65988 .42065 L
.65992 .40035 L
.65998 .38006 L
.66035 .40035 L
.66057 .38006 L
.66084 .40035 L
.66098 .38006 L
Mistroke
.661 .35976 L
.66168 .38006 L
.6618 .40035 L
.66192 .42065 L
.66238 .40035 L
.6628 .42065 L
.66282 .40035 L
.66292 .42065 L
.66345 .40035 L
.6649 .38006 L
.66541 .35976 L
.66591 .38006 L
.66609 .40035 L
.66646 .42065 L
.66648 .40035 L
.66654 .38006 L
.66697 .40035 L
.66713 .42065 L
.66758 .40035 L
.66765 .42065 L
.66779 .44095 L
.66804 .46124 L
.66834 .44095 L
.66843 .46124 L
.66939 .44095 L
.66944 .46124 L
.66972 .48154 L
.66991 .50184 L
.67003 .48154 L
.6701 .46124 L
.6704 .44095 L
.67045 .46124 L
.67054 .44095 L
.67077 .42065 L
.67086 .40035 L
.67095 .38006 L
.67133 .40035 L
.67144 .42065 L
.67144 .44095 L
.67225 .42065 L
.67231 .40035 L
.67255 .42065 L
.67258 .44095 L
.6726 .46124 L
.67291 .48154 L
.67305 .50184 L
.67306 .52213 L
.67345 .50184 L
.67359 .48154 L
.6737 .50184 L
Mistroke
.67374 .52213 L
.67374 .50184 L
.67377 .48154 L
.67391 .50184 L
.67407 .48154 L
.67467 .46124 L
.67492 .48154 L
.67521 .50184 L
.67526 .52213 L
.6756 .50184 L
.67573 .52213 L
.67592 .54243 L
.67615 .52213 L
.67616 .52213 L
.67616 .52213 L
.67618 .50184 L
.67619 .52213 L
.67634 .50184 L
.67637 .48154 L
.67674 .46124 L
.6769 .44095 L
.6771 .42065 L
.67747 .44095 L
.67756 .46124 L
.67758 .48154 L
.67785 .50184 L
.67792 .52213 L
.67792 .50184 L
.67814 .52213 L
.67821 .54243 L
.67834 .52213 L
.67854 .54243 L
.67884 .56273 L
.67889 .58302 L
.6789 .60332 L
.67904 .58302 L
.67911 .56273 L
.67923 .54243 L
.67934 .52213 L
.67944 .54243 L
.67954 .56273 L
.67957 .54243 L
.6799 .52213 L
.68038 .54243 L
.68053 .56273 L
.68061 .54243 L
.68063 .52213 L
.68069 .54243 L
.6811 .56273 L
.68136 .54243 L
Mistroke
.68144 .52213 L
.68145 .54243 L
.6815 .52213 L
.68157 .54243 L
.6816 .56273 L
.68163 .54243 L
.68186 .56273 L
.68195 .54243 L
.682 .52213 L
.68219 .50184 L
.68233 .48154 L
.68242 .46124 L
.68258 .48154 L
.68288 .50184 L
.6835 .48154 L
.68364 .46124 L
.68368 .44095 L
.68368 .42065 L
.68387 .44095 L
.68395 .42065 L
.68407 .44095 L
.68416 .46124 L
.68424 .48154 L
.68428 .50184 L
.68458 .48154 L
.68521 .46124 L
.68587 .48154 L
.68588 .46124 L
.68636 .44095 L
.68663 .42065 L
.68694 .40035 L
.68695 .38006 L
.68702 .35976 L
.6872 .33946 L
.68759 .35976 L
.68777 .38006 L
.68781 .35976 L
.68824 .38006 L
.6884 .40035 L
.68933 .42065 L
.68958 .44095 L
.68977 .46124 L
.68987 .44095 L
.69 .44095 L
.69 .44095 L
.69044 .42065 L
.69077 .44095 L
.6909 .46124 L
.69188 .44095 L
.69235 .42065 L
Mistroke
.69253 .40035 L
.69253 .38006 L
.69267 .40035 L
.69269 .38006 L
.69379 .40035 L
.69394 .38006 L
.69397 .40035 L
.69496 .42065 L
.6952 .40035 L
.69537 .42065 L
.69553 .44095 L
.69554 .42065 L
.69556 .40035 L
.69657 .42065 L
.69663 .40035 L
.69699 .38006 L
.69867 .40035 L
.69956 .42065 L
.69968 .40035 L
.69969 .42065 L
.69972 .44095 L
.70057 .42065 L
.70059 .44095 L
.70078 .42065 L
.70163 .40035 L
.70216 .42065 L
.70246 .44095 L
.70256 .42065 L
.7032 .40035 L
.70331 .38006 L
.70339 .35976 L
.70417 .38006 L
.70505 .40035 L
.70517 .42065 L
.70547 .40035 L
.7057 .42065 L
.70571 .44095 L
.7059 .42065 L
.70603 .40035 L
.70681 .38006 L
.70686 .40035 L
.7071 .42065 L
.70742 .44095 L
.70767 .42065 L
.70808 .44095 L
.70819 .46124 L
.70869 .48154 L
.70885 .50184 L
.70901 .48154 L
.70908 .46124 L
Mistroke
.70929 .48154 L
.70979 .46124 L
.70981 .48154 L
.71016 .50184 L
.7102 .48154 L
.71028 .50184 L
.71037 .48154 L
.71065 .50184 L
.71097 .48154 L
.71121 .50184 L
.71155 .48154 L
.71178 .46124 L
.71201 .48154 L
.71271 .50184 L
.71282 .48154 L
.71293 .50184 L
.71305 .48154 L
.71331 .50184 L
.71348 .48154 L
.71388 .46124 L
.71415 .48154 L
.71455 .46124 L
.71469 .48154 L
.71474 .50184 L
.71493 .52213 L
.71497 .54243 L
.71506 .52213 L
.71517 .50184 L
.71545 .52213 L
.71598 .50184 L
.71598 .48154 L
.71601 .50184 L
.71608 .48154 L
.71647 .46124 L
.71691 .48154 L
.71697 .50184 L
.71748 .48154 L
.71759 .46124 L
.7177 .44095 L
.71819 .46124 L
.71827 .48154 L
.71836 .50184 L
.71838 .52213 L
.71847 .50184 L
.71869 .52213 L
.71915 .50184 L
.71925 .52213 L
.7194 .54243 L
.71949 .56273 L
.71969 .54243 L
Mistroke
.71991 .56273 L
.72003 .58302 L
.72028 .56273 L
.72042 .54243 L
.72076 .52213 L
.72091 .54243 L
.72092 .52213 L
.72131 .50184 L
.72147 .48154 L
.72152 .46124 L
.72158 .44095 L
.72204 .46124 L
.72208 .48154 L
.72226 .46124 L
.72229 .44095 L
.72267 .46124 L
.72356 .44095 L
.72381 .42065 L
.72389 .40035 L
.72415 .38006 L
.72457 .40035 L
.72475 .38006 L
.72486 .40035 L
.72488 .42065 L
.72537 .44095 L
.72539 .46124 L
.72604 .44095 L
.7264 .46124 L
.72644 .48154 L
.72672 .50184 L
.72706 .48154 L
.72706 .46124 L
.72717 .44095 L
.72773 .42065 L
.72779 .40035 L
.72788 .38006 L
.72794 .40035 L
.72802 .42065 L
.72806 .40035 L
.72807 .42065 L
.72818 .44095 L
.72831 .42065 L
.72847 .44095 L
.72849 .42065 L
.72854 .44095 L
.72861 .46124 L
.72876 .44095 L
.72928 .46124 L
.72946 .48154 L
.72993 .50184 L
Mistroke
.72996 .48154 L
.7306 .50184 L
.73123 .48154 L
.73133 .50184 L
.73143 .48154 L
.73161 .50184 L
.73232 .52213 L
.73241 .54243 L
.73262 .52213 L
.73278 .50184 L
.73283 .52213 L
.73288 .54243 L
.73297 .52213 L
.73308 .50184 L
.73313 .52213 L
.7334 .50184 L
.73365 .48154 L
.73366 .50184 L
.73443 .48154 L
.73443 .46124 L
.73464 .44095 L
.73471 .46124 L
.73495 .44095 L
.73508 .46124 L
.73533 .44095 L
.73581 .42065 L
.73591 .40035 L
.736 .42065 L
.73709 .40035 L
.73714 .38006 L
.73729 .40035 L
.73737 .42065 L
.7376 .44095 L
.73777 .46124 L
.73801 .48154 L
.73807 .50184 L
.73818 .52213 L
.73832 .50184 L
.73853 .48154 L
.73854 .50184 L
.73872 .50184 L
.73872 .50184 L
.73909 .52213 L
.73923 .50184 L
.73977 .48154 L
.74025 .50184 L
.74027 .52213 L
.74094 .50184 L
.74105 .52213 L
.74146 .50184 L
Mistroke
.74163 .48154 L
.74188 .46124 L
.74188 .44095 L
.74211 .46124 L
.7422 .48154 L
.74229 .46124 L
.74244 .44095 L
.74253 .42065 L
.74264 .40035 L
.743 .38006 L
.74314 .35976 L
.7433 .33946 L
.74383 .35976 L
.74442 .33946 L
.74448 .35976 L
.74448 .38006 L
.74456 .40035 L
.74512 .38006 L
.74512 .40035 L
.74555 .42065 L
.74563 .44095 L
.7458 .42065 L
.7459 .44095 L
.74667 .42065 L
.74669 .44095 L
.74724 .46124 L
.74725 .48154 L
.7476 .50184 L
.74806 .48154 L
.74812 .46124 L
.74837 .48154 L
.74852 .46124 L
.74874 .44095 L
.74891 .46124 L
.74901 .48154 L
.74906 .46124 L
.74948 .44095 L
.74991 .42065 L
.74992 .44095 L
.75006 .46124 L
.75018 .44095 L
.75035 .42065 L
.75076 .44095 L
.75113 .42065 L
.75139 .44095 L
.75199 .42065 L
.75227 .40035 L
.75232 .42065 L
.75321 .44095 L
.75328 .42065 L
Mistroke
.75343 .44095 L
.75345 .42065 L
.75345 .44095 L
.75367 .42065 L
.75369 .44095 L
.75427 .42065 L
.75442 .44095 L
.75509 .46124 L
.75514 .48154 L
.7554 .50184 L
.7554 .52213 L
.75554 .54243 L
.75594 .52213 L
.75613 .50184 L
.75651 .48154 L
.75662 .46124 L
.75663 .44095 L
.75674 .42065 L
.75723 .40035 L
.75732 .42065 L
.75739 .44095 L
.75749 .42065 L
.75753 .44095 L
.75756 .42065 L
.75763 .40035 L
.75773 .38006 L
.75792 .35976 L
.75841 .38006 L
.75849 .35976 L
.75884 .38006 L
.75902 .40035 L
.75911 .38006 L
.7594 .35976 L
.75996 .38006 L
.76016 .35976 L
.76039 .38006 L
.7604 .40035 L
.76059 .38006 L
.76061 .40035 L
.7608 .38006 L
.7609 .35976 L
.76094 .33946 L
.76145 .31917 L
.76253 .29887 L
.76254 .27857 L
.76261 .29887 L
.76389 .31917 L
.76401 .29887 L
.76404 .27857 L
.76435 .29887 L
Mistroke
.76445 .31917 L
.76505 .29887 L
.76526 .31917 L
.7657 .33946 L
.76579 .35976 L
.76588 .38006 L
.76608 .35976 L
.76613 .38006 L
.76618 .35976 L
.76632 .38006 L
.76649 .40035 L
.76657 .38006 L
.76681 .40035 L
.76763 .38006 L
.76854 .40035 L
.76857 .42065 L
.76873 .40035 L
.76957 .42065 L
.77004 .44095 L
.77107 .42065 L
.77115 .44095 L
.77115 .46124 L
.77136 .44095 L
.77154 .46124 L
.77167 .44095 L
.77193 .46124 L
.77196 .44095 L
.77205 .42065 L
.77343 .40035 L
.77417 .38006 L
.77432 .40035 L
.77442 .42065 L
.77522 .44095 L
.77534 .42065 L
.77566 .40035 L
.77632 .42065 L
.77648 .44095 L
.77697 .42065 L
.77726 .40035 L
.77735 .42065 L
.77862 .40035 L
.77868 .42065 L
.77886 .40035 L
.77889 .42065 L
.77913 .44095 L
.77924 .46124 L
.7797 .44095 L
.77976 .42065 L
.78026 .40035 L
.78105 .42065 L
Mistroke
.7813 .44095 L
.78146 .42065 L
.78155 .40035 L
.78158 .42065 L
.78223 .44095 L
.78275 .46124 L
.78287 .48154 L
.78333 .46124 L
.78364 .44095 L
.78369 .42065 L
.78406 .44095 L
.78413 .42065 L
.78428 .40035 L
.78435 .42065 L
.7849 .40035 L
.78571 .38006 L
.78588 .40035 L
.78614 .42065 L
.78726 .40035 L
.7873 .42065 L
.78748 .40035 L
.78774 .42065 L
.78788 .44095 L
.78805 .46124 L
.78835 .44095 L
.78917 .42065 L
.78965 .40035 L
.78982 .38006 L
.79022 .35976 L
.79036 .38006 L
.7909 .40035 L
.791 .38006 L
.79116 .40035 L
.79116 .42065 L
.79122 .40035 L
.79124 .38006 L
.79128 .35976 L
.7913 .38006 L
.79135 .40035 L
.79157 .38006 L
.79186 .35976 L
.7921 .38006 L
.79224 .40035 L
.79317 .38006 L
.79336 .35976 L
.79337 .33946 L
.7936 .35976 L
.79371 .38006 L
.7942 .35976 L
.79433 .38006 L
Mistroke
.79482 .35976 L
.79515 .38006 L
.79577 .40035 L
.79662 .38006 L
.79721 .40035 L
.79793 .38006 L
.79796 .35976 L
.7997 .33946 L
.7998 .35976 L
.79987 .33946 L
.80033 .35976 L
.80038 .33946 L
.80061 .31917 L
.80074 .33946 L
.80119 .35976 L
.80152 .33946 L
.80162 .35976 L
.80214 .38006 L
.8024 .35976 L
.80273 .33946 L
.80304 .31917 L
.80369 .33946 L
.80514 .31917 L
.8056 .33946 L
.80604 .35976 L
.80636 .38006 L
.8065 .35976 L
.80735 .33946 L
.80769 .35976 L
.80852 .38006 L
.80859 .40035 L
.80865 .42065 L
.80875 .44095 L
.80912 .44095 L
.80913 .44095 L
.80962 .46124 L
.80982 .44095 L
.80986 .42065 L
.81068 .40035 L
.81109 .42065 L
.81126 .40035 L
.81184 .38006 L
.81186 .35976 L
.81205 .38006 L
.8121 .40035 L
.81226 .42065 L
.81279 .44095 L
.81285 .42065 L
.81286 .40035 L
.81308 .42065 L
Mistroke
.81379 .44095 L
.81396 .46124 L
.81425 .48154 L
.81441 .46124 L
.81456 .44095 L
.81462 .46124 L
.81478 .48154 L
.81585 .46124 L
.81586 .44095 L
.81614 .46124 L
.81659 .44095 L
.8168 .42065 L
.81709 .40035 L
.81762 .42065 L
.81776 .40035 L
.81781 .42065 L
.81785 .40035 L
.81807 .42065 L
.81815 .40035 L
.81858 .38006 L
.81926 .40035 L
.81984 .42065 L
.8199 .44095 L
.82054 .46124 L
.82074 .44095 L
.8208 .42065 L
.82125 .44095 L
.82128 .42065 L
.82134 .44095 L
.82179 .42065 L
.82187 .44095 L
.8223 .46124 L
.82278 .44095 L
.8232 .42065 L
.82326 .44095 L
.82337 .46124 L
.82343 .44095 L
.82374 .46124 L
.82439 .44095 L
.82457 .46124 L
.82459 .44095 L
.82523 .42065 L
.82532 .40035 L
.82566 .40035 L
.82566 .40035 L
.82575 .42065 L
.82582 .44095 L
.82589 .46124 L
.82656 .44095 L
.82657 .42065 L
Mistroke
.82673 .44095 L
.82728 .46124 L
.82745 .44095 L
.8276 .42065 L
.8277 .40035 L
.82776 .38006 L
.82844 .38006 L
.82844 .38006 L
.82858 .40035 L
.8286 .42065 L
.8286 .44095 L
.82867 .46124 L
.82887 .44095 L
.829 .42065 L
.82943 .44095 L
.82981 .42065 L
.83003 .40035 L
.83017 .42065 L
.83027 .44095 L
.83046 .42065 L
.83065 .44095 L
.8315 .42065 L
.83151 .44095 L
.83157 .42065 L
.83237 .40035 L
.83332 .38006 L
.83345 .35976 L
.83366 .33946 L
.83371 .35976 L
.83386 .33946 L
.83483 .31917 L
.83487 .29887 L
.83563 .27857 L
.83574 .29887 L
.83577 .27857 L
.83591 .29887 L
.83614 .31917 L
.83673 .29887 L
.83678 .31917 L
.8372 .33946 L
.83745 .31917 L
.83752 .33946 L
.83868 .31917 L
.83992 .29887 L
.84028 .31917 L
.84101 .29887 L
.84194 .27857 L
.84223 .25828 L
.84245 .27857 L
.84257 .29887 L
Mistroke
.84281 .31917 L
.843 .29887 L
.8433 .31917 L
.84333 .33946 L
.84333 .35976 L
.84361 .33946 L
.84367 .31917 L
.84388 .33946 L
.84424 .35976 L
.84527 .33946 L
.84552 .31917 L
.8456 .29887 L
.84568 .31917 L
.846 .33946 L
.84612 .35976 L
.84637 .38006 L
.84641 .35976 L
.84648 .38006 L
.84656 .40035 L
.84716 .38006 L
.84722 .35976 L
.84744 .33946 L
.84761 .31917 L
.84822 .29887 L
.84843 .27857 L
.84876 .29887 L
.84898 .31917 L
.84899 .33946 L
.84938 .31917 L
.84951 .33946 L
.84953 .35976 L
.84993 .38006 L
.85155 .40035 L
.85169 .42065 L
.85372 .40035 L
.85423 .42065 L
.85452 .40035 L
.8549 .42065 L
.855 .44095 L
.85531 .42065 L
.85557 .40035 L
.856 .42065 L
.85626 .44095 L
.8565 .46124 L
.85651 .44095 L
.85655 .42065 L
.85669 .44095 L
.85707 .42065 L
.85778 .44095 L
.85789 .42065 L
Mistroke
.85795 .40035 L
.85796 .42065 L
.85833 .40035 L
.85853 .42065 L
.85917 .44095 L
.85944 .42065 L
.85994 .40035 L
.86106 .42065 L
.86119 .44095 L
.8613 .42065 L
.86159 .44095 L
.86227 .42065 L
.86235 .44095 L
.86406 .42065 L
.86419 .44095 L
.86448 .42065 L
.86493 .44095 L
.86512 .42065 L
.86617 .44095 L
.86698 .46124 L
.86703 .44095 L
.86712 .42065 L
.86753 .40035 L
.86753 .42065 L
.86759 .44095 L
.86787 .46124 L
.86793 .48154 L
.86808 .50184 L
.86841 .48154 L
.86867 .46124 L
.86871 .44095 L
.86884 .42065 L
.86886 .44095 L
.86932 .42065 L
.86943 .44095 L
.86953 .46124 L
.86985 .44095 L
.86991 .46124 L
.86994 .48154 L
.87013 .50184 L
.87033 .52213 L
.87049 .50184 L
.87053 .52213 L
.87054 .50184 L
.87057 .48154 L
.87082 .50184 L
.87083 .52213 L
.87089 .50184 L
.87093 .48154 L
.87102 .50184 L
Mistroke
.87136 .48154 L
.87139 .46124 L
.87147 .44095 L
.87178 .46124 L
.87179 .44095 L
.8718 .42065 L
.87181 .40035 L
.87223 .42065 L
.87247 .44095 L
.87314 .46124 L
.87314 .44095 L
.87332 .46124 L
.87349 .48154 L
.87389 .50184 L
.87421 .52213 L
.87449 .50184 L
.87457 .48154 L
.87513 .50184 L
.87526 .48154 L
.87542 .50184 L
.87548 .48154 L
.87548 .46124 L
.87554 .48154 L
.87577 .46124 L
.87592 .44095 L
.87639 .42065 L
.87639 .44095 L
.87676 .42065 L
.87707 .40035 L
.87757 .38006 L
.87771 .40035 L
.8781 .38006 L
.87864 .40035 L
.879 .38006 L
.88022 .35976 L
.88049 .33946 L
.88115 .35976 L
.88118 .38006 L
.88145 .35976 L
.8816 .33946 L
.88194 .35976 L
.88221 .33946 L
.88244 .35976 L
.88268 .33946 L
.8833 .35976 L
.88362 .33946 L
.8838 .31917 L
.88407 .29887 L
.88502 .31917 L
.8856 .33946 L
Mistroke
.88587 .31917 L
.88588 .29887 L
.88592 .31917 L
.88657 .33946 L
.88664 .35976 L
.88733 .33946 L
.88779 .35976 L
.88853 .38006 L
.88871 .40035 L
.88901 .38006 L
.88927 .35976 L
.88928 .38006 L
.88966 .35976 L
.8922 .33946 L
.8922 .35976 L
.89237 .33946 L
.89244 .31917 L
.89251 .29887 L
.89273 .27857 L
.89328 .29887 L
.89348 .27857 L
.89425 .29887 L
.89432 .31917 L
.89438 .33946 L
.8948 .35976 L
.89485 .38006 L
.89487 .40035 L
.89508 .38006 L
.89544 .40035 L
.89637 .42065 L
.89639 .44095 L
.89683 .46124 L
.89684 .44095 L
.89743 .42065 L
.89851 .40035 L
.89877 .42065 L
.89895 .40035 L
.90048 .38006 L
.90058 .40035 L
.90126 .42065 L
.90132 .40035 L
.90166 .42065 L
.90198 .44095 L
.90314 .42065 L
.90324 .40035 L
.90374 .38006 L
.9038 .40035 L
.9038 .38006 L
.9039 .35976 L
.90447 .38006 L
Mistroke
.90476 .40035 L
.90492 .42065 L
.90525 .44095 L
.90644 .42065 L
.90644 .40035 L
.90661 .38006 L
.9069 .40035 L
.90715 .38006 L
.90856 .40035 L
.90872 .42065 L
.90873 .40035 L
.90889 .42065 L
.90939 .40035 L
.90961 .38006 L
.90965 .35976 L
.91075 .38006 L
.91126 .40035 L
.91174 .42065 L
.91197 .44095 L
.91199 .46124 L
.91224 .48154 L
.91255 .46124 L
.91299 .44095 L
.91311 .46124 L
.91328 .44095 L
.91398 .42065 L
.91407 .40035 L
.91415 .38006 L
.9144 .40035 L
.91463 .42065 L
.91471 .44095 L
.91482 .46124 L
.91495 .48154 L
.91507 .46124 L
.91517 .44095 L
.91547 .42065 L
.91551 .40035 L
.91559 .38006 L
.91605 .40035 L
.91628 .38006 L
.91647 .35976 L
.91656 .33946 L
.91698 .31917 L
.91701 .29887 L
.91708 .31917 L
.91711 .33946 L
.91714 .35976 L
.91746 .38006 L
.91824 .40035 L
.91859 .38006 L
Mistroke
.91908 .35976 L
.92094 .38006 L
.92103 .40035 L
.92116 .42065 L
.92153 .40035 L
.9221 .38006 L
.92282 .40035 L
.92357 .38006 L
.92366 .35976 L
.9239 .33946 L
.92468 .35976 L
.92483 .38006 L
.92559 .40035 L
.92562 .42065 L
.92595 .44095 L
.92629 .42065 L
.92676 .40035 L
.92678 .42065 L
.92688 .40035 L
.92696 .42065 L
.92707 .40035 L
.9273 .38006 L
.92748 .40035 L
.92794 .38006 L
.9284 .40035 L
.92879 .42065 L
.92934 .40035 L
.93028 .38006 L
.93043 .40035 L
.93097 .38006 L
.9311 .35976 L
.93138 .38006 L
.93177 .35976 L
.93262 .38006 L
.93325 .40035 L
.93341 .38006 L
.93383 .40035 L
.93393 .38006 L
.93393 .40035 L
.93432 .42065 L
.93452 .44095 L
.93587 .42065 L
.93699 .44095 L
.93817 .42065 L
.93825 .44095 L
.93873 .42065 L
.93887 .40035 L
.9389 .38006 L
.93895 .35976 L
.9392 .33946 L
Mistroke
.93937 .35976 L
.93984 .38006 L
.93998 .40035 L
.9403 .42065 L
.94041 .40035 L
.94042 .42065 L
.94045 .44095 L
.94127 .46124 L
.94136 .44095 L
.94148 .42065 L
.94202 .40035 L
.94212 .38006 L
.94284 .35976 L
.94301 .33946 L
.94336 .31917 L
.94368 .29887 L
.94373 .31917 L
.94378 .29887 L
.94384 .31917 L
.94452 .33946 L
.9452 .35976 L
.94528 .38006 L
.94533 .40035 L
.94541 .38006 L
.94579 .40035 L
.94587 .38006 L
.9461 .35976 L
.94649 .33946 L
.94665 .31917 L
.94674 .29887 L
.94691 .31917 L
.94712 .33946 L
.94718 .35976 L
.94746 .38006 L
.94748 .35976 L
.94751 .33946 L
.94763 .35976 L
.9478 .38006 L
.94793 .35976 L
.94817 .38006 L
.94881 .35976 L
.94908 .38006 L
.9491 .35976 L
.94916 .38006 L
.94932 .40035 L
.94949 .42065 L
.94978 .44095 L
.95019 .42065 L
.95025 .40035 L
.95078 .42065 L
Mistroke
.95103 .44095 L
.95126 .42065 L
.9523 .44095 L
.95245 .42065 L
.95266 .40035 L
.95291 .38006 L
.95349 .40035 L
.9535 .42065 L
.95374 .44095 L
.95381 .46124 L
.95385 .44095 L
.95423 .42065 L
.95457 .44095 L
.95458 .42065 L
.95512 .40035 L
.95541 .42065 L
.95653 .44095 L
.95731 .42065 L
.958 .40035 L
.95801 .42065 L
.95837 .40035 L
.95844 .42065 L
.95884 .44095 L
.95895 .46124 L
.95918 .48154 L
.95955 .50184 L
.95962 .48154 L
.95972 .46124 L
.95977 .48154 L
.96013 .50184 L
.96032 .52213 L
.96034 .54243 L
.96055 .52213 L
.96092 .50184 L
.96107 .48154 L
.96109 .46124 L
.9612 .48154 L
.96129 .50184 L
.96187 .48154 L
.96232 .50184 L
.96243 .52213 L
.96253 .54243 L
.96279 .56273 L
.96291 .54243 L
.96293 .52213 L
.96297 .54243 L
.9631 .52213 L
.96317 .50184 L
.9635 .52213 L
.96354 .54243 L
Mistroke
.96359 .52213 L
.96371 .54243 L
.9638 .52213 L
.96389 .54243 L
.96421 .56273 L
.96421 .54243 L
.96442 .52213 L
.9647 .50184 L
.96511 .52213 L
.96619 .50184 L
.96646 .52213 L
.96676 .54243 L
.9669 .56273 L
.96701 .54243 L
.9673 .52213 L
.96763 .50184 L
.96783 .48154 L
.96807 .46124 L
.96814 .44095 L
.96823 .46124 L
.9685 .44095 L
.96869 .42065 L
.96999 .40035 L
.96999 .42065 L
.9701 .44095 L
.97041 .42065 L
.97074 .40035 L
.9708 .42065 L
.97089 .44095 L
.97215 .42065 L
.97232 .40035 L
.9725 .42065 L
.97276 .40035 L
.97302 .42065 L
.9731 .44095 L
.97313 .42065 L
.97316 .44095 L
.97382 .42065 L
.97399 .40035 L
.97511 .38006 L
.9752 .35976 L
.97619 .38006 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[198]:=",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/B000`400?l00000o`00003oo`3ooolQ
0?ooo`00A@3oool5000003@0oooo0`00000c0?ooo`<00000<`3oool3000003<0oooo00160?ooo`04
0000003oool0oooo000003D0oooo00<000000?ooo`3oool0<@3oool01@000000oooo0?ooo`3oool0
00000340oooo00D000000?ooo`3oool0oooo0000000b0?ooo`00A`3oool00`000000oooo0?ooo`0b
0?ooo`D00000<P3oool01@000000oooo0?ooo`3oool000000340oooo00D000000?ooo`3oool0oooo
0000000b0?ooo`00B03oool00`000000oooo0?ooo`0a0?ooo`040000003oool0oooo000003<0oooo
1000000c0?ooo`<00000<`3oool004D0oooo00D000000?ooo`3oool0oooo0000000c0?ooo`030000
003oool0000003<0oooo00<000000?ooo`3oool0<`3oool01@000000oooo0?ooo`3oool000000380
oooo00150?ooo`050000003oool0oooo0?ooo`000000=03oool2000003@0oooo00<000000?ooo`3o
ool0<P3oool01@000000oooo0?ooo`3oool000000380oooo00160?ooo`<00000=P3oool00`000000
oooo0?ooo`0c0?ooo`800000<`3oool3000003<0oooo000B0?ooo`030000003oool0oooo0?l0oooo
303oool00180oooo00<000000?ooo`3oool0o`3oool<0?ooo`004P3oool00`000000oooo0?ooo`3o
0?ooo``0oooo000B0?ooo`030000003oool0oooo0?l0oooo303oool000/0ooooo`00000C000000<0
oooo000B0?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool02`3oool00`000000oooo
0?ooo`0;0?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool02`3oool00`000000oooo
0?ooo`0;0?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool02`3oool00`000000oooo
0?ooo`0;0?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool02`3oool00`000000oooo
0?ooo`0;0?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool02`3oool00`000000oooo
0?ooo`0;0?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool02`3oool00`000000oooo
0?ooo`0;0?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool0203oool00180oooo00<0
00000?ooo`3oool0<`3oool00`000000oooo0?ooo`0d0?ooo`030000003oool0oooo03@0oooo00<0
00000?ooo`3oool0<`3oool00`000000oooo0?ooo`0a0?ooo`004P3oool00`000000oooo0?ooo`3o
0?ooo``0oooo000B0?ooo`030000003oool0oooo0?l0oooo303oool00180oooo00<000000?ooo`3o
ool0o`3oool<0?ooo`004P3oool200000?l0oooo3@3oool00180oooo00<000000?ooo`3oool0o`3o
ool<0?ooo`004P3oool00`000000oooo0?ooo`3o0?ooo``0oooo000B0?ooo`800000o`3oool=0?oo
o`004P3oool200000?l0oooo3@3oool00180oooo0P00003o0?ooo`d0oooo000B0?ooo`800000o`3o
ool=0?ooo`004P3oool200000?l0oooo3@3oool00180oooo0P00003o0?ooo`d0oooo000B0?ooo`03
0000003oool000000?l0oooo303oool00180oooo00<000000?ooo`000000o`3oool<0?ooo`004P3o
ool300000?l0oooo303oool00180oooo00<000000?ooo`000000o`3oool<0?ooo`004P3oool00`00
0000oooo0000003o0?ooo``0oooo000B0?ooo`030000003oool000000?l0oooo303oool00180oooo
00<000000?ooo`000000o`3oool<0?ooo`004P3oool3000000030?ooo`000000oooo0?l0oooo2@3o
ool00180oooo00D000000?ooo`000000oooo0000003o0?ooo`X0oooo000B0?ooo`050000003oool0
00000?ooo`000000o`3oool:0?ooo`002@3oool3000000H0oooo00D000000?ooo`000000oooo0000
003o0?ooo`X0oooo00080?ooo`050000003oool0oooo0?ooo`0000001@3oool01@000000oooo0000
003oool000000?l0oooo2P3oool000`0oooo00<000000?ooo`3oool00`3oool01@000000oooo0000
003oool000000?l0oooo2P3oool000`0oooo00<000000?ooo`3oool00`3oool500000?l0oooo2P3o
ool000P0oooo100000060?ooo`030000003oool0000000800000o`3oool:0?ooo`00203oool00`00
0000oooo0?ooo`070?ooo`030000003oool0000000800000o`3oool:0?ooo`00203oool5000000D0
oooo00D000000?ooo`000000oooo0000003o0?ooo`X0oooo000B0?ooo`050000003oool000000?oo
o`000000o`3oool:0?ooo`004P3oool3000000030?ooo`000000oooo0?l0oooo2@3oool00180oooo
00D000000?ooo`3oool0oooo0000003o0?ooo`X0oooo000B0?ooo`050000003oool0oooo0?ooo`00
0000o`3oool:0?ooo`004P3oool01@000000oooo0?ooo`3oool000000?l0oooo2P3oool00180oooo
00D000000?ooo`3oool0oooo0000003o0?ooo`X0oooo000B0?ooo`050000003oool0oooo0?ooo`00
0000o`3oool:0?ooo`004P3oool200000080oooo00<000000?ooo`3oool0o`3oool80?ooo`004P3o
ool01@000000oooo0?ooo`3oool000000?l0oooo2P3oool00180oooo00D000000?ooo`3oool0oooo
0000003o0?ooo`X0oooo000B0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0o`3o
ool70?ooo`004P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0?l0oooo1`3oool0
0180oooo0P0000030?ooo`8000004`3oool200000?80oooo000B0?ooo`030000003oool0oooo0080
oooo0P00000C0?ooo`800000lP3oool00180oooo00<000000?ooo`3oool00P3oool2000001<0oooo
0P00003b0?ooo`004P3oool00`000000oooo0?ooo`020?ooo`8000004`3oool200000?80oooo000B
0?ooo`030000003oool0oooo0080oooo0P00000B0?ooo`<00000lP3oool00180oooo00<000000?oo
o`3oool00P3oool200000180oooo0`00003b0?ooo`004P3oool2000000<0oooo0P00000B0?ooo`<0
0000lP3oool00180oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`0@0?ooo`<00000
lP3oool00180oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`0@0?ooo`<00000lP3o
ool000<0oooo0`0000040?ooo`8000001P3oool00`000000oooo0?ooo`030?ooo`030000003oool0
oooo0100oooo0`00003b0?ooo`00103oool00`000000oooo0?ooo`020?ooo`040000003oool0oooo
000000D0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`0@0?ooo`<00000lP3oool0
00@0oooo00<000000?ooo`3oool00P3oool010000000oooo0?ooo`0000050?ooo`800000103oool2
000000d0oooo00@000000?ooo`3oool0oooo0`00003b0?ooo`00103oool00`000000oooo0?ooo`02
0?ooo`040000003oool0oooo000000D0oooo00<000000?ooo`3oool00`3oool2000000d0oooo00@0
00000?ooo`3oool0oooo0`00003b0?ooo`00103oool00`000000oooo0?ooo`020?ooo`040000003o
ool0oooo000000D0oooo00<000000?ooo`3oool00`3oool2000000d0oooo00@000000?ooo`3oool0
oooo0`00003b0?ooo`000`3oool2000000@0oooo00@000000?ooo`3oool000001@3oool00`000000
oooo0?ooo`030?ooo`8000003@3oool010000000oooo0?ooo`3oool300000?80oooo00040?ooo`03
0000003oool0oooo00<0oooo0P0000060?ooo`030000003oool0oooo00<0oooo0P00000=0?ooo`04
0000003oool0oooo0?ooo`<00000lP3oool00180oooo00<000000?ooo`3oool00`3oool2000000d0
oooo00@000000?ooo`3oool0oooo0`00003b0?ooo`004P3oool2000000@0oooo0`00000;0?ooo`80
000000<0oooo0000003oool00`0000020?ooo`030000003oool0000000<000000`3oool200000004
0?ooo`0000000000000003L0oooo00<000000?ooo`3oool0Y`3oool00180oooo00<000000?ooo`3o
ool0103oool2000000/0oooo0P0000000`3oool000000?ooo`0300000080oooo00<000000?ooo`00
00000`0000030?ooo`80000000@0oooo0000000000000000=`3oool00`000000oooo0?ooo`2W0?oo
o`004P3oool00`000000oooo0?ooo`040?ooo`8000002`3oool2000000030?ooo`000000oooo00<0
00000P3oool00`000000oooo00000003000000<0oooo0P000000103oool0000000000000000g0?oo
o`030000003oool0oooo0:L0oooo000B0?ooo`030000003oool0oooo00@0oooo0P00000;0?ooo`80
000000<0oooo0000000000000P0000000`3oool000000?ooo`0700000080oooo1P00000g0?ooo`03
0000003oool0oooo0:L0oooo000B0?ooo`030000003oool0oooo00@0oooo0P00000;0?ooo`800000
00<0oooo0000000000000P0000000`3oool000000?ooo`0700000080oooo1P00000g0?ooo`030000
003oool0oooo0:L0oooo000B0?ooo`8000001@3oool2000000D0oooo00<000000?ooo`3oool00P3o
ool3000000030?ooo`00000000000080000000<0oooo0000003oool01`0000020?ooo`H00000=@3o
ool00`000000oooo0000000=0?ooo`030000003oool0oooo02@0oooo00<000000?ooo`3oool0@`3o
ool00`000000oooo0?ooo`0/0?ooo`004P3oool00`000000oooo0?ooo`040?ooo`8000001@3oool0
0`000000oooo0?ooo`020?ooo`<0000000@0oooo00000000000000000P3oool00`000000oooo0000
000600000080oooo1P00000e0?ooo`030000003oool0000000d0oooo00<000000?ooo`3oool0903o
ool00`000000oooo0?ooo`130?ooo`030000003oool0oooo02`0oooo000B0?ooo`030000003oool0
oooo00@0oooo0P0000050?ooo`030000003oool0oooo0080oooo0`000000103oool0000000000000
00020?ooo`T000000P3oool6000003D0oooo00<000000?ooo`0000003@3oool00`000000oooo0?oo
o`0T0?ooo`030000003oool0oooo04<0oooo00<000000?ooo`3oool0;03oool00180oooo00<00000
0?ooo`3oool0103oool2000000D0oooo00<000000?ooo`3oool00P3oool3000000040?ooo`000000
000000000080oooo2@0000020?ooo`H00000=@3oool00`000000oooo0000000=0?ooo`030000003o
ool0oooo02@0oooo00<000000?ooo`3oool0@`3oool00`000000oooo0?ooo`0/0?ooo`004P3oool0
0`000000oooo0?ooo`040?ooo`8000001@3oool00`000000oooo0?ooo`020?ooo`<0000000<0oooo
0000000000000`3oool900000080oooo1P00000e0?ooo`040000003oool00000000000`0oooo00<0
00000?ooo`3oool0903oool00`000000oooo0?ooo`130?ooo`030000003oool0oooo02`0oooo000B
0?ooo`030000003oool0oooo00@0oooo0P0000050?ooo`030000003oool0oooo0080oooo0`000000
0`3oool00000000000030?ooo`030000003oool0000000H000000P3oool6000003D0oooo00@00000
0?ooo`0000000000303oool00`000000oooo0?ooo`0T0?ooo`030000003oool0oooo04<0oooo00<0
00000?ooo`3oool0;03oool00180oooo0P0000050?ooo`@000000`3oool00`000000oooo00000002
0?ooo`<0000000<0oooo0000000000000`3oool00`000000oooo0000000600000080oooo1`00000@
0?ooo`030000003oool0oooo00`0oooo0P00000<0?ooo`030000003oool0oooo00@0oooo1@00000;
0?ooo`040000003oool0oooo000002<0oooo00<000000?ooo`3oool0;@3oool00`000000oooo0?oo
o`0A0?ooo`040000003oool00000000000`0oooo00<000000?ooo`3oool07P3oool00180oooo00<0
00000?ooo`3oool01@3oool3000000<0oooo00<000000?ooo`0000000P3oool010000000oooo0000
003oool2000000<0oooo00<000000?ooo`0000000P000000103oool000000000000000020?ooo`<0
00000P3oool200000100oooo00<000000?ooo`3oool0303oool2000000`0oooo00<000000?ooo`3o
ool0103oool5000000/0oooo00@000000?ooo`3oool000008`3oool00`000000oooo0?ooo`0]0?oo
o`030000003oool0oooo0140oooo00@000000?ooo`0000000000303oool00`000000oooo0?ooo`0N
0?ooo`004P3oool00`000000oooo0?ooo`050?ooo`<000000`3oool00`000000oooo000000020?oo
o`040000003oool000000?ooo`8000000`3oool00`000000oooo00000002000000040?ooo`000000
000000000080oooo0`0000020?ooo`800000403oool00`000000oooo0?ooo`0<0?ooo`800000303o
ool00`000000oooo0?ooo`040?ooo`D000002`3oool010000000oooo0?ooo`00000S0?ooo`030000
003oool0oooo02d0oooo00<000000?ooo`3oool04@3oool010000000oooo00000000000<0?ooo`03
0000003oool0oooo01h0oooo000B0?ooo`030000003oool0oooo00D0oooo0`0000030?ooo`030000
003oool000000080oooo00<000000?ooo`0000000`0000030?ooo`040000003oool0000000000080
oooo0`0000000`3oool000000000000200000080oooo0P00000?0?ooo`8000003P3oool2000000`0
oooo00<000000?ooo`3oool0103oool5000000/0oooo0P0000000`3oool000000?ooo`0R0?ooo`80
0000;P3oool200000180oooo1@00000;0?ooo`030000003oool0oooo01h0oooo000B0?ooo`030000
003oool0oooo00D0oooo0`0000030?ooo`030000003oool000000080oooo00<000000?ooo`000000
0`0000030?ooo`040000003oool0000000000080oooo0`0000000`3oool000000000000200000080
oooo0P00000?0?ooo`8000003P3oool2000000`0oooo00<000000?ooo`3oool0103oool5000000/0
oooo0P0000000`3oool000000?ooo`0R0?ooo`800000;P3oool200000180oooo1@00000;0?ooo`03
0000003oool0oooo01h0oooo000B0?ooo`8000001P3oool3000000050?ooo`00000000000000003o
ool00P0000000`3oool000000?ooo`04000000<0oooo00@000000?ooo`00000000000P3oool80000
0080oooo0P00000?0?ooo`8000001P3oool00`000000oooo0?ooo`040?ooo`<00000303oool00`00
0000oooo000000040?ooo`D000002`3oool4000000030?ooo`000000oooo00L0oooo00<000000?oo
o`3oool05P3oool2000002h0oooo0P00000B0?ooo`D00000203oool2000000030?ooo`000000oooo
00@0oooo00<000000?ooo`3oool0103oool200000180oooo000B0?ooo`030000003oool0oooo00H0
oooo0P0000001@3oool00000000000000000oooo0080000000@0oooo0000003oool0oooo0P000007
0?ooo`030000003oool0oooo00P000000`3oool00`000000oooo0?ooo`0=0?ooo`8000001P3oool0
0`000000oooo0?ooo`040?ooo`<00000303oool00`000000oooo000000040?ooo`8000000P3oool0
0`000000oooo0?ooo`090?ooo`@0000000<0oooo0000003oool01`3oool00`000000oooo0?ooo`0F
0?ooo`800000;P3oool200000180oooo1@0000080?ooo`80000000<0oooo0000003oool0103oool0
0`000000oooo0?ooo`040?ooo`8000004P3oool00180oooo00<000000?ooo`3oool01P3oool20000
00050?ooo`00000000000000003oool00P000000103oool000000?ooo`3oool2000000L0oooo00<0
00000?ooo`3oool0200000030?ooo`030000003oool0oooo00d0oooo0P0000060?ooo`030000003o
ool0oooo00@0oooo0`00000<0?ooo`030000003oool0000000@0oooo0P0000020?ooo`030000003o
ool0oooo00T0oooo100000000`3oool000000?ooo`070?ooo`030000003oool0oooo01H0oooo0P00
000^0?ooo`8000004P3oool5000000P0oooo0P0000000`3oool000000?ooo`040?ooo`030000003o
ool0oooo00@0oooo0P00000B0?ooo`000`3oool3000000<0oooo0`0000060?ooo`030000003oool0
oooo00H0oooo0P0000001@3oool00000000000000000oooo0080000000@0oooo0000003oool0oooo
0P0000070?ooo`030000003oool0oooo00P000000`3oool00`000000oooo0?ooo`0=0?ooo`800000
1P3oool00`000000oooo0?ooo`040?ooo`<00000303oool00`000000oooo000000040?ooo`800000
0P3oool00`000000oooo0?ooo`090?ooo`@0000000<0oooo0000003oool01`3oool00`000000oooo
0?ooo`0F0?ooo`800000;P3oool200000180oooo1@0000080?ooo`80000000<0oooo0000003oool0
103oool00`000000oooo0?ooo`040?ooo`8000004P3oool000@0oooo00D000000?ooo`3oool0oooo
000000030?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool01`3oool5000000050?oo
o`00000000000?ooo`0000000P3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo0080
000000H0oooo00000000000000000?ooo`0000030?ooo`030000003oool0oooo00d0oooo0P000006
0?ooo`030000003oool0oooo00@0oooo0`00000<0?ooo`030000003oool0000000@0oooo0P000002
0?ooo`030000003oool0oooo00P0oooo00<000000?ooo`000000100000080?ooo`030000003oool0
oooo01H0oooo0P00000^0?ooo`8000004P3oool5000000P0oooo100000050?ooo`030000003oool0
oooo00@0oooo0P00000B0?ooo`00103oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo
00<0oooo00<000000?ooo`3oool01`3oool5000000050?ooo`00000000000?ooo`0000000P3oool0
0`000000oooo0?ooo`060?ooo`030000003oool0oooo0080000000H0oooo00000000000000000?oo
o`0000030?ooo`030000003oool0oooo00d0oooo0P0000060?ooo`030000003oool0oooo00@0oooo
0`00000<0?ooo`030000003oool0000000@0oooo0P0000020?ooo`030000003oool0oooo00P0oooo
00<000000?ooo`000000100000080?ooo`030000003oool0oooo01H0oooo0P00000^0?ooo`800000
4P3oool5000000P0oooo100000050?ooo`030000003oool0oooo00@0oooo0P00000B0?ooo`00103o
ool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00<0oooo0P0000080?ooo`D0000000<0
oooo0000000000000P0000020?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool00P00
00001P3oool00000000000000000oooo000000<0oooo0P0000060?ooo`8000001@3oool4000000@0
oooo0`0000000`3oool000000?ooo`020?ooo`@000002`3oool01@000000oooo000000000000oooo
00@000000P3oool010000000oooo0?ooo`0000070?ooo`030000003oool0000000@000001@3oool0
10000000oooo0?ooo`00000E0?ooo`030000003oool0oooo00800000;P3oool2000000P0oooo0`00
00070?ooo`D00000203oool4000000D0oooo00<000000?ooo`3oool0103oool200000180oooo0004
0?ooo`040000003oool0oooo0?ooo`@000001P3oool00`000000oooo0?ooo`080?ooo`@0000000<0
oooo0000000000000P0000020?ooo`030000003oool0oooo00T0oooo0P0000000`3oool000000?oo
o`060?ooo`8000001P3oool2000000D0oooo100000040?ooo`<0000000<0oooo0000003oool00P3o
ool4000000/0oooo00D000000?ooo`00000000000?ooo`0400000080oooo00@000000?ooo`3oool0
00001`3oool00`000000oooo00000004000000D0oooo00@000000?ooo`3oool000005@3oool00`00
0000oooo0?ooo`02000002h0oooo0P0000080?ooo`<000001`3oool5000000P0oooo100000050?oo
o`030000003oool0oooo00@0oooo0P00000B0?ooo`000`3oool2000000<0oooo00<000000?ooo`3o
ool01`3oool00`000000oooo0?ooo`080?ooo`@0000000<0oooo0000000000000P0000020?ooo`03
0000003oool0oooo00T0oooo0P0000000`3oool000000?ooo`060?ooo`8000001P3oool2000000D0
oooo100000040?ooo`<0000000<0oooo0000003oool00P3oool4000000/0oooo00D000000?ooo`00
000000000?ooo`0400000080oooo00@000000?ooo`3oool000001`3oool00`000000oooo00000004
000000D0oooo00@000000?ooo`3oool000005@3oool00`000000oooo0?ooo`02000002h0oooo0P00
00080?ooo`<000001`3oool5000000P0oooo100000050?ooo`030000003oool0oooo00@0oooo0P00
000B0?ooo`00103oool010000000oooo0?ooo`3oool5000000D0oooo00<000000?ooo`3oool0203o
ool4000000030?ooo`0000000000008000000P3oool00`000000oooo0?ooo`090?ooo`80000000<0
oooo0000003oool01P3oool2000000H0oooo0P0000050?ooo`@00000103oool3000000030?ooo`00
0000oooo0080oooo1000000;0?ooo`050000003oool000000000003oool0100000020?ooo`040000
003oool0oooo000000L0oooo00<000000?ooo`000000100000050?ooo`040000003oool0oooo0000
01D0oooo00<000000?ooo`3oool00P00000^0?ooo`800000203oool3000000L0oooo1@0000080?oo
o`@000001@3oool00`000000oooo0?ooo`040?ooo`8000004P3oool00180oooo00<000000?ooo`3o
ool0203oool3000000030?ooo`000000oooo00<000000P3oool00`000000oooo0?ooo`0:0?ooo`03
0000003oool0000000P0oooo00<000000?ooo`3oool0103oool2000000D0oooo100000040?ooo`<0
000000<0oooo0000003oool00P3oool00`000000oooo00000002000000X0oooo00D000000?ooo`00
000000000?ooo`0400000080oooo00@000000?ooo`3oool000001`3oool00`000000oooo00000004
000000D0oooo00@000000?ooo`3oool000005@3oool00`000000oooo0?ooo`02000002h0oooo0P00
00080?ooo`<000001`3oool5000000P0oooo100000050?ooo`030000003oool0oooo00@0oooo0P00
000B0?ooo`004P3oool00`000000oooo0?ooo`080?ooo`<0000000<0oooo0000003oool00`000002
0?ooo`030000003oool0oooo00X0oooo00<000000?ooo`000000203oool00`000000oooo0?ooo`04
0?ooo`8000001@3oool4000000@0oooo0`0000000`3oool000000?ooo`020?ooo`030000003oool0
0000008000002P3oool01@000000oooo000000000000oooo00@000000P3oool010000000oooo0?oo
o`0000070?ooo`030000003oool0000000@000001@3oool010000000oooo0?ooo`00000E0?ooo`03
0000003oool0oooo00800000;P3oool2000000P0oooo0`0000070?ooo`D00000203oool4000000D0
oooo00<000000?ooo`3oool0103oool200000180oooo000B0?ooo`8000002@3oool3000000030?oo
o`000000oooo00<000000P3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0000000P0oooo
00D000000?ooo`3oool0oooo000000020?ooo`<00000103oool4000000@0oooo1`0000000`3oool0
00000?ooo`03000000T0oooo1@0000000`3oool000000000000200000080oooo0P0000000`3oool0
0000000000020?ooo`060000003oool0oooo0?ooo`000000oooo1@0000040?ooo`80000000<0oooo
0000000000000P0000000`3oool000000?ooo`020?ooo`030000003oool000000080oooo0P000007
0?ooo`H000001@3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00/0oooo00<00000
0?ooo`3oool0303oool00`000000oooo0?ooo`020?ooo`8000001P3oool00`000000oooo00000002
000000H0oooo1P0000070?ooo`D000001@3oool00`000000oooo000000030?ooo`<000004P3oool0
0180oooo00<000000?ooo`3oool0203oool200000080oooo00@000000?ooo`00000000000`3oool0
0`000000oooo0?ooo`0E0?ooo`050000003oool0oooo0?ooo`0000000P3oool3000000@0oooo0P00
00000`3oool000000?ooo`030?ooo`L0000000<0oooo0000003oool00`0000090?ooo`D0000000@0
oooo00000000000000000`3oool2000000030?ooo`00000000000080oooo00D000000?ooo`3oool0
oooo000000030?ooo`<00000103oool2000000030?ooo`00000000000080000000<0oooo0000003o
ool00P3oool00`000000oooo000000020?ooo`8000001`3oool6000000D0oooo00<000000?ooo`3o
ool00`3oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3o
ool00P3oool2000000H0oooo00<000000?ooo`0000000P0000060?ooo`80000000@0oooo00000000
000000001`3oool5000000D0oooo00<000000?ooo`0000000`3oool300000180oooo000B0?ooo`03
0000003oool0oooo00P0oooo0P0000020?ooo`040000003oool00000000000<0oooo00<000000?oo
o`3oool05@3oool01@000000oooo0?ooo`3oool000000080oooo0`0000040?ooo`80000000<0oooo
0000003oool00`3oool7000000030?ooo`000000oooo00<000002@3oool5000000040?ooo`000000
0000000000<0oooo0P0000000`3oool00000000000020?ooo`050000003oool0oooo0?ooo`000000
0`3oool3000000@0oooo0P0000000`3oool0000000000002000000030?ooo`000000oooo0080oooo
00<000000?ooo`0000000P3oool2000000L0oooo1P0000050?ooo`030000003oool0oooo00<0oooo
00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo0080oooo
0P0000060?ooo`030000003oool00000008000001P3oool2000000040?ooo`0000000000000000L0
oooo1@0000050?ooo`030000003oool0000000<0oooo0`00000B0?ooo`004P3oool00`000000oooo
0?ooo`080?ooo`8000000P3oool010000000oooo0000000000030?ooo`030000003oool0oooo01D0
oooo00D000000?ooo`3oool0oooo000000020?ooo`<00000103oool2000000030?ooo`000000oooo
00<0oooo1`0000000`3oool000000?ooo`03000000T0oooo200000040?ooo`80000000<0oooo0000
000000000P3oool01@000000oooo0?ooo`3oool0000000<0oooo0`0000040?ooo`80000000<0oooo
0000000000000P0000000`3oool000000?ooo`020?ooo`030000003oool000000080oooo0P000007
0?ooo`H000001@3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00X0oooo0P00000>
0?ooo`030000003oool0oooo0080oooo0P0000060?ooo`D000001P3oool00`000000oooo0?ooo`03
000000L0oooo1@0000050?ooo`030000003oool0000000<0oooo1000000A0?ooo`004P3oool00`00
0000oooo0?ooo`080?ooo`8000000P3oool010000000oooo0000000000030?ooo`030000003oool0
oooo01D0oooo00D000000?ooo`3oool0oooo000000020?ooo`<00000103oool2000000030?ooo`00
0000oooo00<0oooo1`0000000`3oool000000?ooo`03000000T0oooo200000040?ooo`80000000<0
oooo0000000000000P3oool01@000000oooo0?ooo`3oool0000000<0oooo0`0000040?ooo`800000
00<0oooo0000000000000P0000000`3oool000000?ooo`020?ooo`030000003oool000000080oooo
0P0000070?ooo`H000001@3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00X0oooo
0P00000>0?ooo`030000003oool0oooo0080oooo0P0000060?ooo`D000001P3oool00`000000oooo
0?ooo`03000000L0oooo1@0000050?ooo`030000003oool0000000<0oooo1000000A0?ooo`004P3o
ool2000000T0oooo0P0000020?ooo`040000003oool00000000000<0oooo00<000000?ooo`3oool0
5@3oool010000000oooo0000003oool2000000050?ooo`00000000000000003oool00P0000001@3o
ool000000000003oool000000080oooo00<000000?ooo`00000020000000103oool0000000000000
00090?ooo`P00000103oool2000000030?ooo`00000000000080oooo00D000000?ooo`3oool0oooo
000000030?ooo`@000000`3oool2000000030?ooo`000000000000@000000P3oool2000000040?oo
o`00000000000?ooo`8000001`3oool6000000D0oooo00<000000?ooo`0000000`3oool01@000000
oooo0?ooo`000000oooo0080000000<0oooo0000003oool00`3oool2000000<0oooo00<000000?oo
o`3oool0203oool010000000oooo0?ooo`3oool3000000H0oooo1@0000000`3oool000000?ooo`03
0?ooo`030000003oool0oooo00<000001`3oool500000080oooo0P0000001`3oool0000000000000
0000oooo0000003oool0100000060?ooo`030000003oool0oooo00P0oooo000B0?ooo`030000003o
ool0oooo00P0oooo0P0000050?ooo`030000003oool0oooo01T0oooo00@000000?ooo`000000oooo
0P0000001@3oool000000?ooo`000000oooo0080000000D0oooo000000000000oooo000000020?oo
o`040000003oool000000?ooo`L0000000@0oooo00000000000000002@3oool7000000H0oooo00@0
00000?ooo`00000000000P3oool01@000000oooo0?ooo`3oool0000000<0oooo100000030?ooo`80
000000<0oooo0000003oool0100000020?ooo`80000000@0oooo000000000000oooo0P0000070?oo
o`H000001@3oool00`000000oooo000000030?ooo`050000003oool0oooo0000003oool00P000000
0`3oool000000?ooo`030?ooo`8000000`3oool00`000000oooo0?ooo`080?ooo`040000003oool0
oooo0?ooo`<000001P3oool5000000030?ooo`000000oooo00<0oooo00@000000?ooo`3oool0oooo
0P0000070?ooo`030000003oool00000008000000P3oool2000000070?ooo`00000000000000003o
ool000000?ooo`04000000H0oooo00<000000?ooo`3oool0203oool00180oooo00<000000?ooo`3o
ool0203oool2000000D0oooo00<000000?ooo`3oool06@3oool010000000oooo0000003oool20000
00050?ooo`000000oooo0000003oool00P0000001@3oool000000000003oool000000080oooo00@0
00000?ooo`000000oooo1`000000103oool000000000000000090?ooo`L000001P3oool010000000
oooo0000000000020?ooo`050000003oool0oooo0?ooo`0000000`3oool4000000<0oooo0P000000
0`3oool000000?ooo`0400000080oooo0P000000103oool000000000003oool2000000L0oooo1P00
00050?ooo`030000003oool0000000<0oooo00D000000?ooo`3oool000000?ooo`02000000030?oo
o`000000oooo00<0oooo0P0000030?ooo`030000003oool0oooo00P0oooo00@000000?ooo`3oool0
oooo0`0000060?ooo`D0000000<0oooo0000003oool00`3oool010000000oooo0?ooo`3oool20000
00L0oooo00<000000?ooo`0000000P0000020?ooo`80000000L0oooo00000000000000000?ooo`00
0000oooo00@000001P3oool00`000000oooo0?ooo`080?ooo`004P3oool00`000000oooo0?ooo`08
0?ooo`8000001@3oool00`000000oooo0?ooo`0I0?ooo`040000003oool000000?ooo`80000000D0
oooo0000003oool000000?ooo`02000000050?ooo`00000000000?ooo`0000000P3oool010000000
oooo0000003oool7000000040?ooo`0000000000000000T0oooo1`0000060?ooo`040000003oool0
000000000080oooo00D000000?ooo`3oool0oooo000000030?ooo`@000000`3oool2000000030?oo
o`000000oooo00@000000P3oool2000000040?ooo`00000000000?ooo`8000001`3oool6000000D0
oooo00<000000?ooo`0000000`3oool01@000000oooo0?ooo`000000oooo0080000000<0oooo0000
003oool00`3oool2000000<0oooo00<000000?ooo`3oool0203oool010000000oooo0?ooo`3oool3
000000H0oooo1@0000000`3oool000000?ooo`030?ooo`040000003oool0oooo0?ooo`8000001`3o
ool00`000000oooo0000000200000080oooo0P0000001`3oool00000000000000000oooo0000003o
ool0100000060?ooo`030000003oool0oooo00P0oooo000B0?ooo`030000003oool0oooo00P0oooo
00<000000?ooo`3oool0103oool00`000000oooo0?ooo`0I0?ooo`040000003oool000000?ooo`@0
000000<0oooo0000003oool00P0000001@3oool000000000003oool000000080oooo00@000000?oo
o`000000oooo1`0000020?ooo`8000002@3oool3000000040?ooo`0000000000000000L0oooo0`00
00000`3oool00000000000030?ooo`040000003oool0oooo0?ooo`80000000<0oooo0000003oool0
0P3oool2000000030?ooo`000000oooo00@000000P3oool2000000040?ooo`00000000000?ooo`80
00001`3oool6000000D0oooo00<000000?ooo`0000000`3oool01@000000oooo0?ooo`000000oooo
00@00000103oool2000000<0oooo00<000000?ooo`3oool0203oool010000000oooo0?ooo`3oool3
000000D0oooo200000040?ooo`040000003oool0oooo0?ooo`8000001`3oool00`000000oooo0000
000200000080oooo0P0000001`3oool00000000000000000oooo0000003oool0100000060?ooo`03
0000003oool0oooo00P0oooo000B0?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool0
103oool00`000000oooo0?ooo`0I0?ooo`040000003oool000000?ooo`@0000000<0oooo0000003o
ool00P0000001@3oool000000000003oool000000080oooo00@000000?ooo`000000oooo1`000002
0?ooo`8000002@3oool3000000040?ooo`0000000000000000L0oooo0`0000000`3oool000000000
00030?ooo`040000003oool0oooo0?ooo`80000000<0oooo0000003oool00P3oool2000000030?oo
o`000000oooo00@000000P3oool2000000040?ooo`00000000000?ooo`8000001`3oool6000000D0
oooo00<000000?ooo`0000000`3oool01@000000oooo0?ooo`000000oooo00@00000103oool20000
00<0oooo00<000000?ooo`3oool0203oool010000000oooo0?ooo`3oool3000000D0oooo20000003
0?ooo`8000000`3oool2000000L0oooo00<000000?ooo`0000000P0000020?ooo`80000000L0oooo
00000000000000000?ooo`000000oooo00@000001P3oool00`000000oooo0?ooo`080?ooo`004P3o
ool2000000T0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`0I0?ooo`040000003o
ool000000?ooo`@0000000<0oooo0000000000000P000000103oool000000000003oool200000005
0?ooo`000000oooo0000003oool01`0000020?ooo`8000002@3oool3000000040?ooo`0000000000
000000L0oooo1P0000020?ooo`8000000`3oool2000000030?ooo`000000oooo0080oooo10000000
0`3oool0000000000002000000050?ooo`00000000000000003oool00P0000000`3oool000000000
0003000000@0oooo1P0000040?ooo`80000000<0oooo0000003oool00P3oool4000000030?ooo`00
0000000000<000000`3oool4000000030?ooo`000000000000@0oooo0P000000103oool000000?oo
o`0000030?ooo`<0000000@0oooo0000003oool0oooo2P0000020?ooo`8000000`3oool2000000H0
oooo0P0000001@3oool00000000000000000oooo00l000001@3oool00`000000oooo0?ooo`080?oo
o`004P3oool00`000000oooo0?ooo`0?0?ooo`030000003oool0oooo01T0oooo00@000000?ooo`00
0000oooo0`0000020?ooo`@0000000@0oooo0000003oool0oooo0P000000103oool000000?ooo`00
00050?ooo`<000000P3oool2000000T0oooo00@000000?ooo`3oool0oooo0`0000070?ooo`H00000
0P3oool2000000@0oooo00<000000?ooo`0000000`3oool4000000030?ooo`000000000000800000
00D0oooo00000000000000000?ooo`02000000030?ooo`000000000000<00000103oool00`000000
oooo000000020?ooo`030000003oool0oooo0080oooo0P0000000`3oool000000?ooo`020?ooo`@0
000000<0oooo0000000000000`0000030?ooo`@0000000<0oooo000000000000103oool200000004
0?ooo`000000oooo000000<0oooo0`000000103oool000000?ooo`3oool500000080oooo0`000002
0?ooo`8000000`3oool2000000H0oooo0P0000001@3oool00000000000000000oooo00l000001@3o
ool00`000000oooo0?ooo`080?ooo`004P3oool00`000000oooo0?ooo`0?0?ooo`030000003oool0
oooo01T0oooo00@000000?ooo`000000oooo0`0000020?ooo`@0000000@0oooo0000003oool0oooo
0P000000103oool000000?ooo`0000050?ooo`<000000P3oool2000000T0oooo00@000000?ooo`3o
ool0oooo0`0000070?ooo`H000000P3oool2000000@0oooo00<000000?ooo`0000000`3oool40000
00030?ooo`00000000000080000000D0oooo00000000000000000?ooo`02000000030?ooo`000000
000000<00000103oool00`000000oooo000000020?ooo`030000003oool0oooo0080oooo0P000000
0`3oool000000?ooo`020?ooo`@0000000<0oooo0000000000000`0000030?ooo`@0000000<0oooo
000000000000103oool2000000040?ooo`000000oooo000000<0oooo0`000000103oool000000?oo
o`3oool500000080oooo0`0000020?ooo`8000000`3oool2000000H0oooo0P0000001@3oool00000
000000000000oooo00l000001@3oool00`000000oooo0?ooo`080?ooo`004P3oool00`000000oooo
0?ooo`0?0?ooo`030000003oool0oooo01T0oooo00@000000?ooo`000000oooo0`0000020?ooo`@0
000000@0oooo0000003oool0oooo0P000000103oool000000?ooo`0000050?ooo`<000000P3oool2
000000T0oooo00@000000?ooo`3oool0oooo0`0000070?ooo`L0000000<0oooo000000000000103o
ool00`000000oooo000000020?ooo`030000003oool000000080000000<0oooo0000000000000P00
00001@3oool00000000000000000oooo00T000000P3oool2000000050?ooo`000000oooo0?ooo`00
0000103oool2000000030?ooo`000000oooo0080oooo100000000`3oool0000000000003000000<0
oooo1`0000040?ooo`80000000@0oooo0000003oool000000`3oool500000080oooo1@0000020?oo
o`@0000000<0oooo0000000000000`3oool2000000H0oooo0P0000000`3oool000000?ooo`0A0000
00D0oooo00<000000?ooo`3oool0203oool00180oooo00<000000?ooo`3oool03`3oool00`000000
oooo0?ooo`0I0?ooo`040000003oool000000?ooo`<000000P3oool4000000040?ooo`000000oooo
0?ooo`80000000@0oooo0000003oool000001@3oool300000080oooo0P0000090?ooo`040000003o
ool0oooo0?ooo`<000001`3oool7000000030?ooo`000000000000@0oooo00<000000?ooo`000000
0P3oool00`000000oooo00000002000000030?ooo`00000000000080000000D0oooo000000000000
00000?ooo`0900000080oooo0P0000001@3oool000000?ooo`3oool0000000@0oooo0P0000000`3o
ool000000?ooo`020?ooo`@0000000<0oooo0000000000000`0000030?ooo`L00000103oool20000
00040?ooo`000000oooo000000<0oooo1@0000020?ooo`D000000P3oool4000000030?ooo`000000
000000<0oooo0P0000060?ooo`80000000<0oooo0000003oool04@0000050?ooo`030000003oool0
oooo00P0oooo000B0?ooo`800000403oool00`000000oooo0?ooo`0I0?ooo`<0000000@0oooo0000
0000000000000P3oool4000000040?ooo`000000oooo0?ooo`@0000000<0oooo0000003oool0103o
ool300000080oooo0P0000060?ooo`80000000<0oooo0000003oool00P3oool3000000L0oooo2P00
00040?ooo`040000003oool000000?ooo`80000000D0oooo00000000000000000?ooo`0800000003
0?ooo`000000000000L0000000H0oooo00000000000000000?ooo`0000020?ooo`030000003oool0
oooo0080oooo100000030?ooo`@0000000<0oooo0000000000000`0000030?ooo`L00000103oool2
000000070?ooo`000000oooo0000003oool000000?ooo`0<00000080oooo1`0000030?ooo`D00000
00<0oooo0000000000000P0000000`3oool000000?ooo`0B000000<0oooo0P00000:0?ooo`004P3o
ool00`000000oooo0?ooo`0?0?ooo`030000003oool0oooo01T0oooo0`000000103oool000000000
000000020?ooo`@0000000@0oooo0000003oool0oooo100000000`3oool000000?ooo`040?ooo`<0
00000`3oool00`000000oooo0?ooo`040?ooo`80000000<0oooo0000003oool0303oool:000000H0
oooo00D000000?ooo`00000000000?ooo`02000000D0oooo0`0000000`3oool000000?ooo`030000
0080oooo100000000`3oool00000000000020?ooo`040000003oool0oooo000000@0oooo10000003
0?ooo`@0000000<0oooo0000000000000`0000030?ooo`L00000103oool2000000080?ooo`000000
oooo0000003oool000000?ooo`0000020?ooo`L00000103oool7000000@0oooo10000000103oool0
00000000000000040?ooo`P0000000<0oooo0000000000000`000000103oool00000000000000003
0?ooo`8000002P3oool00180oooo00<000000?ooo`3oool03`3oool00`000000oooo0?ooo`0I0?oo
o`<0000000@0oooo00000000000000000P3oool4000000040?ooo`000000oooo0?ooo`@0000000<0
oooo0000003oool0103oool3000000<0oooo00<000000?ooo`3oool0103oool2000000030?ooo`00
0000oooo00`0oooo2P0000060?ooo`050000003oool000000000003oool00P0000050?ooo`<00000
00<0oooo0000003oool00`0000020?ooo`@0000000<0oooo0000000000000P3oool010000000oooo
0?ooo`0000040?ooo`@000000`3oool4000000030?ooo`000000000000<000000`3oool7000000@0
oooo0P000000203oool000000?ooo`000000oooo0000003oool000000P3oool7000000@0oooo1`00
00040?ooo`@0000000@0oooo0000000000000000103oool8000000030?ooo`000000000000<00000
00@0oooo00000000000000000`3oool2000000X0oooo00020?ooo`D000000`3oool2000000H0oooo
00<000000?ooo`3oool03`3oool00`000000oooo0?ooo`0I0?ooo`<0000000@0oooo000000000000
00000P3oool4000000040?ooo`000000oooo0?ooo`@0000000<0oooo0000003oool0103oool30000
00<0oooo00<000000?ooo`3oool0103oool2000000030?ooo`000000oooo00`0oooo2P0000060?oo
o`050000003oool000000000003oool00P0000050?ooo`<0000000<0oooo0000003oool00`000002
0?ooo`@0000000<0oooo0000000000000P3oool010000000oooo0?ooo`0000040?ooo`@000000`3o
ool4000000030?ooo`000000000000<000000`3oool7000000@0oooo0P000000203oool000000?oo
o`000000oooo0000003oool000000P3oool7000000@0oooo1`0000040?ooo`@0000000@0oooo0000
000000000000103oool8000000030?ooo`000000000000<0000000@0oooo00000000000000000`3o
ool2000000X0oooo00030?ooo`040000003oool0oooo00000080oooo00@000000?ooo`3oool00000
1@3oool00`000000oooo0?ooo`0?0?ooo`030000003oool0oooo01T0oooo0`000000103oool00000
0000000000020?ooo`H000000P3oool5000000H0oooo0`0000030?ooo`030000003oool0oooo00@0
oooo0P0000000`3oool000000?ooo`0<0?ooo`X000001P3oool4000000030?ooo`000000000000D0
oooo0`0000000`3oool000000?ooo`0300000080oooo100000000`3oool00000000000020?ooo`04
0000003oool0oooo000000@0oooo100000020?ooo`D0000000<0oooo000000000000100000020?oo
o`L000000`3oool3000000050?ooo`000000oooo0000003oool00`0000020?ooo`L00000103oool7
000000@0oooo10000000103oool000000000000000050?ooo`L0000000<0oooo0000003oool00`00
0000103oool000000000000000020?ooo`<000002P3oool000@0oooo00<000000?ooo`3oool00P3o
ool010000000oooo0?ooo`0000050?ooo`030000003oool0oooo00l0oooo00<000000?ooo`3oool0
6@3oool3000000040?ooo`000000000000000080oooo1P0000020?ooo`D000001P3oool3000000<0
oooo00<000000?ooo`3oool0103oool2000000030?ooo`000000oooo00`0oooo2P0000060?ooo`@0
000000<0oooo0000000000001@3oool3000000030?ooo`000000oooo00<000000P3oool400000003
0?ooo`00000000000080oooo00@000000?ooo`3oool00000103oool400000080oooo1@0000000`3o
ool000000000000400000080oooo1`0000030?ooo`<0000000D0oooo0000003oool000000?ooo`03
00000080oooo1`0000040?ooo`L00000103oool4000000040?ooo`0000000000000000D0oooo1`00
00000`3oool000000?ooo`03000000040?ooo`000000000000000080oooo0`00000:0?ooo`001@3o
ool01@000000oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool00`3oool200000100oooo
00<000000?ooo`3oool06@3oool700000080oooo1P0000020?ooo`D000001P3oool3000000<0oooo
0P0000030?ooo`H000003@3oool:000000H0oooo100000000`3oool00000000000050?ooo`<00000
00<0oooo0000000000000`0000020?ooo`@0000000<0oooo0000000000000P3oool010000000oooo
0?ooo`0000020?ooo`030000003oool0000000<0000000<0oooo000000000000100000000`3oool0
000000000005000000030?ooo`000000000000D000000`3oool3000000030?ooo`000000oooo00D0
00000P3oool7000000@0oooo1`0000040?ooo`P000001@3oool7000000030?ooo`000000oooo00<0
000000@0oooo00000000000000000P3oool3000000X0oooo00020?ooo`050000003oool0oooo0?oo
o`0000000P3oool010000000oooo0?ooo`0000050?ooo`030000003oool0oooo02`0oooo1P000003
0?ooo`D000000P3oool5000000`0oooo0P0000030?ooo`H000003@3oool2000000030?ooo`000000
000000D000001P3oool4000000030?ooo`000000000000D0oooo0`0000000`3oool0000000000003
00000080oooo100000000`3oool00000000000050?ooo`050000003oool0oooo0000003oool01000
00000`3oool0000000000004000000040?ooo`00000000000?ooo`@0000000<0oooo000000000000
1@0000030?ooo`<0000000<0oooo0000003oool01@0000020?ooo`H000001@3oool7000000D0oooo
1`0000050?ooo`<0000000<0oooo0000000000000P3oool00`000000oooo00000002000000040?oo
o`000000000000000080oooo0`00000:0?ooo`000P3oool01@000000oooo0?ooo`3oool000000080
oooo00@000000?ooo`3oool000001@3oool00`000000oooo0?ooo`0/0?ooo`H000000`3oool50000
0080oooo1@00000<0?ooo`8000000`3oool6000000d0oooo0P0000000`3oool00000000000050000
00H0oooo100000000`3oool00000000000050?ooo`<0000000<0oooo0000000000000`0000020?oo
o`@0000000<0oooo0000000000001@3oool01@000000oooo0?ooo`000000oooo00@0000000<0oooo
00000000000010000000103oool000000000003oool4000000030?ooo`000000000000D000000`3o
ool3000000030?ooo`000000oooo00D000000P3oool6000000D0oooo1`0000050?ooo`L000001@3o
ool3000000030?ooo`00000000000080oooo00<000000?ooo`0000000P000000103oool000000000
000000020?ooo`<000002P3oool000<0oooo0`0000040?ooo`8000001P3oool00`000000oooo0?oo
o`0/0?ooo`H000000`3oool500000080oooo1@00000<0?ooo`8000000`3oool6000000d0oooo0P00
00000`3oool0000000000004000000L0oooo100000000`3oool00000000000050?ooo`<0000000<0
oooo0000000000000`0000020?ooo`@0000000<0oooo0000000000001P3oool010000000oooo0000
003oool3000000030?ooo`000000000000D0000000@0oooo000000000000oooo100000000`3oool0
000000000005000000<0oooo0`0000000`3oool000000?ooo`0500000080oooo1P0000050?ooo`L0
00001@3oool7000000D0oooo0`0000000`3oool00000000000020?ooo`030000003oool000000080
000000<0oooo0000000000000P0000000`3oool000000000000;0?ooo`004P3oool00`000000oooo
0?ooo`0/0?ooo`H000000`3oool500000080oooo1@00000<0?ooo`8000000`3oool6000000d0oooo
0P0000000`3oool0000000000004000000L0oooo100000000`3oool00000000000050?ooo`<00000
00<0oooo0000000000000`0000020?ooo`@0000000<0oooo0000000000001P3oool010000000oooo
0000003oool3000000030?ooo`000000000000D0000000@0oooo000000000000oooo100000000`3o
ool0000000000005000000<0oooo0`0000000`3oool000000?ooo`0500000080oooo1P0000050?oo
o`L000001@3oool7000000D0oooo0`0000000`3oool00000000000020?ooo`030000003oool00000
0080000000<0oooo0000000000000P0000000`3oool000000000000;0?ooo`004P3oool2000002d0
oooo1P0000030?ooo`D000000P3oool5000000`0oooo0P0000000`3oool000000?ooo`06000000d0
oooo0P0000000`3oool0000000000004000000L0oooo100000000`3oool00000000000050?ooo`<0
000000<0oooo0000000000000`0000020?ooo`@0000000<0oooo0000000000001P3oool00`000000
oooo00000004000000030?ooo`000000000000P0000000<0oooo0000000000000P0000000`3oool0
00000000000500000080oooo300000020?ooo`H000001@3oool7000000D0oooo1`0000050?ooo`<0
000000<0oooo0000000000000P3oool00`000000oooo00000002000000030?ooo`00000000000080
000000<0oooo0000000000002`3oool00180oooo00<000000?ooo`3oool0;@3oool200000080oooo
00<000000?ooo`3oool0103oool200000080oooo00<000000?ooo`0000000P00000<0?ooo`800000
00<0oooo0000003oool01P00000=0?ooo`80000000@0oooo0000003oool0oooo0P0000090?ooo`<0
000000<0oooo0000000000001@3oool200000080oooo1@0000030?ooo`<0000000<0oooo00000000
00001P3oool00`000000oooo00000004000000070?ooo`00000000000000003oool000000?ooo`04
000000030?ooo`00000000000080000000@0oooo00000000000000000`3oool00`000000oooo0?oo
o`0;000000<0oooo0P000000103oool000000000000000050?ooo`H000001`3oool00`000000oooo
00000003000000D0oooo00@000000?ooo`3oool0oooo0P0000060?ooo`080000003oool0oooo0000
003oool000000?ooo`00000<0?ooo`004P3oool00`000000oooo0?ooo`0]0?ooo`8000000P3oool0
0`000000oooo0?ooo`040?ooo`8000000P3oool00`000000oooo00000002000000`0oooo0P000000
0`3oool000000?ooo`06000000d0oooo0P000000103oool000000?ooo`3oool2000000T0oooo0`00
00000`3oool00000000000050?ooo`8000000P3oool5000000<0oooo0`0000000`3oool000000000
00060?ooo`030000003oool0000000@0000000L0oooo00000000000000000?ooo`000000oooo00@0
000000<0oooo0000000000000P000000103oool000000000000000030?ooo`030000003oool0oooo
00/000000`3oool2000000040?ooo`0000000000000000D0oooo1P0000070?ooo`030000003oool0
000000<000001@3oool010000000oooo0?ooo`3oool2000000H0oooo00P000000?ooo`3oool00000
0?ooo`000000oooo000000`0oooo000B0?ooo`030000003oool0oooo02d0oooo0P0000020?ooo`03
0000003oool0oooo00@0oooo0P0000020?ooo`030000003oool0000000800000303oool200000003
0?ooo`000000oooo00H000003@3oool2000000040?ooo`000000oooo0?ooo`8000002@3oool30000
00030?ooo`000000000000D0oooo0P0000020?ooo`D000000`3oool3000000030?ooo`0000000000
00H0oooo00<000000?ooo`000000100000001`3oool00000000000000000oooo0000003oool01000
00000`3oool0000000000002000000040?ooo`0000000000000000<0oooo00<000000?ooo`3oool0
2`0000030?ooo`80000000@0oooo00000000000000001@3oool6000000L0oooo00<000000?ooo`00
00000`0000050?ooo`040000003oool0oooo0?ooo`8000001P3oool020000000oooo0?ooo`000000
oooo0000003oool00000303oool00180oooo00<000000?ooo`3oool0;P3oool010000000oooo0?oo
o`0000060?ooo`8000000P3oool00`000000oooo00000002000000`0oooo0P0000000`3oool00000
0?ooo`06000000d0oooo00@000000?ooo`3oool000000P3oool2000000T0oooo0`0000000`3oool0
0000000000050?ooo`8000000P3oool200000080oooo00H000000?ooo`3oool0oooo0000003oool3
000000L0oooo00<000000?ooo`000000100000001`3oool00000000000000000oooo0000003oool0
0P0000000`3oool000000?ooo`04000000040?ooo`0000000000000000<0oooo00<000000?ooo`3o
ool02`0000030?ooo`80000000@0oooo00000000000000001@3oool6000000L0oooo00<000000?oo
o`3oool00`0000050?ooo`040000003oool0oooo0?ooo`8000001P3oool020000000oooo0?ooo`00
0000oooo0000003oool00000303oool00180oooo00<000000?ooo`3oool0;P3oool010000000oooo
0?ooo`0000060?ooo`8000000P3oool00`000000oooo00000002000000`0oooo0P0000000`3oool0
00000?ooo`06000000d0oooo00@000000?ooo`3oool000000P3oool2000000T0oooo0`0000000`3o
ool00000000000050?ooo`8000000P3oool200000080oooo00H000000?ooo`3oool0oooo0000003o
ool3000000L0oooo00<000000?ooo`000000100000001`3oool00000000000000000oooo0000003o
ool00P0000000`3oool000000?ooo`04000000040?ooo`0000000000000000<0oooo00<000000?oo
o`3oool02`0000030?ooo`80000000@0oooo00000000000000001@3oool6000000L0oooo00<00000
0?ooo`3oool00`0000050?ooo`040000003oool0oooo0?ooo`8000001P3oool020000000oooo0?oo
o`000000oooo0000003oool00000303oool00180oooo0P00000_0?ooo`040000003oool0oooo0000
00H0oooo0P0000020?ooo`030000003oool0000000800000303oool;000000d0oooo00@000000?oo
o`3oool000000P3oool2000000T0oooo0`0000000`3oool00000000000050?ooo`8000000P3oool2
00000080oooo00H000000?ooo`3oool0oooo0000003oool3000000L0oooo00<000000?ooo`000000
100000001`3oool00000000000000000oooo0000003oool00P0000000`3oool000000?ooo`080000
00<0oooo3P0000030?ooo`80000000@0oooo00000000000000001@3oool6000000L0oooo00<00000
0?ooo`3oool00`0000050?ooo`040000003oool0oooo0?ooo`8000001P3oool020000000oooo0?oo
o`000000oooo0000003oool00000303oool00180oooo00<000000?ooo`3oool0;P3oool00`000000
oooo0?ooo`070?ooo`800000103oool3000000`0oooo2`00000@0?ooo`030000003oool0oooo0080
00002@3oool3000000030?ooo`000000oooo00H0oooo00<000000?ooo`3oool00P0000060?ooo`03
0000003oool00000008000001`3oool00`000000oooo00000004000000060?ooo`00000000000000
003oool000000P3oool00`000000oooo000000020?ooo`D000001@3oool<000000030?ooo`000000
oooo00H0oooo00<000000?ooo`3oool01@3oool2000000d0oooo0`0000090?ooo`8000002`3oool0
0`000000oooo0000000<0?ooo`004P3oool00`000000oooo0?ooo`0^0?ooo`030000003oool0oooo
00L0oooo0P0000040?ooo`<00000303oool;00000100oooo00<000000?ooo`3oool00P0000090?oo
o`<0000000<0oooo0000003oool01P3oool00`000000oooo0?ooo`02000000H0oooo00<000000?oo
o`0000000P0000070?ooo`030000003oool0000000@0000000H0oooo00000000000000000?ooo`00
00020?ooo`030000003oool000000080oooo1@0000050?ooo``0000000<0oooo0000003oool01P3o
ool00`000000oooo0?ooo`050?ooo`8000003@3oool3000000T0oooo0P00000;0?ooo`030000003o
ool0000000`0oooo000B0?ooo`030000003oool0oooo02h0oooo00<000000?ooo`3oool01`3oool0
0`000000oooo0?ooo`030?ooo`<000003@3oool:00000100oooo00<000000?ooo`3oool00P000009
0?ooo`<0000000<0oooo0000003oool01P3oool00`000000oooo0?ooo`02000000H0oooo00<00000
0?ooo`0000000P0000070?ooo`030000003oool0000000@0000000H0oooo00000000000000000?oo
o`0000020?ooo`030000003oool000000080oooo1@0000050?ooo``0000000<0oooo0000003oool0
1P3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00`0oooo0`0000090?ooo`800000
2`3oool00`000000oooo0000000<0?ooo`004P3oool00`000000oooo0?ooo`0^0?ooo`030000003o
ool0oooo00L0oooo00<000000?ooo`3oool00`3oool3000000d0oooo2P00000@0?ooo`030000003o
ool0oooo008000002@3oool3000000030?ooo`000000oooo00H0oooo00<000000?ooo`3oool00P00
00060?ooo`030000003oool00000008000001`3oool00`000000oooo00000004000000060?ooo`00
000000000000003oool000000P3oool00`000000oooo000000020?ooo`D000001@3oool<00000003
0?ooo`000000oooo00H0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`0<0?ooo`<0
00002@3oool2000000/0oooo00<000000?ooo`000000303oool00180oooo0P00000_0?ooo`030000
003oool0oooo00L0oooo00<000000?ooo`3oool00`3oool3000000d0oooo2P00000@0?ooo`030000
003oool0oooo008000002@3oool3000000030?ooo`000000oooo00H0oooo00<000000?ooo`3oool0
0P0000060?ooo`030000003oool00000008000001`3oool7000000060?ooo`00000000000000003o
ool000000P3oool00`000000oooo000000020?ooo`D000001@3oool<000000030?ooo`000000oooo
00H0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`0<0?ooo`<000002@3oool20000
00/0oooo00<000000?ooo`000000303oool00180oooo00<000000?ooo`3oool0C`3oool500000003
0?ooo`000000000001@0oooo00<000000?ooo`3oool02@3oool2000000`0oooo0P0000080?ooo`80
0000203oool600000080oooo00D000000?ooo`3oool0oooo000000020?ooo`030000003oool0oooo
0080oooo1@0000050?ooo`X0000000@0oooo0000003oool000007P3oool3000001H0oooo00<00000
0?ooo`000000303oool00180oooo00<000000?ooo`3oool0C`3oool5000000030?ooo`0000000000
01@0oooo00<000000?ooo`3oool02@3oool2000000`0oooo0P0000080?ooo`800000203oool60000
0080oooo00D000000?ooo`3oool0oooo000000020?ooo`030000003oool0oooo0080oooo1@000005
0?ooo`X0000000@0oooo0000003oool000007P3oool3000001H0oooo00<000000?ooo`000000303o
ool00180oooo00<000000?ooo`3oool0C`3oool5000000030?ooo`000000000001@0oooo00<00000
0?ooo`3oool02@3oool2000000`0oooo0P0000080?ooo`800000203oool600000080oooo00D00000
0?ooo`3oool0oooo000000020?ooo`030000003oool0oooo0080oooo1@0000050?ooo`X0000000@0
oooo0000003oool000007P3oool3000001H0oooo00<000000?ooo`000000303oool00180oooo00<0
00000?ooo`3oool0C`3oool5000000030?ooo`000000000001@0oooo00<000000?ooo`3oool02@3o
ool2000000d0oooo00<000000?ooo`3oool01P3oool2000000P0oooo1P0000020?ooo`050000003o
ool0oooo0?ooo`0000000P3oool00`000000oooo0?ooo`020?ooo`D000001@3oool:000000040?oo
o`000000oooo000001h0oooo0`00000F0?ooo`<00000303oool00180oooo00<000000?ooo`3oool0
C`3oool5000000030?ooo`000000000001@0oooo00<000000?ooo`3oool02@3oool2000000d0oooo
00<000000?ooo`3oool01P3oool2000000P0oooo1P0000020?ooo`050000003oool0oooo0?ooo`00
00000P3oool00`000000oooo0?ooo`020?ooo`D000001@3oool:000000040?ooo`000000oooo0000
01h0oooo0`00000F0?ooo`<00000303oool00180oooo0P00001@0?ooo`D0000000<0oooo00000000
0000503oool00`000000oooo0?ooo`090?ooo`8000003@3oool00`000000oooo0?ooo`060?ooo`80
0000203oool600000080oooo00D000000?ooo`3oool0oooo000000020?ooo`030000003oool0oooo
0080oooo1@0000050?ooo`X0000000@0oooo0000003oool000007P3oool3000001H0oooo0`00000<
0?ooo`004P3oool00`000000oooo0?ooo`1?0?ooo`D000000P3oool00`000000oooo0?ooo`0f0?oo
o`800000203oool600000080oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`030?oo
o`<00000203oool300000080oooo0`0000030?ooo`030000003oool0oooo01`0oooo0`00000F0?oo
o`<00000303oool00180oooo00<000000?ooo`3oool0C`3oool500000080oooo00<000000?ooo`3o
ool0=P3oool2000000P0oooo1P0000020?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3o
ool00`3oool3000000P0oooo0`0000020?ooo`<000000`3oool00`000000oooo0?ooo`0L0?ooo`<0
00005P3oool3000000`0oooo00020?ooo`D000000P3oool3000000H0oooo00<000000?ooo`3oool0
C`3oool00`000000oooo0000000200000080oooo00<000000?ooo`3oool0=P3oool2000000P0oooo
1@0000030?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool00`3oool3000000P0oooo
0`0000020?ooo`<000000`3oool00`000000oooo0?ooo`0L0?ooo`<000005P3oool3000000`0oooo
00030?ooo`060000003oool0oooo0000003oool000000`3oool00`000000oooo0?ooo`030?ooo`03
0000003oool0oooo04l0oooo00<000000?ooo`0000000P0000020?ooo`030000003oool0oooo03H0
oooo0P0000080?ooo`D000000`3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00<0
oooo0`0000080?ooo`<000000P3oool3000000<0oooo00<000000?ooo`3oool0703oool3000001H0
oooo0`00000<0?ooo`00103oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00<0oooo
0P00001@0?ooo`030000003oool00000008000000P3oool00`000000oooo0?ooo`0f0?ooo`800000
203oool5000000<0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`030?ooo`<00000
203oool300000080oooo0`0000030?ooo`030000003oool0oooo01`0oooo0`00000F0?ooo`<00000
303oool000D0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`030?ooo`030000003o
ool0oooo04l0oooo00<000000?ooo`000000?@3oool2000000P0oooo0P0000060?ooo`030000003o
ool0oooo00@0oooo00<000000?ooo`3oool00`3oool3000000P0oooo0`0000020?ooo`030000003o
ool0oooo00<0oooo00<000000?ooo`3oool0=@3oool3000000`0oooo00020?ooo`060000003oool0
oooo0?ooo`000000oooo100000060?ooo`030000003oool0oooo04l0oooo00<000000?ooo`000000
?@3oool2000000P0oooo0P0000060?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0
0`3oool3000000P0oooo0`0000020?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0
=@3oool3000000`0oooo00020?ooo`070000003oool0oooo0?ooo`000000oooo000000090?ooo`03
0000003oool0oooo04l0oooo00<000000?ooo`000000?@3oool2000000P0oooo0P0000060?ooo`03
0000003oool0oooo00@0oooo00<000000?ooo`3oool00`3oool3000000P0oooo0`0000020?ooo`03
0000003oool0oooo00<0oooo00<000000?ooo`3oool0=@3oool3000000`0oooo00030?ooo`<00000
0P3oool5000000D0oooo00<000000?ooo`3oool0C`3oool00`000000oooo0000000m0?ooo`800000
203oool2000000H0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`030?ooo`<00000
203oool300000080oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`0e0?ooo`<00000
303oool00180oooo00<000000?ooo`3oool0C`3oool00`000000oooo0000000m0?ooo`800000203o
ool2000000H0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`030?ooo`<00000203o
ool300000080oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`0e0?ooo`<00000303o
ool00180oooo0P00001@0?ooo`030000003oool0000003d0oooo0P0000080?ooo`8000001P3oool0
0`000000oooo0?ooo`040?ooo`030000003oool0oooo00<0oooo0`0000080?ooo`<000000P3oool0
0`000000oooo0?ooo`030?ooo`030000003oool0oooo03D0oooo0`00000<0?ooo`004P3oool00`00
0000oooo0?ooo`2I0?ooo`800000503oool2000000T0oooo0P0000110?ooo`800000303oool00180
oooo00<000000?ooo`3oool0V@3oool2000001@0oooo0P0000090?ooo`800000@@3oool2000000`0
oooo000B0?ooo`030000003oool0oooo09T0oooo0P00000D0?ooo`8000002@3oool200000440oooo
0P00000<0?ooo`004P3oool00`000000oooo0?ooo`2I0?ooo`800000503oool2000000T0oooo0P00
00110?ooo`800000303oool00180oooo0P00002J0?ooo`800000503oool2000000T0oooo0P000011
0?ooo`800000303oool00180oooo00<000000?ooo`3oool0V@3oool2000001@0oooo00<000000?oo
o`3oool0203oool2000004l0oooo000B0?ooo`030000003oool0oooo09T0oooo0P00000D0?ooo`03
0000003oool0oooo00P0oooo0P00001?0?ooo`004P3oool00`000000oooo0?ooo`2I0?ooo`800000
503oool00`000000oooo0?ooo`080?ooo`800000C`3oool00180oooo00<000000?ooo`3oool0VP3o
ool00`000000oooo0?ooo`0B0?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool0CP3o
ool00180oooo00<000000?ooo`3oool0VP3oool00`000000oooo0?ooo`0B0?ooo`030000003oool0
oooo00P0oooo00<000000?ooo`3oool0CP3oool00180oooo0P00002K0?ooo`030000003oool0oooo
0180oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`1>0?ooo`004P3oool00`000000
oooo0?ooo`2_0?ooo`030000003oool0oooo05T0oooo000B0?ooo`030000003oool0oooo0:l0oooo
00<000000?ooo`3oool0F@3oool00180oooo00<000000?ooo`3oool0[`3oool00`000000oooo0?oo
o`1I0?ooo`004P3oool00`000000oooo0?ooo`2_0?ooo`030000003oool0oooo05T0oooo000B0?oo
o`800000/03oool00`000000oooo0?ooo`1I0?ooo`004P3oool00`000000oooo0?ooo`3o0?ooo``0
oooo000B0?ooo`030000003oool0oooo0?l0oooo303oool00180oooo00<000000?ooo`3oool0o`3o
ool<0?ooo`004P3oool00`000000oooo0?ooo`3o0?ooo``0oooo0000\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.662284, -2.24177, \
0.0365958, 0.180667}}],

Cell[BoxData[
    \(19.672953451043337`\)], "Output",
  CellLabel->"Out[200]="]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["\<\
Distribution of segments per ancestral lineage: ~exponential, mean \
& sd {2.63, 2.05}\
\>", "SubsubsectionIcon"],

Cell[CellGroupData[{

Cell[BoxData[
    \(nsegs = 
      Flatten[\(\((Length /@ \((# /. 
                    AncestralLineage[_, _, s_, j_, _] :> 
                      Partition[
                        If[s\[LeftDoubleBracket]1\[RightDoubleBracket] === \
{}, j, Prepend[j, 0]], 2])\))\) &\) /@ lpList]\)], "Input",
  CellLabel->"In[328]:="],

Cell[BoxData[
    \({1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 
      1, 1, 2, 1, 1, 1, 2, 1, 1, 1, 2, 1, 1, 2, 1, 1, 2, 2, 1, 1, 2, 2, 1, 1, 
      1, 2, 1, 2, 1, 1, 1, 1, 2, 1, 1, 2, 1, 1, 1, 2, 1, 1, 2, 1, 1, 1, 1, 2, 
      1, 1, 1, 1, 1, 1, 2, 1, 1, 1, 1, 1, 2, 1, 1, 1, 1, 1, 1, 2, 1, 1, 1, 1, 
      1, 1, 1, 1, 2, 1, 1, 1, 1, 1, 1, 1, 1, 2, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 
      2, 1, 1, 1, 2, 1, 1, 1, 1, 1, 1, 1, 1, 2, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 
      1, 1, 2, 1, 1, 1, 1, 1, 1, 1, 1, 1, 2, 1, 2, 1, 1, 1, 1, 1, 1, 1, 1, 2, 
      1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 2, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 2, 1, 1, 
      1, 1, 1, 2, 1, 1, 1, 1, 1, 1, 1, 1, 1, 2, 3, 1, 1, 1, 1, 1, 1, 1, 1, 2, 
      3, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 2, 1, 1, 1, 2, 1, 1, 1, 1, 1, 1, 1, 1, 
      2, 1, 1, 2, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 2, 1, 3, 1, 1, 1, 1, 1, 
      1, 1, 1, 1, 1, 2, 1, 2, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 2, 1, 2, 1, 1, 1, 
      1, 1, 1, 1, 1, 1, 1, 2, 1, 1, 1, 2, 1, 1, 1, 1, 1, 1, 1, 2, 1, 1, 1, 2, 
      2, 1, 1, 1, 1, 1, 1, 2, 1, 1, 1, 2, 2, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 
      2, 2, 1, 1, 2, 1, 1, 1, 1, 1, 1, 1, 1, 1, 2, 2, 1, 1, 2, 1, 1, 1, 1, 1, 
      1, 1, 1, 2, 1, 1, 2, 1, 2, 1, 1, 1, 1, 1, 1, 1, 1, 1, 2, 1, 2, 1, 1, 1, 
      1, 1, 1, 1, 1, 1, 1, 2, 1, 2, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 2, 1, 2, 1, 
      1, 1, 1, 2, 1, 1, 1, 1, 1, 1, 2, 1, 2, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 
      2, 1, 2, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 2, 1, 1, 1, 1, 1, 1, 1, 
      1, 1, 1, 2, 1, 1, 1, 1, 1, 2, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 2, 1, 1, 1, 
      1, 1, 2, 1, 1, 1, 1, 1, 1, 1, 1, 1, 2, 1, 2, 1, 1, 1, 1, 2, 1, 1, 1, 1, 
      1, 1, 1, 2, 1, 2, 2, 1, 1, 1, 1, 2, 1, 1, 1, 1, 1, 1, 1, 1, 2, 4, 1, 1, 
      1, 2, 1, 1, 1, 1, 1, 1, 1, 2, 4, 2, 1, 1, 1, 2, 1, 1, 1, 1, 1, 1, 1, 2, 
      2, 2, 2, 1, 1, 2, 1, 1, 1, 1, 1, 1, 1, 2, 2, 2, 2, 1, 1, 1, 2, 1, 1, 1, 
      1, 1, 1, 1, 2, 2, 2, 2, 1, 2, 1, 2, 1, 1, 1, 1, 1, 2, 2, 2, 2, 1, 2, 2, 
      1, 2, 1, 1, 1, 1, 1, 2, 2, 2, 2, 1, 2, 1, 1, 1, 2, 1, 1, 1, 1, 2, 2, 2, 
      2, 1, 2, 1, 2, 1, 2, 1, 1, 1, 1, 2, 2, 2, 1, 2, 1, 2, 1, 1, 1, 2, 1, 1, 
      1, 1, 2, 2, 1, 2, 1, 2, 1, 1, 1, 2, 1, 2, 1, 1, 1, 1, 2, 1, 2, 1, 2, 1, 
      1, 1, 4, 2, 1, 1, 1, 1, 2, 1, 2, 1, 2, 1, 1, 4, 2, 2, 1, 1, 1, 2, 1, 2, 
      1, 2, 1, 1, 4, 2, 1, 1, 2, 1, 1, 1, 2, 1, 2, 1, 1, 4, 2, 1, 1, 2, 2, 1, 
      1, 1, 2, 1, 1, 4, 2, 1, 1, 2, 3, 2, 1, 1, 2, 1, 4, 2, 1, 1, 2, 3, 2, 2, 
      1, 1, 2, 1, 4, 2, 1, 1, 2, 2, 1, 2, 1, 1, 2, 1, 4, 2, 1, 1, 2, 2, 1, 3, 
      1, 1, 2, 1, 4, 2, 1, 1, 2, 1, 3, 1, 1, 1, 1, 2, 1, 4, 2, 1, 1, 2, 1, 3, 
      1, 1, 1, 1, 1, 2, 1, 4, 2, 1, 1, 2, 1, 1, 1, 1, 1, 2, 1, 1, 2, 1, 4, 1, 
      1, 2, 1, 1, 1, 1, 1, 2, 1, 1, 1, 1, 1, 4, 1, 1, 2, 1, 1, 1, 1, 1, 2, 1, 
      1, 1, 1, 1, 1, 4, 1, 1, 2, 1, 1, 1, 1, 1, 2, 1, 1, 1, 2, 1, 4, 1, 2, 1, 
      1, 1, 1, 1, 2, 1, 1, 1, 2, 2, 1, 4, 1, 2, 1, 1, 1, 1, 2, 1, 1, 2, 2, 2, 
      1, 2, 1, 1, 1, 1, 2, 1, 1, 2, 2, 2, 4, 1, 2, 1, 1, 1, 2, 1, 1, 2, 2, 2, 
      4, 1, 1, 1, 2, 1, 1, 1, 2, 1, 1, 2, 2, 4, 1, 1, 1, 1, 1, 1, 1, 1, 2, 1, 
      1, 2, 2, 4, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 2, 1, 1, 2, 2, 4, 1, 1, 1, 1, 
      2, 1, 1, 1, 1, 2, 1, 2, 2, 4, 1, 1, 1, 1, 2, 1, 1, 1, 1, 1, 2, 1, 2, 2, 
      4, 1, 1, 1, 2, 1, 1, 2, 1, 1, 1, 2, 2, 2, 4, 1, 1, 1, 1, 1, 2, 3, 1, 1, 
      1, 2, 2, 2, 4, 1, 1, 1, 1, 1, 2, 2, 2, 1, 1, 1, 2, 2, 4, 1, 1, 1, 1, 1, 
      2, 2, 2, 1, 1, 1, 1, 1, 2, 2, 4, 1, 1, 1, 1, 2, 2, 2, 1, 1, 1, 1, 1, 1, 
      1, 2, 2, 4, 1, 1, 1, 2, 2, 2, 1, 1, 1, 1, 1, 1, 1, 2, 2, 4, 1, 1, 1, 2, 
      2, 2, 1, 1, 2, 1, 1, 2, 2, 4, 1, 1, 1, 2, 2, 2, 1, 1, 2, 1, 1, 1, 1, 2, 
      2, 4, 1, 1, 1, 2, 2, 1, 1, 2, 1, 1, 1, 1, 1, 1, 2, 2, 4, 1, 1, 1, 2, 2, 
      1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 2, 2, 4, 1, 1, 1, 2, 1, 1, 1, 1, 1, 1, 1, 
      1, 1, 2, 1, 1, 2, 2, 4, 1, 1, 1, 2, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 
      1, 2, 2, 4, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 3, 1, 1, 2, 2, 1, 1, 
      1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 3, 5, 1, 1, 2, 2, 1, 1, 1, 1, 1, 1, 1, 1, 
      1, 1, 3, 5, 1, 1, 1, 2, 1, 1, 1, 1, 1, 1, 1, 1, 1, 3, 5, 1, 3, 1, 1, 2, 
      1, 1, 1, 1, 1, 1, 1, 3, 5, 1, 3, 2, 1, 1, 2, 1, 1, 1, 1, 1, 1, 1, 5, 1, 
      3, 2, 3, 1, 1, 2, 1, 1, 1, 1, 1, 1, 5, 1, 3, 2, 3, 1, 2, 1, 2, 1, 1, 1, 
      1, 1, 5, 3, 2, 3, 1, 2, 1, 2, 1, 1, 1, 1, 1, 5, 3, 2, 3, 1, 2, 1, 1, 1, 
      2, 1, 1, 1, 1, 1, 5, 3, 3, 1, 2, 1, 1, 1, 1, 1, 2, 1, 1, 1, 1, 3, 3, 1, 
      2, 1, 1, 1, 1, 1, 5, 2, 1, 1, 1, 3, 1, 2, 1, 1, 1, 1, 1, 5, 4, 2, 1, 1, 
      1, 2, 1, 1, 1, 1, 1, 5, 4, 4, 2, 1, 1, 1, 2, 1, 1, 1, 5, 4, 4, 1, 2, 1, 
      1, 1, 2, 1, 1, 1, 4, 4, 1, 4, 2, 2, 1, 1, 1, 1, 1, 4, 4, 1, 4, 2, 3, 2, 
      1, 1, 1, 1, 1, 4, 4, 2, 3, 5, 2, 1, 1, 1, 1, 4, 4, 2, 3, 5, 1, 1, 2, 1, 
      1, 1, 1, 4, 4, 3, 5, 1, 1, 1, 1, 2, 1, 1, 1, 1, 4, 4, 3, 5, 1, 1, 2, 2, 
      1, 1, 1, 1, 4, 4, 5, 1, 2, 4, 2, 1, 1, 1, 4, 4, 5, 1, 4, 3, 2, 1, 1, 1, 
      4, 5, 1, 4, 3, 1, 3, 2, 1, 1, 1, 4, 5, 1, 4, 3, 1, 1, 2, 2, 1, 1, 1, 4, 
      5, 1, 4, 3, 1, 1, 1, 1, 2, 1, 1, 1, 4, 5, 1, 4, 1, 1, 1, 1, 3, 1, 2, 1, 
      1, 1, 4, 1, 1, 1, 1, 1, 3, 1, 8, 2, 1, 1, 1, 4, 1, 1, 1, 1, 1, 3, 1, 4, 
      5, 2, 1, 1, 1, 4, 1, 1, 1, 1, 3, 1, 4, 5, 1, 1, 2, 1, 1, 4, 1, 1, 1, 3, 
      1, 4, 5, 1, 1, 2, 2, 1, 1, 4, 1, 1, 1, 3, 1, 4, 1, 1, 2, 2, 3, 2, 1, 1, 
      4, 1, 1, 1, 3, 1, 4, 1, 1, 2, 3, 1, 1, 2, 1, 1, 4, 1, 1, 1, 1, 4, 1, 1, 
      2, 3, 1, 1, 1, 2, 2, 1, 1, 4, 1, 1, 1, 1, 4, 1, 1, 3, 1, 1, 1, 4, 1, 1, 
      4, 1, 1, 1, 1, 4, 1, 1, 3, 1, 1, 1, 6, 1, 1, 4, 1, 1, 1, 1, 4, 1, 1, 3, 
      1, 1, 1, 2, 4, 1, 1, 4, 1, 1, 1, 4, 1, 3, 1, 1, 1, 2, 4, 2, 1, 1, 4, 1, 
      1, 4, 1, 3, 1, 1, 1, 2, 2, 3, 1, 4, 1, 1, 4, 1, 1, 1, 1, 2, 2, 3, 4, 1, 
      4, 1, 1, 4, 1, 1, 1, 1, 2, 2, 4, 1, 2, 1, 4, 1, 1, 4, 1, 1, 1, 1, 2, 4, 
      2, 2, 1, 4, 1, 1, 4, 1, 1, 1, 1, 4, 2, 4, 1, 4, 1, 4, 1, 1, 1, 1, 2, 4, 
      5, 1, 4, 1, 4, 1, 1, 1, 1, 2, 5, 1, 4, 1, 4, 1, 4, 1, 1, 1, 1, 2, 5, 1, 
      2, 2, 1, 4, 1, 4, 1, 1, 1, 1, 2, 1, 2, 2, 1, 4, 1, 4, 1, 4, 1, 1, 1, 1, 
      2, 2, 1, 4, 3, 1, 4, 1, 4, 1, 1, 1, 1, 2, 4, 3, 3, 1, 4, 1, 4, 1, 1, 1, 
      2, 3, 3, 5, 1, 4, 1, 4, 1, 1, 2, 3, 5, 4, 1, 4, 4, 1, 2, 3, 5, 4, 2, 1, 
      4, 4, 2, 3, 5, 4, 3, 1, 4, 4, 2, 3, 5, 4, 2, 1, 1, 4, 4, 2, 3, 4, 2, 1, 
      1, 4, 1, 4, 4, 2, 3, 2, 1, 1, 4, 1, 3, 1, 4, 4, 2, 2, 1, 1, 4, 1, 3, 2, 
      1, 1, 4, 2, 2, 1, 4, 1, 3, 2, 1, 5, 1, 4, 2, 2, 1, 1, 3, 2, 1, 5, 2, 2, 
      1, 4, 2, 2, 1, 1, 2, 1, 2, 2, 7, 1, 4, 2, 2, 1, 1, 2, 1, 2, 2, 4, 3, 1, 
      4, 2, 2, 1, 2, 1, 2, 4, 3, 3, 1, 2, 2, 1, 2, 1, 4, 3, 3, 6, 1, 2, 2, 1, 
      2, 1, 4, 3, 3, 5, 2, 1, 2, 2, 1, 1, 3, 3, 5, 2, 6, 1, 2, 2, 1, 1, 3, 3, 
      6, 6, 1, 2, 1, 1, 3, 3, 6, 7, 1, 2, 1, 1, 3, 6, 7, 1, 2, 1, 2, 1, 1, 6, 
      7, 1, 2, 3, 1, 1, 2, 1, 1, 6, 1, 2, 3, 1, 5, 2, 1, 2, 1, 1, 6, 1, 2, 1, 
      5, 2, 1, 3, 1, 2, 1, 1, 6, 1, 1, 5, 2, 1, 3, 1, 2, 1, 2, 1, 1, 6, 1, 1, 
      2, 1, 3, 1, 2, 3, 2, 1, 2, 1, 1, 1, 2, 1, 3, 1, 2, 3, 2, 5, 2, 1, 1, 2, 
      1, 3, 1, 2, 3, 2, 5, 2, 2, 1, 1, 1, 3, 1, 2, 3, 2, 5, 2, 1, 1, 2, 1, 1, 
      1, 3, 1, 2, 3, 2, 1, 1, 6, 2, 1, 1, 1, 3, 2, 3, 1, 1, 6, 3, 2, 1, 1, 1, 
      3, 2, 3, 1, 1, 3, 6, 1, 2, 1, 1, 1, 3, 2, 3, 1, 1, 3, 1, 2, 5, 2, 1, 1, 
      1, 3, 2, 3, 1, 3, 1, 2, 5, 1, 1, 2, 1, 1, 1, 3, 2, 1, 3, 1, 5, 1, 1, 3, 
      2, 1, 1, 3, 1, 3, 1, 5, 1, 1, 3, 3, 2, 1, 1, 3, 1, 5, 1, 1, 3, 3, 3, 2, 
      1, 3, 1, 5, 1, 1, 3, 3, 3, 1, 1, 2, 1, 3, 5, 1, 1, 3, 3, 3, 1, 1, 1, 1, 
      2, 1, 3, 5, 1, 1, 3, 3, 1, 1, 1, 1, 1, 2, 2, 1, 3, 5, 1, 1, 3, 3, 1, 1, 
      1, 1, 2, 1, 1, 2, 3, 5, 1, 1, 3, 3, 1, 1, 1, 2, 1, 1, 2, 2, 3, 5, 1, 1, 
      3, 1, 1, 2, 1, 1, 2, 3, 3, 5, 1, 1, 3, 1, 1, 2, 1, 2, 3, 3, 3, 5, 1, 1, 
      3, 1, 2, 1, 2, 3, 3, 5, 1, 1, 3, 1, 2, 1, 2, 3, 3, 1, 3, 5, 1, 1, 1, 2, 
      2, 3, 3, 1, 3, 4, 5, 1, 1, 1, 2, 2, 3, 3, 1, 4, 1, 3, 1, 1, 1, 2, 2, 3, 
      3, 1, 4, 1, 8, 1, 1, 1, 2, 2, 3, 3, 1, 4, 1, 5, 3, 1, 1, 2, 2, 3, 3, 1, 
      4, 1, 5, 3, 1, 1, 1, 2, 2, 3, 3, 1, 4, 1, 5, 3, 1, 1, 1, 2, 2, 3, 3, 1, 
      1, 5, 3, 1, 1, 4, 1, 1, 2, 2, 3, 3, 1, 5, 1, 1, 4, 1, 4, 1, 2, 2, 3, 3, 
      1, 1, 1, 4, 1, 4, 3, 2, 1, 2, 2, 3, 3, 1, 1, 4, 4, 3, 2, 2, 1, 2, 2, 3, 
      1, 1, 4, 4, 3, 2, 2, 3, 1, 1, 2, 2, 3, 1, 1, 4, 4, 3, 3, 1, 4, 1, 2, 2, 
      3, 1, 1, 4, 4, 3, 3, 1, 3, 1, 1, 2, 2, 3, 1, 1, 4, 4, 3, 3, 3, 2, 1, 2, 
      2, 3, 1, 4, 4, 3, 3, 2, 4, 1, 2, 2, 3, 1, 4, 3, 3, 2, 4, 3, 1, 1, 2, 2, 
      3, 1, 4, 3, 3, 2, 1, 2, 1, 2, 2, 3, 1, 4, 3, 3, 2, 1, 1, 2, 1, 2, 2, 1, 
      3, 3, 2, 1, 1, 2, 5, 1, 2, 1, 3, 3, 2, 1, 1, 2, 5, 1, 1, 1, 2, 1, 3, 3, 
      1, 1, 2, 5, 1, 1, 2, 1, 1, 2, 1, 3, 3, 1, 1, 2, 1, 1, 2, 1, 5, 1, 1, 2, 
      1, 3, 3, 1, 1, 2, 1, 1, 1, 5, 1, 1, 1, 1, 2, 1, 3, 3, 1, 1, 2, 1, 1, 1, 
      5, 1, 2, 1, 2, 1, 3, 3, 1, 1, 1, 1, 1, 5, 1, 2, 1, 1, 1, 2, 1, 3, 3, 1, 
      1, 1, 1, 1, 5, 1, 2, 1, 1, 1, 1, 2, 1, 3, 3, 1, 1, 1, 1, 5, 1, 2, 1, 1, 
      2, 1, 2, 1, 3, 3, 1, 1, 1, 1, 1, 2, 1, 1, 7, 1, 2, 1, 3, 1, 1, 1, 1, 2, 
      1, 1, 7, 4, 1, 2, 1, 3, 1, 1, 1, 2, 1, 1, 7, 5, 1, 2, 3, 1, 1, 1, 1, 1, 
      7, 5, 1, 1, 2, 3, 1, 1, 1, 1, 1, 7, 1, 2, 4, 1, 2, 1, 1, 1, 1, 1, 7, 1, 
      2, 4, 2, 1, 1, 2, 1, 1, 1, 1, 7, 1, 2, 2, 1, 5, 1, 2, 1, 1, 1, 7, 1, 2, 
      2, 1, 5, 1, 1, 1, 2, 1, 1, 1, 1, 2, 2, 1, 5, 1, 1, 1, 7, 1, 2, 1, 1, 1, 
      2, 2, 1, 1, 1, 1, 7, 6, 1, 2, 1, 1, 1, 2, 2, 1, 1, 1, 1, 6, 3, 4, 1, 1, 
      1, 1, 2, 2, 1, 1, 1, 1, 6, 3, 4, 1, 1, 1, 1, 1, 1, 2, 1, 1, 1, 6, 3, 4, 
      1, 1, 3, 1, 1, 1, 1, 2, 1, 1, 1, 3, 4, 1, 1, 3, 5, 1, 1, 1, 1, 2, 1, 1, 
      1, 3, 4, 1, 1, 3, 5, 1, 1, 1, 1, 1, 1, 1, 1, 1, 3, 4, 1, 3, 5, 1, 1, 1, 
      3, 1, 1, 1, 1, 1, 3, 1, 3, 5, 1, 1, 1, 3, 5, 1, 1, 1, 1, 1, 3, 1, 3, 5, 
      1, 1, 1, 3, 2, 3, 1, 1, 1, 1, 1, 3, 1, 3, 5, 1, 1, 1, 2, 3, 2, 1, 1, 1, 
      1, 1, 3, 1, 3, 1, 1, 1, 2, 3, 2, 1, 6, 1, 1, 1, 1, 3, 3, 1, 1, 1, 2, 3, 
      2, 1, 7, 1, 1, 1, 1, 3, 1, 1, 1, 2, 3, 2, 1, 7, 1, 2, 1, 1, 1, 1, 3, 1, 
      1, 1, 2, 3, 2, 7, 1, 3, 1, 1, 1, 1, 3, 1, 1, 1, 2, 2, 7, 1, 3, 3, 1, 1, 
      1, 1, 1, 3, 1, 1, 1, 2, 7, 1, 3, 1, 2, 1, 1, 1, 3, 1, 1, 1, 2, 7, 3, 1, 
      2, 2, 1, 1, 1, 3, 1, 1, 1, 7, 3, 2, 2, 3, 1, 1, 1, 1, 1, 7, 3, 2, 2, 3, 
      4, 1, 1, 1, 1, 1, 7, 3, 2, 3, 4, 1, 1, 1, 1, 1, 1, 1, 7, 3, 2, 3, 1, 1, 
      1, 3, 1, 1, 1, 1, 1, 7, 3, 3, 1, 1, 1, 3, 1, 1, 1, 1, 1, 1, 1, 3, 3, 1, 
      1, 1, 3, 1, 1, 2, 5, 1, 1, 1, 1, 3, 1, 1, 1, 3, 1, 1, 2, 5, 4, 1, 1, 1, 
      1, 3, 1, 1, 1, 1, 1, 2, 5, 5, 1, 1, 1, 1, 3, 1, 1, 1, 1, 1, 2, 5, 3, 2, 
      1, 1, 1, 1, 1, 1, 1, 1, 1, 2, 5, 3, 2, 1, 2, 1, 1, 1, 1, 1, 1, 1, 2, 5, 
      3, 2, 1, 2, 2, 1, 1, 1, 1, 1, 2, 5, 3, 2, 1, 2, 2, 2, 1, 1, 1, 1, 1, 2, 
      5, 3, 2, 1, 2, 2, 1, 1, 1, 1, 1, 1, 2, 5, 3, 2, 1, 2, 2, 1, 2, 1, 1, 1, 
      1, 2, 3, 2, 1, 2, 2, 1, 2, 3, 3, 1, 1, 1, 1, 2, 3, 1, 2, 1, 2, 3, 3, 4, 
      1, 1, 1, 1, 2, 3, 1, 2, 3, 3, 4, 3, 1, 1, 1, 3, 1, 2, 3, 3, 4, 3, 2, 1, 
      1, 1, 3, 2, 3, 3, 4, 3, 2, 1, 1, 1, 1, 1, 3, 2, 3, 3, 3, 2, 1, 1, 3, 1, 
      1, 1, 1, 3, 2, 3, 3, 2, 1, 1, 3, 1, 1, 2, 1, 1, 3, 3, 3, 2, 1, 1, 3, 1, 
      1, 2, 2, 1, 1, 3, 3, 3, 2, 1, 1, 1, 1, 2, 2, 2, 1, 1, 1, 3, 3, 3, 2, 1, 
      1, 1, 1, 2, 2, 1, 1, 1, 1, 3, 3, 3, 2, 1, 1, 1, 1, 2, 1, 1, 1, 3, 3, 3, 
      3, 2, 1, 1, 1, 2, 1, 1, 1, 3, 2, 3, 3, 2, 1, 1, 1, 2, 1, 1, 1, 2, 6, 3, 
      3, 2, 1, 1, 1, 2, 1, 2, 6, 2, 3, 3, 2, 1, 1, 1, 2, 1, 2, 2, 2, 4, 3, 3, 
      2, 1, 1, 1, 1, 2, 2, 2, 4, 1, 1, 3, 2, 1, 1, 1, 1, 2, 2, 2, 1, 1, 5, 2, 
      1, 1, 1, 2, 2, 2, 1, 1, 5, 4, 2, 1, 1, 2, 2, 2, 1, 1, 5, 4, 1, 1, 2, 1, 
      1, 2, 2, 2, 1, 1, 5, 1, 1, 3, 2, 2, 1, 1, 2, 2, 1, 1, 5, 1, 1, 2, 5, 2, 
      1, 1, 2, 1, 1, 5, 1, 1, 2, 5, 1, 1, 2, 1, 1, 2, 1, 5, 1, 1, 2, 5, 1, 2, 
      2, 1, 1, 2, 5, 1, 2, 5, 1, 2, 2, 1, 1, 2, 5, 1, 2, 5, 1, 2, 2, 1, 2, 1, 
      1, 2, 5, 2, 5, 2, 2, 1, 2, 2, 1, 1, 2, 5, 2, 2, 2, 1, 2, 2, 1, 5, 1, 2, 
      5, 2, 2, 2, 1, 2, 2, 1, 5, 1, 1, 1, 2, 5, 2, 2, 2, 1, 2, 2, 1, 1, 1, 3, 
      2, 1, 2, 5, 2, 2, 1, 2, 2, 1, 1, 3, 2, 3, 1, 2, 5, 2, 2, 1, 2, 1, 1, 3, 
      2, 3, 1, 1, 1, 2, 5, 2, 1, 2, 1, 1, 3, 3, 1, 1, 4, 1, 2, 2, 1, 2, 1, 1, 
      3, 3, 1, 1, 4, 4, 2, 1, 2, 2, 1, 2, 1, 1, 3, 3, 1, 1, 4, 2, 2, 2, 1, 2, 
      2, 1, 2, 1, 1, 3, 3, 1, 4, 2, 2, 3, 1, 2, 2, 1, 2, 1, 1, 3, 1, 4, 2, 2, 
      3, 2, 1, 1, 2, 2, 1, 2, 1, 1, 3, 4, 2, 2, 3, 2, 2, 1, 2, 2, 1, 2, 1, 3, 
      4, 2, 2, 3, 2, 3, 1, 2, 2, 1, 2, 1, 3, 4, 2, 2, 2, 3, 2, 1, 1, 2, 2, 1, 
      2, 1, 3, 4, 2, 2, 3, 2, 1, 1, 1, 1, 2, 2, 1, 1, 3, 4, 2, 2, 3, 2, 1, 1, 
      1, 2, 1, 1, 2, 2, 1, 3, 4, 2, 3, 2, 1, 1, 1, 2, 1, 3, 1, 2, 2, 1, 3, 4, 
      2, 3, 2, 1, 1, 1, 2, 1, 1, 2, 1, 2, 2, 1, 4, 2, 3, 2, 1, 1, 1, 2, 1, 1, 
      2, 2, 2, 1, 2, 2, 4, 2, 3, 2, 1, 1, 2, 1, 1, 2, 2, 2, 2, 1, 2, 2, 4, 2, 
      3, 1, 1, 2, 1, 1, 2, 2, 2, 2, 1, 1, 1, 2, 2, 4, 2, 1, 1, 2, 1, 1, 2, 2, 
      2, 2, 1, 1, 1, 2, 1, 2, 2, 2, 1, 1, 2, 1, 1, 2, 2, 2, 2, 1, 1, 1, 2, 4, 
      1, 1, 2, 2, 1, 1, 2, 1, 1, 2, 2, 2, 2, 1, 1, 1, 2, 4, 1, 2, 1, 1, 2, 2, 
      1, 1, 2, 1, 1, 2, 2, 2, 1, 1, 1, 2, 4, 1, 1, 4, 1, 2, 2, 1, 1, 2, 1, 1, 
      2, 2, 2, 1, 1, 1, 2, 4, 1, 1, 2, 2, 1, 2, 2, 1, 1, 1, 1, 2, 2, 2, 1, 1, 
      1, 2, 1, 1, 2, 2, 6, 1, 2, 2, 1, 1, 1, 1, 2, 2, 2, 1, 1, 1, 2, 1, 1, 2, 
      6, 1, 1, 1, 2, 2, 1, 1, 1, 1, 2, 2, 1, 1, 1, 2, 1, 1, 2, 6, 1, 1, 1, 2, 
      1, 2, 2, 1, 1, 1, 1, 2, 1, 1, 1, 2, 1, 2, 6, 1, 1, 1, 2, 3, 1, 2, 1, 1, 
      1, 1, 2, 1, 1, 1, 1, 2, 6, 1, 1, 1, 2, 3, 4, 1, 2, 1, 1, 1, 2, 1, 1, 1, 
      1, 2, 6, 1, 1, 1, 2, 3, 4, 1, 1, 1, 2, 1, 1, 1, 2, 1, 1, 1, 1, 2, 1, 1, 
      2, 3, 4, 1, 1, 7, 1, 2, 1, 1, 1, 1, 1, 1, 1, 2, 1, 1, 2, 3, 4, 1, 1, 7, 
      1, 1, 2, 1, 1, 1, 1, 1, 1, 1, 2, 1, 1, 2, 4, 1, 1, 7, 1, 1, 4, 2, 1, 1, 
      1, 1, 1, 1, 2, 1, 1, 2, 4, 1, 1, 7, 1, 4, 2, 2, 1, 1, 1, 1, 1, 1, 2, 1, 
      2, 4, 1, 7, 1, 4, 2, 2, 2, 1, 1, 1, 1, 1, 1, 2, 1, 2, 4, 1, 7, 1, 4, 2, 
      1, 1, 2, 1, 1, 1, 1, 1, 1, 2, 1, 2, 1, 7, 1, 4, 2, 1, 1, 4, 1, 2, 1, 1, 
      1, 1, 1, 1, 2, 1, 2, 1, 7, 1, 2, 1, 1, 4, 1, 2, 2, 2, 1, 1, 1, 1, 1, 1, 
      2, 1, 2, 7, 1, 2, 1, 1, 4, 1, 2, 2, 1, 1, 2, 1, 1, 1, 1, 1, 1, 2, 2, 7, 
      1, 2, 1, 1, 4, 1, 2, 2, 1, 2, 2, 1, 1, 1, 1, 1, 1, 2, 2, 7, 1, 1, 1, 4, 
      1, 2, 2, 1, 2, 1, 1, 2, 1, 1, 1, 1, 1, 1, 2, 2, 1, 1, 1, 4, 1, 2, 2, 1, 
      2, 1, 1, 3, 4, 2, 1, 1, 1, 1, 1, 2, 2, 1, 1, 1, 4, 1, 2, 2, 1, 2, 1, 1, 
      3, 4, 1, 1, 2, 1, 1, 1, 1, 1, 2, 2, 1, 1, 1, 2, 2, 1, 2, 1, 1, 3, 4, 1, 
      1, 5, 1, 1, 1, 1, 1, 2, 2, 1, 1, 1, 2, 2, 1, 2, 1, 1, 3, 4, 1, 1, 5, 1, 
      1, 1, 1, 1, 1, 1, 2, 2, 1, 1, 2, 2, 1, 2, 1, 3, 4, 1, 1, 5, 1, 1, 2, 1, 
      1, 1, 1, 2, 2, 1, 2, 2, 1, 2, 1, 3, 4, 1, 1, 5, 1, 1, 2, 2, 1, 1, 1, 1, 
      2, 2, 1, 1, 2, 1, 3, 4, 1, 1, 5, 1, 1, 2, 2, 4, 1, 1, 1, 1, 2, 2, 1, 1, 
      2, 1, 3, 1, 1, 5, 1, 1, 2, 2, 4, 3, 1, 1, 1, 1, 1, 2, 2, 1, 1, 2, 1, 3, 
      1, 1, 5, 1, 1, 2, 2, 3, 1, 2, 2, 1, 1, 1, 1, 2, 1, 1, 2, 1, 3, 1, 1, 5, 
      1, 1, 2, 2, 3, 1, 2, 2, 2, 1, 1, 1, 1, 1, 2, 1, 2, 1, 3, 1, 1, 5, 1, 1, 
      2, 3, 1, 2, 2, 2, 1, 3, 1, 1, 1, 1, 2, 1, 2, 3, 1, 1, 5, 1, 1, 3, 1, 2, 
      2, 2, 1, 3, 3, 1, 1, 1, 1, 2, 1, 2, 3, 1, 1, 5, 1, 1, 3, 1, 2, 2, 2, 1, 
      3, 2, 1, 1, 1, 1, 1, 2, 1, 2, 3, 1, 1, 5, 1, 1, 3, 1, 2, 2, 1, 2, 1, 5, 
      1, 1, 1, 2, 2, 3, 1, 1, 5, 1, 1, 3, 1, 2, 2, 1, 2, 1, 5, 2, 1, 1, 1, 2, 
      2, 3, 1, 1, 5, 1, 1, 3, 1, 2, 1, 2, 1, 5, 2, 1, 1, 1, 1, 2, 2, 3, 1, 1, 
      5, 1, 1, 3, 1, 2, 1, 2, 1, 5, 1, 1, 3, 1, 1, 2, 2, 3, 1, 5, 1, 3, 1, 2, 
      1, 2, 1, 5, 1, 1, 3, 2, 1, 1, 2, 3, 1, 5, 1, 3, 1, 2, 1, 1, 5, 1, 1, 3, 
      2, 4, 1, 1, 2, 3, 5, 3, 1, 2, 1, 1, 5, 1, 1, 3, 2, 4, 2, 1, 1, 2, 3, 5, 
      1, 2, 1, 1, 5, 1, 3, 2, 4, 2, 4, 1, 1, 2, 3, 5, 1, 2, 1, 1, 5, 1, 3, 2, 
      4, 2, 2, 2, 1, 1, 2, 3, 5, 1, 2, 1, 1, 1, 3, 2, 4, 2, 2, 2, 1, 4, 1, 1, 
      2, 3, 5, 1, 2, 1, 1, 1, 2, 4, 2, 2, 2, 1, 4, 2, 1, 1, 1, 2, 3, 5, 1, 1, 
      1, 2, 4, 2, 2, 2, 1, 4, 2, 1, 3, 1, 1, 2, 3, 1, 1, 1, 2, 4, 2, 2, 2, 1, 
      4, 2, 1, 3, 5, 1, 1, 2, 3, 1, 1, 1, 2, 4, 2, 2, 2, 1, 4, 1, 3, 5, 1, 3, 
      1, 2, 3, 1, 2, 4, 2, 2, 2, 1, 4, 1, 3, 5, 1, 3, 2, 1, 2, 3, 1, 2, 4, 2, 
      2, 2, 1, 1, 3, 5, 1, 3, 2, 1, 3, 1, 2, 3, 1, 2, 4, 2, 2, 2, 1, 1, 3, 1, 
      3, 2, 1, 3, 3, 3, 2, 3, 1, 2, 4, 2, 2, 2, 1, 1, 3, 1, 3, 2, 1, 3, 3, 3, 
      1, 1, 2, 3, 1, 2, 4, 2, 2, 2, 1, 1, 3, 1, 3, 2, 1, 3, 3, 1, 1, 1, 2, 2, 
      3, 1, 2, 4, 2, 2, 1, 1, 3, 1, 2, 1, 3, 3, 1, 1, 1, 2, 5, 2, 3, 1, 2, 4, 
      2, 2, 1, 1, 3, 1, 2, 3, 3, 1, 1, 1, 2, 5, 1, 1, 2, 1, 2, 4, 2, 2, 1, 1, 
      3, 1, 2, 3, 3, 1, 1, 1, 2, 5, 1, 4, 2, 1, 2, 4, 2, 2, 1, 1, 3, 1, 2, 3, 
      3, 1, 1, 1, 2, 1, 4, 4, 1, 2, 1, 2, 4, 2, 2, 1, 1, 3, 1, 2, 3, 3, 1, 1, 
      1, 2, 4, 4, 2, 2, 2, 4, 2, 2, 1, 1, 1, 2, 3, 3, 1, 1, 1, 2, 4, 4, 2, 4, 
      2, 2, 4, 2, 2, 1, 1, 1, 2, 3, 3, 1, 1, 1, 2, 4, 2, 4, 3, 1, 2, 2, 4, 2, 
      1, 1, 2, 3, 3, 1, 1, 1, 2, 4, 2, 4, 3, 1, 3, 2, 2, 4, 1, 1, 2, 3, 3, 1, 
      1, 2, 4, 2, 4, 3, 1, 3, 3, 2, 2, 4, 1, 1, 2, 3, 3, 1, 1, 2, 4, 2, 4, 3, 
      1, 3, 2, 1, 2, 2, 4, 1, 1, 2, 3, 3, 1, 1, 2, 4, 2, 3, 1, 3, 2, 1, 2, 2, 
      2, 2, 4, 1, 1, 2, 3, 3, 1, 1, 2, 4, 2, 3, 1, 3, 1, 2, 2, 1, 1, 2, 2, 4, 
      1, 1, 2, 3, 3, 1, 1, 2, 2, 3, 1, 3, 1, 2, 2, 1, 1, 3, 2, 2, 4, 1, 1, 2, 
      3, 3, 1, 2, 2, 3, 1, 3, 1, 2, 2, 1, 1, 3, 2, 3, 2, 4, 1, 1, 2, 3, 3, 1, 
      2, 2, 3, 3, 1, 2, 2, 1, 3, 2, 3, 2, 2, 4, 1, 1, 2, 3, 3, 1, 2, 2, 3, 1, 
      2, 1, 3, 2, 3, 2, 5, 2, 4, 1, 1, 2, 3, 3, 1, 2, 3, 1, 2, 1, 3, 2, 3, 5, 
      4, 2, 1, 1, 2, 3, 3, 1, 3, 1, 2, 1, 3, 2, 3, 5, 4, 6, 2, 1, 1, 2, 3, 3, 
      1, 3, 1, 2, 1, 2, 3, 4, 6, 8, 2, 1, 1, 2, 3, 3, 1, 3, 1, 2, 1, 2, 3, 4, 
      6, 6, 2, 2, 1, 1, 2, 3, 3, 1, 3, 1, 2, 1, 2, 4, 6, 6, 2, 1, 2, 2, 1, 1, 
      3, 3, 1, 3, 1, 2, 1, 2, 6, 6, 2, 1, 2, 6, 2, 1, 1, 3, 3, 1, 1, 2, 1, 2, 
      6, 2, 1, 2, 6, 8, 2, 1, 1, 3, 1, 1, 2, 1, 2, 6, 2, 1, 2, 6, 8, 2, 1, 2, 
      1, 1, 3, 1, 1, 2, 1, 2, 6, 2, 2, 6, 8, 1, 3, 2, 1, 1, 3, 1, 1, 1, 2, 6, 
      2, 6, 8, 1, 3, 4, 2, 1, 1, 3, 1, 1, 1, 2, 6, 2, 6, 8, 1, 4, 1, 2, 1, 1, 
      3, 1, 1, 1, 2, 6, 2, 8, 1, 4, 1, 2, 8, 1, 1, 3, 1, 1, 1, 2, 6, 2, 1, 4, 
      1, 2, 8, 7, 1, 1, 1, 3, 1, 1, 1, 2, 6, 2, 1, 4, 1, 8, 7, 3, 1, 1, 3, 1, 
      1, 1, 2, 6, 2, 1, 4, 1, 8, 3, 1, 7, 1, 3, 1, 1, 1, 2, 6, 2, 1, 4, 1, 8, 
      3, 1, 7, 1, 1, 1, 3, 1, 1, 1, 2, 6, 2, 1, 1, 8, 3, 1, 1, 1, 8, 1, 3, 1, 
      1, 1, 2, 2, 1, 1, 8, 1, 1, 1, 8, 9, 1, 3, 1, 1, 1, 2, 2, 1, 1, 8, 1, 1, 
      1, 8, 3, 6, 1, 3, 1, 1, 2, 2, 1, 1, 8, 1, 1, 1, 3, 6, 9, 1, 3, 1, 1, 2, 
      2, 1, 1, 1, 1, 1, 3, 6, 9, 4, 5, 1, 3, 1, 1, 2, 2, 1, 1, 1, 1, 1, 3, 9, 
      4, 5, 5, 1, 1, 3, 1, 1, 2, 2, 1, 1, 1, 1, 1, 9, 4, 5, 1, 8, 1, 3, 1, 1, 
      2, 2, 1, 1, 1, 1, 9, 4, 1, 8, 6, 1, 3, 1, 1, 2, 2, 1, 1, 1, 1, 9, 1, 8, 
      6, 1, 3, 1, 3, 1, 1, 2, 2, 1, 1, 1, 1, 1, 8, 6, 1, 3, 7, 2, 1, 3, 1, 1, 
      2, 1, 1, 1, 1, 1, 8, 6, 1, 7, 2, 5, 1, 3, 1, 1, 2, 1, 1, 1, 1, 1, 8, 6, 
      1, 2, 5, 1, 6, 1, 3, 1, 1, 2, 1, 1, 1, 1, 1, 6, 1, 2, 5, 1, 6, 7, 1, 1, 
      3, 1, 1, 2, 1, 1, 1, 1, 1, 6, 1, 2, 5, 1, 6, 1, 4, 3, 1, 3, 1, 1, 2, 1, 
      1, 1, 1, 1, 6, 1, 2, 5, 1, 6, 1, 3, 3, 1, 1, 3, 1, 1, 2, 1, 1, 1, 1, 6, 
      1, 5, 1, 6, 1, 3, 3, 1, 3, 1, 3, 1, 1, 2, 1, 1, 1, 1, 6, 1, 5, 1, 6, 1, 
      3, 3, 1, 1, 2, 1, 3, 1, 1, 2, 1, 1, 1, 6, 1, 5, 1, 6, 1, 3, 1, 1, 2, 3, 
      1, 3, 1, 1, 2, 1, 1, 1, 1, 5, 1, 6, 1, 3, 1, 1, 2, 9, 1, 3, 1, 1, 2, 1, 
      1, 1, 1, 5, 1, 1, 3, 1, 1, 2, 9, 3, 4, 1, 3, 1, 1, 2, 1, 1, 1, 1, 1, 1, 
      3, 1, 1, 2, 9, 3, 4, 1, 4, 1, 3, 1, 1, 2, 1, 1, 1, 1, 1, 3, 1, 1, 9, 3, 
      4, 1, 4, 3, 1, 3, 1, 1, 2, 1, 1, 1, 1, 1, 3, 1, 1, 3, 4, 1, 4, 3, 8, 1, 
      1, 3, 1, 2, 1, 1, 1, 1, 1, 3, 1, 1, 3, 4, 1, 4, 3, 8, 1, 1, 1, 1, 1, 2, 
      1, 1, 1, 1, 1, 3, 1, 1, 3, 4, 1, 4, 3, 1, 1, 1, 9, 1, 1, 2, 1, 1, 1, 1, 
      1, 3, 1, 3, 4, 1, 4, 3, 1, 1, 1, 9, 1, 1, 1, 2, 1, 1, 1, 1, 3, 1, 3, 4, 
      1, 4, 3, 1, 1, 1, 9, 1, 1, 2, 1, 2, 1, 1, 1, 1, 3, 1, 3, 4, 1, 3, 1, 1, 
      1, 9, 1, 1, 2, 2, 2, 2, 1, 1, 1, 3, 1, 3, 4, 1, 3, 1, 1, 1, 9, 1, 1, 2, 
      2, 2, 2, 2, 1, 1, 1, 3, 1, 3, 4, 1, 3, 1, 9, 1, 1, 2, 2, 2, 2, 2, 2, 1, 
      1, 1, 1, 3, 4, 1, 3, 1, 9, 1, 1, 2, 2, 2, 2, 2, 2, 2, 2, 1, 1, 1, 1, 3, 
      4, 1, 3, 1, 9, 1, 2, 2, 2, 2, 2, 2, 3, 2, 1, 1, 1, 1, 3, 4, 1, 3, 1, 1, 
      2, 2, 2, 2, 2, 2, 3, 2, 8, 2, 1, 1, 1, 1, 3, 4, 1, 1, 1, 2, 2, 2, 2, 2, 
      2, 3, 2, 8, 1, 2, 2, 1, 1, 1, 1, 3, 4, 1, 1, 1, 2, 2, 2, 2, 2, 3, 2, 8, 
      1, 4, 2, 1, 1, 1, 3, 4, 1, 1, 1, 2, 2, 2, 2, 3, 2, 8, 1, 4, 3, 1, 1, 1, 
      3, 4, 1, 1, 1, 2, 2, 2, 3, 2, 8, 1, 4, 3, 4, 1, 1, 1, 3, 4, 1, 1, 1, 2, 
      3, 2, 8, 1, 4, 3, 4, 4, 1, 1, 1, 3, 4, 1, 1, 1, 2, 2, 8, 1, 4, 3, 4, 4, 
      1, 2, 1, 1, 1, 3, 4, 1, 1, 2, 2, 8, 1, 4, 3, 4, 1, 2, 4, 1, 1, 1, 3, 4, 
      1, 2, 2, 8, 1, 4, 3, 4, 1, 2, 4, 1, 1, 1, 1, 1, 3, 4, 1, 2, 2, 8, 1, 4, 
      3, 4, 1, 2, 1, 1, 1, 3, 1, 1, 1, 3, 4, 1, 2, 2, 8, 1, 4, 4, 1, 2, 1, 1, 
      1, 3, 2, 2, 1, 1, 1, 3, 4, 1, 2, 2, 8, 1, 4, 1, 2, 1, 1, 1, 3, 2, 2, 1, 
      3, 1, 1, 1, 3, 1, 2, 2, 8, 1, 4, 1, 2, 1, 1, 1, 3, 2, 2, 3, 5, 1, 1, 1, 
      3, 1, 2, 2, 8, 1, 4, 2, 1, 1, 1, 3, 2, 2, 3, 5, 1, 1, 1, 1, 1, 3, 1, 2, 
      8, 1, 4, 2, 1, 1, 1, 3, 2, 2, 3, 1, 1, 6, 1, 1, 1, 3, 1, 2, 8, 1, 4, 2, 
      1, 1, 1, 3, 2, 2, 3, 1, 1, 3, 4, 1, 1, 1, 3, 1, 8, 1, 4, 2, 1, 1, 1, 3, 
      2, 3, 1, 1, 3, 4, 4, 1, 1, 1, 3, 1, 8, 1, 4, 2, 1, 1, 3, 2, 3, 1, 1, 3, 
      4, 5, 1, 1, 1, 3, 1, 8, 1, 2, 1, 1, 3, 2, 1, 1, 3, 4, 5, 5, 1, 1, 1, 3, 
      1, 8, 1, 2, 1, 1, 3, 2, 1, 1, 4, 5, 5, 1, 2, 1, 1, 1, 3, 1, 8, 1, 1, 1, 
      3, 2, 1, 1, 4, 5, 5, 1, 2, 1, 1, 1, 1, 1, 3, 1, 1, 1, 1, 3, 2, 1, 1, 4, 
      5, 5, 1, 2, 1, 1, 7, 2, 1, 1, 1, 3, 1, 1, 1, 1, 3, 2, 1, 1, 4, 5, 5, 1, 
      2, 1, 1, 2, 5, 3, 1, 1, 1, 3, 1, 1, 3, 2, 1, 1, 4, 5, 5, 1, 2, 1, 1, 2, 
      5, 3, 2, 1, 1, 1, 3, 1, 1, 3, 2, 1, 1, 4, 5, 5, 1, 2, 1, 1, 2, 5, 3, 1, 
      1, 1, 1, 1, 3, 1, 3, 2, 1, 1, 4, 5, 5, 2, 1, 1, 2, 5, 3, 1, 1, 2, 1, 1, 
      1, 3, 3, 2, 1, 1, 4, 5, 5, 2, 1, 2, 5, 3, 1, 1, 2, 2, 1, 1, 1, 3, 3, 2, 
      1, 1, 4, 5, 2, 1, 2, 5, 3, 1, 1, 2, 2, 4, 1, 1, 1, 1, 3, 3, 2, 1, 1, 4, 
      5, 2, 1, 2, 5, 3, 1, 1, 2, 2, 1, 3, 1, 1, 1, 1, 3, 3, 2, 1, 1, 4, 5, 2, 
      1, 2, 3, 1, 1, 2, 2, 1, 3, 1, 2, 3, 1, 1, 1, 3, 3, 2, 1, 1, 4, 2, 1, 3, 
      1, 1, 2, 2, 1, 3, 1, 2, 3, 4, 1, 1, 1, 3, 3, 2, 1, 1, 4, 2, 1, 3, 1, 1, 
      2, 2, 1, 3, 2, 3, 4, 1, 1, 1, 1, 1, 3, 3, 2, 1, 1, 4, 3, 1, 1, 2, 2, 1, 
      3, 2, 3, 4, 1, 1, 3, 1, 1, 1, 3, 3, 2, 1, 1, 4, 3, 1, 2, 1, 3, 4, 1, 1, 
      3, 3, 3, 1, 1, 1, 3, 3, 2, 1, 1, 4, 3, 1, 2, 1, 3, 4, 1, 1, 3, 3, 3, 1, 
      1, 1, 3, 3, 2, 1, 1, 4, 3, 1, 2, 3, 4, 1, 1, 3, 3, 3, 1, 1, 1, 1, 1, 3, 
      2, 1, 1, 4, 3, 1, 2, 3, 4, 1, 3, 3, 3, 1, 1, 4, 1, 1, 1, 3, 2, 1, 1, 4, 
      3, 1, 2, 4, 1, 3, 3, 1, 1, 4, 6, 1, 1, 3, 2, 1, 1, 4, 1, 2, 4, 1, 3, 3, 
      1, 1, 4, 6, 4, 1, 1, 3, 2, 1, 1, 4, 2, 4, 1, 3, 3, 1, 4, 6, 4, 2, 1, 2, 
      1, 1, 4, 2, 4, 1, 3, 3, 1, 4, 6, 4, 2, 4, 2, 1, 1, 4, 2, 4, 1, 3, 1, 4, 
      6, 4, 2, 4, 4, 2, 1, 1, 4, 2, 1, 3, 1, 4, 6, 4, 2, 4, 4, 3, 1, 2, 1, 1, 
      4, 2, 1, 3, 1, 4, 6, 4, 4, 4, 3, 1, 2, 1, 2, 1, 4, 2, 1, 3, 4, 6, 4, 4, 
      4, 3, 1, 2, 1, 2, 2, 1, 4, 2, 1, 3, 4, 6, 4, 4, 4, 3, 1, 2, 1, 1, 1, 2, 
      1, 4, 2, 1, 3, 4, 6, 4, 4, 3, 1, 2, 1, 1, 1, 2, 3, 2, 1, 4, 2, 1, 3, 4, 
      6, 4, 4, 3, 2, 1, 1, 2, 3, 2, 2, 1, 4, 2, 1, 3, 4, 6, 4, 4, 2, 1, 1, 2, 
      3, 2, 3, 1, 2, 1, 4, 2, 3, 4, 6, 4, 4, 2, 1, 2, 3, 2, 3, 1, 2, 2, 1, 4, 
      2, 3, 4, 6, 4, 4, 1, 2, 3, 3, 1, 2, 4, 2, 1, 4, 2, 3, 4, 6, 4, 2, 3, 3, 
      1, 2, 4, 5, 2, 1, 4, 2, 3, 4, 6, 4, 2, 3, 3, 1, 2, 5, 2, 2, 2, 1, 4, 2, 
      3, 6, 4, 2, 3, 3, 1, 2, 5, 2, 2, 2, 2, 2, 1, 4, 2, 3, 4, 2, 3, 3, 1, 2, 
      5, 2, 2, 2, 2, 3, 3, 2, 1, 2, 3, 4, 2, 3, 3, 1, 5, 2, 2, 2, 2, 3, 3, 5, 
      2, 1, 2, 3, 4, 2, 3, 3, 5, 2, 2, 2, 3, 3, 5, 3, 2, 1, 2, 3, 4, 2, 3, 3, 
      2, 2, 3, 3, 5, 3, 6, 2, 1, 3, 4, 2, 3, 3, 2, 2, 3, 3, 3, 6, 7, 2, 1, 3, 
      4, 3, 3, 2, 2, 3, 3, 6, 7, 5, 2, 1, 3, 4, 3, 3, 2, 2, 3, 3, 6, 7, 4, 1, 
      2, 1, 3, 4, 3, 3, 2, 2, 3, 3, 7, 4, 1, 1, 5, 2, 1, 3, 4, 3, 3, 2, 2, 3, 
      3, 7, 1, 1, 5, 4, 1, 2, 1, 3, 4, 3, 3, 2, 3, 7, 1, 1, 5, 4, 1, 5, 2, 1, 
      3, 4, 3, 3, 2, 3, 7, 1, 1, 5, 1, 5, 2, 1, 3, 4, 3, 3, 2, 3, 1, 1, 5, 1, 
      5, 4, 3, 2, 1, 3, 3, 3, 2, 3, 1, 1, 5, 1, 5, 4, 3, 3, 2, 2, 1, 3, 3, 3, 
      3, 1, 1, 5, 1, 5, 4, 3, 3, 4, 2, 1, 3, 3, 3, 3, 1, 1, 5, 1, 5, 3, 3, 4, 
      1, 3, 2, 1, 3, 3, 3, 3, 1, 1, 5, 1, 5, 3, 3, 4, 1, 1, 3, 2, 1, 3, 3, 3, 
      3, 1, 1, 5, 1, 5, 3, 4, 1, 1, 3, 2, 1, 2, 1, 3, 3, 3, 3, 1, 1, 1, 5, 3, 
      4, 1, 1, 3, 2, 1, 4, 1, 2, 1, 3, 3, 3, 3, 1, 1, 1, 5, 3, 1, 1, 3, 2, 1, 
      4, 1, 2, 2, 1, 3, 3, 3, 3, 1, 1, 1, 5, 3, 1, 1, 3, 2, 1, 4, 2, 2, 3, 1, 
      3, 3, 3, 1, 1, 1, 5, 3, 1, 3, 2, 1, 4, 2, 2, 3, 4, 1, 3, 3, 1, 1, 1, 5, 
      3, 1, 3, 2, 1, 4, 2, 2, 3, 4, 2, 1, 1, 3, 3, 1, 1, 1, 5, 3, 1, 3, 2, 1, 
      4, 2, 2, 3, 2, 1, 1, 3, 1, 3, 3, 1, 1, 1, 3, 1, 3, 2, 1, 4, 2, 2, 3, 2, 
      1, 1, 3, 4, 1, 1, 3, 3, 1, 1, 1, 3, 1, 3, 2, 1, 2, 2, 3, 2, 1, 1, 3, 4, 
      1, 1, 4, 1, 3, 3, 1, 1, 1, 3, 1, 3, 2, 3, 2, 1, 1, 3, 1, 1, 4, 6, 3, 1, 
      3, 3, 1, 1, 1, 3, 1, 3, 2, 3, 2, 1, 1, 3, 1, 1, 4, 6, 3, 1, 3, 3, 1, 1, 
      1, 3, 1, 3, 2, 3, 2, 1, 1, 3, 1, 4, 6, 3, 1, 1, 1, 3, 3, 1, 1, 1, 3, 1, 
      3, 2, 3, 2, 1, 1, 3, 1, 4, 1, 1, 9, 1, 3, 3, 1, 1, 1, 3, 1, 3, 2, 3, 2, 
      1, 1, 3, 1, 4, 1, 1, 3, 7, 1, 3, 3, 1, 1, 1, 3, 3, 2, 3, 1, 1, 3, 1, 4, 
      1, 1, 3, 7, 3, 1, 3, 1, 1, 1, 3, 3, 2, 3, 1, 1, 3, 1, 4, 1, 1, 3, 7, 3, 
      1, 2, 1, 3, 1, 1, 1, 3, 2, 3, 1, 3, 1, 4, 1, 1, 3, 7, 3, 1, 2, 4, 1, 3, 
      1, 1, 1, 3, 2, 3, 1, 3, 1, 4, 1, 1, 3, 3, 1, 2, 4, 4, 3, 1, 3, 1, 1, 1, 
      3, 2, 3, 1, 3, 1, 4, 1, 1, 3, 1, 2, 4, 3, 6, 1, 3, 1, 1, 1, 3, 2, 3, 1, 
      3, 1, 4, 1, 1, 3, 1, 2, 4, 3, 4, 3, 1, 3, 1, 1, 3, 2, 3, 1, 3, 1, 4, 1, 
      3, 1, 2, 4, 3, 4, 3, 2, 1, 3, 1, 1, 3, 2, 3, 3, 1, 4, 1, 3, 2, 4, 3, 4, 
      3, 2, 2, 1, 1, 1, 3, 2, 3, 3, 1, 4, 1, 2, 4, 3, 4, 3, 2, 2, 5, 1, 1, 1, 
      2, 3, 3, 1, 4, 1, 2, 4, 3, 4, 3, 2, 2, 5, 1, 2, 1, 1, 1, 2, 3, 3, 1, 4, 
      1, 2, 4, 3, 4, 3, 2, 2, 1, 2, 3, 2, 1, 2, 3, 3, 1, 4, 1, 2, 4, 3, 4, 3, 
      2, 2, 1, 2, 3, 2, 2, 1, 2, 3, 3, 1, 4, 1, 2, 4, 3, 4, 2, 2, 1, 2, 3, 2, 
      2, 1, 3, 1, 3, 3, 1, 4, 1, 2, 4, 3, 4, 2, 2, 1, 2, 2, 2, 1, 3, 5, 1, 3, 
      3, 1, 4, 1, 2, 4, 3, 4, 2, 2, 1, 2, 2, 1, 3, 5, 1, 1, 3, 3, 1, 4, 1, 2, 
      4, 4, 2, 2, 1, 2, 2, 1, 3, 5, 1, 1, 4, 3, 1, 4, 1, 2, 4, 4, 2, 2, 1, 2, 
      2, 1, 3, 5, 1, 1, 4, 1, 2, 3, 1, 4, 1, 2, 4, 2, 2, 1, 2, 2, 1, 3, 5, 1, 
      1, 4, 1, 2, 3, 1, 3, 1, 4, 1, 2, 4, 2, 2, 1, 2, 2, 5, 1, 1, 4, 1, 2, 3, 
      1, 3, 3, 1, 4, 1, 2, 4, 2, 2, 1, 2, 2, 5, 1, 1, 4, 1, 3, 1, 3, 1, 1, 3, 
      1, 4, 1, 2, 4, 2, 2, 1, 2, 2, 1, 1, 4, 1, 3, 1, 3, 1, 1, 3, 2, 3, 1, 4, 
      1, 2, 4, 2, 2, 1, 2, 1, 1, 4, 1, 3, 1, 3, 1, 1, 3, 2, 1, 1, 3, 1, 1, 2, 
      4, 2, 2, 1, 2, 1, 1, 4, 1, 3, 1, 1, 1, 3, 2, 1, 1, 7, 3, 1, 1, 2, 4, 2, 
      2, 1, 1, 1, 4, 1, 3, 1, 1, 1, 3, 2, 1, 1, 7, 1, 1, 3, 1, 2, 4, 2, 2, 1, 
      1, 1, 4, 1, 3, 1, 1, 1, 3, 2, 1, 7, 1, 1, 2, 3, 1, 4, 2, 2, 1, 1, 1, 4, 
      1, 3, 1, 1, 1, 3, 1, 7, 1, 1, 2, 4, 3, 1, 4, 2, 2, 1, 1, 1, 4, 1, 3, 1, 
      1, 1, 1, 7, 1, 1, 2, 4, 3, 1, 3, 1, 4, 2, 2, 1, 1, 1, 4, 3, 1, 1, 1, 1, 
      7, 1, 2, 4, 3, 1, 2, 3, 1, 4, 2, 2, 1, 1, 1, 1, 1, 1, 1, 7, 1, 2, 4, 3, 
      1, 2, 6, 3, 1, 4, 2, 2, 1, 1, 1, 1, 1, 1, 1, 7, 1, 2, 4, 3, 1, 2, 1, 5, 
      3, 1, 4, 2, 2, 1, 1, 1, 1, 1, 1, 1, 1, 2, 4, 3, 1, 2, 1, 5, 6, 1, 3, 1, 
      4, 2, 2, 1, 1, 1, 1, 1, 1, 1, 2, 4, 3, 2, 1, 5, 6, 1, 2, 3, 1, 4, 2, 2, 
      1, 1, 1, 1, 1, 1, 1, 4, 3, 2, 1, 5, 6, 1, 2, 1, 1, 1, 4, 2, 2, 1, 1, 1, 
      1, 1, 1, 1, 4, 3, 2, 1, 5, 6, 1, 2, 1, 1, 2, 1, 1, 4, 2, 2, 1, 1, 1, 1, 
      1, 1, 4, 3, 2, 1, 5, 6, 1, 2, 1, 1, 1, 3, 1, 4, 2, 2, 1, 1, 1, 1, 1, 1, 
      4, 3, 2, 1, 5, 6, 1, 1, 1, 3, 3, 1, 4, 2, 2, 1, 1, 1, 1, 1, 4, 3, 1, 5, 
      6, 1, 1, 1, 3, 3, 3, 4, 2, 2, 1, 1, 1, 1, 4, 3, 1, 5, 6, 1, 1, 1, 3, 3, 
      3, 2, 4, 2, 1, 1, 1, 1, 4, 3, 1, 5, 6, 1, 1, 3, 3, 3, 2, 3, 4, 2, 1, 1, 
      1, 1, 4, 3, 1, 5, 1, 1, 3, 3, 2, 3, 9, 4, 1, 1, 1, 1, 4, 3, 1, 5, 1, 1, 
      3, 3, 2, 3, 9, 1, 1, 4, 1, 1, 1, 1, 4, 3, 1, 5, 1, 1, 3, 3, 2, 9, 1, 1, 
      2, 1, 4, 1, 1, 1, 1, 4, 3, 1, 1, 1, 3, 3, 2, 9, 1, 1, 2, 1, 1, 4, 4, 1, 
      1, 1, 1, 4, 3, 1, 1, 1, 3, 3, 9, 1, 1, 2, 1, 1, 4, 1, 2, 4, 1, 1, 1, 1, 
      4, 3, 1, 1, 1, 3, 9, 1, 1, 2, 1, 4, 1, 2, 3, 4, 1, 1, 1, 1, 4, 3, 1, 1, 
      1, 3, 1, 1, 2, 1, 4, 1, 2, 3, 4, 5, 4, 1, 1, 1, 1, 4, 3, 1, 1, 1, 3, 1, 
      1, 1, 4, 1, 2, 3, 4, 5, 1, 1, 4, 1, 1, 1, 1, 4, 3, 1, 1, 1, 3, 1, 1, 1, 
      4, 1, 2, 3, 4, 1, 1, 2, 3, 4, 1, 1, 1, 4, 3, 1, 1, 3, 1, 1, 1, 4, 1, 2, 
      3, 4, 1, 1, 2, 3, 2, 4, 1, 1, 1, 4, 3, 1, 1, 1, 1, 4, 1, 2, 3, 4, 1, 1, 
      2, 3, 2, 4, 4, 1, 1, 1, 4, 3, 1, 1, 1, 1, 4, 1, 2, 3, 4, 1, 2, 3, 2, 4, 
      1, 1, 4, 1, 1, 1, 4, 3, 1, 1, 1, 1, 4, 1, 2, 3, 4, 1, 2, 2, 4, 1, 4, 1, 
      1, 1, 4, 1, 1, 1, 1, 4, 1, 2, 3, 4, 1, 2, 2, 4, 1, 4, 7, 1, 1, 1, 4, 1, 
      1, 1, 1, 4, 1, 2, 3, 4, 1, 2, 2, 4, 1, 7, 1, 4, 1, 1, 1, 4, 1, 1, 1, 4, 
      1, 2, 3, 4, 1, 2, 2, 4, 1, 7, 1, 4, 1, 1, 1, 1, 1, 4, 1, 1, 4, 1, 2, 4, 
      1, 2, 2, 4, 1, 7, 1, 4, 1, 1, 4, 1, 1, 1, 4, 1, 4, 1, 2, 4, 1, 2, 2, 1, 
      7, 1, 4, 1, 1, 4, 4, 1, 1, 1, 4, 1, 4, 1, 2, 4, 1, 2, 2, 1, 7, 1, 4, 1, 
      1, 4, 2, 2, 1, 1, 1, 4, 4, 1, 2, 4, 1, 2, 1, 7, 1, 4, 1, 1, 4, 2, 2, 3, 
      1, 1, 1, 4, 4, 1, 2, 4, 1, 2, 1, 7, 1, 4, 1, 4, 2, 2, 4, 1, 1, 4, 4, 1, 
      2, 4, 1, 1, 7, 1, 4, 1, 4, 2, 2, 4, 3, 1, 1, 4, 1, 2, 4, 1, 1, 7, 4, 1, 
      4, 2, 2, 4, 3, 5, 1, 1, 4, 1, 2, 4, 1, 7, 4, 1, 4, 2, 4, 3, 5, 3, 1, 1, 
      4, 1, 2, 4, 1, 7, 4, 1, 2, 3, 5, 3, 6, 1, 1, 4, 1, 2, 1, 7, 4, 1, 2, 3, 
      5, 3, 6, 1, 4, 1, 1, 4, 1, 1, 7, 4, 1, 2, 3, 3, 6, 1, 4, 7, 1, 1, 4, 1, 
      1, 7, 4, 1, 2, 3, 3, 6, 1, 4, 4, 3, 1, 4, 1, 1, 7, 4, 1, 2, 3, 6, 1, 4, 
      4, 3, 4, 1, 4, 1, 1, 7, 4, 1, 2, 3, 6, 1, 4, 3, 4, 2, 3, 1, 4, 1, 1, 4, 
      1, 2, 3, 6, 1, 4, 3, 4, 2, 3, 2, 6, 1, 1, 1, 4, 1, 2, 3, 6, 4, 3, 4, 2, 
      3, 2, 6, 5, 1, 1, 4, 2, 3, 6, 4, 3, 4, 2, 3, 2, 6, 5, 2, 1, 4, 2, 3, 6, 
      4, 3, 4, 3, 2, 6, 5, 2, 3, 1, 4, 2, 3, 6, 4, 4, 3, 2, 6, 5, 2, 3, 2, 1, 
      1, 2, 3, 6, 4, 4, 3, 2, 6, 2, 3, 2, 1, 8, 1, 2, 3, 6, 4, 3, 2, 6, 2, 3, 
      2, 1, 8, 1, 3, 1, 2, 3, 4, 3, 2, 6, 2, 3, 2, 1, 8, 1, 3, 5, 1, 1, 2, 3, 
      4, 3, 6, 2, 3, 1, 8, 1, 3, 5, 1, 4, 1, 2, 3, 4, 3, 6, 2, 3, 1, 8, 1, 3, 
      5, 1, 2, 3, 1, 2, 3, 4, 3, 6, 2, 3, 8, 1, 3, 5, 1, 2, 3, 1, 1, 1, 3, 4, 
      3, 6, 2, 3, 8, 1, 3, 5, 1, 2, 3, 1, 3, 1, 3, 4, 3, 6, 2, 3, 1, 3, 5, 2, 
      3, 1, 3, 8, 1, 3, 4, 6, 2, 3, 1, 3, 5, 2, 3, 1, 3, 8, 2, 2, 3, 4, 6, 3, 
      1, 3, 5, 2, 3, 1, 3, 8, 2, 2, 3, 3, 4, 6, 3, 1, 3, 5, 2, 1, 3, 8, 2, 2, 
      3, 1, 2, 3, 4, 6, 3, 1, 3, 5, 2, 3, 8, 2, 2, 3, 1, 3, 3, 4, 6, 3, 1, 3, 
      5, 2, 8, 2, 2, 3, 1, 3, 2, 1, 3, 4, 6, 3, 1, 3, 2, 8, 2, 2, 3, 1, 3, 2, 
      1, 2, 3, 3, 4, 6, 3, 1, 3, 8, 2, 3, 1, 3, 2, 1, 2, 3, 4, 4, 6, 3, 1, 3, 
      8, 2, 3, 1, 3, 2, 1, 2, 3, 4, 1, 2, 4, 6, 3, 1, 8, 2, 3, 1, 3, 2, 1, 2, 
      3, 4, 1, 2, 2, 1, 4, 6, 3, 1, 8, 2, 3, 1, 2, 1, 2, 3, 4, 1, 2, 1, 4, 4, 
      6, 1, 8, 2, 3, 1, 2, 1, 2, 3, 4, 1, 2, 1, 7, 4, 6, 1, 2, 3, 1, 2, 1, 2, 
      3, 4, 1, 2, 1, 7, 2, 6, 4, 6, 1, 2, 3, 1, 2, 1, 2, 3, 1, 2, 1, 7, 2, 6, 
      2, 2, 4, 6, 1, 3, 1, 1, 2, 3, 1, 2, 1, 7, 2, 6, 2, 2, 4, 4, 6, 1, 3, 1, 
      1, 2, 3, 1, 2, 1, 2, 6, 2, 2, 4, 2, 5, 4, 1, 3, 1, 1, 2, 1, 2, 1, 2, 6, 
      2, 2, 4, 2, 5, 9, 4, 1, 3, 1, 1, 2, 1, 2, 1, 2, 2, 2, 4, 2, 5, 9, 6, 1, 
      4, 1, 1, 1, 2, 1, 2, 1, 2, 2, 4, 2, 5, 9, 6, 1, 5, 4, 1, 1, 1, 2, 1, 2, 
      2, 2, 4, 2, 5, 9, 6, 1, 6, 4, 1, 1, 1, 2, 1, 2, 2, 2, 4, 5, 9, 6, 1, 6, 
      2, 1, 4, 1, 2, 1, 2, 2, 2, 4, 5, 9, 6, 1, 6, 2, 1, 2, 4, 1, 2, 1, 2, 2, 
      4, 5, 6, 1, 6, 2, 1, 2, 11, 4, 1, 2, 1, 2, 2, 5, 6, 1, 6, 2, 1, 2, 11, 
      3, 2, 4, 1, 2, 1, 2, 2, 5, 6, 1, 6, 2, 1, 11, 3, 2, 1, 1, 4, 1, 2, 1, 
      2, 2, 5, 6, 1, 2, 1, 11, 3, 2, 1, 1, 3, 3, 4, 1, 2, 1, 2, 5, 1, 2, 1, 
      11, 3, 2, 1, 1, 3, 3, 8, 4, 1, 2, 1, 2, 1, 2, 1, 11, 3, 2, 1, 1, 3, 3, 
      8, 5, 1, 4, 1, 2, 1, 2, 1, 2, 1, 11, 3, 1, 1, 3, 3, 8, 1, 7, 4, 1, 2, 
      1, 2, 1, 2, 1, 11, 3, 1, 1, 3, 8, 1, 7, 1, 2, 4, 1, 2, 1, 2, 1, 2, 1, 
      11, 3, 1, 8, 1, 7, 1, 2, 3, 4, 1, 2, 2, 1, 2, 1, 11, 3, 1, 1, 7, 1, 2, 
      3, 9, 4, 1, 2, 2, 1, 2, 1, 11, 1, 1, 7, 1, 2, 3, 9, 2, 1, 4, 1, 2, 2, 
      1, 2, 1, 1, 1, 7, 1, 9, 2, 1, 5, 8, 4, 4, 1, 2, 2, 1, 2, 1, 1, 1, 7, 1, 
      9, 2, 1, 5, 8, 4, 4, 1, 2, 2, 1, 2, 1, 1, 1, 7, 1, 9, 2, 1, 5, 11, 4, 
      1, 2, 2, 1, 2, 1, 1, 1, 7, 1, 9, 2, 1, 11, 4, 1, 4, 1, 2, 2, 1, 2, 1, 
      1, 1, 7, 1, 9, 2, 1, 4, 1, 10, 2, 4, 1, 2, 1, 2, 1, 1, 1, 7, 1, 9, 2, 
      1, 4, 1, 2, 12, 4, 1, 2, 1, 2, 1, 1, 1, 7, 1, 9, 2, 4, 2, 12, 2, 4, 1, 
      2, 1, 2, 1, 1, 1, 7, 1, 2, 4, 2, 12, 2, 5, 5, 1, 2, 1, 2, 1, 1, 1, 7, 
      1, 2, 4, 2, 12, 2, 5, 5, 2, 3, 1, 2, 1, 2, 1, 1, 1, 7, 1, 2, 4, 2, 2, 
      5, 5, 2, 3, 8, 4, 1, 2, 1, 2, 1, 1, 1, 7, 1, 4, 2, 5, 5, 2, 3, 8, 4, 4, 
      1, 2, 1, 2, 1, 1, 1, 1, 4, 2, 5, 5, 2, 3, 8, 4, 4, 2, 5, 1, 2, 1, 2, 1, 
      1, 1, 4, 2, 5, 5, 2, 3, 8, 4, 4, 2, 5, 1, 1, 1, 2, 1, 2, 1, 1, 4, 2, 5, 
      5, 2, 3, 8, 4, 2, 5, 1, 1, 5, 1, 2, 2, 1, 4, 2, 5, 5, 2, 3, 8, 4, 2, 5, 
      1, 1, 5, 2, 1, 2, 2, 1, 2, 5, 5, 2, 3, 8, 4, 5, 1, 1, 5, 2, 6, 1, 2, 2, 
      1, 2, 5, 5, 2, 3, 8, 4, 5, 1, 1, 5, 2, 3, 3, 1, 2, 2, 1, 2, 5, 5, 2, 3, 
      8, 5, 1, 1, 5, 2, 3, 3, 4, 1, 1, 2, 2, 1, 2, 5, 5, 2, 8, 5, 1, 1, 5, 2, 
      3, 3, 4, 4, 1, 2, 2, 1, 5, 5, 2, 8, 1, 1, 5, 2, 3, 3, 4, 4, 7, 1, 2, 2, 
      1, 5, 2, 8, 1, 1, 5, 2, 3, 3, 4, 4, 7, 3, 2, 1, 2, 2, 1, 2, 8, 1, 1, 5, 
      2, 3, 3, 4, 4, 7, 3, 2, 3, 2, 1, 2, 2, 1, 2, 8, 1, 5, 2, 3, 4, 4, 7, 3, 
      2, 3, 2, 4, 1, 2, 2, 1, 2, 8, 1, 5, 2, 3, 4, 7, 3, 2, 3, 2, 4, 4, 1, 1, 
      2, 2, 1, 2, 8, 1, 5, 2, 3, 4, 7, 2, 3, 2, 4, 4, 1, 2, 1, 1, 2, 2, 1, 2, 
      8, 1, 5, 2, 3, 7, 2, 3, 4, 4, 1, 2, 1, 6, 1, 2, 2, 1, 2, 8, 1, 5, 2, 3, 
      2, 4, 4, 1, 2, 1, 6, 7, 1, 2, 2, 1, 2, 8, 1, 5, 2, 3, 2, 4, 4, 1, 2, 1, 
      9, 1, 2, 2, 1, 2, 8, 1, 5, 2, 3, 2, 4, 1, 2, 1, 9, 1, 3, 1, 2, 2, 1, 2, 
      8, 1, 5, 2, 3, 2, 4, 1, 2, 1, 1, 3, 5, 5, 1, 2, 2, 1, 2, 8, 1, 5, 2, 3, 
      2, 1, 2, 1, 1, 3, 5, 5, 3, 1, 2, 1, 2, 8, 1, 5, 2, 3, 2, 1, 2, 1, 1, 3, 
      5, 5, 3, 1, 3, 2, 1, 2, 8, 1, 5, 2, 3, 2, 1, 2, 1, 5, 5, 3, 1, 3, 3, 2, 
      1, 2, 8, 1, 5, 2, 3, 2, 1, 2, 5, 3, 1, 3, 3, 6, 2, 1, 2, 8, 1, 5, 2, 3, 
      2, 1, 2, 5, 3, 3, 3, 6, 2, 1, 2, 8, 1, 5, 2, 3, 2, 1, 2, 5, 3, 6, 6, 2, 
      1, 2, 8, 1, 5, 3, 2, 1, 5, 3, 6, 6, 4, 2, 1, 2, 8, 1, 5, 3, 2, 1, 5, 3, 
      6, 4, 1, 5, 2, 1, 2, 8, 1, 5, 3, 2, 1, 5, 3, 4, 5, 5, 2, 1, 8, 1, 5, 3, 
      2, 1, 5, 4, 5, 5, 4, 2, 1, 8, 1, 3, 2, 1, 5, 4, 5, 5, 4, 2, 3, 2, 1, 8, 
      1, 3, 2, 1, 5, 5, 5, 4, 2, 3, 2, 2, 1, 8, 1, 3, 2, 1, 5, 5, 4, 2, 3, 2, 
      2, 7, 1, 8, 1, 3, 2, 1, 5, 4, 2, 3, 2, 2, 7, 2, 3, 1, 8, 1, 3, 2, 1, 5, 
      4, 2, 3, 2, 7, 2, 3, 1, 1, 8, 1, 3, 2, 5, 4, 2, 3, 2, 7, 2, 3, 1, 1, 2, 
      8, 1, 3, 2, 4, 2, 3, 2, 7, 2, 1, 1, 2, 8, 8, 1, 3, 4, 2, 3, 2, 2, 1, 1, 
      2, 8, 9, 8, 1, 3, 4, 2, 2, 2, 1, 1, 2, 8, 9, 2, 1, 8, 1, 3, 4, 2, 2, 2, 
      1, 1, 8, 9, 2, 1, 1, 1, 8, 1, 3, 4, 2, 2, 1, 1, 8, 9, 2, 1, 1, 3, 8, 1, 
      3, 2, 2, 1, 1, 8, 9, 2, 1, 1, 3, 4, 1, 1, 3, 2, 2, 1, 1, 9, 2, 1, 1, 3, 
      4, 1, 16, 1, 3, 2, 1, 1, 9, 2, 1, 1, 3, 4, 1, 16, 1, 1, 1, 2, 1, 1, 9, 
      2, 1, 1, 3, 4, 1, 16, 1, 1, 1, 3, 1, 2, 1, 1, 9, 2, 1, 1, 3, 4, 1, 1, 
      1, 1, 3, 14, 2, 1, 1, 1, 9, 2, 1, 1, 3, 4, 1, 1, 1, 3, 14, 2, 3, 1, 1, 
      1, 2, 1, 1, 3, 4, 1, 1, 1, 3, 14, 2, 3, 3, 6, 1, 1, 1, 2, 1, 1, 3, 4, 
      1, 1, 1, 3, 14, 2, 3, 3, 6, 1, 1, 1, 1, 2, 1, 1, 3, 4, 1, 1, 1, 3, 14, 
      2, 3, 6, 1, 1, 2, 1, 1, 1, 2, 1, 1, 3, 1, 1, 1, 3, 14, 2, 3, 6, 1, 2, 
      5, 1, 1, 1, 2, 1, 1, 3, 1, 1, 1, 3, 14, 2, 3, 1, 2, 5, 4, 3, 1, 1, 1, 
      2, 1, 1, 3, 1, 1, 3, 14, 2, 1, 2, 5, 4, 3, 4, 1, 1, 1, 2, 1, 1, 1, 1, 
      3, 14, 2, 1, 5, 4, 3, 4, 3, 1, 1, 1, 2, 1, 1, 1, 14, 2, 1, 5, 4, 3, 4, 
      3, 4, 1, 1, 1, 2, 1, 1, 14, 2, 1, 5, 4, 4, 3, 4, 4, 1, 1, 1, 2, 1, 1, 
      2, 1, 5, 4, 4, 3, 4, 4, 4, 11, 1, 1, 1, 2, 1, 1, 2, 1, 5, 4, 4, 3, 4, 
      4, 4, 10, 2, 1, 1, 1, 2, 1, 1, 2, 1, 5, 4, 3, 4, 4, 4, 10, 2, 3, 1, 1, 
      1, 1, 2, 1, 1, 2, 1, 5, 4, 4, 4, 4, 10, 2, 3, 1, 2, 1, 1, 1, 1, 2, 1, 
      2, 1, 5, 4, 4, 4, 4, 10, 2, 3, 2, 1, 2, 1, 1, 1, 2, 1, 2, 1, 5, 4, 4, 
      4, 4, 2, 3, 2, 1, 2, 9, 2, 1, 1, 1, 2, 1, 2, 1, 5, 4, 4, 4, 4, 2, 3, 2, 
      2, 9, 2, 1, 1, 1, 1, 1, 2, 1, 2, 1, 4, 4, 4, 4, 2, 3, 2, 2, 9, 2, 1, 1, 
      2, 3, 1, 1, 1, 2, 1, 2, 1, 4, 4, 4, 4, 2, 3, 2, 9, 2, 1, 1, 2, 3, 1, 1, 
      1, 1, 1, 2, 1, 2, 1, 4, 4, 4, 2, 3, 2, 9, 2, 1, 1, 2, 3, 1, 1, 2, 3, 1, 
      1, 2, 1, 2, 1, 4, 4, 4, 2, 3, 2, 9, 2, 1, 1, 2, 3, 1, 2, 3, 2, 1, 1, 2, 
      1, 2, 1, 4, 4, 4, 2, 3, 2, 9, 2, 1, 1, 2, 1, 2, 3, 2, 2, 1, 1, 1, 2, 1, 
      4, 4, 4, 2, 3, 2, 9, 2, 1, 1, 2, 1, 2, 3, 2, 2, 1, 3, 1, 1, 2, 1, 4, 4, 
      4, 2, 3, 2, 9, 1, 2, 1, 2, 3, 2, 2, 1, 3, 3, 1, 2, 1, 4, 4, 2, 3, 2, 9, 
      1, 2, 1, 2, 3, 2, 2, 1, 3, 3, 5, 1, 2, 1, 4, 2, 3, 2, 9, 1, 2, 1, 2, 3, 
      2, 2, 1, 3, 3, 5, 3, 2, 1, 2, 1, 4, 2, 3, 2, 9, 1, 2, 1, 2, 3, 2, 2, 1, 
      3, 3, 5, 3, 1, 1, 1, 2, 1, 4, 3, 2, 9, 2, 1, 2, 3, 2, 2, 1, 3, 3, 5, 3, 
      1, 1, 3, 1, 2, 1, 4, 3, 2, 9, 2, 1, 2, 3, 2, 2, 1, 3, 5, 3, 1, 1, 3, 2, 
      2, 1, 2, 1, 4, 3, 2, 9, 2, 1, 2, 3, 2, 2, 3, 5, 3, 1, 1, 3, 2, 2, 1, 1, 
      1, 2, 1, 4, 3, 2, 9, 2, 1, 2, 3, 2, 2, 3, 5, 3, 1, 1, 3, 2, 1, 1, 2, 1, 
      1, 1, 4, 3, 2, 9, 2, 1, 2, 3, 2, 2, 3, 5, 3, 1, 1, 3, 2, 1, 1, 1, 4, 1, 
      4, 3, 2, 9, 2, 1, 2, 3, 2, 2, 3, 5, 3, 1, 1, 3, 1, 1, 1, 4, 3, 1, 4, 3, 
      2, 9, 2, 1, 2, 3, 2, 2, 3, 3, 1, 1, 3, 1, 1, 1, 4, 3, 4, 1, 1, 4, 3, 2, 
      9, 2, 1, 2, 3, 2, 2, 3, 1, 1, 3, 1, 1, 1, 4, 3, 4, 1, 1, 2, 1, 4, 3, 2, 
      9, 2, 1, 2, 3, 2, 2, 3, 1, 1, 3, 1, 1, 1, 3, 4, 1, 1, 2, 2, 2, 1, 4, 3, 
      2, 9, 2, 1, 2, 3, 2, 3, 1, 1, 3, 1, 1, 1, 3, 4, 1, 1, 2, 2, 2, 1, 1, 1, 
      4, 3, 2, 2, 1, 2, 3, 2, 3, 1, 1, 3, 1, 1, 1, 3, 1, 1, 2, 2, 2, 1, 1, 
      13, 1, 4, 3, 2, 2, 1, 2, 3, 2, 3, 1, 1, 3, 1, 1, 3, 1, 1, 2, 2, 2, 1, 
      1, 13, 1, 1, 4, 3, 2, 2, 1, 2, 3, 2, 3, 1, 1, 3, 1, 1, 3, 1, 1, 2, 2, 
      2, 1, 1, 1, 1, 14, 4, 3, 2, 2, 1, 2, 3, 2, 3, 1, 1, 1, 1, 3, 1, 1, 2, 
      2, 1, 1, 1, 1, 14, 3, 4, 3, 2, 2, 1, 2, 3, 2, 3, 1, 1, 1, 3, 1, 2, 2, 
      1, 1, 1, 1, 14, 3, 2, 4, 3, 2, 1, 2, 3, 2, 3, 1, 1, 1, 3, 1, 2, 2, 1, 
      1, 1, 1, 14, 3, 2, 1, 1, 4, 3, 2, 1, 2, 3, 2, 3, 1, 1, 1, 3, 1, 2, 2, 
      1, 1, 1, 1, 14, 3, 2, 1, 1, 1, 3, 2, 1, 2, 3, 2, 3, 1, 1, 1, 3, 1, 2, 
      2, 1, 1, 1, 1, 14, 2, 1, 1, 1, 7, 3, 2, 1, 2, 3, 2, 3, 1, 1, 1, 3, 1, 
      2, 2, 1, 1, 1, 1, 14, 2, 1, 1, 8, 3, 2, 1, 2, 3, 2, 3, 1, 1, 3, 2, 2, 
      1, 1, 1, 1, 14, 2, 1, 1, 8, 2, 3, 2, 1, 2, 3, 2, 3, 1, 1, 3, 2, 2, 1, 
      1, 1, 1, 14, 1, 1, 8, 2, 2, 1, 3, 2, 1, 2, 2, 3, 1, 1, 3, 2, 2, 1, 1, 
      1, 1, 14, 1, 8, 2, 2, 1, 4, 2, 1, 2, 2, 3, 1, 3, 2, 2, 1, 1, 1, 1, 14, 
      1, 8, 2, 2, 1, 4, 4, 2, 1, 2, 2, 3, 1, 3, 2, 2, 1, 1, 1, 1, 14, 1, 8, 
      2, 2, 1, 4, 3, 1, 2, 1, 2, 2, 3, 1, 3, 2, 2, 1, 1, 1, 1, 1, 8, 2, 2, 1, 
      4, 3, 1, 11, 4, 2, 1, 2, 2, 3, 1, 3, 2, 2, 1, 1, 1, 1, 1, 8, 2, 2, 4, 
      3, 1, 11, 5, 2, 1, 2, 2, 3, 1, 3, 2, 2, 1, 1, 1, 1, 1, 2, 2, 4, 3, 1, 
      11, 5, 5, 3, 2, 1, 2, 2, 3, 1, 3, 2, 2, 1, 1, 1, 1, 1, 2, 2, 4, 3, 1, 
      11, 5, 3, 4, 1, 2, 1, 2, 3, 1, 3, 2, 2, 1, 1, 1, 1, 1, 2, 2, 4, 3, 1, 
      11, 3, 4, 1, 7, 2, 1, 2, 3, 1, 3, 1, 1, 1, 1, 1, 2, 2, 4, 3, 1, 11, 3, 
      4, 1, 7, 4, 2, 1, 2, 3, 1, 3, 1, 1, 1, 1, 1, 2, 2, 3, 1, 11, 3, 4, 1, 
      4, 4, 3, 2, 2, 2, 1, 2, 3, 1, 3, 1, 1, 1, 1, 1, 2, 2, 3, 1, 11, 3, 4, 
      1, 4, 4, 3, 2, 2, 2, 1, 2, 3, 1, 3, 1, 1, 1, 1, 1, 2, 2, 3, 1, 3, 4, 1, 
      4, 4, 3, 2, 2, 11, 1, 2, 1, 2, 3, 1, 3, 1, 1, 1, 1, 1, 2, 2, 3, 1, 3, 
      4, 1, 4, 3, 2, 2, 11, 1, 2, 2, 2, 1, 2, 3, 1, 3, 1, 1, 1, 1, 1, 2, 2, 
      3, 1, 3, 1, 4, 3, 2, 11, 1, 2, 2, 6, 2, 1, 2, 3, 1, 3, 1, 1, 1, 1, 1, 
      2, 2, 3, 3, 1, 4, 3, 2, 11, 1, 2, 6, 3, 2, 1, 2, 3, 1, 3, 1, 1, 1, 1, 
      2, 2, 3, 3, 1, 4, 3, 2, 11, 2, 6, 3, 2, 2, 1, 2, 3, 1, 3, 1, 1, 1, 2, 
      2, 3, 3, 1, 4, 3, 2, 2, 6, 3, 2, 12, 2, 1, 2, 3, 1, 3, 1, 1, 1, 2, 2, 
      3, 3, 1, 4, 3, 2, 2, 6, 3, 12, 1, 2, 2, 1, 2, 3, 1, 3, 1, 1, 1, 2, 2, 
      3, 1, 4, 3, 2, 2, 6, 3, 12, 1, 2, 1, 3, 2, 1, 2, 3, 1, 3, 1, 1, 1, 2, 
      2, 3, 1, 4, 3, 2, 2, 3, 12, 1, 2, 1, 3, 2, 5, 2, 1, 2, 3, 1, 3, 1, 1, 
      1, 2, 2, 3, 1, 4, 3, 2, 12, 1, 2, 1, 3, 2, 5, 5, 2, 1, 2, 3, 1, 3, 1, 
      1, 1, 2, 2, 1, 4, 3, 2, 12, 1, 2, 1, 3, 5, 5, 5, 2, 1, 2, 3, 1, 3, 1, 
      1, 1, 2, 1, 4, 3, 2, 12, 1, 1, 3, 5, 5, 5, 4, 2, 2, 3, 1, 3, 1, 1, 1, 
      1, 4, 3, 2, 12, 1, 1, 3, 5, 5, 5, 4, 3, 2, 2, 3, 1, 3, 1, 1, 1, 4, 3, 
      2, 12, 1, 1, 3, 5, 5, 4, 3, 6, 2, 2, 3, 1, 3, 1, 1, 1, 4, 2, 12, 1, 1, 
      3, 5, 5, 4, 3, 6, 1, 2, 2, 2, 3, 1, 3, 1, 1, 1, 4, 2, 12, 1, 1, 3, 5, 
      5, 4, 3, 1, 2, 5, 1, 2, 2, 3, 1, 3, 1, 1, 1, 4, 2, 12, 1, 1, 3, 5, 5, 
      4, 3, 5, 1, 3, 2, 2, 3, 1, 3, 1, 1, 1, 2, 12, 1, 1, 3, 5, 5, 4, 3, 5, 
      1, 3, 3, 2, 2, 2, 1, 3, 1, 1, 1, 2, 12, 1, 1, 3, 5, 5, 4, 3, 5, 1, 3, 
      2, 6, 2, 2, 1, 3, 1, 1, 1, 2, 12, 1, 1, 3, 5, 5, 4, 5, 1, 3, 2, 6, 1, 
      2, 2, 2, 1, 3, 1, 1, 1, 2, 12, 1, 3, 5, 5, 4, 5, 1, 3, 2, 6, 1, 2, 1, 
      1, 2, 2, 1, 3, 1, 1, 1, 2, 12, 1, 3, 5, 5, 5, 1, 3, 2, 6, 1, 2, 1, 1, 
      2, 2, 2, 2, 1, 1, 1, 1, 2, 12, 1, 3, 5, 5, 5, 1, 3, 2, 6, 1, 2, 1, 1, 
      2, 2, 2, 1, 2, 2, 1, 1, 1, 1, 12, 1, 3, 5, 5, 1, 3, 2, 6, 1, 2, 1, 1, 
      2, 2, 2, 1, 7, 2, 2, 1, 1, 1, 12, 3, 5, 5, 1, 3, 2, 6, 1, 2, 1, 1, 2, 
      2, 2, 1, 7, 2, 2, 2, 1, 1, 1, 12, 3, 5, 1, 3, 2, 6, 1, 2, 1, 1, 2, 2, 
      2, 1, 7, 2, 3, 3, 2, 1, 1, 1, 12, 3, 5, 1, 3, 2, 6, 2, 1, 1, 2, 2, 2, 
      1, 7, 2, 3, 3, 3, 2, 1, 1, 1, 12, 3, 5, 1, 3, 2, 6, 2, 1, 1, 2, 2, 1, 
      7, 2, 3, 3, 5, 2, 1, 1, 1, 12, 3, 5, 1, 3, 2, 6, 2, 1, 1, 2, 1, 7, 2, 
      3, 3, 5, 1, 1, 2, 1, 1, 1, 3, 5, 1, 3, 2, 6, 2, 1, 1, 2, 1, 7, 2, 3, 3, 
      1, 1, 17, 2, 1, 1, 1, 3, 5, 1, 3, 2, 6, 2, 1, 1, 2, 1, 7, 2, 3, 1, 17, 
      4, 2, 1, 1, 1, 3, 1, 3, 2, 6, 1, 1, 2, 1, 7, 2, 3, 1, 17, 4, 7, 2, 1, 
      1, 1, 3, 1, 3, 2, 6, 1, 1, 2, 1, 7, 2, 3, 1, 17, 7, 2, 2, 2, 1, 1, 1, 
      3, 1, 3, 2, 6, 1, 1, 2, 1, 7, 3, 1, 17, 7, 2, 2, 1, 1, 2, 1, 1, 1, 3, 
      1, 3, 2, 6, 1, 1, 2, 1, 7, 1, 17, 7, 2, 2, 1, 1, 3, 1, 2, 1, 1, 1, 3, 
      1, 3, 2, 6, 1, 1, 2, 1, 7, 17, 7, 2, 2, 1, 1, 1, 4, 2, 1, 1, 1, 3, 1, 
      3, 2, 1, 1, 2, 1, 7, 17, 7, 2, 2, 1, 1, 1, 4, 4, 2, 2, 1, 1, 3, 1, 3, 
      2, 1, 1, 2, 1, 7, 2, 1, 1, 1, 4, 4, 2, 8, 19, 2, 1, 1, 3, 1, 3, 2, 1, 
      1, 2, 1, 7, 2, 1, 1, 1, 4, 4, 2, 8, 19, 2, 1, 1, 3, 1, 3, 2, 1, 1, 2, 
      1, 7, 2, 1, 1, 1, 4, 4, 8, 19, 1, 1, 2, 1, 1, 3, 1, 3, 2, 1, 1, 2, 1, 
      7, 2, 1, 1, 4, 4, 8, 19, 1, 2, 2, 1, 1, 3, 1, 3, 2, 1, 1, 2, 1, 7, 2, 
      1, 1, 4, 8, 19, 1, 2, 3, 1, 2, 1, 1, 3, 1, 2, 1, 2, 1, 7, 2, 1, 1, 4, 
      8, 19, 1, 2, 3, 1, 4, 2, 1, 3, 2, 1, 2, 1, 7, 2, 1, 1, 4, 8, 19, 1, 2, 
      3, 1, 4, 2, 2, 1, 3, 2, 1, 2, 1, 7, 2, 1, 1, 4, 8, 19, 1, 2, 3, 1, 2, 
      3, 1, 2, 2, 1, 2, 1, 7, 2, 1, 1, 4, 8, 19, 1, 2, 3, 1, 2, 3, 1, 4, 2, 
      2, 1, 2, 7, 2, 1, 1, 4, 8, 19, 1, 2, 3, 1, 2, 1, 4, 4, 2, 2, 1, 2, 7, 
      2, 1, 1, 4, 8, 19, 1, 2, 3, 1, 2, 1, 4, 3, 1, 2, 2, 1, 2, 7, 2, 1, 1, 
      4, 8, 1, 2, 3, 1, 2, 1, 4, 3, 1, 12, 7, 2, 2, 1, 2, 7, 2, 1, 1, 4, 8, 
      1, 2, 3, 2, 1, 4, 1, 12, 7, 4, 2, 2, 1, 2, 7, 2, 1, 1, 4, 1, 2, 3, 2, 
      1, 4, 1, 12, 7, 4, 7, 1, 2, 2, 1, 2, 7, 2, 1, 1, 4, 1, 2, 3, 2, 1, 4, 
      1, 12, 7, 7, 1, 3, 1, 2, 2, 1, 2, 7, 2, 1, 1, 4, 1, 2, 3, 2, 1, 4, 1, 
      12, 7, 1, 3, 1, 1, 6, 2, 2, 1, 2, 7, 1, 1, 4, 1, 2, 3, 2, 1, 4, 1, 12, 
      7, 1, 1, 1, 6, 5, 2, 2, 1, 2, 7, 1, 1, 4, 1, 3, 2, 1, 4, 1, 7, 1, 1, 1, 
      6, 5, 14, 2, 2, 2, 7, 1, 1, 4, 1, 3, 2, 1, 4, 1, 7, 1, 1, 1, 6, 5, 15, 
      2, 2, 2, 7, 1, 1, 4, 1, 3, 2, 1, 4, 1, 1, 1, 1, 6, 5, 15, 2, 5, 2, 2, 
      2, 1, 1, 4, 1, 3, 2, 1, 4, 1, 1, 1, 6, 5, 15, 2, 5, 8, 2, 2, 2, 1, 4, 
      1, 3, 2, 1, 4, 1, 1, 1, 6, 5, 15, 5, 8, 3, 2, 2, 2, 1, 4, 1, 3, 2, 1, 
      4, 1, 1, 1, 6, 15, 5, 8, 3, 3, 2, 2, 2, 2, 1, 4, 1, 3, 2, 1, 4, 1, 1, 
      1, 6, 15, 5, 8, 3, 2, 2, 1, 2, 2, 2, 1, 4, 1, 3, 2, 1, 4, 1, 1, 1, 6, 
      5, 8, 3, 2, 1, 17, 2, 2, 2, 1, 4, 1, 3, 1, 4, 1, 1, 1, 6, 5, 8, 3, 2, 
      1, 17, 1, 1, 2, 2, 2, 1, 4, 1, 3, 1, 4, 1, 1, 6, 5, 8, 3, 2, 1, 17, 1, 
      2, 2, 2, 2, 1, 4, 1, 3, 1, 4, 1, 1, 6, 5, 8, 3, 2, 1, 1, 2, 2, 16, 2, 
      2, 1, 1, 3, 1, 4, 1, 1, 6, 5, 8, 3, 2, 1, 1, 2, 2, 16, 6, 2, 2, 1, 1, 
      3, 1, 4, 1, 1, 5, 8, 3, 2, 1, 1, 2, 2, 16, 6, 2, 4, 2, 2, 1, 1, 3, 1, 
      4, 1, 1, 5, 8, 3, 2, 1, 1, 2, 2, 6, 2, 4, 5, 11, 2, 2, 1, 1, 3, 1, 1, 
      1, 5, 8, 3, 2, 1, 1, 2, 2, 6, 2, 4, 5, 11, 3, 1, 2, 2, 1, 1, 3, 1, 1, 
      1, 5, 3, 2, 1, 1, 2, 2, 6, 2, 4, 5, 11, 3, 1, 3, 5, 2, 1, 1, 3, 1, 1, 
      1, 5, 3, 2, 1, 1, 2, 2, 6, 4, 5, 11, 3, 1, 3, 5, 4, 2, 1, 1, 3, 1, 1, 
      1, 5, 3, 2, 1, 1, 2, 2, 6, 4, 5, 11, 3, 3, 5, 5, 2, 1, 1, 3, 1, 1, 1, 
      5, 3, 2, 1, 1, 2, 2, 6, 4, 11, 3, 3, 5, 5, 1, 4, 2, 1, 1, 3, 1, 1, 1, 
      3, 2, 1, 1, 2, 2, 6, 4, 11, 3, 3, 5, 5, 1, 4, 1, 4, 2, 1, 1, 3, 1, 1, 
      1, 3, 2, 1, 1, 2, 2, 6, 4, 11, 3, 3, 5, 1, 4, 1, 4, 2, 3, 2, 1, 1, 3, 
      1, 1, 1, 3, 1, 1, 2, 2, 6, 4, 3, 3, 5, 1, 4, 1, 4, 2, 3, 12, 2, 1, 1, 
      3, 1, 1, 1, 3, 1, 1, 2, 2, 6, 4, 3, 5, 1, 1, 4, 2, 3, 12, 7, 2, 1, 1, 
      3, 1, 1, 1, 3, 1, 1, 2, 2, 6, 4, 3, 5, 1, 1, 2, 3, 7, 13, 2, 1, 1, 3, 
      1, 1, 1, 3, 1, 1, 2, 2, 6, 4, 3, 5, 1, 1, 2, 7, 13, 1, 2, 2, 1, 1, 3, 
      1, 1, 1, 3, 1, 2, 2, 6, 4, 3, 5, 1, 1, 2, 7, 13, 1, 3, 2, 1, 1, 3, 1, 
      1, 3, 1, 2, 2, 6, 4, 3, 5, 1, 1, 2, 7, 1, 3, 14, 2, 1, 1, 3, 1, 1, 3, 
      1, 2, 2, 6, 3, 5, 1, 1, 7, 1, 3, 14, 6, 2, 1, 1, 3, 1, 1, 3, 1, 2, 2, 
      6, 3, 1, 1, 7, 1, 3, 14, 6, 2, 3, 2, 1, 1, 3, 1, 1, 3, 1, 2, 2, 6, 3, 
      1, 1, 1, 3, 14, 6, 2, 3, 5, 2, 2, 1, 1, 3, 1, 1, 3, 1, 2, 2, 6, 3, 1, 
      1, 1, 3, 6, 2, 3, 5, 2, 5, 9, 2, 1, 3, 1, 1, 3, 2, 2, 6, 3, 1, 1, 1, 3, 
      6, 2, 3, 5, 2, 5, 9, 2, 2, 1, 3, 1, 3, 2, 2, 6, 3, 1, 1, 1, 3, 6, 3, 5, 
      2, 5, 9, 2, 3, 2, 1, 3, 1, 3, 2, 2, 6, 3, 1, 1, 1, 3, 3, 5, 2, 5, 9, 2, 
      3, 2, 4, 2, 1, 3, 1, 3, 2, 2, 6, 3, 1, 1, 1, 3, 5, 2, 5, 9, 3, 2, 4, 4, 
      2, 1, 3, 1, 3, 2, 2, 6, 3, 1, 3, 5, 2, 5, 9, 3, 2, 4, 4, 2, 2, 1, 3, 1, 
      3, 2, 2, 6, 3, 1, 3, 2, 5, 9, 3, 2, 4, 4, 2, 4, 1, 2, 1, 3, 1, 2, 6, 3, 
      1, 3, 2, 5, 9, 3, 2, 4, 4, 2, 4, 1, 2, 2, 1, 3, 1, 2, 6, 3, 1, 3, 2, 5, 
      9, 2, 4, 4, 2, 4, 1, 2, 1, 2, 2, 1, 3, 1, 2, 6, 3, 1, 3, 5, 9, 2, 4, 2, 
      4, 1, 2, 1, 2, 6, 2, 3, 1, 2, 6, 3, 1, 3, 9, 2, 4, 2, 4, 1, 2, 1, 2, 6, 
      5, 2, 3, 1, 2, 3, 1, 3, 9, 2, 4, 2, 4, 1, 2, 1, 2, 6, 5, 4, 2, 2, 1, 2, 
      3, 1, 3, 9, 2, 4, 2, 1, 2, 1, 2, 6, 5, 4, 2, 7, 2, 1, 2, 3, 1, 3, 9, 2, 
      4, 1, 2, 1, 6, 5, 4, 2, 7, 3, 2, 1, 2, 3, 1, 9, 2, 4, 1, 2, 1, 5, 4, 2, 
      7, 3, 7, 1, 2, 1, 9, 2, 4, 1, 2, 1, 5, 4, 2, 7, 3, 7, 5, 1, 2, 1, 9, 2, 
      4, 1, 2, 1, 5, 4, 7, 3, 7, 5, 1, 2, 1, 2, 1, 9, 2, 4, 1, 2, 1, 5, 4, 7, 
      3, 5, 1, 2, 3, 5, 1, 2, 1, 9, 2, 4, 1, 2, 1, 5, 4, 3, 5, 2, 3, 5, 8, 1, 
      2, 1, 9, 2, 4, 1, 2, 1, 5, 4, 3, 2, 3, 5, 8, 3, 3, 1, 2, 1, 9, 4, 1, 2, 
      1, 5, 4, 3, 2, 5, 8, 3, 3, 5, 1, 2, 1, 9, 4, 2, 1, 5, 4, 3, 2, 5, 8, 3, 
      3, 6, 1, 2, 1, 9, 4, 2, 1, 5, 4, 2, 5, 8, 3, 6, 6, 2, 1, 9, 4, 2, 1, 5, 
      4, 2, 5, 8, 3, 6, 7, 2, 1, 9, 4, 1, 5, 4, 2, 8, 3, 6, 7, 7, 2, 1, 4, 1, 
      5, 4, 2, 8, 3, 6, 7, 7, 1, 9, 2, 1, 4, 5, 4, 2, 8, 3, 6, 7, 7, 1, 9, 1, 
      1, 2, 1, 4, 5, 4, 2, 3, 6, 7, 7, 1, 9, 1, 1, 6, 3, 2, 1, 4, 5, 4, 2, 3, 
      6, 7, 1, 9, 1, 1, 6, 3, 2, 5, 2, 1, 4, 5, 4, 2, 3, 6, 7, 1, 1, 1, 6, 3, 
      2, 5, 5, 4, 2, 1, 4, 5, 4, 2, 3, 6, 7, 1, 1, 6, 3, 5, 5, 4, 3, 2, 1, 5, 
      4, 2, 3, 6, 1, 1, 6, 3, 5, 5, 4, 3, 10, 2, 1, 5, 4, 2, 6, 1, 1, 6, 3, 
      5, 5, 4, 3, 10, 2, 1, 2, 1, 5, 4, 2, 6, 1, 1, 3, 5, 5, 4, 3, 10, 2, 1, 
      1, 5, 2, 1, 5, 4, 6, 1, 1, 5, 5, 4, 3, 10, 2, 1, 1, 5, 4, 2, 1, 5, 4, 
      6, 1, 1, 5, 4, 3, 10, 2, 1, 1, 5, 4, 3, 2, 2, 1, 5, 6, 1, 1, 5, 4, 10, 
      2, 1, 1, 5, 4, 3, 2, 7, 2, 1, 5, 6, 1, 1, 5, 4, 10, 2, 1, 1, 5, 3, 2, 
      7, 1, 3, 2, 1, 5, 6, 1, 5, 4, 2, 1, 1, 5, 3, 2, 7, 1, 3, 11, 2, 1, 5, 
      6, 1, 5, 4, 2, 1, 1, 5, 2, 7, 1, 3, 11, 1, 2, 2, 1, 5, 6, 1, 5, 4, 2, 
      1, 1, 5, 2, 7, 1, 3, 1, 11, 2, 1, 5, 6, 1, 5, 4, 1, 5, 2, 7, 1, 3, 1, 
      11, 3, 2, 1, 5, 6, 1, 5, 4, 1, 5, 7, 1, 3, 1, 3, 11, 2, 1, 5, 6, 5, 4, 
      1, 5, 1, 3, 1, 3, 11, 8, 2, 1, 5, 6, 4, 1, 5, 1, 3, 1, 3, 11, 8, 2, 4, 
      2, 1, 5, 6, 4, 1, 5, 1, 3, 1, 3, 8, 2, 4, 3, 9, 2, 1, 5, 6, 4, 1, 5, 1, 
      3, 1, 3, 8, 2, 3, 9, 3, 2, 2, 1, 5, 6, 4, 1, 5, 1, 3, 1, 3, 8, 3, 9, 3, 
      4, 2, 1, 5, 4, 1, 1, 3, 1, 3, 8, 3, 9, 3, 4, 7, 2, 1, 5, 4, 1, 1, 3, 1, 
      3, 8, 3, 9, 3, 7, 2, 2, 2, 1, 5, 4, 1, 1, 3, 1, 3, 8, 3, 3, 7, 2, 2, 5, 
      5, 2, 1, 5, 4, 1, 1, 3, 1, 3, 8, 3, 3, 7, 2, 5, 7, 2, 1, 5, 1, 1, 3, 1, 
      3, 8, 3, 3, 7, 2, 5, 7, 3, 1, 2, 1, 5, 1, 1, 3, 1, 3, 8, 3, 7, 2, 5, 7, 
      3, 1, 2, 1, 2, 1, 5, 1, 1, 3, 1, 3, 8, 3, 7, 2, 7, 3, 1, 2, 1, 1, 4, 2, 
      1, 5, 1, 1, 3, 3, 8, 3, 7, 2, 7, 3, 1, 2, 1, 1, 5, 2, 1, 5, 1, 1, 3, 3, 
      8, 3, 7, 2, 7, 3, 1, 1, 5, 3, 2, 1, 5, 1, 1, 3, 3, 3, 7, 2, 7, 3, 1, 1, 
      5, 3, 2, 6, 2, 1, 1, 1, 3, 3, 7, 2, 7, 3, 1, 1, 5, 3, 2, 6, 8, 2, 1, 1, 
      1, 3, 7, 2, 7, 3, 1, 1, 5, 3, 2, 8, 9, 2, 1, 1, 1, 3, 7, 7, 3, 1, 1, 5, 
      3, 2, 8, 9, 1, 1, 2, 1, 1, 1, 7, 7, 3, 1, 1, 5, 3, 2, 8, 9, 1, 1, 1, 2, 
      2, 1, 1, 1, 7, 7, 3, 1, 1, 5, 3, 2, 8, 1, 1, 1, 2, 7, 2, 2, 1, 1, 7, 7, 
      3, 1, 1, 5, 3, 2, 8, 1, 1, 1, 7, 2, 3, 2, 1, 1, 7, 1, 1, 5, 3, 2, 8, 1, 
      1, 1, 7, 2, 3, 8, 2, 1, 1, 7, 1, 1, 5, 3, 2, 8, 1, 1, 1, 7, 2, 3, 6, 3, 
      2, 1, 1, 7, 1, 1, 5, 3, 2, 8, 1, 1, 1, 7, 2, 3, 3, 2, 4, 2, 1, 7, 1, 1, 
      5, 3, 2, 1, 1, 1, 7, 2, 3, 3, 2, 4, 9, 2, 1, 1, 1, 5, 3, 2, 1, 1, 1, 7, 
      3, 3, 2, 4, 9, 9, 2, 1, 1, 1, 5, 3, 2, 1, 1, 1, 7, 3, 2, 4, 9, 9, 1, 2, 
      2, 1, 1, 5, 2, 1, 1, 1, 7, 3, 2, 4, 9, 9, 1, 2, 4, 2, 1, 1, 5, 2, 1, 1, 
      1, 3, 2, 4, 9, 9, 1, 2, 4, 2, 5, 2, 1, 1, 5, 2, 1, 1, 1, 3, 2, 4, 9, 1, 
      2, 4, 2, 5, 7, 2, 2, 1, 1, 5, 2, 1, 1, 3, 2, 4, 9, 1, 2, 4, 2, 7, 2, 5, 
      2, 1, 1, 5, 1, 1, 3, 2, 4, 9, 1, 2, 4, 2, 2, 5, 9, 1, 1, 5, 1, 1, 3, 2, 
      4, 9, 1, 2, 4, 2, 2, 9, 7, 1, 1, 5, 1, 1, 2, 4, 9, 1, 2, 4, 2, 2, 9, 6, 
      1, 1, 5, 1, 1, 2, 9, 1, 2, 4, 2, 2, 9, 6, 3, 1, 1, 1, 5, 1, 2, 9, 1, 2, 
      4, 2, 9, 6, 3, 1, 3, 1, 1, 5, 1, 2, 9, 1, 2, 4, 2, 9, 6, 3, 1, 1, 2, 1, 
      5, 1, 2, 9, 1, 2, 4, 2, 9, 6, 3, 1, 2, 2, 1, 1, 2, 9, 1, 2, 4, 2, 9, 6, 
      3, 1, 2, 2, 3, 2, 1, 1, 2, 9, 1, 2, 4, 2, 6, 3, 2, 2, 3, 2, 10, 1, 1, 
      2, 9, 1, 2, 2, 6, 3, 2, 2, 3, 2, 10, 3, 1, 1, 1, 2, 9, 1, 2, 6, 3, 2, 
      3, 2, 10, 3, 1, 4, 1, 1, 2, 9, 1, 2, 3, 2, 3, 2, 10, 3, 1, 4, 5, 1, 1, 
      1, 2, 9, 1, 2, 3, 2, 3, 2, 10, 3, 1, 5, 1, 2, 2, 1, 2, 9, 1, 2, 3, 3, 
      2, 10, 3, 1, 5, 1, 2, 2, 2, 1, 2, 9, 1, 3, 2, 10, 3, 1, 5, 1, 2, 2, 2, 
      4, 1, 2, 9, 1, 2, 10, 3, 1, 5, 1, 2, 2, 4, 4, 1, 2, 9, 1, 2, 10, 3, 1, 
      5, 1, 2, 2, 4, 1, 3, 1, 2, 9, 1, 2, 10, 1, 5, 1, 2, 4, 1, 3, 5, 1, 2, 
      9, 1, 2, 10, 5, 2, 4, 1, 3, 5, 2, 1, 2, 9, 1, 2, 10, 2, 4, 1, 3, 5, 7, 
      1, 2, 9, 1, 2, 10, 2, 4, 1, 3, 7, 2, 3, 1, 2, 9, 1, 2, 2, 4, 1, 3, 7, 
      2, 3, 9, 2, 1, 2, 9, 1, 2, 2, 1, 7, 2, 3, 9, 2, 6, 1, 2, 9, 1, 2, 2, 1, 
      2, 3, 9, 2, 6, 6, 1, 1, 2, 9, 1, 2, 2, 1, 2, 3, 2, 6, 6, 1, 2, 7, 1, 2, 
      9, 1, 2, 2, 1, 3, 2, 6, 1, 2, 7, 8, 1, 2, 9, 1, 2, 2, 1, 3, 2, 1, 2, 7, 
      8, 6, 1, 1, 2, 1, 2, 2, 1, 3, 2, 1, 2, 7, 8, 6, 1, 6, 3, 1, 1, 2, 2, 1, 
      3, 2, 2, 7, 8, 6, 1, 6, 3, 3, 1, 1, 2, 2, 1, 3, 2, 2, 8, 1, 6, 3, 3, 
      10, 1, 1, 2, 2, 1, 3, 2, 8, 1, 3, 3, 10, 6, 1, 1, 2, 2, 1, 3, 2, 1, 3, 
      3, 10, 6, 2, 6, 1, 1, 2, 2, 1, 3, 2, 1, 10, 6, 2, 6, 5, 1, 1, 2, 1, 3, 
      2, 1, 6, 2, 6, 5, 11, 1, 2, 1, 3, 2, 1, 6, 2, 6, 5, 10, 1, 1, 3, 2, 1, 
      6, 2, 6, 5, 10, 1, 2, 1, 1, 3, 1, 2, 6, 5, 10, 1, 2, 8, 1, 1, 3, 1, 2, 
      6, 10, 1, 2, 8, 3, 3, 1, 1, 3, 1, 2, 6, 10, 1, 2, 8, 3, 2, 1, 1, 1, 3, 
      1, 2, 6, 1, 2, 8, 3, 2, 1, 7, 4, 1, 1, 3, 1, 2, 6, 2, 8, 3, 1, 7, 4, 3, 
      1, 3, 1, 2, 6, 2, 8, 3, 1, 7, 4, 4, 1, 3, 1, 2, 6, 2, 8, 3, 1, 7, 4, 1, 
      3, 1, 3, 1, 2, 6, 2, 3, 1, 7, 4, 1, 3, 1, 7, 3, 1, 2, 6, 2, 3, 1, 7, 1, 
      3, 1, 7, 5, 3, 1, 2, 6, 2, 1, 7, 1, 3, 1, 7, 5, 1, 2, 3, 1, 6, 2, 1, 7, 
      3, 1, 7, 5, 1, 2, 1, 3, 1, 6, 2, 1, 7, 3, 1, 7, 1, 2, 1, 2, 3, 3, 1, 6, 
      2, 1, 3, 1, 7, 1, 2, 1, 2, 3, 1, 7, 3, 1, 6, 2, 1, 1, 7, 1, 2, 1, 2, 3, 
      1, 7, 2, 1, 3, 1, 6, 2, 1, 7, 1, 2, 1, 2, 1, 7, 2, 1, 3, 3, 1, 6, 1, 7, 
      1, 2, 1, 2, 1, 7, 2, 1, 3, 2, 1, 3, 1, 1, 7, 1, 2, 1, 2, 1, 7, 2, 1, 3, 
      2, 1, 2, 4, 3, 1, 7, 1, 2, 1, 1, 7, 2, 1, 3, 2, 1, 2, 4, 3, 3, 1, 7, 1, 
      2, 1, 1, 7, 2, 1, 2, 1, 2, 4, 3, 3, 1, 3, 1, 7, 1, 2, 1, 7, 2, 1, 2, 1, 
      2, 4, 3, 1, 4, 3, 1, 7, 1, 2, 1, 7, 2, 1, 2, 1, 2, 4, 3, 1, 1, 3, 3, 1, 
      7, 1, 2, 1, 7, 2, 1, 2, 1, 4, 1, 1, 3, 5, 3, 1, 7, 1, 2, 1, 7, 2, 1, 2, 
      1, 4, 1, 3, 5, 1, 1, 3, 1, 7, 1, 2, 1, 2, 1, 2, 1, 4, 1, 3, 5, 1, 1, 2, 
      6, 3, 1, 7, 1, 2, 1, 2, 1, 2, 1, 1, 3, 5, 1, 1, 2, 6, 2, 3, 3, 1, 7, 2, 
      1, 2, 1, 2, 1, 1, 3, 5, 1, 1, 2, 6, 2, 3, 1, 1, 3, 1, 7, 2, 1, 2, 1, 2, 
      1, 3, 5, 1, 1, 2, 6, 2, 3, 1, 1, 1, 1, 3, 1, 7, 2, 1, 2, 1, 2, 1, 3, 5, 
      1, 1, 2, 6, 2, 3, 1, 1, 1, 1, 1, 3, 1, 7, 2, 1, 2, 1, 2, 1, 5, 1, 1, 2, 
      6, 2, 3, 1, 1, 1, 1, 4, 3, 1, 7, 2, 1, 2, 1, 2, 1, 5, 1, 2, 6, 2, 3, 1, 
      1, 1, 1, 4, 1, 1, 3, 1, 7, 2, 1, 2, 1, 1, 5, 1, 2, 6, 3, 1, 1, 1, 1, 4, 
      1, 1, 4, 3, 1, 7, 2, 1, 2, 1, 1, 1, 2, 6, 3, 1, 1, 1, 4, 1, 1, 4, 6, 3, 
      1, 7, 2, 1, 2, 1, 1, 1, 2, 6, 3, 1, 1, 1, 4, 1, 4, 6, 1, 1, 3, 1, 2, 1, 
      2, 1, 1, 1, 2, 6, 3, 1, 1, 1, 4, 1, 4, 6, 1, 8, 3, 1, 2, 1, 1, 1, 1, 2, 
      6, 3, 1, 1, 1, 4, 1, 4, 6, 1, 8, 1, 1, 3, 1, 2, 1, 1, 1, 2, 6, 3, 1, 1, 
      1, 4, 1, 6, 1, 8, 1, 1, 5, 1, 2, 1, 1, 1, 2, 6, 1, 1, 1, 4, 1, 6, 1, 8, 
      1, 1, 5, 6, 1, 2, 1, 1, 2, 6, 1, 1, 1, 4, 6, 1, 8, 1, 1, 5, 6, 2, 1, 2, 
      1, 1, 2, 6, 1, 1, 1, 4, 1, 8, 1, 1, 5, 6, 8, 1, 2, 1, 2, 6, 1, 1, 1, 4, 
      1, 8, 1, 5, 6, 8, 2, 1, 2, 1, 2, 6, 1, 1, 1, 4, 1, 8, 1, 5, 8, 2, 1, 5, 
      1, 2, 1, 2, 6, 1, 1, 4, 1, 8, 1, 5, 8, 2, 5, 2, 1, 1, 2, 6, 1, 1, 4, 1, 
      8, 1, 5, 8, 5, 2, 4, 1, 1, 2, 6, 1, 1, 4, 1, 1, 5, 8, 5, 2, 4, 2, 7, 1, 
      1, 2, 1, 1, 4, 1, 1, 5, 8, 5, 2, 2, 7, 10, 1, 1, 2, 1, 1, 4, 1, 1, 5, 
      8, 5, 2, 2, 7, 10, 1, 1, 1, 2, 1, 1, 4, 1, 1, 5, 8, 5, 2, 2, 10, 1, 6, 
      1, 1, 1, 1, 1, 4, 1, 1, 5, 8, 5, 2, 2, 10, 6, 1, 3, 1, 1, 1, 1, 1, 1, 
      5, 8, 5, 2, 2, 10, 6, 1, 3, 3, 2, 1, 1, 1, 1, 1, 5, 8, 5, 2, 2, 10, 6, 
      1, 3, 2, 4, 1, 1, 1, 1, 1, 5, 8, 5, 2, 2, 10, 6, 1, 3, 4, 1, 1, 1, 1, 
      1, 1, 1, 5, 8, 5, 2, 2, 10, 6, 1, 4, 1, 1, 1, 2, 1, 1, 1, 1, 5, 8, 5, 
      2, 2, 10, 1, 4, 1, 1, 1, 2, 7, 1, 1, 1, 1, 5, 8, 5, 2, 2, 1, 4, 1, 1, 
      1, 2, 7, 6, 5, 1, 1, 1, 1, 5, 8, 2, 2, 1, 4, 1, 1, 1, 2, 7, 6, 5, 3, 2, 
      1, 1, 1, 1, 5, 8, 2, 2, 1, 4, 1, 1, 1, 2, 5, 3, 2, 6, 1, 1, 1, 5, 8, 2, 
      2, 1, 4, 1, 1, 1, 2, 5, 3, 2, 7, 1, 1, 1, 5, 8, 2, 2, 1, 4, 1, 1, 1, 2, 
      5, 3, 7, 2, 1, 1, 1, 1, 5, 8, 2, 2, 1, 4, 1, 1, 1, 2, 5, 3, 2, 1, 3, 5, 
      1, 1, 1, 8, 2, 2, 1, 4, 1, 1, 1, 2, 5, 3, 2, 1, 3, 5, 1, 5, 1, 1, 8, 2, 
      2, 4, 1, 1, 1, 2, 5, 3, 2, 1, 3, 5, 1, 5, 1, 1, 1, 8, 2, 2, 4, 1, 1, 1, 
      2, 5, 3, 2, 1, 3, 1, 5, 1, 4, 1, 1, 1, 8, 2, 2, 4, 1, 1, 2, 5, 3, 2, 1, 
      3, 1, 5, 1, 4, 1, 1, 1, 8, 2, 2, 1, 1, 2, 5, 3, 2, 1, 3, 1, 5, 1, 4, 5, 
      1, 1, 8, 2, 1, 1, 2, 5, 3, 2, 1, 3, 1, 5, 1, 4, 5, 1, 1, 1, 1, 8, 2, 1, 
      1, 2, 5, 3, 2, 1, 3, 1, 5, 1, 4, 1, 1, 5, 1, 1, 1, 8, 2, 1, 1, 2, 5, 3, 
      2, 1, 3, 1, 5, 1, 1, 1, 5, 5, 1, 1, 8, 2, 1, 1, 5, 3, 2, 1, 3, 1, 5, 1, 
      1, 1, 5, 5, 1, 1, 1, 1, 8, 2, 1, 1, 5, 3, 2, 1, 3, 1, 5, 1, 1, 1, 5, 1, 
      1, 1, 5, 1, 1, 8, 2, 1, 1, 5, 2, 1, 3, 1, 5, 1, 1, 1, 5, 1, 1, 1, 5, 2, 
      1, 1, 1, 8, 2, 1, 1, 5, 2, 1, 3, 1, 5, 1, 1, 1, 5, 1, 1, 1, 2, 1, 4, 1, 
      1, 1, 8, 2, 1, 1, 5, 2, 3, 1, 5, 1, 1, 5, 1, 1, 1, 2, 1, 4, 1, 2, 1, 1, 
      8, 2, 1, 1, 3, 1, 5, 1, 1, 5, 1, 1, 1, 2, 1, 4, 1, 2, 7, 1, 1, 8, 2, 1, 
      1, 3, 1, 5, 1, 1, 5, 1, 1, 1, 2, 1, 4, 1, 2, 4, 3, 1, 8, 2, 1, 3, 1, 5, 
      1, 1, 5, 1, 1, 1, 2, 1, 4, 1, 2, 4, 3, 2, 1, 8, 2, 1, 3, 5, 1, 1, 1, 1, 
      1, 2, 1, 4, 1, 2, 4, 3, 2, 6, 1, 8, 2, 1, 3, 5, 1, 1, 1, 1, 1, 2, 1, 4, 
      1, 4, 3, 2, 6, 1, 1, 1, 8, 2, 1, 3, 5, 1, 1, 1, 1, 2, 1, 4, 1, 4, 2, 6, 
      1, 1, 4, 1, 8, 2, 1, 3, 1, 1, 1, 2, 1, 4, 1, 4, 2, 6, 1, 1, 4, 6, 1, 8, 
      2, 1, 3, 1, 1, 1, 2, 1, 4, 1, 4, 2, 6, 1, 1, 4, 1, 5, 1, 8, 2, 1, 3, 1, 
      1, 2, 1, 4, 1, 4, 2, 6, 1, 1, 4, 1, 6, 1, 2, 1, 3, 1, 1, 2, 1, 4, 1, 4, 
      2, 6, 1, 1, 4, 1, 6, 6, 3, 1, 2, 3, 1, 1, 2, 1, 4, 1, 4, 2, 1, 1, 4, 1, 
      6, 6, 3, 7, 2, 3, 1, 1, 2, 1, 4, 1, 4, 2, 1, 1, 4, 1, 6, 6, 7, 4, 2, 3, 
      1, 1, 2, 1, 4, 1, 4, 2, 1, 1, 6, 6, 7, 4, 5, 2, 1, 1, 2, 1, 4, 1, 4, 2, 
      1, 1, 6, 7, 4, 5, 9, 2, 1, 1, 2, 1, 4, 1, 4, 2, 1, 1, 6, 7, 4, 5, 1, 8, 
      2, 1, 1, 2, 1, 4, 1, 4, 2, 1, 1, 6, 7, 5, 1, 8, 2, 3, 2, 1, 1, 2, 1, 4, 
      1, 4, 2, 1, 1, 6, 7, 1, 8, 2, 3, 5, 1, 2, 1, 1, 2, 1, 4, 1, 4, 2, 1, 1, 
      6, 1, 8, 2, 3, 5, 1, 3, 4, 2, 1, 1, 2, 1, 4, 1, 4, 2, 1, 1, 6, 1, 8, 2, 
      3, 1, 3, 4, 1, 4, 2, 1, 1, 2, 1, 4, 4, 2, 1, 1, 1, 8, 2, 3, 1, 3, 4, 1, 
      4, 7, 2, 1, 1, 2, 1, 4, 4, 2, 1, 1, 1, 2, 3, 1, 3, 4, 4, 7, 9, 2, 1, 1, 
      2, 1, 4, 4, 1, 1, 1, 2, 3, 1, 3, 4, 4, 7, 9, 1, 1, 1, 1, 2, 1, 4, 4, 1, 
      1, 1, 2, 3, 1, 3, 4, 4, 7, 9, 1, 3, 1, 2, 1, 4, 1, 1, 1, 2, 3, 1, 3, 4, 
      4, 7, 9, 1, 3, 5, 1, 2, 1, 4, 1, 1, 2, 3, 1, 3, 4, 4, 7, 9, 1, 3, 5, 1, 
      1, 2, 1, 4, 1, 2, 3, 1, 3, 4, 4, 7, 9, 1, 3, 5, 1, 1, 2, 2, 1, 4, 1, 2, 
      3, 1, 3, 4, 4, 7, 9, 1, 3, 1, 1, 2, 1, 4, 2, 1, 4, 1, 2, 3, 1, 3, 4, 4, 
      7, 1, 3, 1, 1, 2, 1, 4, 3, 6, 2, 1, 4, 1, 3, 1, 3, 4, 4, 7, 1, 3, 1, 1, 
      2, 1, 4, 3, 6, 1, 1, 2, 1, 4, 1, 3, 1, 3, 4, 4, 7, 1, 3, 1, 1, 2, 1, 4, 
      6, 1, 1, 3, 1, 2, 1, 4, 1, 3, 1, 4, 4, 7, 1, 3, 1, 1, 2, 1, 4, 6, 1, 1, 
      3, 1, 2, 2, 2, 1, 4, 1, 3, 1, 4, 4, 7, 1, 3, 1, 2, 1, 4, 6, 1, 1, 3, 1, 
      2, 3, 2, 1, 4, 1, 3, 1, 4, 4, 7, 1, 3, 1, 2, 1, 4, 6, 1, 1, 3, 1, 2, 1, 
      3, 2, 1, 4, 1, 3, 1, 4, 4, 7, 1, 3, 1, 1, 4, 6, 1, 1, 3, 1, 2, 3, 3, 2, 
      1, 4, 1, 3, 1, 4, 4, 7, 1, 1, 1, 4, 6, 1, 1, 3, 1, 2, 3, 3, 1, 2, 1, 1, 
      3, 1, 4, 4, 7, 1, 1, 1, 4, 6, 1, 1, 3, 1, 2, 3, 3, 1, 2, 6, 1, 1, 3, 1, 
      4, 4, 7, 1, 1, 1, 4, 6, 1, 1, 3, 1, 2, 3, 1, 2, 6, 2, 1, 1, 1, 3, 1, 4, 
      4, 1, 1, 1, 4, 6, 1, 1, 3, 1, 2, 3, 1, 2, 6, 2, 1, 6, 1, 1, 1, 3, 4, 1, 
      1, 1, 4, 6, 1, 1, 3, 1, 2, 3, 1, 2, 6, 2, 1, 6, 1, 5, 1, 1, 3, 4, 1, 1, 
      1, 4, 6, 1, 1, 3, 1, 2, 3, 2, 2, 1, 6, 1, 5, 7, 1, 1, 3, 4, 1, 1, 1, 4, 
      6, 1, 1, 3, 1, 2, 3, 2, 1, 6, 1, 5, 7, 1, 2, 1, 1, 3, 4, 1, 1, 1, 4, 6, 
      1, 1, 3, 1, 2, 2, 1, 6, 1, 5, 1, 2, 10, 1, 1, 3, 4, 1, 1, 1, 4, 6, 1, 
      3, 1, 2, 1, 6, 1, 5, 1, 2, 10, 2, 1, 1, 3, 4, 1, 1, 4, 6, 1, 3, 1, 2, 
      1, 6, 1, 5, 2, 10, 2, 2, 1, 1, 4, 1, 1, 4, 6, 1, 3, 1, 2, 1, 1, 5, 2, 
      10, 2, 2, 8, 1, 1, 4, 1, 1, 4, 6, 1, 3, 1, 2, 1, 1, 5, 2, 10, 2, 8, 1, 
      1, 1, 1, 4, 1, 1, 4, 6, 1, 3, 1, 2, 1, 1, 2, 10, 2, 8, 1, 1, 2, 3, 1, 
      1, 4, 1, 1, 4, 6, 1, 3, 1, 2, 1, 2, 10, 2, 8, 1, 1, 2, 4, 1, 1, 4, 1, 
      1, 4, 6, 1, 1, 2, 1, 2, 10, 2, 8, 1, 1, 2, 4, 1, 2, 1, 1, 4, 1, 1, 4, 
      6, 1, 1, 1, 2, 10, 2, 8, 1, 2, 4, 1, 2, 3, 1, 1, 4, 1, 1, 4, 6, 1, 1, 
      1, 2, 10, 2, 8, 2, 4, 2, 3, 2, 1, 1, 4, 1, 1, 4, 6, 1, 1, 1, 2, 10, 2, 
      8, 2, 2, 3, 2, 1, 3, 1, 1, 4, 1, 1, 4, 6, 1, 1, 1, 2, 10, 2, 8, 2, 3, 
      2, 1, 5, 1, 1, 4, 1, 1, 4, 6, 1, 1, 1, 2, 10, 2, 8, 2, 3, 2, 1, 2, 3, 
      1, 1, 4, 1, 1, 4, 6, 1, 1, 1, 2, 10, 2, 2, 3, 2, 1, 2, 3, 4, 5, 1, 1, 
      4, 1, 4, 6, 1, 1, 1, 2, 10, 2, 3, 2, 1, 2, 3, 4, 5, 3, 1, 1, 1, 4, 6, 
      1, 1, 1, 2, 10, 2, 3, 1, 2, 3, 4, 5, 3, 6, 1, 1, 1, 6, 1, 1, 1, 2, 10, 
      2, 3, 1, 2, 3, 5, 3, 6, 8, 1, 1, 1, 6, 1, 1, 1, 2, 10, 2, 3, 1, 2, 3, 
      3, 6, 8, 3, 3, 1, 1, 1, 6, 1, 1, 1, 2, 10, 2, 1, 2, 3, 6, 8, 3, 3, 6, 
      1, 1, 1, 6, 1, 1, 1, 2, 10, 2, 1, 2, 3, 6, 3, 3, 6, 7, 1, 1, 1, 1, 6, 
      1, 1, 1, 2, 10, 2, 1, 2, 3, 3, 3, 6, 7, 1, 2, 4, 1, 1, 1, 6, 1, 1, 1, 
      2, 10, 2, 1, 2, 3, 3, 3, 7, 1, 2, 4, 3, 3, 1, 1, 1, 6, 1, 1, 1, 2, 10, 
      2, 1, 2, 3, 3, 7, 1, 2, 3, 3, 3, 1, 1, 1, 1, 1, 1, 2, 10, 1, 2, 3, 3, 
      7, 1, 2, 3, 3, 3, 8, 1, 1, 1, 1, 1, 1, 2, 10, 1, 2, 3, 3, 7, 1, 2, 3, 
      3, 8, 2, 1, 1, 1, 1, 1, 1, 1, 2, 10, 1, 2, 3, 7, 2, 3, 3, 8, 2, 1, 4, 
      1, 1, 1, 1, 1, 1, 2, 10, 1, 2, 3, 2, 3, 3, 2, 1, 4, 11, 1, 1, 1, 1, 1, 
      2, 10, 1, 2, 3, 2, 3, 2, 1, 4, 11, 3, 1, 1, 1, 1, 1, 2, 10, 1, 2, 2, 3, 
      2, 1, 4, 11, 3, 2, 1, 1, 1, 1, 1, 1, 10, 1, 2, 2, 2, 1, 4, 11, 3, 2, 1, 
      5, 1, 1, 1, 1, 1, 10, 1, 2, 2, 2, 1, 4, 11, 3, 2, 1, 2, 3, 1, 1, 1, 1, 
      10, 1, 2, 2, 2, 1, 4, 11, 3, 2, 1, 3, 3, 1, 1, 1, 1, 1, 2, 2, 1, 4, 11, 
      3, 2, 1, 3, 3, 10, 1, 1, 1, 1, 2, 2, 4, 11, 3, 2, 1, 3, 3, 10, 2, 1, 1, 
      2, 2, 4, 11, 3, 2, 1, 3, 3, 10, 2, 2, 1, 2, 4, 11, 3, 2, 1, 3, 3, 10, 
      2, 2, 3, 1, 2, 4, 3, 2, 1, 3, 10, 2, 2, 3, 10, 1, 2, 4, 3, 2, 1, 10, 2, 
      2, 3, 10, 1, 2, 1, 2, 4, 3, 2, 1, 10, 2, 2, 3, 10, 1, 2, 1, 4, 3, 2, 1, 
      10, 2, 2, 3, 10, 1, 2, 1, 3, 4, 3, 2, 1, 10, 2, 3, 1, 2, 1, 3, 10, 4, 
      3, 2, 1, 10, 2, 1, 2, 1, 3, 10, 2, 1, 4, 2, 1, 10, 2, 1, 2, 1, 3, 10, 
      2, 1, 2, 2, 4, 2, 1, 10, 1, 2, 1, 3, 10, 2, 1, 2, 2, 1, 1, 4, 2, 1, 10, 
      1, 2, 1, 10, 2, 2, 2, 1, 1, 4, 4, 2, 1, 10, 1, 2, 1, 10, 2, 2, 2, 1, 1, 
      4, 1, 2, 1, 10, 1, 2, 1, 10, 2, 2, 2, 1, 1, 4, 1, 2, 3, 2, 1, 10, 1, 2, 
      1, 2, 2, 2, 1, 1, 1, 2, 3, 12, 2, 1, 10, 1, 1, 2, 2, 2, 1, 1, 1, 3, 12, 
      4, 2, 1, 10, 1, 1, 2, 2, 2, 1, 1, 1, 3, 4, 5, 7, 2, 1, 10, 1, 2, 2, 2, 
      1, 1, 3, 4, 5, 7, 1, 2, 1, 10, 1, 2, 2, 2, 1, 1, 3, 5, 7, 1, 2, 2, 2, 
      10, 2, 2, 2, 1, 1, 3, 5, 7, 1, 2, 2, 2, 2, 10, 2, 2, 2, 1, 1, 3, 5, 1, 
      2, 2, 2, 6, 1, 10, 2, 2, 2, 1, 3, 5, 1, 2, 2, 2, 6, 1, 3, 10, 2, 2, 2, 
      1, 3, 5, 1, 2, 2, 6, 1, 3, 1, 1, 10, 2, 2, 2, 1, 3, 1, 2, 2, 6, 1, 3, 
      1, 1, 1, 4, 10, 2, 2, 3, 1, 2, 2, 6, 1, 3, 1, 1, 1, 4, 3, 10, 2, 2, 3, 
      1, 2, 6, 1, 3, 1, 1, 1, 4, 3, 1, 1, 2, 2, 3, 1, 2, 6, 1, 3, 1, 1, 1, 4, 
      3, 1, 1, 4, 6, 2, 2, 3, 1, 2, 6, 1, 3, 1, 1, 1, 4, 3, 1, 1, 6, 3, 2, 2, 
      2, 3, 1, 2, 6, 1, 1, 1, 1, 4, 3, 1, 6, 3, 2, 4, 2, 2, 3, 1, 6, 1, 1, 1, 
      1, 4, 3, 1, 6, 3, 2, 5, 2, 2, 3, 1, 6, 1, 1, 4, 3, 1, 6, 3, 2, 5, 2, 2, 
      2, 3, 1, 1, 4, 3, 1, 6, 3, 2, 5, 2, 7, 2, 2, 3, 1, 3, 1, 6, 3, 2, 5, 2, 
      7, 5, 2, 2, 3, 1, 3, 1, 6, 3, 2, 5, 2, 5, 1, 6, 2, 2, 3, 1, 3, 6, 3, 2, 
      5, 2, 5, 6, 2, 2, 2, 3, 1, 3, 6, 3, 5, 2, 5, 6, 2, 2, 1, 2, 2, 3, 1, 3, 
      6, 3, 5, 5, 6, 2, 1, 3, 2, 2, 3, 3, 6, 3, 5, 5, 6, 2, 1, 3, 1, 1, 2, 2, 
      3, 6, 3, 5, 5, 6, 2, 1, 3, 1, 1, 2, 1, 2, 3, 6, 3, 5, 6, 2, 1, 3, 1, 1, 
      2, 1, 6, 2, 3, 6, 3, 6, 2, 1, 3, 1, 1, 2, 1, 6, 4, 1, 2, 3, 6, 3, 6, 2, 
      1, 3, 1, 1, 2, 1, 4, 1, 1, 5, 2, 3, 6, 3, 6, 2, 1, 1, 1, 2, 1, 4, 1, 1, 
      5, 2, 1, 2, 3, 6, 3, 6, 2, 1, 1, 1, 1, 4, 1, 1, 5, 2, 1, 2, 1, 2, 3, 6, 
      3, 6, 2, 1, 1, 4, 1, 1, 5, 2, 1, 2, 1, 2, 2, 6, 3, 6, 2, 1, 1, 4, 1, 1, 
      5, 2, 1, 2, 1, 2, 2, 1, 2, 3, 6, 2, 1, 1, 4, 1, 1, 5, 2, 1, 2, 1, 2, 2, 
      1, 3, 3, 3, 6, 2, 1, 1, 4, 1, 5, 2, 1, 2, 1, 2, 2, 1, 3, 3, 2, 6, 1, 1, 
      4, 1, 5, 2, 1, 2, 1, 2, 2, 1, 3, 3, 2, 4, 6, 1, 1, 4, 1, 5, 2, 1, 2, 2, 
      2, 1, 3, 3, 2, 5, 6, 1, 4, 1, 5, 2, 1, 2, 2, 1, 3, 3, 2, 5, 3, 1, 4, 1, 
      5, 2, 1, 2, 2, 1, 3, 3, 2, 5, 3, 5, 2, 1, 4, 1, 5, 2, 1, 2, 2, 1, 3, 3, 
      2, 5, 3, 5, 1, 2, 1, 4, 5, 2, 1, 2, 2, 1, 3, 3, 2, 5, 5, 1, 2, 4, 1, 4, 
      5, 2, 1, 2, 2, 1, 3, 2, 5, 5, 1, 2, 4, 2, 1, 1, 4, 5, 2, 1, 2, 1, 2, 5, 
      5, 1, 2, 4, 2, 1, 5, 1, 4, 5, 2, 2, 1, 2, 5, 5, 1, 4, 2, 1, 5, 3, 1, 4, 
      5, 2, 2, 1, 2, 5, 1, 4, 1, 5, 3, 3, 1, 5, 2, 2, 1, 2, 5, 1, 4, 1, 5, 3, 
      3, 3, 1, 5, 2, 2, 1, 2, 5, 1, 4, 1, 5, 3, 3, 3, 2, 5, 2, 2, 1, 2, 5, 1, 
      4, 1, 5, 3, 3, 3, 1, 1, 5, 2, 2, 1, 2, 5, 1, 4, 1, 5, 3, 3, 1, 1, 2, 1, 
      5, 2, 2, 1, 2, 5, 1, 1, 5, 3, 3, 1, 1, 2, 1, 2, 2, 5, 2, 2, 1, 2, 5, 1, 
      1, 3, 3, 1, 1, 2, 1, 2, 2, 3, 2, 5, 2, 2, 1, 2, 5, 1, 1, 3, 3, 1, 1, 2, 
      2, 3, 2, 3, 5, 2, 2, 1, 2, 5, 1, 1, 3, 1, 1, 2, 2, 3, 2, 3, 1, 2, 5, 2, 
      2, 1, 5, 1, 1, 3, 1, 1, 2, 2, 3, 2, 3, 1, 2, 2, 1, 5, 2, 2, 1, 1, 1, 3, 
      1, 1, 2, 2, 3, 2, 3, 1, 2, 2, 1, 4, 2, 5, 2, 2, 1, 1, 1, 3, 1, 1, 2, 2, 
      3, 2, 3, 1, 2, 2, 1, 2, 3, 2, 5, 2, 2, 1, 1, 1, 3, 1, 1, 2, 2, 2, 3, 1, 
      2, 2, 1, 2, 3, 5, 5, 2, 1, 1, 1, 3, 1, 1, 2, 2, 2, 3, 1, 2, 1, 2, 3, 5, 
      4, 5, 2, 1, 1, 1, 3, 1, 1, 2, 2, 2, 3, 1, 2, 1, 2, 3, 4, 1, 5, 5, 2, 1, 
      1, 1, 3, 1, 1, 2, 2, 2, 3, 1, 1, 2, 3, 4, 1, 5, 2, 1, 5, 2, 1, 1, 1, 3, 
      1, 1, 2, 2, 3, 1, 1, 2, 3, 4, 1, 5, 2, 1, 1, 1, 5, 2, 1, 1, 1, 3, 1, 1, 
      2, 2, 3, 1, 2, 3, 4, 5, 2, 1, 1, 1, 2, 5, 2, 1, 1, 1, 3, 1, 1, 2, 2, 3, 
      1, 2, 3, 5, 2, 1, 1, 1, 2, 2, 2, 5, 2, 1, 1, 1, 3, 1, 1, 2, 2, 1, 2, 3, 
      5, 2, 1, 1, 1, 2, 2, 2, 2, 1, 5, 2, 1, 1, 1, 3, 1, 1, 2, 1, 2, 3, 2, 1, 
      1, 1, 2, 2, 2, 2, 1, 7, 5, 2, 1, 1, 1, 3, 1, 1, 2, 1, 2, 3, 2, 1, 1, 1, 
      2, 2, 2, 1, 7, 1, 2, 5, 2, 1, 1, 1, 3, 1, 2, 1, 2, 3, 2, 1, 1, 2, 2, 2, 
      1, 7, 1, 2, 2, 5, 2, 1, 1, 1, 3, 1, 2, 1, 2, 3, 2, 1, 1, 2, 2, 2, 1, 7, 
      1, 2, 1, 1, 5, 2, 1, 1, 1, 3, 1, 2, 1, 2, 3, 2, 1, 1, 2, 2, 2, 1, 7, 2, 
      1, 2, 5, 2, 1, 1, 1, 3, 1, 2, 1, 2, 3, 2, 1, 1, 2, 2, 1, 7, 2, 1, 2, 1, 
      1, 5, 2, 1, 1, 1, 3, 1, 2, 1, 2, 3, 2, 1, 1, 2, 2, 1, 2, 1, 2, 1, 1, 3, 
      4, 5, 2, 1, 1, 1, 3, 1, 2, 1, 2, 3, 1, 1, 2, 2, 1, 2, 1, 2, 1, 1, 4, 5, 
      5, 2, 1, 1, 1, 3, 1, 2, 1, 2, 3, 1, 1, 2, 1, 2, 1, 2, 1, 1, 5, 6, 5, 2, 
      1, 1, 1, 3, 1, 2, 1, 3, 1, 1, 1, 2, 1, 2, 1, 1, 5, 6, 4, 5, 2, 1, 1, 1, 
      3, 1, 2, 1, 1, 1, 2, 1, 2, 1, 1, 5, 6, 4, 3, 5, 1, 1, 1, 3, 1, 2, 1, 1, 
      1, 2, 1, 1, 1, 5, 6, 4, 3, 4, 1, 1, 1, 3, 1, 2, 1, 1, 1, 2, 1, 1, 1, 5, 
      6, 4, 3, 4, 4, 2, 1, 1, 1, 3, 1, 2, 1, 1, 1, 1, 1, 1, 5, 6, 4, 3, 4, 4, 
      2, 1, 2, 1, 1, 1, 3, 1, 2, 1, 1, 1, 1, 1, 1, 5, 4, 3, 4, 4, 2, 1, 2, 5, 
      1, 1, 1, 1, 3, 1, 2, 1, 1, 1, 1, 1, 5, 4, 3, 4, 4, 1, 2, 5, 1, 3, 1, 1, 
      1, 3, 1, 2, 1, 1, 1, 1, 1, 5, 4, 3, 4, 1, 2, 5, 1, 3, 3, 1, 1, 1, 1, 3, 
      1, 2, 1, 1, 1, 1, 1, 4, 3, 4, 1, 2, 5, 1, 3, 3, 1, 2, 3, 1, 1, 1, 3, 1, 
      2, 1, 1, 1, 1, 1, 4, 3, 4, 1, 2, 1, 3, 3, 1, 2, 3, 2, 3, 1, 1, 3, 1, 2, 
      1, 1, 1, 1, 1, 4, 3, 4, 2, 1, 3, 3, 1, 2, 3, 2, 3, 2, 1, 1, 3, 1, 2, 1, 
      1, 1, 1, 1, 3, 4, 2, 1, 3, 3, 1, 2, 3, 3, 2, 5, 1, 3, 1, 2, 1, 1, 1, 1, 
      1, 3, 4, 2, 1, 3, 3, 1, 2, 3, 3, 2, 5, 1, 3, 1, 1, 1, 1, 1, 1, 3, 4, 2, 
      3, 3, 1, 2, 3, 3, 2, 5, 3, 1, 3, 1, 1, 1, 1, 1, 3, 4, 2, 3, 3, 2, 3, 3, 
      2, 5, 3, 2, 1, 3, 1, 1, 1, 1, 1, 3, 4, 2, 3, 2, 3, 3, 2, 5, 3, 4, 1, 3, 
      1, 1, 1, 1, 3, 4, 2, 3, 2, 3, 3, 2, 5, 4, 4, 1, 3, 1, 1, 1, 1, 3, 4, 2, 
      3, 2, 3, 3, 2, 4, 4, 5, 1, 1, 3, 1, 1, 1, 1, 3, 4, 2, 3, 3, 3, 4, 4, 5, 
      1, 4, 1, 3, 1, 1, 3, 4, 2, 3, 3, 3, 4, 4, 5, 1, 4, 2, 1, 3, 1, 1, 3, 4, 
      2, 3, 3, 3, 4, 5, 1, 4, 2, 4, 1, 1, 3, 1, 1, 3, 4, 2, 3, 3, 3, 4, 5, 1, 
      4, 4, 3, 1, 3, 1, 3, 4, 2, 3, 3, 3, 4, 5, 1, 4, 4, 3, 1, 1, 3, 1, 3, 4, 
      2, 3, 3, 4, 5, 1, 4, 4, 3, 1, 1, 4, 3, 3, 4, 2, 3, 3, 4, 5, 1, 4, 4, 3, 
      1, 1, 5, 3, 3, 4, 2, 3, 3, 4, 5, 1, 4, 4, 3, 1, 1, 1, 4, 3, 3, 4, 2, 3, 
      3, 4, 5, 1, 4, 4, 1, 1, 1, 4, 2, 1, 3, 3, 4, 2, 3, 3, 5, 1, 4, 4, 1, 1, 
      1, 4, 2, 1, 3, 1, 3, 3, 4, 2, 3, 3, 5, 1, 4, 4, 1, 1, 1, 4, 2, 1, 1, 1, 
      2, 3, 3, 4, 2, 3, 3, 5, 1, 4, 1, 1, 1, 4, 2, 1, 1, 1, 2, 1, 4, 3, 3, 4, 
      2, 3, 3, 5, 1, 1, 1, 1, 4, 2, 1, 1, 1, 2, 1, 4, 2, 2, 3, 3, 4, 3, 3, 5, 
      1, 1, 1, 1, 4, 2, 1, 1, 1, 1, 4, 2, 2, 4, 3, 3, 4, 3, 3, 5, 1, 1, 1, 1, 
      4, 2, 1, 1, 1, 4, 2, 2, 4, 1, 1, 3, 3, 4, 3, 3, 5, 1, 1, 1, 4, 2, 1, 1, 
      1, 4, 2, 2, 4, 1, 1, 1, 1, 3, 3, 4, 3, 3, 1, 1, 1, 4, 2, 1, 1, 1, 4, 2, 
      2, 4, 1, 1, 1, 1, 5, 1, 3, 3, 4, 3, 3, 1, 1, 1, 4, 2, 1, 1, 4, 2, 2, 4, 
      1, 1, 1, 5, 1, 2, 3, 4, 3, 3, 1, 1, 1, 4, 2, 1, 1, 4, 2, 2, 4, 1, 1, 1, 
      5, 2, 4, 3, 4, 3, 1, 1, 1, 4, 2, 1, 1, 4, 2, 2, 4, 1, 1, 5, 2, 4, 4, 3, 
      4, 3, 1, 1, 1, 2, 1, 1, 4, 2, 2, 4, 1, 1, 5, 2, 4, 4, 2, 2, 3, 4, 3, 1, 
      1, 1, 2, 1, 1, 4, 2, 2, 4, 1, 1, 5, 4, 4, 2, 2, 1, 1, 3, 4, 3, 1, 1, 2, 
      1, 4, 2, 2, 4, 1, 1, 5, 4, 4, 2, 2, 1, 1, 2, 3, 4, 3, 1, 1, 2, 1, 4, 2, 
      2, 4, 1, 5, 4, 4, 2, 2, 1, 2, 2, 3, 4, 3, 1, 1, 2, 1, 2, 2, 4, 1, 5, 4, 
      4, 2, 2, 1, 2, 2, 1, 3, 3, 4, 3, 1, 2, 1, 2, 2, 4, 1, 5, 4, 4, 2, 2, 1, 
      2, 1, 3, 3, 3, 4, 3, 1, 2, 1, 2, 2, 4, 1, 5, 4, 4, 2, 2, 1, 1, 3, 3, 1, 
      1, 3, 4, 3, 1, 2, 1, 2, 2, 4, 1, 5, 4, 4, 2, 2, 1, 1, 3, 1, 1, 2, 1, 3, 
      4, 3, 1, 2, 1, 2, 2, 4, 1, 5, 4, 2, 2, 1, 1, 3, 1, 2, 1, 5, 3, 4, 3, 1, 
      2, 1, 2, 4, 1, 5, 4, 2, 2, 1, 1, 3, 1, 2, 1, 5, 2, 1, 3, 4, 3, 1, 2, 1, 
      2, 4, 5, 4, 2, 1, 1, 3, 1, 2, 1, 5, 2, 1, 2, 3, 4, 3, 1, 2, 1, 2, 4, 5, 
      4, 2, 1, 3, 2, 1, 5, 2, 1, 2, 2, 3, 4, 3, 2, 1, 2, 4, 4, 2, 1, 3, 2, 1, 
      5, 2, 1, 2, 2, 6, 3, 3, 2, 1, 2, 4, 4, 2, 1, 3, 2, 1, 5, 2, 1, 2, 6, 6, 
      3, 3, 2, 1, 2, 4, 4, 2, 1, 3, 2, 1, 2, 1, 2, 6, 6, 3, 2, 3, 3, 2, 1, 2, 
      4, 4, 2, 1, 3, 1, 2, 1, 2, 6, 3, 4, 1, 5, 3, 3, 2, 1, 2, 4, 4, 2, 1, 3, 
      1, 2, 1, 2, 6, 3, 4, 1, 5, 3, 3, 2, 1, 2, 4, 4, 3, 1, 2, 1, 2, 6, 3, 4, 
      1, 5, 2, 2, 1, 2, 4, 4, 3, 1, 2, 1, 2, 6, 3, 4, 1, 5, 2, 6, 2, 1, 2, 4, 
      3, 1, 2, 1, 2, 6, 3, 4, 1, 5, 2, 6, 1, 3, 2, 1, 2, 4, 3, 1, 2, 1, 2, 6, 
      3, 1, 5, 6, 1, 3, 6, 2, 1, 2, 4, 3, 1, 2, 1, 2, 6, 3, 1, 5, 1, 3, 6, 4, 
      3, 2, 1, 2, 4, 3, 1, 2, 1, 2, 6, 3, 1, 5, 1, 3, 4, 3, 3, 3, 2, 1, 2, 4, 
      3, 1, 2, 1, 2, 3, 1, 5, 1, 3, 4, 3, 3, 9, 2, 1, 2, 4, 3, 1, 2, 1, 3, 1, 
      5, 3, 4, 3, 3, 9, 3, 2, 1, 4, 3, 1, 2, 1, 3, 1, 5, 3, 3, 3, 9, 3, 6, 2, 
      1, 4, 3, 1, 2, 1, 3, 1, 5, 3, 3, 3, 9, 6, 1, 2, 2, 1, 3, 1, 2, 3, 1, 5, 
      3, 3, 3, 9, 6, 1, 2, 5, 2, 1, 3, 1, 2, 3, 1, 5, 3, 3, 3, 6, 1, 2, 5, 3, 
      7, 2, 3, 1, 2, 3, 1, 5, 3, 3, 6, 1, 2, 5, 3, 7, 4, 2, 3, 2, 1, 5, 3, 3, 
      6, 1, 2, 5, 3, 7, 4, 4, 3, 2, 1, 5, 3, 3, 6, 1, 2, 5, 3, 4, 4, 9, 3, 2, 
      1, 3, 3, 6, 1, 2, 5, 3, 4, 4, 9, 3, 2, 3, 2, 1, 3, 3, 6, 1, 2, 5, 3, 4, 
      9, 3, 2, 1, 3, 3, 1, 3, 6, 1, 2, 5, 3, 4, 9, 3, 2, 1, 3, 5, 3, 1, 3, 6, 
      1, 2, 5, 3, 4, 3, 2, 1, 3, 5, 2, 7, 3, 1, 3, 6, 1, 2, 5, 3, 3, 2, 1, 3, 
      5, 2, 7, 3, 1, 3, 1, 3, 6, 1, 2, 5, 3, 3, 2, 1, 3, 5, 2, 3, 7, 3, 1, 6, 
      1, 2, 5, 3, 3, 2, 1, 3, 5, 2, 3, 7, 2, 1, 3, 1, 1, 2, 5, 3, 3, 2, 1, 3, 
      5, 2, 3, 7, 2, 1, 4, 2, 3, 1, 1, 2, 3, 2, 1, 3, 5, 2, 3, 7, 2, 1, 4, 2, 
      7, 3, 1, 1, 2, 3, 2, 1, 3, 5, 2, 3, 2, 1, 4, 2, 7, 5, 2, 3, 1, 1, 2, 3, 
      2, 1, 3, 5, 2, 3, 2, 1, 4, 2, 5, 2, 5, 2, 3, 1, 1, 2, 3, 2, 1, 3, 5, 2, 
      3, 2, 1, 4, 2, 5, 5, 4, 3, 1, 1, 2, 3, 2, 1, 3, 5, 2, 3, 2, 1, 4, 2, 5, 
      4, 4, 1, 3, 1, 1, 2, 3, 1, 3, 5, 2, 3, 2, 4, 2, 5, 4, 4, 1, 1, 3, 1, 1, 
      2, 3, 1, 3, 5, 2, 3, 2, 4, 2, 5, 4, 1, 1, 4, 1, 3, 1, 1, 2, 3, 1, 3, 5, 
      2, 2, 4, 2, 5, 4, 1, 1, 1, 7, 3, 1, 1, 2, 3, 1, 3, 5, 2, 2, 4, 2, 4, 1, 
      1, 1, 7, 2, 3, 3, 1, 2, 3, 3, 5, 2, 2, 4, 2, 4, 1, 1, 1, 7, 2, 3, 2, 3, 
      1, 2, 3, 3, 5, 2, 2, 2, 4, 1, 1, 7, 2, 3, 2, 5, 1, 2, 3, 3, 5, 2, 2, 2, 
      4, 1, 1, 7, 2, 3, 2, 5, 1, 3, 1, 2, 3, 3, 5, 2, 2, 2, 4, 1, 1, 2, 3, 2, 
      5, 1, 3, 3, 4, 1, 2, 3, 3, 5, 2, 2, 2, 4, 1, 1, 3, 2, 5, 1, 3, 3, 6, 1, 
      2, 3, 3, 5, 2, 2, 4, 1, 1, 3, 2, 5, 1, 3, 3, 6, 1, 1, 2, 3, 5, 2, 2, 4, 
      1, 1, 3, 2, 5, 1, 3, 3, 6, 1, 1, 4, 2, 3, 2, 2, 4, 1, 1, 3, 2, 5, 1, 3, 
      3, 6, 1, 1, 4, 2, 3, 2, 2, 2, 4, 1, 1, 2, 5, 1, 3, 3, 6, 1, 1, 4, 2, 3, 
      6, 2, 2, 2, 4, 1, 1, 2, 5, 1, 3, 3, 1, 1, 4, 2, 3, 6, 1, 6, 2, 2, 4, 1, 
      1, 2, 5, 1, 3, 1, 1, 4, 2, 3, 6, 1, 6, 5, 2, 4, 1, 2, 5, 1, 3, 1, 1, 4, 
      2, 3, 6, 1, 6, 5, 3, 2, 4, 1, 2, 5, 1, 3, 1, 1, 2, 3, 6, 1, 5, 3, 10, 
      2, 4, 1, 2, 5, 1, 3, 1, 1, 2, 3, 6, 1, 5, 10, 1, 2, 2, 4, 1, 2, 1, 3, 
      1, 1, 2, 3, 6, 1, 5, 10, 1, 2, 4, 1, 2, 4, 1, 2, 1, 3, 1, 1, 2, 3, 6, 
      1, 5, 1, 2, 4, 1, 8, 2, 2, 4, 1, 2, 1, 1, 2, 3, 6, 1, 5, 1, 2, 4, 1, 8, 
      2, 4, 2, 4, 1, 1, 1, 2, 3, 6, 1, 5, 2, 4, 1, 8, 2, 4, 2, 4, 1, 1, 1, 2, 
      3, 6, 1, 5, 2, 4, 1, 8, 2, 4, 2, 1, 1, 4, 1, 1, 1, 2, 3, 6, 1, 5, 2, 4, 
      8, 2, 4, 2, 1, 1, 1, 1, 1, 1, 2, 3, 6, 1, 5, 2, 4, 8, 2, 4, 2, 1, 1, 1, 
      1, 5, 1, 1, 2, 3, 6, 1, 5, 4, 8, 2, 4, 2, 1, 1, 1, 5, 3, 1, 1, 2, 3, 6, 
      1, 4, 8, 2, 4, 2, 1, 1, 1, 5, 3, 2, 3, 1, 1, 2, 3, 6, 1, 4, 8, 2, 4, 2, 
      1, 1, 1, 3, 2, 3, 5, 1, 1, 1, 2, 3, 6, 1, 8, 2, 4, 2, 1, 1, 1, 2, 3, 5, 
      1, 7, 1, 1, 2, 6, 1, 8, 2, 4, 1, 1, 1, 2, 3, 5, 1, 7, 5, 1, 1, 2, 6, 1, 
      2, 4, 1, 1, 1, 2, 3, 5, 1, 7, 5, 2, 7, 1, 2, 6, 1, 2, 4, 1, 1, 1, 2, 3, 
      5, 1, 7, 5, 2, 8, 1, 2, 6, 1, 2, 4, 1, 1, 1, 2, 3, 5, 1, 5, 8, 8, 1, 2, 
      6, 1, 2, 4, 1, 1, 1, 2, 3, 5, 1, 8, 8, 2, 4, 1, 2, 6, 1, 2, 4, 1, 1, 2, 
      5, 1, 8, 8, 2, 4, 3, 1, 2, 6, 1, 2, 4, 1, 1, 2, 5, 1, 8, 8, 2, 3, 4, 1, 
      1, 2, 6, 1, 2, 4, 1, 1, 5, 1, 8, 8, 2, 3, 4, 1, 2, 1, 1, 2, 6, 1, 2, 4, 
      1, 1, 1, 8, 8, 2, 3, 4, 1, 2, 1, 1, 4, 1, 2, 6, 1, 2, 4, 1, 1, 1, 8, 8, 
      2, 3, 4, 1, 2, 1, 5, 1, 2, 6, 1, 2, 4, 1, 1, 1, 8, 2, 3, 4, 1, 2, 1, 5, 
      7, 2, 1, 2, 6, 1, 2, 4, 1, 1, 1, 2, 3, 4, 1, 2, 1, 5, 7, 2, 5, 4, 1, 2, 
      6, 1, 2, 4, 1, 1, 1, 3, 4, 1, 2, 1, 5, 7, 2, 5, 4, 2, 1, 1, 2, 6, 1, 2, 
      4, 1, 1, 1, 3, 1, 2, 1, 5, 7, 2, 5, 4, 2, 1, 1, 3, 1, 2, 6, 1, 2, 1, 1, 
      1, 3, 1, 2, 1, 5, 7, 2, 5, 4, 2, 1, 3, 4, 1, 2, 6, 1, 2, 1, 1, 3, 1, 2, 
      1, 5, 7, 2, 5, 4, 2, 1, 3, 4, 1, 1, 1, 2, 6, 1, 2, 1, 1, 3, 1, 2, 1, 5, 
      7, 5, 4, 2, 1, 3, 4, 1, 1, 1, 1, 1, 2, 6, 1, 2, 1, 1, 3, 2, 1, 5, 7, 5, 
      2, 1, 3, 4, 1, 1, 1, 1, 4, 1, 2, 6, 1, 2, 1, 3, 2, 1, 5, 7, 2, 1, 3, 4, 
      1, 1, 1, 1, 4, 6, 1, 2, 6, 2, 1, 3, 2, 1, 5, 7, 2, 1, 3, 4, 1, 1, 1, 4, 
      6, 2, 1, 2, 6, 2, 1, 3, 2, 1, 5, 7, 2, 1, 3, 4, 1, 1, 1, 4, 6, 1, 1, 1, 
      2, 6, 2, 1, 3, 2, 1, 5, 7, 2, 1, 3, 4, 1, 1, 1, 6, 1, 1, 1, 3, 1, 2, 6, 
      2, 1, 3, 2, 1, 5, 7, 2, 1, 3, 1, 1, 1, 6, 1, 1, 3, 5, 1, 6, 2, 1, 3, 2, 
      1, 5, 7, 2, 1, 1, 1, 1, 6, 1, 1, 3, 5, 5, 1, 2, 1, 3, 2, 1, 5, 2, 1, 1, 
      1, 1, 6, 1, 1, 3, 5, 5, 13, 1, 1, 3, 2, 1, 5, 2, 1, 1, 1, 1, 6, 1, 1, 
      3, 5, 5, 13, 1, 1, 1, 1, 3, 2, 1, 5, 2, 1, 1, 1, 1, 6, 1, 1, 5, 5, 13, 
      1, 4, 1, 1, 2, 1, 5, 2, 1, 1, 1, 1, 6, 1, 1, 5, 5, 13, 1, 4, 3, 1, 1, 
      1, 2, 1, 5, 2, 1, 1, 1, 1, 6, 1, 1, 5, 5, 1, 4, 3, 1, 8, 5, 1, 1, 2, 1, 
      5, 2, 1, 1, 1, 1, 6, 1, 5, 5, 4, 3, 1, 8, 5, 2, 1, 1, 2, 1, 5, 2, 1, 1, 
      1, 1, 6, 1, 5, 4, 3, 1, 5, 2, 7, 1, 1, 2, 1, 5, 2, 1, 1, 1, 1, 6, 1, 5, 
      4, 3, 1, 5, 2, 7, 1, 1, 1, 2, 1, 5, 2, 1, 1, 1, 1, 6, 1, 4, 3, 1, 5, 2, 
      1, 8, 1, 1, 1, 5, 2, 1, 1, 1, 1, 6, 1, 4, 3, 1, 5, 2, 8, 3, 1, 1, 1, 5, 
      2, 1, 1, 1, 1, 6, 1, 4, 3, 1, 5, 2, 8, 1, 3, 1, 1, 1, 5, 2, 1, 1, 1, 1, 
      6, 1, 4, 5, 2, 8, 1, 3, 3, 1, 1, 1, 5, 2, 1, 1, 1, 1, 6, 1, 4, 5, 2, 8, 
      1, 3, 1, 2, 1, 1, 1, 5, 2, 1, 1, 1, 1, 6, 1, 4, 5, 2, 8, 1, 3, 3, 1, 1, 
      1, 5, 2, 1, 1, 1, 1, 6, 1, 4, 5, 8, 3, 3, 3, 1, 1, 1, 5, 2, 1, 1, 1, 1, 
      6, 1, 4, 5, 3, 3, 3, 6, 2, 1, 1, 1, 5, 2, 1, 1, 1, 1, 6, 1, 4, 5, 3, 3, 
      3, 2, 4, 2, 1, 1, 5, 2, 1, 1, 1, 1, 6, 1, 4, 5, 3, 3, 3, 4, 2, 3, 1, 1, 
      5, 2, 1, 1, 1, 6, 1, 4, 5, 3, 3, 3, 4, 2, 4, 1, 1, 5, 2, 1, 1, 1, 6, 1, 
      4, 5, 3, 3, 4, 2, 4, 1, 2, 1, 1, 2, 1, 1, 1, 6, 1, 4, 5, 3, 4, 2, 4, 1, 
      2, 8, 1, 1, 2, 1, 1, 1, 6, 1, 4, 5, 4, 2, 4, 1, 2, 8, 2, 1, 1, 1, 1, 1, 
      1, 6, 1, 4, 5, 4, 2, 4, 1, 2, 8, 2, 3, 1, 1, 1, 6, 1, 4, 5, 4, 2, 4, 1, 
      2, 8, 2, 3, 2, 1, 1, 1, 6, 1, 4, 5, 4, 2, 4, 1, 2, 8, 2, 3, 1, 1, 1, 1, 
      1, 6, 1, 4, 5, 4, 2, 4, 1, 2, 8, 2, 1, 1, 2, 1, 1, 1, 1, 6, 1, 4, 5, 4, 
      2, 1, 2, 8, 2, 1, 1, 2, 1, 3, 2, 1, 1, 1, 6, 1, 4, 5, 4, 2, 1, 2, 8, 2, 
      1, 1, 2, 1, 3, 1, 1, 1, 1, 1, 6, 1, 4, 5, 2, 1, 2, 8, 2, 1, 1, 2, 1, 3, 
      1, 1, 1, 3, 1, 1, 1, 6, 1, 4, 5, 1, 2, 8, 2, 1, 1, 2, 1, 3, 1, 1, 1, 3, 
      1, 2, 1, 1, 1, 6, 1, 4, 5, 1, 2, 8, 2, 1, 1, 2, 1, 3, 1, 1, 1, 3, 1, 1, 
      1, 1, 1, 1, 1, 4, 5, 1, 2, 8, 2, 1, 1, 2, 3, 1, 1, 1, 3, 1, 1, 1, 7, 1, 
      1, 1, 1, 4, 5, 1, 2, 8, 2, 1, 1, 2, 3, 1, 1, 1, 3, 1, 1, 7, 1, 1, 1, 1, 
      1, 1, 4, 5, 1, 2, 8, 2, 1, 1, 2, 3, 1, 1, 1, 3, 1, 1, 1, 1, 5, 2, 1, 1, 
      1, 4, 5, 1, 2, 2, 1, 1, 2, 3, 1, 1, 1, 3, 1, 1, 1, 1, 5, 2, 8, 1, 1, 1, 
      4, 5, 1, 2, 2, 1, 1, 2, 3, 1, 1, 1, 3, 1, 1, 1, 2, 8, 6, 1, 1, 1, 4, 5, 
      1, 2, 2, 1, 1, 2, 1, 1, 1, 3, 1, 1, 2, 8, 6, 4, 1, 1, 1, 4, 5, 1, 2, 1, 
      1, 2, 1, 1, 1, 1, 1, 2, 8, 6, 4, 5, 1, 1, 1, 4, 5, 1, 2, 1, 1, 2, 1, 1, 
      1, 1, 1, 2, 6, 4, 5, 4, 4, 1, 1, 1, 4, 5, 1, 2, 1, 2, 1, 1, 1, 1, 1, 2, 
      6, 5, 4, 4, 5, 1, 1, 1, 4, 5, 1, 2, 1, 2, 1, 1, 1, 1, 1, 2, 6, 5, 4, 4, 
      1, 4, 1, 1, 1, 4, 5, 1, 2, 1, 2, 1, 1, 1, 1, 1, 2, 6, 4, 4, 1, 4, 2, 3, 
      1, 1, 1, 4, 5, 1, 2, 1, 2, 1, 1, 1, 1, 1, 2, 6, 4, 1, 4, 3, 6, 1, 1, 1, 
      4, 5, 2, 1, 2, 1, 1, 1, 1, 1, 6, 4, 1, 4, 3, 6, 3, 1, 1, 1, 4, 2, 1, 2, 
      1, 1, 1, 1, 1, 6, 4, 1, 3, 6, 3, 6, 1, 1, 1, 4, 2, 1, 2, 1, 1, 1, 1, 1, 
      6, 4, 1, 3, 3, 6, 2, 4, 1, 1, 1, 4, 2, 1, 2, 1, 1, 1, 1, 6, 4, 1, 3, 3, 
      2, 4, 6, 1, 1, 1, 4, 2, 1, 2, 1, 1, 1, 1, 6, 4, 1, 3, 2, 4, 6, 2, 1, 1, 
      1, 1, 4, 2, 2, 1, 1, 1, 1, 6, 4, 1, 3, 2, 4, 6, 1, 3, 1, 1, 4, 2, 2, 1, 
      1, 1, 1, 6, 4, 1, 3, 4, 6, 1, 3, 3, 1, 1, 4, 2, 2, 1, 1, 1, 1, 6, 4, 1, 
      4, 6, 3, 3, 4, 1, 1, 4, 2, 1, 1, 1, 6, 4, 1, 4, 6, 3, 3, 4, 3, 1, 1, 4, 
      2, 1, 1, 1, 4, 1, 4, 6, 3, 3, 4, 3, 2, 4, 1, 1, 4, 2, 1, 1, 1, 1, 4, 6, 
      3, 3, 4, 3, 2, 4, 1, 3, 1, 4, 2, 1, 1, 1, 4, 6, 3, 3, 4, 3, 2, 4, 1, 3, 
      2, 1, 4, 2, 1, 1, 1, 4, 6, 3, 4, 3, 2, 4, 1, 3, 2, 2, 1, 4, 2, 1, 1, 1, 
      4, 6, 3, 3, 2, 4, 1, 3, 2, 2, 1, 5, 4, 2, 1, 1, 1, 4, 6, 3, 3, 2, 4, 1, 
      3, 2, 2, 1, 1, 4, 2, 1, 1, 1, 4, 6, 3, 3, 2, 4, 1, 3, 2, 2, 1, 1, 4, 2, 
      2, 2, 1, 1, 1, 4, 3, 3, 2, 4, 1, 3, 2, 2, 1, 4, 2, 2, 7, 2, 1, 1, 1, 4, 
      3, 3, 2, 1, 3, 2, 2, 1, 4, 2, 2, 7, 3, 1, 2, 1, 1, 1, 4, 3, 2, 1, 3, 2, 
      2, 1, 4, 2, 2, 7, 3, 1, 1, 2, 2, 1, 1, 1, 4, 3, 1, 3, 2, 2, 1, 4, 2, 7, 
      3, 1, 1, 2, 4, 2, 1, 1, 1, 4, 3, 1, 2, 2, 1, 4, 2, 7, 3, 1, 1, 4, 5, 2, 
      1, 1, 1, 4, 3, 1, 2, 2, 1, 2, 7, 3, 1, 1, 4, 5, 2, 2, 2, 1, 1, 1, 4, 1, 
      2, 2, 1, 2, 7, 3, 1, 1, 4, 5, 2, 2, 2, 1, 2, 1, 1, 1, 4, 1, 2, 2, 2, 7, 
      3, 1, 1, 4, 5, 2, 2, 2, 1, 1, 1, 2, 1, 1, 1, 4, 2, 2, 7, 3, 1, 1, 4, 5, 
      2, 2, 2, 1, 1, 1, 3, 2, 1, 1, 1, 4, 2, 3, 1, 1, 4, 5, 2, 2, 2, 1, 1, 1, 
      3, 9, 2, 1, 1, 1, 4, 2, 3, 1, 4, 5, 2, 2, 1, 1, 1, 3, 9, 3, 1, 1, 1, 4, 
      2, 3, 1, 4, 5, 2, 1, 1, 1, 3, 9, 3, 4, 1, 1, 1, 4, 2, 3, 1, 4, 5, 2, 1, 
      1, 1, 3, 9, 3, 2, 2, 1, 1, 1, 4, 2, 3, 1, 4, 5, 2, 1, 1, 1, 3, 9, 2, 2, 
      2, 2, 1, 1, 1, 4, 2, 1, 4, 5, 2, 1, 1, 1, 3, 9, 2, 2, 2, 2, 2, 2, 1, 1, 
      1, 4, 2, 1, 4, 5, 1, 1, 1, 3, 9, 2, 2, 2, 2, 2, 2, 1, 1, 1, 1, 1, 4, 2, 
      1, 5, 1, 1, 1, 3, 9, 2, 2, 2, 2, 2, 2, 1, 1, 2, 2, 1, 1, 1, 4, 2, 1, 5, 
      1, 1, 3, 2, 2, 2, 2, 2, 2, 1, 1, 2, 2, 10, 1, 1, 1, 4, 2, 1, 5, 1, 1, 
      2, 2, 2, 2, 2, 2, 1, 1, 2, 2, 10, 1, 3, 1, 1, 1, 4, 2, 1, 5, 1, 1, 2, 
      2, 2, 2, 2, 1, 2, 2, 10, 1, 3, 3, 1, 1, 1, 4, 2, 1, 5, 1, 1, 2, 2, 2, 
      2, 2, 1, 2, 2, 1, 3, 3, 8, 2, 1, 1, 1, 4, 2, 1, 5, 1, 1, 2, 2, 2, 2, 1, 
      2, 2, 3, 3, 8, 2, 3, 1, 1, 1, 4, 2, 1, 5, 1, 1, 2, 2, 2, 2, 1, 2, 2, 3, 
      8, 2, 3, 1, 2, 1, 1, 1, 4, 2, 1, 5, 1, 1, 2, 2, 2, 1, 2, 2, 3, 2, 3, 1, 
      2, 9, 1, 1, 1, 4, 2, 1, 5, 1, 1, 2, 2, 1, 2, 3, 2, 3, 1, 2, 9, 4, 1, 1, 
      1, 4, 2, 1, 5, 1, 1, 2, 1, 2, 2, 3, 1, 2, 9, 4, 5, 1, 1, 1, 4, 2, 1, 5, 
      1, 1, 2, 1, 2, 2, 3, 1, 2, 9, 4, 4, 1, 1, 1, 4, 2, 1, 5, 1, 2, 1, 2, 2, 
      3, 1, 2, 9, 4, 4, 1, 2, 1, 1, 4, 2, 1, 5, 1, 2, 1, 2, 1, 2, 9, 4, 4, 1, 
      2, 5, 1, 1, 4, 2, 1, 1, 2, 1, 2, 2, 9, 4, 4, 1, 2, 5, 5, 1, 1, 2, 1, 1, 
      2, 1, 2, 2, 9, 4, 1, 2, 5, 5, 8, 1, 1, 2, 1, 1, 2, 1, 2, 2, 4, 1, 2, 5, 
      5, 8, 4, 6, 1, 1, 2, 1, 1, 2, 1, 2, 2, 4, 2, 5, 5, 8, 6, 5, 1, 1, 2, 1, 
      1, 2, 1, 2, 2, 4, 2, 5, 8, 6, 5, 1, 4, 1, 1, 2, 1, 1, 2, 1, 2, 2, 4, 2, 
      5, 8, 6, 1, 4, 4, 1, 1, 1, 2, 1, 1, 1, 2, 2, 4, 2, 5, 8, 6, 1, 4, 4, 1, 
      2, 1, 1, 2, 1, 1, 1, 2, 2, 4, 2, 5, 8, 6, 1, 4, 1, 2, 1, 5, 1, 2, 1, 1, 
      1, 2, 2, 4, 5, 8, 6, 1, 4, 1, 1, 5, 4, 1, 2, 1, 1, 2, 2, 4, 8, 6, 1, 4, 
      1, 1, 5, 4, 6, 1, 2, 1, 1, 2, 2, 8, 6, 1, 4, 1, 1, 5, 4, 6, 2, 2, 1, 2, 
      1, 1, 2, 2, 8, 6, 1, 4, 1, 1, 4, 6, 2, 2, 4, 1, 2, 1, 1, 2, 2, 6, 1, 4, 
      1, 1, 4, 6, 2, 2, 4, 1, 9, 2, 1, 1, 2, 2, 6, 1, 1, 1, 4, 6, 2, 2, 4, 1, 
      9, 2, 2, 2, 1, 1, 2, 2, 6, 1, 1, 1, 6, 2, 2, 4, 1, 9, 2, 2, 2, 3, 2, 1, 
      1, 2, 2, 6, 1, 1, 6, 2, 2, 4, 1, 9, 2, 2, 3, 3, 2, 1, 1, 2, 2, 6, 1, 1, 
      6, 2, 2, 4, 1, 9, 2, 2, 3, 2, 2, 2, 1, 1, 2, 2, 6, 1, 1, 6, 2, 4, 1, 2, 
      2, 3, 2, 2, 9, 2, 1, 1, 2, 6, 1, 1, 2, 4, 1, 2, 2, 3, 2, 2, 9, 8, 2, 1, 
      1, 2, 1, 1, 2, 4, 1, 2, 2, 3, 2, 9, 8, 8, 2, 1, 1, 2, 1, 1, 2, 4, 1, 2, 
      2, 3, 2, 8, 8, 6, 3, 2, 1, 1, 2, 1, 1, 2, 4, 1, 2, 2, 3, 2, 8, 6, 3, 4, 
      5, 2, 1, 1, 2, 1, 1, 2, 4, 1, 2, 2, 3, 2, 8, 3, 5, 9, 2, 1, 1, 1, 2, 4, 
      1, 2, 2, 3, 2, 8, 3, 5, 9, 3, 2, 1, 1, 1, 2, 4, 1, 2, 2, 2, 8, 3, 5, 9, 
      3, 2, 1, 2, 1, 1, 1, 2, 4, 1, 2, 2, 2, 3, 5, 9, 3, 2, 1, 3, 5, 2, 1, 1, 
      1, 2, 4, 1, 2, 2, 3, 5, 9, 3, 2, 1, 3, 5, 2, 1, 2, 1, 1, 1, 2, 4, 1, 2, 
      3, 5, 9, 3, 2, 1, 3, 5, 2, 1, 2, 1, 2, 1, 1, 2, 4, 1, 3, 5, 9, 3, 2, 1, 
      3, 5, 2, 1, 2, 1, 2, 2, 1, 1, 2, 4, 1, 3, 5, 3, 2, 1, 3, 5, 2, 1, 2, 1, 
      2, 3, 6, 2, 1, 1, 2, 4, 1, 3, 3, 2, 1, 3, 5, 2, 1, 2, 1, 2, 3, 6, 4, 1, 
      2, 1, 1, 2, 4, 1, 3, 3, 2, 1, 3, 5, 2, 1, 2, 3, 6, 4, 1, 2, 2, 1, 1, 2, 
      4, 1, 3, 2, 1, 3, 5, 2, 1, 2, 3, 6, 4, 2, 4, 2, 1, 1, 2, 4, 1, 2, 1, 3, 
      5, 2, 1, 2, 3, 6, 4, 2, 4, 1, 2, 2, 1, 1, 2, 4, 1, 2, 1, 3, 5, 2, 2, 6, 
      4, 2, 4, 1, 2, 4, 2, 1, 2, 4, 2, 1, 3, 5, 2, 2, 6, 4, 2, 4, 1, 2, 4, 2, 
      2, 1, 2, 4, 2, 1, 3, 5, 2, 2, 6, 4, 2, 4, 1, 2, 2, 3, 2, 2, 1, 2, 1, 3, 
      5, 2, 2, 6, 4, 2, 4, 1, 2, 2, 3, 2, 6, 2, 1, 2, 1, 3, 5, 2, 2, 4, 2, 4, 
      1, 2, 2, 3, 2, 6, 3, 3, 2, 1, 2, 1, 5, 2, 2, 4, 2, 4, 1, 2, 2, 3, 2, 6, 
      3, 3, 2, 1, 2, 1, 2, 1, 5, 2, 2, 4, 2, 4, 1, 2, 3, 2, 6, 3, 2, 1, 3, 2, 
      1, 2, 1, 5, 2, 2, 4, 2, 1, 2, 3, 6, 3, 2, 1, 3, 6, 2, 1, 1, 5, 2, 2, 4, 
      2, 1, 2, 3, 6, 3, 2, 1, 3, 6, 1, 2, 2, 1, 1, 5, 2, 2, 4, 2, 1, 2, 3, 6, 
      2, 1, 3, 1, 2, 9, 2, 1, 1, 5, 2, 2, 4, 1, 2, 3, 6, 2, 1, 3, 1, 2, 9, 2, 
      1, 2, 1, 1, 5, 2, 2, 4, 1, 2, 6, 2, 1, 3, 1, 2, 9, 2, 1, 1, 3, 2, 1, 1, 
      5, 2, 2, 4, 1, 2, 6, 2, 1, 1, 2, 9, 2, 1, 1, 3, 1, 2, 2, 1, 1, 5, 2, 2, 
      1, 2, 6, 2, 1, 1, 2, 9, 1, 1, 3, 1, 2, 6, 2, 1, 1, 5, 2, 2, 1, 6, 2, 1, 
      1, 2, 9, 1, 1, 3, 1, 2, 6, 1, 2, 2, 1, 1, 5, 2, 2, 1, 6, 2, 1, 1, 2, 1, 
      1, 3, 1, 2, 6, 1, 2, 1, 8, 2, 1, 1, 5, 2, 2, 1, 6, 2, 1, 1, 2, 1, 1, 3, 
      1, 6, 1, 2, 1, 8, 1, 1, 1, 1, 5, 2, 2, 1, 6, 2, 1, 1, 2, 1, 1, 3, 1, 6, 
      1, 2, 1, 8, 1, 3, 1, 5, 2, 2, 1, 6, 2, 1, 1, 2, 1, 1, 3, 6, 1, 2, 1, 8, 
      1, 3, 2, 1, 5, 2, 2, 1, 6, 2, 1, 1, 2, 1, 1, 6, 1, 1, 8, 1, 3, 2, 5, 1, 
      5, 2, 2, 6, 1, 1, 2, 1, 1, 6, 1, 1, 8, 1, 3, 2, 5, 3, 1, 5, 2, 2, 6, 1, 
      1, 2, 1, 1, 6, 1, 1, 8, 2, 5, 3, 4, 1, 5, 2, 2, 6, 1, 1, 2, 1, 1, 6, 1, 
      1, 8, 2, 3, 4, 3, 2, 1, 5, 2, 2, 6, 1, 1, 2, 1, 1, 6, 1, 8, 2, 3, 4, 2, 
      4, 1, 5, 2, 2, 1, 1, 2, 1, 1, 6, 1, 8, 2, 3, 4, 2, 4, 2, 4, 1, 5, 2, 2, 
      1, 1, 2, 1, 1, 6, 1, 8, 2, 3, 4, 2, 2, 4, 3, 1, 1, 5, 2, 1, 1, 2, 1, 1, 
      6, 1, 8, 2, 3, 4, 2, 4, 3, 1, 4, 1, 5, 2, 1, 1, 2, 1, 6, 1, 8, 3, 4, 2, 
      4, 3, 1, 4, 3, 1, 2, 1, 1, 2, 1, 6, 1, 8, 3, 4, 2, 4, 3, 1, 4, 3, 3, 3, 
      1, 2, 1, 1, 2, 1, 6, 1, 8, 3, 4, 2, 4, 3, 1, 3, 3, 3, 2, 2, 1, 2, 1, 1, 
      2, 1, 6, 1, 8, 3, 2, 4, 3, 1, 3, 3, 2, 2, 7, 1, 2, 1, 2, 1, 6, 8, 3, 2, 
      4, 3, 1, 3, 3, 2, 2, 7, 2, 1, 2, 1, 2, 1, 6, 8, 3, 2, 4, 3, 1, 3, 3, 2, 
      2, 2, 1, 7, 1, 2, 1, 2, 1, 6, 8, 3, 2, 3, 1, 3, 3, 2, 2, 2, 1, 7, 3, 1, 
      1, 2, 1, 2, 1, 8, 3, 2, 3, 1, 3, 3, 2, 2, 2, 1, 7, 3, 1, 2, 4, 1, 2, 1, 
      2, 1, 8, 3, 2, 1, 3, 3, 2, 2, 2, 1, 7, 1, 2, 4, 6, 1, 2, 1, 2, 1, 8, 2, 
      1, 3, 3, 2, 2, 2, 1, 7, 1, 2, 4, 6, 2, 1, 1, 2, 1, 2, 1, 2, 1, 3, 3, 2, 
      2, 2, 1, 7, 1, 2, 4, 6, 2, 1, 3, 5, 1, 2, 1, 2, 1, 1, 3, 3, 2, 2, 2, 1, 
      7, 1, 2, 4, 6, 2, 1, 3, 5, 1, 1, 1, 2, 1, 2, 1, 1, 3, 3, 2, 2, 2, 1, 1, 
      2, 4, 6, 2, 1, 3, 5, 1, 1, 5, 2, 1, 2, 1, 2, 1, 1, 3, 3, 2, 2, 2, 1, 1, 
      2, 4, 2, 1, 3, 5, 1, 1, 5, 2, 3, 3, 1, 2, 1, 2, 1, 1, 3, 3, 2, 2, 2, 1, 
      1, 2, 4, 2, 1, 3, 5, 1, 1, 5, 3, 3, 1, 1, 1, 2, 1, 2, 1, 1, 3, 3, 2, 2, 
      2, 1, 2, 4, 2, 1, 5, 1, 1, 5, 3, 3, 1, 1, 4, 1, 2, 1, 2, 1, 1, 3, 3, 2, 
      2, 2, 4, 2, 1, 5, 1, 1, 5, 3, 3, 1, 1, 4, 3, 1, 2, 1, 2, 1, 1, 3, 2, 2, 
      2, 4, 2, 1, 5, 1, 1, 5, 3, 3, 1, 1, 4, 3, 2, 1, 1, 2, 1, 2, 1, 1, 3, 2, 
      2, 2, 4, 2, 1, 5, 1, 5, 3, 3, 1, 1, 3, 2, 1, 5, 1, 2, 1, 2, 1, 1, 3, 2, 
      2, 2, 4, 2, 1, 1, 5, 3, 3, 1, 1, 3, 2, 1, 5, 3, 3, 1, 2, 1, 2, 1, 1, 3, 
      2, 2, 2, 4, 2, 1, 5, 3, 3, 1, 1, 3, 2, 1, 5, 3, 4, 1, 2, 1, 2, 1, 1, 3, 
      2, 2, 2, 4, 2, 1, 5, 3, 3, 1, 1, 2, 1, 5, 3, 4, 1, 2, 1, 2, 1, 2, 1, 1, 
      3, 2, 2, 2, 4, 2, 1, 5, 3, 3, 1, 2, 1, 5, 3, 4, 2, 2, 1, 2, 1, 2, 1, 1, 
      3, 2, 2, 2, 4, 2, 1, 5, 3, 3, 1, 2, 1, 3, 4, 2, 2, 2, 3, 1, 2, 1, 2, 1, 
      1, 3, 2, 2, 2, 4, 2, 1, 5, 3, 3, 1, 2, 1, 3, 4, 2, 2, 3, 1, 2, 1, 2, 1, 
      2, 1, 1, 3, 2, 2, 2, 4, 2, 1, 5, 3, 3, 1, 2, 1, 3, 4, 2, 2, 3, 2, 2, 1, 
      1, 1, 3, 2, 2, 2, 4, 2, 1, 5, 3, 3, 1, 2, 1, 3, 4, 2, 2, 3, 1, 1, 3, 2, 
      1, 1, 1, 3, 2, 2, 2, 4, 2, 1, 5, 3, 3, 1, 2, 1, 3, 4, 2, 2, 3, 1, 1, 3, 
      2, 1, 1, 3, 2, 2, 2, 4, 2, 1, 3, 3, 1, 2, 1, 3, 4, 2, 2, 3, 1, 1, 3, 6, 
      2, 1, 1, 3, 2, 2, 2, 4, 2, 1, 3, 3, 1, 2, 1, 3, 2, 3, 1, 1, 3, 6, 5, 2, 
      1, 1, 3, 2, 2, 2, 4, 2, 1, 3, 3, 1, 2, 1, 3, 2, 3, 1, 1, 3, 6, 4, 2, 2, 
      1, 1, 3, 2, 2, 2, 1, 3, 3, 1, 2, 1, 3, 2, 3, 1, 1, 3, 6, 4, 2, 6, 2, 1, 
      1, 3, 2, 2, 2, 1, 3, 3, 2, 1, 3, 2, 1, 1, 3, 6, 4, 2, 6, 4, 2, 1, 1, 3, 
      2, 2, 2, 1, 3, 3, 2, 1, 3, 2, 1, 1, 3, 6, 2, 6, 4, 2, 2, 2, 1, 1, 3, 2, 
      2, 2, 1, 3, 3, 2, 1, 2, 1, 1, 3, 6, 2, 6, 4, 2, 5, 2, 1, 1, 3, 2, 2, 1, 
      3, 3, 2, 1, 2, 1, 1, 3, 6, 2, 6, 2, 5, 6, 2, 1, 1, 3, 1, 3, 3, 2, 1, 2, 
      1, 1, 3, 6, 2, 6, 2, 5, 6, 3, 2, 1, 1, 3, 3, 2, 1, 2, 1, 1, 3, 6, 2, 6, 
      2, 5, 6, 3, 4, 2, 1, 1, 3, 3, 2, 1, 2, 1, 1, 3, 6, 2, 6, 2, 6, 3, 4, 1, 
      5, 2, 1, 1, 3, 3, 2, 1, 2, 1, 1, 6, 2, 6, 2, 6, 3, 4, 1, 5, 1, 2, 2, 1, 
      3, 3, 2, 1, 2, 1, 1, 6, 2, 6, 2, 6, 3, 4, 1, 5, 2, 2, 2, 1, 3, 3, 2, 1, 
      2, 1, 1, 6, 2, 6, 2, 3, 4, 1, 5, 2, 2, 5, 1, 2, 1, 3, 2, 1, 2, 1, 1, 6, 
      2, 6, 2, 3, 4, 1, 5, 2, 2, 5, 1, 3, 1, 2, 3, 2, 2, 1, 1, 6, 2, 6, 2, 3, 
      4, 1, 5, 2, 2, 5, 1, 3, 1, 2, 2, 3, 2, 2, 1, 1, 6, 2, 6, 2, 3, 1, 5, 2, 
      2, 5, 1, 3, 1, 2, 2, 3, 2, 3, 2, 2, 1, 1, 6, 2, 6, 2, 3, 1, 2, 2, 5, 1, 
      3, 1, 2, 2, 3, 2, 3, 2, 3, 2, 1, 1, 6, 2, 6, 2, 3, 1, 2, 5, 1, 3, 1, 2, 
      2, 3, 2, 3, 4, 2, 3, 2, 1, 1, 6, 2, 6, 2, 3, 1, 2, 5, 1, 3, 1, 2, 2, 2, 
      4, 6, 2, 3, 2, 1, 1, 6, 2, 6, 2, 3, 1, 2, 5, 1, 3, 1, 2, 2, 2, 6, 2, 3, 
      2, 3, 2, 1, 1, 6, 2, 6, 2, 3, 1, 2, 5, 1, 3, 1, 2, 2, 6, 2, 3, 1, 1, 2, 
      3, 2, 1, 1, 6, 2, 6, 2, 3, 1, 2, 1, 3, 2, 2, 6, 2, 3, 1, 1, 6, 2, 3, 2, 
      1, 1, 6, 2, 6, 2, 3, 1, 2, 2, 2, 6, 2, 3, 1, 1, 6, 4, 3, 2, 1, 1, 6, 2, 
      6, 2, 3, 1, 2, 2, 2, 2, 3, 1, 1, 6, 4, 8, 3, 2, 1, 1, 6, 2, 6, 2, 3, 1, 
      2, 2, 2, 2, 1, 1, 6, 4, 8, 1, 2, 3, 2, 1, 1, 6, 2, 6, 2, 3, 1, 2, 2, 1, 
      1, 6, 4, 8, 1, 2, 4, 3, 2, 1, 1, 6, 6, 2, 3, 1, 2, 1, 1, 6, 4, 8, 1, 2, 
      4, 4, 3, 2, 1, 1, 6, 6, 2, 3, 1, 2, 1, 1, 6, 4, 1, 2, 4, 4, 2, 6, 3, 1, 
      1, 6, 6, 2, 1, 2, 1, 1, 6, 4, 1, 2, 4, 4, 2, 6, 5, 3, 1, 1, 6, 6, 2, 1, 
      2, 1, 1, 6, 4, 1, 2, 4, 2, 6, 5, 2, 2, 3, 1, 1, 6, 6, 2, 1, 2, 1, 1, 6, 
      4, 1, 4, 2, 5, 2, 2, 8, 3, 1, 1, 6, 6, 2, 1, 2, 1, 6, 4, 1, 4, 2, 5, 2, 
      2, 8, 1, 1, 3, 1, 1, 6, 6, 2, 1, 6, 4, 1, 4, 2, 5, 2, 2, 8, 1, 1, 3, 3, 
      1, 1, 6, 6, 2, 1, 6, 4, 1, 4, 2, 5, 2, 8, 1, 3, 3, 3, 1, 1, 6, 6, 2, 1, 
      4, 1, 4, 2, 5, 2, 8, 1, 3, 9, 3, 1, 6, 2, 1, 4, 1, 4, 2, 5, 2, 8, 1, 3, 
      9, 7, 3, 1, 6, 2, 1, 4, 1, 2, 5, 2, 8, 1, 3, 9, 7, 3, 2, 3, 1, 6, 2, 1, 
      4, 2, 5, 2, 8, 1, 9, 7, 3, 2, 4, 3, 6, 1, 4, 2, 5, 2, 8, 1, 9, 7, 3, 2, 
      4, 3, 3, 6, 1, 4, 2, 5, 2, 8, 1, 7, 3, 2, 4, 3, 3, 7, 3, 1, 4, 2, 5, 2, 
      8, 1, 7, 3, 2, 3, 3, 7, 8, 3, 1, 4, 2, 2, 8, 1, 7, 3, 2, 3, 3, 7, 8, 2, 
      3, 3, 1, 4, 2, 2, 8, 1, 7, 3, 2, 3, 3, 7, 2, 3, 7, 1, 3, 1, 4, 2, 2, 8, 
      1, 3, 2, 3, 3, 7, 2, 3, 7, 1, 1, 6, 3, 1, 4, 2, 2, 8, 1, 3, 2, 3, 3, 7, 
      2, 7, 1, 1, 6, 1, 2, 3, 1, 2, 2, 8, 1, 3, 2, 3, 3, 7, 2, 7, 1, 1, 6, 1, 
      6, 3, 1, 2, 2, 1, 3, 2, 3, 3, 7, 2, 7, 1, 1, 6, 1, 8, 3, 1, 2, 2, 1, 3, 
      2, 3, 3, 7, 2, 7, 1, 1, 6, 1, 1, 7, 3, 1, 2, 1, 3, 2, 3, 3, 7, 2, 7, 1, 
      6, 1, 1, 7, 3, 3, 1, 2, 1, 3, 2, 3, 3, 7, 2, 7, 1, 6, 1, 1, 7, 3, 1, 3, 
      1, 2, 1, 3, 2, 3, 3, 7, 2, 7, 1, 6, 1, 3, 1, 8, 3, 2, 1, 3, 2, 3, 3, 7, 
      2, 7, 1, 6, 3, 1, 8, 2, 3, 2, 1, 3, 2, 3, 3, 7, 2, 7, 1, 3, 1, 8, 2, 5, 
      1, 3, 2, 1, 3, 2, 3, 7, 2, 7, 1, 1, 8, 2, 5, 1, 6, 3, 2, 1, 3, 2, 7, 2, 
      7, 1, 1, 8, 2, 5, 1, 6, 1, 3, 3, 2, 1, 2, 7, 2, 7, 1, 1, 8, 2, 5, 1, 6, 
      1, 3, 2, 1, 3, 2, 1, 2, 7, 2, 1, 1, 8, 2, 5, 1, 6, 1, 3, 2, 1, 6, 1, 3, 
      2, 1, 2, 7, 2, 1, 1, 2, 5, 1, 6, 1, 3, 2, 1, 6, 1, 1, 7, 2, 1, 2, 7, 2, 
      1, 1, 5, 1, 6, 1, 3, 2, 1, 6, 1, 1, 7, 5, 2, 1, 2, 2, 1, 1, 5, 1, 6, 3, 
      2, 1, 6, 1, 1, 7, 5, 8, 2, 1, 2, 2, 1, 1, 5, 1, 6, 3, 2, 6, 1, 1, 7, 5, 
      9, 1, 2, 2, 1, 5, 1, 6, 3, 2, 6, 1, 1, 7, 5, 9, 3, 1, 2, 2, 1, 1, 6, 3, 
      2, 6, 1, 1, 7, 5, 9, 3, 4, 1, 1, 2, 2, 1, 1, 6, 3, 2, 6, 1, 1, 7, 5, 9, 
      3, 5, 1, 2, 2, 1, 1, 6, 3, 2, 6, 1, 1, 7, 5, 3, 5, 6, 4, 1, 2, 2, 1, 1, 
      3, 2, 6, 1, 1, 7, 5, 3, 5, 6, 4, 6, 1, 2, 2, 1, 1, 3, 2, 6, 1, 1, 7, 5, 
      3, 5, 6, 4, 1, 7, 2, 2, 1, 1, 3, 2, 6, 1, 7, 5, 3, 6, 4, 1, 7, 6, 2, 2, 
      1, 1, 3, 6, 1, 7, 5, 3, 6, 4, 1, 7, 8, 2, 2, 1, 1, 3, 6, 1, 7, 5, 6, 4, 
      1, 7, 8, 2, 1, 2, 2, 1, 1, 3, 1, 7, 5, 6, 4, 1, 7, 8, 1, 7, 2, 2, 1, 1, 
      3, 1, 5, 6, 4, 1, 7, 1, 7, 7, 2, 2, 1, 3, 1, 5, 6, 4, 7, 1, 7, 7, 2, 2, 
      2, 1, 3, 1, 6, 4, 7, 1, 7, 2, 9, 2, 2, 1, 3, 1, 6, 7, 1, 7, 2, 9, 2, 2, 
      2, 2, 1, 3, 1, 6, 1, 7, 2, 9, 2, 2, 4, 4, 2, 2, 1, 3, 1, 6, 2, 9, 2, 2, 
      4, 4, 8, 2, 2, 1, 3, 1, 6, 2, 2, 2, 4, 4, 8, 3, 6, 2, 2, 1, 3, 1, 6, 2, 
      2, 4, 4, 8, 3, 6, 1, 1, 2, 2, 1, 3, 1, 2, 2, 4, 4, 8, 3, 6, 1, 7, 2, 1, 
      3, 1, 2, 2, 4, 4, 8, 3, 1, 7, 8, 2, 1, 3, 1, 2, 2, 4, 8, 3, 1, 7, 8, 3, 
      1, 2, 1, 3, 1, 2, 4, 8, 3, 1, 7, 8, 3, 1, 1, 1, 2, 1, 3, 2, 4, 8, 3, 1, 
      7, 8, 3, 1, 1, 2, 2, 1, 3, 2, 4, 8, 3, 1, 7, 3, 1, 1, 2, 3, 5, 2, 1, 3, 
      2, 4, 8, 3, 1, 3, 1, 1, 2, 3, 5, 1, 6, 2, 1, 3, 2, 4, 8, 3, 1, 3, 1, 1, 
      2, 1, 6, 8, 2, 1, 3, 2, 4, 8, 1, 3, 1, 1, 1, 6, 8, 5, 2, 1, 3, 2, 4, 1, 
      3, 1, 1, 1, 6, 8, 5, 2, 7, 2, 1, 3, 2, 4, 1, 3, 1, 1, 1, 6, 8, 5, 2, 5, 
      3, 2, 1, 3, 2, 4, 1, 3, 1, 1, 1, 6, 8, 5, 5, 3, 1, 1, 2, 1, 3, 2, 4, 1, 
      3, 1, 1, 1, 6, 8, 5, 5, 1, 1, 2, 1, 1, 3, 2, 4, 1, 3, 1, 1, 1, 6, 5, 5, 
      1, 1, 2, 1, 10, 1, 3, 2, 4, 1, 1, 1, 1, 6, 5, 5, 1, 2, 1, 10, 3, 1, 3, 
      2, 4, 1, 1, 1, 1, 6, 5, 1, 2, 1, 10, 3, 3, 2, 1, 3, 2, 4, 1, 1, 1, 6, 
      5, 1, 2, 1, 3, 3, 2, 11, 1, 3, 2, 4, 1, 1, 1, 6, 5, 1, 2, 1, 3, 3, 2, 
      2, 10, 1, 2, 4, 1, 1, 1, 6, 5, 1, 2, 1, 3, 3, 2, 2, 10, 2, 1, 1, 2, 4, 
      1, 1, 1, 5, 1, 2, 1, 3, 3, 2, 2, 10, 2, 1, 5, 1, 1, 2, 4, 1, 1, 1, 5, 
      1, 3, 3, 2, 2, 10, 2, 1, 5, 1, 3, 1, 2, 4, 1, 1, 1, 5, 1, 3, 3, 2, 2, 
      10, 2, 1, 1, 3, 4, 1, 1, 2, 4, 1, 1, 5, 1, 3, 3, 2, 2, 10, 2, 1, 1, 3, 
      4, 2, 1, 2, 4, 1, 1, 5, 1, 3, 2, 2, 10, 2, 1, 1, 3, 4, 2, 2, 2, 1, 2, 
      1, 1, 5, 1, 3, 2, 2, 10, 2, 1, 1, 3, 4, 2, 2, 6, 1, 2, 1, 1, 5, 1, 3, 
      2, 2, 10, 2, 1, 1, 3, 4, 2, 6, 1, 1, 1, 2, 1, 1, 5, 1, 3, 2, 2, 2, 1, 
      1, 3, 4, 2, 6, 1, 1, 8, 3, 1, 2, 1, 1, 5, 1, 3, 2, 2, 2, 1, 1, 3, 4, 2, 
      1, 1, 8, 3, 1, 6, 1, 2, 1, 1, 1, 3, 2, 2, 2, 1, 1, 3, 4, 2, 1, 1, 8, 3, 
      1, 6, 2, 3, 1, 2, 1, 1, 1, 3, 2, 2, 2, 1, 1, 3, 4, 2, 1, 1, 3, 1, 6, 2, 
      3, 6, 3, 2, 1, 1, 1, 3, 2, 2, 2, 1, 1, 3, 4, 2, 1, 3, 1, 6, 2, 3, 6, 3, 
      2, 1, 1, 3, 2, 2, 2, 1, 1, 3, 4, 2, 1, 3, 1, 6, 2, 3, 6, 3, 2, 3, 1, 1, 
      3, 2, 2, 1, 1, 3, 4, 2, 1, 3, 1, 6, 2, 3, 6, 3, 2, 3, 1, 1, 1, 1, 3, 2, 
      2, 1, 1, 3, 4, 2, 1, 3, 1, 6, 2, 3, 3, 2, 3, 1, 1, 4, 2, 1, 1, 3, 2, 2, 
      1, 1, 3, 4, 2, 1, 3, 1, 6, 2, 3, 3, 2, 3, 1, 1, 4, 2, 1, 1, 1, 3, 2, 1, 
      1, 3, 4, 2, 1, 3, 6, 2, 3, 3, 2, 3, 1, 1, 4, 2, 1, 3, 1, 1, 3, 2, 1, 1, 
      3, 4, 2, 1, 3, 6, 2, 3, 3, 2, 3, 1, 1, 2, 1, 3, 3, 1, 1, 1, 3, 2, 1, 1, 
      3, 4, 2, 1, 3, 6, 2, 3, 3, 2, 3, 1, 1, 2, 1, 3, 1, 1, 3, 1, 1, 2, 1, 1, 
      3, 4, 2, 1, 3, 6, 2, 3, 3, 2, 3, 1, 1, 2, 1, 3, 1, 1, 3, 2, 1, 1, 1, 2, 
      1, 1, 3, 4, 2, 1, 3, 6, 2, 3, 3, 3, 1, 1, 2, 1, 3, 1, 1, 3, 2, 1, 1, 1, 
      1, 1, 2, 1, 1, 3, 4, 2, 1, 3, 2, 3, 3, 3, 1, 1, 2, 1, 3, 1, 1, 3, 2, 1, 
      1, 1, 5, 2, 1, 1, 2, 1, 1, 3, 4, 2, 1, 3, 2, 3, 3, 3, 1, 1, 2, 1, 1, 1, 
      3, 2, 1, 1, 1, 2, 8, 1, 1, 2, 1, 1, 3, 4, 2, 1, 3, 2, 3, 3, 3, 1, 2, 1, 
      1, 3, 2, 1, 1, 1, 2, 8, 2, 1, 1, 2, 1, 1, 3, 4, 2, 3, 2, 3, 3, 3, 1, 2, 
      1, 1, 3, 2, 1, 1, 2, 8, 2, 2, 1, 1, 2, 1, 1, 3, 3, 2, 3, 3, 3, 1, 2, 1, 
      1, 3, 2, 1, 1, 2, 8, 2, 2, 6, 1, 1, 2, 1, 1, 3, 3, 2, 3, 3, 3, 1, 2, 1, 
      1, 3, 2, 1, 1, 2, 2, 2, 6, 6, 2, 1, 2, 1, 1, 3, 3, 2, 3, 3, 1, 2, 1, 1, 
      3, 2, 1, 1, 2, 2, 2, 6, 6, 2, 4, 1, 2, 1, 3, 3, 2, 3, 3, 1, 2, 1, 1, 3, 
      1, 1, 2, 2, 2, 6, 6, 2, 4, 3, 1, 2, 1, 3, 3, 2, 3, 3, 1, 2, 1, 1, 3, 1, 
      1, 2, 2, 2, 6, 2, 4, 3, 1, 6, 1, 2, 1, 3, 2, 3, 3, 1, 2, 1, 1, 3, 1, 1, 
      2, 2, 2, 6, 2, 4, 3, 1, 6, 1, 2, 1, 2, 1, 3, 2, 3, 3, 1, 2, 1, 1, 3, 1, 
      1, 2, 2, 6, 2, 4, 3, 1, 1, 2, 8, 1, 2, 1, 3, 2, 3, 3, 1, 2, 1, 1, 1, 1, 
      2, 2, 6, 2, 4, 3, 1, 1, 2, 8, 1, 2, 1, 2, 1, 3, 2, 3, 3, 1, 2, 1, 1, 1, 
      2, 2, 6, 2, 4, 3, 1, 1, 2, 8, 2, 2, 1, 2, 1, 3, 2, 3, 3, 1, 2, 1, 1, 1, 
      2, 2, 6, 2, 4, 3, 1, 1, 2, 2, 2, 1, 7, 1, 2, 3, 2, 3, 3, 1, 2, 1, 1, 1, 
      2, 2, 6, 2, 4, 1, 1, 2, 2, 2, 1, 7, 4, 1, 2, 3, 2, 3, 3, 1, 2, 1, 1, 1, 
      2, 2, 6, 2, 4, 1, 1, 2, 2, 1, 7, 4, 1, 1, 2, 3, 2, 3, 3, 1, 2, 1, 1, 2, 
      2, 6, 2, 4, 1, 1, 2, 2, 1, 7, 4, 1, 1, 2, 2, 3, 2, 3, 3, 1, 2, 1, 1, 2, 
      2, 2, 4, 1, 1, 2, 2, 1, 7, 4, 1, 1, 2, 1, 6, 2, 3, 2, 3, 3, 1, 2, 1, 1, 
      2, 2, 2, 4, 1, 1, 2, 1, 7, 4, 1, 2, 1, 6, 3, 2, 3, 2, 3, 3, 2, 1, 1, 2, 
      2, 2, 4, 1, 1, 2, 1, 7, 1, 2, 1, 6, 3, 5, 2, 3, 2, 3, 3, 2, 1, 1, 2, 2, 
      4, 1, 1, 2, 1, 7, 1, 2, 1, 6, 3, 5, 1, 1, 2, 3, 2, 3, 3, 2, 1, 1, 2, 2, 
      4, 1, 1, 2, 1, 7, 1, 1, 6, 3, 5, 1, 1, 1, 2, 2, 3, 2, 3, 2, 1, 2, 2, 4, 
      1, 1, 2, 1, 7, 1, 1, 6, 3, 5, 1, 1, 1, 2, 3, 2, 3, 3, 2, 1, 2, 2, 1, 1, 
      2, 1, 7, 1, 1, 6, 3, 5, 1, 1, 1, 2, 3, 6, 2, 3, 3, 2, 1, 2, 1, 1, 2, 1, 
      7, 1, 1, 6, 3, 5, 1, 1, 2, 3, 6, 3, 2, 3, 2, 1, 2, 1, 1, 2, 1, 7, 1, 1, 
      6, 5, 1, 1, 2, 3, 6, 3, 6, 2, 3, 2, 2, 1, 1, 2, 1, 7, 1, 1, 6, 5, 1, 2, 
      3, 6, 3, 6, 2, 2, 3, 2, 2, 1, 1, 2, 1, 1, 1, 6, 5, 1, 2, 3, 6, 3, 6, 2, 
      6, 1, 2, 3, 2, 2, 1, 1, 2, 1, 1, 1, 6, 5, 1, 3, 6, 3, 6, 2, 6, 1, 1, 2, 
      2, 3, 2, 2, 1, 1, 2, 1, 1, 1, 6, 5, 1, 3, 6, 3, 6, 1, 1, 2, 8, 2, 3, 2, 
      2, 1, 1, 2, 1, 1, 1, 6, 5, 1, 3, 6, 3, 6, 1, 1, 8, 1, 1, 2, 3, 2, 2, 1, 
      2, 1, 1, 1, 5, 1, 3, 6, 3, 6, 1, 1, 8, 1, 1, 7, 2, 3, 2, 2, 1, 2, 1, 1, 
      1, 5, 1, 3, 3, 6, 1, 1, 8, 1, 1, 7, 5, 1, 2, 3, 2, 2, 1, 2, 1, 1, 1, 5, 
      1, 3, 3, 6, 1, 1, 8, 1, 1, 7, 1, 1, 4, 3, 2, 2, 1, 2, 1, 1, 1, 5, 1, 3, 
      3, 6, 1, 8, 1, 1, 7, 1, 1, 4, 3, 3, 2, 2, 1, 2, 1, 1, 1, 5, 1, 3, 3, 6, 
      1, 1, 1, 7, 1, 1, 4, 3, 1, 7, 3, 2, 2, 1, 2, 1, 1, 1, 5, 1, 3, 3, 6, 1, 
      1, 1, 7, 1, 4, 3, 1, 7, 1, 1, 3, 2, 2, 1, 2, 1, 1, 1, 5, 1, 3, 3, 6, 1, 
      1, 7, 1, 4, 3, 7, 1, 1, 2, 3, 2, 2, 1, 2, 1, 1, 1, 5, 1, 3, 3, 6, 1, 1, 
      7, 1, 4, 7, 1, 1, 2, 2, 1, 3, 2, 2, 1, 2, 1, 1, 1, 5, 1, 3, 3, 6, 1, 1, 
      7, 1, 4, 7, 1, 1, 2, 1, 2, 1, 3, 2, 1, 2, 1, 1, 1, 5, 1, 3, 3, 6, 1, 1, 
      7, 1, 4, 7, 1, 1, 1, 2, 1, 4, 3, 2, 1, 2, 1, 1, 5, 1, 3, 3, 6, 1, 1, 7, 
      1, 4, 7, 1, 1, 1, 2, 1, 5, 3, 2, 1, 2, 1, 1, 5, 1, 3, 6, 1, 1, 7, 1, 4, 
      7, 1, 1, 1, 2, 1, 5, 1, 2, 3, 1, 2, 1, 1, 5, 1, 3, 6, 1, 1, 7, 1, 4, 7, 
      1, 1, 1, 2, 1, 1, 2, 7, 3, 1, 2, 1, 1, 5, 1, 3, 6, 1, 1, 1, 4, 7, 1, 1, 
      1, 2, 1, 1, 2, 12, 3, 1, 2, 1, 1, 5, 1, 3, 6, 1, 1, 4, 7, 1, 1, 1, 2, 
      1, 2, 12, 2, 3, 1, 2, 1, 1, 5, 1, 3, 1, 1, 4, 7, 1, 1, 1, 2, 1, 2, 12, 
      2, 2, 4, 3, 1, 2, 1, 1, 5, 1, 3, 1, 1, 4, 7, 1, 1, 1, 2, 1, 2, 2, 2, 4, 
      7, 5, 3, 1, 1, 5, 1, 3, 1, 1, 4, 7, 1, 1, 1, 2, 1, 2, 2, 2, 4, 7, 5, 3, 
      3, 1, 1, 5, 1, 3, 1, 1, 4, 7, 1, 1, 1, 2, 1, 2, 2, 4, 7, 5, 5, 3, 1, 1, 
      5, 1, 3, 1, 1, 4, 7, 1, 1, 2, 2, 2, 4, 7, 5, 5, 2, 3, 1, 1, 5, 1, 3, 1, 
      1, 4, 7, 1, 1, 2, 2, 2, 4, 7, 5, 5, 1, 1, 3, 1, 1, 5, 1, 3, 1, 1, 4, 7, 
      1, 1, 2, 2, 2, 4, 7, 5, 1, 1, 2, 3, 3, 1, 1, 5, 1, 3, 1, 1, 4, 1, 1, 2, 
      2, 2, 7, 5, 1, 1, 2, 3, 11, 3, 1, 5, 1, 3, 1, 1, 4, 1, 1, 2, 2, 2, 7, 
      5, 1, 1, 2, 11, 4, 3, 1, 5, 1, 3, 1, 1, 4, 1, 2, 2, 2, 7, 5, 1, 1, 2, 
      4, 11, 3, 1, 5, 1, 3, 1, 1, 4, 2, 2, 2, 5, 1, 1, 2, 4, 11, 8, 3, 1, 5, 
      1, 3, 1, 1, 4, 2, 2, 2, 5, 1, 1, 2, 4, 11, 7, 1, 5, 1, 3, 1, 1, 4, 2, 
      2, 2, 5, 1, 1, 2, 4, 11, 7, 1, 4, 5, 1, 3, 1, 1, 4, 2, 2, 2, 5, 1, 1, 
      2, 4, 7, 1, 4, 7, 4, 5, 1, 3, 1, 1, 4, 2, 2, 2, 5, 1, 1, 2, 4, 1, 4, 7, 
      4, 3, 5, 5, 1, 3, 1, 1, 4, 2, 2, 5, 1, 1, 4, 1, 4, 7, 4, 3, 5, 4, 5, 1, 
      3, 1, 1, 4, 2, 2, 5, 1, 1, 4, 1, 7, 4, 3, 5, 4, 1, 3, 1, 3, 1, 1, 4, 2, 
      2, 5, 1, 1, 4, 1, 7, 4, 3, 5, 4, 1, 3, 3, 2, 1, 3, 1, 1, 2, 2, 5, 1, 1, 
      4, 1, 7, 4, 3, 5, 4, 1, 3, 3, 2, 4, 1, 1, 3, 1, 2, 2, 5, 1, 1, 4, 1, 7, 
      4, 3, 5, 4, 1, 3, 3, 2, 4, 1, 1, 1, 1, 3, 1, 2, 5, 1, 1, 4, 1, 7, 4, 3, 
      5, 4, 1, 3, 3, 2, 4, 1, 1, 1, 1, 1, 1, 3, 1, 5, 1, 1, 4, 1, 7, 4, 3, 5, 
      4, 1, 3, 3, 4, 1, 1, 1, 1, 1, 4, 1, 3, 1, 5, 1, 1, 4, 1, 7, 4, 5, 4, 1, 
      3, 3, 4, 1, 1, 1, 1, 1, 4, 1, 2, 1, 3, 1, 5, 1, 1, 4, 1, 7, 5, 4, 1, 3, 
      3, 4, 1, 1, 1, 1, 1, 4, 1, 2, 4, 1, 1, 3, 1, 5, 1, 4, 1, 7, 5, 4, 1, 3, 
      3, 4, 1, 1, 1, 1, 4, 1, 2, 4, 1, 2, 1, 3, 1, 5, 1, 4, 1, 5, 4, 1, 3, 3, 
      1, 1, 1, 1, 4, 1, 2, 4, 1, 2, 6, 1, 3, 1, 5, 1, 4, 1, 5, 4, 1, 3, 1, 1, 
      1, 4, 1, 2, 4, 1, 2, 6, 4, 1, 3, 1, 4, 1, 5, 4, 1, 3, 1, 1, 1, 4, 1, 2, 
      4, 1, 2, 6, 4, 6, 1, 3, 1, 4, 1, 5, 4, 1, 3, 1, 1, 1, 4, 1, 2, 1, 2, 6, 
      4, 6, 4, 1, 1, 3, 1, 4, 5, 4, 1, 3, 1, 1, 1, 4, 1, 2, 2, 6, 4, 6, 4, 1, 
      2, 1, 3, 1, 4, 5, 1, 3, 1, 1, 1, 4, 1, 2, 6, 4, 6, 4, 1, 2, 5, 1, 3, 1, 
      4, 5, 1, 3, 1, 1, 4, 1, 2, 6, 4, 6, 4, 1, 2, 5, 1, 1, 1, 1, 4, 5, 1, 3, 
      1, 1, 4, 1, 2, 6, 4, 6, 4, 1, 2, 5, 1, 1, 1, 3, 1, 1, 4, 5, 1, 3, 1, 4, 
      1, 2, 6, 4, 6, 4, 1, 2, 5, 1, 1, 1, 4, 1, 1, 4, 1, 3, 1, 4, 1, 6, 4, 6, 
      4, 1, 2, 5, 1, 1, 1, 4, 6, 1, 4, 1, 3, 1, 4, 1, 6, 4, 6, 4, 1, 5, 1, 1, 
      1, 4, 6, 3, 4, 1, 1, 4, 1, 6, 4, 6, 4, 1, 5, 1, 1, 1, 4, 6, 3, 4, 4, 1, 
      1, 4, 1, 6, 4, 6, 4, 1, 5, 1, 1, 1, 4, 6, 7, 4, 1, 1, 4, 1, 6, 6, 4, 1, 
      5, 1, 1, 1, 4, 7, 9, 4, 1, 1, 4, 1, 6, 6, 4, 1, 1, 1, 1, 4, 7, 9, 2, 3, 
      4, 1, 1, 1, 6, 6, 4, 1, 1, 1, 1, 4, 7, 9, 3, 6, 1, 1, 1, 6, 6, 4, 1, 1, 
      1, 1, 4, 7, 9, 3, 6, 1, 4, 1, 1, 1, 6, 4, 1, 1, 1, 1, 4, 7, 9, 3, 6, 1, 
      4, 2, 5, 1, 1, 6, 4, 1, 1, 1, 4, 7, 9, 3, 6, 1, 4, 2, 5, 2, 1, 1, 6, 4, 
      1, 1, 1, 4, 7, 3, 6, 1, 4, 2, 5, 2, 8, 2, 1, 1, 6, 4, 1, 1, 1, 4, 7, 3, 
      1, 4, 2, 5, 2, 8, 2, 2, 4, 1, 1, 4, 1, 1, 1, 4, 7, 3, 1, 4, 2, 5, 2, 8, 
      2, 2, 4, 4, 2, 1, 1, 4, 1, 1, 1, 4, 7, 3, 4, 2, 5, 2, 8, 2, 2, 4, 4, 2, 
      1, 1, 1, 1, 4, 1, 1, 1, 4, 7, 4, 2, 5, 2, 8, 2, 2, 4, 2, 1, 1, 7, 1, 1, 
      4, 1, 1, 1, 4, 4, 2, 5, 2, 8, 2, 2, 4, 2, 1, 1, 7, 2, 5, 1, 1, 4, 1, 1, 
      1, 4, 4, 2, 5, 8, 2, 2, 2, 1, 1, 7, 2, 5, 6, 1, 1, 4, 1, 1, 1, 4, 4, 2, 
      5, 8, 2, 2, 2, 1, 1, 7, 2, 5, 3, 3, 1, 1, 4, 1, 1, 1, 4, 2, 5, 8, 2, 2, 
      2, 1, 1, 7, 2, 5, 3, 3, 1, 3, 1, 1, 4, 1, 1, 1, 2, 5, 8, 2, 2, 2, 1, 1, 
      7, 2, 5, 3, 3, 1, 3, 1, 3, 1, 1, 1, 1, 1, 2, 5, 8, 2, 2, 2, 1, 1, 7, 2, 
      5, 3, 1, 3, 1, 3, 7, 1, 1, 1, 1, 2, 8, 2, 2, 2, 1, 1, 7, 2, 5, 3, 1, 3, 
      1, 3, 7, 6, 1, 1, 1, 1, 2, 8, 2, 2, 2, 7, 2, 5, 3, 1, 3, 1, 3, 7, 6, 1, 
      1, 1, 1, 2, 8, 2, 2, 2, 7, 2, 5, 3, 1, 3, 3, 7, 6, 1, 2, 1, 1, 1, 2, 8, 
      2, 2, 2, 7, 2, 5, 3, 1, 3, 3, 6, 1, 2, 3, 4, 1, 1, 1, 2, 8, 2, 2, 2, 7, 
      5, 3, 1, 3, 3, 6, 1, 2, 4, 5, 1, 1, 1, 2, 8, 2, 2, 2, 7, 5, 3, 1, 3, 3, 
      6, 1, 2, 5, 2, 2, 1, 1, 2, 8, 2, 2, 2, 7, 5, 3, 1, 3, 3, 6, 2, 5, 2, 2, 
      2, 1, 2, 8, 2, 2, 7, 5, 3, 1, 3, 3, 6, 2, 5, 2, 2, 2, 2, 1, 8, 2, 2, 7, 
      5, 3, 1, 3, 3, 6, 2, 2, 2, 2, 2, 7, 1, 8, 2, 2, 7, 5, 3, 1, 3, 3, 6, 2, 
      2, 2, 2, 7, 1, 1, 1, 8, 2, 2, 7, 5, 3, 1, 3, 3, 2, 2, 2, 2, 7, 1, 1, 5, 
      1, 1, 8, 7, 5, 3, 1, 3, 3, 2, 2, 2, 2, 7, 1, 1, 5, 1, 4, 1, 8, 7, 3, 1, 
      3, 3, 2, 2, 2, 2, 7, 1, 1, 1, 4, 10, 1, 8, 7, 3, 1, 3, 3, 2, 2, 2, 2, 
      7, 1, 1, 1, 4, 8, 2, 1, 8, 7, 3, 1, 3, 3, 2, 2, 2, 2, 7, 1, 1, 1, 4, 2, 
      5, 3, 1, 8, 3, 1, 3, 3, 2, 2, 2, 2, 7, 1, 1, 1, 4, 2, 5, 3, 3, 4, 1, 8, 
      3, 1, 3, 3, 2, 2, 2, 7, 1, 1, 4, 2, 5, 3, 3, 4, 3, 1, 8, 3, 1, 3, 3, 2, 
      2, 2, 7, 1, 1, 2, 5, 3, 3, 4, 3, 4, 1, 1, 8, 1, 3, 3, 2, 2, 2, 7, 1, 1, 
      2, 5, 3, 4, 3, 4, 1, 6, 1, 1, 3, 3, 2, 2, 2, 7, 1, 1, 2, 5, 3, 4, 3, 4, 
      1, 6, 5, 3, 1, 1, 3, 3, 2, 2, 2, 7, 1, 1, 2, 5, 3, 3, 4, 1, 6, 5, 3, 3, 
      2, 1, 1, 3, 3, 2, 2, 2, 1, 1, 2, 5, 3, 3, 4, 1, 6, 5, 3, 3, 2, 1, 6, 1, 
      1, 3, 3, 2, 2, 2, 1, 1, 2, 5, 3, 3, 4, 1, 6, 5, 3, 2, 1, 6, 1, 2, 1, 1, 
      3, 3, 2, 2, 1, 1, 2, 5, 3, 3, 4, 1, 6, 5, 3, 2, 1, 6, 1, 2, 1, 1, 1, 1, 
      3, 3, 2, 2, 1, 1, 2, 5, 3, 3, 4, 1, 5, 3, 2, 1, 6, 1, 2, 1, 1, 3, 3, 1, 
      1, 3, 3, 2, 2, 1, 1, 2, 5, 3, 3, 1, 5, 3, 2, 1, 6, 1, 2, 1, 1, 3, 3, 2, 
      2, 1, 1, 3, 2, 2, 1, 2, 5, 3, 3, 1, 5, 3, 2, 1, 6, 1, 2, 1, 1, 3, 3, 2, 
      2, 4, 1, 1, 3, 2, 2, 1, 2, 5, 3, 3, 1, 5, 3, 2, 1, 6, 1, 1, 1, 3, 2, 2, 
      4, 5, 1, 1, 3, 2, 2, 1, 2, 5, 3, 3, 1, 5, 3, 2, 6, 1, 1, 1, 2, 2, 4, 5, 
      4, 1, 1, 3, 2, 1, 2, 5, 3, 3, 1, 5, 3, 2, 6, 1, 1, 2, 2, 4, 5, 4, 3, 1, 
      1, 3, 2, 1, 2, 5, 3, 3, 1, 5, 3, 2, 6, 1, 1, 2, 2, 4, 5, 3, 2, 2, 1, 1, 
      3, 2, 1, 2, 5, 3, 3, 1, 5, 3, 2, 6, 1, 1, 2, 2, 4, 3, 2, 6, 1, 1, 3, 2, 
      1, 2, 5, 3, 3, 1, 5, 3, 2, 6, 1, 1, 2, 2, 4, 2, 6, 1, 2, 1, 1, 3, 1, 2, 
      5, 3, 3, 1, 5, 3, 2, 6, 1, 1, 2, 2, 4, 6, 1, 2, 4, 1, 1, 3, 1, 2, 5, 3, 
      3, 1, 5, 2, 1, 1, 2, 2, 4, 6, 1, 2, 4, 9, 1, 1, 3, 1, 2, 5, 3, 3, 1, 5, 
      2, 1, 1, 2, 2, 4, 6, 1, 2, 9, 1, 3, 1, 1, 3, 1, 2, 5, 3, 3, 1, 5, 2, 1, 
      1, 2, 2, 4, 1, 2, 9, 1, 3, 3, 3, 1, 1, 3, 1, 2, 5, 3, 3, 5, 2, 1, 1, 2, 
      2, 4, 1, 2, 9, 1, 3, 3, 3, 1, 1, 3, 1, 2, 5, 3, 3, 5, 2, 1, 1, 2, 2, 4, 
      1, 2, 9, 1, 3, 3, 1, 2, 1, 1, 3, 1, 2, 5, 3, 3, 5, 2, 1, 1, 2, 4, 1, 2, 
      9, 1, 3, 3, 1, 4, 1, 3, 1, 2, 5, 3, 3, 5, 2, 1, 2, 4, 1, 2, 9, 1, 3, 3, 
      1, 4, 2, 1, 3, 1, 2, 5, 3, 3, 2, 2, 4, 1, 2, 9, 1, 3, 3, 1, 4, 2, 6, 1, 
      3, 1, 2, 5, 3, 3, 2, 2, 4, 1, 2, 9, 1, 3, 3, 1, 4, 2, 2, 5, 1, 3, 1, 2, 
      3, 3, 2, 2, 4, 1, 2, 9, 1, 3, 3, 1, 4, 2, 2, 5, 4, 1, 3, 1, 2, 3, 3, 2, 
      2, 4, 1, 2, 9, 1, 3, 3, 1, 4, 2, 2, 5, 1, 5, 3, 1, 2, 3, 3, 2, 2, 4, 1, 
      2, 9, 1, 3, 1, 4, 2, 2, 5, 1, 5, 1, 2, 3, 1, 2, 3, 3, 2, 4, 1, 2, 9, 1, 
      3, 1, 4, 2, 2, 5, 1, 5, 1, 2, 2, 1, 3, 1, 2, 3, 3, 2, 1, 2, 9, 1, 3, 1, 
      2, 2, 5, 1, 5, 1, 2, 2, 1, 7, 3, 1, 2, 3, 3, 2, 1, 2, 9, 1, 3, 1, 2, 5, 
      1, 5, 1, 2, 2, 1, 7, 1, 1, 3, 1, 2, 3, 2, 1, 2, 9, 1, 3, 1, 2, 5, 1, 1, 
      2, 2, 1, 7, 1, 1, 8, 3, 1, 2, 3, 2, 1, 2, 9, 1, 1, 2, 5, 1, 1, 2, 2, 1, 
      7, 1, 1, 8, 3, 1, 3, 1, 2, 3, 2, 2, 9, 1, 1, 5, 1, 1, 2, 2, 1, 7, 1, 1, 
      8, 3, 1, 3, 3, 1, 2, 3, 2, 2, 9, 1, 1, 1, 2, 2, 1, 7, 1, 1, 8, 3, 1, 3, 
      6, 3, 2, 3, 2, 2, 9, 1, 1, 1, 2, 2, 1, 7, 1, 8, 3, 1, 3, 6, 2, 3, 2, 3, 
      2, 2, 9, 1, 1, 1, 2, 2, 1, 7, 1, 8, 3, 1, 3, 6, 1, 1, 3, 2, 3, 2, 2, 9, 
      1, 1, 1, 2, 1, 7, 1, 8, 3, 1, 6, 1, 1, 5, 3, 2, 3, 2, 2, 9, 1, 1, 1, 2, 
      1, 7, 1, 8, 3, 1, 1, 1, 5, 5, 1, 3, 2, 3, 2, 9, 1, 1, 1, 2, 1, 7, 1, 8, 
      3, 1, 1, 1, 5, 5, 3, 3, 2, 3, 2, 9, 1, 1, 1, 2, 1, 1, 8, 3, 1, 1, 1, 5, 
      5, 3, 5, 2, 2, 3, 2, 9, 1, 1, 1, 2, 1, 1, 8, 3, 1, 1, 5, 5, 3, 5, 2, 4, 
      2, 3, 2, 9, 1, 1, 1, 2, 1, 8, 3, 1, 1, 5, 5, 5, 2, 4, 3, 2, 3, 2, 9, 1, 
      1, 1, 2, 1, 8, 3, 1, 1, 5, 5, 2, 4, 3, 2, 3, 2, 3, 9, 1, 1, 1, 2, 1, 8, 
      3, 1, 5, 5, 2, 4, 3, 2, 3, 3, 2, 3, 9, 1, 1, 1, 8, 3, 1, 5, 5, 2, 4, 3, 
      2, 3, 3, 3, 2, 9, 1, 1, 1, 8, 3, 1, 5, 2, 4, 3, 2, 3, 3, 3, 8, 2, 9, 1, 
      1, 1, 8, 3, 1, 5, 4, 3, 3, 3, 3, 8, 4, 2, 9, 1, 1, 1, 8, 3, 1, 5, 4, 3, 
      3, 3, 8, 4, 1, 2, 2, 9, 1, 1, 1, 8, 1, 5, 4, 3, 3, 3, 8, 4, 2, 4, 2, 9, 
      1, 1, 1, 8, 1, 5, 4, 3, 3, 3, 4, 2, 4, 2, 6, 2, 9, 1, 1, 1, 8, 1, 5, 4, 
      3, 3, 3, 4, 2, 4, 2, 1, 6, 2, 9, 1, 1, 1, 8, 1, 5, 4, 3, 3, 4, 2, 4, 2, 
      1, 6, 1, 2, 2, 9, 1, 1, 1, 8, 1, 5, 4, 3, 4, 2, 4, 2, 1, 6, 1, 2, 2, 1, 
      2, 9, 1, 1, 8, 1, 5, 4, 3, 4, 2, 4, 2, 1, 6, 1, 2, 2, 1, 1, 1, 2, 9, 1, 
      8, 1, 5, 4, 3, 4, 2, 4, 2, 1, 6, 1, 2, 1, 1, 1, 3, 2, 9, 1, 8, 1, 5, 4, 
      3, 4, 2, 4, 2, 1, 6, 1, 2, 1, 1, 1, 1, 2, 2, 9, 1, 8, 1, 5, 4, 3, 2, 4, 
      2, 1, 6, 1, 2, 1, 1, 1, 1, 2, 2, 2, 2, 9, 1, 8, 1, 5, 4, 3, 2, 4, 2, 1, 
      1, 2, 1, 1, 1, 1, 2, 2, 2, 3, 3, 2, 9, 1, 1, 5, 4, 3, 2, 4, 2, 1, 1, 2, 
      1, 1, 1, 1, 2, 2, 2, 3, 3, 1, 7, 2, 9, 1, 1, 5, 4, 3, 2, 4, 2, 1, 1, 2, 
      1, 1, 1, 2, 2, 2, 3, 3, 7, 2, 2, 9, 1, 5, 4, 3, 2, 4, 2, 1, 1, 2, 1, 1, 
      1, 2, 2, 3, 3, 7, 2, 3, 2, 9, 1, 5, 4, 3, 2, 4, 2, 1, 2, 1, 1, 2, 2, 3, 
      3, 7, 2, 3, 2, 9, 1, 5, 4, 3, 2, 4, 2, 1, 2, 1, 2, 2, 3, 3, 7, 2, 3, 2, 
      3, 9, 1, 5, 4, 3, 2, 4, 2, 1, 2, 2, 3, 3, 7, 2, 3, 2, 3, 3, 9, 1, 4, 3, 
      2, 4, 2, 1, 2, 2, 3, 3, 7, 2, 3, 2, 3, 3, 3, 2, 9, 1, 4, 3, 2, 4, 2, 1, 
      2, 2, 3, 3, 2, 3, 2, 3, 3, 2, 9, 1, 4, 3, 4, 2, 1, 2, 2, 3, 3, 2, 3, 2, 
      3, 3, 2, 9, 10, 1, 4, 3, 2, 1, 2, 2, 3, 3, 2, 3, 2, 3, 3, 2, 9, 10, 1, 
      3, 1, 3, 2, 1, 2, 2, 3, 3, 2, 3, 2, 3, 3, 2, 9, 10, 1, 3, 1, 3, 1, 3, 
      2, 1, 2, 2, 3, 3, 2, 3, 2, 3, 2, 9, 10, 1, 3, 1, 3, 1, 2, 1, 3, 2, 1, 
      2, 2, 3, 3, 2, 3, 2, 2, 9, 10, 3, 1, 3, 1, 2, 4, 1, 3, 2, 1, 2, 2, 3, 
      3, 2, 3, 2, 2, 9, 10, 3, 1, 3, 1, 2, 3, 1, 1, 3, 2, 1, 2, 2, 3, 3, 2, 
      2, 2, 9, 10, 3, 1, 1, 2, 3, 1, 6, 1, 2, 2, 2, 3, 3, 2, 2, 2, 9, 10, 3, 
      1, 1, 2, 3, 1, 6, 4, 1, 2, 2, 2, 3, 2, 2, 2, 9, 10, 1, 1, 2, 3, 1, 6, 
      4, 6, 1, 2, 2, 2, 3, 2, 2, 9, 10, 1, 1, 2, 3, 1, 6, 4, 6, 2, 1, 1, 2, 
      2, 2, 3, 2, 2, 9, 1, 1, 2, 3, 1, 6, 4, 6, 1, 12, 1, 2, 2, 2, 3, 2, 2, 
      1, 1, 2, 3, 1, 6, 4, 6, 1, 12, 8, 1, 1, 2, 2, 3, 2, 2, 1, 1, 2, 3, 1, 
      6, 4, 6, 1, 12, 8, 1, 1, 2, 1, 2, 2, 3, 2, 2, 1, 1, 2, 3, 1, 6, 4, 6, 
      12, 8, 1, 1, 2, 1, 1, 1, 2, 3, 2, 1, 1, 2, 3, 1, 6, 4, 6, 12, 8, 1, 1, 
      2, 1, 1, 2, 1, 2, 3, 2, 1, 1, 2, 3, 1, 4, 6, 12, 8, 1, 1, 2, 1, 1, 2, 
      1, 5, 1, 2, 3, 2, 1, 1, 2, 3, 6, 12, 8, 1, 1, 2, 1, 1, 2, 1, 5, 4, 1, 
      2, 3, 2, 1, 1, 2, 3, 6, 12, 8, 1, 2, 1, 1, 2, 1, 5, 5, 1, 2, 3, 2, 1, 
      2, 3, 6, 8, 1, 2, 1, 1, 2, 1, 5, 5, 12, 1, 2, 3, 2, 1, 3, 8, 1, 2, 1, 
      1, 2, 1, 5, 5, 12, 8, 1, 2, 3, 2, 1, 3, 8, 1, 2, 1, 1, 2, 1, 5, 5, 12, 
      2, 6, 1, 2, 1, 3, 8, 1, 2, 1, 1, 2, 1, 5, 5, 12, 2, 6, 5, 1, 2, 1, 3, 
      8, 1, 2, 1, 1, 2, 1, 5, 12, 2, 6, 5, 5, 1, 1, 2, 1, 8, 1, 2, 1, 1, 2, 
      1, 5, 12, 2, 6, 5, 5, 1, 2, 1, 1, 2, 1, 8, 1, 1, 1, 2, 5, 12, 2, 6, 5, 
      5, 1, 2, 1, 3, 1, 2, 1, 8, 1, 1, 1, 2, 5, 12, 2, 5, 5, 1, 2, 1, 3, 3, 
      3, 1, 2, 1, 8, 1, 1, 1, 2, 5, 12, 2, 5, 1, 2, 1, 3, 3, 3, 1, 4, 1, 2, 
      1, 8, 1, 1, 1, 2, 5, 12, 5, 1, 1, 3, 3, 3, 1, 4, 4, 1, 2, 1, 8, 1, 1, 
      1, 2, 5, 12, 5, 1, 1, 3, 3, 3, 1, 4, 1, 3, 1, 2, 1, 8, 1, 1, 1, 2, 5, 
      12, 5, 1, 1, 3, 3, 3, 1, 4, 1, 2, 1, 1, 2, 1, 8, 1, 1, 1, 2, 5, 12, 5, 
      1, 1, 3, 3, 3, 1, 1, 2, 1, 2, 2, 1, 2, 1, 8, 1, 1, 1, 2, 5, 12, 5, 1, 
      1, 3, 3, 3, 1, 1, 2, 2, 3, 1, 2, 1, 8, 1, 1, 1, 2, 5, 12, 5, 1, 1, 3, 
      3, 1, 1, 2, 2, 3, 1, 2, 1, 2, 1, 8, 1, 1, 1, 2, 5, 12, 5, 1, 1, 3, 1, 
      1, 2, 2, 3, 1, 2, 1, 3, 1, 2, 1, 8, 1, 1, 1, 2, 5, 12, 1, 1, 3, 1, 1, 
      2, 2, 3, 1, 2, 1, 3, 4, 1, 1, 1, 8, 1, 1, 1, 2, 5, 12, 1, 1, 3, 1, 1, 
      2, 2, 3, 1, 2, 1, 3, 4, 1, 1, 1, 1, 1, 8, 1, 1, 1, 2, 5, 1, 1, 3, 1, 1, 
      2, 2, 3, 1, 2, 1, 3, 4, 1, 1, 1, 8, 4, 1, 1, 8, 1, 1, 1, 2, 5, 1, 1, 3, 
      1, 1, 2, 2, 3, 1, 2, 1, 3, 4, 1, 1, 1, 12, 1, 1, 8, 1, 1, 1, 2, 5, 1, 
      1, 3, 1, 2, 2, 3, 1, 2, 1, 3, 1, 1, 1, 12, 5, 1, 1, 8, 1, 1, 1, 2, 1, 
      1, 3, 1, 2, 2, 3, 1, 2, 1, 3, 1, 1, 1, 12, 5, 4, 1, 1, 1, 8, 1, 1, 1, 
      2, 1, 1, 3, 1, 2, 2, 3, 1, 2, 1, 3, 1, 1, 1, 5, 4, 1, 10, 2, 1, 1, 8, 
      1, 1, 1, 1, 3, 1, 2, 2, 3, 1, 2, 1, 3, 1, 1, 1, 5, 4, 1, 10, 2, 3, 1, 
      1, 8, 1, 1, 1, 1, 3, 1, 2, 2, 3, 1, 2, 3, 1, 1, 5, 4, 1, 10, 2, 3, 2, 
      1, 1, 8, 1, 1, 1, 1, 3, 1, 2, 2, 3, 1, 2, 1, 1, 5, 4, 1, 10, 2, 3, 4, 
      1, 1, 8, 1, 1, 1, 1, 3, 1, 2, 2, 3, 1, 1, 1, 5, 4, 10, 2, 3, 4, 3, 1, 
      1, 8, 1, 1, 1, 1, 3, 1, 2, 2, 3, 1, 1, 1, 5, 4, 2, 3, 4, 3, 4, 7, 1, 1, 
      8, 1, 1, 1, 3, 1, 2, 3, 1, 1, 1, 5, 4, 2, 3, 4, 3, 4, 7, 3, 1, 1, 8, 1, 
      1, 1, 3, 1, 2, 3, 1, 1, 1, 5, 4, 2, 3, 4, 3, 4, 3, 3, 5, 1, 1, 8, 1, 1, 
      1, 3, 3, 1, 1, 1, 5, 4, 2, 3, 4, 3, 4, 3, 3, 5, 3, 1, 1, 8, 1, 1, 1, 3, 
      1, 1, 1, 5, 4, 2, 3, 4, 3, 4, 3, 5, 3, 6, 1, 1, 8, 1, 1, 1, 3, 1, 1, 1, 
      5, 4, 2, 4, 3, 4, 3, 5, 3, 6, 2, 2, 1, 1, 8, 1, 1, 1, 1, 1, 1, 5, 4, 4, 
      3, 4, 3, 5, 3, 6, 2, 2, 5, 1, 8, 1, 1, 1, 1, 1, 1, 4, 4, 3, 4, 3, 5, 3, 
      6, 2, 2, 5, 6, 8, 1, 1, 1, 1, 1, 4, 4, 3, 4, 3, 5, 3, 6, 2, 2, 5, 6, 2, 
      8, 1, 1, 1, 1, 1, 4, 4, 3, 4, 5, 3, 6, 2, 2, 5, 6, 2, 1, 3, 8, 1, 1, 1, 
      1, 1, 4, 4, 3, 4, 5, 6, 2, 2, 5, 6, 2, 3, 4, 1, 1, 1, 1, 1, 4, 4, 3, 4, 
      5, 6, 2, 2, 5, 2, 3, 4, 10, 1, 1, 1, 1, 4, 4, 3, 4, 5, 6, 2, 5, 2, 3, 
      4, 10, 3, 1, 1, 1, 1, 4, 4, 3, 4, 5, 6, 2, 5, 2, 3, 10, 3, 1, 3, 1, 1, 
      1, 1, 4, 4, 3, 4, 6, 2, 5, 3, 10, 3, 1, 3, 7, 1, 1, 1, 1, 4, 4, 3, 4, 
      6, 5, 3, 10, 3, 1, 3, 7, 1, 1, 1, 1, 1, 1, 4, 4, 3, 4, 6, 3, 10, 3, 1, 
      3, 7, 1, 5, 1, 1, 1, 1, 4, 4, 3, 6, 3, 10, 3, 1, 3, 7, 1, 5, 1, 3, 1, 
      1, 1, 1, 4, 4, 3, 3, 10, 3, 1, 3, 7, 1, 5, 1, 3, 3, 3, 1, 1, 1, 1, 4, 
      4, 3, 3, 10, 3, 1, 3, 7, 1, 1, 3, 3, 3, 3, 2, 1, 1, 1, 1, 4, 4, 3, 3, 
      10, 3, 1, 3, 7, 1, 1, 3, 3, 3, 2, 2, 1, 1, 1, 1, 1, 4, 4, 3, 10, 3, 1, 
      3, 7, 1, 1, 3, 3, 3, 2, 2, 1, 2, 1, 1, 1, 1, 1, 4, 4, 3, 10, 1, 3, 7, 
      1, 1, 3, 3, 3, 2, 2, 1, 2, 1, 2, 1, 1, 1, 1, 1, 4, 3, 10, 3, 7, 1, 1, 
      3, 3, 3, 2, 2, 1, 2, 1, 2, 1, 5, 1, 1, 1, 1, 4, 10, 3, 7, 1, 3, 3, 3, 
      2, 2, 1, 2, 1, 2, 1, 5, 4, 1, 1, 1, 4, 10, 3, 7, 1, 3, 3, 3, 2, 2, 1, 
      2, 1, 2, 5, 4, 2, 1, 1, 1, 4, 10, 3, 7, 1, 3, 3, 3, 2, 1, 2, 1, 2, 4, 
      2, 7, 1, 1, 1, 4, 10, 3, 7, 1, 3, 3, 3, 2, 1, 2, 4, 2, 7, 3, 1, 1, 1, 
      4, 10, 3, 7, 1, 3, 3, 3, 2, 1, 2, 2, 7, 3, 2, 2, 1, 1, 1, 4, 10, 3, 7, 
      1, 3, 3, 2, 1, 2, 2, 7, 2, 2, 6, 1, 1, 1, 4, 10, 3, 7, 1, 3, 3, 2, 1, 
      2, 2, 2, 2, 6, 4, 3, 1, 1, 4, 3, 7, 1, 3, 3, 2, 1, 2, 2, 2, 2, 6, 4, 3, 
      11, 1, 1, 4, 3, 7, 1, 3, 3, 2, 1, 2, 2, 2, 6, 3, 11, 6, 1, 1, 4, 3, 7, 
      1, 3, 3, 2, 1, 2, 2, 6, 3, 11, 6, 1, 1, 1, 1, 4, 3, 7, 1, 3, 3, 2, 1, 
      2, 2, 6, 3, 11, 1, 1, 4, 2, 1, 1, 4, 3, 1, 3, 3, 2, 1, 2, 2, 6, 3, 11, 
      1, 1, 4, 2, 1, 6, 1, 1, 4, 3, 1, 3, 2, 1, 2, 2, 6, 3, 11, 1, 1, 2, 1, 
      6, 7, 1, 1, 4, 3, 1, 3, 2, 1, 2, 2, 6, 3, 1, 1, 2, 1, 6, 7, 1, 10, 1, 
      1, 4, 3, 1, 3, 2, 1, 2, 2, 6, 1, 2, 1, 6, 7, 1, 10, 4, 1, 1, 4, 3, 1, 
      3, 2, 1, 2, 2, 6, 1, 2, 1, 6, 7, 1, 10, 2, 2, 1, 1, 4, 3, 1, 3, 2, 1, 
      2, 2, 1, 2, 1, 6, 7, 1, 10, 2, 8, 1, 1, 4, 3, 1, 3, 2, 1, 2, 2, 1, 2, 
      1, 6, 1, 10, 8, 9, 1, 1, 4, 3, 3, 2, 1, 2, 1, 2, 1, 6, 1, 10, 8, 9, 3, 
      1, 1, 4, 3, 3, 2, 1, 2, 1, 2, 1, 6, 1, 10, 9, 3, 3, 5, 1, 1, 4, 3, 3, 
      2, 1, 2, 1, 2, 1, 6, 1, 10, 9, 3, 5, 1, 3, 1, 1, 4, 3, 3, 2, 1, 2, 1, 
      2, 1, 6, 1, 10, 9, 5, 1, 3, 1, 3, 1, 1, 4, 3, 2, 1, 2, 2, 1, 6, 1, 10, 
      9, 5, 1, 3, 1, 3, 4, 1, 1, 3, 1, 2, 2, 1, 6, 1, 10, 9, 5, 1, 3, 1, 3, 
      4, 5, 1, 1, 3, 1, 2, 2, 1, 6, 1, 10, 5, 1, 3, 1, 3, 4, 5, 6, 3, 1, 1, 
      3, 1, 2, 2, 1, 6, 1, 5, 1, 3, 1, 3, 4, 5, 6, 3, 9, 2, 1, 1, 3, 1, 2, 2, 
      1, 1, 5, 1, 3, 3, 4, 5, 6, 3, 9, 2, 7, 1, 1, 3, 1, 2, 2, 1, 1, 5, 1, 3, 
      3, 4, 5, 3, 9, 2, 7, 4, 2, 1, 1, 3, 1, 2, 2, 1, 1, 5, 1, 3, 3, 4, 5, 3, 
      9, 2, 4, 2, 3, 4, 1, 1, 1, 2, 2, 1, 1, 5, 1, 3, 3, 4, 5, 3, 9, 2, 4, 2, 
      3, 4, 1, 2, 1, 1, 1, 2, 2, 1, 5, 1, 3, 3, 4, 5, 3, 9, 2, 2, 3, 4, 1, 2, 
      4, 1, 1, 1, 2, 2, 1, 1, 3, 3, 4, 5, 3, 9, 2, 2, 3, 4, 1, 2, 4, 1, 4, 1, 
      1, 1, 2, 2, 1, 3, 3, 4, 5, 3, 2, 2, 3, 4, 1, 2, 4, 1, 4, 10, 1, 1, 1, 
      2, 2, 1, 3, 3, 4, 5, 3, 2, 2, 3, 4, 1, 2, 4, 1, 4, 4, 7, 1, 1, 1, 2, 2, 
      1, 3, 3, 4, 5, 3, 2, 2, 3, 4, 1, 2, 4, 1, 4, 7, 3, 1, 1, 1, 1, 2, 2, 1, 
      3, 3, 4, 5, 3, 2, 2, 3, 4, 1, 2, 4, 1, 4, 3, 1, 6, 1, 1, 1, 1, 2, 2, 1, 
      3, 4, 5, 3, 2, 2, 3, 4, 1, 2, 4, 1, 4, 3, 1, 6, 4, 1, 1, 1, 2, 2, 1, 3, 
      5, 3, 2, 2, 3, 4, 1, 2, 4, 1, 4, 1, 6, 4, 5, 1, 1, 1, 2, 2, 1, 3, 5, 3, 
      2, 2, 3, 4, 2, 4, 1, 4, 6, 4, 5, 2, 1, 1, 1, 2, 2, 1, 3, 5, 2, 2, 3, 4, 
      2, 4, 1, 4, 6, 4, 5, 2, 1, 2, 1, 1, 2, 2, 1, 3, 5, 2, 2, 3, 4, 2, 4, 1, 
      4, 4, 5, 2, 1, 2, 7, 1, 1, 2, 2, 1, 5, 2, 2, 3, 4, 2, 4, 1, 4, 4, 5, 2, 
      2, 7, 4, 1, 1, 2, 1, 5, 2, 3, 4, 2, 4, 1, 4, 4, 5, 2, 2, 7, 4, 4, 1, 2, 
      1, 5, 2, 3, 4, 2, 4, 1, 4, 4, 2, 2, 7, 4, 4, 6, 1, 2, 1, 5, 2, 3, 4, 2, 
      4, 1, 4, 4, 2, 2, 4, 4, 6, 3, 4, 1, 2, 1, 5, 2, 3, 4, 2, 4, 1, 4, 4, 2, 
      2, 4, 6, 3, 4, 3, 1, 1, 2, 1, 5, 2, 3, 2, 4, 1, 4, 4, 2, 2, 4, 6, 3, 4, 
      3, 1, 2, 2, 1, 2, 5, 2, 3, 2, 4, 1, 4, 4, 2, 2, 6, 3, 4, 3, 1, 2, 2, 5, 
      1, 2, 2, 3, 2, 4, 1, 4, 4, 2, 2, 6, 3, 4, 3, 2, 2, 5, 5, 1, 2, 2, 3, 2, 
      1, 4, 4, 2, 2, 6, 3, 4, 3, 2, 2, 5, 5, 3, 2, 1, 2, 2, 3, 2, 1, 4, 4, 2, 
      2, 6, 3, 4, 3, 2, 2, 5, 3, 2, 4, 2, 1, 2, 2, 3, 2, 1, 4, 4, 2, 2, 6, 3, 
      4, 3, 2, 2, 5, 3, 2, 2, 3, 1, 1, 2, 2, 3, 2, 1, 4, 4, 2, 2, 6, 3, 4, 3, 
      2, 2, 5, 3, 2, 2, 1, 3, 1, 1, 2, 2, 3, 2, 1, 4, 4, 2, 2, 6, 3, 4, 3, 2, 
      2, 3, 2, 2, 1, 3, 1, 3, 2, 1, 2, 2, 3, 2, 1, 4, 4, 2, 2, 3, 4, 3, 2, 2, 
      3, 2, 2, 1, 3, 1, 3, 2, 1, 5, 1, 2, 2, 3, 2, 1, 4, 2, 3, 4, 3, 2, 2, 3, 
      2, 2, 1, 3, 1, 3, 2, 1, 5, 6, 1, 2, 2, 3, 2, 1, 4, 2, 3, 3, 2, 3, 2, 2, 
      1, 3, 1, 3, 2, 1, 5, 6, 3, 1, 2, 2, 3, 2, 1, 2, 3, 3, 2, 3, 2, 2, 1, 3, 
      1, 3, 2, 1, 5, 6, 3, 4, 1, 1, 2, 2, 3, 2, 1, 2, 3, 3, 2, 3, 2, 2, 1, 3, 
      1, 3, 2, 1, 5, 3, 4, 1, 3, 3, 1, 2, 2, 2, 1, 2, 3, 3, 2, 3, 2, 2, 1, 3, 
      1, 2, 1, 5, 3, 4, 1, 3, 3, 6, 1, 2, 2, 2, 1, 2, 3, 2, 3, 2, 2, 1, 3, 1, 
      2, 5, 3, 4, 1, 3, 3, 6, 4, 1, 2, 2, 2, 1, 2, 3, 2, 3, 2, 2, 1, 3, 1, 2, 
      5, 3, 4, 1, 3, 3, 6, 2, 2, 2, 2, 2, 1, 2, 3, 2, 3, 2, 2, 1, 3, 1, 2, 5, 
      3, 4, 1, 3, 3, 6, 2, 3, 2, 2, 2, 1, 2, 3, 2, 2, 2, 1, 3, 2, 5, 3, 4, 1, 
      3, 3, 6, 2, 3, 4, 2, 2, 2, 1, 2, 3, 2, 2, 2, 1, 3, 2, 5, 3, 4, 1, 3, 6, 
      2, 3, 4, 1, 2, 2, 2, 2, 1, 2, 3, 2, 2, 2, 1, 3, 2, 5, 3, 4, 1, 3, 6, 2, 
      3, 1, 2, 3, 1, 2, 2, 2, 1, 2, 3, 2, 2, 1, 3, 2, 5, 3, 4, 1, 3, 6, 2, 3, 
      1, 2, 3, 1, 1, 1, 2, 2, 1, 2, 3, 2, 2, 1, 2, 5, 3, 4, 1, 3, 6, 2, 3, 1, 
      2, 3, 1, 1, 1, 5, 2, 2, 1, 2, 3, 2, 2, 1, 2, 5, 3, 4, 1, 6, 2, 3, 1, 2, 
      3, 1, 1, 1, 5, 1, 3, 2, 2, 1, 2, 3, 2, 2, 1, 2, 5, 3, 4, 1, 2, 3, 1, 2, 
      3, 1, 1, 1, 5, 1, 3, 2, 4, 2, 2, 1, 2, 3, 2, 2, 1, 2, 5, 3, 4, 1, 2, 1, 
      2, 3, 1, 1, 5, 1, 3, 2, 4, 4, 2, 2, 1, 2, 3, 2, 1, 2, 5, 3, 1, 1, 2, 3, 
      1, 1, 5, 1, 3, 2, 4, 4, 4, 1, 3, 2, 2, 1, 2, 3, 2, 1, 2, 5, 3, 1, 1, 2, 
      3, 1, 1, 5, 1, 3, 2, 4, 4, 4, 1, 3, 2, 2, 1, 2, 3, 2, 1, 2, 5, 3, 1, 1, 
      2, 3, 1, 1, 5, 1, 3, 4, 4, 1, 3, 6, 2, 2, 1, 2, 3, 2, 1, 2, 3, 1, 1, 2, 
      3, 1, 1, 5, 1, 3, 4, 4, 1, 3, 6, 3, 2, 2, 2, 1, 2, 3, 2, 1, 2, 3, 1, 1, 
      2, 3, 1, 1, 5, 4, 4, 1, 3, 6, 3, 2, 3, 2, 2, 1, 2, 3, 2, 1, 2, 3, 1, 1, 
      2, 3, 1, 5, 4, 4, 3, 6, 3, 2, 3, 2, 2, 2, 1, 2, 3, 2, 1, 2, 3, 1, 1, 2, 
      3, 1, 5, 4, 4, 3, 6, 3, 2, 5, 2, 2, 1, 3, 2, 1, 2, 3, 1, 1, 2, 3, 1, 5, 
      4, 3, 6, 3, 2, 5, 5, 2, 2, 1, 2, 1, 2, 3, 1, 2, 3, 1, 5, 4, 3, 6, 3, 2, 
      5, 5, 3, 2, 2, 1, 2, 1, 2, 3, 1, 2, 3, 1, 5, 4, 3, 6, 3, 2, 5, 3, 4, 1, 
      2, 2, 1, 2, 1, 2, 3, 1, 2, 3, 1, 5, 4, 3, 6, 3, 5, 3, 4, 1, 1, 1, 2, 2, 
      1, 2, 1, 2, 3, 1, 2, 3, 1, 4, 3, 6, 3, 5, 3, 4, 1, 1, 1, 3, 3, 2, 2, 1, 
      2, 1, 2, 3, 1, 2, 3, 1, 4, 3, 3, 5, 3, 4, 1, 1, 1, 3, 3, 5, 1, 2, 2, 1, 
      2, 1, 2, 3, 1, 2, 3, 1, 4, 3, 3, 5, 3, 1, 1, 1, 3, 3, 5, 1, 2, 2, 2, 2, 
      1, 2, 1, 2, 3, 1, 2, 3, 1, 4, 3, 5, 3, 1, 1, 3, 3, 5, 1, 2, 2, 4, 2, 2, 
      1, 2, 1, 2, 3, 1, 2, 3, 1, 3, 5, 3, 1, 1, 3, 3, 5, 1, 2, 2, 4, 1, 3, 2, 
      2, 1, 2, 1, 2, 3, 1, 2, 3, 1, 3, 5, 3, 1, 1, 3, 3, 5, 1, 2, 2, 4, 1, 1, 
      2, 2, 2, 1, 2, 1, 2, 3, 1, 2, 3, 3, 5, 3, 1, 1, 3, 3, 5, 1, 2, 2, 4, 1, 
      2, 2, 2, 2, 1, 2, 1, 2, 3, 1, 2, 3, 3, 5, 3, 1, 1, 3, 3, 5, 1, 2, 4, 1, 
      2, 2, 1, 1, 2, 2, 1, 2, 1, 2, 3, 1, 2, 3, 3, 5, 3, 1, 1, 3, 3, 5, 1, 4, 
      1, 2, 2, 1, 1, 1, 2, 2, 2, 1, 2, 1, 2, 3, 1, 2, 3, 3, 5, 3, 1, 1, 3, 5, 
      1, 4, 1, 2, 2, 1, 1, 1, 2, 1, 2, 2, 2, 1, 2, 1, 2, 3, 1, 2, 3, 5, 3, 1, 
      1, 3, 5, 1, 4, 1, 2, 2, 1, 1, 1, 2, 1, 2, 2, 1, 2, 2, 1, 2, 1, 2, 3, 1, 
      3, 5, 3, 1, 1, 3, 1, 4, 1, 2, 2, 1, 1, 1, 2, 1, 2, 2, 1, 7, 2, 2, 1, 2, 
      1, 2, 1, 3, 5, 3, 1, 3, 1, 4, 1, 2, 2, 1, 1, 1, 2, 1, 2, 2, 1, 7, 4, 2, 
      1, 2, 1, 2, 1, 3, 5, 3, 1, 3, 1, 4, 1, 2, 2, 1, 1, 1, 2, 2, 2, 1, 7, 4, 
      3, 2, 1, 2, 1, 1, 3, 5, 3, 1, 3, 1, 4, 1, 2, 2, 1, 1, 1, 2, 2, 1, 7, 4, 
      3, 4, 2, 1, 2, 1, 1, 3, 5, 3, 1, 3, 1, 4, 1, 2, 2, 1, 1, 1, 2, 2, 1, 4, 
      3, 4, 4, 3, 2, 1, 2, 1, 1, 3, 5, 3, 1, 3, 1, 4, 1, 2, 2, 1, 1, 1, 2, 2, 
      1, 3, 4, 4, 3, 3, 1, 2, 1, 2, 1, 1, 3, 5, 3, 1, 3, 1, 1, 2, 2, 1, 1, 1, 
      2, 2, 1, 3, 4, 4, 3, 3, 5, 2, 1, 2, 1, 1, 3, 5, 3, 1, 3, 1, 1, 2, 2, 1, 
      1, 1, 2, 1, 3, 4, 3, 3, 5, 6, 2, 1, 2, 1, 1, 3, 5, 3, 1, 3, 1, 1, 2, 2, 
      1, 1, 1, 1, 3, 4, 3, 3, 5, 6, 1, 1, 2, 1, 2, 1, 1, 3, 5, 3, 1, 3, 1, 1, 
      2, 2, 1, 1, 1, 1, 3, 4, 3, 3, 5, 1, 1, 4, 2, 2, 1, 2, 1, 3, 5, 3, 1, 3, 
      1, 1, 2, 2, 1, 1, 1, 3, 4, 3, 3, 5, 1, 1, 4, 2, 2, 2, 1, 2, 1, 3, 5, 3, 
      1, 3, 1, 2, 2, 1, 1, 1, 3, 3, 3, 5, 1, 1, 4, 2, 2, 4, 2, 1, 2, 1, 3, 5, 
      3, 1, 3, 1, 2, 2, 1, 1, 1, 3, 3, 5, 1, 1, 4, 2, 2, 4, 1, 3, 2, 1, 2, 1, 
      3, 5, 3, 1, 3, 1, 2, 2, 1, 1, 1, 3, 3, 5, 1, 1, 4, 2, 2, 4, 1, 1, 2, 2, 
      1, 2, 1, 3, 5, 3, 1, 1, 2, 2, 1, 1, 1, 3, 3, 5, 1, 1, 4, 2, 4, 1, 1, 2, 
      5, 2, 1, 2, 1, 3, 5, 3, 1, 1, 2, 2, 1, 1, 1, 3, 3, 5, 1, 4, 2, 4, 1, 2, 
      5, 2, 2, 1, 2, 1, 3, 5, 3, 1, 1, 2, 2, 1, 1, 1, 3, 3, 5, 1, 4, 2, 4, 1, 
      2, 2, 1, 4, 2, 1, 2, 1, 3, 5, 3, 1, 1, 2, 2, 1, 1, 1, 3, 3, 5, 4, 2, 4, 
      1, 2, 2, 4, 2, 2, 1, 1, 3, 5, 3, 1, 1, 2, 2, 1, 1, 1, 3, 3, 5, 4, 2, 4, 
      1, 2, 2, 4, 2, 1, 1, 2, 1, 1, 3, 5, 3, 1, 1, 2, 2, 1, 1, 1, 3, 3, 5, 4, 
      2, 4, 1, 2, 2, 2, 1, 1, 1, 4, 2, 1, 1, 3, 5, 3, 1, 2, 1, 1, 1, 3, 3, 5, 
      4, 2, 4, 1, 2, 2, 2, 1, 1, 1, 4, 3, 2, 1, 1, 3, 5, 3, 1, 2, 1, 1, 1, 3, 
      3, 5, 4, 2, 4, 1, 2, 2, 2, 1, 1, 1, 4, 2, 1, 2, 1, 3, 5, 3, 1, 2, 1, 1, 
      3, 3, 5, 4, 2, 4, 1, 2, 2, 2, 1, 1, 1, 4, 2, 1, 2, 2, 1, 3, 5, 3, 1, 2, 
      1, 1, 3, 3, 5, 4, 2, 4, 1, 2, 1, 1, 1, 4, 2, 1, 2, 4, 2, 1, 3, 5, 3, 1, 
      2, 1, 3, 3, 5, 4, 2, 4, 1, 1, 1, 1, 4, 2, 1, 2, 4, 3, 2, 1, 3, 5, 3, 1, 
      2, 3, 5, 4, 2, 4, 1, 1, 1, 1, 4, 2, 1, 2, 4, 3, 2, 2, 1, 3, 5, 3, 1, 2, 
      3, 5, 4, 2, 4, 1, 1, 1, 4, 2, 1, 2, 4, 3, 3, 2, 1, 3, 5, 3, 1, 2, 3, 4, 
      2, 4, 1, 1, 1, 4, 2, 1, 2, 4, 3, 3, 2, 4, 2, 1, 3, 3, 1, 2, 3, 4, 2, 4, 
      1, 1, 1, 4, 2, 1, 2, 4, 3, 3, 2, 4, 3, 2, 2, 1, 3, 3, 1, 2, 3, 4, 2, 4, 
      1, 4, 2, 1, 2, 4, 3, 3, 2, 4, 3, 2, 2, 2, 1, 3, 3, 1, 2, 3, 4, 2, 4, 1, 
      4, 2, 2, 4, 3, 3, 2, 4, 3, 2, 2, 2, 1, 3, 3, 2, 3, 4, 2, 4, 1, 4, 2, 2, 
      4, 3, 3, 2, 4, 3, 2, 2, 2, 1, 3, 3, 2, 3, 4, 2, 4, 4, 2, 2, 4, 3, 3, 2, 
      3, 2, 2, 5, 2, 1, 3, 3, 2, 3, 4, 2, 4, 4, 2, 2, 4, 3, 2, 3, 2, 2, 5, 2, 
      1, 2, 1, 3, 3, 3, 4, 2, 4, 4, 2, 4, 3, 2, 3, 2, 2, 5, 2, 1, 4, 2, 1, 3, 
      3, 3, 4, 2, 4, 4, 2, 4, 3, 2, 3, 2, 2, 5, 2, 1, 2, 2, 2, 1, 3, 3, 3, 4, 
      2, 4, 4, 2, 4, 3, 2, 3, 2, 2, 5, 1, 2, 2, 1, 1, 2, 1, 3, 3, 3, 4, 2, 4, 
      4, 4, 3, 2, 3, 2, 2, 5, 1, 2, 2, 1, 1, 1, 1, 2, 1, 3, 3, 3, 4, 2, 4, 4, 
      4, 2, 3, 2, 2, 5, 1, 2, 2, 1, 1, 1, 1, 3, 1, 2, 1, 3, 3, 4, 2, 4, 4, 4, 
      2, 3, 2, 2, 5, 1, 2, 2, 1, 1, 1, 3, 1, 4, 2, 1, 3, 3, 4, 2, 4, 4, 4, 2, 
      3, 2, 5, 1, 2, 1, 1, 1, 3, 1, 4, 3, 2, 1, 3, 3, 4, 2, 4, 4, 4, 2, 3, 2, 
      1, 2, 1, 1, 1, 3, 1, 4, 3, 3, 2, 2, 1, 3, 3, 4, 2, 4, 4, 4, 2, 3, 1, 2, 
      1, 1, 1, 3, 1, 4, 3, 2, 5, 1, 3, 3, 4, 2, 4, 4, 4, 2, 3, 1, 2, 1, 1, 1, 
      3, 4, 3, 2, 5, 3, 1, 3, 3, 4, 2, 4, 4, 4, 2, 3, 1, 2, 1, 1, 4, 3, 2, 5, 
      3, 4, 1, 3, 4, 2, 4, 4, 4, 2, 3, 1, 2, 1, 1, 4, 3, 2, 5, 3, 7, 1, 3, 4, 
      2, 4, 4, 2, 3, 1, 2, 1, 4, 3, 2, 5, 3, 7, 5, 1, 3, 4, 2, 4, 4, 2, 3, 1, 
      2, 1, 4, 3, 2, 3, 5, 10, 1, 3, 4, 4, 4, 2, 3, 1, 2, 1, 4, 3, 2, 5, 10, 
      5, 1, 3, 4, 4, 2, 3, 1, 2, 1, 4, 3, 2, 5, 10, 5, 2, 2, 1, 3, 4, 4, 2, 
      1, 2, 1, 4, 3, 2, 5, 10, 5, 2, 2, 2, 1, 1, 3, 4, 4, 2, 1, 2, 4, 3, 2, 
      5, 10, 5, 2, 2, 1, 3, 1, 3, 4, 4, 2, 1, 2, 4, 3, 2, 5, 5, 2, 2, 1, 3, 
      7, 3, 1, 3, 4, 4, 2, 1, 2, 4, 3, 2, 5, 2, 2, 1, 3, 7, 3, 3, 2, 3, 4, 4, 
      2, 1, 2, 4, 3, 2, 5, 2, 2, 1, 3, 7, 3, 3, 2, 1, 1, 3, 4, 4, 2, 1, 2, 4, 
      3, 2, 5, 2, 2, 1, 3, 3, 3, 2, 1, 1, 2, 5, 3, 4, 4, 2, 1, 2, 4, 3, 2, 5, 
      2, 2, 1, 3, 3, 3, 2, 1, 1, 2, 5, 1, 3, 4, 4, 2, 1, 2, 4, 2, 5, 2, 1, 3, 
      3, 3, 2, 1, 1, 2, 5, 1, 5, 3, 4, 4, 2, 1, 2, 4, 2, 2, 1, 3, 3, 3, 2, 1, 
      1, 2, 1, 10, 1, 4, 3, 4, 4, 2, 1, 2, 4, 2, 2, 1, 3, 3, 3, 2, 1, 1, 2, 
      1, 10, 1, 4, 3, 4, 4, 2, 1, 4, 2, 2, 1, 3, 3, 2, 1, 1, 2, 1, 10, 1, 4, 
      5, 3, 4, 4, 2, 1, 2, 2, 1, 3, 3, 2, 1, 1, 2, 1, 10, 1, 4, 5, 1, 4, 3, 
      4, 4, 1, 2, 2, 1, 3, 3, 2, 1, 1, 2, 1, 10, 1, 4, 5, 1, 4, 1, 1, 3, 4, 
      4, 2, 2, 1, 3, 3, 2, 1, 1, 2, 10, 1, 4, 5, 1, 4, 1, 1, 2, 3, 4, 4, 2, 
      1, 3, 3, 2, 1, 2, 10, 1, 4, 5, 1, 4, 1, 1, 2, 3, 4, 4, 2, 1, 3, 3, 2, 
      1, 2, 10, 1, 4, 5, 1, 4, 1, 1, 2, 5, 4, 4, 2, 1, 3, 3, 2, 1, 2, 10, 4, 
      5, 1, 4, 1, 1, 2, 6, 4, 4, 2, 1, 3, 3, 2, 1, 2, 10, 4, 1, 4, 1, 1, 2, 
      6, 4, 1, 4, 4, 2, 1, 3, 3, 2, 1, 2, 10, 1, 4, 1, 1, 6, 4, 1, 4, 4, 4, 
      2, 1, 3, 3, 2, 1, 2, 10, 1, 4, 1, 1, 4, 1, 4, 5, 2, 4, 2, 1, 3, 3, 2, 
      1, 2, 10, 1, 4, 1, 1, 4, 1, 4, 2, 9, 4, 2, 1, 3, 3, 2, 1, 2, 10, 4, 1, 
      1, 4, 1, 4, 2, 9, 1, 1, 4, 2, 1, 3, 3, 2, 1, 2, 4, 1, 1, 4, 1, 4, 2, 9, 
      1, 1, 3, 7, 4, 2, 1, 3, 2, 1, 2, 4, 1, 1, 4, 1, 4, 2, 9, 1, 3, 7, 4, 4, 
      2, 1, 3, 2, 1, 2, 4, 1, 1, 4, 1, 4, 2, 9, 1, 3, 4, 6, 1, 4, 2, 1, 3, 2, 
      1, 2, 4, 1, 1, 4, 1, 4, 2, 9, 1, 4, 6, 1, 2, 1, 4, 2, 1, 2, 1, 2, 4, 1, 
      1, 4, 4, 2, 9, 1, 4, 6, 1, 2, 1, 4, 4, 2, 1, 2, 1, 2, 4, 1, 4, 4, 2, 9, 
      1, 4, 1, 2, 1, 4, 7, 4, 2, 1, 2, 1, 2, 4, 1, 4, 4, 2, 9, 4, 1, 2, 1, 4, 
      7, 1, 1, 4, 2, 1, 2, 1, 2, 4, 1, 4, 4, 2, 9, 4, 1, 4, 7, 1, 1, 3, 2, 1, 
      2, 1, 2, 4, 1, 4, 4, 2, 9, 4, 1, 7, 1, 1, 3, 8, 2, 1, 2, 1, 2, 4, 1, 4, 
      4, 9, 4, 1, 7, 1, 1, 3, 8, 1, 1, 2, 1, 2, 1, 2, 4, 1, 4, 4, 9, 4, 1, 7, 
      1, 1, 3, 1, 1, 5, 3, 2, 1, 2, 2, 4, 1, 4, 4, 9, 4, 1, 7, 1, 1, 1, 1, 5, 
      3, 4, 2, 1, 2, 2, 4, 1, 4, 9, 4, 1, 7, 1, 1, 1, 1, 5, 3, 4, 4, 1, 2, 1, 
      2, 2, 1, 4, 9, 4, 1, 7, 1, 1, 1, 1, 5, 3, 4, 4, 1, 1, 3, 2, 2, 2, 4, 9, 
      4, 1, 7, 1, 1, 1, 1, 5, 3, 4, 4, 1, 1, 3, 1, 2, 2, 2, 4, 9, 4, 1, 7, 1, 
      1, 1, 1, 5, 3, 4, 1, 1, 3, 1, 2, 2, 2, 2, 2, 9, 1, 7, 1, 1, 1, 1, 5, 3, 
      4, 1, 1, 3, 1, 2, 2, 8, 2, 9, 1, 7, 1, 1, 1, 1, 5, 3, 4, 1, 1, 3, 1, 2, 
      2, 8, 4, 2, 9, 1, 7, 1, 1, 1, 1, 5, 3, 4, 1, 1, 3, 1, 2, 2, 8, 2, 2, 2, 
      9, 1, 7, 1, 1, 1, 1, 5, 3, 4, 1, 1, 3, 1, 2, 2, 8, 2, 1, 1, 2, 9, 1, 1, 
      1, 1, 5, 3, 4, 1, 1, 3, 1, 2, 2, 8, 2, 1, 1, 8, 2, 1, 1, 1, 1, 5, 3, 4, 
      1, 1, 3, 1, 2, 2, 8, 2, 1, 8, 10, 2, 1, 1, 1, 5, 3, 1, 1, 3, 1, 2, 2, 
      8, 2, 1, 8, 10, 5, 1, 1, 1, 5, 3, 1, 1, 1, 2, 2, 8, 2, 1, 8, 10, 5, 5, 
      1, 1, 1, 5, 3, 1, 1, 1, 2, 2, 2, 1, 8, 10, 5, 5, 7, 1, 1, 1, 1, 3, 1, 
      1, 1, 2, 2, 2, 1, 8, 10, 5, 5, 7, 1, 4, 1, 1, 1, 1, 3, 1, 1, 1, 2, 2, 
      2, 1, 8, 10, 5, 5, 1, 4, 1, 5, 2, 1, 1, 1, 3, 1, 1, 1, 2, 2, 1, 8, 10, 
      5, 1, 4, 1, 5, 2, 7, 1, 1, 1, 3, 1, 1, 1, 2, 1, 8, 10, 5, 1, 4, 1, 5, 
      2, 7, 1, 1, 1, 1, 1, 3, 1, 1, 1, 2, 8, 10, 5, 1, 4, 1, 5, 2, 7, 1, 1, 
      1, 1, 1, 1, 1, 3, 1, 1, 2, 8, 10, 5, 4, 1, 5, 2, 7, 1, 1, 1, 1, 2, 1, 
      1, 3, 1, 1, 8, 10, 5, 4, 1, 5, 2, 7, 1, 1, 1, 1, 2, 3, 3, 1, 1, 8, 10, 
      5, 4, 1, 5, 2, 7, 1, 1, 1, 1, 2, 3, 2, 3, 1, 8, 10, 5, 4, 1, 5, 2, 7, 
      1, 1, 1, 1, 2, 3, 2, 1, 1, 3, 1, 8, 10, 5, 4, 1, 5, 2, 7, 1, 1, 1, 1, 
      2, 3, 1, 1, 1, 1, 3, 1, 8, 10, 4, 1, 5, 2, 7, 1, 1, 1, 1, 2, 3, 1, 1, 
      1, 1, 3, 2, 3, 1, 8, 10, 4, 1, 5, 2, 7, 1, 1, 1, 1, 2, 1, 1, 1, 1, 3, 
      3, 3, 1, 10, 4, 1, 5, 2, 7, 1, 1, 1, 1, 2, 1, 1, 1, 1, 3, 3, 7, 2, 3, 
      1, 10, 4, 1, 5, 2, 7, 1, 1, 1, 1, 2, 1, 1, 1, 1, 3, 7, 2, 1, 2, 3, 1, 
      4, 1, 5, 2, 7, 1, 1, 1, 1, 2, 1, 1, 1, 1, 3, 7, 2, 1, 2, 7, 3, 3, 1, 4, 
      1, 5, 2, 7, 1, 1, 1, 1, 2, 1, 1, 1, 1, 3, 2, 1, 2, 7, 3, 3, 4, 3, 1, 4, 
      1, 5, 2, 1, 1, 1, 1, 2, 1, 1, 1, 3, 2, 1, 2, 7, 3, 3, 4, 7, 3, 1, 4, 1, 
      5, 1, 1, 1, 1, 2, 1, 1, 1, 2, 1, 2, 7, 3, 3, 4, 7, 5, 3, 1, 4, 1, 5, 1, 
      1, 1, 1, 2, 1, 1, 1, 2, 1, 2, 7, 3, 3, 4, 5, 4, 4, 3, 1, 1, 5, 1, 1, 1, 
      1, 2, 1, 1, 1, 2, 1, 2, 7, 3, 3, 4, 5, 4, 8, 3, 1, 1, 5, 1, 1, 1, 1, 2, 
      1, 1, 1, 2, 1, 2, 7, 3, 3, 5, 4, 8, 3, 1, 3, 1, 1, 5, 1, 1, 1, 1, 1, 1, 
      1, 2, 1, 2, 7, 3, 3, 5, 4, 8, 3, 1, 2, 1, 3, 1, 1, 5, 1, 1, 1, 1, 1, 1, 
      1, 2, 1, 2, 7, 3, 5, 4, 3, 1, 2, 1, 11, 3, 1, 1, 5, 1, 1, 1, 1, 1, 1, 
      1, 1, 2, 7, 3, 5, 4, 3, 1, 2, 1, 11, 1, 1, 3, 1, 1, 5, 1, 1, 1, 1, 1, 
      1, 1, 1, 2, 3, 5, 3, 1, 2, 1, 11, 1, 1, 10, 3, 1, 1, 5, 1, 1, 1, 1, 1, 
      1, 1, 1, 2, 3, 5, 3, 1, 2, 1, 1, 1, 10, 3, 8, 3, 1, 5, 1, 1, 1, 1, 1, 
      1, 1, 1, 2, 3, 5, 1, 2, 1, 1, 1, 10, 3, 8, 4, 3, 1, 5, 1, 1, 1, 1, 1, 
      1, 1, 1, 2, 3, 5, 1, 2, 1, 1, 1, 3, 8, 4, 8, 2, 3, 1, 5, 1, 1, 1, 1, 1, 
      1, 2, 3, 5, 1, 2, 1, 1, 1, 3, 8, 4, 8, 2, 2, 3, 5, 1, 1, 1, 1, 1, 1, 2, 
      3, 5, 1, 1, 1, 1, 3, 8, 4, 8, 2, 2, 3, 3, 5, 1, 1, 1, 1, 1, 1, 2, 3, 5, 
      1, 1, 1, 1, 3, 4, 8, 2, 2, 3, 1, 8, 3, 5, 1, 1, 1, 1, 1, 1, 2, 3, 5, 1, 
      1, 1, 3, 4, 8, 2, 2, 3, 1, 8, 1, 1, 3, 5, 1, 1, 1, 1, 1, 2, 3, 5, 1, 1, 
      1, 4, 8, 2, 2, 3, 1, 8, 1, 1, 4, 3, 5, 1, 1, 1, 1, 1, 2, 5, 1, 1, 1, 4, 
      8, 2, 2, 3, 1, 8, 1, 1, 4, 2, 1, 3, 5, 1, 1, 1, 1, 1, 2, 5, 1, 1, 4, 8, 
      2, 2, 3, 1, 8, 1, 1, 2, 1, 5, 3, 5, 1, 1, 1, 1, 1, 2, 1, 1, 4, 8, 2, 2, 
      3, 1, 8, 1, 1, 2, 1, 5, 3, 2, 3, 5, 1, 1, 1, 1, 1, 2, 1, 4, 8, 2, 2, 3, 
      1, 8, 1, 1, 2, 1, 5, 3, 3, 3, 5, 1, 1, 1, 1, 1, 1, 4, 8, 2, 2, 1, 8, 1, 
      1, 2, 1, 5, 3, 3, 5, 3, 5, 1, 1, 1, 1, 1, 1, 4, 8, 2, 2, 1, 1, 1, 2, 1, 
      5, 3, 3, 5, 4, 5, 3, 5, 1, 1, 1, 1, 1, 1, 4, 8, 2, 2, 1, 2, 1, 5, 3, 3, 
      5, 4, 5, 2, 3, 5, 1, 1, 1, 1, 1, 1, 4, 8, 2, 2, 1, 2, 1, 3, 3, 5, 4, 5, 
      2, 4, 1, 3, 5, 1, 1, 1, 1, 1, 1, 4, 8, 2, 2, 1, 2, 1, 3, 3, 5, 4, 5, 4, 
      1, 1, 1, 3, 5, 1, 1, 1, 1, 1, 1, 4, 8, 2, 2, 1, 2, 1, 3, 3, 4, 5, 4, 1, 
      1, 1, 2, 3, 3, 1, 1, 1, 1, 1, 1, 4, 8, 2, 2, 1, 2, 1, 3, 3, 4, 5, 4, 1, 
      1, 1, 2, 3, 4, 1, 3, 1, 1, 1, 1, 1, 1, 4, 8, 2, 1, 1, 3, 3, 4, 5, 4, 1, 
      1, 1, 2, 3, 4, 1, 4, 3, 1, 1, 1, 1, 1, 4, 8, 2, 1, 1, 3, 3, 4, 5, 4, 1, 
      1, 2, 3, 4, 1, 4, 2, 3, 1, 1, 1, 1, 4, 8, 2, 1, 1, 3, 3, 4, 5, 4, 1, 1, 
      2, 3, 4, 1, 4, 2, 1, 1, 3, 1, 1, 1, 1, 4, 8, 2, 1, 1, 3, 4, 5, 4, 1, 1, 
      2, 3, 4, 1, 4, 2, 1, 4, 3, 1, 1, 1, 4, 8, 2, 1, 1, 4, 5, 4, 1, 1, 2, 3, 
      4, 1, 4, 2, 1, 4, 4, 3, 1, 1, 1, 4, 8, 1, 1, 4, 5, 4, 1, 1, 2, 3, 4, 1, 
      4, 2, 1, 4, 4, 1, 2, 3, 1, 1, 1, 4, 1, 1, 4, 5, 4, 1, 1, 2, 3, 4, 1, 4, 
      2, 1, 4, 1, 2, 12, 3, 1, 1, 1, 4, 1, 1, 4, 5, 4, 1, 1, 2, 4, 1, 2, 1, 
      4, 1, 2, 12, 7, 3, 1, 1, 1, 4, 1, 1, 4, 5, 4, 1, 1, 2, 4, 1, 1, 4, 1, 
      2, 12, 7, 2, 1, 3, 1, 1, 1, 4, 1, 1, 4, 5, 4, 1, 1, 2, 4, 1, 1, 4, 1, 
      2, 12, 7, 1, 1, 1, 3, 1, 1, 1, 4, 1, 1, 4, 5, 4, 1, 2, 4, 1, 1, 4, 1, 
      2, 7, 1, 1, 1, 11, 3, 1, 1, 4, 1, 1, 4, 5, 4, 1, 2, 4, 1, 1, 4, 1, 2, 
      7, 1, 1, 11, 2, 3, 1, 1, 4, 1, 1, 4, 5, 4, 2, 4, 1, 1, 4, 1, 7, 1, 1, 
      11, 2, 3, 3, 1, 1, 4, 1, 1, 4, 5, 4, 2, 4, 1, 1, 4, 1, 7, 1, 1, 11, 2, 
      2, 1, 3, 1, 1, 1, 1, 4, 5, 4, 2, 4, 1, 1, 4, 1, 7, 1, 1, 11, 2, 2, 1, 
      1, 3, 3, 1, 1, 1, 1, 4, 5, 4, 2, 4, 1, 1, 1, 7, 1, 1, 11, 2, 2, 1, 1, 
      3, 3, 1, 3, 1, 1, 1, 1, 4, 5, 4, 2, 1, 1, 1, 7, 1, 1, 11, 2, 2, 1, 1, 
      3, 3, 1, 4, 1, 3, 1, 1, 1, 1, 4, 5, 4, 2, 1, 1, 7, 1, 11, 2, 2, 1, 1, 
      3, 3, 1, 4, 1, 2, 3, 1, 1, 1, 1, 4, 5, 4, 2, 1, 1, 7, 1, 2, 2, 1, 1, 3, 
      3, 1, 4, 1, 2, 8, 3, 1, 1, 1, 1, 4, 5, 4, 2, 1, 1, 1, 2, 2, 1, 1, 3, 3, 
      1, 4, 1, 2, 8, 3, 10, 1, 1, 1, 1, 4, 5, 4, 2, 1, 1, 1, 2, 2, 1, 1, 3, 
      3, 1, 4, 1, 2, 3, 10, 3, 6, 1, 1, 1, 1, 4, 5, 4, 2, 1, 1, 1, 2, 2, 1, 
      1, 3, 3, 1, 4, 1, 2, 3, 3, 6, 1, 9, 1, 1, 1, 1, 4, 5, 2, 1, 1, 1, 2, 2, 
      1, 1, 3, 3, 1, 4, 1, 2, 3, 3, 6, 1, 9, 3, 1, 1, 1, 1, 1, 4, 5, 2, 1, 1, 
      1, 2, 2, 1, 1, 3, 1, 1, 2, 3, 3, 6, 1, 9, 3, 1, 7, 1, 1, 1, 1, 4, 5, 2, 
      1, 1, 1, 2, 2, 1, 1, 3, 1, 1, 2, 3, 6, 1, 9, 3, 1, 7, 1, 2, 1, 1, 1, 1, 
      4, 5, 2, 1, 1, 1, 2, 2, 1, 1, 3, 1, 1, 2, 3, 6, 1, 9, 3, 1, 1, 2, 1, 6, 
      1, 1, 1, 1, 4, 5, 2, 1, 1, 1, 2, 2, 1, 1, 3, 1, 2, 3, 6, 1, 9, 3, 1, 1, 
      2, 1, 7, 1, 1, 1, 1, 4, 5, 2, 1, 1, 1, 2, 2, 1, 3, 1, 2, 3, 6, 1, 3, 1, 
      1, 2, 1, 7, 9, 1, 1, 1, 1, 4, 5, 2, 1, 1, 1, 2, 2, 1, 1, 2, 3, 6, 1, 1, 
      1, 2, 1, 7, 9, 6, 1, 1, 1, 1, 4, 5, 2, 1, 1, 1, 2, 2, 1, 1, 2, 3, 6, 1, 
      1, 1, 2, 1, 9, 6, 3, 4, 1, 1, 1, 1, 5, 2, 1, 1, 1, 2, 2, 1, 2, 3, 6, 1, 
      1, 1, 2, 1, 9, 6, 3, 4, 5, 1, 1, 1, 1, 5, 2, 1, 1, 2, 2, 1, 2, 3, 6, 1, 
      1, 2, 1, 9, 6, 3, 4, 5, 2, 1, 1, 1, 1, 5, 2, 1, 1, 2, 2, 1, 2, 6, 1, 2, 
      1, 9, 6, 3, 4, 5, 2, 4, 1, 1, 1, 5, 2, 1, 1, 2, 2, 1, 2, 6, 2, 1, 9, 6, 
      3, 4, 5, 2, 4, 2, 1, 1, 1, 1, 1, 2, 2, 1, 2, 6, 2, 1, 9, 6, 3, 4, 5, 2, 
      4, 2, 6, 1, 1, 1, 1, 1, 2, 1, 2, 6, 2, 1, 9, 6, 3, 4, 5, 2, 4, 2, 6, 1, 
      1, 1, 1, 1, 1, 1, 2, 1, 2, 6, 2, 1, 9, 6, 3, 4, 5, 2, 4, 6, 1, 1, 1, 1, 
      1, 1, 1, 1, 1, 2, 1, 2, 6, 2, 1, 6, 3, 4, 5, 2, 4, 6, 1, 1, 1, 9, 1, 1, 
      1, 1, 2, 1, 2, 6, 1, 6, 3, 4, 5, 2, 4, 6, 1, 1, 1, 9, 3, 1, 1, 1, 1, 2, 
      1, 2, 6, 1, 6, 3, 4, 5, 2, 4, 6, 1, 1, 1, 3, 9, 1, 1, 1, 1, 2, 2, 6, 1, 
      6, 3, 4, 5, 2, 4, 6, 1, 1, 1, 3, 9, 1, 2, 1, 1, 2, 2, 6, 1, 3, 4, 5, 2, 
      4, 6, 1, 1, 1, 3, 9, 1, 2, 7, 1, 2, 2, 6, 1, 3, 4, 5, 2, 4, 1, 1, 1, 3, 
      9, 1, 2, 7, 7, 2, 2, 6, 1, 3, 5, 2, 4, 1, 1, 1, 3, 9, 1, 2, 7, 7, 5, 2, 
      6, 1, 3, 5, 2, 4, 1, 1, 1, 3, 9, 1, 2, 7, 7, 5, 1, 1, 2, 6, 1, 3, 5, 2, 
      4, 1, 1, 3, 9, 1, 2, 7, 7, 5, 1, 2, 2, 6, 1, 3, 5, 2, 4, 1, 1, 3, 9, 1, 
      7, 7, 5, 1, 2, 1, 1, 2, 6, 1, 3, 5, 2, 4, 1, 1, 3, 1, 7, 7, 5, 1, 2, 1, 
      1, 2, 7, 2, 6, 1, 3, 5, 4, 1, 1, 3, 1, 7, 7, 5, 1, 2, 1, 1, 2, 7, 1, 1, 
      2, 6, 1, 3, 5, 1, 1, 3, 1, 7, 7, 5, 1, 2, 1, 1, 2, 7, 1, 1, 3, 1, 2, 6, 
      1, 3, 5, 1, 1, 3, 1, 7, 7, 5, 2, 1, 1, 2, 7, 1, 3, 1, 2, 2, 6, 1, 3, 5, 
      1, 1, 3, 1, 7, 5, 2, 1, 1, 2, 7, 1, 3, 1, 2, 2, 5, 2, 6, 1, 3, 5, 1, 1, 
      1, 7, 5, 2, 1, 1, 2, 7, 1, 3, 1, 2, 2, 5, 2, 2, 2, 6, 1, 3, 5, 1, 1, 1, 
      7, 5, 1, 1, 2, 7, 1, 3, 1, 2, 2, 5, 2, 2, 1, 1, 2, 6, 1, 3, 5, 1, 1, 1, 
      7, 5, 1, 1, 2, 7, 1, 3, 1, 2, 5, 2, 2, 1, 3, 6, 1, 3, 5, 1, 1, 1, 7, 5, 
      1, 1, 2, 7, 1, 3, 1, 2, 5, 2, 2, 3, 3, 6, 1, 3, 1, 1, 1, 7, 5, 1, 2, 7, 
      1, 3, 1, 2, 5, 2, 2, 3, 3, 6, 6, 1, 1, 1, 1, 7, 5, 1, 2, 7, 1, 3, 1, 5, 
      2, 2, 3, 3, 6, 5, 6, 1, 1, 1, 1, 7, 5, 1, 7, 1, 1, 5, 2, 2, 3, 3, 6, 5, 
      5, 6, 1, 1, 1, 7, 1, 7, 1, 1, 5, 2, 2, 3, 3, 6, 5, 5, 6, 6, 1, 1, 1, 7, 
      1, 7, 1, 1, 5, 2, 3, 3, 6, 5, 5, 6, 2, 1, 6, 1, 1, 1, 7, 1, 7, 1, 1, 5, 
      2, 3, 6, 5, 5, 6, 2, 1, 2, 1, 6, 1, 1, 1, 7, 1, 7, 1, 1, 5, 2, 3, 6, 5, 
      5, 6, 2, 2, 2, 6, 1, 1, 1, 7, 1, 7, 1, 1, 5, 3, 6, 5, 5, 6, 2, 2, 2, 1, 
      1, 6, 1, 1, 1, 7, 1, 7, 1, 1, 5, 3, 6, 5, 6, 2, 2, 2, 1, 1, 3, 2, 6, 1, 
      1, 1, 7, 1, 7, 1, 5, 3, 6, 5, 6, 2, 2, 2, 1, 3, 2, 2, 6, 1, 1, 1, 1, 7, 
      1, 5, 3, 6, 5, 6, 2, 2, 2, 1, 3, 2, 2, 3, 4, 6, 1, 1, 1, 1, 7, 1, 5, 3, 
      6, 6, 2, 2, 2, 1, 3, 2, 2, 3, 9, 6, 1, 1, 1, 1, 7, 1, 5, 3, 6, 6, 2, 2, 
      2, 1, 3, 2, 2, 3, 5, 4, 6, 1, 1, 1, 1, 7, 1, 5, 3, 6, 6, 2, 2, 2, 1, 3, 
      2, 3, 5, 4, 1, 1, 6, 1, 1, 1, 1, 7, 1, 5, 3, 6, 2, 2, 1, 3, 2, 3, 5, 4, 
      1, 1, 8, 6, 1, 1, 1, 1, 7, 1, 5, 3, 6, 2, 1, 3, 2, 3, 5, 4, 1, 1, 8, 1, 
      2, 1, 1, 1, 1, 7, 1, 5, 3, 6, 2, 1, 3, 2, 3, 5, 4, 1, 1, 8, 1, 2, 1, 5, 
      1, 1, 1, 1, 7, 1, 5, 3, 6, 2, 1, 3, 2, 3, 5, 4, 1, 1, 1, 2, 1, 5, 2, 6, 
      1, 1, 1, 1, 7, 1, 5, 3, 1, 3, 2, 3, 5, 4, 1, 1, 1, 2, 1, 5, 2, 6, 7, 1, 
      1, 1, 1, 7, 1, 3, 1, 3, 2, 3, 5, 4, 1, 1, 1, 2, 1, 5, 2, 6, 7, 1, 4, 1, 
      1, 1, 1, 7, 1, 3, 1, 3, 2, 3, 5, 4, 1, 1, 1, 1, 5, 2, 7, 1, 4, 7, 1, 1, 
      1, 1, 7, 1, 1, 3, 2, 3, 5, 4, 1, 1, 1, 1, 5, 2, 7, 1, 4, 7, 2, 1, 1, 1, 
      1, 7, 1, 1, 3, 2, 3, 5, 4, 1, 1, 1, 1, 5, 2, 7, 1, 4, 2, 1, 8, 1, 1, 1, 
      7, 1, 1, 3, 2, 3, 5, 4, 1, 1, 1, 1, 2, 7, 1, 4, 2, 1, 8, 3, 2, 1, 1, 1, 
      1, 1, 3, 2, 3, 5, 4, 1, 1, 1, 1, 2, 7, 1, 4, 2, 1, 8, 3, 2, 5, 3, 1, 1, 
      1, 1, 1, 3, 2, 3, 5, 4, 1, 1, 1, 1, 2, 1, 4, 2, 1, 8, 3, 2, 5, 3, 4, 4, 
      1, 1, 1, 1, 1, 3, 2, 3, 4, 1, 1, 1, 2, 1, 4, 2, 1, 8, 3, 2, 5, 3, 4, 4, 
      6, 1, 1, 1, 1, 3, 2, 3, 4, 1, 1, 1, 2, 1, 4, 2, 1, 8, 3, 2, 5, 4, 4, 6, 
      4, 1, 1, 1, 1, 3, 2, 3, 4, 1, 1, 1, 2, 1, 4, 2, 1, 8, 3, 2, 5, 4, 4, 4, 
      5, 1, 1, 1, 1, 1, 3, 2, 3, 4, 1, 1, 1, 2, 1, 4, 2, 1, 3, 2, 5, 4, 4, 4, 
      5, 1, 1, 7, 1, 1, 1, 3, 2, 3, 4, 1, 1, 1, 2, 1, 4, 2, 1, 3, 2, 5, 4, 4, 
      4, 1, 1, 7, 6, 1, 1, 1, 3, 2, 4, 1, 1, 2, 1, 4, 2, 1, 3, 2, 5, 4, 4, 4, 
      1, 1, 7, 6, 4, 1, 1, 1, 3, 2, 4, 1, 1, 2, 1, 4, 2, 1, 3, 2, 5, 4, 4, 1, 
      1, 7, 6, 4, 1, 3, 1, 1, 3, 2, 4, 1, 1, 2, 1, 4, 2, 1, 3, 2, 5, 4, 1, 1, 
      7, 6, 4, 1, 3, 5, 1, 1, 3, 2, 4, 1, 2, 1, 4, 2, 3, 2, 5, 4, 1, 1, 7, 6, 
      4, 1, 3, 5, 2, 1, 1, 3, 2, 4, 1, 2, 1, 4, 2, 3, 2, 5, 4, 1, 1, 7, 6, 4, 
      1, 3, 2, 4, 1, 1, 3, 2, 4, 1, 2, 1, 4, 2, 3, 2, 5, 4, 1, 1, 7, 4, 1, 3, 
      2, 4, 1, 7, 1, 3, 2, 4, 2, 1, 4, 2, 3, 2, 5, 4, 1, 1, 7, 4, 1, 3, 2, 4, 
      7, 2, 1, 3, 2, 4, 2, 1, 4, 2, 3, 2, 5, 4, 1, 1, 7, 4, 1, 4, 7, 2, 5, 1, 
      3, 2, 4, 2, 1, 4, 2, 3, 2, 4, 1, 1, 7, 4, 1, 4, 7, 2, 5, 1, 4, 1, 3, 2, 
      4, 2, 1, 4, 2, 3, 2, 4, 1, 7, 4, 1, 4, 7, 2, 5, 1, 5, 1, 3, 2, 4, 2, 1, 
      4, 2, 3, 2, 4, 1, 7, 4, 1, 4, 7, 5, 1, 5, 1, 1, 3, 2, 4, 2, 1, 4, 2, 3, 
      2, 4, 1, 7, 4, 1, 4, 7, 1, 5, 1, 1, 6, 3, 2, 4, 2, 1, 4, 3, 2, 4, 1, 4, 
      1, 4, 7, 1, 5, 1, 1, 6, 9, 3, 2, 4, 2, 1, 4, 3, 2, 4, 4, 1, 4, 7, 1, 5, 
      1, 6, 9, 2, 3, 2, 4, 2, 1, 4, 3, 2, 4, 4, 1, 7, 1, 5, 1, 6, 9, 2, 1, 3, 
      3, 2, 4, 2, 1, 4, 3, 4, 4, 1, 7, 1, 5, 1, 6, 2, 1, 3, 10, 3, 4, 2, 4, 
      3, 4, 4, 1, 7, 1, 5, 1, 6, 2, 1, 3, 10, 3, 3, 4, 2, 4, 4, 4, 1, 7, 1, 
      5, 1, 6, 2, 1, 3, 10, 3, 1, 2, 3, 4, 2, 4, 4, 4, 1, 7, 1, 5, 1, 6, 1, 
      3, 10, 3, 1, 2, 1, 1, 3, 4, 2, 4, 4, 4, 1, 7, 1, 5, 1, 6, 1, 3, 3, 1, 
      2, 1, 1, 3, 7, 3, 4, 2, 4, 4, 4, 1, 7, 1, 5, 1, 6, 1, 3, 3, 1, 2, 1, 1, 
      3, 4, 4, 3, 4, 2, 4, 4, 1, 7, 1, 5, 1, 6, 1, 3, 3, 1, 2, 1, 1, 3, 4, 4, 
      2, 2, 3, 4, 2, 4, 4, 1, 1, 5, 1, 6, 1, 3, 3, 1, 2, 1, 1, 3, 4, 4, 2, 2, 
      6, 1, 3, 4, 2, 4, 4, 1, 1, 1, 6, 1, 3, 3, 1, 2, 1, 1, 3, 4, 4, 2, 2, 6, 
      1, 1, 4, 3, 4, 2, 4, 4, 1, 1, 1, 6, 1, 3, 3, 1, 1, 1, 3, 4, 4, 2, 2, 6, 
      1, 1, 6, 3, 4, 2, 4, 4, 1, 1, 6, 1, 3, 3, 1, 1, 1, 4, 4, 2, 2, 6, 1, 1, 
      6, 4, 3, 4, 2, 4, 4, 1, 1, 1, 3, 3, 1, 1, 1, 4, 4, 2, 2, 6, 1, 1, 6, 4, 
      1, 6, 3, 4, 2, 4, 4, 1, 1, 3, 3, 1, 1, 1, 4, 4, 2, 2, 6, 1, 1, 6, 1, 5, 
      1, 5, 3, 4, 2, 4, 4, 1, 1, 3, 3, 1, 1, 1, 4, 4, 2, 2, 6, 1, 1, 6, 1, 5, 
      1, 5, 3, 4, 2, 4, 1, 1, 3, 3, 1, 1, 1, 4, 4, 2, 2, 6, 1, 1, 6, 1, 5, 1, 
      5, 4, 1, 3, 4, 2, 4, 1, 1, 3, 3, 1, 1, 1, 4, 4, 2, 6, 1, 1, 6, 1, 5, 5, 
      4, 1, 3, 3, 4, 2, 4, 1, 3, 3, 1, 1, 4, 4, 2, 6, 1, 1, 6, 1, 5, 5, 4, 1, 
      3, 2, 3, 4, 2, 4, 1, 3, 3, 1, 1, 4, 4, 2, 6, 1, 1, 6, 1, 5, 5, 4, 1, 2, 
      1, 2, 3, 4, 2, 4, 1, 3, 3, 1, 1, 4, 4, 2, 6, 1, 1, 1, 5, 5, 4, 1, 2, 1, 
      2, 2, 4, 4, 2, 4, 1, 3, 3, 1, 1, 4, 4, 2, 6, 1, 1, 1, 5, 5, 4, 1, 2, 1, 
      2, 4, 5, 4, 2, 4, 1, 3, 3, 1, 1, 4, 4, 2, 6, 1, 1, 1, 5, 4, 1, 2, 1, 2, 
      4, 5, 2, 4, 4, 2, 4, 1, 3, 3, 1, 1, 4, 2, 6, 1, 1, 1, 5, 4, 1, 2, 2, 4, 
      5, 2, 4, 5, 2, 4, 1, 3, 3, 1, 1, 4, 2, 6, 1, 1, 1, 5, 1, 2, 2, 4, 5, 2, 
      4, 5, 8, 4, 1, 3, 3, 1, 1, 4, 2, 6, 1, 1, 1, 5, 1, 2, 2, 4, 2, 4, 5, 8, 
      7, 4, 1, 3, 3, 1, 2, 6, 1, 1, 1, 5, 1, 2, 2, 4, 2, 4, 5, 8, 7, 5, 4, 1, 
      3, 3, 1, 6, 1, 1, 1, 5, 1, 2, 2, 4, 2, 4, 5, 8, 7, 5, 1, 1, 4, 1, 3, 3, 
      1, 6, 1, 1, 1, 5, 1, 2, 2, 4, 2, 4, 8, 7, 5, 1, 1, 4, 1, 4, 1, 3, 1, 6, 
      1, 1, 5, 1, 2, 2, 4, 2, 4, 8, 7, 5, 1, 1, 4, 1, 4, 4, 1, 3, 1, 1, 5, 1, 
      2, 2, 4, 2, 4, 8, 7, 5, 1, 1, 4, 1, 4, 6, 4, 3, 1, 1, 5, 1, 2, 2, 4, 2, 
      4, 8, 7, 5, 1, 1, 1, 4, 6, 5, 4, 3, 1, 1, 5, 1, 2, 2, 4, 2, 4, 8, 5, 1, 
      1, 4, 6, 5, 8, 4, 1, 1, 5, 1, 2, 2, 4, 2, 4, 8, 5, 1, 4, 6, 5, 8, 4, 4, 
      1, 1, 5, 1, 2, 2, 2, 8, 5, 1, 4, 6, 5, 8, 4, 7, 4, 1, 1, 5, 1, 2, 2, 2, 
      5, 4, 6, 5, 8, 4, 7, 9, 4, 1, 1, 5, 1, 2, 2, 5, 4, 6, 5, 8, 4, 7, 9, 1, 
      1, 4, 1, 1, 5, 1, 2, 2, 5, 4, 5, 4, 7, 9, 1, 1, 9, 4, 1, 1, 5, 1, 2, 2, 
      5, 4, 5, 7, 9, 1, 1, 9, 3, 1, 4, 1, 1, 5, 1, 2, 2, 5, 4, 5, 7, 1, 1, 9, 
      3, 1, 8, 1, 4, 1, 1, 5, 1, 2, 2, 5, 4, 5, 1, 1, 9, 3, 1, 8, 1, 1, 7, 4, 
      1, 1, 5, 2, 2, 5, 4, 5, 1, 1, 9, 1, 8, 1, 1, 7, 4, 4, 1, 1, 5, 2, 2, 5, 
      5, 1, 1, 9, 1, 8, 1, 1, 7, 4, 3, 1, 4, 1, 1, 5, 2, 2, 5, 5, 1, 1, 9, 1, 
      8, 1, 1, 4, 3, 1, 2, 5, 4, 1, 1, 5, 2, 2, 5, 1, 1, 9, 1, 8, 1, 1, 4, 3, 
      1, 2, 5, 3, 3, 4, 1, 1, 5, 2, 5, 1, 1, 1, 8, 1, 1, 4, 3, 1, 2, 5, 3, 3, 
      11, 4, 1, 1, 5, 2, 5, 1, 1, 1, 8, 1, 1, 4, 3, 1, 2, 5, 3, 11, 1, 2, 4, 
      1, 1, 5, 2, 5, 1, 8, 1, 1, 4, 3, 1, 2, 5, 3, 11, 1, 2, 2, 4, 1, 1, 5, 
      2, 1, 8, 1, 1, 4, 3, 1, 2, 5, 3, 11, 1, 2, 2, 1, 4, 4, 1, 1, 5, 2, 1, 
      8, 1, 1, 4, 3, 1, 2, 5, 3, 11, 1, 2, 1, 4, 1, 1, 4, 1, 1, 5, 2, 1, 8, 
      1, 1, 4, 3, 1, 2, 5, 3, 1, 2, 1, 4, 1, 1, 3, 9, 4, 1, 1, 2, 1, 8, 1, 1, 
      4, 3, 1, 2, 5, 3, 1, 2, 1, 4, 1, 1, 3, 9, 2, 4, 4, 1, 1, 2, 1, 8, 1, 1, 
      4, 3, 1, 5, 3, 1, 2, 1, 4, 1, 1, 3, 9, 2, 6, 4, 1, 2, 1, 8, 1, 1, 4, 1, 
      5, 3, 1, 2, 1, 4, 1, 1, 3, 9, 2, 6, 4, 4, 1, 1, 8, 1, 1, 4, 1, 5, 3, 1, 
      2, 1, 4, 1, 1, 3, 9, 2, 6, 4, 2, 1, 4, 1, 1, 8, 1, 1, 4, 5, 3, 1, 2, 1, 
      4, 1, 3, 9, 2, 6, 4, 2, 1, 2, 4, 1, 8, 1, 1, 4, 5, 3, 1, 2, 1, 4, 1, 3, 
      9, 2, 4, 2, 1, 2, 6, 4, 1, 8, 1, 1, 4, 5, 3, 1, 2, 1, 4, 1, 3, 2, 4, 2, 
      1, 2, 6, 2, 7, 4, 1, 8, 1, 1, 4, 5, 3, 1, 2, 4, 1, 3, 2, 4, 2, 1, 2, 6, 
      2, 7, 1, 1, 4, 1, 8, 1, 1, 4, 5, 3, 1, 2, 4, 1, 3, 4, 2, 1, 2, 6, 2, 7, 
      1, 3, 4, 1, 8, 1, 1, 5, 3, 1, 2, 4, 1, 3, 4, 2, 1, 2, 6, 2, 7, 3, 5, 1, 
      8, 1, 1, 5, 3, 1, 2, 1, 3, 4, 2, 1, 2, 6, 2, 7, 3, 5, 8, 1, 1, 1, 5, 3, 
      1, 2, 1, 3, 4, 2, 1, 2, 6, 2, 7, 3, 5, 8, 4, 4, 1, 1, 1, 5, 3, 1, 2, 1, 
      3, 4, 2, 1, 2, 2, 7, 3, 5, 8, 4, 4, 4, 2, 1, 1, 1, 5, 3, 1, 2, 1, 3, 4, 
      2, 1, 2, 2, 7, 5, 8, 4, 4, 2, 7, 1, 1, 5, 3, 1, 2, 3, 4, 2, 1, 2, 2, 7, 
      5, 8, 4, 4, 2, 7, 2, 1, 1, 5, 3, 1, 2, 3, 4, 2, 1, 2, 2, 7, 5, 8, 4, 2, 
      7, 2, 3, 1, 1, 1, 5, 3, 1, 2, 3, 4, 2, 1, 2, 2, 7, 5, 8, 2, 7, 3, 1, 6, 
      1, 1, 5, 3, 1, 2, 3, 4, 2, 1, 2, 2, 5, 8, 2, 7, 3, 1, 6, 5, 2, 1, 1, 3, 
      1, 2, 3, 4, 2, 1, 2, 2, 5, 8, 2, 3, 1, 6, 5, 2, 12, 1, 1, 3, 1, 2, 3, 
      4, 2, 2, 2, 5, 8, 2, 3, 1, 5, 2, 12, 7, 1, 1, 3, 1, 3, 4, 2, 2, 2, 5, 
      8, 2, 3, 1, 5, 2, 12, 7, 1, 1, 1, 1, 3, 1, 3, 4, 2, 2, 5, 8, 2, 3, 1, 
      5, 2, 12, 7, 1, 1, 1, 1, 1, 1, 1, 3, 4, 2, 2, 5, 8, 2, 1, 5, 2, 12, 7, 
      1, 1, 1, 1, 6, 1, 1, 1, 3, 4, 2, 5, 8, 2, 1, 5, 2, 12, 7, 1, 1, 1, 1, 
      6, 1, 2, 1, 1, 1, 3, 4, 2, 8, 2, 1, 5, 2, 12, 7, 1, 1, 1, 1, 1, 2, 11, 
      1, 1, 1, 3, 4, 2, 8, 2, 5, 2, 12, 7, 1, 1, 1, 1, 1, 2, 11, 1, 1, 1, 1, 
      1, 3, 4, 2, 8, 2, 5, 2, 12, 7, 1, 1, 1, 2, 11, 1, 1, 2, 1, 1, 1, 3, 4, 
      2, 8, 2, 5, 2, 12, 1, 1, 1, 2, 11, 1, 1, 2, 2, 5, 1, 1, 1, 3, 4, 8, 2, 
      5, 2, 12, 1, 1, 1, 2, 11, 1, 1, 2, 5, 3, 1, 1, 1, 3, 4, 8, 2, 5, 2, 12, 
      1, 1, 1, 2, 1, 1, 2, 5, 3, 8, 3, 1, 1, 1, 3, 4, 8, 2, 5, 2, 1, 1, 1, 2, 
      1, 1, 2, 5, 3, 8, 3, 9, 3, 1, 1, 1, 3, 4, 2, 5, 2, 1, 1, 1, 2, 1, 1, 2, 
      5, 3, 8, 3, 9, 3, 5, 3, 1, 1, 1, 3, 4, 2, 5, 2, 1, 1, 1, 2, 1, 1, 2, 5, 
      3, 8, 3, 9, 3, 3, 4, 2, 1, 1, 1, 3, 2, 5, 2, 1, 1, 1, 2, 1, 1, 2, 5, 3, 
      8, 3, 9, 3, 3, 4, 2, 3, 1, 1, 1, 1, 3, 2, 5, 2, 1, 1, 1, 2, 1, 1, 2, 5, 
      3, 8, 3, 3, 3, 4, 2, 3, 1, 7, 2, 1, 1, 1, 3, 2, 5, 2, 1, 1, 1, 2, 1, 1, 
      2, 5, 3, 8, 3, 3, 4, 2, 3, 1, 7, 5, 1, 1, 1, 3, 2, 5, 2, 1, 1, 2, 1, 1, 
      2, 5, 3, 8, 3, 4, 2, 3, 1, 7, 5, 4, 1, 1, 1, 3, 2, 5, 2, 1, 2, 1, 2, 5, 
      3, 8, 3, 4, 2, 3, 1, 7, 5, 4, 2, 1, 1, 1, 3, 2, 5, 2, 1, 2, 1, 2, 5, 3, 
      8, 3, 4, 2, 1, 7, 4, 2, 8, 1, 1, 1, 3, 2, 5, 2, 1, 1, 2, 5, 3, 8, 3, 4, 
      2, 1, 7, 2, 8, 5, 1, 1, 1, 3, 2, 5, 2, 1, 1, 2, 3, 3, 4, 2, 1, 7, 2, 8, 
      5, 13, 1, 1, 1, 2, 5, 2, 1, 1, 2, 3, 3, 4, 2, 1, 7, 2, 8, 13, 8, 1, 1, 
      1, 2, 5, 2, 1, 1, 2, 3, 3, 4, 2, 1, 7, 2, 8, 13, 7, 1, 1, 1, 1, 2, 5, 
      2, 1, 1, 2, 3, 3, 4, 2, 1, 7, 8, 13, 7, 1, 1, 2, 1, 1, 1, 2, 2, 1, 1, 
      2, 3, 3, 4, 2, 7, 8, 13, 7, 1, 1, 2, 5, 1, 1, 1, 2, 2, 1, 2, 3, 3, 4, 
      2, 7, 8, 13, 7, 1, 1, 2, 5, 1, 1, 1, 1, 1, 2, 2, 2, 3, 4, 2, 7, 8, 13, 
      7, 1, 1, 2, 5, 1, 1, 4, 1, 1, 1, 2, 2, 2, 3, 4, 7, 8, 7, 1, 1, 2, 5, 1, 
      1, 4, 14, 1, 1, 1, 2, 2, 2, 3, 8, 7, 1, 1, 2, 5, 1, 1, 4, 14, 9, 1, 1, 
      1, 2, 2, 2, 3, 8, 7, 1, 2, 5, 1, 1, 4, 14, 10, 1, 1, 1, 2, 2, 2, 3, 7, 
      1, 2, 5, 1, 1, 4, 14, 10, 6, 3, 1, 1, 1, 2, 2, 2, 3, 1, 2, 5, 1, 1, 4, 
      14, 6, 3, 15, 1, 1, 1, 2, 2, 2, 3, 1, 2, 5, 1, 1, 4, 6, 3, 15, 8, 6, 1, 
      1, 1, 2, 2, 2, 3, 1, 2, 5, 1, 1, 4, 6, 3, 8, 6, 12, 4, 1, 1, 2, 2, 3, 
      1, 2, 5, 1, 1, 4, 6, 3, 8, 6, 12, 4, 3, 1, 1, 2, 2, 3, 2, 5, 1, 1, 6, 
      3, 8, 6, 12, 4, 3, 4, 1, 1, 2, 2, 3, 2, 5, 1, 1, 6, 3, 8, 6, 4, 3, 4, 
      1, 12, 1, 1, 2, 2, 3, 2, 1, 1, 6, 8, 6, 4, 3, 4, 1, 12, 8, 1, 1, 2, 2, 
      3, 2, 1, 1, 6, 8, 6, 4, 4, 1, 12, 8, 1, 2, 1, 1, 2, 2, 3, 2, 1, 1, 6, 
      8, 6, 4, 1, 12, 8, 1, 2, 3, 1, 1, 2, 3, 2, 1, 1, 6, 8, 6, 4, 1, 12, 8, 
      1, 2, 3, 1, 3, 1, 2, 3, 2, 1, 1, 6, 8, 6, 4, 1, 12, 8, 1, 2, 3, 1, 1, 
      2, 1, 2, 2, 1, 1, 6, 6, 4, 1, 12, 8, 1, 2, 3, 1, 1, 2, 11, 1, 2, 2, 1, 
      1, 6, 6, 1, 12, 8, 1, 2, 1, 1, 2, 11, 7, 2, 2, 1, 1, 6, 1, 12, 8, 1, 2, 
      1, 1, 2, 11, 7, 6, 2, 2, 1, 1, 6, 1, 12, 8, 1, 2, 1, 2, 11, 7, 7, 2, 2, 
      1, 6, 1, 12, 8, 2, 1, 2, 11, 7, 7, 2, 2, 2, 1, 6, 1, 12, 8, 2, 2, 11, 
      7, 2, 8, 2, 2, 1, 1, 12, 8, 2, 2, 11, 7, 2, 8, 3, 3, 2, 2, 1, 1, 12, 8, 
      2, 2, 7, 2, 8, 3, 3, 8, 3, 2, 2, 1, 1, 8, 2, 2, 7, 2, 8, 3, 8, 3, 14, 
      2, 2, 1, 1, 8, 2, 2, 7, 2, 3, 3, 14, 16, 2, 2, 1, 1, 8, 2, 2, 7, 2, 3, 
      3, 14, 10, 6, 2, 2, 1, 1, 8, 2, 2, 7, 3, 3, 14, 10, 6, 1, 1, 2, 2, 1, 
      8, 2, 2, 7, 3, 14, 10, 6, 1, 1, 4, 2, 2, 1, 2, 2, 7, 3, 14, 10, 6, 1, 
      1, 4, 5, 4, 2, 2, 1, 2, 2, 7, 14, 10, 6, 1, 1, 4, 5, 4, 1, 3, 2, 2, 1, 
      2, 2, 14, 10, 6, 1, 1, 4, 5, 4, 1, 3, 2, 5, 2, 2, 1, 2, 2, 14, 6, 1, 1, 
      4, 5, 4, 1, 3, 2, 5, 5, 5, 2, 2, 1, 2, 2, 14, 6, 1, 1, 4, 4, 1, 3, 2, 
      5, 5, 7, 2, 2, 1, 2, 2, 14, 6, 1, 1, 4, 4, 1, 3, 2, 5, 7, 1, 4, 2, 1, 
      2, 14, 6, 1, 1, 4, 4, 1, 3, 2, 5, 7, 1, 4, 4, 2, 1, 2, 14, 6, 1, 1, 4, 
      1, 3, 2, 5, 7, 1, 4, 4, 2, 2, 2, 1, 2, 14, 6, 1, 1, 1, 3, 2, 5, 7, 1, 
      4, 4, 2, 2, 1, 3, 2, 1, 2, 14, 6, 1, 1, 1, 3, 5, 7, 1, 4, 4, 2, 1, 3, 
      4, 2, 1, 2, 14, 6, 1, 1, 1, 3, 5, 7, 1, 4, 4, 1, 3, 4, 1, 1, 2, 1, 2, 
      14, 6, 1, 1, 1, 3, 5, 7, 4, 4, 1, 3, 4, 1, 2, 2, 1, 2, 14, 1, 1, 1, 3, 
      5, 7, 4, 4, 1, 3, 4, 1, 2, 4, 2, 2, 1, 2, 14, 1, 1, 1, 3, 5, 7, 4, 4, 
      1, 3, 4, 1, 2, 2, 1, 4, 2, 1, 2, 1, 1, 1, 3, 5, 4, 4, 1, 3, 4, 1, 2, 2, 
      1, 4, 9, 2, 1, 2, 1, 1, 1, 3, 5, 4, 4, 1, 4, 1, 2, 2, 1, 4, 9, 2, 1, 2, 
      1, 2, 1, 1, 1, 3, 5, 4, 1, 4, 1, 2, 2, 1, 4, 9, 2, 1, 2, 2, 2, 2, 1, 1, 
      1, 3, 5, 4, 1, 4, 1, 2, 2, 1, 4, 9, 2, 2, 2, 2, 2, 2, 1, 1, 1, 3, 5, 4, 
      1, 4, 1, 2, 2, 1, 4, 9, 2, 2, 2, 1, 1, 2, 1, 1, 1, 3, 5, 4, 1, 4, 1, 2, 
      2, 1, 4, 9, 2, 2, 2, 1, 1, 2, 1, 2, 1, 1, 1, 3, 5, 4, 1, 4, 1, 2, 4, 9, 
      2, 2, 2, 1, 1, 2, 1, 3, 2, 1, 1, 1, 3, 5, 4, 1, 4, 1, 2, 4, 2, 2, 2, 1, 
      1, 2, 1, 3, 8, 1, 2, 1, 1, 1, 5, 4, 1, 4, 1, 4, 2, 2, 2, 1, 1, 2, 1, 3, 
      8, 1, 4, 2, 1, 1, 1, 5, 4, 1, 4, 1, 4, 2, 2, 2, 1, 1, 2, 1, 3, 1, 4, 7, 
      2, 2, 1, 1, 1, 5, 1, 4, 1, 2, 2, 2, 1, 1, 2, 1, 3, 1, 4, 7, 2, 3, 2, 1, 
      1, 1, 5, 1, 4, 2, 2, 2, 1, 1, 2, 3, 1, 4, 7, 2, 3, 2, 2, 1, 1, 1, 5, 1, 
      2, 2, 2, 1, 2, 3, 1, 4, 7, 2, 3, 2, 4, 2, 1, 1, 5, 1, 2, 2, 2, 1, 2, 3, 
      1, 4, 7, 2, 3, 4, 2, 2, 1, 1, 5, 1, 2, 2, 2, 1, 2, 3, 1, 4, 7, 2, 3, 4, 
      1, 1, 2, 1, 1, 5, 1, 2, 2, 2, 1, 2, 1, 4, 7, 2, 3, 4, 1, 1, 2, 1, 2, 1, 
      1, 5, 1, 2, 2, 2, 1, 2, 1, 4, 7, 2, 3, 1, 1, 2, 1, 2, 2, 2, 1, 5, 1, 2, 
      2, 2, 1, 2, 1, 4, 7, 2, 3, 1, 1, 2, 1, 2, 3, 2, 1, 5, 1, 2, 2, 2, 1, 2, 
      1, 4, 7, 2, 1, 1, 1, 2, 3, 4, 2, 1, 5, 1, 2, 2, 2, 1, 2, 1, 4, 7, 2, 1, 
      1, 1, 2, 3, 3, 2, 2, 1, 5, 1, 2, 2, 2, 1, 2, 1, 7, 2, 1, 1, 1, 2, 3, 3, 
      2, 4, 1, 2, 1, 5, 1, 2, 2, 1, 2, 1, 7, 2, 1, 1, 2, 3, 3, 2, 4, 1, 2, 2, 
      1, 5, 1, 1, 2, 1, 7, 2, 1, 1, 2, 3, 3, 2, 4, 1, 2, 4, 2, 1, 1, 1, 2, 1, 
      7, 2, 1, 1, 2, 3, 3, 2, 4, 1, 2, 4, 1, 4, 2, 1, 1, 1, 2, 1, 7, 2, 1, 1, 
      2, 3, 3, 4, 2, 4, 1, 4, 3, 2, 1, 1, 1, 2, 1, 2, 1, 1, 2, 3, 3, 4, 2, 4, 
      1, 4, 3, 1, 7, 1, 1, 1, 2, 1, 2, 1, 1, 2, 3, 3, 4, 2, 4, 1, 4, 1, 7, 5, 
      1, 1, 1, 2, 1, 2, 1, 1, 2, 3, 3, 4, 2, 4, 1, 1, 7, 5, 1, 3, 1, 1, 1, 2, 
      1, 2, 1, 1, 2, 3, 4, 2, 4, 1, 1, 7, 5, 1, 3, 1, 3, 1, 1, 1, 2, 1, 2, 1, 
      1, 2, 3, 4, 2, 1, 1, 7, 5, 1, 3, 1, 3, 2, 2, 1, 1, 1, 2, 1, 2, 1, 1, 2, 
      3, 2, 1, 1, 7, 5, 1, 3, 1, 3, 2, 6, 1, 1, 1, 2, 1, 2, 1, 1, 2, 3, 2, 1, 
      1, 5, 1, 3, 1, 3, 2, 13, 1, 1, 1, 2, 1, 2, 1, 1, 2, 3, 2, 1, 1, 3, 1, 
      3, 2, 13, 6, 1, 1, 1, 2, 1, 2, 1, 1, 2, 3, 2, 1, 1, 3, 1, 3, 2, 13, 5, 
      1, 1, 1, 1, 2, 1, 2, 1, 1, 2, 3, 2, 1, 1, 3, 1, 3, 2, 5, 1, 2, 12, 1, 
      1, 2, 1, 2, 1, 1, 2, 3, 2, 1, 1, 3, 1, 3, 2, 5, 2, 12, 2, 1, 1, 2, 1, 
      1, 1, 2, 3, 2, 1, 3, 1, 3, 2, 5, 2, 12, 2, 3, 1, 1, 2, 1, 1, 1, 2, 3, 
      2, 1, 3, 1, 3, 5, 2, 12, 2, 3, 1, 1, 1, 1, 2, 1, 1, 1, 2, 3, 2, 1, 3, 
      1, 3, 5, 2, 12, 2, 1, 1, 1, 2, 1, 1, 2, 1, 1, 1, 2, 3, 2, 1, 3, 1, 3, 
      2, 12, 2, 1, 1, 1, 2, 3, 2, 1, 2, 1, 1, 1, 2, 3, 2, 1, 3, 1, 3, 2, 12, 
      2, 1, 1, 1, 2, 3, 2, 1, 1, 1, 2, 1, 1, 1, 2, 2, 3, 1, 3, 2, 12, 2, 1, 
      1, 1, 2, 3, 2, 1, 1, 4, 1, 2, 1, 1, 1, 2, 2, 3, 1, 3, 2, 12, 2, 1, 1, 
      1, 2, 2, 1, 4, 4, 1, 2, 1, 1, 2, 2, 3, 3, 2, 12, 2, 1, 1, 1, 2, 2, 1, 
      4, 4, 2, 1, 2, 1, 1, 2, 2, 3, 3, 2, 2, 1, 1, 1, 2, 2, 1, 4, 4, 2, 6, 7, 
      1, 2, 1, 1, 2, 2, 3, 3, 2, 1, 1, 2, 2, 1, 4, 4, 2, 6, 7, 3, 1, 2, 1, 1, 
      2, 2, 3, 2, 1, 1, 2, 2, 1, 4, 2, 6, 7, 3, 7, 1, 2, 1, 1, 2, 2, 3, 2, 1, 
      1, 2, 2, 1, 4, 6, 7, 3, 7, 1, 1, 1, 2, 1, 1, 2, 3, 2, 1, 1, 2, 2, 1, 4, 
      6, 3, 7, 1, 1, 9, 1, 1, 1, 2, 3, 2, 1, 1, 2, 1, 4, 6, 3, 7, 1, 1, 9, 4, 
      1, 1, 1, 2, 3, 2, 1, 1, 1, 4, 6, 3, 7, 1, 1, 9, 4, 2, 1, 1, 1, 1, 2, 3, 
      2, 1, 1, 1, 6, 3, 7, 1, 1, 9, 4, 2, 1, 3, 1, 1, 1, 2, 3, 2, 1, 1, 6, 3, 
      7, 1, 1, 9, 4, 2, 1, 3, 1, 2, 1, 1, 2, 2, 1, 1, 6, 3, 7, 1, 1, 9, 4, 2, 
      1, 3, 1, 2, 1, 2, 1, 1, 2, 2, 1, 6, 3, 7, 1, 1, 9, 4, 2, 1, 3, 1, 2, 1, 
      3, 1, 1, 2, 2, 1, 6, 3, 7, 1, 1, 9, 4, 2, 1, 3, 1, 1, 3, 1, 1, 1, 1, 2, 
      2, 1, 6, 7, 1, 1, 9, 4, 2, 1, 3, 1, 1, 3, 1, 1, 2, 1, 1, 1, 2, 2, 1, 6, 
      7, 1, 1, 4, 2, 1, 3, 1, 1, 3, 1, 1, 2, 1, 6, 3, 1, 1, 2, 2, 1, 6, 7, 1, 
      1, 4, 2, 1, 1, 1, 1, 1, 2, 1, 6, 3, 6, 1, 1, 2, 1, 6, 7, 1, 1, 4, 2, 1, 
      1, 1, 1, 1, 2, 1, 3, 6, 8, 1, 2, 1, 6, 7, 1, 1, 4, 2, 1, 1, 1, 1, 1, 2, 
      1, 3, 8, 7, 1, 2, 1, 6, 7, 1, 1, 4, 1, 1, 1, 1, 2, 1, 3, 8, 7, 2, 1, 2, 
      1, 6, 7, 1, 4, 1, 1, 1, 1, 1, 3, 8, 7, 2, 3, 1, 2, 1, 6, 7, 1, 4, 1, 1, 
      1, 1, 1, 3, 8, 7, 2, 2, 1, 1, 2, 1, 6, 7, 1, 4, 1, 1, 1, 1, 1, 3, 8, 2, 
      2, 1, 3, 4, 1, 2, 1, 6, 7, 1, 4, 1, 1, 1, 1, 8, 2, 2, 1, 3, 4, 4, 1, 2, 
      1, 6, 7, 1, 4, 1, 1, 1, 1, 2, 2, 1, 3, 4, 4, 1, 7, 1, 2, 1, 6, 7, 1, 4, 
      1, 1, 1, 1, 2, 2, 1, 3, 4, 1, 7, 1, 3, 1, 2, 1, 6, 7, 1, 4, 1, 1, 1, 2, 
      2, 1, 4, 1, 7, 1, 3, 4, 1, 2, 1, 6, 7, 1, 4, 1, 1, 2, 2, 1, 1, 7, 1, 3, 
      4, 4, 1, 2, 1, 6, 7, 1, 4, 1, 1, 2, 1, 1, 1, 3, 4, 4, 9, 1, 2, 1, 6, 7, 
      1, 4, 1, 1, 2, 1, 1, 1, 3, 4, 4, 5, 4, 1, 1, 6, 7, 1, 4, 1, 1, 2, 1, 1, 
      1, 3, 4, 4, 5, 4, 1, 2, 1, 1, 6, 7, 1, 4, 1, 1, 1, 1, 3, 4, 4, 5, 4, 1, 
      2, 3, 1, 6, 7, 1, 4, 1, 1, 1, 1, 3, 4, 4, 5, 4, 1, 3, 3, 1, 6, 7, 1, 1, 
      1, 1, 1, 3, 4, 4, 5, 4, 1, 3, 3, 2, 2, 1, 6, 7, 1, 1, 1, 1, 1, 3, 4, 5, 
      4, 1, 3, 3, 2, 2, 3, 1, 1, 6, 7, 1, 1, 1, 3, 4, 5, 4, 1, 3, 3, 2, 2, 3, 
      1, 2, 1, 6, 7, 1, 1, 1, 3, 5, 4, 1, 3, 3, 2, 3, 1, 2, 5, 1, 6, 1, 1, 1, 
      3, 5, 4, 1, 3, 2, 3, 1, 2, 5, 9, 1, 6, 1, 1, 1, 3, 5, 1, 3, 2, 3, 1, 2, 
      5, 9, 2, 2, 1, 6, 1, 1, 1, 3, 5, 1, 2, 3, 1, 2, 5, 9, 2, 2, 2, 1, 1, 6, 
      1, 1, 3, 1, 2, 3, 1, 2, 5, 9, 2, 2, 2, 1, 6, 1, 6, 1, 1, 3, 1, 2, 3, 1, 
      2, 5, 9, 2, 2, 2, 1, 2, 5, 1, 6, 1, 1, 3, 1, 2, 3, 1, 2, 5, 9, 2, 2, 2, 
      5, 3, 1, 6, 1, 1, 3, 1, 2, 3, 1, 2, 5, 9, 2, 2, 2, 3, 2, 3, 1, 6, 1, 1, 
      3, 1, 2, 3, 1, 5, 9, 2, 2, 2, 3, 2, 3, 1, 1, 1, 6, 1, 1, 2, 3, 1, 5, 9, 
      2, 2, 2, 3, 2, 3, 1, 1, 4, 1, 6, 1, 1, 2, 1, 5, 9, 2, 2, 2, 3, 2, 3, 1, 
      1, 4, 2, 1, 1, 6, 1, 2, 1, 5, 9, 2, 2, 3, 2, 3, 1, 1, 4, 2, 1, 3, 1, 6, 
      1, 2, 1, 5, 9, 2, 3, 2, 1, 1, 4, 2, 1, 3, 5, 1, 6, 1, 1, 5, 9, 2, 3, 2, 
      1, 1, 4, 2, 3, 5, 3, 1, 6, 1, 1, 5, 9, 2, 3, 2, 1, 1, 2, 3, 5, 3, 1, 3, 
      1, 6, 1, 1, 5, 9, 2, 3, 2, 1, 2, 3, 5, 3, 3, 2, 1, 6, 1, 1, 5, 9, 2, 3, 
      1, 2, 3, 5, 3, 3, 2, 2, 1, 1, 6, 1, 1, 5, 9, 3, 1, 2, 3, 3, 3, 2, 2, 1, 
      7, 1, 6, 1, 5, 9, 3, 1, 2, 3, 3, 2, 2, 1, 7, 4, 1, 6, 1, 5, 9, 3, 1, 2, 
      3, 3, 2, 2, 1, 4, 2, 5, 1, 6, 1, 5, 9, 3, 1, 2, 3, 3, 2, 2, 1, 4, 2, 3, 
      2, 1, 6, 1, 9, 3, 1, 2, 3, 3, 2, 1, 4, 2, 3, 2, 7, 1, 6, 1, 9, 3, 1, 2, 
      3, 3, 2, 1, 2, 3, 2, 7, 3, 1, 1, 6, 1, 3, 1, 2, 3, 3, 2, 1, 2, 3, 2, 7, 
      3, 1, 7, 3, 1, 6, 1, 1, 2, 3, 3, 2, 1, 2, 3, 2, 3, 1, 7, 3, 8, 1, 6, 1, 
      1, 2, 3, 3, 2, 1, 2, 3, 1, 7, 3, 8, 4, 6, 1, 1, 2, 3, 2, 1, 2, 3, 1, 7, 
      3, 8, 4, 2, 1, 1, 2, 3, 2, 1, 2, 3, 1, 7, 3, 8, 4, 2, 6, 1, 1, 1, 2, 3, 
      2, 3, 1, 7, 3, 8, 4, 2, 6, 1, 2, 1, 1, 2, 3, 2, 3, 1, 3, 8, 4, 2, 6, 1, 
      2, 4, 3, 1, 1, 2, 2, 3, 1, 3, 8, 4, 2, 6, 1, 2, 4, 3, 1, 3, 1, 1, 2, 2, 
      3, 1, 3, 8, 2, 6, 1, 2, 4, 3, 1, 3, 1, 3, 1, 2, 2, 3, 1, 3, 8, 2, 6, 1, 
      2, 4, 3, 1, 1, 3, 4, 1, 2, 2, 3, 1, 3, 8, 6, 1, 2, 4, 3, 1, 1, 4, 5, 1, 
      2, 2, 3, 1, 3, 8, 6, 1, 2, 4, 3, 1, 1, 5, 1, 3, 1, 2, 2, 3, 1, 3, 6, 1, 
      2, 4, 3, 1, 1, 5, 1, 3, 2, 6, 1, 2, 2, 3, 1, 3, 1, 2, 4, 3, 1, 1, 5, 1, 
      3, 2, 6, 6, 1, 1, 2, 2, 3, 1, 3, 1, 2, 4, 3, 1, 1, 1, 3, 2, 6, 6, 1, 4, 
      1, 1, 2, 2, 3, 1, 1, 2, 4, 3, 1, 1, 1, 3, 2, 6, 6, 1, 4, 1, 3, 1, 1, 2, 
      2, 3, 1, 1, 2, 4, 3, 1, 1, 3, 2, 1, 4, 1, 3, 1, 7, 2, 5, 1, 2, 2, 3, 1, 
      1, 2, 4, 3, 1, 1, 3, 2, 1, 4, 1, 3, 1, 7, 2, 5, 1, 2, 2, 3, 1, 1, 4, 3, 
      1, 1, 3, 2, 1, 4, 1, 3, 1, 7, 2, 5, 1, 1, 1, 2, 2, 3, 1, 1, 4, 3, 1, 1, 
      3, 1, 4, 1, 3, 7, 2, 5, 1, 1, 3, 1, 2, 2, 3, 1, 1, 4, 3, 1, 1, 3, 4, 1, 
      3, 7, 5, 1, 1, 3, 3, 1, 2, 2, 1, 1, 4, 3, 1, 1, 4, 1, 3, 7, 5, 1, 1, 3, 
      3, 6, 1, 2, 1, 1, 4, 3, 1, 1, 4, 1, 3, 7, 5, 1, 1, 3, 3, 6, 2, 1, 1, 2, 
      1, 1, 3, 1, 1, 4, 3, 7, 5, 1, 1, 3, 3, 6, 2, 1, 5, 1, 2, 1, 1, 3, 1, 1, 
      4, 3, 5, 1, 1, 3, 3, 6, 1, 5, 9, 1, 2, 1, 1, 3, 1, 4, 3, 5, 1, 3, 3, 6, 
      1, 5, 9, 2, 1, 2, 1, 1, 3, 1, 4, 3, 5, 1, 3, 3, 6, 1, 5, 2, 8, 1, 1, 2, 
      1, 1, 3, 1, 4, 3, 5, 1, 3, 3, 6, 1, 2, 8, 1, 4, 1, 1, 2, 1, 1, 3, 1, 3, 
      5, 1, 3, 3, 6, 1, 2, 8, 1, 4, 1, 2, 2, 1, 2, 1, 1, 3, 1, 3, 5, 1, 3, 6, 
      1, 2, 8, 1, 4, 1, 2, 2, 2, 1, 1, 2, 1, 1, 3, 1, 5, 1, 3, 6, 1, 2, 8, 1, 
      4, 1, 2, 2, 2, 3, 1, 2, 1, 1, 3, 1, 5, 3, 6, 1, 2, 8, 1, 4, 2, 2, 2, 3, 
      2, 1, 2, 1, 1, 3, 1, 5, 3, 6, 1, 2, 8, 1, 4, 2, 2, 3, 2, 1, 1, 1, 2, 1, 
      1, 3, 1, 5, 3, 6, 1, 2, 8, 1, 4, 2, 2, 2, 1, 1, 2, 1, 1, 2, 1, 1, 3, 1, 
      5, 3, 6, 1, 2, 8, 1, 4, 2, 2, 1, 1, 2, 1, 1, 1, 1, 2, 1, 1, 3, 1, 5, 6, 
      1, 2, 8, 1, 4, 2, 2, 1, 1, 2, 1, 1, 1, 2, 2, 1, 2, 1, 3, 1, 5, 6, 1, 2, 
      8, 1, 4, 2, 2, 1, 1, 2, 1, 1, 2, 2, 2, 1, 2, 1, 1, 5, 6, 1, 2, 8, 1, 4, 
      2, 2, 1, 2, 1, 1, 2, 2, 2, 4, 1, 2, 1, 1, 5, 6, 1, 2, 1, 4, 2, 2, 1, 2, 
      1, 1, 2, 2, 2, 4, 3, 6, 1, 2, 1, 1, 5, 6, 1, 2, 1, 4, 2, 2, 1, 2, 1, 2, 
      2, 2, 4, 3, 6, 1, 1, 1, 2, 1, 1, 5, 6, 1, 4, 2, 2, 1, 2, 1, 2, 2, 2, 4, 
      3, 6, 1, 1, 3, 1, 2, 1, 1, 6, 1, 4, 2, 2, 1, 2, 1, 2, 2, 2, 4, 3, 6, 1, 
      3, 6, 1, 2, 1, 1, 6, 1, 4, 2, 2, 1, 2, 1, 2, 2, 2, 4, 3, 6, 1, 3, 1, 5, 
      1, 2, 1, 1, 4, 2, 2, 1, 2, 1, 2, 2, 2, 4, 3, 6, 1, 3, 1, 5, 6, 1, 2, 1, 
      1, 4, 2, 2, 1, 2, 1, 2, 2, 2, 4, 3, 6, 3, 1, 5, 7, 1, 2, 1, 1, 4, 2, 2, 
      1, 2, 2, 2, 2, 4, 3, 3, 1, 5, 7, 7, 1, 2, 1, 1, 4, 2, 2, 1, 2, 2, 2, 2, 
      4, 3, 3, 1, 7, 7, 5, 1, 1, 2, 1, 1, 2, 1, 2, 2, 2, 2, 4, 3, 3, 1, 7, 7, 
      5, 1, 6, 1, 2, 1, 1, 2, 1, 2, 2, 2, 2, 4, 3, 1, 7, 7, 5, 1, 6, 3, 1, 1, 
      2, 1, 1, 2, 1, 2, 2, 2, 4, 3, 1, 7, 7, 1, 6, 3, 1, 6, 1, 2, 1, 1, 2, 1, 
      2, 2, 2, 4, 3, 1, 7, 1, 6, 3, 1, 6, 4, 3, 1, 2, 1, 1, 2, 1, 2, 2, 4, 3, 
      1, 7, 1, 6, 3, 1, 6, 3, 6, 1, 2, 1, 2, 1, 2, 2, 4, 3, 7, 1, 6, 3, 1, 6, 
      3, 6, 2, 1, 2, 1, 2, 1, 2, 2, 4, 3, 7, 1, 6, 3, 1, 6, 3, 6, 1, 1, 1, 2, 
      1, 2, 1, 2, 2, 4, 3, 7, 1, 6, 3, 1, 3, 6, 1, 1, 4, 2, 1, 2, 1, 2, 1, 2, 
      2, 3, 7, 1, 6, 3, 1, 3, 6, 1, 1, 4, 2, 1, 4, 1, 2, 1, 2, 1, 2, 2, 3, 7, 
      1, 3, 1, 3, 6, 1, 1, 4, 2, 1, 4, 2, 4, 1, 2, 1, 2, 1, 2, 2, 3, 7, 1, 3, 
      1, 3, 6, 1, 1, 2, 4, 2, 4, 5, 1, 2, 1, 2, 1, 2, 7, 1, 3, 1, 3, 6, 1, 1, 
      2, 4, 2, 4, 5, 5, 1, 2, 1, 2, 1, 2, 7, 1, 3, 1, 3, 6, 1, 1, 2, 4, 2, 4, 
      5, 3, 2, 1, 2, 1, 2, 7, 1, 3, 1, 3, 6, 1, 1, 2, 4, 2, 4, 5, 3, 2, 3, 1, 
      2, 1, 2, 7, 1, 3, 1, 3, 6, 1, 1, 2, 4, 4, 5, 3, 2, 3, 1, 1, 1, 2, 1, 2, 
      7, 3, 1, 3, 6, 1, 2, 4, 4, 5, 3, 2, 3, 1, 1, 2, 1, 2, 1, 2, 7, 1, 3, 6, 
      1, 2, 4, 4, 5, 3, 2, 3, 1, 1, 2, 2, 1, 1, 2, 1, 2, 7, 1, 3, 6, 1, 2, 4, 
      5, 3, 2, 3, 1, 1, 2, 2, 1, 3, 1, 1, 2, 1, 2, 7, 1, 3, 6, 1, 2, 3, 2, 3, 
      1, 1, 2, 2, 1, 3, 1, 6, 1, 2, 1, 2, 7, 1, 3, 6, 1, 2, 3, 2, 3, 1, 2, 2, 
      1, 3, 1, 7, 1, 2, 1, 2, 7, 1, 3, 6, 1, 2, 3, 2, 1, 2, 2, 1, 3, 1, 7, 2, 
      1, 1, 2, 1, 2, 7, 1, 3, 6, 1, 2, 3, 2, 1, 2, 2, 1, 3, 1, 2, 1, 7, 1, 1, 
      2, 2, 7, 1, 3, 6, 1, 2, 3, 2, 1, 2, 2, 1, 3, 1, 1, 7, 1, 3, 1, 2, 2, 7, 
      1, 3, 6, 1, 2, 3, 2, 1, 2, 2, 1, 3, 1, 1, 1, 3, 1, 6, 1, 2, 2, 7, 3, 6, 
      1, 2, 3, 2, 1, 2, 2, 1, 1, 1, 1, 3, 1, 6, 4, 1, 2, 2, 7, 3, 6, 1, 3, 2, 
      1, 2, 2, 1, 1, 1, 1, 3, 1, 6, 4, 1, 2, 1, 2, 2, 7, 3, 6, 1, 3, 2, 2, 2, 
      1, 1, 1, 1, 1, 6, 4, 1, 2, 4, 1, 2, 7, 6, 1, 3, 2, 2, 2, 1, 1, 1, 1, 1, 
      6, 4, 1, 2, 4, 5, 1, 2, 7, 6, 1, 2, 2, 2, 1, 1, 1, 1, 1, 6, 1, 2, 4, 5, 
      7, 1, 6, 1, 2, 2, 2, 1, 1, 1, 1, 6, 1, 2, 4, 5, 7, 1, 1, 8, 1, 6, 1, 2, 
      2, 2, 1, 1, 1, 1, 6, 1, 2, 4, 5, 7, 1, 1, 8, 1, 1, 2, 2, 2, 1, 1, 1, 1, 
      6, 1, 2, 4, 5, 7, 1, 1, 8, 1, 5, 1, 1, 2, 2, 2, 1, 1, 1, 1, 1, 2, 4, 5, 
      7, 1, 1, 8, 1, 5, 4, 2, 1, 1, 2, 2, 2, 1, 1, 1, 1, 1, 2, 4, 5, 1, 1, 8, 
      1, 5, 4, 2, 6, 1, 1, 1, 2, 2, 2, 1, 1, 1, 1, 2, 4, 5, 1, 1, 1, 5, 4, 2, 
      6, 1, 9, 1, 2, 2, 2, 1, 1, 1, 1, 2, 4, 5, 1, 1, 1, 5, 4, 2, 1, 9, 6, 1, 
      2, 2, 2, 1, 1, 1, 1, 2, 4, 5, 1, 1, 5, 4, 2, 1, 9, 6, 1, 1, 1, 2, 2, 2, 
      1, 1, 1, 1, 2, 5, 1, 1, 5, 4, 2, 1, 9, 6, 1, 1, 3, 1, 2, 2, 2, 1, 1, 1, 
      1, 2, 5, 1, 1, 5, 4, 2, 1, 6, 1, 1, 3, 1, 9, 2, 2, 2, 1, 1, 1, 1, 2, 5, 
      1, 1, 5, 4, 2, 1, 6, 1, 3, 1, 10, 2, 2, 2, 1, 1, 1, 1, 5, 1, 1, 4, 2, 
      1, 6, 1, 3, 1, 10, 7, 2, 2, 1, 1, 1, 1, 5, 1, 1, 4, 2, 1, 1, 3, 1, 10, 
      7, 8, 2, 2, 1, 1, 1, 1, 5, 1, 1, 4, 1, 1, 3, 1, 10, 8, 2, 8, 2, 2, 1, 
      1, 1, 1, 5, 1, 1, 4, 1, 1, 3, 1, 10, 8, 2, 8, 2, 2, 1, 1, 1, 1, 5, 1, 
      1, 4, 1, 1, 3, 1, 10, 2, 8, 7, 1, 2, 2, 1, 1, 1, 1, 5, 1, 1, 4, 1, 1, 
      3, 1, 10, 2, 7, 1, 3, 5, 2, 2, 1, 1, 1, 1, 5, 1, 1, 4, 1, 1, 1, 10, 2, 
      7, 1, 3, 5, 2, 1, 2, 2, 1, 1, 1, 1, 5, 1, 1, 4, 1, 1, 1, 2, 7, 1, 3, 5, 
      2, 1, 8, 2, 2, 1, 1, 1, 1, 5, 1, 1, 4, 1, 1, 1, 2, 7, 1, 3, 5, 2, 1, 8, 
      4, 2, 1, 1, 1, 1, 1, 1, 4, 1, 1, 1, 2, 7, 1, 5, 2, 1, 8, 4, 8, 2, 1, 1, 
      1, 1, 1, 1, 4, 1, 1, 1, 2, 1, 5, 2, 1, 8, 4, 8, 4, 4, 2, 1, 1, 1, 1, 1, 
      4, 1, 1, 1, 1, 5, 2, 1, 8, 4, 8, 4, 4, 3, 2, 1, 1, 1, 1, 1, 1, 1, 1, 5, 
      2, 1, 8, 4, 8, 4, 4, 3, 5, 2, 1, 1, 1, 1, 1, 1, 1, 1, 5, 2, 1, 8, 4, 8, 
      4, 4, 3, 1, 5, 2, 1, 1, 1, 1, 1, 1, 1, 1, 5, 2, 1, 8, 4, 8, 4, 3, 1, 5, 
      3, 2, 1, 1, 1, 1, 1, 1, 1, 1, 5, 2, 1, 8, 4, 8, 4, 1, 5, 3, 2, 5, 1, 1, 
      1, 1, 1, 1, 1, 1, 5, 2, 1, 8, 4, 8, 4, 1, 3, 2, 5, 4, 1, 1, 1, 1, 1, 1, 
      1, 1, 5, 2, 1, 8, 4, 8, 4, 1, 2, 5, 4, 1, 3, 1, 1, 1, 1, 1, 1, 5, 2, 1, 
      8, 4, 8, 4, 1, 2, 5, 4, 1, 3, 1, 1, 1, 1, 1, 1, 1, 5, 2, 1, 8, 4, 8, 4, 
      1, 2, 5, 4, 1, 3, 1, 2, 1, 1, 1, 5, 2, 1, 8, 4, 8, 4, 1, 2, 5, 4, 1, 3, 
      1, 2, 2, 1, 1, 1, 5, 2, 1, 8, 4, 8, 4, 1, 2, 4, 1, 3, 2, 2, 6, 1, 1, 5, 
      2, 8, 4, 8, 4, 1, 2, 4, 1, 3, 2, 2, 6, 2, 1, 1, 5, 2, 4, 8, 4, 1, 2, 4, 
      1, 3, 2, 2, 2, 14, 1, 1, 5, 2, 4, 8, 4, 1, 4, 1, 3, 2, 2, 2, 14, 1, 1, 
      1, 1, 5, 4, 8, 4, 1, 1, 3, 2, 2, 2, 14, 1, 1, 6, 1, 1, 5, 4, 8, 4, 1, 
      1, 3, 2, 2, 14, 1, 6, 3, 1, 5, 4, 8, 4, 1, 1, 3, 2, 2, 14, 1, 6, 4, 1, 
      5, 4, 8, 4, 1, 1, 3, 2, 2, 1, 6, 13, 1, 5, 4, 8, 1, 1, 3, 2, 2, 1, 6, 
      13, 3, 1, 1, 5, 4, 8, 1, 3, 2, 2, 1, 6, 13, 3, 2, 1, 5, 8, 1, 3, 2, 2, 
      1, 6, 13, 3, 2, 2, 2, 1, 5, 8, 1, 3, 2, 2, 1, 6, 3, 2, 2, 2, 10, 3, 1, 
      5, 8, 3, 2, 2, 1, 6, 3, 2, 2, 10, 3, 3, 1, 5, 3, 2, 2, 1, 6, 3, 2, 2, 
      10, 3, 3, 4, 4, 1, 5, 3, 2, 2, 1, 3, 2, 2, 10, 3, 3, 4, 4, 2, 4, 1, 5, 
      2, 2, 1, 3, 2, 2, 10, 3, 3, 4, 2, 4, 7, 1, 5, 2, 2, 1, 3, 2, 2, 10, 3, 
      4, 2, 4, 7, 3, 1, 1, 5, 2, 2, 1, 3, 2, 10, 3, 2, 4, 7, 3, 1, 5, 1, 5, 
      2, 2, 3, 2, 10, 3, 2, 7, 3, 1, 5, 5, 1, 5, 2, 2, 3, 2, 10, 3, 2, 7, 3, 
      5, 5, 1, 1, 1, 5, 2, 2, 10, 3, 2, 7, 3, 5, 5, 1, 1, 5, 1, 5, 10, 3, 2, 
      7, 3, 5, 5, 1, 1, 5, 4, 5, 10, 3, 2, 7, 5, 5, 1, 1, 5, 4, 4, 5, 10, 3, 
      2, 7, 5, 5, 1, 1, 4, 4, 3, 2, 5, 10, 3, 2, 7, 5, 5, 1, 1, 4, 3, 2, 1, 
      3, 10, 3, 2, 7, 5, 5, 1, 1, 4, 3, 2, 1, 3, 3, 2, 10, 3, 2, 7, 5, 5, 1, 
      4, 3, 1, 3, 3, 2, 3, 10, 3, 7, 5, 5, 1, 4, 3, 1, 3, 3, 2, 3, 1, 1, 10, 
      3, 5, 5, 1, 4, 3, 1, 3, 3, 2, 3, 1, 1, 3, 4, 10, 3, 5, 5, 1, 4, 3, 1, 
      3, 3, 2, 3, 1, 1, 3, 1, 3, 10, 3, 5, 5, 4, 3, 1, 3, 3, 2, 3, 1, 1, 3, 
      3, 2, 10, 3, 5, 5, 4, 3, 3, 3, 2, 3, 1, 3, 3, 2, 2, 10, 3, 5, 5, 4, 3, 
      3, 2, 3, 1, 3, 3, 2, 2, 1, 2, 3, 5, 5, 4, 3, 3, 2, 3, 1, 3, 3, 2, 2, 1, 
      2, 5, 5, 3, 5, 5, 4, 3, 3, 2, 3, 3, 3, 2, 2, 1, 2, 5, 6, 3, 5, 4, 3, 3, 
      2, 3, 3, 3, 2, 2, 1, 2, 6, 10, 3, 5, 4, 3, 3, 2, 3, 3, 3, 2, 1, 6, 10, 
      4, 3, 5, 4, 3, 3, 2, 3, 3, 2, 1, 6, 10, 4, 2, 1, 3, 5, 4, 3, 3, 2, 3, 
      3, 2, 1, 6, 4, 2, 1, 1, 9, 5, 4, 3, 3, 2, 3, 3, 2, 1, 6, 4, 2, 1, 1, 9, 
      2, 1, 5, 3, 3, 2, 3, 3, 2, 1, 6, 4, 2, 1, 1, 9, 2, 1, 3, 2, 5, 3, 3, 2, 
      3, 3, 1, 6, 4, 2, 1, 1, 2, 1, 3, 2, 11, 5, 3, 3, 2, 3, 3, 1, 6, 4, 2, 
      1, 1, 2, 1, 2, 11, 1, 3, 5, 3, 3, 2, 3, 3, 1, 6, 4, 2, 1, 1, 2, 1, 2, 
      1, 3, 6, 6, 5, 3, 3, 3, 3, 1, 6, 4, 2, 1, 2, 1, 2, 1, 3, 6, 6, 3, 5, 3, 
      3, 3, 3, 1, 4, 1, 2, 1, 2, 1, 3, 6, 6, 3, 8, 5, 3, 3, 3, 1, 4, 1, 2, 1, 
      1, 3, 6, 6, 3, 8, 5, 5, 3, 1, 4, 1, 2, 1, 1, 3, 6, 6, 3, 8, 5, 6, 5, 3, 
      1, 4, 1, 2, 1, 1, 6, 6, 3, 8, 5, 5, 5, 3, 1, 4, 1, 1, 1, 6, 3, 8, 5, 5, 
      5, 5, 3, 1, 4, 1, 1, 1, 6, 8, 5, 5, 5, 1, 2, 5, 3, 1, 4, 1, 1, 1, 6, 8, 
      5, 5, 1, 2, 3, 2, 5, 3, 1, 4, 1, 1, 1, 6, 8, 5, 1, 2, 3, 2, 2, 3, 5, 3, 
      1, 1, 1, 6, 8, 5, 1, 2, 3, 2, 2, 3, 5, 5, 3, 1, 1, 1, 6, 5, 1, 2, 3, 2, 
      2, 3, 5, 5, 4, 5, 3, 1, 1, 1, 6, 1, 2, 3, 2, 2, 3, 5, 5, 4, 1, 5, 5, 3, 
      1, 1, 1, 6, 1, 2, 3, 2, 2, 3, 5, 4, 1, 5, 3, 2, 5, 3, 1, 1, 1, 6, 1, 2, 
      3, 2, 2, 5, 4, 1, 5, 3, 2, 2, 2, 3, 1, 1, 1, 6, 1, 2, 3, 2, 2, 5, 4, 1, 
      5, 3, 2, 2, 2, 1, 4, 3, 1, 1, 1, 6, 1, 2, 3, 2, 2, 4, 1, 5, 3, 2, 2, 1, 
      4, 7, 3, 1, 1, 1, 6, 1, 2, 3, 2, 2, 4, 1, 5, 3, 2, 2, 1, 4, 6, 1, 3, 1, 
      1, 1, 6, 2, 3, 2, 2, 4, 1, 5, 2, 2, 1, 4, 6, 1, 4, 3, 1, 1, 1, 6, 2, 3, 
      2, 2, 4, 1, 5, 2, 2, 1, 6, 1, 4, 3, 2, 3, 1, 1, 1, 6, 2, 3, 2, 2, 4, 1, 
      5, 2, 2, 1, 1, 4, 3, 2, 3, 3, 3, 1, 1, 1, 6, 2, 2, 2, 4, 1, 5, 2, 2, 1, 
      1, 4, 3, 3, 3, 5, 3, 1, 1, 1, 2, 2, 4, 1, 5, 2, 2, 1, 1, 4, 3, 3, 3, 5, 
      7, 3, 1, 1, 1, 2, 2, 4, 1, 5, 2, 2, 1, 1, 4, 3, 3, 5, 7, 2, 2, 3, 1, 1, 
      1, 2, 2, 4, 1, 5, 2, 2, 1, 1, 4, 3, 5, 7, 2, 2, 2, 1, 3, 1, 1, 1, 2, 2, 
      4, 1, 5, 2, 2, 1, 1, 3, 5, 7, 2, 2, 2, 1, 2, 2, 3, 1, 1, 1, 2, 2, 4, 1, 
      5, 2, 1, 1, 3, 7, 2, 2, 2, 1, 2, 2, 7, 3, 1, 1, 1, 2, 2, 4, 1, 5, 2, 1, 
      1, 3, 7, 2, 2, 1, 2, 7, 1, 3, 1, 1, 1, 2, 2, 4, 1, 5, 2, 1, 1, 3, 7, 2, 
      2, 1, 2, 1, 5, 2, 3, 1, 2, 2, 4, 1, 5, 2, 1, 1, 3, 7, 2, 2, 1, 2, 1, 5, 
      2, 2, 3, 1, 2, 2, 4, 1, 5, 2, 1, 1, 7, 2, 2, 1, 2, 1, 5, 2, 2, 1, 3, 3, 
      1, 2, 2, 4, 1, 5, 2, 1, 1, 2, 2, 1, 2, 1, 5, 2, 1, 3, 8, 3, 1, 2, 2, 4, 
      1, 5, 2, 1, 2, 2, 1, 2, 1, 2, 1, 3, 8, 6, 3, 1, 2, 2, 4, 1, 5, 2, 1, 2, 
      2, 1, 2, 1, 2, 1, 8, 6, 2, 1, 3, 1, 2, 4, 1, 5, 2, 1, 2, 2, 1, 2, 1, 1, 
      8, 6, 2, 1, 4, 3, 1, 4, 1, 5, 2, 1, 2, 2, 1, 2, 1, 1, 8, 6, 2, 1, 4, 1, 
      1, 3, 1, 4, 1, 5, 1, 2, 2, 1, 2, 1, 1, 8, 6, 2, 1, 4, 1, 1, 1, 1, 3, 1, 
      4, 5, 1, 2, 2, 1, 2, 1, 1, 8, 6, 1, 4, 1, 1, 1, 1, 3, 3, 1, 4, 5, 1, 2, 
      2, 1, 2, 8, 6, 1, 4, 1, 1, 1, 1, 3, 2, 3, 1, 4, 5, 1, 2, 2, 1, 2, 6, 1, 
      4, 1, 1, 1, 1, 3, 2, 6, 3, 3, 1, 4, 5, 1, 2, 1, 2, 6, 1, 4, 1, 1, 1, 1, 
      3, 2, 6, 3, 1, 2, 3, 1, 4, 5, 1, 1, 2, 6, 1, 4, 1, 1, 1, 3, 2, 6, 3, 1, 
      2, 3, 3, 1, 4, 5, 1, 1, 2, 6, 1, 1, 1, 1, 3, 2, 6, 3, 1, 2, 3, 3, 1, 3, 
      1, 4, 1, 1, 2, 6, 1, 1, 1, 3, 2, 6, 3, 1, 2, 3, 3, 1, 6, 3, 4, 1, 1, 2, 
      6, 1, 1, 1, 3, 2, 6, 3, 1, 2, 3, 3, 1, 6, 1, 1, 3, 4, 1, 1, 2, 1, 1, 1, 
      3, 2, 6, 3, 1, 2, 3, 3, 1, 6, 1, 7, 3, 4, 1, 1, 2, 1, 1, 1, 3, 2, 6, 3, 
      1, 2, 3, 1, 6, 1, 7, 3, 1, 3, 4, 1, 1, 2, 1, 1, 1, 2, 6, 3, 1, 2, 3, 1, 
      6, 1, 3, 1, 9, 3, 4, 1, 1, 2, 1, 1, 1, 2, 6, 1, 2, 3, 1, 6, 1, 3, 1, 9, 
      1, 2, 3, 4, 1, 1, 2, 1, 1, 1, 2, 6, 1, 2, 3, 1, 1, 3, 9, 1, 2, 6, 3, 4, 
      1, 1, 2, 1, 1, 1, 2, 1, 2, 3, 1, 1, 3, 9, 1, 2, 6, 4, 2, 3, 4, 1, 1, 2, 
      1, 1, 1, 1, 2, 3, 1, 1, 3, 9, 1, 2, 6, 4, 2, 1, 1, 3, 4, 1, 1, 2, 1, 1, 
      1, 1, 2, 3, 1, 1, 9, 1, 2, 6, 4, 2, 1, 4, 3, 4, 1, 2, 1, 1, 1, 1, 2, 3, 
      1, 1, 9, 1, 2, 6, 4, 2, 4, 2, 3, 4, 1, 1, 1, 1, 2, 3, 1, 1, 9, 1, 2, 6, 
      4, 2, 4, 2, 3, 3, 4, 1, 1, 1, 1, 2, 3, 1, 1, 1, 2, 6, 4, 2, 4, 2, 3, 1, 
      8, 3, 4, 1, 1, 1, 1, 2, 3, 1, 1, 1, 2, 4, 2, 4, 2, 3, 1, 8, 3, 4, 3, 4, 
      1, 1, 1, 1, 2, 3, 1, 1, 1, 2, 4, 2, 4, 2, 3, 1, 8, 4, 2, 2, 3, 4, 1, 1, 
      1, 1, 2, 3, 1, 1, 1, 2, 4, 2, 2, 3, 1, 8, 4, 2, 2, 1, 3, 3, 4, 1, 1, 1, 
      1, 2, 3, 1, 1, 2, 4, 2, 2, 3, 1, 8, 4, 2, 2, 1, 3, 1, 1, 3, 4, 1, 1, 1, 
      1, 2, 3, 1, 1, 2, 4, 2, 3, 1, 8, 4, 2, 2, 3, 1, 1, 3, 3, 4, 1, 1, 1, 1, 
      2, 3, 1, 1, 2, 4, 2, 1, 8, 2, 2, 3, 1, 1, 3, 6, 3, 4, 1, 1, 1, 1, 2, 3, 
      1, 1, 2, 4, 2, 8, 2, 2, 3, 1, 1, 6, 4, 4, 1, 1, 1, 1, 2, 3, 1, 1, 4, 2, 
      8, 2, 2, 3, 1, 1, 6, 4, 5, 4, 1, 1, 1, 1, 2, 3, 1, 1, 4, 2, 2, 2, 3, 1, 
      1, 6, 4, 5, 3, 5, 4, 1, 1, 1, 2, 3, 1, 1, 4, 2, 2, 2, 3, 1, 1, 6, 4, 5, 
      5, 4, 4, 1, 1, 1, 2, 3, 1, 1, 4, 2, 2, 2, 3, 1, 1, 6, 5, 5, 4, 2, 2, 4, 
      1, 1, 1, 2, 3, 1, 1, 4, 2, 2, 2, 3, 1, 1, 6, 5, 4, 2, 2, 1, 4, 4, 1, 1, 
      1, 2, 3, 1, 1, 4, 2, 2, 2, 3, 1, 1, 5, 4, 2, 1, 4, 8, 4, 1, 1, 1, 2, 1, 
      1, 4, 2, 2, 2, 3, 1, 1, 5, 4, 2, 1, 4, 8, 2, 1, 4, 1, 1, 1, 2, 1, 1, 4, 
      2, 2, 2, 3, 1, 1, 5, 4, 1, 4, 8, 2, 1, 1, 2, 4, 1, 1, 1, 2, 1, 1, 2, 2, 
      2, 3, 1, 1, 5, 4, 1, 4, 8, 2, 1, 1, 2, 1, 3, 4, 1, 1, 1, 2, 1, 1, 2, 2, 
      2, 3, 1, 1, 5, 4, 1, 4, 2, 1, 1, 2, 1, 3, 4, 4, 4, 1, 1, 1, 2, 1, 1, 2, 
      2, 2, 1, 1, 5, 4, 1, 4, 2, 1, 1, 2, 1, 3, 4, 7, 4, 1, 1, 1, 2, 1, 1, 2, 
      2, 2, 1, 1, 5, 4, 1, 4, 2, 1, 1, 1, 3, 4, 7, 1, 2, 4, 1, 1, 2, 1, 1, 2, 
      2, 1, 1, 5, 4, 1, 4, 2, 1, 1, 1, 3, 4, 7, 1, 2, 3, 4, 1, 1, 2, 1, 1, 2, 
      2, 1, 1, 5, 4, 1, 2, 1, 1, 3, 4, 7, 1, 2, 3, 5, 4, 1, 1, 2, 1, 1, 2, 2, 
      1, 1, 5, 1, 2, 1, 1, 3, 4, 7, 1, 2, 3, 5, 3, 1, 4, 1, 1, 2, 1, 1, 2, 2, 
      1, 1, 5, 1, 2, 1, 1, 3, 4, 1, 2, 3, 5, 3, 1, 4, 3, 4, 1, 1, 2, 1, 1, 2, 
      2, 1, 1, 5, 1, 2, 1, 1, 3, 4, 2, 5, 3, 1, 4, 3, 4, 4, 2, 1, 1, 2, 2, 1, 
      1, 5, 1, 2, 1, 1, 3, 4, 2, 5, 3, 1, 4, 3, 4, 2, 4, 2, 1, 1, 2, 2, 1, 1, 
      5, 1, 2, 1, 1, 3, 4, 2, 3, 1, 4, 3, 4, 2, 2, 3, 4, 2, 1, 1, 2, 2, 1, 1, 
      5, 1, 2, 1, 1, 4, 2, 3, 4, 3, 4, 2, 2, 3, 4, 4, 1, 1, 2, 1, 1, 5, 1, 2, 
      1, 1, 4, 2, 3, 4, 3, 4, 2, 2, 3, 4, 4, 4, 1, 1, 2, 1, 1, 1, 2, 1, 4, 2, 
      3, 4, 3, 4, 2, 2, 3, 4, 4, 5, 4, 1, 1, 2, 1, 1, 1, 2, 1, 4, 2, 3, 4, 3, 
      4, 2, 3, 4, 4, 5, 1, 1, 4, 1, 1, 2, 1, 1, 2, 1, 2, 3, 4, 3, 4, 2, 3, 4, 
      4, 5, 1, 1, 5, 4, 1, 1, 2, 1, 1, 2, 1, 2, 3, 4, 3, 4, 2, 3, 4, 5, 1, 5, 
      5, 4, 1, 1, 2, 1, 1, 2, 2, 3, 4, 3, 4, 3, 4, 5, 1, 5, 5, 3, 4, 1, 1, 2, 
      1, 1, 2, 2, 3, 4, 3, 4, 3, 4, 5, 1, 5, 5, 2, 1, 4, 1, 1, 2, 1, 1, 2, 2, 
      3, 4, 3, 4, 3, 4, 5, 1, 5, 5, 1, 1, 1, 4, 1, 1, 2, 1, 1, 2, 2, 3, 4, 3, 
      4, 3, 4, 5, 5, 5, 1, 1, 1, 1, 1, 4, 1, 2, 1, 1, 2, 3, 4, 3, 4, 3, 4, 5, 
      5, 5, 1, 1, 1, 1, 1, 3, 4, 1, 2, 1, 1, 2, 3, 4, 3, 4, 3, 4, 5, 5, 5, 1, 
      1, 1, 1, 1, 1, 2, 4, 1, 2, 1, 1, 2, 3, 4, 3, 4, 3, 5, 5, 5, 1, 1, 1, 1, 
      1, 1, 2, 3, 1, 4, 1, 2, 1, 1, 2, 3, 4, 3, 4, 3, 5, 5, 5, 1, 1, 1, 1, 1, 
      1, 3, 1, 1, 1, 4, 1, 2, 1, 1, 2, 3, 4, 3, 3, 5, 5, 5, 1, 1, 1, 1, 1, 1, 
      3, 1, 1, 1, 1, 3, 1, 2, 1, 1, 2, 3, 4, 3, 3, 5, 5, 5, 1, 1, 1, 1, 1, 3, 
      1, 1, 1, 1, 3, 5, 1, 2, 1, 1, 2, 3, 4, 3, 3, 5, 5, 5, 1, 1, 1, 3, 1, 1, 
      1, 1, 3, 5, 2, 1, 2, 1, 1, 2, 3, 4, 3, 3, 5, 5, 5, 1, 1, 1, 3, 1, 1, 1, 
      1, 3, 2, 1, 4, 1, 2, 1, 1, 2, 3, 4, 3, 3, 5, 5, 1, 1, 1, 3, 1, 1, 1, 3, 
      2, 1, 4, 6, 1, 2, 1, 1, 2, 3, 4, 3, 3, 5, 5, 1, 1, 3, 1, 1, 1, 3, 2, 1, 
      4, 6, 1, 1, 1, 2, 1, 1, 2, 3, 4, 3, 3, 5, 5, 1, 1, 3, 1, 1, 1, 2, 1, 4, 
      6, 1, 4, 1, 2, 1, 2, 3, 4, 3, 3, 5, 5, 1, 1, 3, 1, 1, 2, 1, 4, 6, 1, 4, 
      2, 1, 2, 1, 2, 3, 4, 3, 3, 5, 5, 1, 1, 1, 1, 2, 1, 4, 6, 1, 4, 2, 2, 1, 
      2, 1, 2, 3, 4, 3, 5, 5, 1, 1, 1, 1, 2, 1, 4, 6, 1, 4, 2, 2, 1, 3, 1, 2, 
      3, 4, 3, 5, 5, 1, 1, 1, 1, 2, 1, 4, 6, 1, 4, 2, 1, 3, 4, 1, 2, 3, 4, 3, 
      5, 5, 1, 1, 1, 2, 1, 4, 1, 4, 2, 1, 3, 4, 7, 1, 2, 3, 4, 3, 5, 5, 1, 1, 
      1, 2, 1, 1, 4, 2, 1, 3, 4, 7, 1, 4, 1, 3, 4, 3, 5, 5, 1, 1, 1, 2, 1, 1, 
      4, 2, 1, 3, 4, 7, 1, 6, 1, 3, 4, 3, 5, 5, 1, 1, 2, 1, 1, 4, 2, 1, 3, 4, 
      1, 6, 8, 1, 3, 4, 3, 5, 1, 1, 2, 1, 1, 4, 2, 1, 3, 4, 1, 6, 9, 1, 3, 4, 
      3, 5, 1, 1, 2, 1, 1, 4, 2, 1, 3, 4, 1, 6, 9, 1, 1, 3, 4, 3, 5, 1, 1, 2, 
      1, 1, 4, 3, 4, 1, 6, 9, 1, 3, 1, 3, 4, 3, 5, 1, 1, 2, 1, 1, 3, 4, 1, 6, 
      9, 1, 3, 1, 3, 1, 3, 4, 3, 5, 1, 1, 2, 1, 1, 4, 1, 6, 9, 1, 1, 3, 6, 1, 
      3, 4, 3, 5, 2, 1, 1, 4, 1, 6, 9, 1, 1, 3, 6, 2, 1, 3, 4, 3, 5, 1, 1, 4, 
      1, 6, 1, 1, 3, 6, 2, 10, 1, 3, 4, 3, 1, 1, 4, 1, 6, 1, 1, 3, 6, 2, 10, 
      1, 4, 1, 3, 4, 3, 1, 1, 4, 1, 6, 1, 1, 6, 2, 10, 1, 4, 2, 1, 1, 3, 4, 
      3, 1, 1, 4, 1, 6, 1, 6, 2, 10, 4, 2, 1, 2, 3, 4, 3, 1, 1, 4, 1, 6, 1, 
      6, 2, 10, 2, 1, 2, 5, 3, 4, 3, 1, 1, 4, 1, 6, 1, 2, 10, 2, 1, 2, 5, 1, 
      5, 3, 4, 3, 1, 1, 4, 1, 6, 1, 10, 2, 1, 2, 5, 1, 5, 3, 4, 3, 1, 1, 4, 
      1, 6, 1, 2, 1, 2, 5, 1, 5, 8, 2, 3, 1, 1, 4, 1, 6, 1, 2, 1, 2, 5, 1, 5, 
      8, 2, 7, 3, 1, 1, 4, 1, 6, 1, 2, 1, 2, 1, 5, 8, 2, 7, 1, 4, 3, 1, 1, 4, 
      1, 6, 1, 2, 1, 1, 5, 8, 2, 7, 1, 6, 3, 1, 4, 1, 6, 1, 2, 1, 1, 5, 8, 2, 
      7, 6, 2, 3, 1, 4, 6, 1, 2, 1, 1, 8, 2, 7, 6, 2, 6, 3, 1, 4, 6, 1, 2, 1, 
      1, 8, 2, 7, 2, 6, 5, 1, 3, 1, 4, 6, 1, 2, 1, 1, 8, 2, 7, 2, 6, 1, 1, 4, 
      3, 4, 6, 1, 2, 1, 8, 2, 7, 2, 6, 1, 1, 4, 2, 4, 6, 1, 2, 1, 8, 2, 7, 2, 
      6, 1, 1, 2, 6, 4, 6, 1, 2, 1, 8, 2, 7, 2, 1, 1, 2, 6, 3, 3, 4, 6, 1, 2, 
      1, 8, 2, 7, 2, 1, 1, 2, 3, 3, 1, 5, 4, 6, 1, 2, 1, 2, 7, 2, 1, 1, 2, 3, 
      3, 1, 5, 6, 3, 4, 6, 1, 2, 1, 2, 7, 2, 1, 2, 3, 3, 1, 5, 6, 4, 6, 1, 2, 
      1, 2, 7, 2, 1, 2, 3, 3, 1, 5, 6, 4, 2, 2, 6, 1, 2, 1, 2, 7, 2, 1, 2, 3, 
      3, 1, 5, 4, 2, 2, 4, 2, 6, 1, 2, 1, 2, 7, 1, 2, 3, 3, 1, 5, 4, 2, 2, 4, 
      2, 1, 1, 6, 2, 1, 2, 1, 2, 3, 3, 1, 5, 4, 2, 2, 4, 2, 1, 1, 8, 6, 2, 1, 
      2, 1, 2, 3, 1, 4, 2, 2, 4, 2, 1, 1, 8, 4, 6, 1, 2, 1, 2, 3, 1, 4, 2, 2, 
      4, 2, 1, 1, 8, 4, 1, 2, 6, 1, 2, 2, 3, 1, 4, 2, 4, 2, 1, 1, 8, 4, 1, 2, 
      3, 6, 1, 2, 2, 3, 1, 4, 2, 4, 2, 1, 8, 1, 2, 3, 5, 6, 1, 2, 2, 3, 1, 4, 
      2, 4, 2, 1, 1, 2, 3, 5, 7, 1, 6, 1, 2, 2, 3, 1, 2, 4, 1, 1, 2, 3, 5, 7, 
      1, 5, 6, 1, 2, 2, 3, 2, 4, 1, 1, 2, 3, 5, 1, 5, 8, 2, 2, 3, 2, 4, 1, 1, 
      2, 3, 5, 1, 5, 8, 7, 2, 2, 3, 2, 4, 1, 1, 2, 3, 5, 5, 8, 8, 2, 3, 2, 4, 
      1, 1, 2, 3, 5, 5, 8, 8, 1, 1, 2, 3, 2, 4, 1, 2, 3, 5, 8, 8, 1, 1, 6, 2, 
      3, 2, 4, 1, 2, 3, 5, 8, 8, 1, 1, 1, 6, 2, 2, 4, 1, 2, 3, 5, 8, 8, 1, 1, 
      1, 6, 1, 2, 2, 2, 4, 1, 2, 3, 5, 8, 8, 1, 1, 1, 1, 2, 2, 4, 2, 2, 4, 1, 
      2, 3, 5, 8, 1, 1, 1, 1, 2, 2, 4, 7, 1, 2, 2, 4, 1, 2, 3, 5, 8, 1, 1, 1, 
      1, 2, 2, 4, 1, 6, 1, 2, 2, 4, 1, 2, 3, 5, 1, 1, 1, 1, 2, 2, 4, 1, 6, 1, 
      1, 7, 2, 2, 4, 2, 3, 5, 1, 1, 1, 1, 2, 4, 1, 6, 1, 1, 7, 3, 2, 2, 2, 3, 
      5, 1, 1, 1, 1, 2, 4, 1, 6, 1, 1, 7, 3, 1, 3, 2, 2, 2, 3, 5, 1, 1, 1, 1, 
      2, 4, 1, 6, 1, 1, 3, 1, 3, 7, 1, 2, 2, 2, 3, 5, 1, 1, 1, 1, 2, 1, 6, 1, 
      1, 3, 1, 3, 7, 1, 3, 1, 2, 2, 2, 3, 1, 1, 1, 1, 2, 1, 6, 1, 1, 3, 1, 3, 
      7, 1, 3, 1, 1, 5, 2, 2, 3, 1, 1, 1, 1, 2, 1, 6, 1, 1, 3, 1, 3, 7, 1, 3, 
      1, 5, 3, 2, 2, 3, 1, 1, 1, 1, 2, 1, 6, 1, 3, 1, 3, 7, 1, 3, 1, 3, 6, 2, 
      2, 3, 1, 1, 1, 1, 2, 6, 1, 3, 1, 3, 7, 1, 3, 1, 6, 4, 2, 2, 3, 1, 1, 1, 
      1, 2, 6, 1, 3, 1, 3, 7, 1, 3, 1, 6, 2, 2, 2, 2, 3, 1, 1, 1, 6, 1, 3, 1, 
      3, 7, 1, 3, 1, 6, 2, 2, 3, 2, 2, 1, 1, 1, 6, 1, 3, 1, 7, 1, 3, 1, 6, 2, 
      2, 3, 4, 2, 1, 1, 1, 6, 1, 3, 1, 7, 1, 3, 1, 6, 2, 2, 3, 4, 2, 1, 2, 1, 
      1, 1, 6, 1, 3, 1, 7, 1, 3, 1, 2, 2, 3, 4, 2, 1, 5, 1, 2, 1, 1, 1, 6, 1, 
      3, 1, 1, 3, 1, 2, 2, 3, 4, 2, 1, 5, 8, 2, 1, 1, 1, 6, 1, 3, 1, 1, 1, 2, 
      2, 3, 4, 2, 1, 5, 8, 2, 1, 2, 1, 1, 1, 6, 1, 3, 1, 1, 1, 2, 2, 3, 4, 2, 
      1, 8, 2, 1, 4, 2, 2, 1, 1, 1, 6, 1, 3, 1, 1, 1, 2, 3, 4, 2, 1, 8, 2, 1, 
      4, 4, 2, 1, 1, 1, 1, 3, 1, 1, 1, 2, 3, 4, 2, 1, 8, 1, 4, 4, 8, 2, 1, 1, 
      1, 3, 1, 1, 2, 3, 4, 2, 1, 8, 1, 4, 4, 8, 2, 2, 1, 1, 1, 3, 1, 1, 2, 3, 
      4, 2, 1, 8, 1, 4, 8, 2, 1, 3, 2, 1, 1, 3, 1, 1, 2, 3, 4, 2, 1, 8, 1, 4, 
      2, 1, 3, 7, 2, 1, 1, 3, 1, 1, 2, 4, 1, 8, 1, 4, 2, 1, 3, 7, 5, 2, 1, 1, 
      3, 1, 1, 2, 4, 1, 8, 1, 4, 2, 1, 3, 7, 1, 4, 2, 1, 1, 3, 1, 1, 2, 4, 1, 
      8, 1, 4, 2, 1, 7, 1, 4, 3, 1, 1, 1, 3, 1, 1, 2, 4, 1, 8, 1, 4, 2, 1, 7, 
      1, 4, 3, 1, 1, 1, 1, 1, 3, 1, 1, 2, 4, 1, 8, 1, 4, 2, 1, 7, 1, 3, 1, 1, 
      1, 2, 2, 1, 1, 1, 1, 2, 4, 1, 8, 1, 4, 2, 1, 7, 1, 3, 1, 1, 2, 2, 4, 1, 
      1, 1, 1, 2, 4, 1, 8, 1, 2, 1, 7, 1, 3, 1, 1, 2, 4, 6, 1, 1, 1, 2, 4, 8, 
      1, 2, 1, 7, 1, 3, 1, 1, 2, 4, 6, 2, 1, 1, 1, 2, 4, 1, 2, 1, 7, 1, 3, 1, 
      1, 2, 4, 6, 2, 7, 1, 1, 1, 1, 2, 4, 1, 2, 1, 7, 1, 3, 1, 2, 4, 2, 7, 1, 
      6, 1, 1, 1, 2, 4, 1, 2, 1, 1, 3, 1, 2, 4, 2, 7, 1, 6, 7, 1, 1, 1, 1, 2, 
      4, 1, 2, 1, 1, 3, 1, 2, 4, 7, 1, 6, 7, 1, 1, 1, 1, 2, 4, 1, 2, 1, 1, 3, 
      1, 2, 4, 7, 1, 6, 7, 1, 1, 1, 2, 1, 2, 4, 1, 2, 1, 1, 3, 1, 2, 4, 7, 1, 
      7, 1, 1, 1, 2, 2, 4, 1, 1, 2, 1, 1, 3, 1, 2, 4, 7, 1, 7, 1, 1, 1, 2, 2, 
      4, 6, 1, 1, 2, 1, 1, 3, 1, 2, 1, 7, 1, 1, 1, 2, 2, 4, 6, 11, 1, 1, 2, 
      1, 1, 3, 2, 1, 7, 1, 1, 1, 2, 2, 4, 11, 7, 1, 1, 2, 1, 1, 3, 2, 1, 7, 
      1, 1, 1, 2, 2, 4, 7, 10, 1, 1, 1, 2, 1, 1, 3, 2, 1, 7, 1, 1, 1, 2, 2, 
      4, 7, 1, 9, 2, 1, 1, 2, 1, 1, 3, 2, 1, 7, 1, 1, 1, 2, 2, 4, 1, 9, 2, 6, 
      1, 1, 1, 2, 1, 1, 3, 2, 1, 7, 1, 1, 1, 2, 4, 1, 9, 2, 6, 1, 1, 1, 1, 1, 
      2, 1, 1, 3, 2, 1, 7, 1, 1, 1, 2, 4, 1, 9, 2, 1, 1, 1, 5, 1, 1, 1, 2, 1, 
      1, 3, 2, 1, 1, 1, 1, 2, 4, 1, 9, 2, 1, 1, 1, 5, 1, 5, 2, 1, 1, 2, 1, 1, 
      2, 1, 1, 1, 1, 2, 4, 1, 9, 2, 1, 1, 1, 5, 1, 5, 5, 1, 1, 2, 1, 2, 1, 1, 
      1, 2, 4, 1, 9, 2, 1, 1, 1, 5, 1, 5, 5, 2, 1, 1, 2, 1, 2, 1, 1, 1, 2, 4, 
      1, 9, 2, 1, 1, 1, 5, 1, 5, 5, 1, 1, 1, 1, 2, 1, 2, 1, 1, 1, 4, 1, 9, 2, 
      1, 1, 1, 5, 1, 5, 1, 1, 7, 1, 1, 2, 1, 2, 1, 1, 1, 4, 1, 9, 2, 1, 1, 5, 
      1, 5, 1, 7, 2, 1, 1, 2, 1, 2, 1, 1, 1, 1, 2, 1, 1, 5, 1, 5, 1, 7, 2, 
      13, 1, 1, 2, 1, 2, 1, 1, 1, 1, 2, 1, 5, 1, 5, 1, 7, 13, 3, 1, 1, 1, 2, 
      1, 1, 1, 1, 2, 1, 5, 1, 5, 1, 7, 13, 3, 1, 1, 1, 1, 1, 2, 1, 1, 1, 1, 
      2, 1, 5, 1, 5, 1, 7, 3, 1, 1, 9, 4, 1, 1, 1, 2, 1, 1, 1, 1, 2, 1, 5, 1, 
      5, 1, 7, 1, 1, 9, 4, 1, 2, 1, 1, 1, 2, 1, 1, 1, 1, 2, 1, 5, 1, 5, 1, 7, 
      1, 1, 9, 4, 1, 1, 1, 1, 1, 1, 2, 1, 1, 1, 1, 2, 1, 5, 1, 5, 1, 7, 1, 1, 
      9, 1, 1, 1, 3, 1, 1, 1, 1, 2, 1, 1, 1, 1, 5, 1, 5, 1, 7, 1, 1, 9, 1, 1, 
      1, 3, 1, 3, 1, 1, 1, 2, 1, 1, 1, 1, 5, 1, 7, 1, 1, 9, 1, 1, 1, 3, 1, 3, 
      6, 1, 1, 1, 2, 1, 1, 1, 5, 7, 1, 1, 9, 1, 1, 1, 3, 1, 3, 6, 2, 1, 1, 1, 
      2, 1, 1, 5, 7, 1, 9, 1, 1, 1, 3, 1, 3, 6, 2, 2, 1, 1, 1, 2, 1, 1, 5, 7, 
      1, 9, 1, 1, 3, 1, 3, 6, 2, 3, 1, 1, 1, 2, 1, 1, 5, 7, 1, 1, 1, 3, 1, 3, 
      6, 2, 3, 2, 7, 1, 1, 1, 1, 1, 5, 7, 1, 1, 3, 1, 3, 6, 2, 3, 2, 7, 3, 1, 
      1, 1, 1, 1, 5, 7, 3, 1, 3, 6, 2, 3, 2, 7, 3, 2, 1, 1, 1, 1, 1, 5, 7, 3, 
      3, 2, 3, 2, 7, 3, 2, 7, 1, 1, 1, 1, 5, 7, 3, 2, 3, 2, 7, 3, 2, 7, 4, 1, 
      1, 1, 7, 3, 2, 3, 2, 7, 3, 2, 7, 4, 6, 1, 1, 1, 7, 3, 2, 3, 2, 7, 3, 2, 
      4, 6, 6, 1, 1, 1, 1, 7, 2, 3, 2, 7, 3, 2, 4, 6, 6, 1, 2, 1, 1, 1, 1, 7, 
      2, 3, 2, 7, 3, 4, 6, 6, 1, 2, 1, 1, 1, 1, 1, 1, 7, 2, 3, 2, 7, 4, 6, 6, 
      1, 2, 1, 1, 1, 1, 2, 1, 1, 1, 7, 2, 3, 2, 7, 6, 6, 1, 2, 1, 1, 1, 1, 2, 
      1, 3, 1, 1, 1, 7, 2, 3, 2, 7, 6, 1, 2, 1, 1, 1, 1, 2, 1, 7, 1, 1, 1, 7, 
      3, 2, 7, 6, 1, 2, 1, 1, 1, 2, 1, 7, 3, 1, 1, 1, 7, 3, 2, 6, 1, 2, 1, 1, 
      1, 2, 1, 7, 3, 3, 5, 1, 1, 1, 7, 3, 2, 6, 1, 2, 1, 1, 1, 2, 1, 7, 3, 3, 
      4, 1, 1, 1, 1, 7, 3, 2, 6, 1, 2, 1, 1, 1, 2, 1, 7, 3, 4, 1, 2, 1, 1, 1, 
      1, 7, 3, 6, 1, 2, 1, 1, 1, 2, 7, 3, 4, 1, 2, 1, 2, 1, 1, 7, 3, 6, 1, 2, 
      1, 1, 1, 2, 3, 4, 1, 2, 1, 2, 7, 1, 1, 7, 3, 1, 2, 1, 1, 1, 2, 3, 4, 1, 
      2, 1, 2, 7, 1, 5, 1, 1, 1, 2, 1, 1, 1, 2, 3, 4, 1, 2, 1, 2, 7, 1, 5, 
      10, 1, 1, 1, 2, 1, 1, 1, 2, 3, 4, 1, 1, 7, 1, 5, 10, 4, 1, 1, 1, 2, 1, 
      1, 1, 2, 4, 1, 7, 1, 5, 10, 4, 4, 1, 1, 1, 2, 1, 1, 1, 2, 4, 1, 7, 1, 
      5, 4, 4, 10, 1, 1, 1, 1, 2, 1, 1, 1, 2, 4, 1, 7, 1, 5, 4, 4, 1, 8, 2, 
      1, 1, 1, 2, 1, 1, 1, 2, 4, 1, 7, 1, 5, 4, 4, 1, 2, 6, 2, 1, 1, 1, 2, 1, 
      1, 1, 2, 4, 1, 1, 5, 4, 4, 1, 2, 6, 2, 6, 1, 1, 1, 1, 2, 1, 1, 1, 2, 4, 
      1, 1, 5, 4, 4, 1, 2, 6, 2, 1, 4, 3, 1, 1, 1, 1, 1, 2, 4, 1, 1, 5, 4, 4, 
      1, 2, 6, 2, 1, 4, 3, 3, 1, 1, 1, 1, 1, 2, 4, 1, 5, 4, 1, 2, 6, 2, 1, 4, 
      3, 3, 3, 1, 1, 1, 1, 1, 2, 4, 1, 4, 1, 2, 6, 2, 1, 4, 3, 3, 3, 3, 2, 1, 
      1, 1, 1, 1, 4, 1, 4, 1, 2, 6, 2, 1, 4, 3, 3, 3, 3, 4, 1, 1, 1, 1, 1, 4, 
      1, 4, 1, 2, 6, 2, 1, 4, 3, 3, 3, 4, 1, 2, 1, 1, 1, 1, 4, 1, 4, 1, 2, 6, 
      2, 1, 4, 3, 3, 4, 1, 2, 4, 1, 1, 4, 1, 4, 1, 2, 6, 2, 1, 4, 3, 3, 4, 1, 
      2, 4, 2, 1, 4, 1, 4, 1, 2, 6, 2, 1, 4, 3, 3, 4, 1, 2, 4, 2, 1, 1, 4, 1, 
      4, 1, 2, 6, 2, 1, 4, 3, 3, 4, 1, 2, 4, 2, 1, 2, 4, 1, 4, 1, 2, 6, 2, 1, 
      4, 3, 3, 4, 1, 2, 4, 1, 2, 1, 1, 4, 1, 4, 1, 2, 6, 2, 1, 3, 3, 4, 1, 2, 
      4, 1, 2, 1, 1, 1, 4, 4, 1, 4, 1, 2, 6, 2, 1, 3, 3, 4, 1, 2, 4, 1, 2, 1, 
      4, 2, 4, 1, 4, 1, 2, 6, 2, 1, 3, 3, 4, 1, 4, 1, 2, 1, 4, 3, 4, 1, 4, 1, 
      2, 6, 2, 1, 3, 3, 1, 4, 1, 2, 1, 4, 3, 2, 2, 4, 1, 4, 2, 6, 2, 1, 3, 1, 
      4, 1, 2, 1, 4, 3, 2, 2, 4, 4, 1, 4, 2, 6, 2, 1, 3, 1, 4, 1, 2, 1, 4, 3, 
      2, 6, 4, 1, 4, 2, 6, 2, 1, 1, 4, 1, 2, 1, 4, 3, 2, 6, 3, 1, 4, 1, 4, 2, 
      6, 2, 1, 1, 1, 2, 4, 3, 2, 6, 3, 1, 5, 4, 1, 2, 6, 2, 1, 1, 1, 2, 4, 3, 
      2, 6, 3, 1, 5, 4, 1, 4, 1, 2, 6, 2, 1, 1, 2, 4, 3, 2, 6, 3, 1, 5, 4, 1, 
      1, 1, 4, 1, 2, 6, 2, 1, 1, 2, 4, 3, 2, 6, 3, 5, 4, 1, 1, 2, 4, 1, 2, 6, 
      1, 1, 2, 4, 3, 2, 6, 3, 5, 4, 1, 1, 2, 1, 1, 1, 2, 6, 1, 1, 2, 4, 3, 2, 
      6, 3, 5, 4, 1, 1, 1, 1, 6, 1, 2, 6, 1, 1, 2, 4, 3, 2, 6, 3, 4, 1, 1, 1, 
      1, 6, 3, 2, 1, 2, 6, 1, 1, 2, 4, 3, 6, 3, 4, 1, 1, 1, 1, 6, 3, 2, 1, 1, 
      1, 2, 6, 1, 1, 2, 4, 3, 6, 3, 4, 1, 1, 1, 1, 6, 3, 2, 1, 1, 1, 1, 2, 6, 
      1, 2, 4, 6, 3, 4, 1, 1, 1, 1, 6, 3, 2, 1, 1, 1, 4, 1, 2, 6, 1, 2, 4, 6, 
      3, 4, 1, 1, 1, 1, 3, 2, 1, 1, 1, 4, 2, 4, 2, 6, 1, 2, 4, 6, 3, 4, 1, 1, 
      1, 1, 2, 1, 1, 1, 4, 2, 4, 4, 2, 6, 1, 2, 4, 6, 3, 4, 1, 1, 1, 1, 2, 1, 
      1, 1, 4, 2, 4, 3, 1, 2, 6, 1, 2, 4, 6, 4, 1, 1, 1, 2, 1, 1, 1, 4, 2, 4, 
      3, 1, 4, 2, 1, 4, 6, 4, 1, 1, 1, 2, 1, 1, 1, 4, 2, 4, 3, 1, 4, 8, 2, 1, 
      4, 4, 1, 1, 1, 2, 1, 1, 1, 4, 2, 4, 1, 4, 8, 9, 2, 1, 4, 1, 1, 2, 1, 1, 
      1, 4, 2, 4, 1, 4, 8, 9, 4, 1, 4, 1, 1, 2, 1, 1, 1, 4, 2, 4, 1, 4, 8, 9, 
      6, 1, 4, 1, 1, 2, 1, 1, 1, 4, 2, 4, 1, 4, 8, 9, 4, 2, 1, 4, 1, 1, 2, 1, 
      1, 1, 4, 2, 4, 1, 4, 8, 4, 2, 7, 3, 1, 4, 1, 1, 2, 1, 1, 1, 4, 2, 1, 4, 
      8, 4, 2, 7, 3, 2, 3, 1, 4, 1, 1, 2, 1, 1, 1, 4, 2, 1, 4, 4, 2, 7, 3, 2, 
      3, 7, 1, 1, 4, 1, 1, 2, 1, 1, 1, 2, 1, 4, 4, 2, 7, 3, 2, 3, 7, 5, 1, 4, 
      1, 1, 2, 1, 1, 1, 2, 1, 4, 4, 7, 3, 2, 3, 7, 5, 2, 1, 1, 1, 1, 2, 1, 1, 
      1, 2, 1, 4, 4, 7, 3, 2, 3, 7, 5, 2, 1, 1, 3, 1, 1, 1, 2, 1, 1, 1, 2, 1, 
      4, 7, 3, 2, 3, 7, 5, 2, 1, 1, 3, 2, 3, 1, 1, 1, 1, 1, 1, 2, 4, 7, 3, 2, 
      3, 7, 5, 2, 1, 1, 3, 2, 3, 3, 1, 1, 1, 1, 1, 2, 4, 7, 3, 2, 3, 5, 2, 1, 
      1, 3, 2, 3, 3, 8, 1, 1, 1, 1, 2, 4, 7, 3, 2, 3, 5, 2, 1, 3, 2, 3, 3, 8, 
      2, 1, 1, 1, 1, 2, 4, 7, 3, 2, 3, 5, 2, 3, 2, 3, 8, 2, 4, 1, 1, 1, 1, 4, 
      7, 3, 2, 3, 5, 3, 2, 3, 8, 2, 4, 4, 1, 1, 1, 1, 4, 7, 3, 2, 3, 5, 3, 2, 
      2, 4, 4, 11, 1, 1, 1, 1, 4, 7, 2, 3, 5, 2, 2, 4, 4, 11, 6, 1, 1, 1, 1, 
      4, 7, 2, 3, 5, 2, 4, 11, 6, 6, 1, 1, 1, 1, 4, 7, 2, 3, 2, 4, 11, 6, 6, 
      2, 3, 1, 1, 1, 4, 7, 2, 3, 2, 4, 11, 6, 6, 2, 4, 1, 1, 1, 4, 7, 2, 3, 
      2, 4, 11, 6, 2, 4, 4, 2, 1, 1, 1, 4, 7, 2, 3, 2, 4, 11, 6, 2, 4, 2, 3, 
      1, 1, 1, 1, 4, 2, 3, 2, 4, 11, 6, 2, 4, 2, 3, 1, 2, 5, 1, 1, 1, 4, 2, 
      3, 2, 4, 11, 2, 4, 2, 3, 1, 2, 5, 3, 3, 1, 1, 1, 4, 2, 3, 2, 4, 11, 2, 
      4, 2, 3, 1, 2, 3, 3, 4, 1, 1, 1, 1, 4, 2, 3, 2, 11, 2, 4, 3, 1, 2, 3, 
      3, 4, 1, 4, 1, 1, 1, 4, 2, 3, 2, 11, 2, 3, 1, 2, 3, 3, 4, 1, 4, 2, 2, 
      1, 1, 1, 4, 2, 3, 2, 2, 3, 1, 2, 3, 3, 4, 1, 4, 2, 12, 1, 1, 1, 4, 2, 
      3, 2, 2, 3, 1, 2, 3, 4, 4, 2, 12, 3, 1, 1, 1, 4, 2, 3, 2, 2, 3, 1, 3, 
      4, 2, 12, 3, 6, 1, 1, 1, 4, 2, 2, 2, 3, 1, 4, 2, 12, 3, 6, 6, 1, 1, 1, 
      4, 2, 2, 2, 3, 1, 2, 12, 6, 6, 7, 1, 1, 1, 4, 2, 2, 2, 3, 1, 2, 12, 6, 
      7, 3, 3, 1, 1, 1, 4, 2, 2, 2, 3, 1, 2, 6, 7, 3, 3, 11, 2, 1, 1, 1, 4, 
      2, 2, 2, 3, 1, 2, 6, 3, 3, 11, 2, 1, 6, 1, 1, 1, 4, 2, 2, 2, 3, 1, 2, 
      3, 3, 11, 2, 1, 6, 2, 4, 1, 1, 4, 2, 2, 3, 1, 2, 3, 3, 11, 2, 1, 6, 2, 
      4, 3, 1, 1, 4, 2, 2, 1, 2, 3, 3, 11, 2, 1, 6, 4, 3, 5, 1, 1, 4, 2, 2, 
      1, 3, 3, 11, 2, 1, 6, 4, 3, 5, 1, 1, 1, 1, 4, 2, 2, 1, 3, 3, 11, 1, 6, 
      4, 3, 5, 1, 1, 1, 2, 1, 1, 4, 2, 2, 1, 3, 11, 1, 6, 4, 3, 5, 1, 1, 2, 
      4, 1, 1, 4, 2, 2, 1, 3, 11, 1, 6, 4, 3, 1, 1, 2, 4, 3, 3, 1, 1, 2, 2, 
      1, 3, 1, 6, 4, 3, 1, 1, 2, 4, 3, 3, 9, 1, 1, 2, 2, 1, 3, 1, 6, 4, 3, 1, 
      1, 2, 4, 3, 9, 2, 1, 1, 1, 2, 3, 1, 6, 4, 3, 1, 1, 2, 4, 3, 9, 2, 1, 3, 
      1, 1, 2, 1, 6, 4, 3, 1, 1, 2, 4, 3, 9, 2, 1, 3, 2, 1, 1, 1, 2, 1, 6, 4, 
      1, 1, 2, 4, 3, 9, 2, 1, 3, 2, 1, 2, 1, 1, 1, 2, 1, 6, 4, 1, 1, 2, 3, 9, 
      2, 1, 3, 2, 1, 2, 1, 1, 3, 1, 1, 2, 1, 6, 4, 1, 1, 2, 3, 2, 1, 3, 2, 1, 
      2, 1, 1, 3, 6, 3, 1, 1, 2, 1, 6, 4, 1, 1, 2, 3, 2, 1, 3, 1, 2, 1, 1, 3, 
      3, 4, 1, 1, 2, 6, 4, 1, 1, 2, 3, 2, 1, 3, 1, 2, 1, 3, 3, 4, 2, 1, 1, 2, 
      6, 4, 1, 1, 2, 3, 2, 1, 1, 2, 1, 3, 3, 4, 2, 1, 3, 1, 2, 6, 4, 1, 1, 2, 
      3, 2, 1, 1, 2, 1, 3, 3, 4, 2, 1, 3, 1, 1, 1, 2, 6, 4, 1, 1, 2, 3, 2, 1, 
      2, 1, 3, 3, 4, 1, 3, 1, 1, 3, 1, 2, 6, 4, 1, 1, 2, 3, 2, 1, 2, 1, 3, 4, 
      1, 3, 1, 1, 3, 2, 1, 1, 2, 6, 4, 1, 2, 3, 2, 1, 1, 3, 4, 1, 3, 1, 1, 3, 
      2, 1, 3, 1, 2, 6, 4, 1, 2, 2, 1, 1, 3, 4, 1, 3, 1, 1, 3, 2, 3, 4, 1, 2, 
      1, 2, 2, 1, 1, 3, 4, 1, 3, 1, 1, 3, 2, 3, 4, 10, 1, 2, 1, 2, 2, 1, 1, 
      3, 1, 3, 1, 1, 3, 2, 3, 4, 10, 3, 2, 1, 2, 1, 2, 2, 1, 3, 1, 3, 1, 1, 
      3, 2, 3, 4, 10, 3, 2, 1, 1, 1, 2, 1, 2, 2, 1, 3, 1, 3, 1, 1, 3, 2, 3, 
      4, 10, 2, 1, 1, 2, 2, 1, 2, 1, 2, 2, 1, 3, 1, 3, 1, 1, 3, 2, 3, 4, 10, 
      1, 1, 2, 2, 1, 1, 1, 2, 1, 2, 2, 1, 3, 1, 3, 1, 1, 2, 3, 4, 10, 1, 2, 
      2, 1, 1, 4, 1, 2, 1, 2, 1, 3, 1, 3, 1, 1, 3, 4, 10, 1, 2, 2, 1, 1, 4, 
      4, 1, 2, 1, 2, 1, 3, 1, 1, 1, 3, 4, 10, 1, 2, 2, 1, 1, 4, 4, 2, 1, 1, 
      2, 1, 2, 1, 3, 1, 1, 1, 4, 10, 1, 2, 2, 1, 4, 4, 2, 1, 3, 1, 2, 1, 2, 
      1, 3, 1, 1, 1, 4, 10, 1, 2, 4, 4, 2, 1, 3, 2, 1, 2, 1, 2, 1, 3, 1, 1, 
      1, 4, 10, 1, 2, 4, 2, 1, 3, 2, 2, 2, 1, 2, 1, 2, 1, 3, 1, 1, 1, 4, 10, 
      1, 2, 2, 1, 3, 2, 2, 2, 2, 3, 1, 2, 1, 2, 3, 1, 1, 1, 4, 10, 1, 2, 2, 
      1, 2, 2, 2, 2, 3, 4, 1, 2, 1, 2, 3, 1, 1, 4, 10, 1, 2, 2, 2, 2, 2, 2, 
      3, 4, 2, 1, 2, 1, 2, 3, 1, 1, 4, 1, 2, 2, 2, 2, 2, 2, 3, 4, 2, 1, 9, 1, 
      2, 1, 2, 3, 1, 1, 4, 1, 2, 2, 2, 2, 2, 4, 2, 1, 9, 4, 1, 2, 1, 2, 3, 1, 
      1, 4, 1, 2, 2, 2, 2, 4, 2, 1, 9, 4, 2, 1, 1, 2, 1, 2, 3, 1, 1, 4, 1, 2, 
      2, 2, 2, 4, 2, 1, 9, 2, 1, 1, 3, 1, 2, 1, 2, 3, 1, 1, 4, 1, 2, 2, 2, 2, 
      4, 2, 1, 9, 2, 1, 1, 1, 2, 1, 2, 1, 2, 3, 1, 1, 4, 1, 2, 2, 2, 2, 2, 1, 
      9, 2, 1, 1, 1, 2, 3, 1, 1, 2, 1, 2, 3, 1, 1, 4, 1, 2, 2, 2, 2, 2, 1, 9, 
      2, 1, 1, 1, 3, 1, 1, 1, 1, 2, 1, 2, 3, 1, 1, 4, 1, 2, 2, 2, 2, 1, 9, 2, 
      1, 1, 1, 3, 1, 1, 3, 1, 2, 1, 2, 3, 1, 4, 1, 2, 2, 2, 1, 9, 2, 1, 1, 1, 
      3, 1, 1, 3, 3, 1, 2, 1, 2, 3, 1, 4, 1, 2, 2, 2, 1, 9, 2, 1, 1, 1, 3, 1, 
      1, 3, 1, 2, 1, 2, 1, 2, 3, 1, 4, 1, 2, 2, 1, 9, 2, 1, 1, 1, 3, 1, 1, 3, 
      1, 2, 1, 1, 1, 2, 1, 2, 3, 1, 4, 1, 2, 2, 1, 9, 2, 1, 1, 1, 3, 1, 1, 3, 
      1, 1, 1, 1, 1, 1, 2, 1, 2, 3, 1, 4, 1, 2, 2, 1, 9, 2, 1, 1, 1, 3, 1, 1, 
      1, 1, 1, 1, 1, 2, 1, 1, 2, 1, 2, 3, 1, 4, 1, 2, 1, 9, 2, 1, 1, 1, 3, 1, 
      1, 1, 1, 1, 1, 2, 1, 3, 1, 2, 1, 2, 3, 1, 4, 2, 1, 9, 2, 1, 1, 1, 3, 1, 
      1, 1, 1, 1, 2, 1, 3, 2, 1, 2, 2, 3, 1, 4, 2, 1, 9, 2, 1, 1, 1, 3, 1, 1, 
      1, 1, 1, 1, 3, 2, 3, 1, 2, 2, 3, 1, 2, 1, 9, 2, 1, 1, 1, 3, 1, 1, 1, 1, 
      1, 3, 2, 3, 5, 1, 2, 2, 3, 1, 2, 1, 9, 2, 1, 1, 1, 3, 1, 1, 1, 1, 1, 3, 
      2, 3, 3, 2, 1, 2, 2, 3, 1, 2, 1, 9, 2, 1, 1, 1, 3, 1, 1, 1, 1, 1, 3, 3, 
      3, 2, 1, 1, 1, 2, 2, 3, 1, 2, 1, 9, 2, 1, 1, 3, 1, 1, 1, 1, 3, 3, 3, 2, 
      1, 1, 2, 1, 2, 2, 3, 1, 2, 1, 2, 1, 1, 3, 1, 1, 1, 1, 3, 3, 3, 2, 1, 1, 
      2, 3, 6, 1, 2, 2, 3, 1, 2, 1, 2, 1, 1, 3, 1, 1, 1, 1, 3, 3, 3, 2, 1, 1, 
      2, 3, 4, 3, 1, 2, 2, 3, 1, 2, 1, 2, 1, 1, 3, 1, 1, 1, 1, 3, 3, 3, 2, 1, 
      2, 3, 4, 3, 1, 1, 1, 2, 2, 3, 1, 2, 1, 2, 1, 1, 3, 1, 1, 1, 1, 3, 3, 2, 
      1, 2, 3, 4, 3, 1, 1, 3, 1, 1, 2, 2, 3, 2, 1, 2, 1, 1, 3, 1, 1, 1, 1, 3, 
      3, 2, 1, 2, 3, 4, 1, 1, 3, 1, 4, 1, 2, 2, 2, 1, 2, 1, 3, 1, 1, 1, 1, 3, 
      3, 2, 1, 2, 3, 4, 1, 1, 3, 1, 4, 4, 1, 2, 2, 2, 1, 2, 1, 3, 1, 1, 1, 1, 
      3, 3, 2, 1, 2, 3, 4, 1, 1, 3, 1, 4, 1, 3, 1, 2, 2, 1, 2, 1, 3, 1, 1, 1, 
      1, 3, 3, 2, 2, 3, 4, 1, 1, 3, 1, 4, 1, 3, 3, 1, 2, 2, 1, 2, 1, 3, 1, 1, 
      1, 1, 3, 3, 2, 2, 3, 1, 1, 3, 1, 4, 1, 3, 6, 1, 2, 2, 1, 2, 1, 1, 1, 1, 
      1, 3, 3, 2, 2, 3, 1, 1, 3, 1, 4, 1, 3, 6, 2, 2, 1, 2, 2, 1, 2, 1, 1, 1, 
      1, 1, 3, 3, 2, 2, 3, 1, 1, 1, 4, 1, 3, 6, 2, 2, 2, 1, 1, 2, 2, 1, 2, 1, 
      1, 1, 1, 1, 3, 3, 2, 2, 3, 1, 1, 4, 3, 6, 2, 2, 2, 1, 2, 1, 2, 2, 1, 2, 
      1, 1, 1, 1, 1, 3, 3, 2, 2, 3, 1, 4, 3, 6, 2, 2, 2, 1, 2, 1, 1, 1, 2, 2, 
      1, 2, 1, 1, 1, 1, 3, 3, 2, 2, 3, 1, 4, 3, 2, 2, 2, 1, 2, 1, 1, 7, 1, 2, 
      2, 1, 2, 1, 1, 1, 1, 3, 2, 2, 3, 1, 4, 3, 2, 2, 2, 1, 2, 1, 1, 7, 2, 1, 
      1, 2, 2, 1, 2, 1, 1, 1, 1, 3, 2, 2, 3, 1, 4, 3, 2, 2, 2, 1, 1, 1, 7, 2, 
      1, 1, 1, 2, 2, 1, 2, 1, 1, 1, 1, 3, 2, 2, 3, 1, 3, 2, 2, 2, 1, 1, 1, 7, 
      2, 1, 1, 1, 4, 2, 1, 2, 1, 1, 1, 1, 3, 2, 2, 3, 1, 3, 2, 2, 2, 1, 1, 1, 
      7, 2, 1, 1, 4, 3, 2, 1, 2, 1, 1, 1, 1, 3, 2, 2, 3, 1, 3, 2, 1, 1, 1, 7, 
      2, 1, 1, 4, 3, 3, 2, 1, 2, 1, 1, 1, 1, 3, 2, 2, 3, 1, 3, 2, 1, 1, 1, 7, 
      2, 1, 1, 4, 3, 3, 1, 2, 1, 1, 1, 1, 1, 3, 2, 2, 3, 1, 3, 2, 1, 1, 1, 7, 
      1, 1, 4, 3, 3, 1, 4, 2, 1, 1, 1, 1, 1, 3, 2, 3, 1, 3, 2, 1, 1, 1, 7, 1, 
      1, 4, 3, 3, 1, 4, 1, 1, 2, 1, 1, 1, 1, 1, 3, 2, 3, 1, 3, 2, 1, 1, 1, 1, 
      1, 4, 3, 3, 1, 4, 1, 1, 1, 6, 2, 1, 1, 1, 1, 1, 3, 2, 3, 1, 3, 2, 1, 1, 
      1, 1, 1, 4, 3, 3, 1, 1, 1, 1, 6, 1, 3, 2, 1, 1, 1, 1, 3, 3, 1, 3, 2, 1, 
      1, 1, 1, 1, 4, 3, 3, 1, 1, 1, 1, 6, 1, 3, 3, 2, 1, 1, 1, 1, 3, 3, 1, 3, 
      2, 1, 1, 1, 1, 1, 4, 3, 3, 1, 1, 6, 1, 3, 3, 2, 2, 1, 1, 1, 1, 3, 3, 1, 
      3, 2, 1, 1, 1, 1, 4, 3, 3, 1, 6, 1, 3, 3, 2, 2, 2, 1, 1, 1, 1, 3, 1, 3, 
      2, 1, 1, 1, 1, 4, 3, 1, 6, 1, 3, 3, 2, 2, 6, 2, 1, 1, 1, 1, 3, 1, 3, 1, 
      1, 1, 1, 4, 3, 1, 6, 1, 3, 2, 2, 6, 5, 2, 1, 1, 1, 3, 3, 1, 1, 1, 1, 4, 
      3, 1, 6, 1, 3, 2, 2, 6, 5, 2, 2, 1, 1, 1, 3, 1, 1, 1, 1, 4, 3, 1, 6, 1, 
      3, 2, 2, 6, 5, 2, 1, 2, 2, 1, 1, 1, 3, 1, 1, 1, 4, 3, 1, 6, 1, 3, 2, 2, 
      5, 2, 1, 2, 7, 2, 1, 1, 1, 3, 1, 4, 3, 1, 6, 1, 3, 2, 2, 5, 2, 1, 2, 7, 
      2, 2, 1, 1, 1, 3, 1, 4, 3, 1, 6, 1, 3, 2, 5, 1, 2, 7, 2, 3, 2, 1, 1, 1, 
      3, 1, 4, 3, 1, 6, 1, 3, 2, 1, 2, 7, 2, 3, 3, 2, 2, 1, 1, 1, 3, 1, 4, 3, 
      1, 6, 1, 3, 2, 1, 2, 7, 2, 3, 2, 2, 1, 2, 1, 1, 1, 3, 1, 3, 1, 1, 3, 2, 
      1, 2, 7, 2, 3, 2, 2, 1, 6, 2, 1, 1, 3, 1, 3, 1, 1, 3, 2, 1, 2, 7, 2, 3, 
      2, 2, 1, 7, 2, 1, 1, 3, 1, 3, 1, 1, 3, 1, 2, 7, 2, 3, 2, 2, 1, 7, 1, 1, 
      2, 1, 1, 3, 1, 3, 1, 1, 3, 1, 2, 2, 3, 2, 2, 1, 7, 1, 1, 3, 4, 2, 1, 1, 
      3, 1, 3, 1, 1, 3, 1, 2, 3, 2, 2, 1, 7, 1, 1, 4, 5, 2, 1, 1, 3, 1, 3, 1, 
      1, 3, 2, 3, 2, 2, 1, 7, 1, 4, 5, 2, 2, 1, 1, 3, 1, 3, 1, 1, 3, 2, 3, 2, 
      2, 1, 1, 4, 5, 2, 6, 1, 1, 1, 3, 1, 3, 1, 1, 3, 2, 3, 2, 1, 1, 4, 5, 2, 
      6, 1, 4, 1, 1, 3, 1, 1, 1, 3, 2, 3, 2, 1, 1, 4, 5, 2, 6, 1, 4, 2, 1, 1, 
      1, 3, 1, 1, 1, 3, 2, 3, 2, 1, 1, 4, 5, 6, 1, 4, 2, 1, 1, 1, 1, 1, 3, 1, 
      1, 1, 3, 2, 3, 2, 1, 1, 4, 5, 1, 4, 1, 1, 1, 8, 1, 1, 3, 1, 1, 1, 3, 2, 
      3, 2, 1, 1, 4, 5, 1, 4, 1, 1, 1, 1, 7, 1, 1, 3, 1, 1, 1, 3, 2, 3, 2, 1, 
      1, 4, 1, 4, 1, 1, 1, 7, 6, 1, 1, 3, 1, 1, 1, 3, 2, 3, 2, 1, 4, 1, 4, 1, 
      1, 7, 6, 2, 1, 3, 1, 1, 1, 3, 2, 2, 1, 4, 1, 4, 1, 1, 7, 6, 2, 4, 3, 1, 
      1, 1, 3, 2, 1, 4, 1, 4, 1, 1, 7, 6, 2, 4, 3, 3, 1, 1, 1, 3, 2, 1, 4, 1, 
      4, 1, 1, 7, 6, 2, 3, 1, 3}\)], "Output",
  CellLabel->"Out[328]="]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    \(bc = BinCounts[nsegs, {0, 19}]\)], "Input",
  CellLabel->"In[330]:="],

Cell[BoxData[
    \({21987, 12854, 8132, 5279, 3030, 2004, 1308, 940, 500, 293, 119, 119, 
      26, 57, 8, 7, 11, 0, 11}\)], "Output",
  CellLabel->"Out[330]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(BarChart[bc, PlotRange -> {{0, 20}, {0, 25000}}];\)\)], "Input",
  CellLabel->"In[332]:="],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-2.77556e-17 0.05 0 2.47214e-05 [
[.05 -0.0125 -3 -9 ]
[.05 -0.0125 3 0 ]
[.1 -0.0125 -3 -9 ]
[.1 -0.0125 3 0 ]
[.15 -0.0125 -3 -9 ]
[.15 -0.0125 3 0 ]
[.2 -0.0125 -3 -9 ]
[.2 -0.0125 3 0 ]
[.25 -0.0125 -3 -9 ]
[.25 -0.0125 3 0 ]
[.3 -0.0125 -3 -9 ]
[.3 -0.0125 3 0 ]
[.35 -0.0125 -3 -9 ]
[.35 -0.0125 3 0 ]
[.4 -0.0125 -3 -9 ]
[.4 -0.0125 3 0 ]
[.45 -0.0125 -3 -9 ]
[.45 -0.0125 3 0 ]
[.5 -0.0125 -6 -9 ]
[.5 -0.0125 6 0 ]
[.55 -0.0125 -6 -9 ]
[.55 -0.0125 6 0 ]
[.6 -0.0125 -6 -9 ]
[.6 -0.0125 6 0 ]
[.65 -0.0125 -6 -9 ]
[.65 -0.0125 6 0 ]
[.7 -0.0125 -6 -9 ]
[.7 -0.0125 6 0 ]
[.75 -0.0125 -6 -9 ]
[.75 -0.0125 6 0 ]
[.8 -0.0125 -6 -9 ]
[.8 -0.0125 6 0 ]
[.85 -0.0125 -6 -9 ]
[.85 -0.0125 6 0 ]
[.9 -0.0125 -6 -9 ]
[.9 -0.0125 6 0 ]
[.95 -0.0125 -6 -9 ]
[.95 -0.0125 6 0 ]
[.0075 .12361 -24 -4.5 ]
[.0075 .12361 0 4.5 ]
[.0075 .24721 -30 -4.5 ]
[.0075 .24721 0 4.5 ]
[.0075 .37082 -30 -4.5 ]
[.0075 .37082 0 4.5 ]
[.0075 .49443 -30 -4.5 ]
[.0075 .49443 0 4.5 ]
[.0075 .61803 -30 -4.5 ]
[.0075 .61803 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.05 0 m
.05 .00625 L
s
[(1)] .05 -0.0125 0 1 Mshowa
.1 0 m
.1 .00625 L
s
[(2)] .1 -0.0125 0 1 Mshowa
.15 0 m
.15 .00625 L
s
[(3)] .15 -0.0125 0 1 Mshowa
.2 0 m
.2 .00625 L
s
[(4)] .2 -0.0125 0 1 Mshowa
.25 0 m
.25 .00625 L
s
[(5)] .25 -0.0125 0 1 Mshowa
.3 0 m
.3 .00625 L
s
[(6)] .3 -0.0125 0 1 Mshowa
.35 0 m
.35 .00625 L
s
[(7)] .35 -0.0125 0 1 Mshowa
.4 0 m
.4 .00625 L
s
[(8)] .4 -0.0125 0 1 Mshowa
.45 0 m
.45 .00625 L
s
[(9)] .45 -0.0125 0 1 Mshowa
.5 0 m
.5 .00625 L
s
[(10)] .5 -0.0125 0 1 Mshowa
.55 0 m
.55 .00625 L
s
[(11)] .55 -0.0125 0 1 Mshowa
.6 0 m
.6 .00625 L
s
[(12)] .6 -0.0125 0 1 Mshowa
.65 0 m
.65 .00625 L
s
[(13)] .65 -0.0125 0 1 Mshowa
.7 0 m
.7 .00625 L
s
[(14)] .7 -0.0125 0 1 Mshowa
.75 0 m
.75 .00625 L
s
[(15)] .75 -0.0125 0 1 Mshowa
.8 0 m
.8 .00625 L
s
[(16)] .8 -0.0125 0 1 Mshowa
.85 0 m
.85 .00625 L
s
[(17)] .85 -0.0125 0 1 Mshowa
.9 0 m
.9 .00625 L
s
[(18)] .9 -0.0125 0 1 Mshowa
.95 0 m
.95 .00625 L
s
[(19)] .95 -0.0125 0 1 Mshowa
0 0 m
1 0 L
s
.02 .12361 m
.02625 .12361 L
s
[(5000)] .0075 .12361 1 0 Mshowa
.02 .24721 m
.02625 .24721 L
s
[(10000)] .0075 .24721 1 0 Mshowa
.02 .37082 m
.02625 .37082 L
s
[(15000)] .0075 .37082 1 0 Mshowa
.02 .49443 m
.02625 .49443 L
s
[(20000)] .0075 .49443 1 0 Mshowa
.02 .61803 m
.02625 .61803 L
s
[(25000)] .0075 .61803 1 0 Mshowa
.125 Mabswid
.02 .02472 m
.02375 .02472 L
s
.02 .04944 m
.02375 .04944 L
s
.02 .07416 m
.02375 .07416 L
s
.02 .09889 m
.02375 .09889 L
s
.02 .14833 m
.02375 .14833 L
s
.02 .17305 m
.02375 .17305 L
s
.02 .19777 m
.02375 .19777 L
s
.02 .22249 m
.02375 .22249 L
s
.02 .27193 m
.02375 .27193 L
s
.02 .29666 m
.02375 .29666 L
s
.02 .32138 m
.02375 .32138 L
s
.02 .3461 m
.02375 .3461 L
s
.02 .39554 m
.02375 .39554 L
s
.02 .42026 m
.02375 .42026 L
s
.02 .44498 m
.02375 .44498 L
s
.02 .46971 m
.02375 .46971 L
s
.02 .51915 m
.02375 .51915 L
s
.02 .54387 m
.02375 .54387 L
s
.02 .56859 m
.02375 .56859 L
s
.02 .59331 m
.02375 .59331 L
s
.25 Mabswid
.02 0 m
.02 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
1 0 0 r
.03 0 m
.03 .54355 L
.07 .54355 L
.07 0 L
F
0 g
.5 Mabswid
.03 0 m
.03 .54355 L
.07 .54355 L
.07 0 L
.03 0 L
s
1 0 0 r
.08 0 m
.08 .31777 L
.12 .31777 L
.12 0 L
F
0 g
.08 0 m
.08 .31777 L
.12 .31777 L
.12 0 L
.08 0 L
s
1 0 0 r
.13 0 m
.13 .20103 L
.17 .20103 L
.17 0 L
F
0 g
.13 0 m
.13 .20103 L
.17 .20103 L
.17 0 L
.13 0 L
s
1 0 0 r
.18 0 m
.18 .1305 L
.22 .1305 L
.22 0 L
F
0 g
.18 0 m
.18 .1305 L
.22 .1305 L
.22 0 L
.18 0 L
s
1 0 0 r
.23 0 m
.23 .07491 L
.27 .07491 L
.27 0 L
F
0 g
.23 0 m
.23 .07491 L
.27 .07491 L
.27 0 L
.23 0 L
s
1 0 0 r
.28 0 m
.28 .04954 L
.32 .04954 L
.32 0 L
F
0 g
.28 0 m
.28 .04954 L
.32 .04954 L
.32 0 L
.28 0 L
s
1 0 0 r
.33 0 m
.33 .03234 L
.37 .03234 L
.37 0 L
F
0 g
.33 0 m
.33 .03234 L
.37 .03234 L
.37 0 L
.33 0 L
s
1 0 0 r
.38 0 m
.38 .02324 L
.42 .02324 L
.42 0 L
F
0 g
.38 0 m
.38 .02324 L
.42 .02324 L
.42 0 L
.38 0 L
s
1 0 0 r
.43 0 m
.43 .01236 L
.47 .01236 L
.47 0 L
F
0 g
.43 0 m
.43 .01236 L
.47 .01236 L
.47 0 L
.43 0 L
s
1 0 0 r
.48 0 m
.48 .00724 L
.52 .00724 L
.52 0 L
F
0 g
.48 0 m
.48 .00724 L
.52 .00724 L
.52 0 L
.48 0 L
s
1 0 0 r
.53 0 m
.53 .00294 L
.57 .00294 L
.57 0 L
F
0 g
.53 0 m
.53 .00294 L
.57 .00294 L
.57 0 L
.53 0 L
s
1 0 0 r
.58 0 m
.58 .00294 L
.62 .00294 L
.62 0 L
F
0 g
.58 0 m
.58 .00294 L
.62 .00294 L
.62 0 L
.58 0 L
s
1 0 0 r
.63 0 m
.63 .00064 L
.67 .00064 L
.67 0 L
F
0 g
.63 0 m
.63 .00064 L
.67 .00064 L
.67 0 L
.63 0 L
s
1 0 0 r
.68 0 m
.68 .00141 L
.72 .00141 L
.72 0 L
F
0 g
.68 0 m
.68 .00141 L
.72 .00141 L
.72 0 L
.68 0 L
s
1 0 0 r
.73 0 m
.73 .0002 L
.77 .0002 L
.77 0 L
F
0 g
.73 0 m
.73 .0002 L
.77 .0002 L
.77 0 L
.73 0 L
s
1 0 0 r
.78 0 m
.78 .00017 L
.82 .00017 L
.82 0 L
F
0 g
.78 0 m
.78 .00017 L
.82 .00017 L
.82 0 L
.78 0 L
s
1 0 0 r
.83 0 m
.83 .00027 L
.87 .00027 L
.87 0 L
F
0 g
.83 0 m
.83 .00027 L
.87 .00027 L
.87 0 L
.83 0 L
s
1 0 0 r
.88 0 m
.88 0 L
.92 0 L
.92 0 L
F
0 g
.88 0 m
.88 0 L
.92 0 L
.92 0 L
.88 0 L
s
1 0 0 r
.93 0 m
.93 .00027 L
.97 .00027 L
.97 0 L
F
0 g
.93 0 m
.93 .00027 L
.97 .00027 L
.97 0 L
.93 0 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[332]:=",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/B000`400?l00000o`00003oo`3ooolQ
0?ooo`009`3oool3000000P0oooo1@0000090?ooo`<000002`3oool3000000T0oooo0`00000:0?oo
o`<000002`3oool00`000000oooo0?ooo`090?ooo`<000002P3oool2000000P0oooo0`0000040?oo
o`800000103oool3000000<0oooo0`0000040?ooo`<000000P3oool5000000<0oooo0`0000030?oo
o`<00000103oool3000000@0oooo0`0000030?ooo`<000000`3oool3000000@0oooo0`0000030?oo
o`<00000103oool3000000@0oooo00<000000?ooo`3oool00`3oool3000000<0oooo0`0000040?oo
o`<000000`3oool2000000/0oooo000X0?ooo`030000003oool0oooo00P0oooo00@000000?ooo`3o
ool00000203oool01@000000oooo0?ooo`3oool0000000/0oooo00<000000?ooo`3oool01`3oool0
1@000000oooo0?ooo`3oool0000000P0oooo00D000000?ooo`3oool0oooo0000000:0?ooo`030000
003oool0oooo00P0oooo00D000000?ooo`3oool0oooo0000000;0?ooo`030000003oool0oooo00H0
oooo00<000000?ooo`3oool00P3oool010000000oooo0?ooo`0000040?ooo`030000003oool0oooo
00<0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`020?ooo`040000003oool0oooo
000000@0oooo00D000000?ooo`3oool0oooo000000030?ooo`030000003oool0oooo0080oooo00<0
00000?ooo`3oool0103oool00`000000oooo0?ooo`030?ooo`050000003oool0oooo0?ooo`000000
0`3oool00`000000oooo0?ooo`020?ooo`050000003oool0oooo0?ooo`0000000`3oool00`000000
oooo0?ooo`020?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0103oool01@000000
oooo0?ooo`3oool0000000<0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`040?oo
o`030000003oool0oooo00P0oooo000X0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3o
ool0303oool00`000000oooo0?ooo`060?ooo`D00000303oool00`000000oooo0?ooo`060?ooo`05
0000003oool0oooo0?ooo`0000002`3oool00`000000oooo0?ooo`070?ooo`050000003oool0oooo
0?ooo`000000303oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo0080oooo00@00000
0?ooo`3oool00000103oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00@0oooo00<0
00000?ooo`3oool00`3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00D0oooo00<0
00000?ooo`3oool00P3oool010000000oooo0?ooo`3oool5000000@0oooo00<000000?ooo`3oool0
1@3oool00`000000oooo0?ooo`020?ooo`050000003oool0oooo0?ooo`0000000`3oool00`000000
oooo0?ooo`020?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool00`3oool01@000000
oooo0?ooo`3oool0000000<0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`050?oo
o`030000003oool0oooo00L0oooo000X0?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3o
ool02@3oool2000000T0oooo00@000000?ooo`3oool000003@3oool00`000000oooo0?ooo`060?oo
o`@00000303oool00`000000oooo0?ooo`080?ooo`<000002P3oool4000000L0oooo00<000000?oo
o`3oool00P3oool010000000oooo0?ooo`0000040?ooo`030000003oool0oooo00<0oooo00<00000
0?ooo`3oool0103oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00<0oooo00<00000
0?ooo`3oool00`3oool2000000D0oooo00D000000?ooo`3oool0oooo000000020?ooo`030000003o
ool0oooo00<0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`020?ooo`040000003o
ool0oooo0?ooo`@000001@3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00<0oooo
00<000000?ooo`3oool00P3oool3000000D0oooo00<000000?ooo`3oool00P3oool4000000T0oooo
000X0?ooo`030000003oool0oooo00L0oooo00D000000?ooo`3oool0oooo0000000<0?ooo`030000
003oool0oooo00L0oooo00<000000?ooo`0000002@3oool4000000T0oooo00<000000?ooo`3oool0
3P3oool00`000000oooo0?ooo`060?ooo`050000003oool0oooo0?ooo`000000203oool01@000000
oooo0?ooo`3oool0000000L0oooo00<000000?ooo`3oool00P3oool010000000oooo0?ooo`000004
0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0103oool01@000000oooo0?ooo`3o
ool0000000<0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`050?ooo`030000003o
ool0oooo0080oooo00<000000?ooo`3oool00P3oool00`000000oooo000000050?ooo`040000003o
ool0oooo0?ooo`@000001@3oool01@000000oooo0?ooo`3oool0000000P0oooo00<000000?ooo`3o
ool01@3oool00`000000oooo0?ooo`020?ooo`050000003oool0oooo0?ooo`0000000`3oool00`00
0000oooo0?ooo`020?ooo`050000003oool0oooo0?ooo`0000000`3oool00`000000oooo0?ooo`07
0?ooo`009`3oool2000000T0oooo00D000000?ooo`3oool0oooo000000080?ooo`050000003oool0
oooo0?ooo`0000002P3oool2000000T0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?oo
o`090?ooo`050000003oool0oooo0?ooo`000000203oool01@000000oooo0?ooo`3oool0000000P0
oooo00D000000?ooo`3oool0oooo000000060?ooo`800000103oool010000000oooo0?ooo`000003
0?ooo`800000103oool2000000D0oooo0P0000030?ooo`050000003oool0oooo0?ooo`0000000`3o
ool2000000<0oooo00D000000?ooo`3oool0oooo000000030?ooo`8000001@3oool2000000@0oooo
0P0000030?ooo`030000003oool0oooo00D0oooo0P0000040?ooo`030000003oool0oooo00@0oooo
0P0000030?ooo`050000003oool0oooo0?ooo`0000000`3oool2000000<0oooo00D000000?ooo`3o
ool0oooo000000030?ooo`8000000`3oool01@000000oooo0?ooo`3oool0000000T0oooo000X0?oo
o`030000003oool0oooo00P0oooo0`00000:0?ooo`<00000303oool00`000000oooo0?ooo`070?oo
o`D000002P3oool2000000T0oooo1@0000090?ooo`<000002P3oool3000000P0oooo00<000000?oo
o`3oool00`3oool2000000D0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`040?oo
o`030000003oool0oooo0080oooo0`0000050?ooo`030000003oool0oooo0080oooo0`0000050?oo
o`030000003oool0oooo00@0oooo00<000000?ooo`3oool00`3oool010000000oooo0?ooo`3oool5
000000@0oooo00<000000?ooo`3oool00`3oool2000000D0oooo00@000000?ooo`3oool0oooo1@00
00040?ooo`030000003oool0oooo0080oooo0`0000050?ooo`030000003oool0oooo0080oooo0`00
000:0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00703o
oooo000000D00000000Q0?ooo`030000003oool0000000X0o`0000<000000?ooo`0000002P3o0000
0`000000oooo0000000:0?l000030000003oool0000000X0o`0000<000000?ooo`0000002@3o0000
10000000oooo0?ooo`0000090?l000040000003oool0oooo000000T0o`0000@000000?ooo`3oool0
00002@3o000010000000oooo0?ooo`0000090?l000040000003oool0oooo000000T0o`0000<00000
0?ooo`3oool02`0000020?ooo`/000001`3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0
oooo00X0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0
oooo00X0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`0;0?ooo`008@3oool00`00
0000oooo0000000:0?l000030000003oool0000000X0o`0000<000000?ooo`0000002P3o00000`00
0000oooo0000000:0?l000030000003oool0000000T0o`0000@000000?ooo`3oool000002@3o0000
10000000oooo0?ooo`0000090?l000040000003oool0oooo000000T0o`0000@000000?ooo`3oool0
00002@3o00000`000000oooo0?ooo`0;000007d0oooo000Q0?ooo`030000003oool0000000X0o`00
00<000000?ooo`0000002P3o00000`000000oooo0000000:0?l000030000003oool0000000X0o`00
00<000000?ooo`0000002@3o000010000000oooo0?ooo`0000090?l000040000003oool0oooo0000
00T0o`0000@000000?ooo`3oool000002@3o00000`000000oooo0?ooo`0;000008X0oooo000Q0?oo
o`030000003oool0000000X0o`0000<000000?ooo`0000002P3o00000`000000oooo0000000:0?l0
00030000003oool0000000X0o`0000<000000?ooo`0000002@3o000010000000oooo0?ooo`000009
0?l000040000003oool0oooo000000T0o`0000@000000?ooo`3oool000002@3o00000`000000oooo
0?ooo`2E0?ooo`008@3oool00`000000oooo0000000:0?l000030000003oool0000000X0o`0000<0
00000?ooo`0000002P3o00000`000000oooo0000000:0?l000030000003oool0000000T0o`0000@0
00000?ooo`3oool000002@3o000010000000oooo0?ooo`0000090?l000040000003oool0oooo0000
00T0o`0000<000000?ooo`3oool0U@3oool00240oooo0`00000:0?l000030000003oool0000000X0
o`0000<000000?ooo`0000002P3o00000`000000oooo0000000:0?l000030000003oool0000000T0
o`0000@000000?ooo`3oool000002@3o000010000000oooo0?ooo`0000090?l000030000003oool0
oooo00/00000U`3oool00240oooo00<000000?ooo`0000002P3o00000`000000oooo0000000:0?l0
00030000003oool0000000X0o`0000<000000?ooo`0000002P3o00000`000000oooo000000090?l0
00040000003oool0oooo000000T0o`0000@000000?ooo`3oool000002@3o00000`000000oooo0?oo
o`2R0?ooo`008@3oool00`000000oooo0000000:0?l000030000003oool0000000X0o`0000<00000
0?ooo`0000002P3o00000`000000oooo0000000:0?l000030000003oool0000000T0o`0000@00000
0?ooo`3oool000002@3o00000`000000oooo0?ooo`0;00000:@0oooo000Q0?ooo`030000003oool0
000000X0o`0000<000000?ooo`0000002P3o00000`000000oooo0000000:0?l000030000003oool0
000000X0o`0000<000000?ooo`0000002@3o000010000000oooo0?ooo`0000090?l000030000003o
ool0oooo0:l0oooo000Q0?ooo`030000003oool0000000X0o`0000<000000?ooo`0000002P3o0000
0`000000oooo0000000:0?l000030000003oool0000000X0o`0000<000000?ooo`0000002@3o0000
10000000oooo0?ooo`0000090?l000030000003oool0oooo0:l0oooo000Q0?ooo`030000003oool0
000000X0o`0000<000000?ooo`0000002P3o00000`000000oooo0000000:0?l000030000003oool0
000000X0o`0000<000000?ooo`0000002@3o000010000000oooo0?ooo`0000090?l000030000003o
ool0oooo0:l0oooo000Q0?ooo`030000003oool0000000X0o`0000<000000?ooo`0000002P3o0000
0`000000oooo0000000:0?l000030000003oool0000000X0o`0000<000000?ooo`0000002@3o0000
10000000oooo0?ooo`0000090?l000030000003oool0oooo0:l0oooo000Q0?ooo`<000002P3o0000
0`000000oooo0000000:0?l000030000003oool0000000X0o`0000<000000?ooo`0000002P3o0000
0`000000oooo000000090?l000030000003oool0oooo00/00000/@3oool00240oooo00<000000?oo
o`0000002P3o00000`000000oooo0000000:0?l000030000003oool0000000X0o`0000<000000?oo
o`0000002P3o00000`000000oooo000000090?l000030000003oool0oooo0;`0oooo000Q0?ooo`03
0000003oool0000000X0o`0000<000000?ooo`0000002P3o00000`000000oooo0000000:0?l00003
0000003oool0000000X0o`0000<000000?ooo`0000002@3o00000`000000oooo0?ooo`2l0?ooo`00
8@3oool00`000000oooo0000000:0?l000030000003oool0000000X0o`0000<000000?ooo`000000
2P3o00000`000000oooo0000000:0?l000030000003oool0000000T0o`0000<000000?ooo`3oool0
_03oool00240oooo00<000000?ooo`0000002P3o00000`000000oooo0000000:0?l000030000003o
ool0000000X0o`0000<000000?ooo`0000002P3o00000`000000oooo000000090?l000030000003o
ool0oooo0;`0oooo000Q0?ooo`030000003oool0000000X0o`0000<000000?ooo`0000002P3o0000
0`000000oooo0000000:0?l000030000003oool0000000X0o`0000<000000?ooo`0000002@3o0000
0`000000oooo0?ooo`2l0?ooo`008@3oool3000000X0o`0000<000000?ooo`0000002P3o00000`00
0000oooo0000000:0?l000030000003oool0000000X0o`0000<000000?ooo`0000002P00002n0?oo
o`008@3oool00`000000oooo0000000:0?l000030000003oool0000000X0o`0000<000000?ooo`00
00002P3o00000`000000oooo0000000:0?l000030000003oool0oooo0<P0oooo000Q0?ooo`030000
003oool0000000X0o`0000<000000?ooo`0000002P3o00000`000000oooo0000000:0?l000030000
003oool0000000X0o`0000<000000?ooo`3oool0b03oool00240oooo00<000000?ooo`0000002P3o
00000`000000oooo0000000:0?l000030000003oool0000000X0o`0000<000000?ooo`0000002P3o
00000`000000oooo0?ooo`380?ooo`008@3oool00`000000oooo0000000:0?l000030000003oool0
000000X0o`0000<000000?ooo`0000002P3o00000`000000oooo0000000:0?l000030000003oool0
oooo0<P0oooo000Q0?ooo`030000003oool0000000X0o`0000<000000?ooo`0000002P3o00000`00
0000oooo0000000:0?l000030000003oool0000000X0o`0000<000000?ooo`3oool0b03oool00240
oooo0`00000:0?l000030000003oool0000000X0o`0000<000000?ooo`0000002P3o00000`000000
oooo0000000:0?l000030000003oool0oooo0<P0oooo000Q0?ooo`030000003oool0000000X0o`00
00<000000?ooo`0000002P3o00000`000000oooo0000000:0?l000030000003oool0000000X0o`00
00<000000?ooo`3oool0b03oool00240oooo00<000000?ooo`0000002P3o00000`000000oooo0000
000:0?l000030000003oool0000000X0o`0000<000000?ooo`0000002P3o00000`000000oooo0?oo
o`380?ooo`008@3oool00`000000oooo0000000:0?l000030000003oool0000000X0o`0000<00000
0?ooo`0000002P3o00000`000000oooo0000000:0?l000030000003oool0oooo0<P0oooo00070?oo
o`<00000103oool2000000@0oooo0P0000040?ooo`8000001@3oool00`000000oooo0000000:0?l0
00030000003oool0000000X0o`0000<000000?ooo`0000002P3o00000`000000oooo0000000:0?l0
00030000003oool0oooo0<P0oooo00060?ooo`050000003oool0oooo0?ooo`0000000P3oool01000
0000oooo0?ooo`0000020?ooo`040000003oool0oooo00000080oooo00@000000?ooo`3oool00000
103oool00`000000oooo0000000:0?l000030000003oool0000000X0o`0000<000000?ooo`000000
2P3o00000`000000oooo0000000:0?l000030000003oool0oooo0<P0oooo000:0?ooo`040000003o
ool0oooo00000080oooo00@000000?ooo`3oool000000P3oool010000000oooo0?ooo`0000020?oo
o`030000003oool0oooo0080oooo00<000000?ooo`0000002P3o00000`000000oooo0000000:0?l0
00030000003oool0000000X0o`0000<000000?ooo`0000002P3o00000`000000oooo0?ooo`380?oo
o`002P3oool010000000oooo0?ooo`0000020?ooo`040000003oool0oooo00000080oooo00@00000
0?ooo`3oool000000P3oool00`000000oooo0?ooo`020?ooo`<000002P3o00000`000000oooo0000
000:0?l000030000003oool0000000X0o`0000<000000?ooo`0000002P3o00000`000000oooo0?oo
o`380?ooo`001P3oool4000000<0oooo00@000000?ooo`3oool000000P3oool010000000oooo0?oo
o`0000020?ooo`040000003oool0oooo000000@0oooo00<000000?ooo`0000002P3o00000`000000
oooo0000000:0?l000030000003oool0000000X0o`0000<000000?ooo`0000002P3o00000`000000
oooo0?ooo`380?ooo`001P3oool00`000000oooo0?ooo`040?ooo`040000003oool0oooo00000080
oooo00@000000?ooo`3oool000000P3oool010000000oooo0?ooo`0000040?ooo`030000003oool0
000000X0o`0000<000000?ooo`0000002P3o00000`000000oooo0000000:0?l000030000003oool0
000000/00000bP3oool000H0oooo1@0000030?ooo`800000103oool2000000@0oooo0P0000050?oo
o`030000003oool0000000X0o`0000<000000?ooo`0000002P3o00000`000000oooo0000000:0?l0
00030000003oool0oooo0=D0oooo000Q0?ooo`030000003oool0000000X0o`0000<000000?ooo`00
00002P3o00000`000000oooo0000000:0?l000030000003oool0oooo0=D0oooo000Q0?ooo`030000
003oool0000000X0o`0000<000000?ooo`0000002P3o00000`000000oooo0000000:0?l000030000
003oool0oooo0=D0oooo000Q0?ooo`<000002P3o00000`000000oooo0000000:0?l000030000003o
ool0000000X0o`0000<000000?ooo`3oool0e@3oool00240oooo00<000000?ooo`0000002P3o0000
0`000000oooo0000000:0?l000030000003oool0000000X0o`0000<000000?ooo`3oool0e@3oool0
0240oooo00<000000?ooo`0000002P3o00000`000000oooo0000000:0?l000030000003oool00000
00X0o`0000<000000?ooo`3oool0e@3oool00240oooo00<000000?ooo`0000002P3o00000`000000
oooo0000000:0?l000030000003oool0000000X0o`0000<000000?ooo`3oool0e@3oool00240oooo
00<000000?ooo`0000002P3o00000`000000oooo0000000:0?l000030000003oool0000000X0o`00
00<000000?ooo`3oool0e@3oool00240oooo00<000000?ooo`0000002P3o00000`000000oooo0000
000:0?l000030000003oool0000000X0o`0000<000000?ooo`3oool0e@3oool00240oooo00<00000
0?ooo`0000002P3o00000`000000oooo0000000:0?l000030000003oool0000000X0o`0000<00000
0?ooo`3oool0e@3oool00240oooo0`00000:0?l000030000003oool0000000X0o`0000<000000?oo
o`0000002P3o00000`000000oooo0?ooo`3E0?ooo`008@3oool00`000000oooo0000000:0?l00003
0000003oool0000000X0o`0000<000000?ooo`0000002P3o00000`000000oooo0?ooo`3E0?ooo`00
8@3oool00`000000oooo0000000:0?l000030000003oool0000000X0o`0000<000000?ooo`000000
2P3o00000`000000oooo0?ooo`3E0?ooo`008@3oool00`000000oooo0000000:0?l000030000003o
ool0000000X0o`0000<000000?ooo`0000002P3o00000`000000oooo0?ooo`3E0?ooo`008@3oool0
0`000000oooo0000000:0?l000030000003oool0000000X0o`0000<000000?ooo`0000002P3o0000
0`000000oooo0?ooo`3E0?ooo`008@3oool00`000000oooo0000000:0?l000030000003oool00000
00X0o`0000<000000?ooo`0000002P3o00000`000000oooo0?ooo`3E0?ooo`008@3oool3000000X0
o`0000<000000?ooo`0000002P3o00000`000000oooo0000000:0?l000030000003oool0oooo0=D0
oooo000Q0?ooo`030000003oool0000000X0o`0000<000000?ooo`0000002P3o00000`000000oooo
0000000;00000=L0oooo000Q0?ooo`030000003oool0000000X0o`0000<000000?ooo`0000002P3o
00000`000000oooo0?ooo`3R0?ooo`008@3oool00`000000oooo0000000:0?l000030000003oool0
000000X0o`0000<000000?ooo`3oool0hP3oool00240oooo00<000000?ooo`0000002P3o00000`00
0000oooo0000000:0?l000030000003oool0oooo0>80oooo000Q0?ooo`030000003oool0000000X0
o`0000<000000?ooo`0000002P3o00000`000000oooo0?ooo`3R0?ooo`008@3oool3000000X0o`00
00<000000?ooo`0000002P3o00000`000000oooo0?ooo`3R0?ooo`008@3oool00`000000oooo0000
000:0?l000030000003oool0000000X0o`0000<000000?ooo`3oool0hP3oool00240oooo00<00000
0?ooo`0000002P3o00000`000000oooo0000000:0?l000030000003oool0oooo0>80oooo000Q0?oo
o`030000003oool0000000X0o`0000<000000?ooo`0000002P3o00000`000000oooo0?ooo`3R0?oo
o`0000@0oooo0000000000000000103oool2000000@0oooo0P0000040?ooo`800000103oool20000
00D0oooo00<000000?ooo`0000002P3o00000`000000oooo0000000:0?l000030000003oool0oooo
0>80oooo00020?ooo`030000003oool0oooo0080oooo00@000000?ooo`3oool000000P3oool01000
0000oooo0?ooo`0000020?ooo`040000003oool0oooo00000080oooo00@000000?ooo`3oool00000
103oool00`000000oooo0000000:0?l000030000003oool0000000X0o`0000<000000?ooo`3oool0
hP3oool00080oooo00<000000?ooo`3oool00P3oool010000000oooo0?ooo`0000020?ooo`040000
003oool0oooo00000080oooo00@000000?ooo`3oool000000P3oool010000000oooo0?ooo`000004
0?ooo`030000003oool0000000X0o`0000<000000?ooo`0000002P3o00000`000000oooo0?ooo`3R
0?ooo`000P3oool00`000000oooo0?ooo`020?ooo`040000003oool0oooo00000080oooo00@00000
0?ooo`3oool000000P3oool010000000oooo0?ooo`0000020?ooo`040000003oool0oooo000000@0
oooo0`00000:0?l000030000003oool0000000X0o`0000<000000?ooo`3oool0hP3oool00080oooo
00<000000?ooo`3oool00P3oool010000000oooo0?ooo`0000020?ooo`040000003oool0oooo0000
0080oooo00@000000?ooo`3oool000000P3oool010000000oooo0?ooo`0000040?ooo`030000003o
ool0000000X0o`0000<000000?ooo`0000002P3o00000`000000oooo0?ooo`3R0?ooo`0000<0oooo
000000000000103oool010000000oooo0?ooo`0000020?ooo`040000003oool0oooo00000080oooo
00@000000?ooo`3oool000000P3oool010000000oooo0?ooo`0000040?ooo`030000003oool00000
00X0o`0000<000000?ooo`0000002P3o00000`000000oooo0?ooo`3R0?ooo`000P3oool00`000000
oooo0?ooo`030?ooo`800000103oool2000000@0oooo0P0000040?ooo`8000001@3oool00`000000
oooo0000000:0?l000030000003oool0000000X0o`0000<000000?ooo`3oool0hP3oool00240oooo
00<000000?ooo`0000002P3o00000`000000oooo0000000:0?l000030000003oool0oooo0>80oooo
000Q0?ooo`030000003oool0000000X0o`0000<000000?ooo`0000002P3o00000`000000oooo0?oo
o`3R0?ooo`008@3oool3000000X0o`0000<000000?ooo`0000002P3o00000`000000oooo0?ooo`3R
0?ooo`008@3oool00`000000oooo0000000:0?l000030000003oool0000000X0o`0000<000000?oo
o`3oool0hP3oool00240oooo00<000000?ooo`0000002P3o00000`000000oooo0000000:0?l00003
0000003oool0oooo0>80oooo000Q0?ooo`030000003oool0000000X0o`0000<000000?ooo`000000
2P3o00000`000000oooo0?ooo`3R0?ooo`008@3oool00`000000oooo0000000:0?l000030000003o
ool0000000X0o`0000<000000?ooo`3oool0hP3oool00240oooo00<000000?ooo`0000002P3o0000
0`000000oooo0000000:0?l000030000003oool0oooo0>80oooo000Q0?ooo`030000003oool00000
00X0o`0000<000000?ooo`0000002P3o00000`000000oooo0?ooo`3R0?ooo`008@3oool3000000X0
o`0000<000000?ooo`0000002P3o00000`000000oooo0?ooo`3R0?ooo`008@3oool00`000000oooo
0000000:0?l000030000003oool0000000X0o`0000<000000?ooo`3oool0hP3oool00240oooo00<0
00000?ooo`0000002P3o00000`000000oooo0000000:0?l000030000003oool0oooo0>80oooo000Q
0?ooo`030000003oool0000000X0o`0000<000000?ooo`0000002P3o00000`000000oooo0?ooo`3R
0?ooo`008@3oool00`000000oooo0000000:0?l000030000003oool0000000X0o`0000<000000?oo
o`3oool0hP3oool00240oooo00<000000?ooo`0000002P3o00000`000000oooo0000000;00000>@0
oooo000Q0?ooo`<000002P3o00000`000000oooo0?ooo`3_0?ooo`008@3oool00`000000oooo0000
000:0?l000030000003oool0oooo0>l0oooo000Q0?ooo`030000003oool0000000X0o`0000<00000
0?ooo`3oool0k`3oool00240oooo00<000000?ooo`0000002P3o00000`000000oooo0?ooo`3_0?oo
o`008@3oool00`000000oooo0000000:0?l000030000003oool0oooo0>l0oooo000Q0?ooo`030000
003oool0000000X0o`0000<000000?ooo`3oool0k`3oool00240oooo00<000000?ooo`0000002P3o
00000`000000oooo0?ooo`3_0?ooo`008@3oool3000000X0o`0000<000000?ooo`3oool0k`3oool0
0240oooo00<000000?ooo`0000002P3o00000`000000oooo0?ooo`3_0?ooo`008@3oool00`000000
oooo0000000:0?l000030000003oool0oooo0>l0oooo0000103oool000000000000000030?ooo`<0
0000103oool2000000@0oooo0P0000040?ooo`8000001@3oool00`000000oooo0000000:0?l00003
0000003oool0oooo0>l0oooo00020?ooo`050000003oool0oooo0?ooo`0000000`3oool010000000
oooo0?ooo`0000020?ooo`040000003oool0oooo00000080oooo00@000000?ooo`3oool000000P3o
ool00`000000oooo0?ooo`020?ooo`030000003oool0000000X0o`0000<000000?ooo`3oool0k`3o
ool00080oooo00<000000?ooo`3oool01@3oool010000000oooo0?ooo`0000020?ooo`040000003o
ool0oooo00000080oooo00@000000?ooo`3oool000000P3oool00`000000oooo0?ooo`020?ooo`03
0000003oool0000000X0o`0000<000000?ooo`3oool0k`3oool00080oooo00<000000?ooo`3oool0
1@3oool010000000oooo0?ooo`0000020?ooo`040000003oool0oooo00000080oooo00@000000?oo
o`3oool000000P3oool00`000000oooo0?ooo`020?ooo`<000002P3o00000`000000oooo0?ooo`3_
0?ooo`000P3oool010000000oooo0?ooo`3oool4000000<0oooo00@000000?ooo`3oool000000P3o
ool010000000oooo0?ooo`0000020?ooo`040000003oool0oooo000000@0oooo00<000000?ooo`00
00002P3o00000`000000oooo0?ooo`3_0?ooo`0000<0oooo0000000000000`3oool00`000000oooo
0?ooo`040?ooo`040000003oool0oooo00000080oooo00@000000?ooo`3oool000000P3oool01000
0000oooo0?ooo`0000040?ooo`030000003oool0000000X0o`0000<000000?ooo`3oool0k`3oool0
0080oooo00@000000?ooo`3oool0oooo1@0000030?ooo`800000103oool2000000@0oooo0P000005
0?ooo`030000003oool0000000X0o`0000<000000?ooo`3oool0k`3oool00240oooo00<000000?oo
o`0000002P3o00000`000000oooo0?ooo`3_0?ooo`008@3oool00`000000oooo0000000:0?l00003
0000003oool0oooo0>l0oooo000Q0?ooo`<000002P3o00000`000000oooo0?ooo`3_0?ooo`008@3o
ool00`000000oooo0000000:0?l000030000003oool0oooo0>l0oooo000Q0?ooo`030000003oool0
000000X0o`0000<000000?ooo`3oool0k`3oool00240oooo00<000000?ooo`0000002P3o00000`00
0000oooo0?ooo`3_0?ooo`008@3oool00`000000oooo0000000:0?l000030000003oool0oooo0>l0
oooo000Q0?ooo`030000003oool0000000X0o`0000<000000?ooo`3oool0k`3oool00240oooo00<0
00000?ooo`0000002P3o00000`000000oooo0?ooo`3_0?ooo`008@3oool3000000X0o`0000<00000
0?ooo`3oool0k`3oool00240oooo00<000000?ooo`0000002P3o00000`000000oooo0?ooo`3_0?oo
o`008@3oool00`000000oooo0000000:0?l000030000003oool0oooo0>l0oooo000Q0?ooo`030000
003oool0000000X0o`0000<000000?ooo`3oool0k`3oool00240oooo00<000000?ooo`0000002P3o
00000`000000oooo0?ooo`3_0?ooo`008@3oool00`000000oooo0000000:0?l000030000003oool0
oooo0>l0oooo000Q0?ooo`<000002P3o00000`000000oooo0?ooo`3_0?ooo`008@3oool00`000000
oooo0000000:0?l000030000003oool0oooo0>l0oooo000Q0?ooo`030000003oool0000000X0o`00
00<000000?ooo`3oool0k`3oool00240oooo00<000000?ooo`0000002P3o00000`000000oooo0?oo
o`3_0?ooo`008@3oool00`000000oooo0000000:0?l000030000003oool0oooo0>l0oooo000Q0?oo
o`030000003oool0000000X0o`0000<000000?ooo`3oool0k`3oool00240oooo00<000000?ooo`00
00002P3o00000`000000oooo0?ooo`3_0?ooo`008@3oool3000000X0o`0000<000000?ooo`3oool0
k`3oool00240oooo00<000000?ooo`0000002P3o00000`000000oooo0?ooo`3_0?ooo`008@3oool0
0`000000oooo0000000:0?l000030000003oool0oooo0>l0oooo0005000000<0oooo0P0000040?oo
o`800000103oool2000000@0oooo0P0000050?ooo`030000003oool0000000X0o`0000<000000?oo
o`3oool0k`3oool000050?ooo`000000oooo0?ooo`0000000P3oool010000000oooo0?ooo`000002
0?ooo`040000003oool0oooo00000080oooo00@000000?ooo`3oool000000P3oool010000000oooo
0?ooo`0000040?ooo`030000003oool0000000X0o`0000<000000?ooo`3oool0k`3oool00080oooo
00<000000?ooo`3oool00P3oool010000000oooo0?ooo`0000020?ooo`040000003oool0oooo0000
0080oooo00@000000?ooo`3oool000000P3oool010000000oooo0?ooo`0000040?ooo`030000003o
ool0000000X0o`0000<000000?ooo`3oool0k`3oool000<0oooo00D000000?ooo`3oool0oooo0000
00020?ooo`040000003oool0oooo00000080oooo00@000000?ooo`3oool000000P3oool010000000
oooo0?ooo`0000020?ooo`030000003oool0oooo0080oooo0`00000:0?l000030000003oool0oooo
0>l0oooo00001@000000oooo0?ooo`3oool000000080oooo00@000000?ooo`3oool000000P3oool0
10000000oooo0?ooo`0000020?ooo`040000003oool0oooo00000080oooo00@000000?ooo`3oool0
0000103oool00`000000oooo0000000:0?l000030000003oool0oooo0>l0oooo00001@000000oooo
0?ooo`3oool000000080oooo00@000000?ooo`3oool000000P3oool010000000oooo0?ooo`000002
0?ooo`040000003oool0oooo00000080oooo00@000000?ooo`3oool00000103oool00`000000oooo
0000000:0?l000030000003oool0oooo0>l0oooo0000103oool000000000000000040?ooo`800000
103oool2000000@0oooo0P0000040?ooo`8000001@3oool00`000000oooo0000000:0?l000030000
003oool0oooo0>l0oooo000Q0?ooo`030000003oool0000000X0o`0000<000000?ooo`3oool0k`3o
ool00240oooo00<000000?ooo`0000002P3o00000`000000oooo0?ooo`3_0?ooo`008@3oool30000
00X0o`0000<000000?ooo`3oool0k`3oool00240oooo00<000000?ooo`0000002P3o00000`000000
oooo0?ooo`3_0?ooo`008@3oool00`000000oooo0000000:0?l000030000003oool0oooo0>l0oooo
000Q0?ooo`030000003oool0000000X0o`0000<000000?ooo`3oool0k`3oool00240oooo00<00000
0?ooo`0000002P3o00000`000000oooo0?ooo`3_0?ooo`008@3oool00`000000oooo0000000:0?l0
00030000003oool0oooo0>l0oooo000Q0?ooo`030000003oool0000000X0o`0000<000000?ooo`3o
ool0k`3oool00240oooo3P00003a0?ooo`008@3oool00`000000oooo0?ooo`3l0?ooo`008@3oool0
0`000000oooo0?ooo`3l0?ooo`008@3oool00`000000oooo0?ooo`3l0?ooo`008@3oool00`000000
oooo0?ooo`3l0?ooo`008@3oool00`000000oooo0?ooo`3l0?ooo`008@3oool200000?d0oooo000Q
0?ooo`030000003oool0oooo0?`0oooo000Q0?ooo`030000003oool0oooo0?`0oooo000Q0?ooo`03
0000003oool0oooo0?`0oooo000Q0?ooo`030000003oool0oooo0?`0oooo000Q0?ooo`030000003o
ool0oooo0?`0oooo000Q0?ooo`030000003oool0oooo0?`0oooo000Q0?ooo`800000o@3oool00240
oooo00<000000?ooo`3oool0o03oool00240oooo00<000000?ooo`3oool0o03oool000D000000P3o
ool3000000@0oooo0P0000040?ooo`800000103oool2000000D0oooo00<000000?ooo`3oool0o03o
ool000070?ooo`000000oooo0?ooo`000000oooo000000030?ooo`040000003oool0oooo00000080
oooo00@000000?ooo`3oool000000P3oool010000000oooo0?ooo`0000020?ooo`030000003oool0
oooo0080oooo00<000000?ooo`3oool0o03oool00080oooo00<000000?ooo`3oool01@3oool01000
0000oooo0?ooo`0000020?ooo`040000003oool0oooo00000080oooo00@000000?ooo`3oool00000
0P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0?`0oooo00030?ooo`030000003o
ool0oooo00@0oooo00@000000?ooo`3oool000000P3oool010000000oooo0?ooo`0000020?ooo`04
0000003oool0oooo00000080oooo00<000000?ooo`3oool00P3oool200000?d0oooo00001P000000
oooo0?ooo`3oool000000?ooo`@000000`3oool010000000oooo0?ooo`0000020?ooo`040000003o
ool0oooo00000080oooo00@000000?ooo`3oool00000o`3oool40?ooo`0000L000000?ooo`3oool0
oooo0000003oool0000000H0oooo00@000000?ooo`3oool000000P3oool010000000oooo0?ooo`00
00020?ooo`040000003oool0oooo00000?l0oooo103oool000040?ooo`000000000000000080oooo
1@0000030?ooo`800000103oool2000000@0oooo0P00003o0?ooo`D0oooo003o0?ooob40oooo0000
\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-2.16724, -1924.74, \
0.0772381, 156.217}}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \({Mean[nsegs], StandardDeviation[nsegs]} // N\)], "Input",
  CellLabel->"In[335]:="],

Cell[BoxData[
    \({2.6283496515833114`, 2.0544569127559`}\)], "Output",
  CellLabel->"Out[335]="]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["Distribution of block lengths", "SubsubsectionIcon"],

Cell["\<\
This is the overall distribution of segment lengths, counting after \
1000 events, and sampling every 10 events \
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(segLengthDist = 
      Sum[BinCounts[
          Flatten[Map[\(-Subtract @@ #\) &, 
              Segments[lpList\[LeftDoubleBracket]k\[RightDoubleBracket], 
                a], {2}]], {0, 50, 0.1}], {k, 1000, Length[lpList], 
          10}]\)], "Input",
  CellLabel->"In[334]:="],

Cell[BoxData[
    \({1533, 1172, 939, 501, 745, 500, 348, 550, 470, 360, 432, 117, 329, 
      250, 183, 300, 156, 160, 156, 223, 92, 95, 114, 68, 63, 55, 126, 39, 
      82, 54, 69, 66, 29, 51, 12, 14, 14, 13, 57, 20, 25, 16, 4, 6, 0, 8, 12, 
      0, 13, 9, 9, 0, 0, 16, 3, 9, 0, 0, 7, 0, 1, 0, 3, 2, 0, 0, 0, 0, 0, 2, 
      1, 7, 0, 0, 0, 7, 0, 4, 0, 0, 0, 0, 1, 0, 4, 0, 0, 0, 0, 0, 0, 0, 0, 1, 
      0, 0, 0, 0, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
      0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
      0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
      0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
      0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
      0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
      0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
      0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
      0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
      0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
      0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
      0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
      0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
      0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
      0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
      0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
      0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
      0}\)], "Output",
  CellLabel->"Out[334]="]
}, Closed]],

Cell["\<\
The mean segment length is rather lower than the theoretical \
expectation of 1, but there is still a reasonable fit to an exponential.  It \
is not clear what significance test to use, since the process is \
autocorrleated.\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(nt = Plus @@ segLengthDist;\)\), "\[IndentingNewLine]", 
    \(\(Show[
        BarChart[Take[segLengthDist, 100], 
          PlotRange \[Rule] {{0, 50}, {0, 1600}}], 
        ListPlot[
          Table[{x*10, nt*Exp[\(-x\)] \((Exp[0.05] - Exp[\(-0.05\)])\)}, {x, 
              0.05, 49.95, 0.1}], 
          PlotJoined \[Rule] True]];\)\), "\[IndentingNewLine]", 
    \(Range[0.05, 49.95, 0.1] . segLengthDist\/nt\)}], "Input",
  CellLabel->"In[354]:="],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.04083e-17 0.02 0 0.000386271 [
[.02 -0.0125 -3 -9 ]
[.02 -0.0125 3 0 ]
[.04 -0.0125 -3 -9 ]
[.04 -0.0125 3 0 ]
[.06 -0.0125 -3 -9 ]
[.06 -0.0125 3 0 ]
[.08 -0.0125 -3 -9 ]
[.08 -0.0125 3 0 ]
[.1 -0.0125 -3 -9 ]
[.1 -0.0125 3 0 ]
[.12 -0.0125 -3 -9 ]
[.12 -0.0125 3 0 ]
[.14 -0.0125 -3 -9 ]
[.14 -0.0125 3 0 ]
[.16 -0.0125 -3 -9 ]
[.16 -0.0125 3 0 ]
[.18 -0.0125 -3 -9 ]
[.18 -0.0125 3 0 ]
[.2 -0.0125 -6 -9 ]
[.2 -0.0125 6 0 ]
[.22 -0.0125 -6 -9 ]
[.22 -0.0125 6 0 ]
[.24 -0.0125 -6 -9 ]
[.24 -0.0125 6 0 ]
[.26 -0.0125 -6 -9 ]
[.26 -0.0125 6 0 ]
[.28 -0.0125 -6 -9 ]
[.28 -0.0125 6 0 ]
[.3 -0.0125 -6 -9 ]
[.3 -0.0125 6 0 ]
[.32 -0.0125 -6 -9 ]
[.32 -0.0125 6 0 ]
[.34 -0.0125 -6 -9 ]
[.34 -0.0125 6 0 ]
[.36 -0.0125 -6 -9 ]
[.36 -0.0125 6 0 ]
[.38 -0.0125 -6 -9 ]
[.38 -0.0125 6 0 ]
[.4 -0.0125 -6 -9 ]
[.4 -0.0125 6 0 ]
[.42 -0.0125 -6 -9 ]
[.42 -0.0125 6 0 ]
[.44 -0.0125 -6 -9 ]
[.44 -0.0125 6 0 ]
[.46 -0.0125 -6 -9 ]
[.46 -0.0125 6 0 ]
[.48 -0.0125 -6 -9 ]
[.48 -0.0125 6 0 ]
[.5 -0.0125 -6 -9 ]
[.5 -0.0125 6 0 ]
[.52 -0.0125 -6 -9 ]
[.52 -0.0125 6 0 ]
[.54 -0.0125 -6 -9 ]
[.54 -0.0125 6 0 ]
[.56 -0.0125 -6 -9 ]
[.56 -0.0125 6 0 ]
[.58 -0.0125 -6 -9 ]
[.58 -0.0125 6 0 ]
[.6 -0.0125 -6 -9 ]
[.6 -0.0125 6 0 ]
[.62 -0.0125 -6 -9 ]
[.62 -0.0125 6 0 ]
[.64 -0.0125 -6 -9 ]
[.64 -0.0125 6 0 ]
[.66 -0.0125 -6 -9 ]
[.66 -0.0125 6 0 ]
[.68 -0.0125 -6 -9 ]
[.68 -0.0125 6 0 ]
[.7 -0.0125 -6 -9 ]
[.7 -0.0125 6 0 ]
[.72 -0.0125 -6 -9 ]
[.72 -0.0125 6 0 ]
[.74 -0.0125 -6 -9 ]
[.74 -0.0125 6 0 ]
[.76 -0.0125 -6 -9 ]
[.76 -0.0125 6 0 ]
[.78 -0.0125 -6 -9 ]
[.78 -0.0125 6 0 ]
[.8 -0.0125 -6 -9 ]
[.8 -0.0125 6 0 ]
[.82 -0.0125 -6 -9 ]
[.82 -0.0125 6 0 ]
[.84 -0.0125 -6 -9 ]
[.84 -0.0125 6 0 ]
[.86 -0.0125 -6 -9 ]
[.86 -0.0125 6 0 ]
[.88 -0.0125 -6 -9 ]
[.88 -0.0125 6 0 ]
[.9 -0.0125 -6 -9 ]
[.9 -0.0125 6 0 ]
[.92 -0.0125 -6 -9 ]
[.92 -0.0125 6 0 ]
[.94 -0.0125 -6 -9 ]
[.94 -0.0125 6 0 ]
[.96 -0.0125 -6 -9 ]
[.96 -0.0125 6 0 ]
[.98 -0.0125 -6 -9 ]
[.98 -0.0125 6 0 ]
[1 -0.0125 -6 -9 ]
[1 -0.0125 6 0 ]
[-0.0045 .07725 -18 -4.5 ]
[-0.0045 .07725 0 4.5 ]
[-0.0045 .15451 -18 -4.5 ]
[-0.0045 .15451 0 4.5 ]
[-0.0045 .23176 -18 -4.5 ]
[-0.0045 .23176 0 4.5 ]
[-0.0045 .30902 -18 -4.5 ]
[-0.0045 .30902 0 4.5 ]
[-0.0045 .38627 -24 -4.5 ]
[-0.0045 .38627 0 4.5 ]
[-0.0045 .46353 -24 -4.5 ]
[-0.0045 .46353 0 4.5 ]
[-0.0045 .54078 -24 -4.5 ]
[-0.0045 .54078 0 4.5 ]
[-0.0045 .61803 -24 -4.5 ]
[-0.0045 .61803 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02 0 m
.02 .00625 L
s
[(1)] .02 -0.0125 0 1 Mshowa
.04 0 m
.04 .00625 L
s
[(2)] .04 -0.0125 0 1 Mshowa
.06 0 m
.06 .00625 L
s
[(3)] .06 -0.0125 0 1 Mshowa
.08 0 m
.08 .00625 L
s
[(4)] .08 -0.0125 0 1 Mshowa
.1 0 m
.1 .00625 L
s
[(5)] .1 -0.0125 0 1 Mshowa
.12 0 m
.12 .00625 L
s
[(6)] .12 -0.0125 0 1 Mshowa
.14 0 m
.14 .00625 L
s
[(7)] .14 -0.0125 0 1 Mshowa
.16 0 m
.16 .00625 L
s
[(8)] .16 -0.0125 0 1 Mshowa
.18 0 m
.18 .00625 L
s
[(9)] .18 -0.0125 0 1 Mshowa
.2 0 m
.2 .00625 L
s
[(10)] .2 -0.0125 0 1 Mshowa
.22 0 m
.22 .00625 L
s
[(11)] .22 -0.0125 0 1 Mshowa
.24 0 m
.24 .00625 L
s
[(12)] .24 -0.0125 0 1 Mshowa
.26 0 m
.26 .00625 L
s
[(13)] .26 -0.0125 0 1 Mshowa
.28 0 m
.28 .00625 L
s
[(14)] .28 -0.0125 0 1 Mshowa
.3 0 m
.3 .00625 L
s
[(15)] .3 -0.0125 0 1 Mshowa
.32 0 m
.32 .00625 L
s
[(16)] .32 -0.0125 0 1 Mshowa
.34 0 m
.34 .00625 L
s
[(17)] .34 -0.0125 0 1 Mshowa
.36 0 m
.36 .00625 L
s
[(18)] .36 -0.0125 0 1 Mshowa
.38 0 m
.38 .00625 L
s
[(19)] .38 -0.0125 0 1 Mshowa
.4 0 m
.4 .00625 L
s
[(20)] .4 -0.0125 0 1 Mshowa
.42 0 m
.42 .00625 L
s
[(21)] .42 -0.0125 0 1 Mshowa
.44 0 m
.44 .00625 L
s
[(22)] .44 -0.0125 0 1 Mshowa
.46 0 m
.46 .00625 L
s
[(23)] .46 -0.0125 0 1 Mshowa
.48 0 m
.48 .00625 L
s
[(24)] .48 -0.0125 0 1 Mshowa
.5 0 m
.5 .00625 L
s
[(25)] .5 -0.0125 0 1 Mshowa
.52 0 m
.52 .00625 L
s
[(26)] .52 -0.0125 0 1 Mshowa
.54 0 m
.54 .00625 L
s
[(27)] .54 -0.0125 0 1 Mshowa
.56 0 m
.56 .00625 L
s
[(28)] .56 -0.0125 0 1 Mshowa
.58 0 m
.58 .00625 L
s
[(29)] .58 -0.0125 0 1 Mshowa
.6 0 m
.6 .00625 L
s
[(30)] .6 -0.0125 0 1 Mshowa
.62 0 m
.62 .00625 L
s
[(31)] .62 -0.0125 0 1 Mshowa
.64 0 m
.64 .00625 L
s
[(32)] .64 -0.0125 0 1 Mshowa
.66 0 m
.66 .00625 L
s
[(33)] .66 -0.0125 0 1 Mshowa
.68 0 m
.68 .00625 L
s
[(34)] .68 -0.0125 0 1 Mshowa
.7 0 m
.7 .00625 L
s
[(35)] .7 -0.0125 0 1 Mshowa
.72 0 m
.72 .00625 L
s
[(36)] .72 -0.0125 0 1 Mshowa
.74 0 m
.74 .00625 L
s
[(37)] .74 -0.0125 0 1 Mshowa
.76 0 m
.76 .00625 L
s
[(38)] .76 -0.0125 0 1 Mshowa
.78 0 m
.78 .00625 L
s
[(39)] .78 -0.0125 0 1 Mshowa
.8 0 m
.8 .00625 L
s
[(40)] .8 -0.0125 0 1 Mshowa
.82 0 m
.82 .00625 L
s
[(41)] .82 -0.0125 0 1 Mshowa
.84 0 m
.84 .00625 L
s
[(42)] .84 -0.0125 0 1 Mshowa
.86 0 m
.86 .00625 L
s
[(43)] .86 -0.0125 0 1 Mshowa
.88 0 m
.88 .00625 L
s
[(44)] .88 -0.0125 0 1 Mshowa
.9 0 m
.9 .00625 L
s
[(45)] .9 -0.0125 0 1 Mshowa
.92 0 m
.92 .00625 L
s
[(46)] .92 -0.0125 0 1 Mshowa
.94 0 m
.94 .00625 L
s
[(47)] .94 -0.0125 0 1 Mshowa
.96 0 m
.96 .00625 L
s
[(48)] .96 -0.0125 0 1 Mshowa
.98 0 m
.98 .00625 L
s
[(49)] .98 -0.0125 0 1 Mshowa
1 0 m
1 .00625 L
s
[(50)] 1 -0.0125 0 1 Mshowa
0 0 m
1 0 L
s
.008 .07725 m
.01425 .07725 L
s
[(200)] -0.0045 .07725 1 0 Mshowa
.008 .15451 m
.01425 .15451 L
s
[(400)] -0.0045 .15451 1 0 Mshowa
.008 .23176 m
.01425 .23176 L
s
[(600)] -0.0045 .23176 1 0 Mshowa
.008 .30902 m
.01425 .30902 L
s
[(800)] -0.0045 .30902 1 0 Mshowa
.008 .38627 m
.01425 .38627 L
s
[(1000)] -0.0045 .38627 1 0 Mshowa
.008 .46353 m
.01425 .46353 L
s
[(1200)] -0.0045 .46353 1 0 Mshowa
.008 .54078 m
.01425 .54078 L
s
[(1400)] -0.0045 .54078 1 0 Mshowa
.008 .61803 m
.01425 .61803 L
s
[(1600)] -0.0045 .61803 1 0 Mshowa
.125 Mabswid
.008 .01931 m
.01175 .01931 L
s
.008 .03863 m
.01175 .03863 L
s
.008 .05794 m
.01175 .05794 L
s
.008 .09657 m
.01175 .09657 L
s
.008 .11588 m
.01175 .11588 L
s
.008 .13519 m
.01175 .13519 L
s
.008 .17382 m
.01175 .17382 L
s
.008 .19314 m
.01175 .19314 L
s
.008 .21245 m
.01175 .21245 L
s
.008 .25108 m
.01175 .25108 L
s
.008 .27039 m
.01175 .27039 L
s
.008 .2897 m
.01175 .2897 L
s
.008 .32833 m
.01175 .32833 L
s
.008 .34764 m
.01175 .34764 L
s
.008 .36696 m
.01175 .36696 L
s
.008 .40558 m
.01175 .40558 L
s
.008 .4249 m
.01175 .4249 L
s
.008 .44421 m
.01175 .44421 L
s
.008 .48284 m
.01175 .48284 L
s
.008 .50215 m
.01175 .50215 L
s
.008 .52147 m
.01175 .52147 L
s
.008 .56009 m
.01175 .56009 L
s
.008 .57941 m
.01175 .57941 L
s
.008 .59872 m
.01175 .59872 L
s
.25 Mabswid
.008 0 m
.008 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
1 0 0 r
.012 0 m
.012 .59215 L
.028 .59215 L
.028 0 L
F
0 g
.5 Mabswid
.012 0 m
.012 .59215 L
.028 .59215 L
.028 0 L
.012 0 L
s
1 0 0 r
.032 0 m
.032 .45271 L
.048 .45271 L
.048 0 L
F
0 g
.032 0 m
.032 .45271 L
.048 .45271 L
.048 0 L
.032 0 L
s
1 0 0 r
.052 0 m
.052 .36271 L
.068 .36271 L
.068 0 L
F
0 g
.052 0 m
.052 .36271 L
.068 .36271 L
.068 0 L
.052 0 L
s
1 0 0 r
.072 0 m
.072 .19352 L
.088 .19352 L
.088 0 L
F
0 g
.072 0 m
.072 .19352 L
.088 .19352 L
.088 0 L
.072 0 L
s
1 0 0 r
.092 0 m
.092 .28777 L
.108 .28777 L
.108 0 L
F
0 g
.092 0 m
.092 .28777 L
.108 .28777 L
.108 0 L
.092 0 L
s
1 0 0 r
.112 0 m
.112 .19314 L
.128 .19314 L
.128 0 L
F
0 g
.112 0 m
.112 .19314 L
.128 .19314 L
.128 0 L
.112 0 L
s
1 0 0 r
.132 0 m
.132 .13442 L
.148 .13442 L
.148 0 L
F
0 g
.132 0 m
.132 .13442 L
.148 .13442 L
.148 0 L
.132 0 L
s
1 0 0 r
.152 0 m
.152 .21245 L
.168 .21245 L
.168 0 L
F
0 g
.152 0 m
.152 .21245 L
.168 .21245 L
.168 0 L
.152 0 L
s
1 0 0 r
.172 0 m
.172 .18155 L
.188 .18155 L
.188 0 L
F
0 g
.172 0 m
.172 .18155 L
.188 .18155 L
.188 0 L
.172 0 L
s
1 0 0 r
.192 0 m
.192 .13906 L
.208 .13906 L
.208 0 L
F
0 g
.192 0 m
.192 .13906 L
.208 .13906 L
.208 0 L
.192 0 L
s
1 0 0 r
.212 0 m
.212 .16687 L
.228 .16687 L
.228 0 L
F
0 g
.212 0 m
.212 .16687 L
.228 .16687 L
.228 0 L
.212 0 L
s
1 0 0 r
.232 0 m
.232 .04519 L
.248 .04519 L
.248 0 L
F
0 g
.232 0 m
.232 .04519 L
.248 .04519 L
.248 0 L
.232 0 L
s
1 0 0 r
.252 0 m
.252 .12708 L
.268 .12708 L
.268 0 L
F
0 g
.252 0 m
.252 .12708 L
.268 .12708 L
.268 0 L
.252 0 L
s
1 0 0 r
.272 0 m
.272 .09657 L
.288 .09657 L
.288 0 L
F
0 g
.272 0 m
.272 .09657 L
.288 .09657 L
.288 0 L
.272 0 L
s
1 0 0 r
.292 0 m
.292 .07069 L
.308 .07069 L
.308 0 L
F
0 g
.292 0 m
.292 .07069 L
.308 .07069 L
.308 0 L
.292 0 L
s
1 0 0 r
.312 0 m
.312 .11588 L
.328 .11588 L
.328 0 L
F
0 g
.312 0 m
.312 .11588 L
.328 .11588 L
.328 0 L
.312 0 L
s
1 0 0 r
.332 0 m
.332 .06026 L
.348 .06026 L
.348 0 L
F
0 g
.332 0 m
.332 .06026 L
.348 .06026 L
.348 0 L
.332 0 L
s
1 0 0 r
.352 0 m
.352 .0618 L
.368 .0618 L
.368 0 L
F
0 g
.352 0 m
.352 .0618 L
.368 .0618 L
.368 0 L
.352 0 L
s
1 0 0 r
.372 0 m
.372 .06026 L
.388 .06026 L
.388 0 L
F
0 g
.372 0 m
.372 .06026 L
.388 .06026 L
.388 0 L
.372 0 L
s
1 0 0 r
.392 0 m
.392 .08614 L
.408 .08614 L
.408 0 L
F
0 g
.392 0 m
.392 .08614 L
.408 .08614 L
.408 0 L
.392 0 L
s
1 0 0 r
.412 0 m
.412 .03554 L
.428 .03554 L
.428 0 L
F
0 g
.412 0 m
.412 .03554 L
.428 .03554 L
.428 0 L
.412 0 L
s
1 0 0 r
.432 0 m
.432 .0367 L
.448 .0367 L
.448 0 L
F
0 g
.432 0 m
.432 .0367 L
.448 .0367 L
.448 0 L
.432 0 L
s
1 0 0 r
.452 0 m
.452 .04403 L
.468 .04403 L
.468 0 L
F
0 g
.452 0 m
.452 .04403 L
.468 .04403 L
.468 0 L
.452 0 L
s
1 0 0 r
.472 0 m
.472 .02627 L
.488 .02627 L
.488 0 L
F
0 g
.472 0 m
.472 .02627 L
.488 .02627 L
.488 0 L
.472 0 L
s
1 0 0 r
.492 0 m
.492 .02434 L
.508 .02434 L
.508 0 L
F
0 g
.492 0 m
.492 .02434 L
.508 .02434 L
.508 0 L
.492 0 L
s
1 0 0 r
.512 0 m
.512 .02124 L
.528 .02124 L
.528 0 L
F
0 g
.512 0 m
.512 .02124 L
.528 .02124 L
.528 0 L
.512 0 L
s
1 0 0 r
.532 0 m
.532 .04867 L
.548 .04867 L
.548 0 L
F
0 g
.532 0 m
.532 .04867 L
.548 .04867 L
.548 0 L
.532 0 L
s
1 0 0 r
.552 0 m
.552 .01506 L
.568 .01506 L
.568 0 L
F
0 g
.552 0 m
.552 .01506 L
.568 .01506 L
.568 0 L
.552 0 L
s
1 0 0 r
.572 0 m
.572 .03167 L
.588 .03167 L
.588 0 L
F
0 g
.572 0 m
.572 .03167 L
.588 .03167 L
.588 0 L
.572 0 L
s
1 0 0 r
.592 0 m
.592 .02086 L
.608 .02086 L
.608 0 L
F
0 g
.592 0 m
.592 .02086 L
.608 .02086 L
.608 0 L
.592 0 L
s
1 0 0 r
.612 0 m
.612 .02665 L
.628 .02665 L
.628 0 L
F
0 g
.612 0 m
.612 .02665 L
.628 .02665 L
.628 0 L
.612 0 L
s
1 0 0 r
.632 0 m
.632 .02549 L
.648 .02549 L
.648 0 L
F
0 g
.632 0 m
.632 .02549 L
.648 .02549 L
.648 0 L
.632 0 L
s
1 0 0 r
.652 0 m
.652 .0112 L
.668 .0112 L
.668 0 L
F
0 g
.652 0 m
.652 .0112 L
.668 .0112 L
.668 0 L
.652 0 L
s
1 0 0 r
.672 0 m
.672 .0197 L
.688 .0197 L
.688 0 L
F
0 g
.672 0 m
.672 .0197 L
.688 .0197 L
.688 0 L
.672 0 L
s
1 0 0 r
.692 0 m
.692 .00464 L
.708 .00464 L
.708 0 L
F
0 g
.692 0 m
.692 .00464 L
.708 .00464 L
.708 0 L
.692 0 L
s
1 0 0 r
.712 0 m
.712 .00541 L
.728 .00541 L
.728 0 L
F
0 g
.712 0 m
.712 .00541 L
.728 .00541 L
.728 0 L
.712 0 L
s
1 0 0 r
.732 0 m
.732 .00541 L
.748 .00541 L
.748 0 L
F
0 g
.732 0 m
.732 .00541 L
.748 .00541 L
.748 0 L
.732 0 L
s
1 0 0 r
.752 0 m
.752 .00502 L
.768 .00502 L
.768 0 L
F
0 g
.752 0 m
.752 .00502 L
.768 .00502 L
.768 0 L
.752 0 L
s
1 0 0 r
.772 0 m
.772 .02202 L
.788 .02202 L
.788 0 L
F
0 g
.772 0 m
.772 .02202 L
.788 .02202 L
.788 0 L
.772 0 L
s
1 0 0 r
.792 0 m
.792 .00773 L
.808 .00773 L
.808 0 L
F
0 g
.792 0 m
.792 .00773 L
.808 .00773 L
.808 0 L
.792 0 L
s
1 0 0 r
.812 0 m
.812 .00966 L
.828 .00966 L
.828 0 L
F
0 g
.812 0 m
.812 .00966 L
.828 .00966 L
.828 0 L
.812 0 L
s
1 0 0 r
.832 0 m
.832 .00618 L
.848 .00618 L
.848 0 L
F
0 g
.832 0 m
.832 .00618 L
.848 .00618 L
.848 0 L
.832 0 L
s
1 0 0 r
.852 0 m
.852 .00155 L
.868 .00155 L
.868 0 L
F
0 g
.852 0 m
.852 .00155 L
.868 .00155 L
.868 0 L
.852 0 L
s
1 0 0 r
.872 0 m
.872 .00232 L
.888 .00232 L
.888 0 L
F
0 g
.872 0 m
.872 .00232 L
.888 .00232 L
.888 0 L
.872 0 L
s
1 0 0 r
.892 0 m
.892 0 L
.908 0 L
.908 0 L
F
0 g
.892 0 m
.892 0 L
.908 0 L
.908 0 L
.892 0 L
s
1 0 0 r
.912 0 m
.912 .00309 L
.928 .00309 L
.928 0 L
F
0 g
.912 0 m
.912 .00309 L
.928 .00309 L
.928 0 L
.912 0 L
s
1 0 0 r
.932 0 m
.932 .00464 L
.948 .00464 L
.948 0 L
F
0 g
.932 0 m
.932 .00464 L
.948 .00464 L
.948 0 L
.932 0 L
s
1 0 0 r
.952 0 m
.952 0 L
.968 0 L
.968 0 L
F
0 g
.952 0 m
.952 0 L
.968 0 L
.968 0 L
.952 0 L
s
1 0 0 r
.972 0 m
.972 .00502 L
.988 .00502 L
.988 0 L
F
0 g
.972 0 m
.972 .00502 L
.988 .00502 L
.988 0 L
.972 0 L
s
1 0 0 r
.992 0 m
.992 .00348 L
1.008 .00348 L
1.008 0 L
F
0 g
.992 0 m
.992 .00348 L
s
.992 .00348 m
1 .00348 L
s
.992 0 m
0 0 rlineto s
1 0 0 r
1.012 0 m
1.012 .00348 L
1.028 .00348 L
1.028 0 L
F
0 g
1 0 0 r
1.032 0 m
1.032 0 L
1.048 0 L
1.048 0 L
F
0 g
1 0 0 r
1.052 0 m
1.052 0 L
1.068 0 L
1.068 0 L
F
0 g
1 0 0 r
1.072 0 m
1.072 .00618 L
1.088 .00618 L
1.088 0 L
F
0 g
1 0 0 r
1.092 0 m
1.092 .00116 L
1.108 .00116 L
1.108 0 L
F
0 g
1 0 0 r
1.112 0 m
1.112 .00348 L
1.128 .00348 L
1.128 0 L
F
0 g
1 0 0 r
1.132 0 m
1.132 0 L
1.148 0 L
1.148 0 L
F
0 g
1 0 0 r
1.152 0 m
1.152 0 L
1.168 0 L
1.168 0 L
F
0 g
1 0 0 r
1.172 0 m
1.172 .0027 L
1.188 .0027 L
1.188 0 L
F
0 g
1 0 0 r
1.192 0 m
1.192 0 L
1.208 0 L
1.208 0 L
F
0 g
1 0 0 r
1.212 0 m
1.212 .00039 L
1.228 .00039 L
1.228 0 L
F
0 g
1 0 0 r
1.232 0 m
1.232 0 L
1.248 0 L
1.248 0 L
F
0 g
1 0 0 r
1.252 0 m
1.252 .00116 L
1.268 .00116 L
1.268 0 L
F
0 g
1 0 0 r
1.272 0 m
1.272 .00077 L
1.288 .00077 L
1.288 0 L
F
0 g
1 0 0 r
1.292 0 m
1.292 0 L
1.308 0 L
1.308 0 L
F
0 g
1 0 0 r
1.312 0 m
1.312 0 L
1.328 0 L
1.328 0 L
F
0 g
1 0 0 r
1.332 0 m
1.332 0 L
1.348 0 L
1.348 0 L
F
0 g
1 0 0 r
1.352 0 m
1.352 0 L
1.368 0 L
1.368 0 L
F
0 g
1 0 0 r
1.372 0 m
1.372 0 L
1.388 0 L
1.388 0 L
F
0 g
1 0 0 r
1.392 0 m
1.392 .00077 L
1.408 .00077 L
1.408 0 L
F
0 g
1 0 0 r
1.412 0 m
1.412 .00039 L
1.428 .00039 L
1.428 0 L
F
0 g
1 0 0 r
1.432 0 m
1.432 .0027 L
1.448 .0027 L
1.448 0 L
F
0 g
1 0 0 r
1.452 0 m
1.452 0 L
1.468 0 L
1.468 0 L
F
0 g
1 0 0 r
1.472 0 m
1.472 0 L
1.488 0 L
1.488 0 L
F
0 g
1 0 0 r
1.492 0 m
1.492 0 L
1.508 0 L
1.508 0 L
F
0 g
1 0 0 r
1.512 0 m
1.512 .0027 L
1.528 .0027 L
1.528 0 L
F
0 g
1 0 0 r
1.532 0 m
1.532 0 L
1.548 0 L
1.548 0 L
F
0 g
1 0 0 r
1.552 0 m
1.552 .00155 L
1.568 .00155 L
1.568 0 L
F
0 g
1 0 0 r
1.572 0 m
1.572 0 L
1.588 0 L
1.588 0 L
F
0 g
1 0 0 r
1.592 0 m
1.592 0 L
1.608 0 L
1.608 0 L
F
0 g
1 0 0 r
1.612 0 m
1.612 0 L
1.628 0 L
1.628 0 L
F
0 g
1 0 0 r
1.632 0 m
1.632 0 L
1.648 0 L
1.648 0 L
F
0 g
1 0 0 r
1.652 0 m
1.652 .00039 L
1.668 .00039 L
1.668 0 L
F
0 g
1 0 0 r
1.672 0 m
1.672 0 L
1.688 0 L
1.688 0 L
F
0 g
1 0 0 r
1.692 0 m
1.692 .00155 L
1.708 .00155 L
1.708 0 L
F
0 g
1 0 0 r
1.712 0 m
1.712 0 L
1.728 0 L
1.728 0 L
F
0 g
1 0 0 r
1.732 0 m
1.732 0 L
1.748 0 L
1.748 0 L
F
0 g
1 0 0 r
1.752 0 m
1.752 0 L
1.768 0 L
1.768 0 L
F
0 g
1 0 0 r
1.772 0 m
1.772 0 L
1.788 0 L
1.788 0 L
F
0 g
1 0 0 r
1.792 0 m
1.792 0 L
1.808 0 L
1.808 0 L
F
0 g
1 0 0 r
1.812 0 m
1.812 0 L
1.828 0 L
1.828 0 L
F
0 g
1 0 0 r
1.832 0 m
1.832 0 L
1.848 0 L
1.848 0 L
F
0 g
1 0 0 r
1.852 0 m
1.852 0 L
1.868 0 L
1.868 0 L
F
0 g
1 0 0 r
1.872 0 m
1.872 .00039 L
1.888 .00039 L
1.888 0 L
F
0 g
1 0 0 r
1.892 0 m
1.892 0 L
1.908 0 L
1.908 0 L
F
0 g
1 0 0 r
1.912 0 m
1.912 0 L
1.928 0 L
1.928 0 L
F
0 g
1 0 0 r
1.932 0 m
1.932 0 L
1.948 0 L
1.948 0 L
F
0 g
1 0 0 r
1.952 0 m
1.952 0 L
1.968 0 L
1.968 0 L
F
0 g
1 0 0 r
1.972 0 m
1.972 .00039 L
1.988 .00039 L
1.988 0 L
F
0 g
1 0 0 r
1.992 0 m
1.992 0 L
2.008 0 L
2.008 0 L
F
0 g
.01 .39435 m
.03 .35682 L
.05 .32286 L
.07 .29214 L
.09 .26434 L
.11 .23918 L
.13 .21642 L
.15 .19583 L
.17 .17719 L
.19 .16033 L
.21 .14507 L
.23 .13127 L
.25 .11877 L
.27 .10747 L
.29 .09724 L
.31 .08799 L
.33 .07962 L
.35 .07204 L
.37 .06518 L
.39 .05898 L
.41 .05337 L
.43 .04829 L
.45 .04369 L
.47 .03954 L
.49 .03577 L
.51 .03237 L
.53 .02929 L
.55 .0265 L
.57 .02398 L
.59 .0217 L
.61 .01963 L
.63 .01776 L
.65 .01607 L
.67 .01454 L
.69 .01316 L
.71 .01191 L
.73 .01077 L
.75 .00975 L
.77 .00882 L
.79 .00798 L
.81 .00722 L
.83 .00654 L
.85 .00591 L
.87 .00535 L
.89 .00484 L
.91 .00438 L
.93 .00396 L
.95 .00359 L
.97 .00325 L
.99 .00294 L
Mistroke
Mfstroke
.99 .00294 m
1 .0028 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[354]:=",
  ImageSize->{529.75, 327.438},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40008A0001Ab000`400?l00000o`00003oo`3ooooo
0?oooa<0oooo000R0?ooo`<000001P3oool5000000H0oooo0`0000080?ooo`<000001@3oool30000
00L0oooo0`0000080?ooo`030000003oool0oooo00H0oooo0`0000070?ooo`8000001@3oool30000
00@0oooo0P000000103oool000000000000000030?ooo`<0000000@0oooo00000000000000000P3o
ool8000000<0oooo0`000000103oool000000000000000040?ooo`H000000`3oool3000000040?oo
o`0000000000000000<0oooo0`000000103oool000000000000000040?ooo`030000003oool0oooo
00<000000`3oool6000000<0oooo0P0000000`3oool0000000000003000000<0oooo1`0000020?oo
o`P0000000<0oooo0000000000001`0000020?ooo`P000000`3oool700000080oooo200000020?oo
o`P000000`3oool00`000000oooo0000000400000080oooo200000020?ooo`8000000P3oool30000
00@0oooo0P000000103oool000000000000000030?ooo`H000000P3oool8000000<0oooo0`000000
103oool000000000000000040?ooo`H000000`3oool3000000040?ooo`0000000000000000<0oooo
0`000000103oool000000000000000040?ooo`030000003oool0oooo00<000000`3oool300000004
0?ooo`0000000000000000<0oooo0P0000030?ooo`<000000`3oool200000080oooo0`0000020?oo
o`<000000P3oool3000000030?ooo`000000000000<0000000@0oooo00000000000000000P3oool3
00000080oooo0`0000030?ooo`<0000000@0oooo00000000000000000P3oool3000000040?ooo`00
0000000000000080oooo0`0000020?ooo`<000000`3oool010000000oooo0?ooo`3oool300000080
oooo0`0000020?ooo`<000000P3oool200000080oooo0`0000040?ooo`8000000`3oool002<0oooo
00<000000?ooo`3oool01P3oool010000000oooo0?ooo`0000050?ooo`050000003oool0oooo0?oo
o`000000203oool00`000000oooo0?ooo`030?ooo`050000003oool0oooo0?ooo`0000001@3oool0
1@000000oooo0?ooo`3oool0000000L0oooo00<000000?ooo`3oool01@3oool01@000000oooo0?oo
o`3oool0000000P0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`020?ooo`060000
003oool0oooo0000003oool000001@3oool01@000000oooo0?ooo`3oool0000000@0oooo00H00000
0?ooo`3oool000000?ooo`0000030?ooo`070000003oool0oooo0?ooo`000000oooo000000060?oo
o`040000003oool0oooo000000<0oooo00L000000?ooo`3oool0oooo0000003oool0000000<0oooo
00L000000?ooo`3oool0oooo0000003oool0000000D0oooo00D000000?ooo`3oool0oooo00000003
0?ooo`040000003oool0oooo0?ooo`8000001P3oool00`000000oooo000000020?ooo`040000003o
ool0oooo00000080oooo0P0000020?ooo`050000003oool0oooo0?ooo`0000000P3oool010000000
oooo0?ooo`0000020?ooo`030000003oool0oooo008000000P3oool00`000000oooo000000030?oo
o`8000000P3oool00`000000oooo0?ooo`020?ooo`030000003oool000000080oooo00<000000?oo
o`0000000`3oool200000080oooo00<000000?ooo`0000000`3oool200000080oooo00D000000?oo
o`3oool0oooo000000020?ooo`060000003oool0oooo0000003oool000000`3oool200000080oooo
00<000000?ooo`3oool00P3oool2000000<0oooo00@000000?ooo`3oool000000P3oool01@000000
oooo0?ooo`3oool0000000<0oooo0P0000030?ooo`040000003oool0oooo00000080oooo00L00000
0?ooo`3oool0oooo0000003oool0000000<0oooo00D000000?ooo`3oool0oooo000000040?ooo`80
00000`3oool00`000000oooo000000030?ooo`070000003oool0oooo0?ooo`000000oooo00000003
0?ooo`050000003oool0oooo0?ooo`0000000`3oool00`000000oooo000000030?ooo`030000003o
ool0000000<0oooo00D000000?ooo`3oool0oooo000000040?ooo`050000003oool0oooo0?ooo`00
00000`3oool010000000oooo0?ooo`0000020?ooo`030000003oool0oooo0080oooo00<000000?oo
o`3oool00P3oool01@000000oooo0?ooo`3oool000000080oooo00@000000?ooo`3oool000000P3o
ool01@000000oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool00`3oool01@000000oooo
0?ooo`3oool000000080oooo00L000000?ooo`3oool0oooo0000003oool000000080oooo00D00000
0?ooo`3oool0oooo000000020?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool00P3o
ool010000000oooo0?ooo`0000030?ooo`040000003oool0oooo000000D0oooo0P0000030?ooo`04
0000003oool0oooo00000080oooo0@0000010?ooo`40oooo000S0?ooo`030000003oool0oooo00L0
oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`030?ooo`D00000203oool00`000000
oooo0?ooo`030?ooo`050000003oool0oooo0?ooo`000000203oool00`000000oooo0?ooo`040?oo
o`050000003oool0oooo0?ooo`0000002@3oool00`000000oooo0?ooo`020?ooo`030000003oool0
oooo0080oooo00H000000?ooo`3oool000000?ooo`0000050?ooo`050000003oool0oooo0?ooo`00
00001@3oool01@000000oooo0?ooo`3oool0000000L0oooo00<000000?ooo`0000000`3oool50000
00030?ooo`000000oooo00H0oooo00<000000?ooo`0000000`3oool01`000000oooo0?ooo`3oool0
00000?ooo`0000001P3oool010000000oooo0?ooo`0000030?ooo`040000003oool0oooo0?ooo`80
00001`3oool00`000000oooo000000040?ooo`060000003oool0oooo0000003oool000001@3oool0
1@000000oooo0?ooo`3oool0000000D0oooo00D000000?ooo`3oool0oooo000000070?ooo`030000
003oool0000000<0oooo1@0000000`3oool000000?ooo`060?ooo`030000003oool0000000<0oooo
00L000000?ooo`3oool0oooo0000003oool0000000H0oooo00@000000?ooo`3oool000000`3oool0
1`000000oooo0?ooo`3oool000000?ooo`0000001`3oool01@000000oooo0?ooo`3oool000000080
oooo00@000000?ooo`3oool000000`3oool01@000000oooo0?ooo`3oool0000000@0oooo00D00000
0?ooo`3oool0oooo000000050?ooo`030000003oool0oooo00<0oooo00H000000?ooo`3oool0oooo
0000003oool5000000<0oooo00<000000?ooo`3oool00`3oool01`000000oooo0?ooo`3oool00000
0?ooo`0000000`3oool01@000000oooo0?ooo`3oool0000000@0oooo00<000000?ooo`3oool00P3o
ool00`000000oooo000000030?ooo`050000003oool0oooo0?ooo`0000001@3oool500000080oooo
00<000000?ooo`3oool01@0000030?ooo`030000003oool0000000@000000`3oool00`000000oooo
00000004000000D0oooo1@0000000`3oool0000000000007000000@0oooo1@0000000`3oool00000
0?ooo`020?ooo`D00000103oool6000000030?ooo`000000oooo0080oooo1@0000050?ooo`050000
003oool0oooo0?ooo`0000000P3oool010000000oooo0?ooo`0000020?ooo`008`3oool00`000000
oooo0?ooo`080?ooo`030000003oool0oooo00H0oooo0P0000060?ooo`040000003oool0oooo0000
00T0oooo00<000000?ooo`3oool00`3oool4000000T0oooo00<000000?ooo`3oool01@3oool30000
00L0oooo100000040?ooo`030000003oool0oooo0080oooo00H000000?ooo`3oool000000?ooo`00
00050?ooo`050000003oool0oooo0?ooo`0000001P3oool010000000oooo0?ooo`0000050?ooo`80
00000P3oool01@000000oooo0?ooo`3oool000000080oooo00@000000?ooo`3oool000001`3oool0
0`000000oooo000000030?ooo`@000000P3oool00`000000oooo0?ooo`040?ooo`040000003oool0
oooo000000@0oooo0`0000000`3oool000000?ooo`030?ooo`@000000P3oool01@000000oooo0?oo
o`3oool000000080oooo00@000000?ooo`3oool00000103oool00`000000oooo0?ooo`020?ooo`03
0000003oool0oooo00<0oooo00D000000?ooo`3oool0oooo000000040?ooo`8000000`3oool01000
0000oooo0?ooo`0000020?ooo`050000003oool0oooo0?ooo`0000001P3oool010000000oooo0?oo
o`0000020?ooo`@000000`3oool00`000000oooo0?ooo`030?ooo`050000003oool0oooo0?ooo`00
00000`3oool3000000<0oooo00@000000?ooo`3oool0oooo100000000`3oool00000000000030?oo
o`050000003oool0oooo0000003oool00P0000040?ooo`030000003oool0oooo008000001@3oool0
0`000000oooo0?ooo`02000000@0oooo0P0000020?ooo`8000000P3oool010000000oooo0?ooo`00
00020?ooo`8000001P3oool010000000oooo0000000000020?ooo`@000000P3oool2000000D0oooo
00<000000?ooo`3oool00P0000030?ooo`<000000P3oool2000000<0oooo100000020?ooo`050000
003oool0oooo0?ooo`0000000P3oool010000000oooo0?ooo`0000040?ooo`030000003oool00000
0080oooo00<000000?ooo`3oool00`3oool200000080oooo00<000000?ooo`3oool00P3oool30000
0080oooo00@000000?ooo`3oool000000P3oool200000080oooo00<000000?ooo`3oool00`3oool2
000000040?ooo`000000oooo0?ooo`D000000P3oool00`000000oooo0?ooo`030?ooo`8000000P3o
ool010000000oooo0?ooo`3oool400000080oooo00@000000?ooo`3oool0oooo100000030?ooo`04
0000003oool0oooo00000080oooo0@0000010?ooo`40oooo000S0?ooo`030000003oool0oooo00D0
oooo00D000000?ooo`3oool0oooo000000090?ooo`030000003oool0oooo00@0oooo00<000000?oo
o`0000001@3oool4000000H0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`030?oo
o`050000003oool0oooo0?ooo`0000001@3oool01@000000oooo0?ooo`3oool0000000@0oooo00<0
00000?ooo`3oool00P3oool01P000000oooo0?ooo`000000oooo000000D0oooo00D000000?ooo`3o
ool0oooo000000030?ooo`070000003oool0oooo0?ooo`000000oooo000000070?ooo`030000003o
ool0000000@0oooo00<000000?ooo`0000000P3oool010000000oooo0?ooo`3oool400000080oooo
00D000000?ooo`3oool0oooo000000050?ooo`030000003oool0oooo00D0oooo00<000000?ooo`00
00000`3oool010000000oooo0?ooo`3oool2000000<0oooo00D000000?ooo`3oool0oooo00000003
0?ooo`040000003oool0oooo00000080oooo00D000000?ooo`3oool0oooo000000030?ooo`030000
003oool0000000<0oooo00<000000?ooo`0000000`3oool01@000000oooo0?ooo`3oool0000000D0
oooo00D000000?ooo`3oool0oooo000000020?ooo`040000003oool00000000000<0oooo00<00000
0?ooo`000000100000030?ooo`030000003oool0000000<0oooo00D000000?ooo`3oool0oooo0000
00050?ooo`070000003oool0oooo0?ooo`000000oooo000000030?ooo`070000003oool0oooo0?oo
o`000000oooo000000030?ooo`050000003oool0oooo0?ooo`0000000P3oool010000000oooo0?oo
o`0000030?ooo`050000003oool0oooo0?ooo`000000103oool00`000000oooo000000030?ooo`05
0000003oool0oooo0?ooo`0000001@3oool01@000000oooo0?ooo`3oool000000080oooo00<00000
0?ooo`000000103oool00`000000oooo00000003000000@0oooo00<000000?ooo`0000001`3oool0
0`000000oooo0?ooo`030?ooo`070000003oool0oooo0?ooo`000000oooo000000030?ooo`070000
003oool0oooo0?ooo`000000oooo000000030?ooo`80000000<0oooo0000003oool00P3oool00`00
0000oooo0?ooo`02000000030?ooo`000000oooo00<0oooo00H000000?ooo`3oool000000?ooo`00
00020?ooo`040000003oool0oooo0?ooo`80000000<0oooo0000003oool01@3oool2000000030?oo
o`000000oooo0080oooo00L000000?ooo`000000oooo0000003oool000000080oooo1@0000001@3o
ool000000?ooo`3oool0000000@0oooo00<000000?ooo`0000001P3oool2000000050?ooo`000000
oooo0?ooo`0000000`3oool2000000050?ooo`000000oooo0?ooo`0000000`3oool4000000<0oooo
00@000000?ooo`3oool000000P3oool00280oooo0P0000070?ooo`050000003oool0oooo0?ooo`00
00001@3oool01@000000oooo0?ooo`3oool0000000L0oooo0P0000050?ooo`030000003oool0oooo
00P0oooo00<000000?ooo`3oool01P3oool01@000000oooo0?ooo`3oool0000000D0oooo00D00000
0?ooo`3oool0oooo000000050?ooo`050000003oool0oooo0?ooo`0000000`3oool2000000@0oooo
00<000000?ooo`3oool00`0000040?ooo`8000000P3oool2000000<0oooo00@000000?ooo`3oool0
oooo0`0000030?ooo`040000003oool0oooo0?ooo`<000001@3oool2000000030?ooo`0000000000
00<0oooo00<000000?ooo`3oool00P3oool2000000@0oooo00@000000?ooo`3oool0oooo0P000003
0?ooo`040000003oool0oooo0?ooo`<000000`3oool010000000oooo0?ooo`3oool2000000<0oooo
00D000000?ooo`3oool0oooo000000030?ooo`040000003oool0oooo00000080oooo00D000000?oo
o`3oool0oooo000000020?ooo`80000000<0oooo0000003oool00P3oool00`000000oooo00000003
0?ooo`070000003oool0oooo0?ooo`000000oooo000000030?ooo`050000003oool0oooo0?ooo`00
00000`3oool3000000<0oooo00<000000?ooo`0000000`3oool01@000000oooo0?ooo`3oool00000
0080oooo00@000000?ooo`3oool000000`3oool00`000000oooo000000030?ooo`070000003oool0
oooo0?ooo`000000oooo000000030?ooo`070000003oool0oooo0?ooo`000000oooo000000030?oo
o`050000003oool0oooo0?ooo`0000000P3oool010000000oooo0?ooo`0000030?ooo`030000003o
ool0oooo00<000000`3oool00`000000oooo000000030?ooo`070000003oool0oooo0?ooo`000000
oooo000000030?ooo`050000003oool0oooo0?ooo`0000000`3oool3000000<0oooo00<000000?oo
o`0000000`3oool01@000000oooo0?ooo`3oool000000080oooo00@000000?ooo`3oool000000`3o
ool00`000000oooo000000030?ooo`070000003oool0oooo0?ooo`000000oooo000000030?ooo`07
0000003oool0oooo0?ooo`000000oooo000000030?ooo`040000003oool00000000000<0oooo00D0
00000?ooo`3oool000000?ooo`02000000<0oooo0P0000030?ooo`8000000P3oool01P000000oooo
0?ooo`3oool000000?ooo`8000000P3oool01P000000oooo0?ooo`3oool000000?ooo`800000103o
ool200000080oooo0P0000020?ooo`030000003oool0oooo0080oooo0P0000030?ooo`030000003o
ool0oooo0080oooo0P0000020?ooo`060000003oool0oooo0?ooo`000000oooo0P0000020?ooo`06
0000003oool0oooo0?ooo`000000oooo0P0000020?ooo`050000003oool0oooo0?ooo`0000001P3o
ool010000000oooo0?ooo`0000020?ooo`008`3oool00`000000oooo0?ooo`060?ooo`<000001`3o
ool3000000T0oooo00<000000?ooo`3oool00`3oool5000000L0oooo0P0000060?ooo`D000001P3o
ool3000000L0oooo0`0000050?ooo`030000003oool0oooo00<0oooo0P0000020?ooo`030000003o
ool0oooo00<0oooo00D000000?ooo`3oool0oooo000000040?ooo`<000000P3oool00`000000oooo
0?ooo`020?ooo`<000000P3oool00`000000oooo0?ooo`040?ooo`040000003oool0oooo000000<0
oooo1@0000000`3oool000000?ooo`040?ooo`8000000P3oool010000000oooo0?ooo`3oool50000
00030?ooo`000000oooo00<0oooo0`0000000`3oool000000?ooo`030?ooo`<0000000@0oooo0000
000000000000103oool2000000040?ooo`0000000000000000@0oooo00<000000?ooo`3oool00`00
00030?ooo`<0000000@0oooo00000000000000000`3oool3000000040?ooo`0000000000000000D0
oooo00<000000?ooo`0000000P0000020?ooo`P00000103oool2000000040?ooo`00000000000000
0080oooo200000030?ooo`<0000000@0oooo00000000000000000`3oool3000000040?ooo`000000
0000000000@0oooo0P000000103oool000000000000000040?ooo`030000003oool0000000800000
0`3oool3000000040?ooo`0000000000000000<0oooo0`000000103oool000000000000000050?oo
o`030000003oool00000008000000P3oool8000000@0oooo0P000000103oool00000000000000002
0?ooo`P000000`3oool3000000040?ooo`0000000000000000<0oooo0`0000030?ooo`030000003o
ool0oooo0080oooo0P0000030?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool00P3o
ool010000000oooo0?ooo`3oool3000000<0oooo00@000000?ooo`3oool0oooo0`0000030?ooo`03
0000003oool0oooo00<0oooo00D000000?ooo`3oool0oooo000000020?ooo`D0000000<0oooo0000
003oool00`3oool2000000<0oooo00<000000?ooo`3oool01@0000020?ooo`040000003oool0oooo
0?ooo`<000000`3oool010000000oooo0?ooo`3oool8000000<0oooo0P0000030?ooo`00o`3ooooo
0?oooa<0oooo003o0?ooool0oooo4`3oool00?l0ooooo`3ooolC0?ooo`00o`3ooooo0?oooa<0oooo
003o0?ooool0oooo4`3oool00?l0ooooo`3ooolC0?ooo`00o`3ooooo0?oooa<0oooo000J0?ooool0
0000lP0000060?ooo`007P3oool00`000000oooo000000070?l000030000003oool0000000L0o`00
00<000000?ooo`0000001`3o00000`000000oooo000000070?l000030000003oool0000000H0o`00
00<000000?ooo`0000001`3o00000`000000oooo000000070?l000030000003oool0000000L0o`00
00<000000?ooo`0000001`3o00000`000000oooo000000070?l000030000003oool0000000L0o`00
00<000000?ooo`0000001`3o00000`000000oooo000000070?l000030000003oool0000000L0o`00
00<000000?ooo`0000001`3o00000`000000oooo000000070?l000030000003oool0000000L0o`00
00<000000?ooo`0000001P3o00000`000000oooo000000070?l000030000003oool0000000L0o`00
00<000000?ooo`0000001`3o00000`000000oooo000000070?l000030000003oool0000000L0o`00
00<000000?ooo`0000001`3o00000`000000oooo000000070?l000030000003oool0000000L0o`00
00<000000?ooo`0000001`3o00000`000000oooo000000070?l000030000003oool0000000L0o`00
00<000000?ooo`0000001`3o00000`000000oooo000000070?l000030000003oool0000000H0o`00
00<000000?ooo`0000001`3o00000`000000oooo000000070?l000030000003oool0000000L0o`00
00<000000?ooo`0000001`3o00000`000000oooo000000070?l000030000003oool0000000L0o`00
00<000000?ooo`0000001`3o00000`000000oooo000000070?l000030000003oool0000000L0o`00
00<000000?ooo`0000001`3o00000`000000oooo00000008000000030?ooo`000000000000L00000
1@3oool00`000000oooo0?ooo`020?ooo`030000003o0000o`0000D0o`0000<000000?ooo`000000
1`3o00000`000000oooo0?ooo`030?ooo`030000003oool0oooo00<0oooo00<000000?l0003o0000
1@3o00000`000000oooo000000070?l00080oooo0@3o000001h0oooo00<000000?ooo`0000001`3o
00000`000000oooo000000070?l000030000003oool0000000L0o`0000<000000?ooo`0000001`3o
00000`000000oooo000000060?l000030000003oool0000000L0o`0000<000000?ooo`0000001`3o
00000`000000oooo000000070?l000030000003oool0000000L0o`0000<000000?ooo`0000001`3o
00000`000000oooo000000070?l000030000003oool0000000L0o`0000<000000?ooo`0000001`3o
00000`000000oooo000000070?l000030000003oool0000000L0o`0000<000000?ooo`0000001`3o
00000`000000oooo000000070?l000030000003oool0000000H0o`0000<000000?ooo`0000001`3o
00000`000000oooo000000070?l000030000003oool0000000L0o`0000<000000?ooo`0000001`3o
00000`000000oooo000000070?l000030000003oool0000000L0o`0000<000000?ooo`0000001`3o
00000`000000oooo000000070?l000030000003oool0000000L0o`0000<000000?ooo`0000001`3o
00000`000000oooo000000070?l000030000003oool0000000L0o`0000<000000?ooo`0000001`3o
00000`000000oooo000000060?l000030000003oool0000000L0o`0000<000000?ooo`0000001`3o
00000`000000oooo000000070?l000030000003oool0000000L0o`0000<000000?ooo`0000001`3o
00000`000000oooo000000070?l000030000003oool0000000L0o`0000<000000?ooo`0000001`3o
00000`000000oooo000000070?l000030000003oool0000000L0o`0000<000000?ooo`3oool00`3o
ool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00L0oooo<P0000030?l00080oooo0@3o
000001h0oooo00<000000?ooo`0000001`3o00000`000000oooo000000070?l000030000003oool0
000000L0o`0000<000000?ooo`0000001`3o00000`000000oooo000000060?l000030000003oool0
000000L0o`0000<000000?ooo`0000001`3o00000`000000oooo000000070?l000030000003oool0
000000L0o`0000<000000?ooo`0000001`3o00000`000000oooo000000070?l000030000003oool0
000000L0o`0000<000000?ooo`0000001`3o00000`000000oooo000000070?l000030000003oool0
000000L0o`0000<000000?ooo`0000001`3o00000`000000oooo000000070?l000030000003oool0
000000H0o`0000<000000?ooo`0000001`3o00000`000000oooo000000070?l000030000003oool0
000000L0o`0000<000000?ooo`0000001`3o00000`000000oooo000000070?l000030000003oool0
000000L0o`0000<000000?ooo`0000001`3o00000`000000oooo000000070?l000030000003oool0
000000L0o`0000<000000?ooo`0000001`3o00000`000000oooo000000070?l000030000003oool0
000000L0o`0000<000000?ooo`0000001`3o00000`000000oooo000000060?l000030000003oool0
000000L0o`0000<000000?ooo`0000001`3o00000`000000oooo00000008000000030?ooo`000000
000000L0000000<0oooo0000000000001`0000000`3oool0000000000007000000030?ooo`000000
o`0000H0o`0000<000000?ooo`0000001`3o00000`000000oooo000000070?l000030000003oool0
000002800000203oool00`000000oooo0?ooo`030?ooo`T000001@3oool00`000000oooo0?ooo`03
0?ooo`T000001@3oool00`000000oooo0?ooo`040?ooo`007P3oool00`000000oooo000000070?l0
00030000003oool0000000L0o`0000<000000?ooo`0000001`3o00000`000000oooo000000070?l0
00030000003oool0000000H0o`0000<000000?ooo`0000001`3o00000`000000oooo000000070?l0
00030000003oool0000000L0o`0000<000000?ooo`0000001`3o00000`000000oooo000000070?l0
00030000003oool0000000L0o`0000<000000?ooo`0000001`3o00000`000000oooo000000070?l0
00030000003oool0000000L0o`0000<000000?ooo`0000001`3o00000`000000oooo000000070?l0
00030000003oool0000000L0o`0000<000000?ooo`0000001P3o00000`000000oooo000000070?l0
00030000003oool0000000L0o`0000<000000?ooo`0000001`3o00000`000000oooo000000070?l0
00030000003oool0000000L0o`0000<000000?ooo`0000001`3o00000`000000oooo000000070?l0
00030000003oool0000000L0o`0000<000000?ooo`0000001`3o00000`000000oooo000000070?l0
00030000003oool0000000L0o`0000<000000?ooo`0000001`3o00000`000000oooo000000070?l0
00030000003oool0000000H0o`0000<000000?ooo`0000001`3o00000`000000oooo000000070?l0
00030000003oool0oooo02L0oooo00@000000?l0003o0000o`007P00001F0?ooo`007P3oool00`00
0000oooo000000070?l000030000003oool0000000L0o`0000<000000?ooo`0000001`3o00000`00
0000oooo000000070?l000030000003oool0000000H0o`0000<000000?ooo`0000001`3o00000`00
0000oooo000000070?l000030000003oool0000000L0o`0000<000000?ooo`0000001`3o00000`00
0000oooo000000070?l000030000003oool0000000L0o`0000<000000?ooo`0000001`3o00000`00
0000oooo000000070?l000030000003oool0000000L0o`0000<000000?ooo`0000001`3o00000`00
0000oooo000000070?l000030000003oool0000000L0o`0000<000000?ooo`0000001P3o00000`00
0000oooo000000070?l000030000003oool0000000L0o`0000<000000?ooo`0000001`3o00000`00
0000oooo000000070?l000030000003oool0000000L0o`0000<000000?ooo`0000001`3o00000`00
0000oooo000000070?l000030000003oool0000000L0o`0000<000000?ooo`0000001`3o00000`00
0000oooo000000070?l000030000003oool0000000L0o`0000<000000?ooo`0000001`3o00000`00
0000oooo000000070?l000030000003oool0000000H0o`0000<000000?ooo`0000001`3o00000`00
0000oooo000000070?l000030000003oool0oooo01L0oooo500000040?l000030000003oool0oooo
00T0oooo2@00001K0?ooo`007P3oool00`000000oooo000000070?l000030000003oool0000000L0
o`0000<000000?ooo`0000001`3o00000`000000oooo000000070?l000030000003oool0000000H0
o`0000<000000?ooo`0000001`3o00000`000000oooo000000070?l000030000003oool0000000L0
o`0000<000000?ooo`0000001`3o00000`000000oooo000000070?l000030000003oool0000000L0
o`0000<000000?ooo`0000001`3o00000`000000oooo000000070?l000030000003oool0000000L0
o`0000<000000?ooo`0000001`3o00000`000000oooo000000070?l000030000003oool0000000L0
o`0000<000000?ooo`0000001P3o00000`000000oooo000000070?l000030000003oool0000000L0
o`0000<000000?ooo`0000001`3o00000`000000oooo000000070?l000030000003oool0000000L0
o`0000<000000?ooo`0000001`3o00000`000000oooo000000070?l000030000003oool0000000L0
o`0000<000000?ooo`0000001`3o00000`000000oooo000000070?l000030000003oool0000000L0
o`0000<000000?ooo`0000001`3o00000`000000oooo000000070?l000030000003oool0000000H0
o`0000<000000?ooo`000000200000000`3oool000000?l000060?l000030000003oool0oooo00<0
oooo5000000@0?ooo`030000003o0000o`0000D0o`0000<000000?ooo`3oool0K@3oool001h0oooo
00<000000?ooo`0000001`3o00000`000000oooo000000070?l000030000003oool0000000L0o`00
00<000000?ooo`0000001`3o00000`000000oooo000000060?l000030000003oool0000000L0o`00
00<000000?ooo`0000001`3o00000`000000oooo000000070?l000030000003oool0000000L0o`00
00<000000?ooo`0000001`3o00000`000000oooo000000070?l000030000003oool0000000L0o`00
00<000000?ooo`0000001`3o00000`000000oooo000000070?l000030000003oool0000000L0o`00
00<000000?ooo`0000001`3o00000`000000oooo000000070?l000030000003oool0000000H0o`00
00<000000?ooo`0000001`3o00000`000000oooo000000070?l000030000003oool0000000L0o`00
00<000000?ooo`0000001`3o00000`000000oooo000000070?l000030000003oool0000000L0o`00
00<000000?ooo`0000001`3o00000`000000oooo000000070?l000030000003oool0000000L0o`00
00<000000?ooo`0000001`3o00000`000000oooo000000070?l000030000003oool0000000L0o`00
00<000000?ooo`0000001`3o00000`000000oooo000000060?l000030000003oool0oooo00<0oooo
5000000T0?ooo`030000003o0000o`0000D0o`0000<000000?ooo`3oool0K@3oool001h0oooo00<0
00000?ooo`0000001`3o00000`000000oooo000000070?l000030000003oool0000000L0o`0000<0
00000?ooo`0000001`3o00000`000000oooo000000060?l000030000003oool0000000L0o`0000<0
00000?ooo`0000001`3o00000`000000oooo000000070?l000030000003oool0000000L0o`0000<0
00000?ooo`0000001`3o00000`000000oooo000000070?l000030000003oool0000000L0o`0000<0
00000?ooo`0000001`3o00000`000000oooo000000070?l000030000003oool0000000L0o`0000<0
00000?ooo`0000001`3o00000`000000oooo000000070?l000030000003oool0000000H0o`0000<0
00000?ooo`0000001`3o00000`000000oooo000000070?l000030000003oool0000000L0o`0000<0
00000?ooo`0000001`3o00000`000000oooo000000070?l000030000003oool0000000L0o`0000<0
00000?ooo`0000001`3o00000`000000oooo000000070?l000030000003oool0000000L0o`0000<0
00000?ooo`000000200000000`3oool000000?l000060?l000030000003oool0000000L0o`0000<0
00000?ooo`0000001`3o00000`000000oooo000000030?l000T000001P3oool00`000000o`000?l0
00050?l000030000003oool0oooo02L0oooo00<000000?l0003o00001@3o00000`000000oooo0?oo
o`1]0?ooo`007P3oool00`000000oooo000000070?l000030000003oool0000000L0o`0000<00000
0?ooo`0000001`3o00000`000000oooo000000070?l000030000003oool0000000H0o`0000<00000
0?ooo`0000001`3o00000`000000oooo000000070?l000030000003oool0000000L0o`0000<00000
0?ooo`0000001`3o00000`000000oooo000000070?l000030000003oool0000000L0o`0000<00000
0?ooo`0000001`3o00000`000000oooo000000070?l000030000003oool0000000L0o`0000<00000
0?ooo`0000001`3o00000`000000oooo000000070?l000030000003oool0000000L0o`0000<00000
0?ooo`0000001P3o00000`000000oooo000000070?l000030000003oool0000000L0o`0000<00000
0?ooo`0000001`3o00000`000000oooo000000070?l000030000003oool0000000L0o`0000<00000
0?ooo`0000001`3o00000`000000oooo000000070?l000030000003oool0000000L0o`0000<00000
0?ooo`0000001`3o00000`000000oooo0?ooo`090?ooo`030000003o0000o`0000D0o`0000<00000
0?ooo`0000001`3o00000`000000oooo000000030?l000X000000`3o00000`000000oooo0?ooo`09
0?ooo`030000003o0000o`0000D0o`0000<000000?ooo`3oool09`3oool00`000000o`000?l00005
0?l000030000003oool0oooo06d0oooo000N0?ooo`<000001`3o00000`000000oooo000000070?l0
00030000003oool0000000L0o`0000<000000?ooo`0000001`3o00000`000000oooo000000060?l0
00030000003oool0000000L0o`0000<000000?ooo`0000001`3o00000`000000oooo000000070?l0
00030000003oool0000000L0o`0000<000000?ooo`0000001`3o00000`000000oooo000000070?l0
00030000003oool0000000L0o`0000<000000?ooo`0000001`3o00000`000000oooo000000070?l0
00030000003oool0000000L0o`0000<000000?ooo`0000001`3o00000`000000oooo000000070?l0
00030000003oool0000000H0o`0000<000000?ooo`0000001`3o00000`000000oooo000000070?l0
00030000003oool0000000L0o`0000<000000?ooo`0000001`3o00000`000000oooo000000070?l0
00030000003oool0000000L0o`0000<000000?ooo`0000001`3o00000`000000oooo000000070?l0
00030000003oool0000000L0o`0000<000000?ooo`3oool02@3oool00`000000o`000?l000050?l0
00030000003oool0000000<0o`002P0000040?l000030000003oool0000000H0o`0000<000000?oo
o`3oool02@3oool9000002T0oooo00<000000?l0003o00001@3o00000`000000oooo0?ooo`1]0?oo
o`007P3oool00`000000oooo000000070?l000030000003oool0000000L0o`0000<000000?ooo`00
00001`3o00000`000000oooo000000070?l000030000003oool0000000H0o`0000<000000?ooo`00
00001`3o00000`000000oooo000000070?l000030000003oool0000000L0o`0000<000000?ooo`00
00001`3o00000`000000oooo000000070?l000030000003oool0000000L0o`0000<000000?ooo`00
00001`3o00000`000000oooo000000070?l000030000003oool0000000L0o`0000<000000?ooo`00
00001`3o00000`000000oooo000000070?l000030000003oool0000000L0o`0000<000000?ooo`00
00001P3o00000`000000oooo000000070?l000030000003oool0000000L0o`0000<000000?ooo`00
00001`3o00000`000000oooo000000070?l000030000003oool0000000L0o`0000<000000?ooo`00
00001`3o00000`000000oooo000000070?l000030000003oool0000000P0000000<0oooo0000003o
00001P3o00000`000000oooo0?ooo`090?ooo`040000003o0000o`000?l000l0000000<0oooo0000
003o00001P3o00000`000000oooo000000060?l000030000003oool0oooo03/0oooo2@00001_0?oo
o`007P3oool00`000000oooo000000070?l000030000003oool0000000L0o`0000<000000?ooo`00
00001`3o00000`000000oooo000000070?l000030000003oool0000000H0o`0000<000000?ooo`00
00001`3o00000`000000oooo000000070?l000030000003oool0000000L0o`0000<000000?ooo`00
00001`3o00000`000000oooo000000070?l000030000003oool0000000L0o`0000<000000?ooo`00
00001`3o00000`000000oooo000000070?l000030000003oool0000000L0o`0000<000000?ooo`00
00001`3o00000`000000oooo000000070?l000030000003oool0000000L0o`0000<000000?ooo`00
00001P3o00000`000000oooo000000070?l000030000003oool0000000L0o`0000<000000?ooo`00
00001`3o00000`000000oooo000000070?l000030000003oool0000000L0o`0000<000000?ooo`00
00001`3o00000`000000oooo00000008000000/0oooo00<000000?l0003o00001@3o00000`000000
oooo0?ooo`030?ooo`X00000103o00000`000000oooo0?ooo`090?ooo`030000003o0000o`0000D0
o`0000<000000?ooo`0000001P3o00000`000000oooo0?ooo`2c0?ooo`007P3oool00`000000oooo
000000070?l000030000003oool0000000L0o`0000<000000?ooo`0000001`3o00000`000000oooo
000000070?l000030000003oool0000000H0o`0000<000000?ooo`0000001`3o00000`000000oooo
000000070?l000030000003oool0000000L0o`0000<000000?ooo`0000001`3o00000`000000oooo
000000070?l000030000003oool0000000L0o`0000<000000?ooo`0000001`3o00000`000000oooo
000000070?l000030000003oool0000000L0o`0000<000000?ooo`0000001`3o00000`000000oooo
000000070?l000030000003oool0000000L0o`0000<000000?ooo`0000001P3o00000`000000oooo
000000070?l000030000003oool0000000L0o`0000<000000?ooo`0000001`3o00000`000000oooo
000000070?l000030000003oool0000000L0o`0000<000000?ooo`0000002000000E0?ooo`030000
003o0000o`0000@0o`001`0000060?ooo`030000003o0000o`0000D0o`0000<000000?ooo`3oool0
2@3oool9000000030?ooo`000000000000H00000]@3oool001h0oooo00<000000?ooo`0000001`3o
00000`000000oooo000000070?l000030000003oool0000000L0o`0000<000000?ooo`0000001`3o
00000`000000oooo000000060?l000030000003oool0000000L0o`0000<000000?ooo`0000001`3o
00000`000000oooo000000070?l000030000003oool0000000L0o`0000<000000?ooo`0000001`3o
00000`000000oooo000000070?l000030000003oool0000000L0o`0000<000000?ooo`0000001`3o
00000`000000oooo000000070?l000030000003oool0000000L0o`0000<000000?ooo`0000001`3o
00000`000000oooo000000070?l000030000003oool0000000H0o`0000<000000?ooo`0000001`3o
00000`000000oooo000000070?l000030000003oool0000000L0o`0000<000000?ooo`0000001`3o
00000`000000oooo000000070?l000030000003oool0oooo01d0oooo00<000000?l0000000001000
00000`3o000000000?ooo`0:0?ooo`030000003o0000o`0000D0o`0000<000000?ooo`3oool0d03o
ool001h0oooo00<000000?ooo`0000001`3o00000`000000oooo000000070?l000030000003oool0
000000L0o`0000<000000?ooo`0000001`3o00000`000000oooo000000060?l000030000003oool0
000000L0o`0000<000000?ooo`0000001`3o00000`000000oooo000000070?l000030000003oool0
000000L0o`0000<000000?ooo`0000001`3o00000`000000oooo000000070?l000030000003oool0
000000L0o`0000<000000?ooo`0000001`3o00000`000000oooo000000070?l000030000003oool0
000000L0o`0000<000000?ooo`0000001`3o00000`000000oooo000000070?l000030000003oool0
000000H0o`0000<000000?ooo`0000001`3o00000`000000oooo000000070?l000030000003oool0
000000L0o`0000<000000?ooo`0000001`3o00000`000000oooo000000070?l000030000003oool0
oooo01L0oooo200000060?l000030000003oool0oooo00T0oooo00<000000?l0003o00001@3o0000
0`000000oooo0?ooo`3@0?ooo`007P3oool00`000000oooo000000070?l000030000003oool00000
00L0o`0000<000000?ooo`0000001`3o00000`000000oooo000000070?l000030000003oool00000
00H0o`0000<000000?ooo`0000001`3o00000`000000oooo000000070?l000030000003oool00000
00L0o`0000<000000?ooo`0000001`3o00000`000000oooo000000070?l000030000003oool00000
00L0o`0000<000000?ooo`0000001`3o00000`000000oooo000000070?l000030000003oool00000
00L0o`0000<000000?ooo`0000001`3o00000`000000oooo000000070?l000030000003oool00000
00L0o`0000<000000?ooo`0000001P3o00000`000000oooo000000070?l000030000003oool00000
00L0o`0000<000000?ooo`0000001`3o00000`000000oooo000000070?l000030000003oool00000
00L0o`0000<000000?ooo`3oool0403oool7000000H0oooo00<000000?l0003o00001@3o00000`00
0000oooo0?ooo`090?ooo`T00000dP3oool001h0oooo00<000000?ooo`0000001`3o00000`000000
oooo000000070?l000030000003oool0000000L0o`0000<000000?ooo`0000001`3o00000`000000
oooo000000060?l000030000003oool0000000L0o`0000<000000?ooo`0000001`3o00000`000000
oooo000000070?l000030000003oool0000000L0o`0000<000000?ooo`0000001`3o00000`000000
oooo000000070?l000030000003oool0000000L0o`0000<000000?ooo`0000001`3o00000`000000
oooo000000070?l000030000003oool0000000L0o`0000<000000?ooo`0000001`3o00000`000000
oooo000000070?l000030000003oool0000000H0o`0000<000000?ooo`0000001`3o00000`000000
oooo000000070?l000030000003oool0000000L0o`0000<000000?ooo`0000001`3o00000`000000
oooo000000070?l000030000003oool0oooo00/0oooo1@00000=0?ooo`030000003o0000o`0000D0
o`0000<000000?ooo`3oool0i03oool001h0oooo00<000000?ooo`0000001`3o00000`000000oooo
000000070?l000030000003oool0000000L0o`0000<000000?ooo`0000001`3o00000`000000oooo
000000060?l000030000003oool0000000L0o`0000<000000?ooo`0000001`3o00000`000000oooo
000000070?l000030000003oool0000000L0o`0000<000000?ooo`0000001`3o00000`000000oooo
000000070?l000030000003oool0000000L0o`0000<000000?ooo`0000001`3o00000`000000oooo
000000070?l000030000003oool0000000L0o`0000<000000?ooo`0000001`3o00000`000000oooo
000000070?l000030000003oool0000000H0o`0000<000000?ooo`0000001`3o00000`000000oooo
000000070?l000030000003oool0000000P0000000<0oooo0000000000001`0000000`3oool00000
0?l000060?l000030000003oool0oooo00H0oooo1@00000B0?ooo`030000003o0000o`0000D0o`00
00<000000?ooo`3oool0i03oool001h0oooo0`0000070?l000030000003oool0000000L0o`0000<0
00000?ooo`0000001`3o00000`000000oooo000000070?l000030000003oool0000000H0o`0000<0
00000?ooo`0000001`3o00000`000000oooo000000070?l000030000003oool0000000L0o`0000<0
00000?ooo`0000001`3o00000`000000oooo000000070?l000030000003oool0000000L0o`0000<0
00000?ooo`0000001`3o00000`000000oooo000000070?l000030000003oool0000000L0o`0000<0
00000?ooo`0000001`3o00000`000000oooo000000070?l000030000003oool0000000L0o`0000<0
00000?ooo`0000001P3o00000`000000oooo000000070?l000030000003oool0000000L0o`0000<0
00000?ooo`3oool04`3oool00`000000o`000?l000050?l000040000003oool0oooo0?ooo`D00000
5`3oool00`000000o`000?l000050?l000030000003oool0oooo0>@0oooo000N0?ooo`030000003o
ool0000000L0o`0000<000000?ooo`0000001`3o00000`000000oooo000000070?l000030000003o
ool0000000L0o`0000<000000?ooo`0000001P3o00000`000000oooo000000070?l000030000003o
ool0000000L0o`0000<000000?ooo`0000001`3o00000`000000oooo000000070?l000030000003o
ool0000000L0o`0000<000000?ooo`0000001`3o00000`000000oooo000000070?l000030000003o
ool0000000L0o`0000<000000?ooo`0000001`3o00000`000000oooo000000070?l000030000003o
ool0000000L0o`0000<000000?ooo`0000001`3o00000`000000oooo000000060?l000030000003o
ool0000000L0o`0000<000000?ooo`0000001`3o00000`000000oooo0?ooo`0C0?ooo`030000003o
0000o`0000@0o`001@00000L0?ooo`030000003o0000o`0000D0o`0000<000000?ooo`3oool0i03o
ool001h0oooo00<000000?ooo`0000001`3o00000`000000oooo000000070?l000030000003oool0
000000L0o`0000<000000?ooo`0000001`3o00000`000000oooo000000060?l000030000003oool0
000000L0o`0000<000000?ooo`0000001`3o00000`000000oooo000000070?l000030000003oool0
000000L0o`0000<000000?ooo`0000001`3o00000`000000oooo000000070?l000030000003oool0
000000L0o`0000<000000?ooo`0000001`3o00000`000000oooo000000070?l000030000003oool0
000000L0o`0000<000000?ooo`0000001`3o00000`000000oooo000000070?l000030000003oool0
000000H0o`0000<000000?ooo`0000001`3o00000`000000oooo000000070?l000030000003oool0
oooo01<0oooo00<000000?l000000000100000000`3o000000000?ooo`0N0?ooo`030000003o0000
o`0000D0o`0000<000000?ooo`3oool0i03oool001h0oooo00<000000?ooo`0000001`3o00000`00
0000oooo000000070?l000030000003oool0000000L0o`0000<000000?ooo`0000001`3o00000`00
0000oooo000000060?l000030000003oool0000000L0o`0000<000000?ooo`0000001`3o00000`00
0000oooo000000070?l000030000003oool0000000L0o`0000<000000?ooo`0000001`3o00000`00
0000oooo000000070?l000030000003oool0000000L0o`0000<000000?ooo`0000001`3o00000`00
0000oooo000000070?l000030000003oool0000000L0o`0000<000000?ooo`0000001`3o00000`00
0000oooo000000070?l000030000003oool0000000H0o`0000<000000?ooo`0000001`3o00000`00
0000oooo000000070?l000030000003oool0oooo0100oooo3000000O0?ooo`030000003o0000o`00
00D0o`0000<000000?ooo`3oool0i03oool001h0oooo00<000000?ooo`0000001`3o00000`000000
oooo000000070?l000030000003oool0000000L0o`0000<000000?ooo`0000001`3o00000`000000
oooo000000060?l000030000003oool0000000L0o`0000<000000?ooo`0000001`3o00000`000000
oooo000000070?l000030000003oool0000000L0o`0000<000000?ooo`0000001`3o00000`000000
oooo000000070?l000030000003oool0000000P0000000<0oooo0000003o00001P3o00000`000000
oooo000000070?l000030000003oool0000000L0o`0000<000000?ooo`0000001`3o00000`000000
oooo000000070?l000030000003oool0000000H0o`0000<000000?ooo`0000001`3o00000`000000
oooo000000070?l000030000003oool0oooo00/0oooo1@00000[0?ooo`030000003o0000o`0000D0
o`0000<000000?ooo`3oool0i03oool001h0oooo00<000000?ooo`0000001`3o00000`000000oooo
000000070?l000030000003oool0000000L0o`0000<000000?ooo`0000001`3o00000`000000oooo
000000060?l000030000003oool0000000L0o`0000<000000?ooo`0000001`3o00000`000000oooo
000000070?l000030000003oool0000000L0o`0000<000000?ooo`0000001`3o00000`000000oooo
000000070?l000030000003oool0oooo00T0oooo00<000000?l0003o00001@3o00000`000000oooo
000000070?l000030000003oool0000000L0o`0000<000000?ooo`0000001`3o00000`000000oooo
000000070?l000030000003oool0000000H0o`0000<000000?ooo`0000001`3o00000`000000oooo
000000070?l000030000003oool0oooo00H0oooo1@00000`0?ooo`T00000iP3oool001h0oooo00<0
00000?ooo`0000001`3o00000`000000oooo000000070?l000030000003oool0000000L0o`0000<0
00000?ooo`0000001`3o00000`000000oooo000000060?l000030000003oool0000000L0o`0000<0
00000?ooo`0000001`3o00000`000000oooo000000070?l000030000003oool0000000L0o`0000<0
00000?ooo`0000001`3o00000`000000oooo000000070?l000030000003oool0oooo00T0oooo00<0
00000?l0003o00001@3o00000`000000oooo000000070?l000030000003oool0000000L0o`0000<0
00000?ooo`0000001`3o00000`000000oooo000000070?l000030000003oool0000000H0o`0000<0
00000?ooo`0000001`3o00000`000000oooo000000070?l000030000003oool0oooo00<0oooo0`00
003o0?ooobD0oooo000N0?ooo`030000003oool0000000L0o`0000<000000?ooo`0000001`3o0000
0`000000oooo000000070?l000030000003oool0000000L0o`0000<000000?ooo`0000001P3o0000
0`000000oooo000000070?l000030000003oool0000000L0o`0000<000000?ooo`0000001`3o0000
0`000000oooo000000070?l000030000003oool0000000L0o`0000<000000?ooo`0000001`3o0000
0`000000oooo0?ooo`090?ooo`030000003o0000o`0000D0o`0000<000000?ooo`0000001`3o0000
0`000000oooo000000070?l000030000003oool0000000L0o`0000<000000?ooo`0000001`3o0000
0`000000oooo000000060?l000030000003oool0000000L0o`0000<000000?ooo`0000001`3o0000
0`000000oooo0?ooo`0300000?l0oooo:03oool001h0oooo00<000000?ooo`0000001`3o00000`00
0000oooo000000070?l000030000003oool0000000L0o`0000<000000?ooo`0000001`3o00000`00
0000oooo000000060?l000030000003oool0000000L0o`0000<000000?ooo`0000001`3o00000`00
0000oooo000000070?l000030000003oool0000000L0o`0000<000000?ooo`0000001`3o00000`00
0000oooo000000070?l000030000003oool0oooo00T0oooo00<000000?l0003o00001@3o00000`00
0000oooo000000070?l000030000003oool0000000L0o`0000<000000?ooo`0000001`3o00000`00
0000oooo000000070?l000030000003oool0000000H0o`0000<000000?ooo`0000001`3o00000`00
0000oooo000000060?l000@00000o`3oool[0?ooo`007P3oool00`000000oooo000000070?l00003
0000003oool0000000L0o`0000<000000?ooo`0000001`3o00000`000000oooo000000070?l00003
0000003oool0000000H0o`0000<000000?ooo`0000001`3o00000`000000oooo000000070?l00003
0000003oool0000000L0o`0000<000000?ooo`0000001`3o00000`000000oooo000000070?l00003
0000003oool0000000L0o`0000<000000?ooo`3oool02@3oool00`000000o`000?l000050?l00003
0000003oool0000000L0o`0000<000000?ooo`0000001`3o00000`000000oooo000000070?l00003
0000003oool0000000L0o`0000<000000?ooo`0000001P3o00000`000000oooo000000070?l00003
0000003oool0000000<0o`000`0000000`3o000000000?ooo`3o0?ooob`0oooo000N0?ooo`<00000
1`3o00000`000000oooo000000070?l000030000003oool0000000L0o`0000<000000?ooo`000000
1`3o00000`000000oooo000000060?l000030000003oool0000000L0o`0000<000000?ooo`000000
1`3o00000`000000oooo000000070?l000030000003oool0000000L0o`0000<000000?ooo`000000
1`3o00000`000000oooo000000070?l000030000003oool0oooo00T0oooo00<000000?l0003o0000
1@3o00000`000000oooo000000070?l000030000003oool0000000L0o`0000<000000?ooo`000000
1`3o00000`000000oooo000000070?l000030000003oool0000000H0o`0000<000000?ooo`000000
1`3o00000`000000oooo00000003000000@0o`0000<000000?ooo`3oool0o`3oool[0?ooo`007P3o
ool00`000000oooo000000070?l000030000003oool0000000L0o`0000<000000?ooo`0000001`3o
00000`000000oooo000000070?l000030000003oool0000000H0o`0000<000000?ooo`0000001`3o
00000`000000oooo000000070?l000030000003oool0000000L0o`0000<000000?ooo`0000001`3o
00000`000000oooo000000070?l000030000003oool0000000L0o`0000<000000?ooo`3oool02@3o
ool00`000000o`000?l000050?l000030000003oool0000000L0o`0000<000000?ooo`0000001`3o
00000`000000oooo000000070?l000030000003oool0000000P0000000<0oooo0000003o00001@3o
00000`000000oooo0000000:000000L0o`0000<000000?ooo`3oool0o`3oool[0?ooo`007P3oool0
0`000000oooo000000070?l000030000003oool0000000L0o`0000<000000?ooo`0000001`3o0000
0`000000oooo000000070?l000030000003oool0000000H0o`0000<000000?ooo`0000001`3o0000
0`000000oooo000000070?l000030000003oool0000000L0o`0000<000000?ooo`0000001`3o0000
0`000000oooo000000070?l000030000003oool0000000L0o`0000<000000?ooo`3oool02@3oool0
0`000000o`000?l000050?l000030000003oool0000000L0o`0000<000000?ooo`0000001`3o0000
0`000000oooo000000070?l000030000003oool0oooo00T0oooo200000050?ooo`<000000`3oool0
0`000000o`000?l000050?l000030000003oool0oooo0?l0oooo:`3oool001h0oooo00<000000?oo
o`0000001`3o00000`000000oooo000000070?l000030000003oool0000000L0o`0000<000000?oo
o`0000001`3o00000`000000oooo000000060?l000030000003oool0000000L0o`0000<000000?oo
o`0000001`3o00000`000000oooo000000070?l000030000003oool0000000L0o`0000<000000?oo
o`0000001`3o00000`000000oooo000000070?l000030000003oool0oooo00T0oooo00<000000?l0
003o00001@3o00000`000000oooo000000070?l000030000003oool0000000L0o`0000<000000?oo
o`0000001`3o00000`000000oooo0?ooo`0C0?ooo`<000001P3oool00`000000o`000?l000050?l0
00030000003oool0oooo0?l0oooo:`3oool001h0oooo00<000000?ooo`0000001`3o00000`000000
oooo000000070?l000030000003oool0000000L0o`0000<000000?ooo`0000001`3o00000`000000
oooo000000060?l000030000003oool0000000L0o`0000<000000?ooo`0000001`3o00000`000000
oooo000000070?l000030000003oool0000000L0o`0000<000000?ooo`0000001`3o00000`000000
oooo000000070?l000030000003oool0oooo00T0oooo00<000000?l0003o00001@3o00000`000000
oooo000000070?l000030000003oool0000000L0o`0000<000000?ooo`0000001`3o00000`000000
oooo0?ooo`0@0?ooo`<000002@3oool00`000000o`000?l000050?l000030000003oool0oooo0?l0
oooo:`3oool001h0oooo00<000000?ooo`0000001`3o00000`000000oooo000000070?l000030000
003oool0000000L0o`0000<000000?ooo`0000001`3o00000`000000oooo000000060?l000030000
003oool0000000L0o`0000<000000?ooo`0000001`3o00000`000000oooo000000070?l000030000
003oool0000000L0o`0000<000000?ooo`0000001`3o00000`000000oooo000000070?l000030000
003oool0oooo00T0oooo00<000000?l0003o00001@3o00000`000000oooo000000070?l000030000
003oool0000000L0o`0000<000000?ooo`0000001`3o00000`000000oooo0?ooo`0=0?ooo`<00000
303oool00`000000o`000?l000050?l000030000003oool0oooo0?l0oooo:`3oool001h0oooo00<0
00000?ooo`0000001`3o00000`000000oooo000000070?l000030000003oool0000000L0o`0000<0
00000?ooo`0000001`3o00000`000000oooo000000060?l000030000003oool0000000L0o`0000<0
00000?ooo`0000001`3o00000`000000oooo000000070?l000030000003oool0000000L0o`0000<0
00000?ooo`0000001`3o00000`000000oooo000000070?l000030000003oool0oooo00T0oooo00<0
00000?l0003o00001@3o00000`000000oooo000000070?l000030000003oool0000000P0000000<0
oooo0000003o00001P3o00000`000000oooo0?ooo`0:0?ooo`<000003`3oool00`000000o`000?l0
00050?l000030000003oool0oooo0?l0oooo:`3oool000H0oooo1@0000030?ooo`800000103oool2
000000P0oooo00<000000?ooo`0000001`3o00000`000000oooo000000070?l000030000003oool0
000000L0o`0000<000000?ooo`0000001`3o00000`000000oooo000000060?l000030000003oool0
000000L0o`0000<000000?ooo`0000001`3o00000`000000oooo000000070?l000030000003oool0
000000L0o`0000<000000?ooo`0000001`3o00000`000000oooo000000070?l000030000003oool0
oooo00T0oooo00<000000?l0003o00001@3o00000`000000oooo000000070?l000030000003oool0
oooo00T0oooo00<000000?l0003o00001@3o00000`000000oooo0?ooo`070?ooo`<000004P3oool0
0`000000o`000?l000050?l000030000003oool0oooo0?l0oooo:`3oool000L0oooo00@000000?oo
o`3oool000000P3oool010000000oooo0?ooo`0000020?ooo`040000003oool0oooo000000L0oooo
00<000000?ooo`0000001`3o00000`000000oooo000000070?l000030000003oool0000000L0o`00
00<000000?ooo`0000001`3o00000`000000oooo000000060?l000030000003oool0000000L0o`00
00<000000?ooo`0000001`3o00000`000000oooo000000070?l000030000003oool0000000L0o`00
00<000000?ooo`0000001`3o00000`000000oooo000000070?l000030000003oool0oooo00T0oooo
00<000000?l0003o00001@3o00000`000000oooo000000070?l000030000003oool0oooo00T0oooo
00<000000?l0003o00001@3o00000`000000oooo0?ooo`040?ooo`<000005@3oool00`000000o`00
0?l000050?l000030000003oool0oooo0?l0oooo:`3oool000P0oooo00<000000?ooo`3oool00P3o
ool010000000oooo0?ooo`0000020?ooo`040000003oool0oooo000000L0oooo00<000000?ooo`00
00001`3o00000`000000oooo000000070?l000030000003oool0000000L0o`0000<000000?ooo`00
00001`3o00000`000000oooo000000060?l000030000003oool0000000L0o`0000<000000?ooo`00
00001`3o00000`000000oooo000000070?l000030000003oool0000000L0o`0000<000000?ooo`00
00001`3o00000`000000oooo000000070?l000030000003oool0oooo00T0oooo00<000000?l0003o
00001@3o00000`000000oooo000000070?l000030000003oool0oooo00T0oooo00<000000?l0003o
00001@3o00000`000000oooo0?ooo`020?ooo`800000603oool00`000000o`000?l000050?l00003
0000003oool0oooo0?l0oooo:`3oool000T0oooo00D000000?ooo`3oool0oooo000000020?ooo`04
0000003oool0oooo00000080oooo00<000000?ooo`3oool01@3oool3000000L0o`0000<000000?oo
o`0000001`3o00000`000000oooo000000070?l000030000003oool0000000L0o`0000<000000?oo
o`0000001P3o00000`000000oooo000000070?l000030000003oool0000000L0o`0000<000000?oo
o`0000001`3o00000`000000oooo000000070?l000030000003oool0000000L0o`0000<000000?oo
o`0000001`3o00000`000000oooo0?ooo`090?ooo`030000003o0000o`0000D0o`0000<000000?oo
o`0000001`3o00000`000000oooo0?ooo`090?ooo`030000003o0000o`0000D0o`0000<000000?oo
o`0000000P00000J0?ooo`030000003o0000o`0000D0o`0000<000000?ooo`3oool0o`3oool[0?oo
o`001P3oool01@000000oooo0?ooo`3oool000000080oooo00@000000?ooo`3oool000000P3oool0
10000000oooo0?ooo`0000070?ooo`030000003oool0000000L0o`0000<000000?ooo`0000001`3o
00000`000000oooo000000070?l000030000003oool0000000L0o`0000<000000?ooo`0000001P3o
00000`000000oooo000000070?l000030000003oool0000000L0o`0000<000000?ooo`0000001`3o
00000`000000oooo000000070?l000030000003oool0000000L0o`0000<000000?ooo`0000001`3o
00000`000000oooo0?ooo`090?ooo`030000003o0000o`0000D0o`0000<000000?ooo`0000001`3o
00000`000000oooo0?ooo`090?ooo`030000003o0000o`0000D0o`000P00000M0?ooo`030000003o
0000o`0000D0o`0000<000000?ooo`3oool0o`3oool[0?ooo`001P3oool01@000000oooo0?ooo`3o
ool000000080oooo00@000000?ooo`3oool000000P3oool010000000oooo0?ooo`0000070?ooo`03
0000003oool0000000L0o`0000<000000?ooo`0000001`3o00000`000000oooo000000070?l00003
0000003oool0000000L0o`0000<000000?ooo`0000001P3o00000`000000oooo000000070?l00003
0000003oool0000000L0o`0000<000000?ooo`0000001`3o00000`000000oooo000000070?l00003
0000003oool0000000L0o`0000<000000?ooo`0000001`3o00000`000000oooo0?ooo`090?ooo`03
0000003o0000o`0000D0o`0000<000000?ooo`0000001`3o00000`000000oooo0?ooo`090?ooo`03
0000003o0000o`000080o`001000000N0?ooo`030000003o0000o`0000D0o`0000<000000?ooo`3o
ool0o`3oool[0?ooo`001`3oool3000000@0oooo0P0000040?ooo`800000203oool00`000000oooo
000000070?l000030000003oool0000000L0o`0000<000000?ooo`0000001`3o00000`000000oooo
000000070?l000030000003oool0000000H0o`0000<000000?ooo`0000001`3o00000`000000oooo
000000070?l000030000003oool0000000L0o`0000<000000?ooo`0000001`3o00000`000000oooo
000000070?l000030000003oool0000000L0o`0000<000000?ooo`3oool02@3oool00`000000o`00
0?l000050?l000030000003oool0000000L0o`0000<000000?ooo`3oool02@3oool00`000000o`00
0?l00002000000<0o`0000<000000?ooo`3oool0703oool00`000000o`000?l000050?l000030000
003oool0oooo0?l0oooo:`3oool001h0oooo00<000000?ooo`0000001`3o00000`000000oooo0000
00070?l000030000003oool0000000L0o`0000<000000?ooo`0000001`3o00000`000000oooo0000
00060?l000030000003oool0000000L0o`0000<000000?ooo`0000001`3o00000`000000oooo0000
00070?l000030000003oool0000000L0o`0000<000000?ooo`0000001`3o00000`000000oooo0000
00070?l000030000003oool0oooo00T0oooo00<000000?l0003o00001@3o00000`000000oooo0000
00070?l000030000003oool0oooo00T0oooo0`0000050?l000030000003oool0oooo01`0oooo2@00
003o0?ooobd0oooo000N0?ooo`030000003oool0000000L0o`0000<000000?ooo`0000001`3o0000
0`000000oooo000000070?l000030000003oool0000000L0o`0000<000000?ooo`0000001P3o0000
0`000000oooo000000070?l000030000003oool0000000L0o`0000<000000?ooo`0000001`3o0000
0`000000oooo000000070?l000030000003oool0000000L0o`0000<000000?ooo`0000001`3o0000
0`000000oooo0?ooo`090?ooo`030000003o0000o`0000D0o`0000<000000?ooo`0000001`3o0000
0`000000oooo0?ooo`070?ooo`<000001`3o00000`000000oooo0?ooo`3o0?oooe80oooo000N0?oo
o`030000003oool0000000L0o`0000<000000?ooo`0000001`3o00000`000000oooo000000070?l0
00030000003oool0000000L0o`0000<000000?ooo`0000001P3o00000`000000oooo000000070?l0
00030000003oool0000000L0o`0000<000000?ooo`0000001`3o00000`000000oooo000000070?l0
00030000003oool0000000L0o`0000<000000?ooo`0000001`3o00000`000000oooo0?ooo`090?oo
o`030000003o0000o`0000D0o`0000<000000?ooo`0000001`3o00000`000000oooo0?ooo`050?oo
o`8000000P3oool00`000000o`000?l000050?l000030000003oool0oooo0?l0ooooDP3oool001h0
oooo00<000000?ooo`0000001`3o00000`000000oooo000000070?l000030000003oool0000000L0
o`0000<000000?ooo`0000001`3o00000`000000oooo000000060?l000030000003oool0000000L0
o`0000<000000?ooo`0000001`3o00000`000000oooo000000070?l000030000003oool0000000L0
o`0000<000000?ooo`0000001`3o00000`000000oooo000000070?l000030000003oool0oooo00T0
oooo00<000000?l0003o00001@3o00000`000000oooo000000070?l000030000003oool0oooo00<0
oooo0P0000040?ooo`030000003o0000o`0000D0o`0000<000000?ooo`3oool0o`3ooomB0?ooo`00
7P3oool00`000000oooo000000070?l000030000003oool0000000L0o`0000<000000?ooo`000000
1`3o00000`000000oooo000000070?l000030000003oool0000000H0o`0000<000000?ooo`000000
1`3o00000`000000oooo000000070?l000030000003oool0000000L0o`0000<000000?ooo`000000
1`3o00000`000000oooo000000070?l000030000003oool0000000L0o`0000<000000?ooo`3oool0
2@3oool00`000000o`000?l000050?l000030000003oool0000000L0o`0000@000000?ooo`3oool0
oooo0P0000060?ooo`030000003o0000o`0000D0o`0000<000000?ooo`3oool0o`3ooomB0?ooo`00
7P3oool3000000L0o`0000<000000?ooo`0000001`3o00000`000000oooo000000070?l000030000
003oool0000000L0o`0000<000000?ooo`0000001P3o00000`000000oooo000000070?l000030000
003oool0000000L0o`0000<000000?ooo`0000001`3o00000`000000oooo000000070?l000030000
003oool0000000L0o`0000<000000?ooo`0000001`3o00000`000000oooo0?ooo`090?ooo`030000
003o0000o`0000D0o`0000<000000?ooo`000000200000000`3oool00000000000080?ooo`030000
003o0000o`0000D0o`0000<000000?ooo`3oool0o`3ooomB0?ooo`007P3oool00`000000oooo0000
00070?l000030000003oool0000000L0o`0000<000000?ooo`0000001`3o00000`000000oooo0000
00070?l000030000003oool0000000H0o`0000<000000?ooo`0000001`3o00000`000000oooo0000
00070?l000030000003oool0000000L0o`0000<000000?ooo`0000001`3o00000`000000oooo0000
00070?l000030000003oool0000000L0o`0000<000000?ooo`3oool02@3oool00`000000o`000?l0
00050?l000030000003oool0oooo00L0oooo0P00000:0?ooo`030000003o0000o`0000D0o`0000<0
00000?ooo`3oool0o`3ooomB0?ooo`007P3oool00`000000oooo000000070?l000030000003oool0
000000L0o`0000<000000?ooo`0000001`3o00000`000000oooo000000070?l000030000003oool0
000000H0o`0000<000000?ooo`0000001`3o00000`000000oooo000000070?l000030000003oool0
000000L0o`0000<000000?ooo`0000001`3o00000`000000oooo000000070?l000030000003oool0
000000L0o`0000<000000?ooo`3oool02@3oool00`000000o`000?l000050?l000030000003oool0
oooo00D0oooo0P00000<0?ooo`030000003o0000o`0000D0o`0000<000000?ooo`3oool0o`3ooomB
0?ooo`007P3oool00`000000oooo000000070?l000030000003oool0000000L0o`0000<000000?oo
o`0000001`3o00000`000000oooo000000070?l000030000003oool0000000H0o`0000<000000?oo
o`0000001`3o00000`000000oooo000000070?l000030000003oool0000000L0o`0000<000000?oo
o`0000001`3o00000`000000oooo000000070?l000030000003oool0000000L0o`0000<000000?oo
o`3oool02@3oool00`000000o`000?l000050?l000030000003oool0oooo00<0oooo0P00000>0?oo
o`030000003o0000o`0000D0o`0000<000000?ooo`3oool0o`3ooomB0?ooo`007P3oool00`000000
oooo000000070?l000030000003oool0000000L0o`0000<000000?ooo`0000001`3o00000`000000
oooo000000070?l000030000003oool0000000H0o`0000<000000?ooo`0000001`3o00000`000000
oooo000000070?l000030000003oool0000000L0o`0000<000000?ooo`0000001`3o00000`000000
oooo000000070?l000030000003oool0000000L0o`0000<000000?ooo`3oool02@3oool00`000000
o`000?l000050?l000040000003oool0oooo0?ooo`800000403oool00`000000o`000?l000050?l0
00030000003oool0oooo0?l0ooooDP3oool001h0oooo00<000000?ooo`0000001`3o00000`000000
oooo000000070?l000030000003oool0000000L0o`0000<000000?ooo`0000001`3o00000`000000
oooo000000060?l000030000003oool0000000L0o`0000<000000?ooo`0000001`3o00000`000000
oooo000000070?l000030000003oool0000000L0o`0000<000000?ooo`0000001`3o00000`000000
oooo000000070?l000030000003oool0oooo00T0oooo00<000000?l0003o00001@3o000010000000
oooo00000000000B0?ooo`030000003o0000o`0000D0o`0000<000000?ooo`3oool0o`3ooomB0?oo
o`007P3oool00`000000oooo000000070?l000030000003oool0000000L0o`0000<000000?ooo`00
00001`3o00000`000000oooo000000070?l000030000003oool0000000H0o`0000<000000?ooo`00
00001`3o00000`000000oooo000000070?l000030000003oool0000000L0o`0000<000000?ooo`00
00001`3o00000`000000oooo000000070?l000030000003oool0000000L0o`0000<000000?ooo`3o
ool02@3oool00`000000o`000?l000050?l000800000503oool00`000000o`000?l000050?l00003
0000003oool0oooo0?l0ooooDP3oool001h0oooo00<000000?ooo`0000001`3o00000`000000oooo
000000070?l000030000003oool0000000L0o`0000<000000?ooo`0000001`3o00000`000000oooo
000000060?l000030000003oool0000000L0o`0000<000000?ooo`0000001`3o00000`000000oooo
000000070?l000030000003oool0000000L0o`0000<000000?ooo`0000001`3o00000`000000oooo
000000070?l000030000003oool0oooo00T0oooo00<000000?l0003o00000`3o0003000001D0oooo
00<000000?l0003o00001@3o00000`000000oooo0?ooo`3o0?oooe80oooo000N0?ooo`030000003o
ool0000000L0o`0000<000000?ooo`0000001`3o00000`000000oooo000000070?l000030000003o
ool0000000L0o`0000<000000?ooo`0000001P3o00000`000000oooo000000070?l000030000003o
ool0000000L0o`0000<000000?ooo`0000001`3o00000`000000oooo000000070?l000030000003o
ool0000000L0o`0000<000000?ooo`0000001`3o00000`000000oooo0?ooo`090?ooo`040000003o
0000o`000?l0008000000P3o00000`000000oooo0?ooo`0C0?ooo`030000003o0000o`0000D0o`00
00<000000?ooo`3oool0o`3ooomB0?ooo`007P3oool00`000000oooo000000070?l000030000003o
ool0000000L0o`0000<000000?ooo`0000001`3o00000`000000oooo000000070?l000030000003o
ool0000000H0o`0000<000000?ooo`0000001`3o00000`000000oooo000000070?l000030000003o
ool0000000L0o`0000<000000?ooo`0000001`3o00000`000000oooo000000070?l000030000003o
ool0000000L0o`0000<000000?ooo`3oool02@3oool010000000o`000000000000040?l000030000
003oool0oooo01<0oooo00<000000?l0003o00001@3o00000`000000oooo0?ooo`3o0?oooe80oooo
000N0?ooo`<000001`3o00000`000000oooo000000070?l000030000003oool0000000L0o`0000<0
00000?ooo`0000001`3o00000`000000oooo000000060?l000030000003oool0000000L0o`0000<0
00000?ooo`0000001`3o00000`000000oooo000000070?l000030000003oool0000000L0o`0000<0
00000?ooo`0000001`3o00000`000000oooo000000070?l000030000003oool0oooo00T0oooo0P00
00060?l000030000003oool0oooo01<0oooo2@00003o0?oooe@0oooo000N0?ooo`030000003oool0
000000L0o`0000<000000?ooo`0000001`3o00000`000000oooo000000070?l000030000003oool0
000000L0o`0000<000000?ooo`0000001P3o00000`000000oooo000000070?l000030000003oool0
000000L0o`0000<000000?ooo`0000001`3o00000`000000oooo000000070?l000030000003oool0
000000L0o`0000<000000?ooo`0000001`3o00000`000000oooo0?ooo`070?ooo`<000001`3o0000
0`000000oooo0?ooo`3o0?ooog00oooo000N0?ooo`030000003oool0000000L0o`0000<000000?oo
o`0000001`3o00000`000000oooo000000070?l000030000003oool0000000L0o`0000<000000?oo
o`0000001P3o00000`000000oooo000000070?l000030000003oool0000000L0o`0000<000000?oo
o`0000001`3o00000`000000oooo000000070?l000030000003oool0000000L0o`0000<000000?oo
o`0000001`3o00000`000000oooo0?ooo`050?ooo`8000000P3oool00`000000o`000?l000050?l0
00030000003oool0oooo0?l0ooooL03oool001h0oooo00<000000?ooo`0000001`3o00000`000000
oooo000000070?l000030000003oool0000000L0o`0000<000000?ooo`0000001`3o00000`000000
oooo000000060?l000030000003oool0000000L0o`0000<000000?ooo`0000001`3o00000`000000
oooo000000070?l000030000003oool0000000L0o`0000<000000?ooo`0000001`3o00000`000000
oooo000000070?l000030000003oool0oooo00@0oooo00<000000?ooo`3oool00P3oool00`000000
o`000?l000050?l000030000003oool0oooo0?l0ooooL03oool001h0oooo00<000000?ooo`000000
1`3o00000`000000oooo000000070?l000030000003oool0000000L0o`0000<000000?ooo`000000
1`3o00000`000000oooo000000060?l000030000003oool0000000L0o`0000<000000?ooo`000000
1`3o00000`000000oooo000000070?l000030000003oool0000000L0o`0000<000000?ooo`000000
1`3o00000`000000oooo000000070?l000030000003oool0oooo0080oooo0P0000050?ooo`030000
003o0000o`0000D0o`0000<000000?ooo`3oool0o`3ooom`0?ooo`007P3oool00`000000oooo0000
00070?l000030000003oool0000000L0o`0000<000000?ooo`0000001`3o00000`000000oooo0000
00070?l000030000003oool0000000H0o`0000<000000?ooo`0000001`3o00000`000000oooo0000
00070?l000030000003oool0000000L0o`0000<000000?ooo`0000001`3o00000`000000oooo0000
00070?l000030000003oool0000000L0o`0000<000000?ooo`3oool00P0000070?ooo`T00000o`3o
oomb0?ooo`007P3oool00`000000oooo000000070?l000030000003oool0000000L0o`0000<00000
0?ooo`0000001`3o00000`000000oooo000000070?l000030000003oool0000000H0o`0000<00000
0?ooo`0000001`3o00000`000000oooo000000070?l000030000003oool0000000L0o`0000<00000
0?ooo`0000001`3o00000`000000oooo000000070?l000030000003oool0000000L0o`0000<00000
0?ooo`000000o`3ooon40?ooo`007P3oool00`000000oooo000000070?l000030000003oool00000
00L0o`0000<000000?ooo`0000001`3o00000`000000oooo000000070?l000030000003oool00000
00H0o`0000<000000?ooo`0000001`3o00000`000000oooo000000070?l000030000003oool00000
00L0o`0000<000000?ooo`0000001`3o00000`000000oooo000000070?l000030000003oool00000
00L0o`000P00003o0?ooohD0oooo000N0?ooo`030000003oool0000000L0o`0000<000000?ooo`00
00001`3o00000`000000oooo000000070?l000030000003oool0000000L0o`0000<000000?ooo`00
00001P3o00000`000000oooo000000070?l000030000003oool0000000L0o`0000<000000?ooo`00
00001`3o00000`000000oooo000000070?l000030000003oool0000000L0o`0000<000000?ooo`00
00001P3o000200000?l0ooooQP3oool001h0oooo0`0000070?l000030000003oool0000000L0o`00
00<000000?ooo`0000001`3o00000`000000oooo000000070?l000030000003oool0000000H0o`00
00<000000?ooo`0000001`3o00000`000000oooo00000008000000030?ooo`000000o`0000H0o`00
00<000000?ooo`0000001`3o00000`000000oooo000000070?l000030000003oool0000000@0o`00
0P0000000`3o000000000?ooo`3o0?ooohD0oooo000N0?ooo`030000003oool0000000L0o`0000<0
00000?ooo`0000001`3o00000`000000oooo000000070?l000030000003oool0000000L0o`0000<0
00000?ooo`0000001P3o00000`000000oooo000000070?l000030000003oool0oooo00T0oooo00<0
00000?l0003o00001@3o00000`000000oooo000000070?l000030000003oool0000000L0o`0000<0
00000?ooo`0000000`3o00001@000000o`000?l0003o000000000?l0ooooQP3oool001h0oooo00<0
00000?ooo`0000001`3o00000`000000oooo000000070?l000030000003oool0000000L0o`0000<0
00000?ooo`0000001`3o00000`000000oooo000000060?l000030000003oool0000000L0o`0000<0
00000?ooo`3oool02@3oool00`000000o`000?l000050?l000030000003oool0000000L0o`0000<0
00000?ooo`000000200000001@3oool000000?l0003o0000000000@0o`0000<000000?ooo`3oool0
o`3ooon40?ooo`007P3oool00`000000oooo000000070?l000030000003oool0000000L0o`0000<0
00000?ooo`0000001`3o00000`000000oooo000000070?l000030000003oool0000000H0o`0000<0
00000?ooo`0000001`3o00000`000000oooo0?ooo`090?ooo`030000003o0000o`0000D0o`0000<0
00000?ooo`0000001`3o00000`000000oooo0?ooo`090?ooo`<000001@3o00000`000000oooo0?oo
o`3o0?oooh@0oooo000N0?ooo`030000003oool0000000L0o`0000<000000?ooo`0000001`3o0000
0`000000oooo000000070?l000030000003oool0000000L0o`0000<000000?ooo`0000001P3o0000
0`000000oooo000000070?l000030000003oool0oooo00T0oooo00<000000?l0003o00001@3o0000
0`000000oooo000000070?l000030000003oool0oooo00T0oooo00<000000?l0003o00001@3o0000
0`000000oooo0?ooo`3o0?oooh@0oooo000N0?ooo`030000003oool0000000L0o`0000<000000?oo
o`0000001`3o00000`000000oooo000000070?l000030000003oool0000000L0o`0000<000000?oo
o`0000001P3o00000`000000oooo000000070?l000030000003oool0oooo00T0oooo00<000000?l0
003o00001@3o00000`000000oooo000000070?l000030000003oool0oooo00L0oooo0`0000070?l0
00030000003oool0oooo0?l0ooooQ03oool001h0oooo00<000000?ooo`0000001`3o00000`000000
oooo000000070?l000030000003oool0000000L0o`0000<000000?ooo`0000001`3o00000`000000
oooo000000060?l000030000003oool0000000L0o`0000<000000?ooo`3oool02@3oool00`000000
o`000?l000050?l000030000003oool0000000L0o`0000<000000?ooo`3oool01P3oool010000000
oooo0?ooo`0000070?l000030000003oool0oooo0?l0ooooQ03oool000P0oooo0`0000030?ooo`80
0000103oool2000000P0oooo00<000000?ooo`0000001`3o00000`000000oooo000000070?l00003
0000003oool0000000L0o`0000<000000?ooo`0000001`3o00000`000000oooo000000060?l00003
0000003oool0000000L0o`0000<000000?ooo`3oool02@3oool00`000000o`000?l000050?l00003
0000003oool0000000L0o`0000<000000?ooo`3oool01@3oool01@000000oooo0?ooo`3oool00000
00L0o`0000<000000?ooo`3oool0o`3ooon40?ooo`002@3oool01@000000oooo0?ooo`3oool00000
0080oooo00@000000?ooo`3oool000000P3oool00`000000oooo0?ooo`050?ooo`030000003oool0
000000L0o`0000<000000?ooo`0000001`3o00000`000000oooo000000070?l000030000003oool0
000000L0o`0000<000000?ooo`0000001P3o00000`000000oooo000000070?l000030000003oool0
oooo00T0oooo00<000000?l0003o00001@3o00000`000000oooo000000070?l000030000003oool0
oooo00@0oooo00<000000?ooo`3oool00P3oool00`000000o`000?l000050?l000030000003oool0
oooo0?l0ooooQ03oool000H0oooo1@0000020?ooo`040000003oool0oooo00000080oooo00@00000
0?ooo`3oool000001`3oool00`000000oooo000000070?l000030000003oool0000000L0o`0000<0
00000?ooo`0000001`3o00000`000000oooo000000070?l000030000003oool0000000H0o`0000<0
00000?ooo`0000001`3o00000`000000oooo0?ooo`090?ooo`030000003o0000o`0000D0o`0000<0
00000?ooo`0000001`3o00000`000000oooo0?ooo`020?ooo`8000001@3oool00`000000o`000?l0
00050?l000030000003oool0oooo0?l0ooooQ03oool000H0oooo00@000000?ooo`3oool000000`3o
ool010000000oooo0?ooo`0000020?ooo`040000003oool0oooo000000L0oooo0`0000070?l00003
0000003oool0000000L0o`0000<000000?ooo`0000001`3o00000`000000oooo000000070?l00003
0000003oool0000000H0o`0000<000000?ooo`0000001`3o00000`000000oooo0?ooo`090?ooo`03
0000003o0000o`0000D0o`0000<000000?ooo`0000001`3o00001@000000oooo0?ooo`3oool00000
00L0oooo00<000000?l0003o00001@3o00000`000000oooo0?ooo`3o0?oooh@0oooo00070?ooo`03
0000003oool0000000<0oooo00@000000?ooo`3oool000000P3oool010000000oooo0?ooo`000007
0?ooo`030000003oool0000000L0o`0000<000000?ooo`0000001`3o00000`000000oooo00000007
0?l000030000003oool0000000L0o`0000<000000?ooo`0000001P3o00000`000000oooo00000007
0?l000030000003oool0oooo00T0oooo00<000000?l0003o00001@3o00000`000000oooo00000007
0?l000040000003oool0oooo000000P0oooo00<000000?l0003o00001@3o00000`000000oooo0?oo
o`3o0?oooh@0oooo00080?ooo`8000000`3oool010000000oooo0?ooo`0000020?ooo`040000003o
ool0oooo000000L0oooo00<000000?ooo`0000001`3o00000`000000oooo000000070?l000030000
003oool0000000L0o`0000<000000?ooo`0000001`3o00000`000000oooo000000060?l000030000
003oool0000000L0o`0000<000000?ooo`3oool02@3oool00`000000o`000?l000050?l000030000
003oool0000000L0o`0000<000000?ooo`0000002@3oool00`000000o`000?l000050?l000030000
003oool0oooo0?l0ooooQ03oool000T0oooo00<000000?ooo`3oool00P3oool2000000@0oooo0P00
00080?ooo`030000003oool0000000L0o`0000<000000?ooo`0000001`3o00000`000000oooo0000
00070?l000030000003oool0000000L0o`0000<000000?ooo`0000001P3o00000`000000oooo0000
00070?l000030000003oool0oooo00T0oooo00<000000?l0003o00001@3o00000`000000oooo0000
00070?l0008000002P3oool00`000000o`000?l000050?l000030000003oool0oooo0?l0ooooQ03o
ool001h0oooo00<000000?ooo`0000001`3o00000`000000oooo000000070?l000030000003oool0
000000L0o`0000<000000?ooo`0000001`3o00000`000000oooo000000060?l000030000003oool0
000000L0o`0000<000000?ooo`3oool02@3oool00`000000o`000?l000050?l000030000003oool0
000000H0o`000P00000;0?ooo`030000003o0000o`0000D0o`0000<000000?ooo`3oool0o`3ooon4
0?ooo`007P3oool00`000000oooo000000070?l000030000003oool0000000L0o`0000<000000?oo
o`0000001`3o00000`000000oooo000000070?l000030000003oool0000000H0o`0000<000000?oo
o`0000001`3o00000`000000oooo0?ooo`090?ooo`030000003o0000o`0000D0o`0000<000000?oo
o`0000001@3o00000`000000o`000000000;0?ooo`030000003o0000o`0000D0o`0000<000000?oo
o`3oool0o`3ooon40?ooo`007P3oool00`000000oooo000000070?l000030000003oool0000000L0
o`0000<000000?ooo`0000001`3o00000`000000oooo000000070?l000030000003oool0000000H0
o`0000<000000?ooo`0000001`3o00000`000000oooo0?ooo`090?ooo`030000003o0000o`0000D0
o`0000<000000?ooo`000000103o000010000000o`000?l00000000;0?ooo`T00000o`3ooon60?oo
o`007P3oool00`000000oooo000000070?l000030000003oool0000000L0o`0000<000000?ooo`00
00001`3o00000`000000oooo000000070?l000030000003oool0000000H0o`0000<000000?ooo`00
00001`3o00000`000000oooo0?ooo`090?ooo`030000003o0000o`0000D0o`0000<000000?ooo`00
00000P3o0002000000<0o`0000<000000?ooo`3oool0o`3ooonH0?ooo`007P3oool00`000000oooo
000000070?l000030000003oool0000000L0o`0000<000000?ooo`0000001`3o00000`000000oooo
000000070?l000030000003oool0000000H0o`0000<000000?ooo`0000001`3o00000`000000oooo
0?ooo`090?ooo`030000003o0000o`0000D0o`0000D000000?ooo`000000o`00000000050?l00003
0000003oool0oooo0?l0ooooV03oool001h0oooo00<000000?ooo`0000001`3o00000`000000oooo
000000070?l000030000003oool0000000L0o`0000<000000?ooo`0000001`3o00000`000000oooo
000000060?l000030000003oool0000000L0o`0000<000000?ooo`3oool02@3oool00`000000o`00
0?l000050?l000040000003oool00000000000H0o`0000<000000?ooo`3oool0o`3ooonH0?ooo`00
7P3oool3000000L0o`0000<000000?ooo`0000001`3o00000`000000oooo000000070?l000030000
003oool0000000L0o`0000<000000?ooo`0000001P3o00000`000000oooo000000070?l000030000
003oool0oooo00T0oooo00<000000?l0003o00001@3o00000`000000oooo000000070?l000030000
003oool0oooo0?l0ooooV03oool001h0oooo00<000000?ooo`0000001`3o00000`000000oooo0000
00070?l000030000003oool0000000L0o`0000<000000?ooo`0000001`3o00000`000000oooo0000
00060?l000030000003oool0000000L0o`0000<000000?ooo`3oool02@3oool00`000000o`000?l0
00050?l000<000001`3o00000`000000oooo0?ooo`3o0?oooiP0oooo000N0?ooo`030000003oool0
000000L0o`0000<000000?ooo`0000001`3o00000`000000oooo000000070?l000030000003oool0
000000L0o`0000<000000?ooo`0000001P3o00000`000000oooo000000070?l000030000003oool0
oooo00T0oooo00<000000?l0003o0000103o0002000000030?ooo`000000o`0000H0o`0000<00000
0?ooo`3oool0o`3ooonH0?ooo`007P3oool00`000000oooo000000070?l000030000003oool00000
00L0o`0000<000000?ooo`0000001`3o00000`000000oooo000000070?l000030000003oool00000
00H0o`0000<000000?ooo`0000001`3o00000`000000oooo0?ooo`090?ooo`030000003o0000o`00
00<0o`0000@000000?l000000000oooo2@00003o0?oooiX0oooo000N0?ooo`030000003oool00000
00L0o`0000<000000?ooo`0000001`3o00000`000000oooo000000070?l000030000003oool00000
00L0o`0000<000000?ooo`0000001P3o00000`000000oooo000000070?l000030000003oool0oooo
00T0oooo00<000000?l0003o00000P3o000010000000o`000?l00000003o0?oooj@0oooo000N0?oo
o`030000003oool0000000L0o`0000<000000?ooo`0000001`3o00000`000000oooo000000070?l0
00030000003oool0000000L0o`0000<000000?ooo`0000001P3o00000`000000oooo000000070?l0
00030000003oool0oooo00T0oooo00D000000?l0003o0000o`00000000030?l000030000003oool0
oooo0?l0ooooXP3oool001h0oooo00<000000?ooo`0000001`3o00000`000000oooo000000070?l0
00030000003oool0000000L0o`0000<000000?ooo`0000001`3o00000`000000oooo000000060?l0
00030000003oool0000000L0o`0000<000000?ooo`3oool02@3oool010000000o`000?l000000004
0?l000030000003oool0oooo0?l0ooooXP3oool001h0oooo00<000000?ooo`0000001`3o00000`00
0000oooo000000070?l000030000003oool0000000L0o`0000<000000?ooo`0000001`3o00000`00
0000oooo000000060?l000030000003oool0000000L0o`0000<000000?ooo`3oool02@3oool00`00
0000o`00000000050?l000030000003oool0oooo0?l0ooooXP3oool001h0oooo00<000000?ooo`00
00001`3o00000`000000oooo000000070?l000030000003oool0000000L0o`0000<000000?ooo`00
00001`3o00000`000000oooo000000060?l000030000003oool0000000L0o`0000<000000?ooo`3o
ool02@3oool2000000H0o`0000<000000?ooo`3oool0o`3ooonR0?ooo`007P3oool3000000L0o`00
00<000000?ooo`0000001`3o00000`000000oooo000000070?l000030000003oool0000000P00000
00<0oooo0000003o00001@3o00000`000000oooo00000008000000/0oooo00<000000?l0003o0000
1@3o00000`000000oooo0?ooo`3o0?oooj80oooo000N0?ooo`030000003oool0000000L0o`0000<0
00000?ooo`0000001`3o00000`000000oooo000000070?l000030000003oool0oooo00T0oooo00<0
00000?l0003o0000103o00000`000000oooo0?ooo`0B0?ooo`8000001`3o00000`000000oooo0?oo
o`3o0?oooj80oooo000N0?ooo`030000003oool0000000L0o`0000<000000?ooo`0000001`3o0000
0`000000oooo000000070?l000030000003oool0oooo00T0oooo00<000000?l0003o0000103o0000
0`000000oooo0?ooo`0B0?ooo`8000001`3o00000`000000oooo0?ooo`3o0?oooj80oooo000N0?oo
o`030000003oool0000000L0o`0000<000000?ooo`0000001`3o00000`000000oooo000000070?l0
00030000003oool0oooo00T0oooo00<000000?l0003o0000103o00000`000000oooo0?ooo`0A0?oo
o`030000003oool0000000L0o`0000<000000?ooo`3oool0o`3ooonR0?ooo`007P3oool00`000000
oooo000000070?l000030000003oool0000000L0o`0000<000000?ooo`0000001`3o00000`000000
oooo0?ooo`090?ooo`030000003o0000o`0000@0o`0000<000000?ooo`3oool0403oool010000000
oooo0?ooo`0000070?l000030000003oool0oooo0?l0ooooXP3oool001h0oooo00<000000?ooo`00
00001`3o00000`000000oooo000000070?l000030000003oool0000000L0o`0000<000000?ooo`3o
ool02@3oool00`000000o`000?l000040?l000030000003oool0oooo00l0oooo00D000000?ooo`3o
ool0oooo000000070?l000030000003oool0oooo0?l0ooooXP3oool001h0oooo00<000000?ooo`00
00001`3o00000`000000oooo000000070?l000030000003oool0000000L0o`0000<000000?ooo`3o
ool02@3oool00`000000o`000?l000040?l000030000003oool0oooo00h0oooo00<000000?ooo`3o
ool00P3oool00`000000o`000?l000050?l000030000003oool0oooo0?l0ooooXP3oool001h0oooo
00<000000?ooo`0000001`3o00000`000000oooo000000070?l000030000003oool0000000L0o`00
00<000000?ooo`3oool02@3oool00`000000o`000?l000040?l000030000003oool0oooo00d0oooo
00<000000?ooo`3oool00`3oool00`000000o`000?l000050?l000030000003oool0oooo0?l0oooo
XP3oool001h0oooo00<000000?ooo`0000001`3o00000`000000oooo000000070?l000030000003o
ool0000000L0o`0000<000000?ooo`3oool02@3oool00`000000o`000?l000040?l000030000003o
ool0oooo00`0oooo00<000000?ooo`3oool0103oool00`000000o`000?l000050?l000030000003o
ool0oooo0?l0ooooXP3oool001h0oooo00<000000?ooo`0000001`3o00000`000000oooo00000007
0?l000030000003oool0000000L0o`0000<000000?ooo`3oool02@3oool00`000000o`000?l00004
0?l000030000003oool0oooo00/0oooo00<000000?ooo`3oool01@3oool00`000000o`000?l00005
0?l000030000003oool0oooo0?l0ooooXP3oool001h0oooo0`0000070?l000030000003oool00000
00L0o`0000<000000?ooo`0000001`3o00000`000000oooo0?ooo`090?ooo`030000003o0000o`00
00@0o`0000<000000?ooo`3oool02P3oool00`000000oooo0?ooo`060?ooo`T00000o`3ooonT0?oo
o`007P3oool00`000000oooo000000070?l000030000003oool0000000L0o`0000<000000?ooo`00
00001`3o00000`000000oooo0?ooo`090?ooo`030000003o0000o`0000@0o`0000<000000?ooo`3o
ool02@3oool00`000000oooo0?ooo`3o0?oook@0oooo000N0?ooo`030000003oool0000000L0o`00
00<000000?ooo`0000001`3o00000`000000oooo000000070?l000030000003oool0oooo00T0oooo
00<000000?l0003o0000103o00000`000000oooo0?ooo`080?ooo`030000003oool0oooo0?l0oooo
]@3oool001h0oooo00<000000?ooo`0000001`3o00000`000000oooo000000070?l000030000003o
ool0000000L0o`0000<000000?ooo`3oool02@3oool00`000000o`000?l000040?l000030000003o
ool0oooo00P0oooo00<000000?ooo`3oool0o`3ooone0?ooo`007P3oool00`000000oooo00000007
0?l000030000003oool0000000L0o`0000<000000?ooo`0000001`3o00000`000000oooo0?ooo`09
0?ooo`030000003o0000o`0000@0o`0000<000000?ooo`3oool01`3oool00`000000oooo0?ooo`3o
0?oookH0oooo000N0?ooo`030000003oool0000000L0o`0000<000000?ooo`0000001`3o00000`00
0000oooo000000070?l000030000003oool0oooo00T0oooo00<000000?l0003o0000103o00000`00
0000oooo0?ooo`060?ooo`030000003oool0oooo0?l0oooo]`3oool001h0oooo00<000000?ooo`00
00001`3o00000`000000oooo000000070?l000030000003oool0000000L0o`0000<000000?ooo`3o
ool02@3oool00`000000o`000?l000040?l000030000003oool0oooo00D0oooo00<000000?ooo`3o
ool0o`3ooonh0?ooo`001`3oool3000000@0oooo0P0000040?ooo`800000203oool00`000000oooo
000000070?l000030000003oool0000000L0o`0000<000000?ooo`0000001`3o00000`000000oooo
0?ooo`090?ooo`030000003o0000o`0000@0o`0000<000000?ooo`3oool0103oool00`000000oooo
0?ooo`3o0?oookT0oooo00060?ooo`050000003oool0oooo0?ooo`0000000P3oool010000000oooo
0?ooo`0000020?ooo`040000003oool0oooo000000L0oooo00<000000?ooo`0000001`3o00000`00
0000oooo000000070?l000030000003oool0000000L0o`0000<000000?ooo`3oool02@3oool00`00
0000o`000?l000040?l000030000003oool0oooo00<0oooo00<000000?ooo`3oool0o`3ooonj0?oo
o`001P3oool01@000000oooo0?ooo`3oool000000080oooo00@000000?ooo`3oool000000P3oool0
10000000oooo0?ooo`0000070?ooo`<000001`3o00000`000000oooo000000070?l000030000003o
ool0000000L0o`0000<000000?ooo`3oool02@3oool00`000000o`000?l000040?l000030000003o
ool0oooo0080oooo00<000000?ooo`3oool0o`3ooonk0?ooo`001P3oool4000000<0oooo00@00000
0?ooo`3oool000000P3oool010000000oooo0?ooo`0000070?ooo`030000003oool0000000L0o`00
00<000000?ooo`0000001`3o00000`000000oooo000000070?l000030000003oool0oooo00T0oooo
00<000000?l0003o0000103o00001@000000oooo0?ooo`3oool000000?l0oooo_P3oool000H0oooo
00<000000?ooo`3oool0103oool010000000oooo0?ooo`0000020?ooo`040000003oool0oooo0000
00L0oooo00<000000?ooo`0000001`3o00000`000000oooo000000070?l000030000003oool00000
00L0o`0000<000000?ooo`3oool02@3oool00`000000o`000?l000040?l000040000003oool0oooo
00000?l0oooo_`3oool000L0oooo00<000000?ooo`3oool00`3oool010000000oooo0?ooo`000002
0?ooo`040000003oool0oooo000000L0oooo00<000000?ooo`0000001`3o00000`000000oooo0000
00070?l000030000003oool0000000L0o`0000<000000?ooo`3oool02@3oool00`000000o`000?l0
00040?l000030000003oool000000?l0oooo`03oool000P0oooo0P0000040?ooo`800000103oool2
000000P0oooo00<000000?ooo`0000001`3o00000`000000oooo000000070?l000030000003oool0
000000L0o`0000<000000?ooo`3oool02@3oool00`000000o`000?l000040?l000800000o`3oooo1
0?ooo`007P3oool00`000000oooo000000070?l000030000003oool0000000L0o`0000<000000?oo
o`0000001`3o00000`000000oooo0?ooo`090?ooo`030000003o0000o`0000@0o`000P00003o0?oo
ol40oooo000N0?ooo`030000003oool0000000L0o`0000<000000?ooo`0000001`3o00000`000000
oooo000000070?l000030000003oool0oooo00T0oooo00<000000?l0003o0000103o00000`000000
oooo0?ooo`3o0?oool00oooo000N0?ooo`030000003oool0000000L0o`0000<000000?ooo`000000
1`3o00000`000000oooo000000070?l000030000003oool0oooo00T0oooo00<000000?l0003o0000
0`3o000200000?l0oooo`P3oool001h0oooo00<000000?ooo`0000001`3o00000`000000oooo0000
00070?l000030000003oool0000000L0o`0000<000000?ooo`3oool02@3oool00`000000o`000?l0
00020?l000030000003o000000000?l0oooo`P3oool001h0oooo00<000000?ooo`0000001`3o0000
0`000000oooo000000070?l000030000003oool0000000L0o`0000<000000?ooo`3oool02@3oool0
0`000000o`000?l000020?l000030000003o000000000?l0oooo`P3oool001h0oooo0`0000070?l0
00030000003oool0000000L0o`0000<000000?ooo`0000001`3o00000`000000oooo0?ooo`090?oo
o`050000003o0000o`000?l0000000000P3o00000`000000oooo0?ooo`3o0?oool00oooo000N0?oo
o`030000003oool0000000L0o`0000<000000?ooo`0000001`3o00000`000000oooo000000070?l0
00030000003oool0oooo00T0oooo00@000000?l0003o000000000`3o00000`000000oooo0?ooo`3o
0?oool00oooo000N0?ooo`030000003oool0000000L0o`0000<000000?ooo`0000001`3o00000`00
0000oooo000000070?l000030000003oool0oooo00T0oooo00<000000?l000000000103o00000`00
0000oooo0?ooo`3o0?oool00oooo000N0?ooo`030000003oool0000000L0o`0000<000000?ooo`00
00001`3o00000`000000oooo000000070?l000030000003oool0oooo00T0oooo00<000000?l00000
0000103o00000`000000oooo0?ooo`3o0?oool00oooo000N0?ooo`030000003oool0000000L0o`00
00<000000?ooo`0000001`3o00000`000000oooo000000070?l000030000003oool0oooo00T0oooo
0P0000050?l000030000003oool0oooo0?l0oooo`03oool001h0oooo00<000000?ooo`0000001`3o
00000`000000oooo000000070?l000030000003oool0000000L0o`0000<000000?ooo`3oool02@3o
ool00`000000o`000?l000040?l000030000003oool0oooo0?l0oooo`03oool001h0oooo00<00000
0?ooo`0000001`3o00000`000000oooo000000070?l000030000003oool0000000L0o`0000<00000
0?ooo`3oool0203oool2000000H0o`0000<000000?ooo`3oool0o`3oooo00?ooo`007P3oool00`00
0000oooo000000070?l000030000003oool0000000L0o`0000<000000?ooo`0000001`3o00000`00
0000oooo0?ooo`080?ooo`8000001P3o00000`000000oooo0?ooo`3o0?oool00oooo000N0?ooo`03
0000003oool0000000L0o`0000<000000?ooo`0000001`3o00000`000000oooo000000070?l00003
0000003oool0oooo00L0oooo00<000000?ooo`0000001P3o00000`000000oooo0?ooo`3o0?oool00
oooo000N0?ooo`<000001`3o00000`000000oooo000000070?l000030000003oool0000000L0o`00
00<000000?ooo`3oool01P3oool010000000oooo0?ooo`0000060?l000030000003oool0oooo0?l0
oooo`03oool001h0oooo00<000000?ooo`0000001`3o00000`000000oooo000000070?l000030000
003oool0000000L0o`0000<000000?ooo`3oool01@3oool01@000000oooo0?ooo`3oool0000000H0
o`0000<000000?ooo`3oool0o`3oooo00?ooo`007P3oool00`000000oooo000000070?l000030000
003oool0000000L0o`0000<000000?ooo`0000001`3o00000`000000oooo0?ooo`050?ooo`050000
003oool0oooo0?ooo`0000001P3o00000`000000oooo0?ooo`3o0?oool00oooo000N0?ooo`030000
003oool0000000L0o`0000<000000?ooo`0000001`3o00000`000000oooo000000070?l000030000
003oool0oooo00@0oooo00<000000?ooo`3oool00P3oool00`000000o`000?l000040?l000030000
003oool0oooo0?l0oooo`03oool001h0oooo00<000000?ooo`0000001`3o00000`000000oooo0000
00070?l000030000003oool0000000L0o`0000<000000?ooo`3oool00`3oool00`000000oooo0?oo
o`030?ooo`030000003o0000o`0000@0o`0000<000000?ooo`3oool0o`3oooo00?ooo`007P3oool0
0`000000oooo000000070?l000030000003oool0000000L0o`0000<000000?ooo`0000001`3o0000
0`000000oooo0?ooo`030?ooo`030000003oool0oooo00<0oooo00<000000?l0003o0000103o0000
0`000000oooo0?ooo`3o0?oool00oooo000N0?ooo`030000003oool0000000L0o`0000<000000?oo
o`0000001`3o00000`000000oooo000000070?l000030000003oool0oooo0080oooo00<000000?oo
o`3oool0103oool00`000000o`000?l000040?l000030000003oool0oooo0?l0oooo`03oool001h0
oooo00<000000?ooo`0000001`3o00000`000000oooo000000070?l000030000003oool0000000L0
o`0000D000000?ooo`3oool0oooo000000070?ooo`030000003o0000o`0000@0o`0000<000000?oo
o`3oool0o`3oooo00?ooo`007P3oool00`000000oooo000000070?l000030000003oool0000000L0
o`0000<000000?ooo`0000001`3o000010000000oooo0?ooo`0000080?ooo`030000003o0000o`00
00@0o`0000<000000?ooo`3oool0o`3oooo00?ooo`007P3oool00`000000oooo000000070?l00003
0000003oool0000000L0o`0000<000000?ooo`0000001`3o000010000000oooo0?ooo`0000080?oo
o`P00000o`3oooo20?ooo`007P3oool3000000L0o`0000<000000?ooo`0000001`3o00000`000000
oooo000000070?l000030000003oool000000?l0ooood`3oool001h0oooo00<000000?ooo`000000
1`3o00000`000000oooo000000070?l000030000003oool0000000L0o`000P00003o0?ooom@0oooo
000N0?ooo`030000003oool0000000L0o`0000<000000?ooo`0000001`3o00000`000000oooo0000
00070?l000800000o`3ooooD0?ooo`007P3oool00`000000oooo000000070?l000030000003oool0
000000L0o`0000<000000?ooo`0000001`3o00000`000000oooo0?ooo`3o0?ooom<0oooo000N0?oo
o`030000003oool0000000L0o`0000<000000?ooo`0000001`3o00000`000000oooo000000060?l0
00800000o`3ooooE0?ooo`007P3oool00`000000oooo000000070?l000030000003oool0000000L0
o`0000<000000?ooo`0000001P3o000200000?l0ooooe@3oool001h0oooo00<000000?ooo`000000
1`3o00000`000000oooo000000070?l000030000003oool0000000D0o`0000<000000?l000000000
o`3ooooE0?ooo`001`3oool3000000@0oooo0P0000040?ooo`800000203oool00`000000oooo0000
00070?l000030000003oool0000000L0o`0000<000000?ooo`0000001@3o00000`000000o`000000
003o0?ooomD0oooo00060?ooo`050000003oool0oooo0?ooo`0000000P3oool010000000oooo0?oo
o`0000020?ooo`040000003oool0oooo000000L0oooo00<000000?ooo`0000001`3o00000`000000
oooo000000070?l000030000003oool0000000@0o`0000@000000?l0003o00000000o`3ooooE0?oo
o`001P3oool01@000000oooo0?ooo`3oool000000080oooo00@000000?ooo`3oool000000P3oool0
10000000oooo0?ooo`0000070?ooo`030000003oool0000000L0o`0000<000000?ooo`0000001`3o
00000`000000oooo000000030?l000050000003o0000o`000?l000000000o`3ooooE0?ooo`001`3o
ool3000000<0oooo00@000000?ooo`3oool000000P3oool010000000oooo0?ooo`0000070?ooo`<0
00001`3o00000`000000oooo000000070?l000030000003oool0000000<0o`0000D000000?l0003o
0000o`000000003o0?ooomD0oooo00060?ooo`050000003oool0oooo0?ooo`0000000P3oool01000
0000oooo0?ooo`0000020?ooo`040000003oool0oooo000000L0oooo00<000000?ooo`0000001`3o
00000`000000oooo000000070?l000030000003oool000000080o`0000<000000?l0003o00000P3o
00000`000000oooo0?ooo`3o0?ooom<0oooo00060?ooo`050000003oool0oooo0?ooo`0000000P3o
ool010000000oooo0?ooo`0000020?ooo`040000003oool0oooo000000L0oooo00<000000?ooo`00
00001`3o00000`000000oooo000000070?l000050000003oool000000?l0000000001@3o00000`00
0000oooo0?ooo`3o0?ooom<0oooo00070?ooo`<00000103oool2000000@0oooo0P0000080?ooo`03
0000003oool0000000L0o`0000<000000?ooo`0000001`3o00001@000000oooo0000003o00000000
00D0o`0000<000000?ooo`3oool0o`3ooooC0?ooo`007P3oool00`000000oooo000000070?l00003
0000003oool0000000L0o`0000@000000?ooo`00000000001P3o00000`000000oooo0?ooo`3o0?oo
om<0oooo000N0?ooo`030000003oool0000000L0o`0000<000000?ooo`0000001`3o000010000000
oooo0000000000060?l000030000003oool0oooo0?l0ooood`3oool001h0oooo00<000000?ooo`00
00001`3o00000`000000oooo000000070?l000030000003oool0000000L0o`0000<000000?ooo`3o
ool0o`3ooooC0?ooo`007P3oool00`000000oooo000000070?l000030000003oool0000000L0o`00
0`0000070?l000030000003oool0oooo0?l0ooood`3oool001h0oooo00<000000?ooo`0000001`3o
00000`000000oooo000000070?l000<000001`3o00000`000000oooo0?ooo`3o0?ooom<0oooo000N
0?ooo`<000001`3o00000`000000oooo000000070?l000030000003oool0000000L0o`0000<00000
0?ooo`3oool0o`3ooooC0?ooo`007P3oool00`000000oooo000000070?l000030000003oool00000
00H0o`000P0000000`3oool000000?l000060?l000030000003oool0oooo0?l0ooood`3oool001h0
oooo00<000000?ooo`0000001`3o00000`000000oooo000000060?l00080000000<0oooo0000003o
00001P3o00000`000000oooo0?ooo`3o0?ooom<0oooo000N0?ooo`030000003oool0000000L0o`00
00<000000?ooo`0000001@3o00001@000000o`000000003oool0000000L0o`0000<000000?ooo`3o
ool0o`3ooooC0?ooo`007P3oool00`000000oooo000000070?l000030000003oool0000000D0o`00
00D000000?l000000000oooo000000070?l000030000003oool0oooo0?l0ooood`3oool001h0oooo
00<000000?ooo`0000001`3o00000`000000oooo000000040?l000060000003o0000o`000000003o
ool000001`3o00000`000000oooo0?ooo`3o0?ooom<0oooo000N0?ooo`030000003oool0000000L0
o`0000<000000?ooo`0000000`3o00001`000000o`000?l0003o000000000?ooo`0000001`3o0000
0`000000oooo0?ooo`3o0?ooom<0oooo000N0?ooo`030000003oool0000000L0o`0000<000000?oo
o`0000000`3o00001`000000o`000?l0003o000000000?ooo`0000001`3o00000`000000oooo0?oo
o`3o0?ooom<0oooo000N0?ooo`030000003oool0000000L0o`0000<000000?ooo`0000000P3o0000
0`000000o`000?l000020?l000030000003oool0000000L0o`0000<000000?ooo`3oool0o`3ooooC
0?ooo`007P3oool00`000000oooo000000070?l000050000003oool000000?l0000000001@3o0000
0`000000oooo000000070?l000030000003oool0oooo0?l0ooood`3oool001h0oooo0`0000070?l0
00050000003oool000000?l0000000001@3o00000`000000oooo000000070?l000030000003oool0
oooo0?l0ooood`3oool001h0oooo00<000000?ooo`0000001`3o000010000000oooo000000000006
0?l000030000003oool0000000L0o`0000<000000?ooo`3oool0o`3ooooC0?ooo`007P3oool00`00
0000oooo000000070?l000040000003oool00000000000H0o`0000<000000?ooo`0000001`3o0000
0`000000oooo0?ooo`3o0?ooom<0oooo000N0?ooo`030000003oool0000000L0o`0000<000000?oo
o`0000001`3o00000`000000oooo000000070?l000030000003oool0oooo0?l0ooood`3oool001h0
oooo00<000000?ooo`0000001`3o0003000000L0o`0000<000000?ooo`0000001`3o00000`000000
oooo0?ooo`3o0?ooom<0oooo000N0?ooo`030000003oool0000000L0o`000`0000070?l000030000
003oool0000000L0o`0000<000000?ooo`3oool0o`3ooooC0?ooo`007P3oool00`000000oooo0000
00070?l000030000003oool0000000L0o`0000<000000?ooo`0000001`3o00000`000000oooo0?oo
o`3o0?ooom<0oooo000N0?ooo`030000003oool0000000L0o`0000<000000?ooo`0000001`3o0000
0`000000oooo0000000800000?l0ooooe@3oool001h0oooo00<000000?ooo`0000001P3o00020000
00030?ooo`000000o`0000H0o`0000<000000?ooo`3oool0o`3ooooM0?ooo`007P3oool3000000H0
o`000P0000000`3oool000000?l000060?l000030000003oool0oooo0?l0oooog@3oool001h0oooo
00<000000?ooo`0000001@3o00001@000000o`000000003oool0000000L0o`0000<000000?ooo`3o
ool0o`3ooooM0?ooo`007P3oool00`000000oooo000000050?l000050000003o000000000?ooo`00
00001`3o00000`000000oooo0?ooo`3o0?ooomd0oooo000N0?ooo`030000003oool0000000@0o`00
00H000000?l0003o000000000?ooo`0000070?l000030000003oool0oooo0?l0oooog@3oool001h0
oooo00<000000?ooo`000000103o00001P000000o`000?l000000000oooo000000L0o`0000<00000
0?ooo`3oool0o`3ooooM0?ooo`007P3oool00`000000oooo000000030?l000070000003o0000o`00
0?l000000000oooo000000070?l000030000003oool0oooo0?l0oooog@3oool001h0oooo00<00000
0?ooo`0000000P3o00000`000000o`000?l000020?l000030000003oool0000000L0o`0000<00000
0?ooo`3oool0o`3ooooM0?ooo`0000@0oooo0000000000000000103oool2000000@0oooo0P000004
0?ooo`800000203oool00`000000oooo000000020?l000030000003o0000o`000080o`0000<00000
0?ooo`0000001`3o00000`000000oooo0?ooo`3o0?ooomd0oooo00020?ooo`030000003oool0oooo
0080oooo00@000000?ooo`3oool000000P3oool010000000oooo0?ooo`0000020?ooo`040000003o
ool0oooo000000L0oooo00D000000?ooo`000000o`00000000050?l000030000003oool0000000L0
o`0000<000000?ooo`3oool0o`3ooooM0?ooo`000P3oool00`000000oooo0?ooo`020?ooo`040000
003oool0oooo00000080oooo00@000000?ooo`3oool000000P3oool010000000oooo0?ooo`000007
0?ooo`050000003oool000000?l0000000001@3o00000`000000oooo000000070?l000030000003o
ool0oooo0?l0oooog@3oool00080oooo00<000000?ooo`3oool00P3oool010000000oooo0?ooo`00
00020?ooo`040000003oool0oooo00000080oooo00@000000?ooo`3oool000001`3oool4000000H0
o`0000<000000?ooo`0000001`3o00000`000000oooo0?ooo`3o0?ooomd0oooo00020?ooo`030000
003oool0oooo0080oooo00@000000?ooo`3oool000000P3oool010000000oooo0?ooo`0000020?oo
o`040000003oool0oooo000000L0oooo00@000000?ooo`00000000001P3o00000`000000oooo0000
00070?l000030000003oool0oooo0?l0oooog@3oool000030?ooo`000000000000@0oooo00@00000
0?ooo`3oool000000P3oool010000000oooo0?ooo`0000020?ooo`040000003oool0oooo000000L0
oooo00<000000?ooo`0000001`3o00000`000000oooo000000070?l000030000003oool0oooo0?l0
oooog@3oool00080oooo00<000000?ooo`3oool00`3oool2000000@0oooo0P0000040?ooo`800000
203oool00`000000oooo000000070?l000030000003oool0000000L0o`0000<000000?ooo`3oool0
o`3ooooM0?ooo`007P3oool3000000L0o`0000<000000?ooo`0000001`3o00000`000000oooo0?oo
o`3o0?ooomd0oooo000N0?ooo`030000003oool0000000L0o`0000<000000?ooo`0000001`3o0000
0`000000oooo0?ooo`3o0?ooomd0oooo000N0?ooo`030000003oool0000000L0o`0000<000000?oo
o`0000001`3o00000`000000oooo0?ooo`3o0?ooomd0oooo000N0?ooo`030000003oool0000000L0
o`0000<000000?ooo`0000001`3o00000`000000oooo0?ooo`3o0?ooomd0oooo000N0?ooo`030000
003oool0000000L0o`0000<000000?ooo`0000001`3o00000`000000oooo0?ooo`3o0?ooomd0oooo
000N0?ooo`030000003oool0000000L0o`0000<000000?ooo`0000001`3o00000`000000oooo0?oo
o`3o0?ooomd0oooo000N0?ooo`<000001`3o00000`000000oooo000000070?l000030000003oool0
oooo0?l0oooog@3oool001h0oooo00<000000?ooo`0000001`3o00000`000000oooo000000070?l0
00030000003oool0oooo0?l0oooog@3oool001h0oooo00<000000?ooo`0000001`3o00000`000000
oooo000000070?l000030000003oool0oooo0?l0oooog@3oool001h0oooo00<000000?ooo`000000
1`3o00000`000000oooo000000070?l000030000003oool0oooo0?l0oooog@3oool001h0oooo00<0
00000?ooo`0000001`3o00000`000000oooo000000070?l000030000003oool0oooo0?l0oooog@3o
ool001h0oooo00<000000?ooo`0000001`3o00000`000000oooo000000070?l000030000003oool0
oooo0?l0oooog@3oool001h0oooo00<000000?ooo`0000001`3o00000`000000oooo000000070?l0
00030000003oool0oooo0?l0oooog@3oool001h0oooo00<000000?ooo`0000001`3o00000`000000
oooo000000070?l000030000003oool0oooo0?l0oooog@3oool001h0oooo00<000000?ooo`000000
1`3o00000`000000oooo000000070?l000030000003oool0oooo0?l0oooog@3oool001h0oooo0`00
00070?l000030000003oool0000000L0o`0000<000000?ooo`3oool0o`3ooooM0?ooo`007P3oool0
0`000000oooo000000070?l000030000003oool0000000L0o`0000<000000?ooo`3oool0o`3ooooM
0?ooo`007P3oool00`000000oooo000000070?l000030000003oool0000000L0o`0000<000000?oo
o`3oool0o`3ooooM0?ooo`007P3oool00`000000oooo000000070?l000030000003oool0000000L0
o`0000<000000?ooo`3oool0o`3ooooM0?ooo`007P3oool00`000000oooo000000070?l000030000
003oool0000000L0o`0000<000000?ooo`3oool0o`3ooooM0?ooo`007P3oool00`000000oooo0000
00070?l000030000003oool0000000L0o`0000<000000?ooo`3oool0o`3ooooM0?ooo`007P3oool0
0`000000oooo000000070?l000030000003oool0000000L0o`0000<000000?ooo`3oool0o`3ooooM
0?ooo`007P3oool00`000000oooo000000070?l000030000003oool0000000L0o`0000<000000?oo
o`3oool0o`3ooooM0?ooo`007P3oool00`000000oooo000000070?l000030000003oool0000000L0
o`0000<000000?ooo`3oool0o`3ooooM0?ooo`007P3oool00`000000oooo000000070?l000030000
003oool0000000L0o`0000<000000?ooo`3oool0o`3ooooM0?ooo`007P3oool3000000L0o`0000<0
00000?ooo`0000001`3o00000`000000oooo0?ooo`3o0?ooomd0oooo000N0?ooo`030000003oool0
000000L0o`0000<000000?ooo`0000001`3o00000`000000oooo0?ooo`3o0?ooomd0oooo000N0?oo
o`030000003oool0000000L0o`0000<000000?ooo`0000001`3o00000`000000oooo0?ooo`3o0?oo
omd0oooo000N0?ooo`030000003oool0000000L0o`0000<000000?ooo`0000001`3o00000`000000
oooo0?ooo`3o0?ooomd0oooo000N0?ooo`030000003oool0000000L0o`0000<000000?ooo`000000
2000003o0?oooml0oooo000N0?ooo`030000003oool0000000L0o`0000<000000?ooo`3oool0o`3o
oooW0?ooo`007P3oool00`000000oooo000000070?l000030000003oool0oooo0?l0ooooi`3oool0
00040?ooo`000000000000000080oooo1@0000030?ooo`800000103oool2000000P0oooo00<00000
0?ooo`0000001`3o00000`000000oooo0?ooo`3o0?ooonL0oooo00020?ooo`030000003oool0oooo
0080oooo00@000000?ooo`3oool000000P3oool010000000oooo0?ooo`0000020?ooo`040000003o
ool0oooo000000L0oooo00<000000?ooo`0000001`3o00000`000000oooo0?ooo`3o0?ooonL0oooo
00020?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool00P3oool010000000oooo0?oo
o`0000020?ooo`040000003oool0oooo000000L0oooo0`0000070?l000030000003oool0oooo0?l0
ooooi`3oool00080oooo00<000000?ooo`3oool0103oool01@000000oooo0?ooo`3oool000000080
oooo00@000000?ooo`3oool000000P3oool00`000000oooo0?ooo`050?ooo`030000003oool00000
00L0o`0000<000000?ooo`3oool0o`3ooooW0?ooo`000P3oool01@000000oooo0?ooo`3oool00000
00<0oooo00@000000?ooo`3oool000000P3oool010000000oooo0?ooo`0000020?ooo`030000003o
ool0oooo00D0oooo00<000000?ooo`0000001`3o00000`000000oooo0?ooo`3o0?ooonL0oooo0000
0`3oool00000000000030?ooo`050000003oool0oooo0?ooo`0000000P3oool010000000oooo0?oo
o`0000020?ooo`040000003oool0oooo000000L0oooo00<000000?ooo`0000001`3o00000`000000
oooo0?ooo`3o0?ooonL0oooo00020?ooo`030000003oool0oooo0080oooo0`0000040?ooo`800000
103oool2000000P0oooo00<000000?ooo`0000001`3o00000`000000oooo0?ooo`3o0?ooonL0oooo
000N0?ooo`030000003oool0000000L0o`0000<000000?ooo`3oool0o`3ooooW0?ooo`007P3oool0
0`000000oooo000000070?l000030000003oool0oooo0?l0ooooi`3oool001h0oooo00<000000?oo
o`0000001`3o00000`000000oooo0?ooo`3o0?ooonL0oooo000N0?ooo`030000003oool0000000L0
o`0000<000000?ooo`3oool0o`3ooooW0?ooo`007P3oool00`000000oooo000000070?l000030000
003oool0oooo0?l0ooooi`3oool001h0oooo0`0000070?l000030000003oool0oooo0?l0ooooi`3o
ool001h0oooo00<000000?ooo`0000001`3o00000`000000oooo0?ooo`3o0?ooonL0oooo000N0?oo
o`030000003oool0000000L0o`0000<000000?ooo`3oool0o`3ooooW0?ooo`007P3oool00`000000
oooo000000070?l000030000003oool0oooo0?l0ooooi`3oool001h0oooo00<000000?ooo`000000
1`3o00000`000000oooo0?ooo`3o0?ooonL0oooo000N0?ooo`030000003oool0000000L0o`0000<0
00000?ooo`3oool0o`3ooooW0?ooo`007P3oool00`000000oooo000000070?l000030000003oool0
oooo0?l0ooooi`3oool001h0oooo00<000000?ooo`0000001`3o00000`000000oooo0?ooo`3o0?oo
onL0oooo000N0?ooo`030000003oool0000000L0o`0000<000000?ooo`3oool0o`3ooooW0?ooo`00
7P3oool3000000L0o`0000<000000?ooo`3oool0o`3ooooW0?ooo`007P3oool00`000000oooo0000
00070?l000030000003oool0oooo0?l0ooooi`3oool001h0oooo00<000000?ooo`0000001`3o0000
0`000000oooo0?ooo`3o0?ooonL0oooo000N0?ooo`030000003oool0000000L0o`0000<000000?oo
o`3oool0o`3ooooW0?ooo`007P3oool00`000000oooo000000070?l000030000003oool0oooo0?l0
ooooi`3oool001h0oooo00<000000?ooo`0000001`3o00000`000000oooo0?ooo`3o0?ooonL0oooo
000N0?ooo`030000003oool0000000L0o`0000<000000?ooo`3oool0o`3ooooW0?ooo`007P3oool0
0`000000oooo000000070?l000030000003oool0oooo0?l0ooooi`3oool001h0oooo00<000000?oo
o`0000001`3o00000`000000oooo0?ooo`3o0?ooonL0oooo000N0?ooo`030000003oool0000000L0
o`0000<000000?ooo`3oool0o`3ooooW0?ooo`007P3oool3000000L0o`0000<000000?ooo`3oool0
o`3ooooW0?ooo`007P3oool00`000000oooo000000070?l000030000003oool0oooo0?l0ooooi`3o
ool001h0oooo00<000000?ooo`0000001`3o00000`000000oooo0?ooo`3o0?ooonL0oooo000N0?oo
o`030000003oool0000000L0o`0000<000000?ooo`3oool0o`3ooooW0?ooo`007P3oool00`000000
oooo000000070?l000030000003oool0oooo0?l0ooooi`3oool001h0oooo00<000000?ooo`000000
1`3o00000`000000oooo0?ooo`3o0?ooonL0oooo000N0?ooo`030000003oool0000000L0o`0000<0
00000?ooo`3oool0o`3ooooW0?ooo`0000@0oooo0000000000000000103oool3000000<0oooo0P00
00040?ooo`800000203oool00`000000oooo000000070?l000030000003oool0oooo0?l0ooooi`3o
ool00080oooo00<000000?ooo`3oool0103oool01@000000oooo0?ooo`3oool000000080oooo00@0
00000?ooo`3oool000000P3oool00`000000oooo0?ooo`050?ooo`030000003oool0000000L0o`00
00<000000?ooo`3oool0o`3ooooW0?ooo`000P3oool010000000oooo0?ooo`3oool500000080oooo
00@000000?ooo`3oool000000P3oool010000000oooo0?ooo`0000070?ooo`030000003oool00000
00L0o`0000<000000?ooo`3oool0o`3ooooW0?ooo`000P3oool01@000000oooo0?ooo`3oool00000
0080oooo00D000000?ooo`3oool0oooo000000020?ooo`040000003oool0oooo00000080oooo00<0
00000?ooo`3oool01@3oool3000000L0o`0000<000000?ooo`3oool0o`3ooooW0?ooo`000P3oool0
0`000000oooo0?ooo`020?ooo`030000003oool0000000<0oooo00@000000?ooo`3oool000000P3o
ool010000000oooo0?ooo`0000070?ooo`030000003oool0000000L0o`0000<000000?ooo`3oool0
o`3ooooW0?ooo`0000<0oooo0000000000001@3oool2000000<0oooo00@000000?ooo`3oool00000
0P3oool010000000oooo0?ooo`0000070?ooo`030000003oool0000000L0o`0000<000000?ooo`3o
ool0o`3ooooW0?ooo`000P3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo0080oooo
0P0000040?ooo`800000203oool00`000000oooo000000070?l000030000003oool0oooo0?l0oooo
i`3oool001h0oooo00<000000?ooo`0000001`3o00000`000000oooo0?ooo`3o0?ooonL0oooo000N
0?ooo`030000003oool0000000L0o`0000<000000?ooo`3oool0o`3ooooW0?ooo`007P3oool00`00
0000oooo000000070?l000030000003oool0oooo0?l0ooooi`3oool001h0oooo00<000000?ooo`00
00001`3o00000`000000oooo0?ooo`3o0?ooonL0oooo000N0?ooo`030000003oool0000000L0o`00
00<000000?ooo`3oool0o`3ooooW0?ooo`007P3oool3000000L0o`0000<000000?ooo`3oool0o`3o
oooW0?ooo`007P3oool00`000000oooo000000070?l000030000003oool0oooo0?l0ooooi`3oool0
01h0oooo00<000000?ooo`0000001`3o00000`000000oooo0?ooo`3o0?ooonL0oooo000N0?ooo`03
0000003oool0000000L0o`0000<000000?ooo`3oool0o`3ooooW0?ooo`007P3oool00`000000oooo
000000070?l000030000003oool0oooo0?l0ooooi`3oool001h0oooo00<000000?ooo`0000001`3o
00000`000000oooo0?ooo`3o0?ooonL0oooo000N0?ooo`030000003oool0000000L0o`0000<00000
0?ooo`3oool0o`3ooooW0?ooo`007P3oool00`000000oooo000000070?l000030000003oool0oooo
0?l0ooooi`3oool001h0oooo00<000000?ooo`0000001`3o00000`000000oooo0?ooo`3o0?ooonL0
oooo000N0?ooo`030000003oool0000000L0o`0000<000000?ooo`3oool0o`3ooooW0?ooo`007P3o
ool3000000L0o`0000<000000?ooo`3oool0o`3ooooW0?ooo`007P3oool00`000000oooo00000007
0?l000030000003oool0oooo0?l0ooooi`3oool001h0oooo00<000000?ooo`0000001`3o00000`00
0000oooo0?ooo`3o0?ooonL0oooo000N0?ooo`030000003oool0000000L0o`0000<000000?ooo`3o
ool0o`3ooooW0?ooo`007P3oool00`000000oooo000000070?l000030000003oool0oooo0?l0oooo
i`3oool001h0oooo00<000000?ooo`0000001`3o00000`000000oooo0?ooo`3o0?ooonL0oooo000N
0?ooo`030000003oool0000000P00000o`3ooooY0?ooo`007P3oool00`000000oooo0?ooo`3o0?oo
oo40oooo000N0?ooo`030000003oool0oooo0?l0ooool@3oool001h0oooo0`00003o0?oooo40oooo
000N0?ooo`030000003oool0oooo0?l0ooool@3oool001h0oooo00<000000?ooo`3oool0o`3ooooa
0?ooo`007P3oool00`000000oooo0?ooo`3o0?oooo40oooo000N0?ooo`030000003oool0oooo0?l0
ooool@3oool001h0oooo00<000000?ooo`3oool0o`3ooooa0?ooo`007P3oool00`000000oooo0?oo
o`3o0?oooo40oooo0000103oool000000000000000030?ooo`<00000103oool2000000@0oooo0P00
00080?ooo`030000003oool0oooo0?l0ooool@3oool00080oooo00D000000?ooo`3oool0oooo0000
00030?ooo`040000003oool0oooo00000080oooo00@000000?ooo`3oool000000P3oool00`000000
oooo0?ooo`050?ooo`030000003oool0oooo0?l0ooool@3oool00080oooo00D000000?ooo`3oool0
oooo000000030?ooo`040000003oool0oooo00000080oooo00@000000?ooo`3oool000000P3oool0
0`000000oooo0?ooo`050?ooo`030000003oool0oooo0?l0ooool@3oool00080oooo00@000000?oo
o`3oool0oooo100000030?ooo`040000003oool0oooo00000080oooo00@000000?ooo`3oool00000
1`3oool400000?l0ooool03oool00080oooo00D000000?ooo`3oool0oooo000000060?ooo`040000
003oool0oooo00000080oooo00@000000?ooo`3oool00000o`3ooook0?ooo`0000<0oooo00000000
0000103oool00`000000oooo0?ooo`030?ooo`040000003oool0oooo00000080oooo00@000000?oo
o`3oool00000o`3ooook0?ooo`000P3oool00`000000oooo0?ooo`030?ooo`800000103oool20000
00@0oooo0P00003o0?oooo`0oooo003o0?ooool0oooo4`3oool00001\
\>"],
  ImageRangeCache->{{{0, 528.75}, {326.438, 0}} -> {-2.6536, -79.3153, \
0.100745, 5.21627}}],

Cell[BoxData[
    \(0.9316088739746461`\)], "Output",
  CellLabel->"Out[356]="]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["Lengths of segments", "SubsubsectionIcon"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(Show[
        PlotSegments[lpList\[LeftDoubleBracket]2000\[RightDoubleBracket], 
          a, {0, 1}], AspectRatio \[Rule] 0.2];\)\)], "Input",
  CellLabel->"In[295]:="],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .2 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.0190476 0.0047619 0.190476 [
[ 0 0 0 0 ]
[ 1 .2 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .2 L
0 .2 L
closepath
clip
newpath
0 0 0 r
.5 Mabswid
[ ] 0 setdash
.03128 .00476 m
.03128 .19524 L
s
.0342 .00476 m
.0342 .19524 L
s
.03603 .00476 m
.03603 .19524 L
s
.04106 .00476 m
.04106 .19524 L
s
.07764 .00476 m
.07764 .19524 L
s
.08617 .00476 m
.08617 .19524 L
s
.10473 .00476 m
.10473 .19524 L
s
.14563 .00476 m
.14563 .19524 L
s
.14881 .00476 m
.14881 .19524 L
s
.17434 .00476 m
.17434 .19524 L
s
.17982 .00476 m
.17982 .19524 L
s
.19746 .00476 m
.19746 .19524 L
s
.20674 .00476 m
.20674 .19524 L
s
.22108 .00476 m
.22108 .19524 L
s
.22315 .00476 m
.22315 .19524 L
s
.24011 .00476 m
.24011 .19524 L
s
.24878 .00476 m
.24878 .19524 L
s
.25444 .00476 m
.25444 .19524 L
s
.27386 .00476 m
.27386 .19524 L
s
.27459 .00476 m
.27459 .19524 L
s
.27607 .00476 m
.27607 .19524 L
s
.3336 .00476 m
.3336 .19524 L
s
.3373 .00476 m
.3373 .19524 L
s
.35985 .00476 m
.35985 .19524 L
s
.3886 .00476 m
.3886 .19524 L
s
.39537 .00476 m
.39537 .19524 L
s
.39773 .00476 m
.39773 .19524 L
s
.3988 .00476 m
.3988 .19524 L
s
.40381 .00476 m
.40381 .19524 L
s
.42262 .00476 m
.42262 .19524 L
s
.44703 .00476 m
.44703 .19524 L
s
.47587 .00476 m
.47587 .19524 L
s
.50763 .00476 m
.50763 .19524 L
s
.57149 .00476 m
.57149 .19524 L
s
.58257 .00476 m
.58257 .19524 L
s
.61423 .00476 m
.61423 .19524 L
s
.61874 .00476 m
.61874 .19524 L
s
.61976 .00476 m
.61976 .19524 L
s
.62882 .00476 m
.62882 .19524 L
s
.63442 .00476 m
.63442 .19524 L
s
.64267 .00476 m
.64267 .19524 L
s
.67226 .00476 m
.67226 .19524 L
s
.68658 .00476 m
.68658 .19524 L
s
.69284 .00476 m
.69284 .19524 L
s
.69489 .00476 m
.69489 .19524 L
s
.71527 .00476 m
.71527 .19524 L
s
.71868 .00476 m
.71868 .19524 L
s
.72657 .00476 m
.72657 .19524 L
s
.78683 .00476 m
.78683 .19524 L
s
.80715 .00476 m
.80715 .19524 L
s
.91289 .00476 m
.91289 .19524 L
s
.9234 .00476 m
.9234 .19524 L
s
.93625 .00476 m
.93625 .19524 L
s
.93703 .00476 m
.93703 .19524 L
s
.96645 .00476 m
.96645 .19524 L
s
.97355 .00476 m
.97355 .19524 L
s
1 1 0 r
.02381 .00476 m
.97619 .00476 L
s
.02381 .01479 m
.97619 .01479 L
s
.02381 .02481 m
.97619 .02481 L
s
.02381 .03484 m
.97619 .03484 L
s
.02381 .04486 m
.97619 .04486 L
s
.02381 .05489 m
.97619 .05489 L
s
.02381 .06491 m
.97619 .06491 L
s
.02381 .07494 m
.97619 .07494 L
s
.02381 .08496 m
.97619 .08496 L
s
.02381 .09499 m
.97619 .09499 L
s
.02381 .10501 m
.97619 .10501 L
s
.02381 .11504 m
.97619 .11504 L
s
.02381 .12506 m
.97619 .12506 L
s
.02381 .13509 m
.97619 .13509 L
s
.02381 .14511 m
.97619 .14511 L
s
.02381 .15514 m
.97619 .15514 L
s
.02381 .16516 m
.97619 .16516 L
s
.02381 .17519 m
.97619 .17519 L
s
.02381 .18521 m
.97619 .18521 L
s
.02381 .19524 m
.97619 .19524 L
s
0 0 1 r
.03603 .00476 m
.04106 .00476 L
s
.07764 .00476 m
.08617 .00476 L
s
.14563 .00476 m
.14881 .00476 L
s
.22108 .01479 m
.22315 .01479 L
s
.24878 .01479 m
.25444 .01479 L
s
.3886 .01479 m
.39537 .01479 L
s
.40381 .01479 m
.42262 .01479 L
s
.0342 .02481 m
.03603 .02481 L
s
.04106 .02481 m
.07764 .02481 L
s
.25444 .02481 m
.27386 .02481 L
s
.27459 .02481 m
.27607 .02481 L
s
.91289 .03484 m
.9234 .03484 L
s
.96645 .03484 m
.97355 .03484 L
s
.17434 .04486 m
.17982 .04486 L
s
.71527 .05489 m
.71868 .05489 L
s
.72657 .05489 m
.78683 .05489 L
s
.80715 .05489 m
.91289 .05489 L
s
.67226 .06491 m
.68658 .06491 L
s
.69489 .06491 m
.71527 .06491 L
s
.71868 .06491 m
.72657 .06491 L
s
.9234 .07494 m
.93625 .07494 L
s
.93703 .07494 m
.96645 .07494 L
s
.69284 .08496 m
.69489 .08496 L
s
.27386 .09499 m
.27459 .09499 L
s
.27607 .09499 m
.3336 .09499 L
s
.19746 .10501 m
.20674 .10501 L
s
.24011 .10501 m
.24878 .10501 L
s
.3336 .10501 m
.3373 .10501 L
s
.44703 .10501 m
.47587 .10501 L
s
.58257 .10501 m
.61423 .10501 L
s
.61874 .10501 m
.61976 .10501 L
s
.62882 .10501 m
.63442 .10501 L
s
.78683 .10501 m
.80715 .10501 L
s
.93625 .10501 m
.93703 .10501 L
s
.97355 .10501 m
.97619 .10501 L
s
.47587 .11504 m
.50763 .11504 L
s
.57149 .12506 m
.58257 .12506 L
s
.61423 .12506 m
.61874 .12506 L
s
.61976 .12506 m
.62882 .12506 L
s
.63442 .12506 m
.64267 .12506 L
s
.02381 .13509 m
.03128 .13509 L
s
.10473 .13509 m
.14563 .13509 L
s
.14881 .13509 m
.17434 .13509 L
s
.20674 .13509 m
.22108 .13509 L
s
.39773 .13509 m
.3988 .13509 L
s
.3373 .14511 m
.35985 .14511 L
s
.35985 .15514 m
.3886 .15514 L
s
.39537 .15514 m
.39773 .15514 L
s
.3988 .15514 m
.40381 .15514 L
s
.42262 .15514 m
.44703 .15514 L
s
.17982 .16516 m
.19746 .16516 L
s
.22315 .17519 m
.24011 .17519 L
s
.50763 .18521 m
.57149 .18521 L
s
.64267 .18521 m
.67226 .18521 L
s
.03128 .19524 m
.0342 .19524 L
s
.08617 .19524 m
.10473 .19524 L
s
.68658 .19524 m
.69284 .19524 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[295]:=",
  ImageSize->{769.375, 153.875},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`4000<10000VB000`400?l00000o`00003oo`3ooooo
0?ooool0oooo103oool00?l0ooooo`3ooooo0?ooo`@0oooo003o0?ooool0ooooo`3oool40?ooo`00
503oool90?oo00D0003o6`3oo`070000obd0ool00`000?oo0?oo0?l0ool0N`3oo`0D0?ooo`006@3o
ool00`000000oooo0?ooo`02000000<0oooo00<000000?ooo`3oool06@3oool00`000000oooo0?oo
o`030?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool0703oool00`000000oooo0000
000C0?ooo`050000003oool0oooo0?ooo`000000303oool00`000000oooo0?ooo`050?ooo`030000
003oool0oooo00L0oooo00<000000?ooo`000000303oool00`000000oooo0?ooo`040?ooo`050000
003oool0oooo0?ooo`0000003P3oool00`000000oooo0000000Z0?ooo`040000003oool0oooo0000
0140oooo00<000000?ooo`3oool04`3oool00`000000oooo0?ooo`020?ooo`030000003oool00000
00<0oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`0?0?ooo`030000003oool0oooo
01<0oooo00<000000?ooo`3oool05P3oool00`000000oooo0?ooo`0]0?ooo`030000003oool0oooo
00H0oooo00<000000?ooo`3oool05@3oool00`000000oooo0?ooo`02000000H0oooo00D000000?oo
o`3oool0oooo000000060?ooo`030000003oool0oooo01<0oooo00<000000?ooo`3oool0203oool0
0`000000oooo0?ooo`020?ooo`030000003oool0000000h0oooo00@000000?ooo`3oool000001@3o
ool00`000000oooo0?ooo`0[0?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool0CP3o
ool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00L0oooo0P00000E0?ooo`030000003o
ool0oooo00<0oooo00<000000?ooo`3oool0503oool001T0oooo00<000000?ooo`3oool00P000003
0?ooo`030000003oool0oooo01T0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`0<
0?ooo`030000003oool0oooo01`0oooo00<000000?ooo`0000004`3oool01@000000oooo0?ooo`3o
ool0000000`0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`070?ooo`030000003o
ool0000000`0oooo00<000000?ooo`3oool0103oool01@000000oooo0?ooo`3oool0000000h0oooo
00<000000?ooo`000000:P3oool010000000oooo0?ooo`00000A0?ooo`030000003oool0oooo01<0
oooo00<000000?ooo`3oool00P3oool00`000000oooo000000030?ooo`030000003oool0oooo00`0
oooo00<000000?ooo`3oool03`3oool00`000000oooo0?ooo`0C0?ooo`030000003oool0oooo01H0
oooo00<000000?ooo`3oool0;@3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo01D0
oooo00<000000?ooo`3oool00P0000060?ooo`050000003oool0oooo0?ooo`0000001P3oool00`00
0000oooo0?ooo`0C0?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool00P3oool00`00
0000oooo0000000>0?ooo`040000003oool0oooo000000D0oooo00<000000?ooo`3oool0:`3oool0
0`000000oooo0?ooo`0<0?ooo`030000003oool0oooo04h0oooo00<000000?ooo`3oool01@3oool0
0`000000oooo0?ooo`070?ooo`8000005@3oool00`000000oooo0?ooo`030?ooo`030000003oool0
oooo01@0oooo000I0?ooo`030000003oool0oooo008000000`3oool00`000000oooo0?ooo`0I0?oo
o`030000003oool0oooo00<0oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`0L0?oo
o`030000003oool0000001<0oooo00D000000?ooo`3oool0oooo0000000<0?ooo`030000003oool0
oooo00D0oooo00<000000?ooo`3oool01`3oool00`000000oooo0000000<0?ooo`030000003oool0
oooo00@0oooo00D000000?ooo`3oool0oooo0000000>0?ooo`030000003oool0000002X0oooo00@0
00000?ooo`3oool000004@3oool00`000000oooo0?ooo`0C0?ooo`030000003oool0oooo0080oooo
00<000000?ooo`0000000`3oool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo00l0oooo
00<000000?ooo`3oool04`3oool00`000000oooo0?ooo`0F0?ooo`030000003oool0oooo02d0oooo
00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`0E0?ooo`030000003oool0oooo00800000
1P3oool01@000000oooo0?ooo`3oool0000000H0oooo00<000000?ooo`3oool04`3oool00`000000
oooo0?ooo`080?ooo`030000003oool0oooo0080oooo00<000000?ooo`0000003P3oool010000000
oooo0?ooo`0000050?ooo`030000003oool0oooo02/0oooo00<000000?ooo`3oool0303oool00`00
0000oooo0?ooo`1>0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool01`3oool20000
01D0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`0D0?ooo`006@3oool00`000000
oooo0?ooo`02000000<0oooo00<000000?ooo`3oool06@3oool00`000000oooo0?ooo`030?ooo`03
0000003oool0oooo00`0oooo00<000000?ooo`3oool0703oool00`000000oooo0000000C0?ooo`05
0000003oool0oooo0?ooo`000000303oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo
00L0oooo00<000000?ooo`000000303oool00`000000oooo0?ooo`040?ooo`050000003oool0oooo
0?ooo`0000003P3oool00`000000oooo0000000Z0?ooo`040000003oool0oooo00000140oooo00<0
00000?ooo`3oool04`3oool00`000000oooo0?ooo`020?ooo`030000003oool0000000<0oooo00<0
00000?ooo`3oool0303oool00`000000oooo0?ooo`0?0?ooo`030000003oool0oooo01<0oooo00<0
00000?ooo`3oool05P3oool00`000000oooo0?ooo`0]0?ooo`030000003oool0oooo00H0oooo00<0
00000?ooo`3oool05@3oool00`000000oooo0?ooo`02000000H0oooo00D000000?ooo`3oool0oooo
000000060?ooo`030000003oool0oooo01<0oooo00<000000?ooo`3oool0203oool00`000000oooo
0?ooo`020?ooo`030000003oool0000000h0oooo00@000000?ooo`3oool000001@3oool00`000000
oooo0?ooo`0[0?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool0CP3oool00`000000
oooo0?ooo`050?ooo`030000003oool0oooo00L0oooo0P00000E0?ooo`030000003oool0oooo00<0
oooo00<000000?ooo`3oool0503oool001T0oooo00<000000?ooo`3oool00P0000030?ooo`030000
003oool0oooo01T0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`0<0?ooo`030000
003oool0oooo01`0oooo00<000000?ooo`0000004`3oool01@000000oooo0?ooo`3oool0000000`0
oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`070?ooo`030000003oool0000000`0
oooo00<000000?ooo`3oool0103oool01@000000oooo0?ooo`3oool0000000h0oooo00<000000?oo
o`000000:P3oool010000000oooo0?ooo`00000A0?ooo`030000003oool0oooo01<0oooo00<00000
0?ooo`3oool00P3oool00`000000oooo000000030?ooo`030000003oool0oooo00`0oooo00<00000
0?ooo`3oool03`3oool00`000000oooo0?ooo`0C0?ooo`030000003oool0oooo01H0oooo00<00000
0?ooo`3oool0;@3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo01D0oooo00<00000
0?ooo`3oool00P0000060?ooo`050000003oool0oooo0?ooo`0000001P3oool00`000000oooo0?oo
o`0C0?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool00P3oool00`000000oooo0000
000>0?ooo`040000003oool0oooo000000D0oooo00<000000?ooo`3oool0:`3oool00`000000oooo
0?ooo`0<0?ooo`030000003oool0oooo04h0oooo00<000000?ooo`3oool01@3oool00`000000oooo
0?ooo`070?ooo`8000005@3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo01@0oooo
000I0?ooo`030000003oool0oooo008000000`3oool00`000000oooo0?ooo`0I0?ooo`030000003o
ool0oooo00<0oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`0L0?ooo`030000003o
ool0000001<0oooo00D000000?ooo`3oool0oooo0000000<0?ooo`030000003oool0oooo00D0oooo
00<000000?ooo`3oool01`3oool00`000000oooo0000000<0?ooo`030000003oool0oooo00@0oooo
00D000000?ooo`3oool0oooo0000000>0?ooo`030000003oool0000002X0oooo00@000000?ooo`3o
ool000004@3oool00`000000oooo0?ooo`0C0?ooo`030000003oool0oooo0080oooo00<000000?oo
o`0000000`3oool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo00l0oooo00<000000?oo
o`3oool04`3oool00`000000oooo0?ooo`0F0?ooo`030000003oool0oooo02d0oooo00<000000?oo
o`3oool01P3oool00`000000oooo0?ooo`0E0?ooo`030000003oool0oooo008000001P3oool01@00
0000oooo0?ooo`3oool0000000H0oooo00<000000?ooo`3oool04`3oool00`000000oooo0?ooo`08
0?ooo`030000003oool0oooo0080oooo00<000000?ooo`0000003P3oool010000000oooo0?ooo`00
00050?ooo`030000003oool0oooo02/0oooo00<000000?ooo`3oool0303oool00`000000oooo0?oo
o`1>0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool01`3oool2000001D0oooo00<0
00000?ooo`3oool00`3oool00`000000oooo0?ooo`0D0?ooo`006@3oool00`000000oooo0?ooo`02
000000<0oooo00<000000?ooo`3oool06@3oool00`000000oooo0?ooo`030?ooo`030000003oool0
oooo00`0oooo00<000000?ooo`3oool0703oool00`000000oooo0000000C0?ooo`050000003oool0
oooo0?ooo`000000303oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00L0oooo00<0
00000?ooo`000000303oool00`000000oooo0?ooo`040?ooo`050000003oool0oooo0?ooo`000000
3P3oool00`000000oooo0000000Z0?ooo`040000003oool0oooo00000140oooo00<000000?ooo`3o
ool04`3oool00`000000oooo0?ooo`020?ooo`030000003oool0000000<0oooo00<000000?ooo`3o
ool0303oool00`000000oooo0?ooo`0?0?ooo`030000003oool0oooo01<0oooo00<000000?ooo`3o
ool05P3oool00`000000oooo0?ooo`0]0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3o
ool05@3oool00`000000oooo0?ooo`02000000H0oooo00D000000?ooo`3oool0oooo000000060?oo
o`030000003oool0oooo01<0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`020?oo
o`030000003oool0000000h0oooo00@000000?ooo`3oool000001@3oool00`000000oooo0?ooo`0[
0?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool0CP3oool00`000000oooo0?ooo`05
0?ooo`030000003oool0oooo00L0oooo0P00000E0?ooo`030000003oool0oooo00<0oooo00<00000
0?ooo`3oool0503oool001@0ooooUP3oo`030000oa<0ool01@000?mV0?oo00H0003o1@3oo`0@0000
ool0ool0Z03oo`0D0?ooo`006@3oool00`000000oooo0?ooo`02000000<0oooo00<000000?ooo`3o
ool06@3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3o
ool0703oool00`000000oooo0000000C0?ooo`050000003oool0oooo0?ooo`000000303oool00`00
0000oooo0?ooo`050?ooo`030000003oool0oooo00L0oooo00<000000?ooo`000000303oool00`00
0000oooo0?ooo`040?ooo`050000003oool0oooo0?ooo`0000003P3oool00`000000oooo0000000Z
0?ooo`040000003oool0oooo00000140oooo00<000000?ooo`3oool04`3oool00`000000oooo0?oo
o`020?ooo`030000003oool0000000<0oooo00<000000?ooo`3oool0303oool00`000000oooo0?oo
o`0?0?ooo`030000003oool0oooo01<0oooo00<000000?ooo`3oool05P3oool00`000000oooo0?oo
o`0]0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool05@3oool00`000000oooo0?oo
o`02000000H0oooo00D000000?ooo`3oool0oooo000000060?ooo`030000003oool0oooo01<0oooo
00<000000?ooo`3oool0203oool00`000000oooo0?ooo`020?ooo`030000003oool0000000h0oooo
00@000000?ooo`3oool000001@3oool00`000000oooo0?ooo`0[0?ooo`030000003oool0oooo00`0
oooo00<000000?ooo`3oool0CP3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00L0
oooo0P00000E0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0503oool001T0oooo
00<000000?ooo`3oool00P0000030?ooo`030000003oool0oooo01T0oooo00<000000?ooo`3oool0
0`3oool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo01`0oooo00<000000?ooo`000000
4`3oool01@000000oooo0?ooo`3oool0000000`0oooo00<000000?ooo`3oool01@3oool00`000000
oooo0?ooo`070?ooo`030000003oool0000000`0oooo00<000000?ooo`3oool0103oool01@000000
oooo0?ooo`3oool0000000h0oooo00<000000?ooo`000000:P3oool010000000oooo0?ooo`00000A
0?ooo`030000003oool0oooo01<0oooo00<000000?ooo`3oool00P3oool00`000000oooo00000003
0?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool03`3oool00`000000oooo0?ooo`0C
0?ooo`030000003oool0oooo01H0oooo00<000000?ooo`3oool0;@3oool00`000000oooo0?ooo`06
0?ooo`030000003oool0oooo01D0oooo00<000000?ooo`3oool00P0000060?ooo`050000003oool0
oooo0?ooo`0000001P3oool00`000000oooo0?ooo`0C0?ooo`030000003oool0oooo00P0oooo00<0
00000?ooo`3oool00P3oool00`000000oooo0000000>0?ooo`040000003oool0oooo000000D0oooo
00<000000?ooo`3oool0:`3oool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo04h0oooo
00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`070?ooo`8000005@3oool00`000000oooo
0?ooo`030?ooo`030000003oool0oooo01@0oooo000I0?ooo`030000003oool0oooo008000000`3o
ool00`000000oooo0?ooo`0I0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0303o
ool00`000000oooo0?ooo`0L0?ooo`030000003oool0000001<0oooo00D000000?ooo`3oool0oooo
0000000<0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool01`3oool00`000000oooo
0000000<0?ooo`030000003oool0oooo00@0oooo00D000000?ooo`3oool0oooo0000000>0?ooo`03
0000003oool0000002X0oooo00@000000?ooo`3oool000004@3oool00`000000oooo0?ooo`0C0?oo
o`030000003oool0oooo0080oooo00<000000?ooo`0000000`3oool00`000000oooo0?ooo`0<0?oo
o`030000003oool0oooo00l0oooo00<000000?ooo`3oool04`3oool00`000000oooo0?ooo`0F0?oo
o`030000003oool0oooo02d0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`0E0?oo
o`030000003oool0oooo008000001P3oool01@000000oooo0?ooo`3oool0000000H0oooo00<00000
0?ooo`3oool04`3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo0080oooo00<00000
0?ooo`0000003P3oool010000000oooo0?ooo`0000050?ooo`030000003oool0oooo02/0oooo00<0
00000?ooo`3oool0303oool00`000000oooo0?ooo`1>0?ooo`030000003oool0oooo00D0oooo00<0
00000?ooo`3oool01`3oool2000001D0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?oo
o`0D0?ooo`006@3oool00`000000oooo0?ooo`02000000<0oooo00<000000?ooo`3oool06@3oool0
0`000000oooo0?ooo`030?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool0703oool0
0`000000oooo0000000C0?ooo`050000003oool0oooo0?ooo`000000303oool00`000000oooo0?oo
o`050?ooo`030000003oool0oooo00L0oooo00<000000?ooo`000000303oool00`000000oooo0?oo
o`040?ooo`050000003oool0oooo0?ooo`0000003P3oool00`000000oooo0000000Z0?ooo`040000
003oool0oooo00000140oooo00<000000?ooo`3oool04`3oool00`000000oooo0?ooo`020?ooo`03
0000003oool0000000<0oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`0?0?ooo`03
0000003oool0oooo01<0oooo00<000000?ooo`3oool05P3oool00`000000oooo0?ooo`0]0?ooo`03
0000003oool0oooo00H0oooo00<000000?ooo`3oool05@3oool00`000000oooo0?ooo`02000000H0
oooo00D000000?ooo`3oool0oooo000000060?ooo`030000003oool0oooo01<0oooo00<000000?oo
o`3oool0203oool00`000000oooo0?ooo`020?ooo`030000003oool0000000h0oooo00@000000?oo
o`3oool000001@3oool00`000000oooo0?ooo`0[0?ooo`030000003oool0oooo00`0oooo00<00000
0?ooo`3oool0CP3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00L0oooo0P00000E
0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0503oool001T0oooo00<000000?oo
o`3oool00P0000030?ooo`030000003oool0oooo01T0oooo00<000000?ooo`3oool00`3oool00`00
0000oooo0?ooo`0<0?ooo`030000003oool0oooo01`0oooo00<000000?ooo`0000004`3oool01@00
0000oooo0?ooo`3oool0000000`0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`07
0?ooo`030000003oool0000000`0oooo00<000000?ooo`3oool0103oool01@000000oooo0?ooo`3o
ool0000000h0oooo00<000000?ooo`000000:P3oool010000000oooo0?ooo`00000A0?ooo`030000
003oool0oooo01<0oooo00<000000?ooo`3oool00P3oool00`000000oooo000000030?ooo`030000
003oool0oooo00`0oooo00<000000?ooo`3oool03`3oool00`000000oooo0?ooo`0C0?ooo`030000
003oool0oooo01H0oooo00<000000?ooo`3oool0;@3oool00`000000oooo0?ooo`060?ooo`030000
003oool0oooo01D0oooo00<000000?ooo`3oool00P0000060?ooo`050000003oool0oooo0?ooo`00
00001P3oool00`000000oooo0?ooo`0C0?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3o
ool00P3oool00`000000oooo0000000>0?ooo`040000003oool0oooo000000D0oooo00<000000?oo
o`3oool0:`3oool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo04h0oooo00<000000?oo
o`3oool01@3oool00`000000oooo0?ooo`070?ooo`8000005@3oool00`000000oooo0?ooo`030?oo
o`030000003oool0oooo01@0oooo000I0?ooo`030000003oool0oooo008000000`3oool00`000000
oooo0?ooo`0I0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0303oool00`000000
oooo0?ooo`0L0?ooo`030000003oool0000001<0oooo00D000000?ooo`3oool0oooo0000000<0?oo
o`030000003oool0oooo00D0oooo00<000000?ooo`3oool01`3oool00`000000oooo0000000<0?oo
o`030000003oool0oooo00@0oooo00D000000?ooo`3oool0oooo0000000>0?ooo`030000003oool0
000002X0oooo00@000000?ooo`3oool000004@3oool00`000000oooo0?ooo`0C0?ooo`030000003o
ool0oooo0080oooo00<000000?ooo`0000000`3oool00`000000oooo0?ooo`0<0?ooo`030000003o
ool0oooo00l0oooo00<000000?ooo`3oool04`3oool00`000000oooo0?ooo`0F0?ooo`030000003o
ool0oooo02d0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`0E0?ooo`030000003o
ool0oooo008000001P3oool01@000000oooo0?ooo`3oool0000000H0oooo00<000000?ooo`3oool0
4`3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo0080oooo00<000000?ooo`000000
3P3oool010000000oooo0?ooo`0000050?ooo`030000003oool0oooo02/0oooo00<000000?ooo`3o
ool0303oool00`000000oooo0?ooo`1>0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3o
ool01`3oool2000001D0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`0D0?ooo`00
6@3oool00`000000oooo0?ooo`02000000<0oooo00<000000?ooo`3oool06@3oool00`000000oooo
0?ooo`030?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool0703oool00`000000oooo
0000000C0?ooo`050000003oool0oooo0?ooo`000000303oool00`000000oooo0?ooo`050?ooo`03
0000003oool0oooo00L0oooo00<000000?ooo`000000303oool00`000000oooo0?ooo`040?ooo`05
0000003oool0oooo0?ooo`0000003P3oool00`000000oooo0000000Z0?ooo`040000003oool0oooo
00000140oooo00<000000?ooo`3oool04`3oool00`000000oooo0?ooo`020?ooo`030000003oool0
000000<0oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`0?0?ooo`030000003oool0
oooo01<0oooo00<000000?ooo`3oool05P3oool00`000000oooo0?ooo`0]0?ooo`030000003oool0
oooo00H0oooo00<000000?ooo`3oool05@3oool00`000000oooo0?ooo`02000000H0oooo00D00000
0?ooo`3oool0oooo000000060?ooo`030000003oool0oooo01<0oooo00<000000?ooo`3oool0203o
ool00`000000oooo0?ooo`020?ooo`030000003oool0000000h0oooo00@000000?ooo`3oool00000
1@3oool00`000000oooo0?ooo`0[0?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool0
CP3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00L0oooo0P00000E0?ooo`030000
003oool0oooo00<0oooo00<000000?ooo`3oool0503oool001@0oooo203oo`020000o`<0ool07@00
0?n60?oo0180003oo`3oo`3o0?oo01T0ool0503oool001T0oooo00<000000?ooo`3oool00P000003
0?ooo`030000003oool0oooo01T0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`0<
0?ooo`030000003oool0oooo01`0oooo00<000000?ooo`0000004`3oool01@000000oooo0?ooo`3o
ool0000000`0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`070?ooo`030000003o
ool0000000`0oooo00<000000?ooo`3oool0103oool01@000000oooo0?ooo`3oool0000000h0oooo
00<000000?ooo`000000:P3oool010000000oooo0?ooo`00000A0?ooo`030000003oool0oooo01<0
oooo00<000000?ooo`3oool00P3oool00`000000oooo000000030?ooo`030000003oool0oooo00`0
oooo00<000000?ooo`3oool03`3oool00`000000oooo0?ooo`0C0?ooo`030000003oool0oooo01H0
oooo00<000000?ooo`3oool0;@3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo01D0
oooo00<000000?ooo`3oool00P0000060?ooo`050000003oool0oooo0?ooo`0000001P3oool00`00
0000oooo0?ooo`0C0?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool00P3oool00`00
0000oooo0000000>0?ooo`040000003oool0oooo000000D0oooo00<000000?ooo`3oool0:`3oool0
0`000000oooo0?ooo`0<0?ooo`030000003oool0oooo04h0oooo00<000000?ooo`3oool01@3oool0
0`000000oooo0?ooo`070?ooo`8000005@3oool00`000000oooo0?ooo`030?ooo`030000003oool0
oooo01@0oooo000I0?ooo`030000003oool0oooo008000000`3oool00`000000oooo0?ooo`0I0?oo
o`030000003oool0oooo00<0oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`0L0?oo
o`030000003oool0000001<0oooo00D000000?ooo`3oool0oooo0000000<0?ooo`030000003oool0
oooo00D0oooo00<000000?ooo`3oool01`3oool00`000000oooo0000000<0?ooo`030000003oool0
oooo00@0oooo00D000000?ooo`3oool0oooo0000000>0?ooo`030000003oool0000002X0oooo00@0
00000?ooo`3oool000004@3oool00`000000oooo0?ooo`0C0?ooo`030000003oool0oooo0080oooo
00<000000?ooo`0000000`3oool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo00l0oooo
00<000000?ooo`3oool04`3oool00`000000oooo0?ooo`0F0?ooo`030000003oool0oooo02d0oooo
00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`0E0?ooo`030000003oool0oooo00800000
1P3oool01@000000oooo0?ooo`3oool0000000H0oooo00<000000?ooo`3oool04`3oool00`000000
oooo0?ooo`080?ooo`030000003oool0oooo0080oooo00<000000?ooo`0000003P3oool010000000
oooo0?ooo`0000050?ooo`030000003oool0oooo02/0oooo00<000000?ooo`3oool0303oool00`00
0000oooo0?ooo`1>0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool01`3oool20000
01D0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`0D0?ooo`006@3oool00`000000
oooo0?ooo`02000000<0oooo00<000000?ooo`3oool06@3oool00`000000oooo0?ooo`030?ooo`03
0000003oool0oooo00`0oooo00<000000?ooo`3oool0703oool00`000000oooo0000000C0?ooo`05
0000003oool0oooo0?ooo`000000303oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo
00L0oooo00<000000?ooo`000000303oool00`000000oooo0?ooo`040?ooo`050000003oool0oooo
0?ooo`0000003P3oool00`000000oooo0000000Z0?ooo`040000003oool0oooo00000140oooo00<0
00000?ooo`3oool04`3oool00`000000oooo0?ooo`020?ooo`030000003oool0000000<0oooo00<0
00000?ooo`3oool0303oool00`000000oooo0?ooo`0?0?ooo`030000003oool0oooo01<0oooo00<0
00000?ooo`3oool05P3oool00`000000oooo0?ooo`0]0?ooo`030000003oool0oooo00H0oooo00<0
00000?ooo`3oool05@3oool00`000000oooo0?ooo`02000000H0oooo00D000000?ooo`3oool0oooo
000000060?ooo`030000003oool0oooo01<0oooo00<000000?ooo`3oool0203oool00`000000oooo
0?ooo`020?ooo`030000003oool0000000h0oooo00@000000?ooo`3oool000001@3oool00`000000
oooo0?ooo`0[0?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool0CP3oool00`000000
oooo0?ooo`050?ooo`030000003oool0oooo00L0oooo0P00000E0?ooo`030000003oool0oooo00<0
oooo00<000000?ooo`3oool0503oool001T0oooo00<000000?ooo`3oool00P0000030?ooo`030000
003oool0oooo01T0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`0<0?ooo`030000
003oool0oooo01`0oooo00<000000?ooo`0000004`3oool01@000000oooo0?ooo`3oool0000000`0
oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`070?ooo`030000003oool0000000`0
oooo00<000000?ooo`3oool0103oool01@000000oooo0?ooo`3oool0000000h0oooo00<000000?oo
o`000000:P3oool010000000oooo0?ooo`00000A0?ooo`030000003oool0oooo01<0oooo00<00000
0?ooo`3oool00P3oool00`000000oooo000000030?ooo`030000003oool0oooo00`0oooo00<00000
0?ooo`3oool03`3oool00`000000oooo0?ooo`0C0?ooo`030000003oool0oooo01H0oooo00<00000
0?ooo`3oool0;@3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo01D0oooo00<00000
0?ooo`3oool00P0000060?ooo`050000003oool0oooo0?ooo`0000001P3oool00`000000oooo0?oo
o`0C0?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool00P3oool00`000000oooo0000
000>0?ooo`040000003oool0oooo000000D0oooo00<000000?ooo`3oool0:`3oool00`000000oooo
0?ooo`0<0?ooo`030000003oool0oooo04h0oooo00<000000?ooo`3oool01@3oool00`000000oooo
0?ooo`070?ooo`8000005@3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo01@0oooo
000I0?ooo`030000003oool0oooo008000000`3oool00`000000oooo0?ooo`0I0?ooo`030000003o
ool0oooo00<0oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`0L0?ooo`030000003o
ool0000001<0oooo00D000000?ooo`3oool0oooo0000000<0?ooo`030000003oool0oooo00D0oooo
00<000000?ooo`3oool01`3oool00`000000oooo0000000<0?ooo`030000003oool0oooo00@0oooo
00D000000?ooo`3oool0oooo0000000>0?ooo`030000003oool0000002X0oooo00@000000?ooo`3o
ool000004@3oool00`000000oooo0?ooo`0C0?ooo`030000003oool0oooo0080oooo00<000000?oo
o`0000000`3oool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo00l0oooo00<000000?oo
o`3oool04`3oool00`000000oooo0?ooo`0F0?ooo`030000003oool0oooo02d0oooo00<000000?oo
o`3oool01P3oool00`000000oooo0?ooo`0E0?ooo`030000003oool0oooo008000001P3oool01@00
0000oooo0?ooo`3oool0000000H0oooo00<000000?ooo`3oool04`3oool00`000000oooo0?ooo`08
0?ooo`030000003oool0oooo0080oooo00<000000?ooo`0000003P3oool010000000oooo0?ooo`00
00050?ooo`030000003oool0oooo02/0oooo00<000000?ooo`3oool0303oool00`000000oooo0?oo
o`1>0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool01`3oool2000001D0oooo00<0
00000?ooo`3oool00`3oool00`000000oooo0?ooo`0D0?ooo`006@3oool00`000000oooo0?ooo`02
000000<0oooo00<000000?ooo`3oool06@3oool00`000000oooo0?ooo`030?ooo`030000003oool0
oooo00`0oooo00<000000?ooo`3oool0703oool00`000000oooo0000000C0?ooo`050000003oool0
oooo0?ooo`000000303oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00L0oooo00<0
00000?ooo`000000303oool00`000000oooo0?ooo`040?ooo`050000003oool0oooo0?ooo`000000
3P3oool00`000000oooo0000000Z0?ooo`040000003oool0oooo00000140oooo00<000000?ooo`3o
ool04`3oool00`000000oooo0?ooo`020?ooo`030000003oool0000000<0oooo00<000000?ooo`3o
ool0303oool00`000000oooo0?ooo`0?0?ooo`030000003oool0oooo01<0oooo00<000000?ooo`3o
ool05P3oool00`000000oooo0?ooo`0]0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3o
ool05@3oool00`000000oooo0?ooo`02000000H0oooo00D000000?ooo`3oool0oooo000000060?oo
o`030000003oool0oooo01<0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`020?oo
o`030000003oool0000000h0oooo00@000000?ooo`3oool000001@3oool00`000000oooo0?ooo`0[
0?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool0CP3oool00`000000oooo0?ooo`05
0?ooo`030000003oool0oooo00L0oooo0P00000E0?ooo`030000003oool0oooo00<0oooo00<00000
0?ooo`3oool0503oool001@0ooooo`3oo`3o0?oo0:T0ool02@000?lP0?oo00L0003o0P3oo`0D0?oo
o`006@3oool00`000000oooo0?ooo`02000000<0oooo00<000000?ooo`3oool06@3oool00`000000
oooo0?ooo`030?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool0703oool00`000000
oooo0000000C0?ooo`050000003oool0oooo0?ooo`000000303oool00`000000oooo0?ooo`050?oo
o`030000003oool0oooo00L0oooo00<000000?ooo`000000303oool00`000000oooo0?ooo`040?oo
o`050000003oool0oooo0?ooo`0000003P3oool00`000000oooo0000000Z0?ooo`040000003oool0
oooo00000140oooo00<000000?ooo`3oool04`3oool00`000000oooo0?ooo`020?ooo`030000003o
ool0000000<0oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`0?0?ooo`030000003o
ool0oooo01<0oooo00<000000?ooo`3oool05P3oool00`000000oooo0?ooo`0]0?ooo`030000003o
ool0oooo00H0oooo00<000000?ooo`3oool05@3oool00`000000oooo0?ooo`02000000H0oooo00D0
00000?ooo`3oool0oooo000000060?ooo`030000003oool0oooo01<0oooo00<000000?ooo`3oool0
203oool00`000000oooo0?ooo`020?ooo`030000003oool0000000h0oooo00@000000?ooo`3oool0
00001@3oool00`000000oooo0?ooo`0[0?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3o
ool0CP3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00L0oooo0P00000E0?ooo`03
0000003oool0oooo00<0oooo00<000000?ooo`3oool0503oool001T0oooo00<000000?ooo`3oool0
0P0000030?ooo`030000003oool0oooo01T0oooo00<000000?ooo`3oool00`3oool00`000000oooo
0?ooo`0<0?ooo`030000003oool0oooo01`0oooo00<000000?ooo`0000004`3oool01@000000oooo
0?ooo`3oool0000000`0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`070?ooo`03
0000003oool0000000`0oooo00<000000?ooo`3oool0103oool01@000000oooo0?ooo`3oool00000
00h0oooo00<000000?ooo`000000:P3oool010000000oooo0?ooo`00000A0?ooo`030000003oool0
oooo01<0oooo00<000000?ooo`3oool00P3oool00`000000oooo000000030?ooo`030000003oool0
oooo00`0oooo00<000000?ooo`3oool03`3oool00`000000oooo0?ooo`0C0?ooo`030000003oool0
oooo01H0oooo00<000000?ooo`3oool0;@3oool00`000000oooo0?ooo`060?ooo`030000003oool0
oooo01D0oooo00<000000?ooo`3oool00P0000060?ooo`050000003oool0oooo0?ooo`0000001P3o
ool00`000000oooo0?ooo`0C0?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool00P3o
ool00`000000oooo0000000>0?ooo`040000003oool0oooo000000D0oooo00<000000?ooo`3oool0
:`3oool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo04h0oooo00<000000?ooo`3oool0
1@3oool00`000000oooo0?ooo`070?ooo`8000005@3oool00`000000oooo0?ooo`030?ooo`030000
003oool0oooo01@0oooo000I0?ooo`030000003oool0oooo008000000`3oool00`000000oooo0?oo
o`0I0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0303oool00`000000oooo0?oo
o`0L0?ooo`030000003oool0000001<0oooo00D000000?ooo`3oool0oooo0000000<0?ooo`030000
003oool0oooo00D0oooo00<000000?ooo`3oool01`3oool00`000000oooo0000000<0?ooo`030000
003oool0oooo00@0oooo00D000000?ooo`3oool0oooo0000000>0?ooo`030000003oool0000002X0
oooo00@000000?ooo`3oool000004@3oool00`000000oooo0?ooo`0C0?ooo`030000003oool0oooo
0080oooo00<000000?ooo`0000000`3oool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo
00l0oooo00<000000?ooo`3oool04`3oool00`000000oooo0?ooo`0F0?ooo`030000003oool0oooo
02d0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`0E0?ooo`030000003oool0oooo
008000001P3oool01@000000oooo0?ooo`3oool0000000H0oooo00<000000?ooo`3oool04`3oool0
0`000000oooo0?ooo`080?ooo`030000003oool0oooo0080oooo00<000000?ooo`0000003P3oool0
10000000oooo0?ooo`0000050?ooo`030000003oool0oooo02/0oooo00<000000?ooo`3oool0303o
ool00`000000oooo0?ooo`1>0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool01`3o
ool2000001D0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`0D0?ooo`006@3oool0
0`000000oooo0?ooo`02000000<0oooo00<000000?ooo`3oool06@3oool00`000000oooo0?ooo`03
0?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool0703oool00`000000oooo0000000C
0?ooo`050000003oool0oooo0?ooo`000000303oool00`000000oooo0?ooo`050?ooo`030000003o
ool0oooo00L0oooo00<000000?ooo`000000303oool00`000000oooo0?ooo`040?ooo`050000003o
ool0oooo0?ooo`0000003P3oool00`000000oooo0000000Z0?ooo`040000003oool0oooo00000140
oooo00<000000?ooo`3oool04`3oool00`000000oooo0?ooo`020?ooo`030000003oool0000000<0
oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`0?0?ooo`030000003oool0oooo01<0
oooo00<000000?ooo`3oool05P3oool00`000000oooo0?ooo`0]0?ooo`030000003oool0oooo00H0
oooo00<000000?ooo`3oool05@3oool00`000000oooo0?ooo`02000000H0oooo00D000000?ooo`3o
ool0oooo000000060?ooo`030000003oool0oooo01<0oooo00<000000?ooo`3oool0203oool00`00
0000oooo0?ooo`020?ooo`030000003oool0000000h0oooo00@000000?ooo`3oool000001@3oool0
0`000000oooo0?ooo`0[0?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool0CP3oool0
0`000000oooo0?ooo`050?ooo`030000003oool0oooo00L0oooo0P00000E0?ooo`030000003oool0
oooo00<0oooo00<000000?ooo`3oool0503oool001T0oooo00<000000?ooo`3oool00P0000030?oo
o`030000003oool0oooo01T0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`0<0?oo
o`030000003oool0oooo01`0oooo00<000000?ooo`0000004`3oool01@000000oooo0?ooo`3oool0
000000`0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`070?ooo`030000003oool0
000000`0oooo00<000000?ooo`3oool0103oool01@000000oooo0?ooo`3oool0000000h0oooo00<0
00000?ooo`000000:P3oool010000000oooo0?ooo`00000A0?ooo`030000003oool0oooo01<0oooo
00<000000?ooo`3oool00P3oool00`000000oooo000000030?ooo`030000003oool0oooo00`0oooo
00<000000?ooo`3oool03`3oool00`000000oooo0?ooo`0C0?ooo`030000003oool0oooo01H0oooo
00<000000?ooo`3oool0;@3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo01D0oooo
00<000000?ooo`3oool00P0000060?ooo`050000003oool0oooo0?ooo`0000001P3oool00`000000
oooo0?ooo`0C0?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool00P3oool00`000000
oooo0000000>0?ooo`040000003oool0oooo000000D0oooo00<000000?ooo`3oool0:`3oool00`00
0000oooo0?ooo`0<0?ooo`030000003oool0oooo04h0oooo00<000000?ooo`3oool01@3oool00`00
0000oooo0?ooo`070?ooo`8000005@3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo
01@0oooo000I0?ooo`030000003oool0oooo008000000`3oool00`000000oooo0?ooo`0I0?ooo`03
0000003oool0oooo00<0oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`0L0?ooo`03
0000003oool0000001<0oooo00D000000?ooo`3oool0oooo0000000<0?ooo`030000003oool0oooo
00D0oooo00<000000?ooo`3oool01`3oool00`000000oooo0000000<0?ooo`030000003oool0oooo
00@0oooo00D000000?ooo`3oool0oooo0000000>0?ooo`030000003oool0000002X0oooo00@00000
0?ooo`3oool000004@3oool00`000000oooo0?ooo`0C0?ooo`030000003oool0oooo0080oooo00<0
00000?ooo`0000000`3oool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo00l0oooo00<0
00000?ooo`3oool04`3oool00`000000oooo0?ooo`0F0?ooo`030000003oool0oooo02d0oooo00<0
00000?ooo`3oool01P3oool00`000000oooo0?ooo`0E0?ooo`030000003oool0oooo008000001P3o
ool01@000000oooo0?ooo`3oool0000000H0oooo00<000000?ooo`3oool04`3oool00`000000oooo
0?ooo`080?ooo`030000003oool0oooo0080oooo00<000000?ooo`0000003P3oool010000000oooo
0?ooo`0000050?ooo`030000003oool0oooo02/0oooo00<000000?ooo`3oool0303oool00`000000
oooo0?ooo`1>0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool01`3oool2000001D0
oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`0D0?ooo`006@3oool00`000000oooo
0?ooo`02000000<0oooo00<000000?ooo`3oool06@3oool00`000000oooo0?ooo`030?ooo`030000
003oool0oooo00`0oooo00<000000?ooo`3oool0703oool00`000000oooo0000000C0?ooo`050000
003oool0oooo0?ooo`000000303oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00L0
oooo00<000000?ooo`000000303oool00`000000oooo0?ooo`040?ooo`050000003oool0oooo0?oo
o`0000003P3oool00`000000oooo0000000Z0?ooo`040000003oool0oooo00000140oooo00<00000
0?ooo`3oool04`3oool00`000000oooo0?ooo`020?ooo`030000003oool0000000<0oooo00<00000
0?ooo`3oool0303oool00`000000oooo0?ooo`0?0?ooo`030000003oool0oooo01<0oooo00<00000
0?ooo`3oool05P3oool00`000000oooo0?ooo`0]0?ooo`030000003oool0oooo00H0oooo00<00000
0?ooo`3oool05@3oool00`000000oooo0?ooo`02000000H0oooo00D000000?ooo`3oool0oooo0000
00060?ooo`030000003oool0oooo01<0oooo00<000000?ooo`3oool0203oool00`000000oooo0?oo
o`020?ooo`030000003oool0000000h0oooo00@000000?ooo`3oool000001@3oool00`000000oooo
0?ooo`0[0?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool0CP3oool00`000000oooo
0?ooo`050?ooo`030000003oool0oooo00L0oooo0P00000E0?ooo`030000003oool0oooo00<0oooo
00<000000?ooo`3oool0503oool001@0ooooL`3oo`050000ool0ool0o`3oo`1S0?oo01@0oooo000I
0?ooo`030000003oool0oooo008000000`3oool00`000000oooo0?ooo`0I0?ooo`030000003oool0
oooo00<0oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`0L0?ooo`030000003oool0
000001<0oooo00D000000?ooo`3oool0oooo0000000<0?ooo`030000003oool0oooo00D0oooo00<0
00000?ooo`3oool01`3oool00`000000oooo0000000<0?ooo`030000003oool0oooo00@0oooo00D0
00000?ooo`3oool0oooo0000000>0?ooo`030000003oool0000002X0oooo00@000000?ooo`3oool0
00004@3oool00`000000oooo0?ooo`0C0?ooo`030000003oool0oooo0080oooo00<000000?ooo`00
00000`3oool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo00l0oooo00<000000?ooo`3o
ool04`3oool00`000000oooo0?ooo`0F0?ooo`030000003oool0oooo02d0oooo00<000000?ooo`3o
ool01P3oool00`000000oooo0?ooo`0E0?ooo`030000003oool0oooo008000001P3oool01@000000
oooo0?ooo`3oool0000000H0oooo00<000000?ooo`3oool04`3oool00`000000oooo0?ooo`080?oo
o`030000003oool0oooo0080oooo00<000000?ooo`0000003P3oool010000000oooo0?ooo`000005
0?ooo`030000003oool0oooo02/0oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`1>
0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool01`3oool2000001D0oooo00<00000
0?ooo`3oool00`3oool00`000000oooo0?ooo`0D0?ooo`006@3oool00`000000oooo0?ooo`020000
00<0oooo00<000000?ooo`3oool06@3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo
00`0oooo00<000000?ooo`3oool0703oool00`000000oooo0000000C0?ooo`050000003oool0oooo
0?ooo`000000303oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00L0oooo00<00000
0?ooo`000000303oool00`000000oooo0?ooo`040?ooo`050000003oool0oooo0?ooo`0000003P3o
ool00`000000oooo0000000Z0?ooo`040000003oool0oooo00000140oooo00<000000?ooo`3oool0
4`3oool00`000000oooo0?ooo`020?ooo`030000003oool0000000<0oooo00<000000?ooo`3oool0
303oool00`000000oooo0?ooo`0?0?ooo`030000003oool0oooo01<0oooo00<000000?ooo`3oool0
5P3oool00`000000oooo0?ooo`0]0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool0
5@3oool00`000000oooo0?ooo`02000000H0oooo00D000000?ooo`3oool0oooo000000060?ooo`03
0000003oool0oooo01<0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`020?ooo`03
0000003oool0000000h0oooo00@000000?ooo`3oool000001@3oool00`000000oooo0?ooo`0[0?oo
o`030000003oool0oooo00`0oooo00<000000?ooo`3oool0CP3oool00`000000oooo0?ooo`050?oo
o`030000003oool0oooo00L0oooo0P00000E0?ooo`030000003oool0oooo00<0oooo00<000000?oo
o`3oool0503oool001T0oooo00<000000?ooo`3oool00P0000030?ooo`030000003oool0oooo01T0
oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo01`0
oooo00<000000?ooo`0000004`3oool01@000000oooo0?ooo`3oool0000000`0oooo00<000000?oo
o`3oool01@3oool00`000000oooo0?ooo`070?ooo`030000003oool0000000`0oooo00<000000?oo
o`3oool0103oool01@000000oooo0?ooo`3oool0000000h0oooo00<000000?ooo`000000:P3oool0
10000000oooo0?ooo`00000A0?ooo`030000003oool0oooo01<0oooo00<000000?ooo`3oool00P3o
ool00`000000oooo000000030?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool03`3o
ool00`000000oooo0?ooo`0C0?ooo`030000003oool0oooo01H0oooo00<000000?ooo`3oool0;@3o
ool00`000000oooo0?ooo`060?ooo`030000003oool0oooo01D0oooo00<000000?ooo`3oool00P00
00060?ooo`050000003oool0oooo0?ooo`0000001P3oool00`000000oooo0?ooo`0C0?ooo`030000
003oool0oooo00P0oooo00<000000?ooo`3oool00P3oool00`000000oooo0000000>0?ooo`040000
003oool0oooo000000D0oooo00<000000?ooo`3oool0:`3oool00`000000oooo0?ooo`0<0?ooo`03
0000003oool0oooo04h0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`070?ooo`80
00005@3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo01@0oooo000I0?ooo`030000
003oool0oooo008000000`3oool00`000000oooo0?ooo`0I0?ooo`030000003oool0oooo00<0oooo
00<000000?ooo`3oool0303oool00`000000oooo0?ooo`0L0?ooo`030000003oool0000001<0oooo
00D000000?ooo`3oool0oooo0000000<0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3o
ool01`3oool00`000000oooo0000000<0?ooo`030000003oool0oooo00@0oooo00D000000?ooo`3o
ool0oooo0000000>0?ooo`030000003oool0000002X0oooo00@000000?ooo`3oool000004@3oool0
0`000000oooo0?ooo`0C0?ooo`030000003oool0oooo0080oooo00<000000?ooo`0000000`3oool0
0`000000oooo0?ooo`0<0?ooo`030000003oool0oooo00l0oooo00<000000?ooo`3oool04`3oool0
0`000000oooo0?ooo`0F0?ooo`030000003oool0oooo02d0oooo00<000000?ooo`3oool01P3oool0
0`000000oooo0?ooo`0E0?ooo`030000003oool0oooo008000001P3oool01@000000oooo0?ooo`3o
ool0000000H0oooo00<000000?ooo`3oool04`3oool00`000000oooo0?ooo`080?ooo`030000003o
ool0oooo0080oooo00<000000?ooo`0000003P3oool010000000oooo0?ooo`0000050?ooo`030000
003oool0oooo02/0oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`1>0?ooo`030000
003oool0oooo00D0oooo00<000000?ooo`3oool01`3oool2000001D0oooo00<000000?ooo`3oool0
0`3oool00`000000oooo0?ooo`0D0?ooo`006@3oool00`000000oooo0?ooo`02000000<0oooo00<0
00000?ooo`3oool06@3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00`0oooo00<0
00000?ooo`3oool0703oool00`000000oooo0000000C0?ooo`050000003oool0oooo0?ooo`000000
303oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00L0oooo00<000000?ooo`000000
303oool00`000000oooo0?ooo`040?ooo`050000003oool0oooo0?ooo`0000003P3oool00`000000
oooo0000000Z0?ooo`040000003oool0oooo00000140oooo00<000000?ooo`3oool04`3oool00`00
0000oooo0?ooo`020?ooo`030000003oool0000000<0oooo00<000000?ooo`3oool0303oool00`00
0000oooo0?ooo`0?0?ooo`030000003oool0oooo01<0oooo00<000000?ooo`3oool05P3oool00`00
0000oooo0?ooo`0]0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool05@3oool00`00
0000oooo0?ooo`02000000H0oooo00D000000?ooo`3oool0oooo000000060?ooo`030000003oool0
oooo01<0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`020?ooo`030000003oool0
000000h0oooo00@000000?ooo`3oool000001@3oool00`000000oooo0?ooo`0[0?ooo`030000003o
ool0oooo00`0oooo00<000000?ooo`3oool0CP3oool00`000000oooo0?ooo`050?ooo`030000003o
ool0oooo00L0oooo0P00000E0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0503o
ool001T0oooo00<000000?ooo`3oool00P0000030?ooo`030000003oool0oooo01T0oooo00<00000
0?ooo`3oool00`3oool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo01`0oooo00<00000
0?ooo`0000004`3oool01@000000oooo0?ooo`3oool0000000`0oooo00<000000?ooo`3oool01@3o
ool00`000000oooo0?ooo`070?ooo`030000003oool0000000`0oooo00<000000?ooo`3oool0103o
ool01@000000oooo0?ooo`3oool0000000h0oooo00<000000?ooo`000000:P3oool010000000oooo
0?ooo`00000A0?ooo`030000003oool0oooo01<0oooo00<000000?ooo`3oool00P3oool00`000000
oooo000000030?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool03`3oool00`000000
oooo0?ooo`0C0?ooo`030000003oool0oooo01H0oooo00<000000?ooo`3oool0;@3oool00`000000
oooo0?ooo`060?ooo`030000003oool0oooo01D0oooo00<000000?ooo`3oool00P0000060?ooo`05
0000003oool0oooo0?ooo`0000001P3oool00`000000oooo0?ooo`0C0?ooo`030000003oool0oooo
00P0oooo00<000000?ooo`3oool00P3oool00`000000oooo0000000>0?ooo`040000003oool0oooo
000000D0oooo00<000000?ooo`3oool0:`3oool00`000000oooo0?ooo`0<0?ooo`030000003oool0
oooo04h0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`070?ooo`8000005@3oool0
0`000000oooo0?ooo`030?ooo`030000003oool0oooo01@0oooo000I0?ooo`030000003oool0oooo
008000000`3oool00`000000oooo0?ooo`0I0?ooo`030000003oool0oooo00<0oooo00<000000?oo
o`3oool0303oool00`000000oooo0?ooo`0L0?ooo`030000003oool0000001<0oooo00D000000?oo
o`3oool0oooo0000000<0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool01`3oool0
0`000000oooo0000000<0?ooo`030000003oool0oooo00@0oooo00D000000?ooo`3oool0oooo0000
000>0?ooo`030000003oool0000002X0oooo00@000000?ooo`3oool000004@3oool00`000000oooo
0?ooo`0C0?ooo`030000003oool0oooo0080oooo00<000000?ooo`0000000`3oool00`000000oooo
0?ooo`0<0?ooo`030000003oool0oooo00l0oooo00<000000?ooo`3oool04`3oool00`000000oooo
0?ooo`0F0?ooo`030000003oool0oooo02d0oooo00<000000?ooo`3oool01P3oool00`000000oooo
0?ooo`0E0?ooo`030000003oool0oooo008000001P3oool01@000000oooo0?ooo`3oool0000000H0
oooo00<000000?ooo`3oool04`3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo0080
oooo00<000000?ooo`0000003P3oool010000000oooo0?ooo`0000050?ooo`030000003oool0oooo
02/0oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`1>0?ooo`030000003oool0oooo
00D0oooo00<000000?ooo`3oool01`3oool2000001D0oooo00<000000?ooo`3oool00`3oool00`00
0000oooo0?ooo`0D0?ooo`00503ooooo0?oo0?l0ool04P3oo`040000o`D0ool0;`000?l>0?oo0580
003o<@3oo`0D0?ooo`006@3oool00`000000oooo0?ooo`02000000<0oooo00<000000?ooo`3oool0
6@3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool0
703oool00`000000oooo0000000C0?ooo`050000003oool0oooo0?ooo`000000303oool00`000000
oooo0?ooo`050?ooo`030000003oool0oooo00L0oooo00<000000?ooo`000000303oool00`000000
oooo0?ooo`040?ooo`050000003oool0oooo0?ooo`0000003P3oool00`000000oooo0000000Z0?oo
o`040000003oool0oooo00000140oooo00<000000?ooo`3oool04`3oool00`000000oooo0?ooo`02
0?ooo`030000003oool0000000<0oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`0?
0?ooo`030000003oool0oooo01<0oooo00<000000?ooo`3oool05P3oool00`000000oooo0?ooo`0]
0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool05@3oool00`000000oooo0?ooo`02
000000H0oooo00D000000?ooo`3oool0oooo000000060?ooo`030000003oool0oooo01<0oooo00<0
00000?ooo`3oool0203oool00`000000oooo0?ooo`020?ooo`030000003oool0000000h0oooo00@0
00000?ooo`3oool000001@3oool00`000000oooo0?ooo`0[0?ooo`030000003oool0oooo00`0oooo
00<000000?ooo`3oool0CP3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00L0oooo
0P00000E0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0503oool001T0oooo00<0
00000?ooo`3oool00P0000030?ooo`030000003oool0oooo01T0oooo00<000000?ooo`3oool00`3o
ool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo01`0oooo00<000000?ooo`0000004`3o
ool01@000000oooo0?ooo`3oool0000000`0oooo00<000000?ooo`3oool01@3oool00`000000oooo
0?ooo`070?ooo`030000003oool0000000`0oooo00<000000?ooo`3oool0103oool01@000000oooo
0?ooo`3oool0000000h0oooo00<000000?ooo`000000:P3oool010000000oooo0?ooo`00000A0?oo
o`030000003oool0oooo01<0oooo00<000000?ooo`3oool00P3oool00`000000oooo000000030?oo
o`030000003oool0oooo00`0oooo00<000000?ooo`3oool03`3oool00`000000oooo0?ooo`0C0?oo
o`030000003oool0oooo01H0oooo00<000000?ooo`3oool0;@3oool00`000000oooo0?ooo`060?oo
o`030000003oool0oooo01D0oooo00<000000?ooo`3oool00P0000060?ooo`050000003oool0oooo
0?ooo`0000001P3oool00`000000oooo0?ooo`0C0?ooo`030000003oool0oooo00P0oooo00<00000
0?ooo`3oool00P3oool00`000000oooo0000000>0?ooo`040000003oool0oooo000000D0oooo00<0
00000?ooo`3oool0:`3oool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo04h0oooo00<0
00000?ooo`3oool01@3oool00`000000oooo0?ooo`070?ooo`8000005@3oool00`000000oooo0?oo
o`030?ooo`030000003oool0oooo01@0oooo000I0?ooo`030000003oool0oooo008000000`3oool0
0`000000oooo0?ooo`0I0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0303oool0
0`000000oooo0?ooo`0L0?ooo`030000003oool0000001<0oooo00D000000?ooo`3oool0oooo0000
000<0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool01`3oool00`000000oooo0000
000<0?ooo`030000003oool0oooo00@0oooo00D000000?ooo`3oool0oooo0000000>0?ooo`030000
003oool0000002X0oooo00@000000?ooo`3oool000004@3oool00`000000oooo0?ooo`0C0?ooo`03
0000003oool0oooo0080oooo00<000000?ooo`0000000`3oool00`000000oooo0?ooo`0<0?ooo`03
0000003oool0oooo00l0oooo00<000000?ooo`3oool04`3oool00`000000oooo0?ooo`0F0?ooo`03
0000003oool0oooo02d0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`0E0?ooo`03
0000003oool0oooo008000001P3oool01@000000oooo0?ooo`3oool0000000H0oooo00<000000?oo
o`3oool04`3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo0080oooo00<000000?oo
o`0000003P3oool010000000oooo0?ooo`0000050?ooo`030000003oool0oooo02/0oooo00<00000
0?ooo`3oool0303oool00`000000oooo0?ooo`1>0?ooo`030000003oool0oooo00D0oooo00<00000
0?ooo`3oool01`3oool2000001D0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`0D
0?ooo`006@3oool00`000000oooo0?ooo`02000000<0oooo00<000000?ooo`3oool06@3oool00`00
0000oooo0?ooo`030?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool0703oool00`00
0000oooo0000000C0?ooo`050000003oool0oooo0?ooo`000000303oool00`000000oooo0?ooo`05
0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`000000303oool00`000000oooo0?ooo`04
0?ooo`050000003oool0oooo0?ooo`0000003P3oool00`000000oooo0000000Z0?ooo`040000003o
ool0oooo00000140oooo00<000000?ooo`3oool04`3oool00`000000oooo0?ooo`020?ooo`030000
003oool0000000<0oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`0?0?ooo`030000
003oool0oooo01<0oooo00<000000?ooo`3oool05P3oool00`000000oooo0?ooo`0]0?ooo`030000
003oool0oooo00H0oooo00<000000?ooo`3oool05@3oool00`000000oooo0?ooo`02000000H0oooo
00D000000?ooo`3oool0oooo000000060?ooo`030000003oool0oooo01<0oooo00<000000?ooo`3o
ool0203oool00`000000oooo0?ooo`020?ooo`030000003oool0000000h0oooo00@000000?ooo`3o
ool000001@3oool00`000000oooo0?ooo`0[0?ooo`030000003oool0oooo00`0oooo00<000000?oo
o`3oool0CP3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00L0oooo0P00000E0?oo
o`030000003oool0oooo00<0oooo00<000000?ooo`3oool0503oool001T0oooo00<000000?ooo`3o
ool00P0000030?ooo`030000003oool0oooo01T0oooo00<000000?ooo`3oool00`3oool00`000000
oooo0?ooo`0<0?ooo`030000003oool0oooo01`0oooo00<000000?ooo`0000004`3oool01@000000
oooo0?ooo`3oool0000000`0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`070?oo
o`030000003oool0000000`0oooo00<000000?ooo`3oool0103oool01@000000oooo0?ooo`3oool0
000000h0oooo00<000000?ooo`000000:P3oool010000000oooo0?ooo`00000A0?ooo`030000003o
ool0oooo01<0oooo00<000000?ooo`3oool00P3oool00`000000oooo000000030?ooo`030000003o
ool0oooo00`0oooo00<000000?ooo`3oool03`3oool00`000000oooo0?ooo`0C0?ooo`030000003o
ool0oooo01H0oooo00<000000?ooo`3oool0;@3oool00`000000oooo0?ooo`060?ooo`030000003o
ool0oooo01D0oooo00<000000?ooo`3oool00P0000060?ooo`050000003oool0oooo0?ooo`000000
1P3oool00`000000oooo0?ooo`0C0?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool0
0P3oool00`000000oooo0000000>0?ooo`040000003oool0oooo000000D0oooo00<000000?ooo`3o
ool0:`3oool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo04h0oooo00<000000?ooo`3o
ool01@3oool00`000000oooo0?ooo`070?ooo`8000005@3oool00`000000oooo0?ooo`030?ooo`03
0000003oool0oooo01@0oooo000I0?ooo`030000003oool0oooo008000000`3oool00`000000oooo
0?ooo`0I0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0303oool00`000000oooo
0?ooo`0L0?ooo`030000003oool0000001<0oooo00D000000?ooo`3oool0oooo0000000<0?ooo`03
0000003oool0oooo00D0oooo00<000000?ooo`3oool01`3oool00`000000oooo0000000<0?ooo`03
0000003oool0oooo00@0oooo00D000000?ooo`3oool0oooo0000000>0?ooo`030000003oool00000
02X0oooo00@000000?ooo`3oool000004@3oool00`000000oooo0?ooo`0C0?ooo`030000003oool0
oooo0080oooo00<000000?ooo`0000000`3oool00`000000oooo0?ooo`0<0?ooo`030000003oool0
oooo00l0oooo00<000000?ooo`3oool04`3oool00`000000oooo0?ooo`0F0?ooo`030000003oool0
oooo02d0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`0E0?ooo`030000003oool0
oooo008000001P3oool01@000000oooo0?ooo`3oool0000000H0oooo00<000000?ooo`3oool04`3o
ool00`000000oooo0?ooo`080?ooo`030000003oool0oooo0080oooo00<000000?ooo`0000003P3o
ool010000000oooo0?ooo`0000050?ooo`030000003oool0oooo02/0oooo00<000000?ooo`3oool0
303oool00`000000oooo0?ooo`1>0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool0
1`3oool2000001D0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`0D0?ooo`00503o
oooo0?oo0?00ool030000?l60?oo0100003o0P3oo`070000okl0ool0503oool001T0oooo00<00000
0?ooo`3oool00P0000030?ooo`030000003oool0oooo01T0oooo00<000000?ooo`3oool00`3oool0
0`000000oooo0?ooo`0<0?ooo`030000003oool0oooo01`0oooo00<000000?ooo`0000004`3oool0
1@000000oooo0?ooo`3oool0000000`0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?oo
o`070?ooo`030000003oool0000000`0oooo00<000000?ooo`3oool0103oool01@000000oooo0?oo
o`3oool0000000h0oooo00<000000?ooo`000000:P3oool010000000oooo0?ooo`00000A0?ooo`03
0000003oool0oooo01<0oooo00<000000?ooo`3oool00P3oool00`000000oooo000000030?ooo`03
0000003oool0oooo00`0oooo00<000000?ooo`3oool03`3oool00`000000oooo0?ooo`0C0?ooo`03
0000003oool0oooo01H0oooo00<000000?ooo`3oool0;@3oool00`000000oooo0?ooo`060?ooo`03
0000003oool0oooo01D0oooo00<000000?ooo`3oool00P0000060?ooo`050000003oool0oooo0?oo
o`0000001P3oool00`000000oooo0?ooo`0C0?ooo`030000003oool0oooo00P0oooo00<000000?oo
o`3oool00P3oool00`000000oooo0000000>0?ooo`040000003oool0oooo000000D0oooo00<00000
0?ooo`3oool0:`3oool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo04h0oooo00<00000
0?ooo`3oool01@3oool00`000000oooo0?ooo`070?ooo`8000005@3oool00`000000oooo0?ooo`03
0?ooo`030000003oool0oooo01@0oooo000I0?ooo`030000003oool0oooo008000000`3oool00`00
0000oooo0?ooo`0I0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0303oool00`00
0000oooo0?ooo`0L0?ooo`030000003oool0000001<0oooo00D000000?ooo`3oool0oooo0000000<
0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool01`3oool00`000000oooo0000000<
0?ooo`030000003oool0oooo00@0oooo00D000000?ooo`3oool0oooo0000000>0?ooo`030000003o
ool0000002X0oooo00@000000?ooo`3oool000004@3oool00`000000oooo0?ooo`0C0?ooo`030000
003oool0oooo0080oooo00<000000?ooo`0000000`3oool00`000000oooo0?ooo`0<0?ooo`030000
003oool0oooo00l0oooo00<000000?ooo`3oool04`3oool00`000000oooo0?ooo`0F0?ooo`030000
003oool0oooo02d0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`0E0?ooo`030000
003oool0oooo008000001P3oool01@000000oooo0?ooo`3oool0000000H0oooo00<000000?ooo`3o
ool04`3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo0080oooo00<000000?ooo`00
00003P3oool010000000oooo0?ooo`0000050?ooo`030000003oool0oooo02/0oooo00<000000?oo
o`3oool0303oool00`000000oooo0?ooo`1>0?ooo`030000003oool0oooo00D0oooo00<000000?oo
o`3oool01`3oool2000001D0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`0D0?oo
o`006@3oool00`000000oooo0?ooo`02000000<0oooo00<000000?ooo`3oool06@3oool00`000000
oooo0?ooo`030?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool0703oool00`000000
oooo0000000C0?ooo`050000003oool0oooo0?ooo`000000303oool00`000000oooo0?ooo`050?oo
o`030000003oool0oooo00L0oooo00<000000?ooo`000000303oool00`000000oooo0?ooo`040?oo
o`050000003oool0oooo0?ooo`0000003P3oool00`000000oooo0000000Z0?ooo`040000003oool0
oooo00000140oooo00<000000?ooo`3oool04`3oool00`000000oooo0?ooo`020?ooo`030000003o
ool0000000<0oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`0?0?ooo`030000003o
ool0oooo01<0oooo00<000000?ooo`3oool05P3oool00`000000oooo0?ooo`0]0?ooo`030000003o
ool0oooo00H0oooo00<000000?ooo`3oool05@3oool00`000000oooo0?ooo`02000000H0oooo00D0
00000?ooo`3oool0oooo000000060?ooo`030000003oool0oooo01<0oooo00<000000?ooo`3oool0
203oool00`000000oooo0?ooo`020?ooo`030000003oool0000000h0oooo00@000000?ooo`3oool0
00001@3oool00`000000oooo0?ooo`0[0?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3o
ool0CP3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00L0oooo0P00000E0?ooo`03
0000003oool0oooo00<0oooo00<000000?ooo`3oool0503oool001T0oooo00<000000?ooo`3oool0
0P0000030?ooo`030000003oool0oooo01T0oooo00<000000?ooo`3oool00`3oool00`000000oooo
0?ooo`0<0?ooo`030000003oool0oooo01`0oooo00<000000?ooo`0000004`3oool01@000000oooo
0?ooo`3oool0000000`0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`070?ooo`03
0000003oool0000000`0oooo00<000000?ooo`3oool0103oool01@000000oooo0?ooo`3oool00000
00h0oooo00<000000?ooo`000000:P3oool010000000oooo0?ooo`00000A0?ooo`030000003oool0
oooo01<0oooo00<000000?ooo`3oool00P3oool00`000000oooo000000030?ooo`030000003oool0
oooo00`0oooo00<000000?ooo`3oool03`3oool00`000000oooo0?ooo`0C0?ooo`030000003oool0
oooo01H0oooo00<000000?ooo`3oool0;@3oool00`000000oooo0?ooo`060?ooo`030000003oool0
oooo01D0oooo00<000000?ooo`3oool00P0000060?ooo`050000003oool0oooo0?ooo`0000001P3o
ool00`000000oooo0?ooo`0C0?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool00P3o
ool00`000000oooo0000000>0?ooo`040000003oool0oooo000000D0oooo00<000000?ooo`3oool0
:`3oool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo04h0oooo00<000000?ooo`3oool0
1@3oool00`000000oooo0?ooo`070?ooo`8000005@3oool00`000000oooo0?ooo`030?ooo`030000
003oool0oooo01@0oooo000I0?ooo`030000003oool0oooo008000000`3oool00`000000oooo0?oo
o`0I0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0303oool00`000000oooo0?oo
o`0L0?ooo`030000003oool0000001<0oooo00D000000?ooo`3oool0oooo0000000<0?ooo`030000
003oool0oooo00D0oooo00<000000?ooo`3oool01`3oool00`000000oooo0000000<0?ooo`030000
003oool0oooo00@0oooo00D000000?ooo`3oool0oooo0000000>0?ooo`030000003oool0000002X0
oooo00@000000?ooo`3oool000004@3oool00`000000oooo0?ooo`0C0?ooo`030000003oool0oooo
0080oooo00<000000?ooo`0000000`3oool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo
00l0oooo00<000000?ooo`3oool04`3oool00`000000oooo0?ooo`0F0?ooo`030000003oool0oooo
02d0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`0E0?ooo`030000003oool0oooo
008000001P3oool01@000000oooo0?ooo`3oool0000000H0oooo00<000000?ooo`3oool04`3oool0
0`000000oooo0?ooo`080?ooo`030000003oool0oooo0080oooo00<000000?ooo`0000003P3oool0
10000000oooo0?ooo`0000050?ooo`030000003oool0oooo02/0oooo00<000000?ooo`3oool0303o
ool00`000000oooo0?ooo`1>0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool01`3o
ool2000001D0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`0D0?ooo`006@3oool0
0`000000oooo0?ooo`02000000<0oooo00<000000?ooo`3oool06@3oool00`000000oooo0?ooo`03
0?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool0703oool00`000000oooo0000000C
0?ooo`050000003oool0oooo0?ooo`000000303oool00`000000oooo0?ooo`050?ooo`030000003o
ool0oooo00L0oooo00<000000?ooo`000000303oool00`000000oooo0?ooo`040?ooo`050000003o
ool0oooo0?ooo`0000003P3oool00`000000oooo0000000Z0?ooo`040000003oool0oooo00000140
oooo00<000000?ooo`3oool04`3oool00`000000oooo0?ooo`020?ooo`030000003oool0000000<0
oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`0?0?ooo`030000003oool0oooo01<0
oooo00<000000?ooo`3oool05P3oool00`000000oooo0?ooo`0]0?ooo`030000003oool0oooo00H0
oooo00<000000?ooo`3oool05@3oool00`000000oooo0?ooo`02000000H0oooo00D000000?ooo`3o
ool0oooo000000060?ooo`030000003oool0oooo01<0oooo00<000000?ooo`3oool0203oool00`00
0000oooo0?ooo`020?ooo`030000003oool0000000h0oooo00@000000?ooo`3oool000001@3oool0
0`000000oooo0?ooo`0[0?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool0CP3oool0
0`000000oooo0?ooo`050?ooo`030000003oool0oooo00L0oooo0P00000E0?ooo`030000003oool0
oooo00<0oooo00<000000?ooo`3oool0503oool001T0oooo00<000000?ooo`3oool00P0000030?oo
o`030000003oool0oooo01T0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`0<0?oo
o`030000003oool0oooo01`0oooo00<000000?ooo`0000004`3oool01@000000oooo0?ooo`3oool0
000000`0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`070?ooo`030000003oool0
000000`0oooo00<000000?ooo`3oool0103oool01@000000oooo0?ooo`3oool0000000h0oooo00<0
00000?ooo`000000:P3oool010000000oooo0?ooo`00000A0?ooo`030000003oool0oooo01<0oooo
00<000000?ooo`3oool00P3oool00`000000oooo000000030?ooo`030000003oool0oooo00`0oooo
00<000000?ooo`3oool03`3oool00`000000oooo0?ooo`0C0?ooo`030000003oool0oooo01H0oooo
00<000000?ooo`3oool0;@3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo01D0oooo
00<000000?ooo`3oool00P0000060?ooo`050000003oool0oooo0?ooo`0000001P3oool00`000000
oooo0?ooo`0C0?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool00P3oool00`000000
oooo0000000>0?ooo`040000003oool0oooo000000D0oooo00<000000?ooo`3oool0:`3oool00`00
0000oooo0?ooo`0<0?ooo`030000003oool0oooo04h0oooo00<000000?ooo`3oool01@3oool00`00
0000oooo0?ooo`070?ooo`8000005@3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo
01@0oooo000D0?ooool0ool0o`3oo`2a0?oo0280003o203oo`0D0?ooo`006@3oool00`000000oooo
0?ooo`02000000<0oooo00<000000?ooo`3oool06@3oool00`000000oooo0?ooo`030?ooo`030000
003oool0oooo00`0oooo00<000000?ooo`3oool0703oool00`000000oooo0000000C0?ooo`050000
003oool0oooo0?ooo`000000303oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00L0
oooo00<000000?ooo`000000303oool00`000000oooo0?ooo`040?ooo`050000003oool0oooo0?oo
o`0000003P3oool00`000000oooo0000000Z0?ooo`040000003oool0oooo00000140oooo00<00000
0?ooo`3oool04`3oool00`000000oooo0?ooo`020?ooo`030000003oool0000000<0oooo00<00000
0?ooo`3oool0303oool00`000000oooo0?ooo`0?0?ooo`030000003oool0oooo01<0oooo00<00000
0?ooo`3oool05P3oool00`000000oooo0?ooo`0]0?ooo`030000003oool0oooo00H0oooo00<00000
0?ooo`3oool05@3oool00`000000oooo0?ooo`02000000H0oooo00D000000?ooo`3oool0oooo0000
00060?ooo`030000003oool0oooo01<0oooo00<000000?ooo`3oool0203oool00`000000oooo0?oo
o`020?ooo`030000003oool0000000h0oooo00@000000?ooo`3oool000001@3oool00`000000oooo
0?ooo`0[0?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool0CP3oool00`000000oooo
0?ooo`050?ooo`030000003oool0oooo00L0oooo0P00000E0?ooo`030000003oool0oooo00<0oooo
00<000000?ooo`3oool0503oool001T0oooo00<000000?ooo`3oool00P0000030?ooo`030000003o
ool0oooo01T0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`0<0?ooo`030000003o
ool0oooo01`0oooo00<000000?ooo`0000004`3oool01@000000oooo0?ooo`3oool0000000`0oooo
00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`070?ooo`030000003oool0000000`0oooo
00<000000?ooo`3oool0103oool01@000000oooo0?ooo`3oool0000000h0oooo00<000000?ooo`00
0000:P3oool010000000oooo0?ooo`00000A0?ooo`030000003oool0oooo01<0oooo00<000000?oo
o`3oool00P3oool00`000000oooo000000030?ooo`030000003oool0oooo00`0oooo00<000000?oo
o`3oool03`3oool00`000000oooo0?ooo`0C0?ooo`030000003oool0oooo01H0oooo00<000000?oo
o`3oool0;@3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo01D0oooo00<000000?oo
o`3oool00P0000060?ooo`050000003oool0oooo0?ooo`0000001P3oool00`000000oooo0?ooo`0C
0?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool00P3oool00`000000oooo0000000>
0?ooo`040000003oool0oooo000000D0oooo00<000000?ooo`3oool0:`3oool00`000000oooo0?oo
o`0<0?ooo`030000003oool0oooo04h0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?oo
o`070?ooo`8000005@3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo01@0oooo000I
0?ooo`030000003oool0oooo008000000`3oool00`000000oooo0?ooo`0I0?ooo`030000003oool0
oooo00<0oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`0L0?ooo`030000003oool0
000001<0oooo00D000000?ooo`3oool0oooo0000000<0?ooo`030000003oool0oooo00D0oooo00<0
00000?ooo`3oool01`3oool00`000000oooo0000000<0?ooo`030000003oool0oooo00@0oooo00D0
00000?ooo`3oool0oooo0000000>0?ooo`030000003oool0000002X0oooo00@000000?ooo`3oool0
00004@3oool00`000000oooo0?ooo`0C0?ooo`030000003oool0oooo0080oooo00<000000?ooo`00
00000`3oool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo00l0oooo00<000000?ooo`3o
ool04`3oool00`000000oooo0?ooo`0F0?ooo`030000003oool0oooo02d0oooo00<000000?ooo`3o
ool01P3oool00`000000oooo0?ooo`0E0?ooo`030000003oool0oooo008000001P3oool01@000000
oooo0?ooo`3oool0000000H0oooo00<000000?ooo`3oool04`3oool00`000000oooo0?ooo`080?oo
o`030000003oool0oooo0080oooo00<000000?ooo`0000003P3oool010000000oooo0?ooo`000005
0?ooo`030000003oool0oooo02/0oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`1>
0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool01`3oool2000001D0oooo00<00000
0?ooo`3oool00`3oool00`000000oooo0?ooo`0D0?ooo`006@3oool00`000000oooo0?ooo`020000
00<0oooo00<000000?ooo`3oool06@3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo
00`0oooo00<000000?ooo`3oool0703oool00`000000oooo0000000C0?ooo`050000003oool0oooo
0?ooo`000000303oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00L0oooo00<00000
0?ooo`000000303oool00`000000oooo0?ooo`040?ooo`050000003oool0oooo0?ooo`0000003P3o
ool00`000000oooo0000000Z0?ooo`040000003oool0oooo00000140oooo00<000000?ooo`3oool0
4`3oool00`000000oooo0?ooo`020?ooo`030000003oool0000000<0oooo00<000000?ooo`3oool0
303oool00`000000oooo0?ooo`0?0?ooo`030000003oool0oooo01<0oooo00<000000?ooo`3oool0
5P3oool00`000000oooo0?ooo`0]0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool0
5@3oool00`000000oooo0?ooo`02000000H0oooo00D000000?ooo`3oool0oooo000000060?ooo`03
0000003oool0oooo01<0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`020?ooo`03
0000003oool0000000h0oooo00@000000?ooo`3oool000001@3oool00`000000oooo0?ooo`0[0?oo
o`030000003oool0oooo00`0oooo00<000000?ooo`3oool0CP3oool00`000000oooo0?ooo`050?oo
o`030000003oool0oooo00L0oooo0P00000E0?ooo`030000003oool0oooo00<0oooo00<000000?oo
o`3oool0503oool001T0oooo00<000000?ooo`3oool00P0000030?ooo`030000003oool0oooo01T0
oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo01`0
oooo00<000000?ooo`0000004`3oool01@000000oooo0?ooo`3oool0000000`0oooo00<000000?oo
o`3oool01@3oool00`000000oooo0?ooo`070?ooo`030000003oool0000000`0oooo00<000000?oo
o`3oool0103oool01@000000oooo0?ooo`3oool0000000h0oooo00<000000?ooo`000000:P3oool0
10000000oooo0?ooo`00000A0?ooo`030000003oool0oooo01<0oooo00<000000?ooo`3oool00P3o
ool00`000000oooo000000030?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool03`3o
ool00`000000oooo0?ooo`0C0?ooo`030000003oool0oooo01H0oooo00<000000?ooo`3oool0;@3o
ool00`000000oooo0?ooo`060?ooo`030000003oool0oooo01D0oooo00<000000?ooo`3oool00P00
00060?ooo`050000003oool0oooo0?ooo`0000001P3oool00`000000oooo0?ooo`0C0?ooo`030000
003oool0oooo00P0oooo00<000000?ooo`3oool00P3oool00`000000oooo0000000>0?ooo`040000
003oool0oooo000000D0oooo00<000000?ooo`3oool0:`3oool00`000000oooo0?ooo`0<0?ooo`03
0000003oool0oooo04h0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`070?ooo`80
00005@3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo01@0oooo000I0?ooo`030000
003oool0oooo008000000`3oool00`000000oooo0?ooo`0I0?ooo`030000003oool0oooo00<0oooo
00<000000?ooo`3oool0303oool00`000000oooo0?ooo`0L0?ooo`030000003oool0000001<0oooo
00D000000?ooo`3oool0oooo0000000<0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3o
ool01`3oool00`000000oooo0000000<0?ooo`030000003oool0oooo00@0oooo00D000000?ooo`3o
ool0oooo0000000>0?ooo`030000003oool0000002X0oooo00@000000?ooo`3oool000004@3oool0
0`000000oooo0?ooo`0C0?ooo`030000003oool0oooo0080oooo00<000000?ooo`0000000`3oool0
0`000000oooo0?ooo`0<0?ooo`030000003oool0oooo00l0oooo00<000000?ooo`3oool04`3oool0
0`000000oooo0?ooo`0F0?ooo`030000003oool0oooo02d0oooo00<000000?ooo`3oool01P3oool0
0`000000oooo0?ooo`0E0?ooo`030000003oool0oooo008000001P3oool01@000000oooo0?ooo`3o
ool0000000H0oooo00<000000?ooo`3oool04`3oool00`000000oooo0?ooo`080?ooo`030000003o
ool0oooo0080oooo00<000000?ooo`0000003P3oool010000000oooo0?ooo`0000050?ooo`030000
003oool0oooo02/0oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`1>0?ooo`030000
003oool0oooo00D0oooo00<000000?ooo`3oool01`3oool2000001D0oooo00<000000?ooo`3oool0
0`3oool00`000000oooo0?ooo`0D0?ooo`006@3oool00`000000oooo0?ooo`02000000<0oooo00<0
00000?ooo`3oool06@3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00`0oooo00<0
00000?ooo`3oool0703oool00`000000oooo0000000C0?ooo`050000003oool0oooo0?ooo`000000
303oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00L0oooo00<000000?ooo`000000
303oool00`000000oooo0?ooo`040?ooo`050000003oool0oooo0?ooo`0000003P3oool00`000000
oooo0000000Z0?ooo`040000003oool0oooo00000140oooo00<000000?ooo`3oool04`3oool00`00
0000oooo0?ooo`020?ooo`030000003oool0000000<0oooo00<000000?ooo`3oool0303oool00`00
0000oooo0?ooo`0?0?ooo`030000003oool0oooo01<0oooo00<000000?ooo`3oool05P3oool00`00
0000oooo0?ooo`0]0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool05@3oool00`00
0000oooo0?ooo`02000000H0oooo00D000000?ooo`3oool0oooo000000060?ooo`030000003oool0
oooo01<0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`020?ooo`030000003oool0
000000h0oooo00@000000?ooo`3oool000001@3oool00`000000oooo0?ooo`0[0?ooo`030000003o
ool0oooo00`0oooo00<000000?ooo`3oool0CP3oool00`000000oooo0?ooo`050?ooo`030000003o
ool0oooo00L0oooo0P00000E0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0503o
ool001@0ooooo`3oo`3o0?oo0040ool00`000?oG0?oo01@0oooo000I0?ooo`030000003oool0oooo
008000000`3oool00`000000oooo0?ooo`0I0?ooo`030000003oool0oooo00<0oooo00<000000?oo
o`3oool0303oool00`000000oooo0?ooo`0L0?ooo`030000003oool0000001<0oooo00D000000?oo
o`3oool0oooo0000000<0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool01`3oool0
0`000000oooo0000000<0?ooo`030000003oool0oooo00@0oooo00D000000?ooo`3oool0oooo0000
000>0?ooo`030000003oool0000002X0oooo00@000000?ooo`3oool000004@3oool00`000000oooo
0?ooo`0C0?ooo`030000003oool0oooo0080oooo00<000000?ooo`0000000`3oool00`000000oooo
0?ooo`0<0?ooo`030000003oool0oooo00l0oooo00<000000?ooo`3oool04`3oool00`000000oooo
0?ooo`0F0?ooo`030000003oool0oooo02d0oooo00<000000?ooo`3oool01P3oool00`000000oooo
0?ooo`0E0?ooo`030000003oool0oooo008000001P3oool01@000000oooo0?ooo`3oool0000000H0
oooo00<000000?ooo`3oool04`3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo0080
oooo00<000000?ooo`0000003P3oool010000000oooo0?ooo`0000050?ooo`030000003oool0oooo
02/0oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`1>0?ooo`030000003oool0oooo
00D0oooo00<000000?ooo`3oool01`3oool2000001D0oooo00<000000?ooo`3oool00`3oool00`00
0000oooo0?ooo`0D0?ooo`006@3oool00`000000oooo0?ooo`02000000<0oooo00<000000?ooo`3o
ool06@3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3o
ool0703oool00`000000oooo0000000C0?ooo`050000003oool0oooo0?ooo`000000303oool00`00
0000oooo0?ooo`050?ooo`030000003oool0oooo00L0oooo00<000000?ooo`000000303oool00`00
0000oooo0?ooo`040?ooo`050000003oool0oooo0?ooo`0000003P3oool00`000000oooo0000000Z
0?ooo`040000003oool0oooo00000140oooo00<000000?ooo`3oool04`3oool00`000000oooo0?oo
o`020?ooo`030000003oool0000000<0oooo00<000000?ooo`3oool0303oool00`000000oooo0?oo
o`0?0?ooo`030000003oool0oooo01<0oooo00<000000?ooo`3oool05P3oool00`000000oooo0?oo
o`0]0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool05@3oool00`000000oooo0?oo
o`02000000H0oooo00D000000?ooo`3oool0oooo000000060?ooo`030000003oool0oooo01<0oooo
00<000000?ooo`3oool0203oool00`000000oooo0?ooo`020?ooo`030000003oool0000000h0oooo
00@000000?ooo`3oool000001@3oool00`000000oooo0?ooo`0[0?ooo`030000003oool0oooo00`0
oooo00<000000?ooo`3oool0CP3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00L0
oooo0P00000E0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0503oool001T0oooo
00<000000?ooo`3oool00P0000030?ooo`030000003oool0oooo01T0oooo00<000000?ooo`3oool0
0`3oool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo01`0oooo00<000000?ooo`000000
4`3oool01@000000oooo0?ooo`3oool0000000`0oooo00<000000?ooo`3oool01@3oool00`000000
oooo0?ooo`070?ooo`030000003oool0000000`0oooo00<000000?ooo`3oool0103oool01@000000
oooo0?ooo`3oool0000000h0oooo00<000000?ooo`000000:P3oool010000000oooo0?ooo`00000A
0?ooo`030000003oool0oooo01<0oooo00<000000?ooo`3oool00P3oool00`000000oooo00000003
0?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool03`3oool00`000000oooo0?ooo`0C
0?ooo`030000003oool0oooo01H0oooo00<000000?ooo`3oool0;@3oool00`000000oooo0?ooo`06
0?ooo`030000003oool0oooo01D0oooo00<000000?ooo`3oool00P0000060?ooo`050000003oool0
oooo0?ooo`0000001P3oool00`000000oooo0?ooo`0C0?ooo`030000003oool0oooo00P0oooo00<0
00000?ooo`3oool00P3oool00`000000oooo0000000>0?ooo`040000003oool0oooo000000D0oooo
00<000000?ooo`3oool0:`3oool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo04h0oooo
00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`070?ooo`8000005@3oool00`000000oooo
0?ooo`030?ooo`030000003oool0oooo01@0oooo000I0?ooo`030000003oool0oooo008000000`3o
ool00`000000oooo0?ooo`0I0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0303o
ool00`000000oooo0?ooo`0L0?ooo`030000003oool0000001<0oooo00D000000?ooo`3oool0oooo
0000000<0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool01`3oool00`000000oooo
0000000<0?ooo`030000003oool0oooo00@0oooo00D000000?ooo`3oool0oooo0000000>0?ooo`03
0000003oool0000002X0oooo00@000000?ooo`3oool000004@3oool00`000000oooo0?ooo`0C0?oo
o`030000003oool0oooo0080oooo00<000000?ooo`0000000`3oool00`000000oooo0?ooo`0<0?oo
o`030000003oool0oooo00l0oooo00<000000?ooo`3oool04`3oool00`000000oooo0?ooo`0F0?oo
o`030000003oool0oooo02d0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`0E0?oo
o`030000003oool0oooo008000001P3oool01@000000oooo0?ooo`3oool0000000H0oooo00<00000
0?ooo`3oool04`3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo0080oooo00<00000
0?ooo`0000003P3oool010000000oooo0?ooo`0000050?ooo`030000003oool0oooo02/0oooo00<0
00000?ooo`3oool0303oool00`000000oooo0?ooo`1>0?ooo`030000003oool0oooo00D0oooo00<0
00000?ooo`3oool01`3oool2000001D0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?oo
o`0D0?ooo`006@3oool00`000000oooo0?ooo`02000000<0oooo00<000000?ooo`3oool06@3oool0
0`000000oooo0?ooo`030?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool0703oool0
0`000000oooo0000000C0?ooo`050000003oool0oooo0?ooo`000000303oool00`000000oooo0?oo
o`050?ooo`030000003oool0oooo00L0oooo00<000000?ooo`000000303oool00`000000oooo0?oo
o`040?ooo`050000003oool0oooo0?ooo`0000003P3oool00`000000oooo0000000Z0?ooo`040000
003oool0oooo00000140oooo00<000000?ooo`3oool04`3oool00`000000oooo0?ooo`020?ooo`03
0000003oool0000000<0oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`0?0?ooo`03
0000003oool0oooo01<0oooo00<000000?ooo`3oool05P3oool00`000000oooo0?ooo`0]0?ooo`03
0000003oool0oooo00H0oooo00<000000?ooo`3oool05@3oool00`000000oooo0?ooo`02000000H0
oooo00D000000?ooo`3oool0oooo000000060?ooo`030000003oool0oooo01<0oooo00<000000?oo
o`3oool0203oool00`000000oooo0?ooo`020?ooo`030000003oool0000000h0oooo00@000000?oo
o`3oool000001@3oool00`000000oooo0?ooo`0[0?ooo`030000003oool0oooo00`0oooo00<00000
0?ooo`3oool0CP3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00L0oooo0P00000E
0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0503oool001T0oooo00<000000?oo
o`3oool00P0000030?ooo`030000003oool0oooo01T0oooo00<000000?ooo`3oool00`3oool00`00
0000oooo0?ooo`0<0?ooo`030000003oool0oooo01`0oooo00<000000?ooo`0000004`3oool01@00
0000oooo0?ooo`3oool0000000`0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`07
0?ooo`030000003oool0000000`0oooo00<000000?ooo`3oool0103oool01@000000oooo0?ooo`3o
ool0000000h0oooo00<000000?ooo`000000:P3oool010000000oooo0?ooo`00000A0?ooo`030000
003oool0oooo01<0oooo00<000000?ooo`3oool00P3oool00`000000oooo000000030?ooo`030000
003oool0oooo00`0oooo00<000000?ooo`3oool03`3oool00`000000oooo0?ooo`0C0?ooo`030000
003oool0oooo01H0oooo00<000000?ooo`3oool0;@3oool00`000000oooo0?ooo`060?ooo`030000
003oool0oooo01D0oooo00<000000?ooo`3oool00P0000060?ooo`050000003oool0oooo0?ooo`00
00001P3oool00`000000oooo0?ooo`0C0?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3o
ool00P3oool00`000000oooo0000000>0?ooo`040000003oool0oooo000000D0oooo00<000000?oo
o`3oool0:`3oool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo04h0oooo00<000000?oo
o`3oool01@3oool00`000000oooo0?ooo`070?ooo`8000005@3oool00`000000oooo0?ooo`030?oo
o`030000003oool0oooo01@0oooo000D0?oookl0ool000<0003o0?oo00000?l0:`000?oo0?oo0>d0
ool0503oool001T0oooo00<000000?ooo`3oool00P0000030?ooo`030000003oool0oooo01T0oooo
00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo01`0oooo
00<000000?ooo`0000004`3oool01@000000oooo0?ooo`3oool0000000`0oooo00<000000?ooo`3o
ool01@3oool00`000000oooo0?ooo`070?ooo`030000003oool0000000`0oooo00<000000?ooo`3o
ool0103oool01@000000oooo0?ooo`3oool0000000h0oooo00<000000?ooo`000000:P3oool01000
0000oooo0?ooo`00000A0?ooo`030000003oool0oooo01<0oooo00<000000?ooo`3oool00P3oool0
0`000000oooo000000030?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool03`3oool0
0`000000oooo0?ooo`0C0?ooo`030000003oool0oooo01H0oooo00<000000?ooo`3oool0;@3oool0
0`000000oooo0?ooo`060?ooo`030000003oool0oooo01D0oooo00<000000?ooo`3oool00P000006
0?ooo`050000003oool0oooo0?ooo`0000001P3oool00`000000oooo0?ooo`0C0?ooo`030000003o
ool0oooo00P0oooo00<000000?ooo`3oool00P3oool00`000000oooo0000000>0?ooo`040000003o
ool0oooo000000D0oooo00<000000?ooo`3oool0:`3oool00`000000oooo0?ooo`0<0?ooo`030000
003oool0oooo04h0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`070?ooo`800000
5@3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo01@0oooo000I0?ooo`030000003o
ool0oooo008000000`3oool00`000000oooo0?ooo`0I0?ooo`030000003oool0oooo00<0oooo00<0
00000?ooo`3oool0303oool00`000000oooo0?ooo`0L0?ooo`030000003oool0000001<0oooo00D0
00000?ooo`3oool0oooo0000000<0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool0
1`3oool00`000000oooo0000000<0?ooo`030000003oool0oooo00@0oooo00D000000?ooo`3oool0
oooo0000000>0?ooo`030000003oool0000002X0oooo00@000000?ooo`3oool000004@3oool00`00
0000oooo0?ooo`0C0?ooo`030000003oool0oooo0080oooo00<000000?ooo`0000000`3oool00`00
0000oooo0?ooo`0<0?ooo`030000003oool0oooo00l0oooo00<000000?ooo`3oool04`3oool00`00
0000oooo0?ooo`0F0?ooo`030000003oool0oooo02d0oooo00<000000?ooo`3oool01P3oool00`00
0000oooo0?ooo`0E0?ooo`030000003oool0oooo008000001P3oool01@000000oooo0?ooo`3oool0
000000H0oooo00<000000?ooo`3oool04`3oool00`000000oooo0?ooo`080?ooo`030000003oool0
oooo0080oooo00<000000?ooo`0000003P3oool010000000oooo0?ooo`0000050?ooo`030000003o
ool0oooo02/0oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`1>0?ooo`030000003o
ool0oooo00D0oooo00<000000?ooo`3oool01`3oool2000001D0oooo00<000000?ooo`3oool00`3o
ool00`000000oooo0?ooo`0D0?ooo`006@3oool00`000000oooo0?ooo`02000000<0oooo00<00000
0?ooo`3oool06@3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00`0oooo00<00000
0?ooo`3oool0703oool00`000000oooo0000000C0?ooo`050000003oool0oooo0?ooo`000000303o
ool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00L0oooo00<000000?ooo`000000303o
ool00`000000oooo0?ooo`040?ooo`050000003oool0oooo0?ooo`0000003P3oool00`000000oooo
0000000Z0?ooo`040000003oool0oooo00000140oooo00<000000?ooo`3oool04`3oool00`000000
oooo0?ooo`020?ooo`030000003oool0000000<0oooo00<000000?ooo`3oool0303oool00`000000
oooo0?ooo`0?0?ooo`030000003oool0oooo01<0oooo00<000000?ooo`3oool05P3oool00`000000
oooo0?ooo`0]0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool05@3oool00`000000
oooo0?ooo`02000000H0oooo00D000000?ooo`3oool0oooo000000060?ooo`030000003oool0oooo
01<0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`020?ooo`030000003oool00000
00h0oooo00@000000?ooo`3oool000001@3oool00`000000oooo0?ooo`0[0?ooo`030000003oool0
oooo00`0oooo00<000000?ooo`3oool0CP3oool00`000000oooo0?ooo`050?ooo`030000003oool0
oooo00L0oooo0P00000E0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0503oool0
01T0oooo00<000000?ooo`3oool00P0000030?ooo`030000003oool0oooo01T0oooo00<000000?oo
o`3oool00`3oool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo01`0oooo00<000000?oo
o`0000004`3oool01@000000oooo0?ooo`3oool0000000`0oooo00<000000?ooo`3oool01@3oool0
0`000000oooo0?ooo`070?ooo`030000003oool0000000`0oooo00<000000?ooo`3oool0103oool0
1@000000oooo0?ooo`3oool0000000h0oooo00<000000?ooo`000000:P3oool010000000oooo0?oo
o`00000A0?ooo`030000003oool0oooo01<0oooo00<000000?ooo`3oool00P3oool00`000000oooo
000000030?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool03`3oool00`000000oooo
0?ooo`0C0?ooo`030000003oool0oooo01H0oooo00<000000?ooo`3oool0;@3oool00`000000oooo
0?ooo`060?ooo`030000003oool0oooo01D0oooo00<000000?ooo`3oool00P0000060?ooo`050000
003oool0oooo0?ooo`0000001P3oool00`000000oooo0?ooo`0C0?ooo`030000003oool0oooo00P0
oooo00<000000?ooo`3oool00P3oool00`000000oooo0000000>0?ooo`040000003oool0oooo0000
00D0oooo00<000000?ooo`3oool0:`3oool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo
04h0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`070?ooo`8000005@3oool00`00
0000oooo0?ooo`030?ooo`030000003oool0oooo01@0oooo000I0?ooo`030000003oool0oooo0080
00000`3oool00`000000oooo0?ooo`0I0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3o
ool0303oool00`000000oooo0?ooo`0L0?ooo`030000003oool0000001<0oooo00D000000?ooo`3o
ool0oooo0000000<0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool01`3oool00`00
0000oooo0000000<0?ooo`030000003oool0oooo00@0oooo00D000000?ooo`3oool0oooo0000000>
0?ooo`030000003oool0000002X0oooo00@000000?ooo`3oool000004@3oool00`000000oooo0?oo
o`0C0?ooo`030000003oool0oooo0080oooo00<000000?ooo`0000000`3oool00`000000oooo0?oo
o`0<0?ooo`030000003oool0oooo00l0oooo00<000000?ooo`3oool04`3oool00`000000oooo0?oo
o`0F0?ooo`030000003oool0oooo02d0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?oo
o`0E0?ooo`030000003oool0oooo008000001P3oool01@000000oooo0?ooo`3oool0000000H0oooo
00<000000?ooo`3oool04`3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo0080oooo
00<000000?ooo`0000003P3oool010000000oooo0?ooo`0000050?ooo`030000003oool0oooo02/0
oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`1>0?ooo`030000003oool0oooo00D0
oooo00<000000?ooo`3oool01`3oool2000001D0oooo00<000000?ooo`3oool00`3oool00`000000
oooo0?ooo`0D0?ooo`006@3oool00`000000oooo0?ooo`02000000<0oooo00<000000?ooo`3oool0
6@3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool0
703oool00`000000oooo0000000C0?ooo`050000003oool0oooo0?ooo`000000303oool00`000000
oooo0?ooo`050?ooo`030000003oool0oooo00L0oooo00<000000?ooo`000000303oool00`000000
oooo0?ooo`040?ooo`050000003oool0oooo0?ooo`0000003P3oool00`000000oooo0000000Z0?oo
o`040000003oool0oooo00000140oooo00<000000?ooo`3oool04`3oool00`000000oooo0?ooo`02
0?ooo`030000003oool0000000<0oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`0?
0?ooo`030000003oool0oooo01<0oooo00<000000?ooo`3oool05P3oool00`000000oooo0?ooo`0]
0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool05@3oool00`000000oooo0?ooo`02
000000H0oooo00D000000?ooo`3oool0oooo000000060?ooo`030000003oool0oooo01<0oooo00<0
00000?ooo`3oool0203oool00`000000oooo0?ooo`020?ooo`030000003oool0000000h0oooo00@0
00000?ooo`3oool000001@3oool00`000000oooo0?ooo`0[0?ooo`030000003oool0oooo00`0oooo
00<000000?ooo`3oool0CP3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00L0oooo
0P00000E0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0503oool001T0oooo00<0
00000?ooo`3oool00P0000030?ooo`030000003oool0oooo01T0oooo00<000000?ooo`3oool00`3o
ool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo01`0oooo00<000000?ooo`0000004`3o
ool01@000000oooo0?ooo`3oool0000000`0oooo00<000000?ooo`3oool01@3oool00`000000oooo
0?ooo`070?ooo`030000003oool0000000`0oooo00<000000?ooo`3oool0103oool01@000000oooo
0?ooo`3oool0000000h0oooo00<000000?ooo`000000:P3oool010000000oooo0?ooo`00000A0?oo
o`030000003oool0oooo01<0oooo00<000000?ooo`3oool00P3oool00`000000oooo000000030?oo
o`030000003oool0oooo00`0oooo00<000000?ooo`3oool03`3oool00`000000oooo0?ooo`0C0?oo
o`030000003oool0oooo01H0oooo00<000000?ooo`3oool0;@3oool00`000000oooo0?ooo`060?oo
o`030000003oool0oooo01D0oooo00<000000?ooo`3oool00P0000060?ooo`050000003oool0oooo
0?ooo`0000001P3oool00`000000oooo0?ooo`0C0?ooo`030000003oool0oooo00P0oooo00<00000
0?ooo`3oool00P3oool00`000000oooo0000000>0?ooo`040000003oool0oooo000000D0oooo00<0
00000?ooo`3oool0:`3oool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo04h0oooo00<0
00000?ooo`3oool01@3oool00`000000oooo0?ooo`070?ooo`8000005@3oool00`000000oooo0?oo
o`030?ooo`030000003oool0oooo01@0oooo000D0?oooh@0ool02@000?lH0?oo00P0003o?`3oo`04
0000oe<0ool05`000?mA0?oo01T0003o0P3oo`020000o`H0ool01@000?md0?oo0100003oHP3oo`02
0000oa/0ool00`000?lD0?ooo`006@3oool00`000000oooo0?ooo`02000000<0oooo00<000000?oo
o`3oool06@3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00`0oooo00<000000?oo
o`3oool0703oool00`000000oooo0000000C0?ooo`050000003oool0oooo0?ooo`000000303oool0
0`000000oooo0?ooo`050?ooo`030000003oool0oooo00L0oooo00<000000?ooo`000000303oool0
0`000000oooo0?ooo`040?ooo`050000003oool0oooo0?ooo`0000003P3oool00`000000oooo0000
000Z0?ooo`040000003oool0oooo00000140oooo00<000000?ooo`3oool04`3oool00`000000oooo
0?ooo`020?ooo`030000003oool0000000<0oooo00<000000?ooo`3oool0303oool00`000000oooo
0?ooo`0?0?ooo`030000003oool0oooo01<0oooo00<000000?ooo`3oool05P3oool00`000000oooo
0?ooo`0]0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool05@3oool00`000000oooo
0?ooo`02000000H0oooo00D000000?ooo`3oool0oooo000000060?ooo`030000003oool0oooo01<0
oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`020?ooo`030000003oool0000000h0
oooo00@000000?ooo`3oool000001@3oool00`000000oooo0?ooo`0[0?ooo`030000003oool0oooo
00`0oooo00<000000?ooo`3oool0CP3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo
00L0oooo0P00000E0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0503oool001T0
oooo00<000000?ooo`3oool00P0000030?ooo`030000003oool0oooo01T0oooo00<000000?ooo`3o
ool00`3oool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo01`0oooo00<000000?ooo`00
00004`3oool01@000000oooo0?ooo`3oool0000000`0oooo00<000000?ooo`3oool01@3oool00`00
0000oooo0?ooo`070?ooo`030000003oool0000000`0oooo00<000000?ooo`3oool0103oool01@00
0000oooo0?ooo`3oool0000000h0oooo00<000000?ooo`000000:P3oool010000000oooo0?ooo`00
000A0?ooo`030000003oool0oooo01<0oooo00<000000?ooo`3oool00P3oool00`000000oooo0000
00030?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool03`3oool00`000000oooo0?oo
o`0C0?ooo`030000003oool0oooo01H0oooo00<000000?ooo`3oool0;@3oool00`000000oooo0?oo
o`060?ooo`030000003oool0oooo01D0oooo00<000000?ooo`3oool00P0000060?ooo`050000003o
ool0oooo0?ooo`0000001P3oool00`000000oooo0?ooo`0C0?ooo`030000003oool0oooo00P0oooo
00<000000?ooo`3oool00P3oool00`000000oooo0000000>0?ooo`040000003oool0oooo000000D0
oooo00<000000?ooo`3oool0:`3oool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo04h0
oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`070?ooo`8000005@3oool00`000000
oooo0?ooo`030?ooo`030000003oool0oooo01@0oooo000I0?ooo`030000003oool0oooo00800000
0`3oool00`000000oooo0?ooo`0I0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0
303oool00`000000oooo0?ooo`0L0?ooo`030000003oool0000001<0oooo00D000000?ooo`3oool0
oooo0000000<0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool01`3oool00`000000
oooo0000000<0?ooo`030000003oool0oooo00@0oooo00D000000?ooo`3oool0oooo0000000>0?oo
o`030000003oool0000002X0oooo00@000000?ooo`3oool000004@3oool00`000000oooo0?ooo`0C
0?ooo`030000003oool0oooo0080oooo00<000000?ooo`0000000`3oool00`000000oooo0?ooo`0<
0?ooo`030000003oool0oooo00l0oooo00<000000?ooo`3oool04`3oool00`000000oooo0?ooo`0F
0?ooo`030000003oool0oooo02d0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`0E
0?ooo`030000003oool0oooo008000001P3oool01@000000oooo0?ooo`3oool0000000H0oooo00<0
00000?ooo`3oool04`3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo0080oooo00<0
00000?ooo`0000003P3oool010000000oooo0?ooo`0000050?ooo`030000003oool0oooo02/0oooo
00<000000?ooo`3oool0303oool00`000000oooo0?ooo`1>0?ooo`030000003oool0oooo00D0oooo
00<000000?ooo`3oool01`3oool2000001D0oooo00<000000?ooo`3oool00`3oool00`000000oooo
0?ooo`0D0?ooo`006@3oool00`000000oooo0?ooo`02000000<0oooo00<000000?ooo`3oool06@3o
ool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool0703o
ool00`000000oooo0000000C0?ooo`050000003oool0oooo0?ooo`000000303oool00`000000oooo
0?ooo`050?ooo`030000003oool0oooo00L0oooo00<000000?ooo`000000303oool00`000000oooo
0?ooo`040?ooo`050000003oool0oooo0?ooo`0000003P3oool00`000000oooo0000000Z0?ooo`04
0000003oool0oooo00000140oooo00<000000?ooo`3oool04`3oool00`000000oooo0?ooo`020?oo
o`030000003oool0000000<0oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`0?0?oo
o`030000003oool0oooo01<0oooo00<000000?ooo`3oool05P3oool00`000000oooo0?ooo`0]0?oo
o`030000003oool0oooo00H0oooo00<000000?ooo`3oool05@3oool00`000000oooo0?ooo`020000
00H0oooo00D000000?ooo`3oool0oooo000000060?ooo`030000003oool0oooo01<0oooo00<00000
0?ooo`3oool0203oool00`000000oooo0?ooo`020?ooo`030000003oool0000000h0oooo00@00000
0?ooo`3oool000001@3oool00`000000oooo0?ooo`0[0?ooo`030000003oool0oooo00`0oooo00<0
00000?ooo`3oool0CP3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00L0oooo0P00
000E0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0503oool001T0oooo00<00000
0?ooo`3oool00P0000030?ooo`030000003oool0oooo01T0oooo00<000000?ooo`3oool00`3oool0
0`000000oooo0?ooo`0<0?ooo`030000003oool0oooo01`0oooo00<000000?ooo`0000004`3oool0
1@000000oooo0?ooo`3oool0000000`0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?oo
o`070?ooo`030000003oool0000000`0oooo00<000000?ooo`3oool0103oool01@000000oooo0?oo
o`3oool0000000h0oooo00<000000?ooo`000000:P3oool010000000oooo0?ooo`00000A0?ooo`03
0000003oool0oooo01<0oooo00<000000?ooo`3oool00P3oool00`000000oooo000000030?ooo`03
0000003oool0oooo00`0oooo00<000000?ooo`3oool03`3oool00`000000oooo0?ooo`0C0?ooo`03
0000003oool0oooo01H0oooo00<000000?ooo`3oool0;@3oool00`000000oooo0?ooo`060?ooo`03
0000003oool0oooo01D0oooo00<000000?ooo`3oool00P0000060?ooo`050000003oool0oooo0?oo
o`0000001P3oool00`000000oooo0?ooo`0C0?ooo`030000003oool0oooo00P0oooo00<000000?oo
o`3oool00P3oool00`000000oooo0000000>0?ooo`040000003oool0oooo000000D0oooo00<00000
0?ooo`3oool0:`3oool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo04h0oooo00<00000
0?ooo`3oool01@3oool00`000000oooo0?ooo`070?ooo`8000005@3oool00`000000oooo0?ooo`03
0?ooo`030000003oool0oooo01@0oooo000I0?ooo`030000003oool0oooo008000000`3oool00`00
0000oooo0?ooo`0I0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0303oool00`00
0000oooo0?ooo`0L0?ooo`030000003oool0000001<0oooo00D000000?ooo`3oool0oooo0000000<
0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool01`3oool00`000000oooo0000000<
0?ooo`030000003oool0oooo00@0oooo00D000000?ooo`3oool0oooo0000000>0?ooo`030000003o
ool0000002X0oooo00@000000?ooo`3oool000004@3oool00`000000oooo0?ooo`0C0?ooo`030000
003oool0oooo0080oooo00<000000?ooo`0000000`3oool00`000000oooo0?ooo`0<0?ooo`030000
003oool0oooo00l0oooo00<000000?ooo`3oool04`3oool00`000000oooo0?ooo`0F0?ooo`030000
003oool0oooo02d0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`0E0?ooo`030000
003oool0oooo008000001P3oool01@000000oooo0?ooo`3oool0000000H0oooo00<000000?ooo`3o
ool04`3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo0080oooo00<000000?ooo`00
00003P3oool010000000oooo0?ooo`0000050?ooo`030000003oool0oooo02/0oooo00<000000?oo
o`3oool0303oool00`000000oooo0?ooo`1>0?ooo`030000003oool0oooo00D0oooo00<000000?oo
o`3oool01`3oool2000001D0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`0D0?oo
o`006@3oool00`000000oooo0?ooo`02000000<0oooo00<000000?ooo`3oool06@3oool00`000000
oooo0?ooo`030?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool0703oool00`000000
oooo0000000C0?ooo`050000003oool0oooo0?ooo`000000303oool00`000000oooo0?ooo`050?oo
o`030000003oool0oooo00L0oooo00<000000?ooo`000000303oool00`000000oooo0?ooo`040?oo
o`050000003oool0oooo0?ooo`0000003P3oool00`000000oooo0000000Z0?ooo`040000003oool0
oooo00000140oooo00<000000?ooo`3oool04`3oool00`000000oooo0?ooo`020?ooo`030000003o
ool0000000<0oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`0?0?ooo`030000003o
ool0oooo01<0oooo00<000000?ooo`3oool05P3oool00`000000oooo0?ooo`0]0?ooo`030000003o
ool0oooo00H0oooo00<000000?ooo`3oool05@3oool00`000000oooo0?ooo`02000000H0oooo00D0
00000?ooo`3oool0oooo000000060?ooo`030000003oool0oooo01<0oooo00<000000?ooo`3oool0
203oool00`000000oooo0?ooo`020?ooo`030000003oool0000000h0oooo00@000000?ooo`3oool0
00001@3oool00`000000oooo0?ooo`0[0?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3o
ool0CP3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00L0oooo0P00000E0?ooo`03
0000003oool0oooo00<0oooo00<000000?ooo`3oool0503oool001@0ooooo`3oo`1J0?oo01X0003o
o`3oo`1W0?oo01@0oooo000I0?ooo`030000003oool0oooo008000000`3oool00`000000oooo0?oo
o`0I0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0303oool00`000000oooo0?oo
o`0L0?ooo`030000003oool0000001<0oooo00D000000?ooo`3oool0oooo0000000<0?ooo`030000
003oool0oooo00D0oooo00<000000?ooo`3oool01`3oool00`000000oooo0000000<0?ooo`030000
003oool0oooo00@0oooo00D000000?ooo`3oool0oooo0000000>0?ooo`030000003oool0000002X0
oooo00@000000?ooo`3oool000004@3oool00`000000oooo0?ooo`0C0?ooo`030000003oool0oooo
0080oooo00<000000?ooo`0000000`3oool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo
00l0oooo00<000000?ooo`3oool04`3oool00`000000oooo0?ooo`0F0?ooo`030000003oool0oooo
02d0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`0E0?ooo`030000003oool0oooo
008000001P3oool01@000000oooo0?ooo`3oool0000000H0oooo00<000000?ooo`3oool04`3oool0
0`000000oooo0?ooo`080?ooo`030000003oool0oooo0080oooo00<000000?ooo`0000003P3oool0
10000000oooo0?ooo`0000050?ooo`030000003oool0oooo02/0oooo00<000000?ooo`3oool0303o
ool00`000000oooo0?ooo`1>0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool01`3o
ool2000001D0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`0D0?ooo`006@3oool0
0`000000oooo0?ooo`02000000<0oooo00<000000?ooo`3oool06@3oool00`000000oooo0?ooo`03
0?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool0703oool00`000000oooo0000000C
0?ooo`050000003oool0oooo0?ooo`000000303oool00`000000oooo0?ooo`050?ooo`030000003o
ool0oooo00L0oooo00<000000?ooo`000000303oool00`000000oooo0?ooo`040?ooo`050000003o
ool0oooo0?ooo`0000003P3oool00`000000oooo0000000Z0?ooo`040000003oool0oooo00000140
oooo00<000000?ooo`3oool04`3oool00`000000oooo0?ooo`020?ooo`030000003oool0000000<0
oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`0?0?ooo`030000003oool0oooo01<0
oooo00<000000?ooo`3oool05P3oool00`000000oooo0?ooo`0]0?ooo`030000003oool0oooo00H0
oooo00<000000?ooo`3oool05@3oool00`000000oooo0?ooo`02000000H0oooo00D000000?ooo`3o
ool0oooo000000060?ooo`030000003oool0oooo01<0oooo00<000000?ooo`3oool0203oool00`00
0000oooo0?ooo`020?ooo`030000003oool0000000h0oooo00@000000?ooo`3oool000001@3oool0
0`000000oooo0?ooo`0[0?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool0CP3oool0
0`000000oooo0?ooo`050?ooo`030000003oool0oooo00L0oooo0P00000E0?ooo`030000003oool0
oooo00<0oooo00<000000?ooo`3oool0503oool001T0oooo00<000000?ooo`3oool00P0000030?oo
o`030000003oool0oooo01T0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`0<0?oo
o`030000003oool0oooo01`0oooo00<000000?ooo`0000004`3oool01@000000oooo0?ooo`3oool0
000000`0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`070?ooo`030000003oool0
000000`0oooo00<000000?ooo`3oool0103oool01@000000oooo0?ooo`3oool0000000h0oooo00<0
00000?ooo`000000:P3oool010000000oooo0?ooo`00000A0?ooo`030000003oool0oooo01<0oooo
00<000000?ooo`3oool00P3oool00`000000oooo000000030?ooo`030000003oool0oooo00`0oooo
00<000000?ooo`3oool03`3oool00`000000oooo0?ooo`0C0?ooo`030000003oool0oooo01H0oooo
00<000000?ooo`3oool0;@3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo01D0oooo
00<000000?ooo`3oool00P0000060?ooo`050000003oool0oooo0?ooo`0000001P3oool00`000000
oooo0?ooo`0C0?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool00P3oool00`000000
oooo0000000>0?ooo`040000003oool0oooo000000D0oooo00<000000?ooo`3oool0:`3oool00`00
0000oooo0?ooo`0<0?ooo`030000003oool0oooo04h0oooo00<000000?ooo`3oool01@3oool00`00
0000oooo0?ooo`070?ooo`8000005@3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo
01@0oooo000I0?ooo`030000003oool0oooo008000000`3oool00`000000oooo0?ooo`0I0?ooo`03
0000003oool0oooo00<0oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`0L0?ooo`03
0000003oool0000001<0oooo00D000000?ooo`3oool0oooo0000000<0?ooo`030000003oool0oooo
00D0oooo00<000000?ooo`3oool01`3oool00`000000oooo0000000<0?ooo`030000003oool0oooo
00@0oooo00D000000?ooo`3oool0oooo0000000>0?ooo`030000003oool0000002X0oooo00@00000
0?ooo`3oool000004@3oool00`000000oooo0?ooo`0C0?ooo`030000003oool0oooo0080oooo00<0
00000?ooo`0000000`3oool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo00l0oooo00<0
00000?ooo`3oool04`3oool00`000000oooo0?ooo`0F0?ooo`030000003oool0oooo02d0oooo00<0
00000?ooo`3oool01P3oool00`000000oooo0?ooo`0E0?ooo`030000003oool0oooo008000001P3o
ool01@000000oooo0?ooo`3oool0000000H0oooo00<000000?ooo`3oool04`3oool00`000000oooo
0?ooo`080?ooo`030000003oool0oooo0080oooo00<000000?ooo`0000003P3oool010000000oooo
0?ooo`0000050?ooo`030000003oool0oooo02/0oooo00<000000?ooo`3oool0303oool00`000000
oooo0?ooo`1>0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool01`3oool2000001D0
oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`0D0?ooo`006@3oool00`000000oooo
0?ooo`02000000<0oooo00<000000?ooo`3oool06@3oool00`000000oooo0?ooo`030?ooo`030000
003oool0oooo00`0oooo00<000000?ooo`3oool0703oool00`000000oooo0000000C0?ooo`050000
003oool0oooo0?ooo`000000303oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00L0
oooo00<000000?ooo`000000303oool00`000000oooo0?ooo`040?ooo`050000003oool0oooo0?oo
o`0000003P3oool00`000000oooo0000000Z0?ooo`040000003oool0oooo00000140oooo00<00000
0?ooo`3oool04`3oool00`000000oooo0?ooo`020?ooo`030000003oool0000000<0oooo00<00000
0?ooo`3oool0303oool00`000000oooo0?ooo`0?0?ooo`030000003oool0oooo01<0oooo00<00000
0?ooo`3oool05P3oool00`000000oooo0?ooo`0]0?ooo`030000003oool0oooo00H0oooo00<00000
0?ooo`3oool05@3oool00`000000oooo0?ooo`02000000H0oooo00D000000?ooo`3oool0oooo0000
00060?ooo`030000003oool0oooo01<0oooo00<000000?ooo`3oool0203oool00`000000oooo0?oo
o`020?ooo`030000003oool0000000h0oooo00@000000?ooo`3oool000001@3oool00`000000oooo
0?ooo`0[0?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool0CP3oool00`000000oooo
0?ooo`050?ooo`030000003oool0oooo00L0oooo0P00000E0?ooo`030000003oool0oooo00<0oooo
00<000000?ooo`3oool0503oool001T0oooo00<000000?ooo`3oool00P0000030?ooo`030000003o
ool0oooo01T0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`0<0?ooo`030000003o
ool0oooo01`0oooo00<000000?ooo`0000004`3oool01@000000oooo0?ooo`3oool0000000`0oooo
00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`070?ooo`030000003oool0000000`0oooo
00<000000?ooo`3oool0103oool01@000000oooo0?ooo`3oool0000000h0oooo00<000000?ooo`00
0000:P3oool010000000oooo0?ooo`00000A0?ooo`030000003oool0oooo01<0oooo00<000000?oo
o`3oool00P3oool00`000000oooo000000030?ooo`030000003oool0oooo00`0oooo00<000000?oo
o`3oool03`3oool00`000000oooo0?ooo`0C0?ooo`030000003oool0oooo01H0oooo00<000000?oo
o`3oool0;@3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo01D0oooo00<000000?oo
o`3oool00P0000060?ooo`050000003oool0oooo0?ooo`0000001P3oool00`000000oooo0?ooo`0C
0?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool00P3oool00`000000oooo0000000>
0?ooo`040000003oool0oooo000000D0oooo00<000000?ooo`3oool0:`3oool00`000000oooo0?oo
o`0<0?ooo`030000003oool0oooo04h0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?oo
o`070?ooo`8000005@3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo01@0oooo000D
0?ooool0ool0X`3oo`0:0000oaL0ool030000?l30?oo00P0003oo`3oo`0D0?ooo`006@3oool00`00
0000oooo0?ooo`02000000<0oooo00<000000?ooo`3oool06@3oool00`000000oooo0?ooo`030?oo
o`030000003oool0oooo00`0oooo00<000000?ooo`3oool0703oool00`000000oooo0000000C0?oo
o`050000003oool0oooo0?ooo`000000303oool00`000000oooo0?ooo`050?ooo`030000003oool0
oooo00L0oooo00<000000?ooo`000000303oool00`000000oooo0?ooo`040?ooo`050000003oool0
oooo0?ooo`0000003P3oool00`000000oooo0000000Z0?ooo`040000003oool0oooo00000140oooo
00<000000?ooo`3oool04`3oool00`000000oooo0?ooo`020?ooo`030000003oool0000000<0oooo
00<000000?ooo`3oool0303oool00`000000oooo0?ooo`0?0?ooo`030000003oool0oooo01<0oooo
00<000000?ooo`3oool05P3oool00`000000oooo0?ooo`0]0?ooo`030000003oool0oooo00H0oooo
00<000000?ooo`3oool05@3oool00`000000oooo0?ooo`02000000H0oooo00D000000?ooo`3oool0
oooo000000060?ooo`030000003oool0oooo01<0oooo00<000000?ooo`3oool0203oool00`000000
oooo0?ooo`020?ooo`030000003oool0000000h0oooo00@000000?ooo`3oool000001@3oool00`00
0000oooo0?ooo`0[0?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool0CP3oool00`00
0000oooo0?ooo`050?ooo`030000003oool0oooo00L0oooo0P00000E0?ooo`030000003oool0oooo
00<0oooo00<000000?ooo`3oool0503oool001T0oooo00<000000?ooo`3oool00P0000030?ooo`03
0000003oool0oooo01T0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`0<0?ooo`03
0000003oool0oooo01`0oooo00<000000?ooo`0000004`3oool01@000000oooo0?ooo`3oool00000
00`0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`070?ooo`030000003oool00000
00`0oooo00<000000?ooo`3oool0103oool01@000000oooo0?ooo`3oool0000000h0oooo00<00000
0?ooo`000000:P3oool010000000oooo0?ooo`00000A0?ooo`030000003oool0oooo01<0oooo00<0
00000?ooo`3oool00P3oool00`000000oooo000000030?ooo`030000003oool0oooo00`0oooo00<0
00000?ooo`3oool03`3oool00`000000oooo0?ooo`0C0?ooo`030000003oool0oooo01H0oooo00<0
00000?ooo`3oool0;@3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo01D0oooo00<0
00000?ooo`3oool00P0000060?ooo`050000003oool0oooo0?ooo`0000001P3oool00`000000oooo
0?ooo`0C0?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool00P3oool00`000000oooo
0000000>0?ooo`040000003oool0oooo000000D0oooo00<000000?ooo`3oool0:`3oool00`000000
oooo0?ooo`0<0?ooo`030000003oool0oooo04h0oooo00<000000?ooo`3oool01@3oool00`000000
oooo0?ooo`070?ooo`8000005@3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo01@0
oooo000I0?ooo`030000003oool0oooo008000000`3oool00`000000oooo0?ooo`0I0?ooo`030000
003oool0oooo00<0oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`0L0?ooo`030000
003oool0000001<0oooo00D000000?ooo`3oool0oooo0000000<0?ooo`030000003oool0oooo00D0
oooo00<000000?ooo`3oool01`3oool00`000000oooo0000000<0?ooo`030000003oool0oooo00@0
oooo00D000000?ooo`3oool0oooo0000000>0?ooo`030000003oool0000002X0oooo00@000000?oo
o`3oool000004@3oool00`000000oooo0?ooo`0C0?ooo`030000003oool0oooo0080oooo00<00000
0?ooo`0000000`3oool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo00l0oooo00<00000
0?ooo`3oool04`3oool00`000000oooo0?ooo`0F0?ooo`030000003oool0oooo02d0oooo00<00000
0?ooo`3oool01P3oool00`000000oooo0?ooo`0E0?ooo`030000003oool0oooo008000001P3oool0
1@000000oooo0?ooo`3oool0000000H0oooo00<000000?ooo`3oool04`3oool00`000000oooo0?oo
o`080?ooo`030000003oool0oooo0080oooo00<000000?ooo`0000003P3oool010000000oooo0?oo
o`0000050?ooo`030000003oool0oooo02/0oooo00<000000?ooo`3oool0303oool00`000000oooo
0?ooo`1>0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool01`3oool2000001D0oooo
00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`0D0?ooo`006@3oool00`000000oooo0?oo
o`02000000<0oooo00<000000?ooo`3oool06@3oool00`000000oooo0?ooo`030?ooo`030000003o
ool0oooo00`0oooo00<000000?ooo`3oool0703oool00`000000oooo0000000C0?ooo`050000003o
ool0oooo0?ooo`000000303oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00L0oooo
00<000000?ooo`000000303oool00`000000oooo0?ooo`040?ooo`050000003oool0oooo0?ooo`00
00003P3oool00`000000oooo0000000Z0?ooo`040000003oool0oooo00000140oooo00<000000?oo
o`3oool04`3oool00`000000oooo0?ooo`020?ooo`030000003oool0000000<0oooo00<000000?oo
o`3oool0303oool00`000000oooo0?ooo`0?0?ooo`030000003oool0oooo01<0oooo00<000000?oo
o`3oool05P3oool00`000000oooo0?ooo`0]0?ooo`030000003oool0oooo00H0oooo00<000000?oo
o`3oool05@3oool00`000000oooo0?ooo`02000000H0oooo00D000000?ooo`3oool0oooo00000006
0?ooo`030000003oool0oooo01<0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`02
0?ooo`030000003oool0000000h0oooo00@000000?ooo`3oool000001@3oool00`000000oooo0?oo
o`0[0?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool0CP3oool00`000000oooo0?oo
o`050?ooo`030000003oool0oooo00L0oooo0P00000E0?ooo`030000003oool0oooo00<0oooo00<0
00000?ooo`3oool0503oool001T0oooo00<000000?ooo`3oool00P0000030?ooo`030000003oool0
oooo01T0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`0<0?ooo`030000003oool0
oooo01`0oooo00<000000?ooo`0000004`3oool01@000000oooo0?ooo`3oool0000000`0oooo00<0
00000?ooo`3oool01@3oool00`000000oooo0?ooo`070?ooo`030000003oool0000000`0oooo00<0
00000?ooo`3oool0103oool01@000000oooo0?ooo`3oool0000000h0oooo00<000000?ooo`000000
:P3oool010000000oooo0?ooo`00000A0?ooo`030000003oool0oooo01<0oooo00<000000?ooo`3o
ool00P3oool00`000000oooo000000030?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3o
ool03`3oool00`000000oooo0?ooo`0C0?ooo`030000003oool0oooo01H0oooo00<000000?ooo`3o
ool0;@3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo01D0oooo00<000000?ooo`3o
ool00P0000060?ooo`050000003oool0oooo0?ooo`0000001P3oool00`000000oooo0?ooo`0C0?oo
o`030000003oool0oooo00P0oooo00<000000?ooo`3oool00P3oool00`000000oooo0000000>0?oo
o`040000003oool0oooo000000D0oooo00<000000?ooo`3oool0:`3oool00`000000oooo0?ooo`0<
0?ooo`030000003oool0oooo04h0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`07
0?ooo`8000005@3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo01@0oooo000I0?oo
o`030000003oool0oooo008000000`3oool00`000000oooo0?ooo`0I0?ooo`030000003oool0oooo
00<0oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`0L0?ooo`030000003oool00000
01<0oooo00D000000?ooo`3oool0oooo0000000<0?ooo`030000003oool0oooo00D0oooo00<00000
0?ooo`3oool01`3oool00`000000oooo0000000<0?ooo`030000003oool0oooo00@0oooo00D00000
0?ooo`3oool0oooo0000000>0?ooo`030000003oool0000002X0oooo00@000000?ooo`3oool00000
4@3oool00`000000oooo0?ooo`0C0?ooo`030000003oool0oooo0080oooo00<000000?ooo`000000
0`3oool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo00l0oooo00<000000?ooo`3oool0
4`3oool00`000000oooo0?ooo`0F0?ooo`030000003oool0oooo02d0oooo00<000000?ooo`3oool0
1P3oool00`000000oooo0?ooo`0E0?ooo`030000003oool0oooo008000001P3oool01@000000oooo
0?ooo`3oool0000000H0oooo00<000000?ooo`3oool04`3oool00`000000oooo0?ooo`080?ooo`03
0000003oool0oooo0080oooo00<000000?ooo`0000003P3oool010000000oooo0?ooo`0000050?oo
o`030000003oool0oooo02/0oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`1>0?oo
o`030000003oool0oooo00D0oooo00<000000?ooo`3oool01`3oool2000001D0oooo00<000000?oo
o`3oool00`3oool00`000000oooo0?ooo`0D0?ooo`006@3oool00`000000oooo0?ooo`02000000<0
oooo00<000000?ooo`3oool06@3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00`0
oooo00<000000?ooo`3oool0703oool00`000000oooo0000000C0?ooo`050000003oool0oooo0?oo
o`000000303oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00L0oooo00<000000?oo
o`000000303oool00`000000oooo0?ooo`040?ooo`050000003oool0oooo0?ooo`0000003P3oool0
0`000000oooo0000000Z0?ooo`040000003oool0oooo00000140oooo00<000000?ooo`3oool04`3o
ool00`000000oooo0?ooo`020?ooo`030000003oool0000000<0oooo00<000000?ooo`3oool0303o
ool00`000000oooo0?ooo`0?0?ooo`030000003oool0oooo01<0oooo00<000000?ooo`3oool05P3o
ool00`000000oooo0?ooo`0]0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool05@3o
ool00`000000oooo0?ooo`02000000H0oooo00D000000?ooo`3oool0oooo000000060?ooo`030000
003oool0oooo01<0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`020?ooo`030000
003oool0000000h0oooo00@000000?ooo`3oool000001@3oool00`000000oooo0?ooo`0[0?ooo`03
0000003oool0oooo00`0oooo00<000000?ooo`3oool0CP3oool00`000000oooo0?ooo`050?ooo`03
0000003oool0oooo00L0oooo0P00000E0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3o
ool0503oool001@0oooo1P000?lh0?oo0200003o00<0ool00000o`000?l04`000?lH0?oo00/0003o
Q`3oo`000`000?l0ool00?oo003o0?oo0;T0ool0503oool001T0oooo00<000000?ooo`3oool00P00
00030?ooo`030000003oool0oooo01T0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?oo
o`0<0?ooo`030000003oool0oooo01`0oooo00<000000?ooo`0000004`3oool01@000000oooo0?oo
o`3oool0000000`0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`070?ooo`030000
003oool0000000`0oooo00<000000?ooo`3oool0103oool01@000000oooo0?ooo`3oool0000000h0
oooo00<000000?ooo`000000:P3oool010000000oooo0?ooo`00000A0?ooo`030000003oool0oooo
01<0oooo00<000000?ooo`3oool00P3oool00`000000oooo000000030?ooo`030000003oool0oooo
00`0oooo00<000000?ooo`3oool03`3oool00`000000oooo0?ooo`0C0?ooo`030000003oool0oooo
01H0oooo00<000000?ooo`3oool0;@3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo
01D0oooo00<000000?ooo`3oool00P0000060?ooo`050000003oool0oooo0?ooo`0000001P3oool0
0`000000oooo0?ooo`0C0?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool00P3oool0
0`000000oooo0000000>0?ooo`040000003oool0oooo000000D0oooo00<000000?ooo`3oool0:`3o
ool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo04h0oooo00<000000?ooo`3oool01@3o
ool00`000000oooo0?ooo`070?ooo`8000005@3oool00`000000oooo0?ooo`030?ooo`030000003o
ool0oooo01@0oooo000I0?ooo`030000003oool0oooo008000000`3oool00`000000oooo0?ooo`0I
0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`0L
0?ooo`030000003oool0000001<0oooo00D000000?ooo`3oool0oooo0000000<0?ooo`030000003o
ool0oooo00D0oooo00<000000?ooo`3oool01`3oool00`000000oooo0000000<0?ooo`030000003o
ool0oooo00@0oooo00D000000?ooo`3oool0oooo0000000>0?ooo`030000003oool0000002X0oooo
00@000000?ooo`3oool000004@3oool00`000000oooo0?ooo`0C0?ooo`030000003oool0oooo0080
oooo00<000000?ooo`0000000`3oool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo00l0
oooo00<000000?ooo`3oool04`3oool00`000000oooo0?ooo`0F0?ooo`030000003oool0oooo02d0
oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`0E0?ooo`030000003oool0oooo0080
00001P3oool01@000000oooo0?ooo`3oool0000000H0oooo00<000000?ooo`3oool04`3oool00`00
0000oooo0?ooo`080?ooo`030000003oool0oooo0080oooo00<000000?ooo`0000003P3oool01000
0000oooo0?ooo`0000050?ooo`030000003oool0oooo02/0oooo00<000000?ooo`3oool0303oool0
0`000000oooo0?ooo`1>0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool01`3oool2
000001D0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`0D0?ooo`006@3oool00`00
0000oooo0?ooo`02000000<0oooo00<000000?ooo`3oool06@3oool00`000000oooo0?ooo`030?oo
o`030000003oool0oooo00`0oooo00<000000?ooo`3oool0703oool00`000000oooo0000000C0?oo
o`050000003oool0oooo0?ooo`000000303oool00`000000oooo0?ooo`050?ooo`030000003oool0
oooo00L0oooo00<000000?ooo`000000303oool00`000000oooo0?ooo`040?ooo`050000003oool0
oooo0?ooo`0000003P3oool00`000000oooo0000000Z0?ooo`040000003oool0oooo00000140oooo
00<000000?ooo`3oool04`3oool00`000000oooo0?ooo`020?ooo`030000003oool0000000<0oooo
00<000000?ooo`3oool0303oool00`000000oooo0?ooo`0?0?ooo`030000003oool0oooo01<0oooo
00<000000?ooo`3oool05P3oool00`000000oooo0?ooo`0]0?ooo`030000003oool0oooo00H0oooo
00<000000?ooo`3oool05@3oool00`000000oooo0?ooo`02000000H0oooo00D000000?ooo`3oool0
oooo000000060?ooo`030000003oool0oooo01<0oooo00<000000?ooo`3oool0203oool00`000000
oooo0?ooo`020?ooo`030000003oool0000000h0oooo00@000000?ooo`3oool000001@3oool00`00
0000oooo0?ooo`0[0?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool0CP3oool00`00
0000oooo0?ooo`050?ooo`030000003oool0oooo00L0oooo0P00000E0?ooo`030000003oool0oooo
00<0oooo00<000000?ooo`3oool0503oool001T0oooo00<000000?ooo`3oool00P0000030?ooo`03
0000003oool0oooo01T0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`0<0?ooo`03
0000003oool0oooo01`0oooo00<000000?ooo`0000004`3oool01@000000oooo0?ooo`3oool00000
00`0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`070?ooo`030000003oool00000
00`0oooo00<000000?ooo`3oool0103oool01@000000oooo0?ooo`3oool0000000h0oooo00<00000
0?ooo`000000:P3oool010000000oooo0?ooo`00000A0?ooo`030000003oool0oooo01<0oooo00<0
00000?ooo`3oool00P3oool00`000000oooo000000030?ooo`030000003oool0oooo00`0oooo00<0
00000?ooo`3oool03`3oool00`000000oooo0?ooo`0C0?ooo`030000003oool0oooo01H0oooo00<0
00000?ooo`3oool0;@3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo01D0oooo00<0
00000?ooo`3oool00P0000060?ooo`050000003oool0oooo0?ooo`0000001P3oool00`000000oooo
0?ooo`0C0?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool00P3oool00`000000oooo
0000000>0?ooo`040000003oool0oooo000000D0oooo00<000000?ooo`3oool0:`3oool00`000000
oooo0?ooo`0<0?ooo`030000003oool0oooo04h0oooo00<000000?ooo`3oool01@3oool00`000000
oooo0?ooo`070?ooo`8000005@3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo01@0
oooo000I0?ooo`030000003oool0oooo008000000`3oool00`000000oooo0?ooo`0I0?ooo`030000
003oool0oooo00<0oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`0L0?ooo`030000
003oool0000001<0oooo00D000000?ooo`3oool0oooo0000000<0?ooo`030000003oool0oooo00D0
oooo00<000000?ooo`3oool01`3oool00`000000oooo0000000<0?ooo`030000003oool0oooo00@0
oooo00D000000?ooo`3oool0oooo0000000>0?ooo`030000003oool0000002X0oooo00@000000?oo
o`3oool000004@3oool00`000000oooo0?ooo`0C0?ooo`030000003oool0oooo0080oooo00<00000
0?ooo`0000000`3oool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo00l0oooo00<00000
0?ooo`3oool04`3oool00`000000oooo0?ooo`0F0?ooo`030000003oool0oooo02d0oooo00<00000
0?ooo`3oool01P3oool00`000000oooo0?ooo`0E0?ooo`030000003oool0oooo008000001P3oool0
1@000000oooo0?ooo`3oool0000000H0oooo00<000000?ooo`3oool04`3oool00`000000oooo0?oo
o`080?ooo`030000003oool0oooo0080oooo00<000000?ooo`0000003P3oool010000000oooo0?oo
o`0000050?ooo`030000003oool0oooo02/0oooo00<000000?ooo`3oool0303oool00`000000oooo
0?ooo`1>0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool01`3oool2000001D0oooo
00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`0D0?ooo`006@3oool00`000000oooo0?oo
o`02000000<0oooo00<000000?ooo`3oool06@3oool00`000000oooo0?ooo`030?ooo`030000003o
ool0oooo00`0oooo00<000000?ooo`3oool0703oool00`000000oooo0000000C0?ooo`050000003o
ool0oooo0?ooo`000000303oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00L0oooo
00<000000?ooo`000000303oool00`000000oooo0?ooo`040?ooo`050000003oool0oooo0?ooo`00
00003P3oool00`000000oooo0000000Z0?ooo`040000003oool0oooo00000140oooo00<000000?oo
o`3oool04`3oool00`000000oooo0?ooo`020?ooo`030000003oool0000000<0oooo00<000000?oo
o`3oool0303oool00`000000oooo0?ooo`0?0?ooo`030000003oool0oooo01<0oooo00<000000?oo
o`3oool05P3oool00`000000oooo0?ooo`0]0?ooo`030000003oool0oooo00H0oooo00<000000?oo
o`3oool05@3oool00`000000oooo0?ooo`02000000H0oooo00D000000?ooo`3oool0oooo00000006
0?ooo`030000003oool0oooo01<0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`02
0?ooo`030000003oool0000000h0oooo00@000000?ooo`3oool000001@3oool00`000000oooo0?oo
o`0[0?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool0CP3oool00`000000oooo0?oo
o`050?ooo`030000003oool0oooo00L0oooo0P00000E0?ooo`030000003oool0oooo00<0oooo00<0
00000?ooo`3oool0503oool001T0oooo00<000000?ooo`3oool00P0000030?ooo`030000003oool0
oooo01T0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`0<0?ooo`030000003oool0
oooo01`0oooo00<000000?ooo`0000004`3oool01@000000oooo0?ooo`3oool0000000`0oooo00<0
00000?ooo`3oool01@3oool00`000000oooo0?ooo`070?ooo`030000003oool0000000`0oooo00<0
00000?ooo`3oool0103oool01@000000oooo0?ooo`3oool0000000h0oooo00<000000?ooo`000000
:P3oool010000000oooo0?ooo`00000A0?ooo`030000003oool0oooo01<0oooo00<000000?ooo`3o
ool00P3oool00`000000oooo000000030?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3o
ool03`3oool00`000000oooo0?ooo`0C0?ooo`030000003oool0oooo01H0oooo00<000000?ooo`3o
ool0;@3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo01D0oooo00<000000?ooo`3o
ool00P0000060?ooo`050000003oool0oooo0?ooo`0000001P3oool00`000000oooo0?ooo`0C0?oo
o`030000003oool0oooo00P0oooo00<000000?ooo`3oool00P3oool00`000000oooo0000000>0?oo
o`040000003oool0oooo000000D0oooo00<000000?ooo`3oool0:`3oool00`000000oooo0?ooo`0<
0?ooo`030000003oool0oooo04h0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`07
0?ooo`8000005@3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo01@0oooo000D0?oo
onl0ool04`000?oo0?oo0=P0ool0503oool001T0oooo00<000000?ooo`3oool00P0000030?ooo`03
0000003oool0oooo01T0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`0<0?ooo`03
0000003oool0oooo01`0oooo00<000000?ooo`0000004`3oool01@000000oooo0?ooo`3oool00000
00`0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`070?ooo`030000003oool00000
00`0oooo00<000000?ooo`3oool0103oool01@000000oooo0?ooo`3oool0000000h0oooo00<00000
0?ooo`000000:P3oool010000000oooo0?ooo`00000A0?ooo`030000003oool0oooo01<0oooo00<0
00000?ooo`3oool00P3oool00`000000oooo000000030?ooo`030000003oool0oooo00`0oooo00<0
00000?ooo`3oool03`3oool00`000000oooo0?ooo`0C0?ooo`030000003oool0oooo01H0oooo00<0
00000?ooo`3oool0;@3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo01D0oooo00<0
00000?ooo`3oool00P0000060?ooo`050000003oool0oooo0?ooo`0000001P3oool00`000000oooo
0?ooo`0C0?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool00P3oool00`000000oooo
0000000>0?ooo`040000003oool0oooo000000D0oooo00<000000?ooo`3oool0:`3oool00`000000
oooo0?ooo`0<0?ooo`030000003oool0oooo04h0oooo00<000000?ooo`3oool01@3oool00`000000
oooo0?ooo`070?ooo`8000005@3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo01@0
oooo000I0?ooo`030000003oool0oooo008000000`3oool00`000000oooo0?ooo`0I0?ooo`030000
003oool0oooo00<0oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`0L0?ooo`030000
003oool0000001<0oooo00D000000?ooo`3oool0oooo0000000<0?ooo`030000003oool0oooo00D0
oooo00<000000?ooo`3oool01`3oool00`000000oooo0000000<0?ooo`030000003oool0oooo00@0
oooo00D000000?ooo`3oool0oooo0000000>0?ooo`030000003oool0000002X0oooo00@000000?oo
o`3oool000004@3oool00`000000oooo0?ooo`0C0?ooo`030000003oool0oooo0080oooo00<00000
0?ooo`0000000`3oool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo00l0oooo00<00000
0?ooo`3oool04`3oool00`000000oooo0?ooo`0F0?ooo`030000003oool0oooo02d0oooo00<00000
0?ooo`3oool01P3oool00`000000oooo0?ooo`0E0?ooo`030000003oool0oooo008000001P3oool0
1@000000oooo0?ooo`3oool0000000H0oooo00<000000?ooo`3oool04`3oool00`000000oooo0?oo
o`080?ooo`030000003oool0oooo0080oooo00<000000?ooo`0000003P3oool010000000oooo0?oo
o`0000050?ooo`030000003oool0oooo02/0oooo00<000000?ooo`3oool0303oool00`000000oooo
0?ooo`1>0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool01`3oool2000001D0oooo
00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`0D0?ooo`006@3oool00`000000oooo0?oo
o`02000000<0oooo00<000000?ooo`3oool06@3oool00`000000oooo0?ooo`030?ooo`030000003o
ool0oooo00`0oooo00<000000?ooo`3oool0703oool00`000000oooo0000000C0?ooo`050000003o
ool0oooo0?ooo`000000303oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00L0oooo
00<000000?ooo`000000303oool00`000000oooo0?ooo`040?ooo`050000003oool0oooo0?ooo`00
00003P3oool00`000000oooo0000000Z0?ooo`040000003oool0oooo00000140oooo00<000000?oo
o`3oool04`3oool00`000000oooo0?ooo`020?ooo`030000003oool0000000<0oooo00<000000?oo
o`3oool0303oool00`000000oooo0?ooo`0?0?ooo`030000003oool0oooo01<0oooo00<000000?oo
o`3oool05P3oool00`000000oooo0?ooo`0]0?ooo`030000003oool0oooo00H0oooo00<000000?oo
o`3oool05@3oool00`000000oooo0?ooo`02000000H0oooo00D000000?ooo`3oool0oooo00000006
0?ooo`030000003oool0oooo01<0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`02
0?ooo`030000003oool0000000h0oooo00@000000?ooo`3oool000001@3oool00`000000oooo0?oo
o`0[0?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool0CP3oool00`000000oooo0?oo
o`050?ooo`030000003oool0oooo00L0oooo0P00000E0?ooo`030000003oool0oooo00<0oooo00<0
00000?ooo`3oool0503oool001T0oooo00<000000?ooo`3oool00P0000030?ooo`030000003oool0
oooo01T0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`0<0?ooo`030000003oool0
oooo01`0oooo00<000000?ooo`0000004`3oool01@000000oooo0?ooo`3oool0000000`0oooo00<0
00000?ooo`3oool01@3oool00`000000oooo0?ooo`070?ooo`030000003oool0000000`0oooo00<0
00000?ooo`3oool0103oool01@000000oooo0?ooo`3oool0000000h0oooo00<000000?ooo`000000
:P3oool010000000oooo0?ooo`00000A0?ooo`030000003oool0oooo01<0oooo00<000000?ooo`3o
ool00P3oool00`000000oooo000000030?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3o
ool03`3oool00`000000oooo0?ooo`0C0?ooo`030000003oool0oooo01H0oooo00<000000?ooo`3o
ool0;@3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo01D0oooo00<000000?ooo`3o
ool00P0000060?ooo`050000003oool0oooo0?ooo`0000001P3oool00`000000oooo0?ooo`0C0?oo
o`030000003oool0oooo00P0oooo00<000000?ooo`3oool00P3oool00`000000oooo0000000>0?oo
o`040000003oool0oooo000000D0oooo00<000000?ooo`3oool0:`3oool00`000000oooo0?ooo`0<
0?ooo`030000003oool0oooo04h0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`07
0?ooo`8000005@3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo01@0oooo000I0?oo
o`030000003oool0oooo008000000`3oool00`000000oooo0?ooo`0I0?ooo`030000003oool0oooo
00<0oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`0L0?ooo`030000003oool00000
01<0oooo00D000000?ooo`3oool0oooo0000000<0?ooo`030000003oool0oooo00D0oooo00<00000
0?ooo`3oool01`3oool00`000000oooo0000000<0?ooo`030000003oool0oooo00@0oooo00D00000
0?ooo`3oool0oooo0000000>0?ooo`030000003oool0000002X0oooo00@000000?ooo`3oool00000
4@3oool00`000000oooo0?ooo`0C0?ooo`030000003oool0oooo0080oooo00<000000?ooo`000000
0`3oool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo00l0oooo00<000000?ooo`3oool0
4`3oool00`000000oooo0?ooo`0F0?ooo`030000003oool0oooo02d0oooo00<000000?ooo`3oool0
1P3oool00`000000oooo0?ooo`0E0?ooo`030000003oool0oooo008000001P3oool01@000000oooo
0?ooo`3oool0000000H0oooo00<000000?ooo`3oool04`3oool00`000000oooo0?ooo`080?ooo`03
0000003oool0oooo0080oooo00<000000?ooo`0000003P3oool010000000oooo0?ooo`0000050?oo
o`030000003oool0oooo02/0oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`1>0?oo
o`030000003oool0oooo00D0oooo00<000000?ooo`3oool01`3oool2000001D0oooo00<000000?oo
o`3oool00`3oool00`000000oooo0?ooo`0D0?ooo`006@3oool00`000000oooo0?ooo`02000000<0
oooo00<000000?ooo`3oool06@3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00`0
oooo00<000000?ooo`3oool0703oool00`000000oooo0000000C0?ooo`050000003oool0oooo0?oo
o`000000303oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00L0oooo00<000000?oo
o`000000303oool00`000000oooo0?ooo`040?ooo`050000003oool0oooo0?ooo`0000003P3oool0
0`000000oooo0000000Z0?ooo`040000003oool0oooo00000140oooo00<000000?ooo`3oool04`3o
ool00`000000oooo0?ooo`020?ooo`030000003oool0000000<0oooo00<000000?ooo`3oool0303o
ool00`000000oooo0?ooo`0?0?ooo`030000003oool0oooo01<0oooo00<000000?ooo`3oool05P3o
ool00`000000oooo0?ooo`0]0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool05@3o
ool00`000000oooo0?ooo`02000000H0oooo00D000000?ooo`3oool0oooo000000060?ooo`030000
003oool0oooo01<0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`020?ooo`030000
003oool0000000h0oooo00@000000?ooo`3oool000001@3oool00`000000oooo0?ooo`0[0?ooo`03
0000003oool0oooo00`0oooo00<000000?ooo`3oool0CP3oool00`000000oooo0?ooo`050?ooo`03
0000003oool0oooo00L0oooo0P00000E0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3o
ool0503oool001@0ooooo`3oo`020?oo01L0003o103oo`070000o`h0ool04`000?oo0?oo09H0ool0
503oool001T0oooo00<000000?ooo`3oool00P0000030?ooo`030000003oool0oooo01T0oooo00<0
00000?ooo`3oool00`3oool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo01`0oooo00<0
00000?ooo`0000004`3oool01@000000oooo0?ooo`3oool0000000`0oooo00<000000?ooo`3oool0
1@3oool00`000000oooo0?ooo`070?ooo`030000003oool0000000`0oooo00<000000?ooo`3oool0
103oool01@000000oooo0?ooo`3oool0000000h0oooo00<000000?ooo`000000:P3oool010000000
oooo0?ooo`00000A0?ooo`030000003oool0oooo01<0oooo00<000000?ooo`3oool00P3oool00`00
0000oooo000000030?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool03`3oool00`00
0000oooo0?ooo`0C0?ooo`030000003oool0oooo01H0oooo00<000000?ooo`3oool0;@3oool00`00
0000oooo0?ooo`060?ooo`030000003oool0oooo01D0oooo00<000000?ooo`3oool00P0000060?oo
o`050000003oool0oooo0?ooo`0000001P3oool00`000000oooo0?ooo`0C0?ooo`030000003oool0
oooo00P0oooo00<000000?ooo`3oool00P3oool00`000000oooo0000000>0?ooo`040000003oool0
oooo000000D0oooo00<000000?ooo`3oool0:`3oool00`000000oooo0?ooo`0<0?ooo`030000003o
ool0oooo04h0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`070?ooo`8000005@3o
ool00`000000oooo0?ooo`030?ooo`030000003oool0oooo01@0oooo000I0?ooo`030000003oool0
oooo008000000`3oool00`000000oooo0?ooo`0I0?ooo`030000003oool0oooo00<0oooo00<00000
0?ooo`3oool0303oool00`000000oooo0?ooo`0L0?ooo`030000003oool0000001<0oooo00D00000
0?ooo`3oool0oooo0000000<0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool01`3o
ool00`000000oooo0000000<0?ooo`030000003oool0oooo00@0oooo00D000000?ooo`3oool0oooo
0000000>0?ooo`030000003oool0000002X0oooo00@000000?ooo`3oool000004@3oool00`000000
oooo0?ooo`0C0?ooo`030000003oool0oooo0080oooo00<000000?ooo`0000000`3oool00`000000
oooo0?ooo`0<0?ooo`030000003oool0oooo00l0oooo00<000000?ooo`3oool04`3oool00`000000
oooo0?ooo`0F0?ooo`030000003oool0oooo02d0oooo00<000000?ooo`3oool01P3oool00`000000
oooo0?ooo`0E0?ooo`030000003oool0oooo008000001P3oool01@000000oooo0?ooo`3oool00000
00H0oooo00<000000?ooo`3oool04`3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo
0080oooo00<000000?ooo`0000003P3oool010000000oooo0?ooo`0000050?ooo`030000003oool0
oooo02/0oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`1>0?ooo`030000003oool0
oooo00D0oooo00<000000?ooo`3oool01`3oool2000001D0oooo00<000000?ooo`3oool00`3oool0
0`000000oooo0?ooo`0D0?ooo`006@3oool00`000000oooo0?ooo`02000000<0oooo00<000000?oo
o`3oool06@3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00`0oooo00<000000?oo
o`3oool0703oool00`000000oooo0000000C0?ooo`050000003oool0oooo0?ooo`000000303oool0
0`000000oooo0?ooo`050?ooo`030000003oool0oooo00L0oooo00<000000?ooo`000000303oool0
0`000000oooo0?ooo`040?ooo`050000003oool0oooo0?ooo`0000003P3oool00`000000oooo0000
000Z0?ooo`040000003oool0oooo00000140oooo00<000000?ooo`3oool04`3oool00`000000oooo
0?ooo`020?ooo`030000003oool0000000<0oooo00<000000?ooo`3oool0303oool00`000000oooo
0?ooo`0?0?ooo`030000003oool0oooo01<0oooo00<000000?ooo`3oool05P3oool00`000000oooo
0?ooo`0]0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool05@3oool00`000000oooo
0?ooo`02000000H0oooo00D000000?ooo`3oool0oooo000000060?ooo`030000003oool0oooo01<0
oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`020?ooo`030000003oool0000000h0
oooo00@000000?ooo`3oool000001@3oool00`000000oooo0?ooo`0[0?ooo`030000003oool0oooo
00`0oooo00<000000?ooo`3oool0CP3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo
00L0oooo0P00000E0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0503oool001T0
oooo00<000000?ooo`3oool00P0000030?ooo`030000003oool0oooo01T0oooo00<000000?ooo`3o
ool00`3oool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo01`0oooo00<000000?ooo`00
00004`3oool01@000000oooo0?ooo`3oool0000000`0oooo00<000000?ooo`3oool01@3oool00`00
0000oooo0?ooo`070?ooo`030000003oool0000000`0oooo00<000000?ooo`3oool0103oool01@00
0000oooo0?ooo`3oool0000000h0oooo00<000000?ooo`000000:P3oool010000000oooo0?ooo`00
000A0?ooo`030000003oool0oooo01<0oooo00<000000?ooo`3oool00P3oool00`000000oooo0000
00030?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool03`3oool00`000000oooo0?oo
o`0C0?ooo`030000003oool0oooo01H0oooo00<000000?ooo`3oool0;@3oool00`000000oooo0?oo
o`060?ooo`030000003oool0oooo01D0oooo00<000000?ooo`3oool00P0000060?ooo`050000003o
ool0oooo0?ooo`0000001P3oool00`000000oooo0?ooo`0C0?ooo`030000003oool0oooo00P0oooo
00<000000?ooo`3oool00P3oool00`000000oooo0000000>0?ooo`040000003oool0oooo000000D0
oooo00<000000?ooo`3oool0:`3oool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo04h0
oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`070?ooo`8000005@3oool00`000000
oooo0?ooo`030?ooo`030000003oool0oooo01@0oooo000I0?ooo`030000003oool0oooo00800000
0`3oool00`000000oooo0?ooo`0I0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0
303oool00`000000oooo0?ooo`0L0?ooo`030000003oool0000001<0oooo00D000000?ooo`3oool0
oooo0000000<0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool01`3oool00`000000
oooo0000000<0?ooo`030000003oool0oooo00@0oooo00D000000?ooo`3oool0oooo0000000>0?oo
o`030000003oool0000002X0oooo00@000000?ooo`3oool000004@3oool00`000000oooo0?ooo`0C
0?ooo`030000003oool0oooo0080oooo00<000000?ooo`0000000`3oool00`000000oooo0?ooo`0<
0?ooo`030000003oool0oooo00l0oooo00<000000?ooo`3oool04`3oool00`000000oooo0?ooo`0F
0?ooo`030000003oool0oooo02d0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`0E
0?ooo`030000003oool0oooo008000001P3oool01@000000oooo0?ooo`3oool0000000H0oooo00<0
00000?ooo`3oool04`3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo0080oooo00<0
00000?ooo`0000003P3oool010000000oooo0?ooo`0000050?ooo`030000003oool0oooo02/0oooo
00<000000?ooo`3oool0303oool00`000000oooo0?ooo`1>0?ooo`030000003oool0oooo00D0oooo
00<000000?ooo`3oool01`3oool2000001D0oooo00<000000?ooo`3oool00`3oool00`000000oooo
0?ooo`0D0?ooo`006@3oool00`000000oooo0?ooo`02000000<0oooo00<000000?ooo`3oool06@3o
ool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool0703o
ool00`000000oooo0000000C0?ooo`050000003oool0oooo0?ooo`000000303oool00`000000oooo
0?ooo`050?ooo`030000003oool0oooo00L0oooo00<000000?ooo`000000303oool00`000000oooo
0?ooo`040?ooo`050000003oool0oooo0?ooo`0000003P3oool00`000000oooo0000000Z0?ooo`04
0000003oool0oooo00000140oooo00<000000?ooo`3oool04`3oool00`000000oooo0?ooo`020?oo
o`030000003oool0000000<0oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`0?0?oo
o`030000003oool0oooo01<0oooo00<000000?ooo`3oool05P3oool00`000000oooo0?ooo`0]0?oo
o`030000003oool0oooo00H0oooo00<000000?ooo`3oool05@3oool00`000000oooo0?ooo`020000
00H0oooo00D000000?ooo`3oool0oooo000000060?ooo`030000003oool0oooo01<0oooo00<00000
0?ooo`3oool0203oool00`000000oooo0?ooo`020?ooo`030000003oool0000000h0oooo00@00000
0?ooo`3oool000001@3oool00`000000oooo0?ooo`0[0?ooo`030000003oool0oooo00`0oooo00<0
00000?ooo`3oool0CP3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00L0oooo0P00
000E0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0503oool001T0oooo00<00000
0?ooo`3oool00P0000030?ooo`030000003oool0oooo01T0oooo00<000000?ooo`3oool00`3oool0
0`000000oooo0?ooo`0<0?ooo`030000003oool0oooo01`0oooo00<000000?ooo`0000004`3oool0
1@000000oooo0?ooo`3oool0000000`0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?oo
o`070?ooo`030000003oool0000000`0oooo00<000000?ooo`3oool0103oool01@000000oooo0?oo
o`3oool0000000h0oooo00<000000?ooo`000000:P3oool010000000oooo0?ooo`00000A0?ooo`03
0000003oool0oooo01<0oooo00<000000?ooo`3oool00P3oool00`000000oooo000000030?ooo`03
0000003oool0oooo00`0oooo00<000000?ooo`3oool03`3oool00`000000oooo0?ooo`0C0?ooo`03
0000003oool0oooo01H0oooo00<000000?ooo`3oool0;@3oool00`000000oooo0?ooo`060?ooo`03
0000003oool0oooo01D0oooo00<000000?ooo`3oool00P0000060?ooo`050000003oool0oooo0?oo
o`0000001P3oool00`000000oooo0?ooo`0C0?ooo`030000003oool0oooo00P0oooo00<000000?oo
o`3oool00P3oool00`000000oooo0000000>0?ooo`040000003oool0oooo000000D0oooo00<00000
0?ooo`3oool0:`3oool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo04h0oooo00<00000
0?ooo`3oool01@3oool00`000000oooo0?ooo`070?ooo`8000005@3oool00`000000oooo0?ooo`03
0?ooo`030000003oool0oooo01@0oooo000D0?ooogL0ool03P000?oo0?oo0?l0ool0EP3oo`0D0?oo
o`006@3oool00`000000oooo0?ooo`02000000<0oooo00<000000?ooo`3oool06@3oool00`000000
oooo0?ooo`030?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool0703oool00`000000
oooo0000000C0?ooo`050000003oool0oooo0?ooo`000000303oool00`000000oooo0?ooo`050?oo
o`030000003oool0oooo00L0oooo00<000000?ooo`000000303oool00`000000oooo0?ooo`040?oo
o`050000003oool0oooo0?ooo`0000003P3oool00`000000oooo0000000Z0?ooo`040000003oool0
oooo00000140oooo00<000000?ooo`3oool04`3oool00`000000oooo0?ooo`020?ooo`030000003o
ool0000000<0oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`0?0?ooo`030000003o
ool0oooo01<0oooo00<000000?ooo`3oool05P3oool00`000000oooo0?ooo`0]0?ooo`030000003o
ool0oooo00H0oooo00<000000?ooo`3oool05@3oool00`000000oooo0?ooo`02000000H0oooo00D0
00000?ooo`3oool0oooo000000060?ooo`030000003oool0oooo01<0oooo00<000000?ooo`3oool0
203oool00`000000oooo0?ooo`020?ooo`030000003oool0000000h0oooo00@000000?ooo`3oool0
00001@3oool00`000000oooo0?ooo`0[0?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3o
ool0CP3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00L0oooo0P00000E0?ooo`03
0000003oool0oooo00<0oooo00<000000?ooo`3oool0503oool001T0oooo00<000000?ooo`3oool0
0P0000030?ooo`030000003oool0oooo01T0oooo00<000000?ooo`3oool00`3oool00`000000oooo
0?ooo`0<0?ooo`030000003oool0oooo01`0oooo00<000000?ooo`0000004`3oool01@000000oooo
0?ooo`3oool0000000`0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`070?ooo`03
0000003oool0000000`0oooo00<000000?ooo`3oool0103oool01@000000oooo0?ooo`3oool00000
00h0oooo00<000000?ooo`000000:P3oool010000000oooo0?ooo`00000A0?ooo`030000003oool0
oooo01<0oooo00<000000?ooo`3oool00P3oool00`000000oooo000000030?ooo`030000003oool0
oooo00`0oooo00<000000?ooo`3oool03`3oool00`000000oooo0?ooo`0C0?ooo`030000003oool0
oooo01H0oooo00<000000?ooo`3oool0;@3oool00`000000oooo0?ooo`060?ooo`030000003oool0
oooo01D0oooo00<000000?ooo`3oool00P0000060?ooo`050000003oool0oooo0?ooo`0000001P3o
ool00`000000oooo0?ooo`0C0?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool00P3o
ool00`000000oooo0000000>0?ooo`040000003oool0oooo000000D0oooo00<000000?ooo`3oool0
:`3oool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo04h0oooo00<000000?ooo`3oool0
1@3oool00`000000oooo0?ooo`070?ooo`8000005@3oool00`000000oooo0?ooo`030?ooo`030000
003oool0oooo01@0oooo000I0?ooo`030000003oool0oooo008000000`3oool00`000000oooo0?oo
o`0I0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0303oool00`000000oooo0?oo
o`0L0?ooo`030000003oool0000001<0oooo00D000000?ooo`3oool0oooo0000000<0?ooo`030000
003oool0oooo00D0oooo00<000000?ooo`3oool01`3oool00`000000oooo0000000<0?ooo`030000
003oool0oooo00@0oooo00D000000?ooo`3oool0oooo0000000>0?ooo`030000003oool0000002X0
oooo00@000000?ooo`3oool000004@3oool00`000000oooo0?ooo`0C0?ooo`030000003oool0oooo
0080oooo00<000000?ooo`0000000`3oool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo
00l0oooo00<000000?ooo`3oool04`3oool00`000000oooo0?ooo`0F0?ooo`030000003oool0oooo
02d0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`0E0?ooo`030000003oool0oooo
008000001P3oool01@000000oooo0?ooo`3oool0000000H0oooo00<000000?ooo`3oool04`3oool0
0`000000oooo0?ooo`080?ooo`030000003oool0oooo0080oooo00<000000?ooo`0000003P3oool0
10000000oooo0?ooo`0000050?ooo`030000003oool0oooo02/0oooo00<000000?ooo`3oool0303o
ool00`000000oooo0?ooo`1>0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool01`3o
ool2000001D0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`0D0?ooo`006@3oool0
0`000000oooo0?ooo`02000000<0oooo00<000000?ooo`3oool06@3oool00`000000oooo0?ooo`03
0?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool0703oool00`000000oooo0000000C
0?ooo`050000003oool0oooo0?ooo`000000303oool00`000000oooo0?ooo`050?ooo`030000003o
ool0oooo00L0oooo00<000000?ooo`000000303oool00`000000oooo0?ooo`040?ooo`050000003o
ool0oooo0?ooo`0000003P3oool00`000000oooo0000000Z0?ooo`040000003oool0oooo00000140
oooo00<000000?ooo`3oool04`3oool00`000000oooo0?ooo`020?ooo`030000003oool0000000<0
oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`0?0?ooo`030000003oool0oooo01<0
oooo00<000000?ooo`3oool05P3oool00`000000oooo0?ooo`0]0?ooo`030000003oool0oooo00H0
oooo00<000000?ooo`3oool05@3oool00`000000oooo0?ooo`02000000H0oooo00D000000?ooo`3o
ool0oooo000000060?ooo`030000003oool0oooo01<0oooo00<000000?ooo`3oool0203oool00`00
0000oooo0?ooo`020?ooo`030000003oool0000000h0oooo00@000000?ooo`3oool000001@3oool0
0`000000oooo0?ooo`0[0?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool0CP3oool0
0`000000oooo0?ooo`050?ooo`030000003oool0oooo00L0oooo0P00000E0?ooo`030000003oool0
oooo00<0oooo00<000000?ooo`3oool0503oool001T0oooo00<000000?ooo`3oool00P0000030?oo
o`030000003oool0oooo01T0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`0<0?oo
o`030000003oool0oooo01`0oooo00<000000?ooo`0000004`3oool01@000000oooo0?ooo`3oool0
000000`0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`070?ooo`030000003oool0
000000`0oooo00<000000?ooo`3oool0103oool01@000000oooo0?ooo`3oool0000000h0oooo00<0
00000?ooo`000000:P3oool010000000oooo0?ooo`00000A0?ooo`030000003oool0oooo01<0oooo
00<000000?ooo`3oool00P3oool00`000000oooo000000030?ooo`030000003oool0oooo00`0oooo
00<000000?ooo`3oool03`3oool00`000000oooo0?ooo`0C0?ooo`030000003oool0oooo01H0oooo
00<000000?ooo`3oool0;@3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo01D0oooo
00<000000?ooo`3oool00P0000060?ooo`050000003oool0oooo0?ooo`0000001P3oool00`000000
oooo0?ooo`0C0?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool00P3oool00`000000
oooo0000000>0?ooo`040000003oool0oooo000000D0oooo00<000000?ooo`3oool0:`3oool00`00
0000oooo0?ooo`0<0?ooo`030000003oool0oooo04h0oooo00<000000?ooo`3oool01@3oool00`00
0000oooo0?ooo`070?ooo`8000005@3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo
01@0oooo000I0?ooo`030000003oool0oooo008000000`3oool00`000000oooo0?ooo`0I0?ooo`03
0000003oool0oooo00<0oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`0L0?ooo`03
0000003oool0000001<0oooo00D000000?ooo`3oool0oooo0000000<0?ooo`030000003oool0oooo
00D0oooo00<000000?ooo`3oool01`3oool00`000000oooo0000000<0?ooo`030000003oool0oooo
00@0oooo00D000000?ooo`3oool0oooo0000000>0?ooo`030000003oool0000002X0oooo00@00000
0?ooo`3oool000004@3oool00`000000oooo0?ooo`0C0?ooo`030000003oool0oooo0080oooo00<0
00000?ooo`0000000`3oool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo00l0oooo00<0
00000?ooo`3oool04`3oool00`000000oooo0?ooo`0F0?ooo`030000003oool0oooo02d0oooo00<0
00000?ooo`3oool01P3oool00`000000oooo0?ooo`0E0?ooo`030000003oool0oooo008000001P3o
ool01@000000oooo0?ooo`3oool0000000H0oooo00<000000?ooo`3oool04`3oool00`000000oooo
0?ooo`080?ooo`030000003oool0oooo0080oooo00<000000?ooo`0000003P3oool010000000oooo
0?ooo`0000050?ooo`030000003oool0oooo02/0oooo00<000000?ooo`3oool0303oool00`000000
oooo0?ooo`1>0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool01`3oool2000001D0
oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`0D0?ooo`006@3oool00`000000oooo
0?ooo`02000000<0oooo00<000000?ooo`3oool06@3oool00`000000oooo0?ooo`030?ooo`030000
003oool0oooo00`0oooo00<000000?ooo`3oool0703oool00`000000oooo0000000C0?ooo`050000
003oool0oooo0?ooo`000000303oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00L0
oooo00<000000?ooo`000000303oool00`000000oooo0?ooo`040?ooo`050000003oool0oooo0?oo
o`0000003P3oool00`000000oooo0000000Z0?ooo`040000003oool0oooo00000140oooo00<00000
0?ooo`3oool04`3oool00`000000oooo0?ooo`020?ooo`030000003oool0000000<0oooo00<00000
0?ooo`3oool0303oool00`000000oooo0?ooo`0?0?ooo`030000003oool0oooo01<0oooo00<00000
0?ooo`3oool05P3oool00`000000oooo0?ooo`0]0?ooo`030000003oool0oooo00H0oooo00<00000
0?ooo`3oool05@3oool00`000000oooo0?ooo`02000000H0oooo00D000000?ooo`3oool0oooo0000
00060?ooo`030000003oool0oooo01<0oooo00<000000?ooo`3oool0203oool00`000000oooo0?oo
o`020?ooo`030000003oool0000000h0oooo00@000000?ooo`3oool000001@3oool00`000000oooo
0?ooo`0[0?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool0CP3oool00`000000oooo
0?ooo`050?ooo`030000003oool0oooo00L0oooo0P00000E0?ooo`030000003oool0oooo00<0oooo
00<000000?ooo`3oool0503oool001@0ooooV03oo`0>0000ool0ool0o`3oo`0e0?oo01@0oooo000I
0?ooo`030000003oool0oooo008000000`3oool00`000000oooo0?ooo`0I0?ooo`030000003oool0
oooo00<0oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`0L0?ooo`030000003oool0
000001<0oooo00D000000?ooo`3oool0oooo0000000<0?ooo`030000003oool0oooo00D0oooo00<0
00000?ooo`3oool01`3oool00`000000oooo0000000<0?ooo`030000003oool0oooo00@0oooo00D0
00000?ooo`3oool0oooo0000000>0?ooo`030000003oool0000002X0oooo00@000000?ooo`3oool0
00004@3oool00`000000oooo0?ooo`0C0?ooo`030000003oool0oooo0080oooo00<000000?ooo`00
00000`3oool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo00l0oooo00<000000?ooo`3o
ool04`3oool00`000000oooo0?ooo`0F0?ooo`030000003oool0oooo02d0oooo00<000000?ooo`3o
ool01P3oool00`000000oooo0?ooo`0E0?ooo`030000003oool0oooo008000001P3oool01@000000
oooo0?ooo`3oool0000000H0oooo00<000000?ooo`3oool04`3oool00`000000oooo0?ooo`080?oo
o`030000003oool0oooo0080oooo00<000000?ooo`0000003P3oool010000000oooo0?ooo`000005
0?ooo`030000003oool0oooo02/0oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`1>
0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool01`3oool2000001D0oooo00<00000
0?ooo`3oool00`3oool00`000000oooo0?ooo`0D0?ooo`006@3oool00`000000oooo0?ooo`020000
00<0oooo00<000000?ooo`3oool06@3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo
00`0oooo00<000000?ooo`3oool0703oool00`000000oooo0000000C0?ooo`050000003oool0oooo
0?ooo`000000303oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00L0oooo00<00000
0?ooo`000000303oool00`000000oooo0?ooo`040?ooo`050000003oool0oooo0?ooo`0000003P3o
ool00`000000oooo0000000Z0?ooo`040000003oool0oooo00000140oooo00<000000?ooo`3oool0
4`3oool00`000000oooo0?ooo`020?ooo`030000003oool0000000<0oooo00<000000?ooo`3oool0
303oool00`000000oooo0?ooo`0?0?ooo`030000003oool0oooo01<0oooo00<000000?ooo`3oool0
5P3oool00`000000oooo0?ooo`0]0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool0
5@3oool00`000000oooo0?ooo`02000000H0oooo00D000000?ooo`3oool0oooo000000060?ooo`03
0000003oool0oooo01<0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`020?ooo`03
0000003oool0000000h0oooo00@000000?ooo`3oool000001@3oool00`000000oooo0?ooo`0[0?oo
o`030000003oool0oooo00`0oooo00<000000?ooo`3oool0CP3oool00`000000oooo0?ooo`050?oo
o`030000003oool0oooo00L0oooo0P00000E0?ooo`030000003oool0oooo00<0oooo00<000000?oo
o`3oool0503oool001T0oooo00<000000?ooo`3oool00P0000030?ooo`030000003oool0oooo01T0
oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo01`0
oooo00<000000?ooo`0000004`3oool01@000000oooo0?ooo`3oool0000000`0oooo00<000000?oo
o`3oool01@3oool00`000000oooo0?ooo`070?ooo`030000003oool0000000`0oooo00<000000?oo
o`3oool0103oool01@000000oooo0?ooo`3oool0000000h0oooo00<000000?ooo`000000:P3oool0
10000000oooo0?ooo`00000A0?ooo`030000003oool0oooo01<0oooo00<000000?ooo`3oool00P3o
ool00`000000oooo000000030?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool03`3o
ool00`000000oooo0?ooo`0C0?ooo`030000003oool0oooo01H0oooo00<000000?ooo`3oool0;@3o
ool00`000000oooo0?ooo`060?ooo`030000003oool0oooo01D0oooo00<000000?ooo`3oool00P00
00060?ooo`050000003oool0oooo0?ooo`0000001P3oool00`000000oooo0?ooo`0C0?ooo`030000
003oool0oooo00P0oooo00<000000?ooo`3oool00P3oool00`000000oooo0000000>0?ooo`040000
003oool0oooo000000D0oooo00<000000?ooo`3oool0:`3oool00`000000oooo0?ooo`0<0?ooo`03
0000003oool0oooo04h0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`070?ooo`80
00005@3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo01@0oooo000I0?ooo`030000
003oool0oooo008000000`3oool00`000000oooo0?ooo`0I0?ooo`030000003oool0oooo00<0oooo
00<000000?ooo`3oool0303oool00`000000oooo0?ooo`0L0?ooo`030000003oool0000001<0oooo
00D000000?ooo`3oool0oooo0000000<0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3o
ool01`3oool00`000000oooo0000000<0?ooo`030000003oool0oooo00@0oooo00D000000?ooo`3o
ool0oooo0000000>0?ooo`030000003oool0000002X0oooo00@000000?ooo`3oool000004@3oool0
0`000000oooo0?ooo`0C0?ooo`030000003oool0oooo0080oooo00<000000?ooo`0000000`3oool0
0`000000oooo0?ooo`0<0?ooo`030000003oool0oooo00l0oooo00<000000?ooo`3oool04`3oool0
0`000000oooo0?ooo`0F0?ooo`030000003oool0oooo02d0oooo00<000000?ooo`3oool01P3oool0
0`000000oooo0?ooo`0E0?ooo`030000003oool0oooo008000001P3oool01@000000oooo0?ooo`3o
ool0000000H0oooo00<000000?ooo`3oool04`3oool00`000000oooo0?ooo`080?ooo`030000003o
ool0oooo0080oooo00<000000?ooo`0000003P3oool010000000oooo0?ooo`0000050?ooo`030000
003oool0oooo02/0oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`1>0?ooo`030000
003oool0oooo00D0oooo00<000000?ooo`3oool01`3oool2000001D0oooo00<000000?ooo`3oool0
0`3oool00`000000oooo0?ooo`0D0?ooo`006@3oool00`000000oooo0?ooo`02000000<0oooo00<0
00000?ooo`3oool06@3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00`0oooo00<0
00000?ooo`3oool0703oool00`000000oooo0000000C0?ooo`050000003oool0oooo0?ooo`000000
303oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00L0oooo00<000000?ooo`000000
303oool00`000000oooo0?ooo`040?ooo`050000003oool0oooo0?ooo`0000003P3oool00`000000
oooo0000000Z0?ooo`040000003oool0oooo00000140oooo00<000000?ooo`3oool04`3oool00`00
0000oooo0?ooo`020?ooo`030000003oool0000000<0oooo00<000000?ooo`3oool0303oool00`00
0000oooo0?ooo`0?0?ooo`030000003oool0oooo01<0oooo00<000000?ooo`3oool05P3oool00`00
0000oooo0?ooo`0]0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool05@3oool00`00
0000oooo0?ooo`02000000H0oooo00D000000?ooo`3oool0oooo000000060?ooo`030000003oool0
oooo01<0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`020?ooo`030000003oool0
000000h0oooo00@000000?ooo`3oool000001@3oool00`000000oooo0?ooo`0[0?ooo`030000003o
ool0oooo00`0oooo00<000000?ooo`3oool0CP3oool00`000000oooo0?ooo`050?ooo`030000003o
ool0oooo00L0oooo0P00000E0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0503o
ool001T0oooo00<000000?ooo`3oool00P0000030?ooo`030000003oool0oooo01T0oooo00<00000
0?ooo`3oool00`3oool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo01`0oooo00<00000
0?ooo`0000004`3oool01@000000oooo0?ooo`3oool0000000`0oooo00<000000?ooo`3oool01@3o
ool00`000000oooo0?ooo`070?ooo`030000003oool0000000`0oooo00<000000?ooo`3oool0103o
ool01@000000oooo0?ooo`3oool0000000h0oooo00<000000?ooo`000000:P3oool010000000oooo
0?ooo`00000A0?ooo`030000003oool0oooo01<0oooo00<000000?ooo`3oool00P3oool00`000000
oooo000000030?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool03`3oool00`000000
oooo0?ooo`0C0?ooo`030000003oool0oooo01H0oooo00<000000?ooo`3oool0;@3oool00`000000
oooo0?ooo`060?ooo`030000003oool0oooo01D0oooo00<000000?ooo`3oool00P0000060?ooo`05
0000003oool0oooo0?ooo`0000001P3oool00`000000oooo0?ooo`0C0?ooo`030000003oool0oooo
00P0oooo00<000000?ooo`3oool00P3oool00`000000oooo0000000>0?ooo`040000003oool0oooo
000000D0oooo00<000000?ooo`3oool0:`3oool00`000000oooo0?ooo`0<0?ooo`030000003oool0
oooo04h0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`070?ooo`8000005@3oool0
0`000000oooo0?ooo`030?ooo`030000003oool0oooo01@0oooo000D0?ooool0ool0L`3oo`0a0000
ocH0ool05`000?oY0?oo01@0oooo000I0?ooo`030000003oool0oooo008000000`3oool00`000000
oooo0?ooo`0I0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0303oool00`000000
oooo0?ooo`0L0?ooo`030000003oool0000001<0oooo00D000000?ooo`3oool0oooo0000000<0?oo
o`030000003oool0oooo00D0oooo00<000000?ooo`3oool01`3oool00`000000oooo0000000<0?oo
o`030000003oool0oooo00@0oooo00D000000?ooo`3oool0oooo0000000>0?ooo`030000003oool0
000002X0oooo00@000000?ooo`3oool000004@3oool00`000000oooo0?ooo`0C0?ooo`030000003o
ool0oooo0080oooo00<000000?ooo`0000000`3oool00`000000oooo0?ooo`0<0?ooo`030000003o
ool0oooo00l0oooo00<000000?ooo`3oool04`3oool00`000000oooo0?ooo`0F0?ooo`030000003o
ool0oooo02d0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`0E0?ooo`030000003o
ool0oooo008000001P3oool01@000000oooo0?ooo`3oool0000000H0oooo00<000000?ooo`3oool0
4`3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo0080oooo00<000000?ooo`000000
3P3oool010000000oooo0?ooo`0000050?ooo`030000003oool0oooo02/0oooo00<000000?ooo`3o
ool0303oool00`000000oooo0?ooo`1>0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3o
ool01`3oool2000001D0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`0D0?ooo`00
6@3oool00`000000oooo0?ooo`02000000<0oooo00<000000?ooo`3oool06@3oool00`000000oooo
0?ooo`030?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool0703oool00`000000oooo
0000000C0?ooo`050000003oool0oooo0?ooo`000000303oool00`000000oooo0?ooo`050?ooo`03
0000003oool0oooo00L0oooo00<000000?ooo`000000303oool00`000000oooo0?ooo`040?ooo`05
0000003oool0oooo0?ooo`0000003P3oool00`000000oooo0000000Z0?ooo`040000003oool0oooo
00000140oooo00<000000?ooo`3oool04`3oool00`000000oooo0?ooo`020?ooo`030000003oool0
000000<0oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`0?0?ooo`030000003oool0
oooo01<0oooo00<000000?ooo`3oool05P3oool00`000000oooo0?ooo`0]0?ooo`030000003oool0
oooo00H0oooo00<000000?ooo`3oool05@3oool00`000000oooo0?ooo`02000000H0oooo00D00000
0?ooo`3oool0oooo000000060?ooo`030000003oool0oooo01<0oooo00<000000?ooo`3oool0203o
ool00`000000oooo0?ooo`020?ooo`030000003oool0000000h0oooo00@000000?ooo`3oool00000
1@3oool00`000000oooo0?ooo`0[0?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool0
CP3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00L0oooo0P00000E0?ooo`030000
003oool0oooo00<0oooo00<000000?ooo`3oool0503oool001T0oooo00<000000?ooo`3oool00P00
00030?ooo`030000003oool0oooo01T0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?oo
o`0<0?ooo`030000003oool0oooo01`0oooo00<000000?ooo`0000004`3oool01@000000oooo0?oo
o`3oool0000000`0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`070?ooo`030000
003oool0000000`0oooo00<000000?ooo`3oool0103oool01@000000oooo0?ooo`3oool0000000h0
oooo00<000000?ooo`000000:P3oool010000000oooo0?ooo`00000A0?ooo`030000003oool0oooo
01<0oooo00<000000?ooo`3oool00P3oool00`000000oooo000000030?ooo`030000003oool0oooo
00`0oooo00<000000?ooo`3oool03`3oool00`000000oooo0?ooo`0C0?ooo`030000003oool0oooo
01H0oooo00<000000?ooo`3oool0;@3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo
01D0oooo00<000000?ooo`3oool00P0000060?ooo`050000003oool0oooo0?ooo`0000001P3oool0
0`000000oooo0?ooo`0C0?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool00P3oool0
0`000000oooo0000000>0?ooo`040000003oool0oooo000000D0oooo00<000000?ooo`3oool0:`3o
ool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo04h0oooo00<000000?ooo`3oool01@3o
ool00`000000oooo0?ooo`070?ooo`8000005@3oool00`000000oooo0?ooo`030?ooo`030000003o
ool0oooo01@0oooo000I0?ooo`030000003oool0oooo008000000`3oool00`000000oooo0?ooo`0I
0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`0L
0?ooo`030000003oool0000001<0oooo00D000000?ooo`3oool0oooo0000000<0?ooo`030000003o
ool0oooo00D0oooo00<000000?ooo`3oool01`3oool00`000000oooo0000000<0?ooo`030000003o
ool0oooo00@0oooo00D000000?ooo`3oool0oooo0000000>0?ooo`030000003oool0000002X0oooo
00@000000?ooo`3oool000004@3oool00`000000oooo0?ooo`0C0?ooo`030000003oool0oooo0080
oooo00<000000?ooo`0000000`3oool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo00l0
oooo00<000000?ooo`3oool04`3oool00`000000oooo0?ooo`0F0?ooo`030000003oool0oooo02d0
oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`0E0?ooo`030000003oool0oooo0080
00001P3oool01@000000oooo0?ooo`3oool0000000H0oooo00<000000?ooo`3oool04`3oool00`00
0000oooo0?ooo`080?ooo`030000003oool0oooo0080oooo00<000000?ooo`0000003P3oool01000
0000oooo0?ooo`0000050?ooo`030000003oool0oooo02/0oooo00<000000?ooo`3oool0303oool0
0`000000oooo0?ooo`1>0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool01`3oool2
000001D0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`0D0?ooo`006@3oool00`00
0000oooo0?ooo`02000000<0oooo00<000000?ooo`3oool06@3oool00`000000oooo0?ooo`030?oo
o`030000003oool0oooo00`0oooo00<000000?ooo`3oool0703oool00`000000oooo0000000C0?oo
o`050000003oool0oooo0?ooo`000000303oool00`000000oooo0?ooo`050?ooo`030000003oool0
oooo00L0oooo00<000000?ooo`000000303oool00`000000oooo0?ooo`040?ooo`050000003oool0
oooo0?ooo`0000003P3oool00`000000oooo0000000Z0?ooo`040000003oool0oooo00000140oooo
00<000000?ooo`3oool04`3oool00`000000oooo0?ooo`020?ooo`030000003oool0000000<0oooo
00<000000?ooo`3oool0303oool00`000000oooo0?ooo`0?0?ooo`030000003oool0oooo01<0oooo
00<000000?ooo`3oool05P3oool00`000000oooo0?ooo`0]0?ooo`030000003oool0oooo00H0oooo
00<000000?ooo`3oool05@3oool00`000000oooo0?ooo`02000000H0oooo00D000000?ooo`3oool0
oooo000000060?ooo`030000003oool0oooo01<0oooo00<000000?ooo`3oool0203oool00`000000
oooo0?ooo`020?ooo`030000003oool0000000h0oooo00@000000?ooo`3oool000001@3oool00`00
0000oooo0?ooo`0[0?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool0CP3oool00`00
0000oooo0?ooo`050?ooo`030000003oool0oooo00L0oooo0P00000E0?ooo`030000003oool0oooo
00<0oooo00<000000?ooo`3oool0503oool001T0oooo00<000000?ooo`3oool00P0000030?ooo`03
0000003oool0oooo01T0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`0<0?ooo`03
0000003oool0oooo01`0oooo00<000000?ooo`0000004`3oool01@000000oooo0?ooo`3oool00000
00`0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`070?ooo`030000003oool00000
00`0oooo00<000000?ooo`3oool0103oool01@000000oooo0?ooo`3oool0000000h0oooo00<00000
0?ooo`000000:P3oool010000000oooo0?ooo`00000A0?ooo`030000003oool0oooo01<0oooo00<0
00000?ooo`3oool00P3oool00`000000oooo000000030?ooo`030000003oool0oooo00`0oooo00<0
00000?ooo`3oool03`3oool00`000000oooo0?ooo`0C0?ooo`030000003oool0oooo01H0oooo00<0
00000?ooo`3oool0;@3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo01D0oooo00<0
00000?ooo`3oool00P0000060?ooo`050000003oool0oooo0?ooo`0000001P3oool00`000000oooo
0?ooo`0C0?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool00P3oool00`000000oooo
0000000>0?ooo`040000003oool0oooo000000D0oooo00<000000?ooo`3oool0:`3oool00`000000
oooo0?ooo`0<0?ooo`030000003oool0oooo04h0oooo00<000000?ooo`3oool01@3oool00`000000
oooo0?ooo`070?ooo`8000005@3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo01@0
oooo000I0?ooo`030000003oool0oooo008000000`3oool00`000000oooo0?ooo`0I0?ooo`030000
003oool0oooo00<0oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`0L0?ooo`030000
003oool0000001<0oooo00D000000?ooo`3oool0oooo0000000<0?ooo`030000003oool0oooo00D0
oooo00<000000?ooo`3oool01`3oool00`000000oooo0000000<0?ooo`030000003oool0oooo00@0
oooo00D000000?ooo`3oool0oooo0000000>0?ooo`030000003oool0000002X0oooo00@000000?oo
o`3oool000004@3oool00`000000oooo0?ooo`0C0?ooo`030000003oool0oooo0080oooo00<00000
0?ooo`0000000`3oool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo00l0oooo00<00000
0?ooo`3oool04`3oool00`000000oooo0?ooo`0F0?ooo`030000003oool0oooo02d0oooo00<00000
0?ooo`3oool01P3oool00`000000oooo0?ooo`0E0?ooo`030000003oool0oooo008000001P3oool0
1@000000oooo0?ooo`3oool0000000H0oooo00<000000?ooo`3oool04`3oool00`000000oooo0?oo
o`080?ooo`030000003oool0oooo0080oooo00<000000?ooo`0000003P3oool010000000oooo0?oo
o`0000050?ooo`030000003oool0oooo02/0oooo00<000000?ooo`3oool0303oool00`000000oooo
0?ooo`1>0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool01`3oool2000001D0oooo
00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`0D0?ooo`00503oool50?oo00@0003o9P3o
o`0@0000ool0ool0_03oo`060000omT0ool0503oool00?l0ooooo`3ooooo0?ooo`@0oooo003o0?oo
ool0ooooo`3oool40?ooo`00o`3ooooo0?ooool0oooo103oool00001\
\>"],
  ImageRangeCache->{{{0, 768.375}, {152.875, 0}} -> {-1.38763, -0.0250052, \
0.0686843, 0.00686843}}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(Show[
        PlotSegments[lpList\[LeftDoubleBracket]2500\[RightDoubleBracket], 
          a, {0, 1}], AspectRatio \[Rule] 0.2];\)\)], "Input",
  CellLabel->"In[392]:="],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .2 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.0190476 0.0047619 0.190476 [
[ 0 0 0 0 ]
[ 1 .2 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .2 L
0 .2 L
closepath
clip
newpath
0 0 0 r
.5 Mabswid
[ ] 0 setdash
.02454 .00476 m
.02454 .19524 L
s
.05103 .00476 m
.05103 .19524 L
s
.0532 .00476 m
.0532 .19524 L
s
.09082 .00476 m
.09082 .19524 L
s
.09789 .00476 m
.09789 .19524 L
s
.10473 .00476 m
.10473 .19524 L
s
.13342 .00476 m
.13342 .19524 L
s
.14443 .00476 m
.14443 .19524 L
s
.14563 .00476 m
.14563 .19524 L
s
.14777 .00476 m
.14777 .19524 L
s
.15263 .00476 m
.15263 .19524 L
s
.19622 .00476 m
.19622 .19524 L
s
.20674 .00476 m
.20674 .19524 L
s
.22108 .00476 m
.22108 .19524 L
s
.22298 .00476 m
.22298 .19524 L
s
.22315 .00476 m
.22315 .19524 L
s
.24011 .00476 m
.24011 .19524 L
s
.27255 .00476 m
.27255 .19524 L
s
.27309 .00476 m
.27309 .19524 L
s
.27386 .00476 m
.27386 .19524 L
s
.27459 .00476 m
.27459 .19524 L
s
.28542 .00476 m
.28542 .19524 L
s
.29623 .00476 m
.29623 .19524 L
s
.32157 .00476 m
.32157 .19524 L
s
.35289 .00476 m
.35289 .19524 L
s
.42294 .00476 m
.42294 .19524 L
s
.4971 .00476 m
.4971 .19524 L
s
.49952 .00476 m
.49952 .19524 L
s
.55443 .00476 m
.55443 .19524 L
s
.56904 .00476 m
.56904 .19524 L
s
.58257 .00476 m
.58257 .19524 L
s
.58952 .00476 m
.58952 .19524 L
s
.68231 .00476 m
.68231 .19524 L
s
.70188 .00476 m
.70188 .19524 L
s
.71868 .00476 m
.71868 .19524 L
s
.74228 .00476 m
.74228 .19524 L
s
.75498 .00476 m
.75498 .19524 L
s
.76922 .00476 m
.76922 .19524 L
s
.78037 .00476 m
.78037 .19524 L
s
.80715 .00476 m
.80715 .19524 L
s
.8399 .00476 m
.8399 .19524 L
s
.85037 .00476 m
.85037 .19524 L
s
.85847 .00476 m
.85847 .19524 L
s
.85907 .00476 m
.85907 .19524 L
s
.90911 .00476 m
.90911 .19524 L
s
.92112 .00476 m
.92112 .19524 L
s
.93287 .00476 m
.93287 .19524 L
s
.93625 .00476 m
.93625 .19524 L
s
.93703 .00476 m
.93703 .19524 L
s
.94674 .00476 m
.94674 .19524 L
s
.97355 .00476 m
.97355 .19524 L
s
1 1 0 r
.02381 .00476 m
.97619 .00476 L
s
.02381 .01479 m
.97619 .01479 L
s
.02381 .02481 m
.97619 .02481 L
s
.02381 .03484 m
.97619 .03484 L
s
.02381 .04486 m
.97619 .04486 L
s
.02381 .05489 m
.97619 .05489 L
s
.02381 .06491 m
.97619 .06491 L
s
.02381 .07494 m
.97619 .07494 L
s
.02381 .08496 m
.97619 .08496 L
s
.02381 .09499 m
.97619 .09499 L
s
.02381 .10501 m
.97619 .10501 L
s
.02381 .11504 m
.97619 .11504 L
s
.02381 .12506 m
.97619 .12506 L
s
.02381 .13509 m
.97619 .13509 L
s
.02381 .14511 m
.97619 .14511 L
s
.02381 .15514 m
.97619 .15514 L
s
.02381 .16516 m
.97619 .16516 L
s
.02381 .17519 m
.97619 .17519 L
s
.02381 .18521 m
.97619 .18521 L
s
.02381 .19524 m
.97619 .19524 L
s
0 0 1 r
.15263 .00476 m
.19622 .00476 L
s
.28542 .01479 m
.29623 .01479 L
s
.32157 .01479 m
.35289 .01479 L
s
.42294 .02481 m
.4971 .02481 L
s
.85907 .02481 m
.90911 .02481 L
s
.02381 .03484 m
.02454 .03484 L
s
.10473 .03484 m
.13342 .03484 L
s
.94674 .04486 m
.97355 .04486 L
s
.78037 .05489 m
.80715 .05489 L
s
.09082 .06491 m
.09789 .06491 L
s
.80715 .07494 m
.8399 .07494 L
s
.8399 .08496 m
.85037 .08496 L
s
.85847 .08496 m
.85907 .08496 L
s
.14563 .09499 m
.14777 .09499 L
s
.19622 .09499 m
.20674 .09499 L
s
.22108 .09499 m
.22298 .09499 L
s
.85037 .09499 m
.85847 .09499 L
s
.35289 .10501 m
.42294 .10501 L
s
.68231 .10501 m
.70188 .10501 L
s
.93287 .10501 m
.93625 .10501 L
s
.93703 .10501 m
.94674 .10501 L
s
.97355 .10501 m
.97619 .10501 L
s
.05103 .11504 m
.0532 .11504 L
s
.09789 .12506 m
.10473 .12506 L
s
.29623 .13509 m
.32157 .13509 L
s
.4971 .14511 m
.49952 .14511 L
s
.55443 .14511 m
.56904 .14511 L
s
.58257 .14511 m
.58952 .14511 L
s
.71868 .14511 m
.74228 .14511 L
s
.75498 .14511 m
.76922 .14511 L
s
.49952 .15514 m
.55443 .15514 L
s
.56904 .15514 m
.58257 .15514 L
s
.58952 .15514 m
.68231 .15514 L
s
.70188 .15514 m
.71868 .15514 L
s
.74228 .16516 m
.75498 .16516 L
s
.76922 .16516 m
.78037 .16516 L
s
.92112 .17519 m
.93287 .17519 L
s
.14443 .18521 m
.14563 .18521 L
s
.14777 .18521 m
.15263 .18521 L
s
.20674 .18521 m
.22108 .18521 L
s
.22298 .18521 m
.22315 .18521 L
s
.24011 .18521 m
.27255 .18521 L
s
.27309 .18521 m
.27386 .18521 L
s
.27459 .18521 m
.28542 .18521 L
s
.90911 .18521 m
.92112 .18521 L
s
.93625 .18521 m
.93703 .18521 L
s
.02454 .19524 m
.05103 .19524 L
s
.0532 .19524 m
.09082 .19524 L
s
.13342 .19524 m
.14443 .19524 L
s
.22315 .19524 m
.24011 .19524 L
s
.27255 .19524 m
.27309 .19524 L
s
.27386 .19524 m
.27459 .19524 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[392]:=",
  ImageSize->{789, 157.688},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`4000<E0000WB000`400?l00000o`00003oo`3ooooo
0?ooool0oooo603oool00?l0ooooo`3ooooo0?oooaP0oooo003o0?ooool0ooooo`3ooolH0?ooo`00
o`3ooooo0?ooool0oooo603oool001@0ooooI@3oo`0T0000ool0ool0o`3oo`1U0?oo01D0oooo000E
0?ooo`030000003oool0oooo0180oooo0P00000M0?ooo`030000003oool0oooo0080oooo00<00000
0?ooo`3oool00`3oool00`000000oooo0?ooo`0C0?ooo`030000003oool0oooo00H0oooo0P000000
1@3oool000000?ooo`3oool000000280oooo00<000000?ooo`3oool01@3oool00`000000oooo0?oo
o`080?ooo`<00000303oool00`000000oooo0?ooo`0F0?ooo`<000001`3oool00`000000oooo0?oo
o`060?ooo`030000003oool0oooo0140oooo00<000000?ooo`3oool05@3oool00`000000oooo0?oo
o`0d0?ooo`030000003oool0oooo03L0oooo00<000000?ooo`000000:P3oool00`000000oooo0?oo
o`090?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?oo
o`150?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?oo
o`0?0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool0203oool00`000000oooo0?oo
o`060?ooo`030000003oool0oooo0180oooo00<000000?ooo`3oool05`3oool00`000000oooo0?oo
o`050?ooo`030000003oool0oooo00<0oooo0P00000V0?ooo`030000003oool0oooo00H0oooo00<0
00000?ooo`3oool01`3oool010000000oooo0000000000060?ooo`030000003oool0oooo0180oooo
00<000000?ooo`3oool05P3oool001D0oooo00<000000?ooo`3oool04P3oool2000001d0oooo00<0
00000?ooo`3oool00P3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo01<0oooo00<0
00000?ooo`3oool01P3oool2000000050?ooo`000000oooo0?ooo`0000008P3oool00`000000oooo
0?ooo`050?ooo`030000003oool0oooo00P0oooo0`00000<0?ooo`030000003oool0oooo01H0oooo
0`0000070?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool04@3oool00`000000oooo
0?ooo`0E0?ooo`030000003oool0oooo03@0oooo00<000000?ooo`3oool0=`3oool00`000000oooo
0000000Z0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool01`3oool00`000000oooo
0?ooo`030?ooo`030000003oool0oooo04D0oooo00<000000?ooo`3oool03@3oool00`000000oooo
0?ooo`0:0?ooo`030000003oool0oooo00l0oooo00<000000?ooo`3oool01`3oool00`000000oooo
0?ooo`080?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool04P3oool00`000000oooo
0?ooo`0G0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool00`3oool2000002H0oooo
00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`070?ooo`040000003oool00000000000H0
oooo00<000000?ooo`3oool04P3oool00`000000oooo0?ooo`0F0?ooo`005@3oool00`000000oooo
0?ooo`0B0?ooo`8000007@3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00<0oooo
00<000000?ooo`3oool04`3oool00`000000oooo0?ooo`060?ooo`80000000D0oooo0000003oool0
oooo0000000R0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool0203oool3000000`0
oooo00<000000?ooo`3oool05P3oool3000000L0oooo00<000000?ooo`3oool01P3oool00`000000
oooo0?ooo`0A0?ooo`030000003oool0oooo01D0oooo00<000000?ooo`3oool0=03oool00`000000
oooo0?ooo`0g0?ooo`030000003oool0000002X0oooo00<000000?ooo`3oool02@3oool00`000000
oooo0?ooo`070?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0A@3oool00`000000
oooo0?ooo`0=0?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool03`3oool00`000000
oooo0?ooo`070?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool01P3oool00`000000
oooo0?ooo`0B0?ooo`030000003oool0oooo01L0oooo00<000000?ooo`3oool01@3oool00`000000
oooo0?ooo`030?ooo`8000009P3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00L0
oooo00@000000?ooo`00000000001P3oool00`000000oooo0?ooo`0B0?ooo`030000003oool0oooo
01H0oooo000E0?ooo`030000003oool0oooo0180oooo0P00000M0?ooo`030000003oool0oooo0080
oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`0C0?ooo`030000003oool0oooo00H0
oooo0P0000001@3oool000000?ooo`3oool000000280oooo00<000000?ooo`3oool01@3oool00`00
0000oooo0?ooo`080?ooo`<00000303oool00`000000oooo0?ooo`0F0?ooo`<000001`3oool00`00
0000oooo0?ooo`060?ooo`030000003oool0oooo0140oooo00<000000?ooo`3oool05@3oool00`00
0000oooo0?ooo`0d0?ooo`030000003oool0oooo03L0oooo00<000000?ooo`000000:P3oool00`00
0000oooo0?ooo`090?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool00`3oool00`00
0000oooo0?ooo`150?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool02P3oool00`00
0000oooo0?ooo`0?0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool0203oool00`00
0000oooo0?ooo`060?ooo`030000003oool0oooo0180oooo00<000000?ooo`3oool05`3oool00`00
0000oooo0?ooo`050?ooo`030000003oool0oooo00<0oooo0P00000V0?ooo`030000003oool0oooo
00H0oooo00<000000?ooo`3oool01`3oool010000000oooo0000000000060?ooo`030000003oool0
oooo0180oooo00<000000?ooo`3oool05P3oool001D0oooo00<000000?ooo`3oool04P3oool20000
01d0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo
01<0oooo00<000000?ooo`3oool01P3oool2000000050?ooo`000000oooo0?ooo`0000008P3oool0
0`000000oooo0?ooo`050?ooo`030000003oool0oooo00P0oooo0`00000<0?ooo`030000003oool0
oooo01H0oooo0`0000070?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool04@3oool0
0`000000oooo0?ooo`0E0?ooo`030000003oool0oooo03@0oooo00<000000?ooo`3oool0=`3oool0
0`000000oooo0000000Z0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool01`3oool0
0`000000oooo0?ooo`030?ooo`030000003oool0oooo04D0oooo00<000000?ooo`3oool03@3oool0
0`000000oooo0?ooo`0:0?ooo`030000003oool0oooo00l0oooo00<000000?ooo`3oool01`3oool0
0`000000oooo0?ooo`080?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool04P3oool0
0`000000oooo0?ooo`0G0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool00`3oool2
000002H0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`070?ooo`040000003oool0
0000000000H0oooo00<000000?ooo`3oool04P3oool00`000000oooo0?ooo`0F0?ooo`005@3oool0
0`000000oooo0?ooo`0B0?ooo`8000007@3oool00`000000oooo0?ooo`020?ooo`030000003oool0
oooo00<0oooo00<000000?ooo`3oool04`3oool00`000000oooo0?ooo`060?ooo`80000000D0oooo
0000003oool0oooo0000000R0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool0203o
ool3000000`0oooo00<000000?ooo`3oool05P3oool3000000L0oooo00<000000?ooo`3oool01P3o
ool00`000000oooo0?ooo`0A0?ooo`030000003oool0oooo01D0oooo00<000000?ooo`3oool0=03o
ool00`000000oooo0?ooo`0g0?ooo`030000003oool0000002X0oooo00<000000?ooo`3oool02@3o
ool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0A@3o
ool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool03`3o
ool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool01P3o
ool00`000000oooo0?ooo`0B0?ooo`030000003oool0oooo01L0oooo00<000000?ooo`3oool01@3o
ool00`000000oooo0?ooo`030?ooo`8000009P3oool00`000000oooo0?ooo`060?ooo`030000003o
ool0oooo00L0oooo00@000000?ooo`00000000001P3oool00`000000oooo0?ooo`0B0?ooo`030000
003oool0oooo01H0oooo000D0?ooold0ool02P000?lC0?oo01T0003oo`3oo`3Z0?oo01D0oooo000E
0?ooo`030000003oool0oooo0180oooo0P00000M0?ooo`030000003oool0oooo0080oooo00<00000
0?ooo`3oool00`3oool00`000000oooo0?ooo`0C0?ooo`030000003oool0oooo00H0oooo0P000000
1@3oool000000?ooo`3oool000000280oooo00<000000?ooo`3oool01@3oool00`000000oooo0?oo
o`080?ooo`<00000303oool00`000000oooo0?ooo`0F0?ooo`<000001`3oool00`000000oooo0?oo
o`060?ooo`030000003oool0oooo0140oooo00<000000?ooo`3oool05@3oool00`000000oooo0?oo
o`0d0?ooo`030000003oool0oooo03L0oooo00<000000?ooo`000000:P3oool00`000000oooo0?oo
o`090?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?oo
o`150?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?oo
o`0?0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool0203oool00`000000oooo0?oo
o`060?ooo`030000003oool0oooo0180oooo00<000000?ooo`3oool05`3oool00`000000oooo0?oo
o`050?ooo`030000003oool0oooo00<0oooo0P00000V0?ooo`030000003oool0oooo00H0oooo00<0
00000?ooo`3oool01`3oool010000000oooo0000000000060?ooo`030000003oool0oooo0180oooo
00<000000?ooo`3oool05P3oool001D0oooo00<000000?ooo`3oool04P3oool2000001d0oooo00<0
00000?ooo`3oool00P3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo01<0oooo00<0
00000?ooo`3oool01P3oool2000000050?ooo`000000oooo0?ooo`0000008P3oool00`000000oooo
0?ooo`050?ooo`030000003oool0oooo00P0oooo0`00000<0?ooo`030000003oool0oooo01H0oooo
0`0000070?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool04@3oool00`000000oooo
0?ooo`0E0?ooo`030000003oool0oooo03@0oooo00<000000?ooo`3oool0=`3oool00`000000oooo
0000000Z0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool01`3oool00`000000oooo
0?ooo`030?ooo`030000003oool0oooo04D0oooo00<000000?ooo`3oool03@3oool00`000000oooo
0?ooo`0:0?ooo`030000003oool0oooo00l0oooo00<000000?ooo`3oool01`3oool00`000000oooo
0?ooo`080?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool04P3oool00`000000oooo
0?ooo`0G0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool00`3oool2000002H0oooo
00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`070?ooo`040000003oool00000000000H0
oooo00<000000?ooo`3oool04P3oool00`000000oooo0?ooo`0F0?ooo`005@3oool00`000000oooo
0?ooo`0B0?ooo`8000007@3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00<0oooo
00<000000?ooo`3oool04`3oool00`000000oooo0?ooo`060?ooo`80000000D0oooo0000003oool0
oooo0000000R0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool0203oool3000000`0
oooo00<000000?ooo`3oool05P3oool3000000L0oooo00<000000?ooo`3oool01P3oool00`000000
oooo0?ooo`0A0?ooo`030000003oool0oooo01D0oooo00<000000?ooo`3oool0=03oool00`000000
oooo0?ooo`0g0?ooo`030000003oool0000002X0oooo00<000000?ooo`3oool02@3oool00`000000
oooo0?ooo`070?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0A@3oool00`000000
oooo0?ooo`0=0?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool03`3oool00`000000
oooo0?ooo`070?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool01P3oool00`000000
oooo0?ooo`0B0?ooo`030000003oool0oooo01L0oooo00<000000?ooo`3oool01@3oool00`000000
oooo0?ooo`030?ooo`8000009P3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00L0
oooo00@000000?ooo`00000000001P3oool00`000000oooo0?ooo`0B0?ooo`030000003oool0oooo
01H0oooo000E0?ooo`030000003oool0oooo0180oooo0P00000M0?ooo`030000003oool0oooo0080
oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`0C0?ooo`030000003oool0oooo00H0
oooo0P0000001@3oool000000?ooo`3oool000000280oooo00<000000?ooo`3oool01@3oool00`00
0000oooo0?ooo`080?ooo`<00000303oool00`000000oooo0?ooo`0F0?ooo`<000001`3oool00`00
0000oooo0?ooo`060?ooo`030000003oool0oooo0140oooo00<000000?ooo`3oool05@3oool00`00
0000oooo0?ooo`0d0?ooo`030000003oool0oooo03L0oooo00<000000?ooo`000000:P3oool00`00
0000oooo0?ooo`090?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool00`3oool00`00
0000oooo0?ooo`150?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool02P3oool00`00
0000oooo0?ooo`0?0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool0203oool00`00
0000oooo0?ooo`060?ooo`030000003oool0oooo0180oooo00<000000?ooo`3oool05`3oool00`00
0000oooo0?ooo`050?ooo`030000003oool0oooo00<0oooo0P00000V0?ooo`030000003oool0oooo
00H0oooo00<000000?ooo`3oool01`3oool010000000oooo0000000000060?ooo`030000003oool0
oooo0180oooo00<000000?ooo`3oool05P3oool001D0oooo00<000000?ooo`3oool04P3oool20000
01d0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo
01<0oooo00<000000?ooo`3oool01P3oool2000000050?ooo`000000oooo0?ooo`0000008P3oool0
0`000000oooo0?ooo`050?ooo`030000003oool0oooo00P0oooo0`00000<0?ooo`030000003oool0
oooo01H0oooo0`0000070?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool04@3oool0
0`000000oooo0?ooo`0E0?ooo`030000003oool0oooo03@0oooo00<000000?ooo`3oool0=`3oool0
0`000000oooo0000000Z0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool01`3oool0
0`000000oooo0?ooo`030?ooo`030000003oool0oooo04D0oooo00<000000?ooo`3oool03@3oool0
0`000000oooo0?ooo`0:0?ooo`030000003oool0oooo00l0oooo00<000000?ooo`3oool01`3oool0
0`000000oooo0?ooo`080?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool04P3oool0
0`000000oooo0?ooo`0G0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool00`3oool2
000002H0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`070?ooo`040000003oool0
0000000000H0oooo00<000000?ooo`3oool04P3oool00`000000oooo0?ooo`0F0?ooo`005@3oool0
0`000000oooo0?ooo`0B0?ooo`8000007@3oool00`000000oooo0?ooo`020?ooo`030000003oool0
oooo00<0oooo00<000000?ooo`3oool04`3oool00`000000oooo0?ooo`060?ooo`80000000D0oooo
0000003oool0oooo0000000R0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool0203o
ool3000000`0oooo00<000000?ooo`3oool05P3oool3000000L0oooo00<000000?ooo`3oool01P3o
ool00`000000oooo0?ooo`0A0?ooo`030000003oool0oooo01D0oooo00<000000?ooo`3oool0=03o
ool00`000000oooo0?ooo`0g0?ooo`030000003oool0000002X0oooo00<000000?ooo`3oool02@3o
ool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0A@3o
ool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool03`3o
ool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool01P3o
ool00`000000oooo0?ooo`0B0?ooo`030000003oool0oooo01L0oooo00<000000?ooo`3oool01@3o
ool00`000000oooo0?ooo`030?ooo`8000009P3oool00`000000oooo0?ooo`060?ooo`030000003o
ool0oooo00L0oooo00@000000?ooo`00000000001P3oool00`000000oooo0?ooo`0B0?ooo`030000
003oool0oooo01H0oooo000E0?ooo`030000003oool0oooo0180oooo0P00000M0?ooo`030000003o
ool0oooo0080oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`0C0?ooo`030000003o
ool0oooo00H0oooo0P0000001@3oool000000?ooo`3oool000000280oooo00<000000?ooo`3oool0
1@3oool00`000000oooo0?ooo`080?ooo`<00000303oool00`000000oooo0?ooo`0F0?ooo`<00000
1`3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo0140oooo00<000000?ooo`3oool0
5@3oool00`000000oooo0?ooo`0d0?ooo`030000003oool0oooo03L0oooo00<000000?ooo`000000
:P3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool0
0`3oool00`000000oooo0?ooo`150?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool0
2P3oool00`000000oooo0?ooo`0?0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool0
203oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo0180oooo00<000000?ooo`3oool0
5`3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00<0oooo0P00000V0?ooo`030000
003oool0oooo00H0oooo00<000000?ooo`3oool01`3oool010000000oooo0000000000060?ooo`03
0000003oool0oooo0180oooo00<000000?ooo`3oool05P3oool001@0ooooo`3oo`0j0?oo03/0003o
o`3oo`0L0?oo02P0003o=@3oo`0E0?ooo`005@3oool00`000000oooo0?ooo`0B0?ooo`8000007@3o
ool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool04`3o
ool00`000000oooo0?ooo`060?ooo`80000000D0oooo0000003oool0oooo0000000R0?ooo`030000
003oool0oooo00D0oooo00<000000?ooo`3oool0203oool3000000`0oooo00<000000?ooo`3oool0
5P3oool3000000L0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`0A0?ooo`030000
003oool0oooo01D0oooo00<000000?ooo`3oool0=03oool00`000000oooo0?ooo`0g0?ooo`030000
003oool0000002X0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`070?ooo`030000
003oool0oooo00<0oooo00<000000?ooo`3oool0A@3oool00`000000oooo0?ooo`0=0?ooo`030000
003oool0oooo00X0oooo00<000000?ooo`3oool03`3oool00`000000oooo0?ooo`070?ooo`030000
003oool0oooo00P0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`0B0?ooo`030000
003oool0oooo01L0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`030?ooo`800000
9P3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00L0oooo00@000000?ooo`000000
00001P3oool00`000000oooo0?ooo`0B0?ooo`030000003oool0oooo01H0oooo000E0?ooo`030000
003oool0oooo0180oooo0P00000M0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0
0`3oool00`000000oooo0?ooo`0C0?ooo`030000003oool0oooo00H0oooo0P0000001@3oool00000
0?ooo`3oool000000280oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`080?ooo`<0
0000303oool00`000000oooo0?ooo`0F0?ooo`<000001`3oool00`000000oooo0?ooo`060?ooo`03
0000003oool0oooo0140oooo00<000000?ooo`3oool05@3oool00`000000oooo0?ooo`0d0?ooo`03
0000003oool0oooo03L0oooo00<000000?ooo`000000:P3oool00`000000oooo0?ooo`090?ooo`03
0000003oool0oooo00L0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`150?ooo`03
0000003oool0oooo00d0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`0?0?ooo`03
0000003oool0oooo00L0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`060?ooo`03
0000003oool0oooo0180oooo00<000000?ooo`3oool05`3oool00`000000oooo0?ooo`050?ooo`03
0000003oool0oooo00<0oooo0P00000V0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3o
ool01`3oool010000000oooo0000000000060?ooo`030000003oool0oooo0180oooo00<000000?oo
o`3oool05P3oool001D0oooo00<000000?ooo`3oool04P3oool2000001d0oooo00<000000?ooo`3o
ool00P3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo01<0oooo00<000000?ooo`3o
ool01P3oool2000000050?ooo`000000oooo0?ooo`0000008P3oool00`000000oooo0?ooo`050?oo
o`030000003oool0oooo00P0oooo0`00000<0?ooo`030000003oool0oooo01H0oooo0`0000070?oo
o`030000003oool0oooo00H0oooo00<000000?ooo`3oool04@3oool00`000000oooo0?ooo`0E0?oo
o`030000003oool0oooo03@0oooo00<000000?ooo`3oool0=`3oool00`000000oooo0000000Z0?oo
o`030000003oool0oooo00T0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`030?oo
o`030000003oool0oooo04D0oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`0:0?oo
o`030000003oool0oooo00l0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`080?oo
o`030000003oool0oooo00H0oooo00<000000?ooo`3oool04P3oool00`000000oooo0?ooo`0G0?oo
o`030000003oool0oooo00D0oooo00<000000?ooo`3oool00`3oool2000002H0oooo00<000000?oo
o`3oool01P3oool00`000000oooo0?ooo`070?ooo`040000003oool00000000000H0oooo00<00000
0?ooo`3oool04P3oool00`000000oooo0?ooo`0F0?ooo`005@3oool00`000000oooo0?ooo`0B0?oo
o`8000007@3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00<0oooo00<000000?oo
o`3oool04`3oool00`000000oooo0?ooo`060?ooo`80000000D0oooo0000003oool0oooo0000000R
0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool0203oool3000000`0oooo00<00000
0?ooo`3oool05P3oool3000000L0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`0A
0?ooo`030000003oool0oooo01D0oooo00<000000?ooo`3oool0=03oool00`000000oooo0?ooo`0g
0?ooo`030000003oool0000002X0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`07
0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0A@3oool00`000000oooo0?ooo`0=
0?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool03`3oool00`000000oooo0?ooo`07
0?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`0B
0?ooo`030000003oool0oooo01L0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`03
0?ooo`8000009P3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00L0oooo00@00000
0?ooo`00000000001P3oool00`000000oooo0?ooo`0B0?ooo`030000003oool0oooo01H0oooo000E
0?ooo`030000003oool0oooo0180oooo0P00000M0?ooo`030000003oool0oooo0080oooo00<00000
0?ooo`3oool00`3oool00`000000oooo0?ooo`0C0?ooo`030000003oool0oooo00H0oooo0P000000
1@3oool000000?ooo`3oool000000280oooo00<000000?ooo`3oool01@3oool00`000000oooo0?oo
o`080?ooo`<00000303oool00`000000oooo0?ooo`0F0?ooo`<000001`3oool00`000000oooo0?oo
o`060?ooo`030000003oool0oooo0140oooo00<000000?ooo`3oool05@3oool00`000000oooo0?oo
o`0d0?ooo`030000003oool0oooo03L0oooo00<000000?ooo`000000:P3oool00`000000oooo0?oo
o`090?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?oo
o`150?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?oo
o`0?0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool0203oool00`000000oooo0?oo
o`060?ooo`030000003oool0oooo0180oooo00<000000?ooo`3oool05`3oool00`000000oooo0?oo
o`050?ooo`030000003oool0oooo00<0oooo0P00000V0?ooo`030000003oool0oooo00H0oooo00<0
00000?ooo`3oool01`3oool010000000oooo0000000000060?ooo`030000003oool0oooo0180oooo
00<000000?ooo`3oool05P3oool001D0oooo00<000000?ooo`3oool04P3oool2000001d0oooo00<0
00000?ooo`3oool00P3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo01<0oooo00<0
00000?ooo`3oool01P3oool2000000050?ooo`000000oooo0?ooo`0000008P3oool00`000000oooo
0?ooo`050?ooo`030000003oool0oooo00P0oooo0`00000<0?ooo`030000003oool0oooo01H0oooo
0`0000070?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool04@3oool00`000000oooo
0?ooo`0E0?ooo`030000003oool0oooo03@0oooo00<000000?ooo`3oool0=`3oool00`000000oooo
0000000Z0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool01`3oool00`000000oooo
0?ooo`030?ooo`030000003oool0oooo04D0oooo00<000000?ooo`3oool03@3oool00`000000oooo
0?ooo`0:0?ooo`030000003oool0oooo00l0oooo00<000000?ooo`3oool01`3oool00`000000oooo
0?ooo`080?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool04P3oool00`000000oooo
0?ooo`0G0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool00`3oool2000002H0oooo
00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`070?ooo`040000003oool00000000000H0
oooo00<000000?ooo`3oool04P3oool00`000000oooo0?ooo`0F0?ooo`005@3oool00`000000oooo
0?ooo`0B0?ooo`8000007@3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00<0oooo
00<000000?ooo`3oool04`3oool00`000000oooo0?ooo`060?ooo`80000000D0oooo0000003oool0
oooo0000000R0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool0203oool3000000`0
oooo00<000000?ooo`3oool05P3oool3000000L0oooo00<000000?ooo`3oool01P3oool00`000000
oooo0?ooo`0A0?ooo`030000003oool0oooo01D0oooo00<000000?ooo`3oool0=03oool00`000000
oooo0?ooo`0g0?ooo`030000003oool0000002X0oooo00<000000?ooo`3oool02@3oool00`000000
oooo0?ooo`070?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0A@3oool00`000000
oooo0?ooo`0=0?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool03`3oool00`000000
oooo0?ooo`070?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool01P3oool00`000000
oooo0?ooo`0B0?ooo`030000003oool0oooo01L0oooo00<000000?ooo`3oool01@3oool00`000000
oooo0?ooo`030?ooo`8000009P3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00L0
oooo00@000000?ooo`00000000001P3oool00`000000oooo0?ooo`0B0?ooo`030000003oool0oooo
01H0oooo000D0?ooo`80003o?P3oo`0G0000ool0ool0o`3oo`2G0?oo01D0oooo000E0?ooo`030000
003oool0oooo0180oooo0P00000M0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0
0`3oool00`000000oooo0?ooo`0C0?ooo`030000003oool0oooo00H0oooo0P0000001@3oool00000
0?ooo`3oool000000280oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`080?ooo`<0
0000303oool00`000000oooo0?ooo`0F0?ooo`<000001`3oool00`000000oooo0?ooo`060?ooo`03
0000003oool0oooo0140oooo00<000000?ooo`3oool05@3oool00`000000oooo0?ooo`0d0?ooo`03
0000003oool0oooo03L0oooo00<000000?ooo`000000:P3oool00`000000oooo0?ooo`090?ooo`03
0000003oool0oooo00L0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`150?ooo`03
0000003oool0oooo00d0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`0?0?ooo`03
0000003oool0oooo00L0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`060?ooo`03
0000003oool0oooo0180oooo00<000000?ooo`3oool05`3oool00`000000oooo0?ooo`050?ooo`03
0000003oool0oooo00<0oooo0P00000V0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3o
ool01`3oool010000000oooo0000000000060?ooo`030000003oool0oooo0180oooo00<000000?oo
o`3oool05P3oool001D0oooo00<000000?ooo`3oool04P3oool2000001d0oooo00<000000?ooo`3o
ool00P3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo01<0oooo00<000000?ooo`3o
ool01P3oool2000000050?ooo`000000oooo0?ooo`0000008P3oool00`000000oooo0?ooo`050?oo
o`030000003oool0oooo00P0oooo0`00000<0?ooo`030000003oool0oooo01H0oooo0`0000070?oo
o`030000003oool0oooo00H0oooo00<000000?ooo`3oool04@3oool00`000000oooo0?ooo`0E0?oo
o`030000003oool0oooo03@0oooo00<000000?ooo`3oool0=`3oool00`000000oooo0000000Z0?oo
o`030000003oool0oooo00T0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`030?oo
o`030000003oool0oooo04D0oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`0:0?oo
o`030000003oool0oooo00l0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`080?oo
o`030000003oool0oooo00H0oooo00<000000?ooo`3oool04P3oool00`000000oooo0?ooo`0G0?oo
o`030000003oool0oooo00D0oooo00<000000?ooo`3oool00`3oool2000002H0oooo00<000000?oo
o`3oool01P3oool00`000000oooo0?ooo`070?ooo`040000003oool00000000000H0oooo00<00000
0?ooo`3oool04P3oool00`000000oooo0?ooo`0F0?ooo`005@3oool00`000000oooo0?ooo`0B0?oo
o`8000007@3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00<0oooo00<000000?oo
o`3oool04`3oool00`000000oooo0?ooo`060?ooo`80000000D0oooo0000003oool0oooo0000000R
0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool0203oool3000000`0oooo00<00000
0?ooo`3oool05P3oool3000000L0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`0A
0?ooo`030000003oool0oooo01D0oooo00<000000?ooo`3oool0=03oool00`000000oooo0?ooo`0g
0?ooo`030000003oool0000002X0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`07
0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0A@3oool00`000000oooo0?ooo`0=
0?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool03`3oool00`000000oooo0?ooo`07
0?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`0B
0?ooo`030000003oool0oooo01L0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`03
0?ooo`8000009P3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00L0oooo00@00000
0?ooo`00000000001P3oool00`000000oooo0?ooo`0B0?ooo`030000003oool0oooo01H0oooo000E
0?ooo`030000003oool0oooo0180oooo0P00000M0?ooo`030000003oool0oooo0080oooo00<00000
0?ooo`3oool00`3oool00`000000oooo0?ooo`0C0?ooo`030000003oool0oooo00H0oooo0P000000
1@3oool000000?ooo`3oool000000280oooo00<000000?ooo`3oool01@3oool00`000000oooo0?oo
o`080?ooo`<00000303oool00`000000oooo0?ooo`0F0?ooo`<000001`3oool00`000000oooo0?oo
o`060?ooo`030000003oool0oooo0140oooo00<000000?ooo`3oool05@3oool00`000000oooo0?oo
o`0d0?ooo`030000003oool0oooo03L0oooo00<000000?ooo`000000:P3oool00`000000oooo0?oo
o`090?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?oo
o`150?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?oo
o`0?0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool0203oool00`000000oooo0?oo
o`060?ooo`030000003oool0oooo0180oooo00<000000?ooo`3oool05`3oool00`000000oooo0?oo
o`050?ooo`030000003oool0oooo00<0oooo0P00000V0?ooo`030000003oool0oooo00H0oooo00<0
00000?ooo`3oool01`3oool010000000oooo0000000000060?ooo`030000003oool0oooo0180oooo
00<000000?ooo`3oool05P3oool001D0oooo00<000000?ooo`3oool04P3oool2000001d0oooo00<0
00000?ooo`3oool00P3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo01<0oooo00<0
00000?ooo`3oool01P3oool2000000050?ooo`000000oooo0?ooo`0000008P3oool00`000000oooo
0?ooo`050?ooo`030000003oool0oooo00P0oooo0`00000<0?ooo`030000003oool0oooo01H0oooo
0`0000070?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool04@3oool00`000000oooo
0?ooo`0E0?ooo`030000003oool0oooo03@0oooo00<000000?ooo`3oool0=`3oool00`000000oooo
0000000Z0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool01`3oool00`000000oooo
0?ooo`030?ooo`030000003oool0oooo04D0oooo00<000000?ooo`3oool03@3oool00`000000oooo
0?ooo`0:0?ooo`030000003oool0oooo00l0oooo00<000000?ooo`3oool01`3oool00`000000oooo
0?ooo`080?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool04P3oool00`000000oooo
0?ooo`0G0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool00`3oool2000002H0oooo
00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`070?ooo`040000003oool00000000000H0
oooo00<000000?ooo`3oool04P3oool00`000000oooo0?ooo`0F0?ooo`005@3oool00`000000oooo
0?ooo`0B0?ooo`8000007@3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00<0oooo
00<000000?ooo`3oool04`3oool00`000000oooo0?ooo`060?ooo`80000000D0oooo0000003oool0
oooo0000000R0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool0203oool3000000`0
oooo00<000000?ooo`3oool05P3oool3000000L0oooo00<000000?ooo`3oool01P3oool00`000000
oooo0?ooo`0A0?ooo`030000003oool0oooo01D0oooo00<000000?ooo`3oool0=03oool00`000000
oooo0?ooo`0g0?ooo`030000003oool0000002X0oooo00<000000?ooo`3oool02@3oool00`000000
oooo0?ooo`070?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0A@3oool00`000000
oooo0?ooo`0=0?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool03`3oool00`000000
oooo0?ooo`070?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool01P3oool00`000000
oooo0?ooo`0B0?ooo`030000003oool0oooo01L0oooo00<000000?ooo`3oool01@3oool00`000000
oooo0?ooo`030?ooo`8000009P3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00L0
oooo00@000000?ooo`00000000001P3oool00`000000oooo0?ooo`0B0?ooo`030000003oool0oooo
01H0oooo000E0?ooo`030000003oool0oooo0180oooo0P00000M0?ooo`030000003oool0oooo0080
oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`0C0?ooo`030000003oool0oooo00H0
oooo0P0000001@3oool000000?ooo`3oool000000280oooo00<000000?ooo`3oool01@3oool00`00
0000oooo0?ooo`080?ooo`<00000303oool00`000000oooo0?ooo`0F0?ooo`<000001`3oool00`00
0000oooo0?ooo`060?ooo`030000003oool0oooo0140oooo00<000000?ooo`3oool05@3oool00`00
0000oooo0?ooo`0d0?ooo`030000003oool0oooo03L0oooo00<000000?ooo`000000:P3oool00`00
0000oooo0?ooo`090?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool00`3oool00`00
0000oooo0?ooo`150?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool02P3oool00`00
0000oooo0?ooo`0?0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool0203oool00`00
0000oooo0?ooo`060?ooo`030000003oool0oooo0180oooo00<000000?ooo`3oool05`3oool00`00
0000oooo0?ooo`050?ooo`030000003oool0oooo00<0oooo0P00000V0?ooo`030000003oool0oooo
00H0oooo00<000000?ooo`3oool01`3oool010000000oooo0000000000060?ooo`030000003oool0
oooo0180oooo00<000000?ooo`3oool05P3oool001@0ooooo`3oo`3o0?oo0=D0ool05P000?l30?oo
01D0oooo000E0?ooo`030000003oool0oooo0180oooo0P00000M0?ooo`030000003oool0oooo0080
oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`0C0?ooo`030000003oool0oooo00H0
oooo0P0000001@3oool000000?ooo`3oool000000280oooo00<000000?ooo`3oool01@3oool00`00
0000oooo0?ooo`080?ooo`<00000303oool00`000000oooo0?ooo`0F0?ooo`<000001`3oool00`00
0000oooo0?ooo`060?ooo`030000003oool0oooo0140oooo00<000000?ooo`3oool05@3oool00`00
0000oooo0?ooo`0d0?ooo`030000003oool0oooo03L0oooo00<000000?ooo`000000:P3oool00`00
0000oooo0?ooo`090?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool00`3oool00`00
0000oooo0?ooo`150?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool02P3oool00`00
0000oooo0?ooo`0?0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool0203oool00`00
0000oooo0?ooo`060?ooo`030000003oool0oooo0180oooo00<000000?ooo`3oool05`3oool00`00
0000oooo0?ooo`050?ooo`030000003oool0oooo00<0oooo0P00000V0?ooo`030000003oool0oooo
00H0oooo00<000000?ooo`3oool01`3oool010000000oooo0000000000060?ooo`030000003oool0
oooo0180oooo00<000000?ooo`3oool05P3oool001D0oooo00<000000?ooo`3oool04P3oool20000
01d0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo
01<0oooo00<000000?ooo`3oool01P3oool2000000050?ooo`000000oooo0?ooo`0000008P3oool0
0`000000oooo0?ooo`050?ooo`030000003oool0oooo00P0oooo0`00000<0?ooo`030000003oool0
oooo01H0oooo0`0000070?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool04@3oool0
0`000000oooo0?ooo`0E0?ooo`030000003oool0oooo03@0oooo00<000000?ooo`3oool0=`3oool0
0`000000oooo0000000Z0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool01`3oool0
0`000000oooo0?ooo`030?ooo`030000003oool0oooo04D0oooo00<000000?ooo`3oool03@3oool0
0`000000oooo0?ooo`0:0?ooo`030000003oool0oooo00l0oooo00<000000?ooo`3oool01`3oool0
0`000000oooo0?ooo`080?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool04P3oool0
0`000000oooo0?ooo`0G0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool00`3oool2
000002H0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`070?ooo`040000003oool0
0000000000H0oooo00<000000?ooo`3oool04P3oool00`000000oooo0?ooo`0F0?ooo`005@3oool0
0`000000oooo0?ooo`0B0?ooo`8000007@3oool00`000000oooo0?ooo`020?ooo`030000003oool0
oooo00<0oooo00<000000?ooo`3oool04`3oool00`000000oooo0?ooo`060?ooo`80000000D0oooo
0000003oool0oooo0000000R0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool0203o
ool3000000`0oooo00<000000?ooo`3oool05P3oool3000000L0oooo00<000000?ooo`3oool01P3o
ool00`000000oooo0?ooo`0A0?ooo`030000003oool0oooo01D0oooo00<000000?ooo`3oool0=03o
ool00`000000oooo0?ooo`0g0?ooo`030000003oool0000002X0oooo00<000000?ooo`3oool02@3o
ool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0A@3o
ool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool03`3o
ool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool01P3o
ool00`000000oooo0?ooo`0B0?ooo`030000003oool0oooo01L0oooo00<000000?ooo`3oool01@3o
ool00`000000oooo0?ooo`030?ooo`8000009P3oool00`000000oooo0?ooo`060?ooo`030000003o
ool0oooo00L0oooo00@000000?ooo`00000000001P3oool00`000000oooo0?ooo`0B0?ooo`030000
003oool0oooo01H0oooo000E0?ooo`030000003oool0oooo0180oooo0P00000M0?ooo`030000003o
ool0oooo0080oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`0C0?ooo`030000003o
ool0oooo00H0oooo0P0000001@3oool000000?ooo`3oool000000280oooo00<000000?ooo`3oool0
1@3oool00`000000oooo0?ooo`080?ooo`<00000303oool00`000000oooo0?ooo`0F0?ooo`<00000
1`3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo0140oooo00<000000?ooo`3oool0
5@3oool00`000000oooo0?ooo`0d0?ooo`030000003oool0oooo03L0oooo00<000000?ooo`000000
:P3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool0
0`3oool00`000000oooo0?ooo`150?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool0
2P3oool00`000000oooo0?ooo`0?0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool0
203oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo0180oooo00<000000?ooo`3oool0
5`3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00<0oooo0P00000V0?ooo`030000
003oool0oooo00H0oooo00<000000?ooo`3oool01`3oool010000000oooo0000000000060?ooo`03
0000003oool0oooo0180oooo00<000000?ooo`3oool05P3oool001D0oooo00<000000?ooo`3oool0
4P3oool2000001d0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`030?ooo`030000
003oool0oooo01<0oooo00<000000?ooo`3oool01P3oool2000000050?ooo`000000oooo0?ooo`00
00008P3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00P0oooo0`00000<0?ooo`03
0000003oool0oooo01H0oooo0`0000070?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3o
ool04@3oool00`000000oooo0?ooo`0E0?ooo`030000003oool0oooo03@0oooo00<000000?ooo`3o
ool0=`3oool00`000000oooo0000000Z0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3o
ool01`3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo04D0oooo00<000000?ooo`3o
ool03@3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo00l0oooo00<000000?ooo`3o
ool01`3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3o
ool04P3oool00`000000oooo0?ooo`0G0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3o
ool00`3oool2000002H0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`070?ooo`04
0000003oool00000000000H0oooo00<000000?ooo`3oool04P3oool00`000000oooo0?ooo`0F0?oo
o`005@3oool00`000000oooo0?ooo`0B0?ooo`8000007@3oool00`000000oooo0?ooo`020?ooo`03
0000003oool0oooo00<0oooo00<000000?ooo`3oool04`3oool00`000000oooo0?ooo`060?ooo`80
000000D0oooo0000003oool0oooo0000000R0?ooo`030000003oool0oooo00D0oooo00<000000?oo
o`3oool0203oool3000000`0oooo00<000000?ooo`3oool05P3oool3000000L0oooo00<000000?oo
o`3oool01P3oool00`000000oooo0?ooo`0A0?ooo`030000003oool0oooo01D0oooo00<000000?oo
o`3oool0=03oool00`000000oooo0?ooo`0g0?ooo`030000003oool0000002X0oooo00<000000?oo
o`3oool02@3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00<0oooo00<000000?oo
o`3oool0A@3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo00X0oooo00<000000?oo
o`3oool03`3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00P0oooo00<000000?oo
o`3oool01P3oool00`000000oooo0?ooo`0B0?ooo`030000003oool0oooo01L0oooo00<000000?oo
o`3oool01@3oool00`000000oooo0?ooo`030?ooo`8000009P3oool00`000000oooo0?ooo`060?oo
o`030000003oool0oooo00L0oooo00@000000?ooo`00000000001P3oool00`000000oooo0?ooo`0B
0?ooo`030000003oool0oooo01H0oooo000E0?ooo`030000003oool0oooo0180oooo0P00000M0?oo
o`030000003oool0oooo0080oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`0C0?oo
o`030000003oool0oooo00H0oooo0P0000001@3oool000000?ooo`3oool000000280oooo00<00000
0?ooo`3oool01@3oool00`000000oooo0?ooo`080?ooo`<00000303oool00`000000oooo0?ooo`0F
0?ooo`<000001`3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo0140oooo00<00000
0?ooo`3oool05@3oool00`000000oooo0?ooo`0d0?ooo`030000003oool0oooo03L0oooo00<00000
0?ooo`000000:P3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00L0oooo00<00000
0?ooo`3oool00`3oool00`000000oooo0?ooo`150?ooo`030000003oool0oooo00d0oooo00<00000
0?ooo`3oool02P3oool00`000000oooo0?ooo`0?0?ooo`030000003oool0oooo00L0oooo00<00000
0?ooo`3oool0203oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo0180oooo00<00000
0?ooo`3oool05`3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00<0oooo0P00000V
0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool01`3oool010000000oooo00000000
00060?ooo`030000003oool0oooo0180oooo00<000000?ooo`3oool05P3oool001@0ooooo`3oo`3o
0?oo05<0ool05P000?n50?oo01D0oooo000E0?ooo`030000003oool0oooo0180oooo0P00000M0?oo
o`030000003oool0oooo0080oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`0C0?oo
o`030000003oool0oooo00H0oooo0P0000001@3oool000000?ooo`3oool000000280oooo00<00000
0?ooo`3oool01@3oool00`000000oooo0?ooo`080?ooo`<00000303oool00`000000oooo0?ooo`0F
0?ooo`<000001`3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo0140oooo00<00000
0?ooo`3oool05@3oool00`000000oooo0?ooo`0d0?ooo`030000003oool0oooo03L0oooo00<00000
0?ooo`000000:P3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00L0oooo00<00000
0?ooo`3oool00`3oool00`000000oooo0?ooo`150?ooo`030000003oool0oooo00d0oooo00<00000
0?ooo`3oool02P3oool00`000000oooo0?ooo`0?0?ooo`030000003oool0oooo00L0oooo00<00000
0?ooo`3oool0203oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo0180oooo00<00000
0?ooo`3oool05`3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00<0oooo0P00000V
0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool01`3oool010000000oooo00000000
00060?ooo`030000003oool0oooo0180oooo00<000000?ooo`3oool05P3oool001D0oooo00<00000
0?ooo`3oool04P3oool2000001d0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`03
0?ooo`030000003oool0oooo01<0oooo00<000000?ooo`3oool01P3oool2000000050?ooo`000000
oooo0?ooo`0000008P3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00P0oooo0`00
000<0?ooo`030000003oool0oooo01H0oooo0`0000070?ooo`030000003oool0oooo00H0oooo00<0
00000?ooo`3oool04@3oool00`000000oooo0?ooo`0E0?ooo`030000003oool0oooo03@0oooo00<0
00000?ooo`3oool0=`3oool00`000000oooo0000000Z0?ooo`030000003oool0oooo00T0oooo00<0
00000?ooo`3oool01`3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo04D0oooo00<0
00000?ooo`3oool03@3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo00l0oooo00<0
00000?ooo`3oool01`3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo00H0oooo00<0
00000?ooo`3oool04P3oool00`000000oooo0?ooo`0G0?ooo`030000003oool0oooo00D0oooo00<0
00000?ooo`3oool00`3oool2000002H0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?oo
o`070?ooo`040000003oool00000000000H0oooo00<000000?ooo`3oool04P3oool00`000000oooo
0?ooo`0F0?ooo`005@3oool00`000000oooo0?ooo`0B0?ooo`8000007@3oool00`000000oooo0?oo
o`020?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool04`3oool00`000000oooo0?oo
o`060?ooo`80000000D0oooo0000003oool0oooo0000000R0?ooo`030000003oool0oooo00D0oooo
00<000000?ooo`3oool0203oool3000000`0oooo00<000000?ooo`3oool05P3oool3000000L0oooo
00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`0A0?ooo`030000003oool0oooo01D0oooo
00<000000?ooo`3oool0=03oool00`000000oooo0?ooo`0g0?ooo`030000003oool0000002X0oooo
00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00<0oooo
00<000000?ooo`3oool0A@3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo00X0oooo
00<000000?ooo`3oool03`3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00P0oooo
00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`0B0?ooo`030000003oool0oooo01L0oooo
00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`030?ooo`8000009P3oool00`000000oooo
0?ooo`060?ooo`030000003oool0oooo00L0oooo00@000000?ooo`00000000001P3oool00`000000
oooo0?ooo`0B0?ooo`030000003oool0oooo01H0oooo000E0?ooo`030000003oool0oooo0180oooo
0P00000M0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool00`3oool00`000000oooo
0?ooo`0C0?ooo`030000003oool0oooo00H0oooo0P0000001@3oool000000?ooo`3oool000000280
oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`080?ooo`<00000303oool00`000000
oooo0?ooo`0F0?ooo`<000001`3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo0140
oooo00<000000?ooo`3oool05@3oool00`000000oooo0?ooo`0d0?ooo`030000003oool0oooo03L0
oooo00<000000?ooo`000000:P3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00L0
oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`150?ooo`030000003oool0oooo00d0
oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`0?0?ooo`030000003oool0oooo00L0
oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo0180
oooo00<000000?ooo`3oool05`3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00<0
oooo0P00000V0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool01`3oool010000000
oooo0000000000060?ooo`030000003oool0oooo0180oooo00<000000?ooo`3oool05P3oool001D0
oooo00<000000?ooo`3oool04P3oool2000001d0oooo00<000000?ooo`3oool00P3oool00`000000
oooo0?ooo`030?ooo`030000003oool0oooo01<0oooo00<000000?ooo`3oool01P3oool200000005
0?ooo`000000oooo0?ooo`0000008P3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo
00P0oooo0`00000<0?ooo`030000003oool0oooo01H0oooo0`0000070?ooo`030000003oool0oooo
00H0oooo00<000000?ooo`3oool04@3oool00`000000oooo0?ooo`0E0?ooo`030000003oool0oooo
03@0oooo00<000000?ooo`3oool0=`3oool00`000000oooo0000000Z0?ooo`030000003oool0oooo
00T0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo
04D0oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo
00l0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo
00H0oooo00<000000?ooo`3oool04P3oool00`000000oooo0?ooo`0G0?ooo`030000003oool0oooo
00D0oooo00<000000?ooo`3oool00`3oool2000002H0oooo00<000000?ooo`3oool01P3oool00`00
0000oooo0?ooo`070?ooo`040000003oool00000000000H0oooo00<000000?ooo`3oool04P3oool0
0`000000oooo0?ooo`0F0?ooo`005@3oool00`000000oooo0?ooo`0B0?ooo`8000007@3oool00`00
0000oooo0?ooo`020?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool04`3oool00`00
0000oooo0?ooo`060?ooo`80000000D0oooo0000003oool0oooo0000000R0?ooo`030000003oool0
oooo00D0oooo00<000000?ooo`3oool0203oool3000000`0oooo00<000000?ooo`3oool05P3oool3
000000L0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`0A0?ooo`030000003oool0
oooo01D0oooo00<000000?ooo`3oool0=03oool00`000000oooo0?ooo`0g0?ooo`030000003oool0
000002X0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`070?ooo`030000003oool0
oooo00<0oooo00<000000?ooo`3oool0A@3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0
oooo00X0oooo00<000000?ooo`3oool03`3oool00`000000oooo0?ooo`070?ooo`030000003oool0
oooo00P0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`0B0?ooo`030000003oool0
oooo01L0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`030?ooo`8000009P3oool0
0`000000oooo0?ooo`060?ooo`030000003oool0oooo00L0oooo00@000000?ooo`00000000001P3o
ool00`000000oooo0?ooo`0B0?ooo`030000003oool0oooo01H0oooo000E0?ooo`030000003oool0
oooo0180oooo0P00000M0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool00`3oool0
0`000000oooo0?ooo`0C0?ooo`030000003oool0oooo00H0oooo0P0000001@3oool000000?ooo`3o
ool000000280oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`080?ooo`<00000303o
ool00`000000oooo0?ooo`0F0?ooo`<000001`3oool00`000000oooo0?ooo`060?ooo`030000003o
ool0oooo0140oooo00<000000?ooo`3oool05@3oool00`000000oooo0?ooo`0d0?ooo`030000003o
ool0oooo03L0oooo00<000000?ooo`000000:P3oool00`000000oooo0?ooo`090?ooo`030000003o
ool0oooo00L0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`150?ooo`030000003o
ool0oooo00d0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`0?0?ooo`030000003o
ool0oooo00L0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`060?ooo`030000003o
ool0oooo0180oooo00<000000?ooo`3oool05`3oool00`000000oooo0?ooo`050?ooo`030000003o
ool0oooo00<0oooo0P00000V0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool01`3o
ool010000000oooo0000000000060?ooo`030000003oool0oooo0180oooo00<000000?ooo`3oool0
5P3oool001@0oooo=@3oo`060000ool0ool0o`3oo`2c0?oo01D0oooo000E0?ooo`030000003oool0
oooo0180oooo0P00000M0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool00`3oool0
0`000000oooo0?ooo`0C0?ooo`030000003oool0oooo00H0oooo0P0000001@3oool000000?ooo`3o
ool000000280oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`080?ooo`<00000303o
ool00`000000oooo0?ooo`0F0?ooo`<000001`3oool00`000000oooo0?ooo`060?ooo`030000003o
ool0oooo0140oooo00<000000?ooo`3oool05@3oool00`000000oooo0?ooo`0d0?ooo`030000003o
ool0oooo03L0oooo00<000000?ooo`000000:P3oool00`000000oooo0?ooo`090?ooo`030000003o
ool0oooo00L0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`150?ooo`030000003o
ool0oooo00d0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`0?0?ooo`030000003o
ool0oooo00L0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`060?ooo`030000003o
ool0oooo0180oooo00<000000?ooo`3oool05`3oool00`000000oooo0?ooo`050?ooo`030000003o
ool0oooo00<0oooo0P00000V0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool01`3o
ool010000000oooo0000000000060?ooo`030000003oool0oooo0180oooo00<000000?ooo`3oool0
5P3oool001D0oooo00<000000?ooo`3oool04P3oool2000001d0oooo00<000000?ooo`3oool00P3o
ool00`000000oooo0?ooo`030?ooo`030000003oool0oooo01<0oooo00<000000?ooo`3oool01P3o
ool2000000050?ooo`000000oooo0?ooo`0000008P3oool00`000000oooo0?ooo`050?ooo`030000
003oool0oooo00P0oooo0`00000<0?ooo`030000003oool0oooo01H0oooo0`0000070?ooo`030000
003oool0oooo00H0oooo00<000000?ooo`3oool04@3oool00`000000oooo0?ooo`0E0?ooo`030000
003oool0oooo03@0oooo00<000000?ooo`3oool0=`3oool00`000000oooo0000000Z0?ooo`030000
003oool0oooo00T0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`030?ooo`030000
003oool0oooo04D0oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`0:0?ooo`030000
003oool0oooo00l0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`080?ooo`030000
003oool0oooo00H0oooo00<000000?ooo`3oool04P3oool00`000000oooo0?ooo`0G0?ooo`030000
003oool0oooo00D0oooo00<000000?ooo`3oool00`3oool2000002H0oooo00<000000?ooo`3oool0
1P3oool00`000000oooo0?ooo`070?ooo`040000003oool00000000000H0oooo00<000000?ooo`3o
ool04P3oool00`000000oooo0?ooo`0F0?ooo`005@3oool00`000000oooo0?ooo`0B0?ooo`800000
7@3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0
4`3oool00`000000oooo0?ooo`060?ooo`80000000D0oooo0000003oool0oooo0000000R0?ooo`03
0000003oool0oooo00D0oooo00<000000?ooo`3oool0203oool3000000`0oooo00<000000?ooo`3o
ool05P3oool3000000L0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`0A0?ooo`03
0000003oool0oooo01D0oooo00<000000?ooo`3oool0=03oool00`000000oooo0?ooo`0g0?ooo`03
0000003oool0000002X0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`070?ooo`03
0000003oool0oooo00<0oooo00<000000?ooo`3oool0A@3oool00`000000oooo0?ooo`0=0?ooo`03
0000003oool0oooo00X0oooo00<000000?ooo`3oool03`3oool00`000000oooo0?ooo`070?ooo`03
0000003oool0oooo00P0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`0B0?ooo`03
0000003oool0oooo01L0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`030?ooo`80
00009P3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00L0oooo00@000000?ooo`00
000000001P3oool00`000000oooo0?ooo`0B0?ooo`030000003oool0oooo01H0oooo000E0?ooo`03
0000003oool0oooo0180oooo0P00000M0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3o
ool00`3oool00`000000oooo0?ooo`0C0?ooo`030000003oool0oooo00H0oooo0P0000001@3oool0
00000?ooo`3oool000000280oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`080?oo
o`<00000303oool00`000000oooo0?ooo`0F0?ooo`<000001`3oool00`000000oooo0?ooo`060?oo
o`030000003oool0oooo0140oooo00<000000?ooo`3oool05@3oool00`000000oooo0?ooo`0d0?oo
o`030000003oool0oooo03L0oooo00<000000?ooo`000000:P3oool00`000000oooo0?ooo`090?oo
o`030000003oool0oooo00L0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`150?oo
o`030000003oool0oooo00d0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`0?0?oo
o`030000003oool0oooo00L0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`060?oo
o`030000003oool0oooo0180oooo00<000000?ooo`3oool05`3oool00`000000oooo0?ooo`050?oo
o`030000003oool0oooo00<0oooo0P00000V0?ooo`030000003oool0oooo00H0oooo00<000000?oo
o`3oool01`3oool010000000oooo0000000000060?ooo`030000003oool0oooo0180oooo00<00000
0?ooo`3oool05P3oool001D0oooo00<000000?ooo`3oool04P3oool2000001d0oooo00<000000?oo
o`3oool00P3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo01<0oooo00<000000?oo
o`3oool01P3oool2000000050?ooo`000000oooo0?ooo`0000008P3oool00`000000oooo0?ooo`05
0?ooo`030000003oool0oooo00P0oooo0`00000<0?ooo`030000003oool0oooo01H0oooo0`000007
0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool04@3oool00`000000oooo0?ooo`0E
0?ooo`030000003oool0oooo03@0oooo00<000000?ooo`3oool0=`3oool00`000000oooo0000000Z
0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`03
0?ooo`030000003oool0oooo04D0oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`0:
0?ooo`030000003oool0oooo00l0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`08
0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool04P3oool00`000000oooo0?ooo`0G
0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool00`3oool2000002H0oooo00<00000
0?ooo`3oool01P3oool00`000000oooo0?ooo`070?ooo`040000003oool00000000000H0oooo00<0
00000?ooo`3oool04P3oool00`000000oooo0?ooo`0F0?ooo`005@3oool00`000000oooo0?ooo`0B
0?ooo`8000007@3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00<0oooo00<00000
0?ooo`3oool04`3oool00`000000oooo0?ooo`060?ooo`80000000D0oooo0000003oool0oooo0000
000R0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool0203oool3000000`0oooo00<0
00000?ooo`3oool05P3oool3000000L0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?oo
o`0A0?ooo`030000003oool0oooo01D0oooo00<000000?ooo`3oool0=03oool00`000000oooo0?oo
o`0g0?ooo`030000003oool0000002X0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?oo
o`070?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0A@3oool00`000000oooo0?oo
o`0=0?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool03`3oool00`000000oooo0?oo
o`070?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?oo
o`0B0?ooo`030000003oool0oooo01L0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?oo
o`030?ooo`8000009P3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00L0oooo00@0
00000?ooo`00000000001P3oool00`000000oooo0?ooo`0B0?ooo`030000003oool0oooo01H0oooo
000E0?ooo`030000003oool0oooo0180oooo0P00000M0?ooo`030000003oool0oooo0080oooo00<0
00000?ooo`3oool00`3oool00`000000oooo0?ooo`0C0?ooo`030000003oool0oooo00H0oooo0P00
00001@3oool000000?ooo`3oool000000280oooo00<000000?ooo`3oool01@3oool00`000000oooo
0?ooo`080?ooo`<00000303oool00`000000oooo0?ooo`0F0?ooo`<000001`3oool00`000000oooo
0?ooo`060?ooo`030000003oool0oooo0140oooo00<000000?ooo`3oool05@3oool00`000000oooo
0?ooo`0d0?ooo`030000003oool0oooo03L0oooo00<000000?ooo`000000:P3oool00`000000oooo
0?ooo`090?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool00`3oool00`000000oooo
0?ooo`150?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool02P3oool00`000000oooo
0?ooo`0?0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool0203oool00`000000oooo
0?ooo`060?ooo`030000003oool0oooo0180oooo00<000000?ooo`3oool05`3oool00`000000oooo
0?ooo`050?ooo`030000003oool0oooo00<0oooo0P00000V0?ooo`030000003oool0oooo00H0oooo
00<000000?ooo`3oool01`3oool010000000oooo0000000000060?ooo`030000003oool0oooo0180
oooo00<000000?ooo`3oool05P3oool001@0ooooo`3oo`3o0?oo06P0ool06`000?m[0?oo01D0oooo
000E0?ooo`030000003oool0oooo0180oooo0P00000M0?ooo`030000003oool0oooo0080oooo00<0
00000?ooo`3oool00`3oool00`000000oooo0?ooo`0C0?ooo`030000003oool0oooo00H0oooo0P00
00001@3oool000000?ooo`3oool000000280oooo00<000000?ooo`3oool01@3oool00`000000oooo
0?ooo`080?ooo`<00000303oool00`000000oooo0?ooo`0F0?ooo`<000001`3oool00`000000oooo
0?ooo`060?ooo`030000003oool0oooo0140oooo00<000000?ooo`3oool05@3oool00`000000oooo
0?ooo`0d0?ooo`030000003oool0oooo03L0oooo00<000000?ooo`000000:P3oool00`000000oooo
0?ooo`090?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool00`3oool00`000000oooo
0?ooo`150?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool02P3oool00`000000oooo
0?ooo`0?0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool0203oool00`000000oooo
0?ooo`060?ooo`030000003oool0oooo0180oooo00<000000?ooo`3oool05`3oool00`000000oooo
0?ooo`050?ooo`030000003oool0oooo00<0oooo0P00000V0?ooo`030000003oool0oooo00H0oooo
00<000000?ooo`3oool01`3oool010000000oooo0000000000060?ooo`030000003oool0oooo0180
oooo00<000000?ooo`3oool05P3oool001D0oooo00<000000?ooo`3oool04P3oool2000001d0oooo
00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo01<0oooo
00<000000?ooo`3oool01P3oool2000000050?ooo`000000oooo0?ooo`0000008P3oool00`000000
oooo0?ooo`050?ooo`030000003oool0oooo00P0oooo0`00000<0?ooo`030000003oool0oooo01H0
oooo0`0000070?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool04@3oool00`000000
oooo0?ooo`0E0?ooo`030000003oool0oooo03@0oooo00<000000?ooo`3oool0=`3oool00`000000
oooo0000000Z0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool01`3oool00`000000
oooo0?ooo`030?ooo`030000003oool0oooo04D0oooo00<000000?ooo`3oool03@3oool00`000000
oooo0?ooo`0:0?ooo`030000003oool0oooo00l0oooo00<000000?ooo`3oool01`3oool00`000000
oooo0?ooo`080?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool04P3oool00`000000
oooo0?ooo`0G0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool00`3oool2000002H0
oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`070?ooo`040000003oool000000000
00H0oooo00<000000?ooo`3oool04P3oool00`000000oooo0?ooo`0F0?ooo`005@3oool00`000000
oooo0?ooo`0B0?ooo`8000007@3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00<0
oooo00<000000?ooo`3oool04`3oool00`000000oooo0?ooo`060?ooo`80000000D0oooo0000003o
ool0oooo0000000R0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool0203oool30000
00`0oooo00<000000?ooo`3oool05P3oool3000000L0oooo00<000000?ooo`3oool01P3oool00`00
0000oooo0?ooo`0A0?ooo`030000003oool0oooo01D0oooo00<000000?ooo`3oool0=03oool00`00
0000oooo0?ooo`0g0?ooo`030000003oool0000002X0oooo00<000000?ooo`3oool02@3oool00`00
0000oooo0?ooo`070?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0A@3oool00`00
0000oooo0?ooo`0=0?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool03`3oool00`00
0000oooo0?ooo`070?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool01P3oool00`00
0000oooo0?ooo`0B0?ooo`030000003oool0oooo01L0oooo00<000000?ooo`3oool01@3oool00`00
0000oooo0?ooo`030?ooo`8000009P3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo
00L0oooo00@000000?ooo`00000000001P3oool00`000000oooo0?ooo`0B0?ooo`030000003oool0
oooo01H0oooo000E0?ooo`030000003oool0oooo0180oooo0P00000M0?ooo`030000003oool0oooo
0080oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`0C0?ooo`030000003oool0oooo
00H0oooo0P0000001@3oool000000?ooo`3oool000000280oooo00<000000?ooo`3oool01@3oool0
0`000000oooo0?ooo`080?ooo`<00000303oool00`000000oooo0?ooo`0F0?ooo`<000001`3oool0
0`000000oooo0?ooo`060?ooo`030000003oool0oooo0140oooo00<000000?ooo`3oool05@3oool0
0`000000oooo0?ooo`0d0?ooo`030000003oool0oooo03L0oooo00<000000?ooo`000000:P3oool0
0`000000oooo0?ooo`090?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool00`3oool0
0`000000oooo0?ooo`150?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool02P3oool0
0`000000oooo0?ooo`0?0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool0203oool0
0`000000oooo0?ooo`060?ooo`030000003oool0oooo0180oooo00<000000?ooo`3oool05`3oool0
0`000000oooo0?ooo`050?ooo`030000003oool0oooo00<0oooo0P00000V0?ooo`030000003oool0
oooo00H0oooo00<000000?ooo`3oool01`3oool010000000oooo0000000000060?ooo`030000003o
ool0oooo0180oooo00<000000?ooo`3oool05P3oool001D0oooo00<000000?ooo`3oool04P3oool2
000001d0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`030?ooo`030000003oool0
oooo01<0oooo00<000000?ooo`3oool01P3oool2000000050?ooo`000000oooo0?ooo`0000008P3o
ool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00P0oooo0`00000<0?ooo`030000003o
ool0oooo01H0oooo0`0000070?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool04@3o
ool00`000000oooo0?ooo`0E0?ooo`030000003oool0oooo03@0oooo00<000000?ooo`3oool0=`3o
ool00`000000oooo0000000Z0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool01`3o
ool00`000000oooo0?ooo`030?ooo`030000003oool0oooo04D0oooo00<000000?ooo`3oool03@3o
ool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo00l0oooo00<000000?ooo`3oool01`3o
ool00`000000oooo0?ooo`080?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool04P3o
ool00`000000oooo0?ooo`0G0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool00`3o
ool2000002H0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`070?ooo`040000003o
ool00000000000H0oooo00<000000?ooo`3oool04P3oool00`000000oooo0?ooo`0F0?ooo`005@3o
ool00`000000oooo0?ooo`0B0?ooo`8000007@3oool00`000000oooo0?ooo`020?ooo`030000003o
ool0oooo00<0oooo00<000000?ooo`3oool04`3oool00`000000oooo0?ooo`060?ooo`80000000D0
oooo0000003oool0oooo0000000R0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool0
203oool3000000`0oooo00<000000?ooo`3oool05P3oool3000000L0oooo00<000000?ooo`3oool0
1P3oool00`000000oooo0?ooo`0A0?ooo`030000003oool0oooo01D0oooo00<000000?ooo`3oool0
=03oool00`000000oooo0?ooo`0g0?ooo`030000003oool0000002X0oooo00<000000?ooo`3oool0
2@3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0
A@3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool0
3`3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool0
1P3oool00`000000oooo0?ooo`0B0?ooo`030000003oool0oooo01L0oooo00<000000?ooo`3oool0
1@3oool00`000000oooo0?ooo`030?ooo`8000009P3oool00`000000oooo0?ooo`060?ooo`030000
003oool0oooo00L0oooo00@000000?ooo`00000000001P3oool00`000000oooo0?ooo`0B0?ooo`03
0000003oool0oooo01H0oooo000D0?ooool0ool0o`3oo`220?oo00T0003o1@3oo`020000oe`0ool0
5@3oool001D0oooo00<000000?ooo`3oool04P3oool2000001d0oooo00<000000?ooo`3oool00P3o
ool00`000000oooo0?ooo`030?ooo`030000003oool0oooo01<0oooo00<000000?ooo`3oool01P3o
ool2000000050?ooo`000000oooo0?ooo`0000008P3oool00`000000oooo0?ooo`050?ooo`030000
003oool0oooo00P0oooo0`00000<0?ooo`030000003oool0oooo01H0oooo0`0000070?ooo`030000
003oool0oooo00H0oooo00<000000?ooo`3oool04@3oool00`000000oooo0?ooo`0E0?ooo`030000
003oool0oooo03@0oooo00<000000?ooo`3oool0=`3oool00`000000oooo0000000Z0?ooo`030000
003oool0oooo00T0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`030?ooo`030000
003oool0oooo04D0oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`0:0?ooo`030000
003oool0oooo00l0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`080?ooo`030000
003oool0oooo00H0oooo00<000000?ooo`3oool04P3oool00`000000oooo0?ooo`0G0?ooo`030000
003oool0oooo00D0oooo00<000000?ooo`3oool00`3oool2000002H0oooo00<000000?ooo`3oool0
1P3oool00`000000oooo0?ooo`070?ooo`040000003oool00000000000H0oooo00<000000?ooo`3o
ool04P3oool00`000000oooo0?ooo`0F0?ooo`005@3oool00`000000oooo0?ooo`0B0?ooo`800000
7@3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0
4`3oool00`000000oooo0?ooo`060?ooo`80000000D0oooo0000003oool0oooo0000000R0?ooo`03
0000003oool0oooo00D0oooo00<000000?ooo`3oool0203oool3000000`0oooo00<000000?ooo`3o
ool05P3oool3000000L0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`0A0?ooo`03
0000003oool0oooo01D0oooo00<000000?ooo`3oool0=03oool00`000000oooo0?ooo`0g0?ooo`03
0000003oool0000002X0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`070?ooo`03
0000003oool0oooo00<0oooo00<000000?ooo`3oool0A@3oool00`000000oooo0?ooo`0=0?ooo`03
0000003oool0oooo00X0oooo00<000000?ooo`3oool03`3oool00`000000oooo0?ooo`070?ooo`03
0000003oool0oooo00P0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`0B0?ooo`03
0000003oool0oooo01L0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`030?ooo`80
00009P3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00L0oooo00@000000?ooo`00
000000001P3oool00`000000oooo0?ooo`0B0?ooo`030000003oool0oooo01H0oooo000E0?ooo`03
0000003oool0oooo0180oooo0P00000M0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3o
ool00`3oool00`000000oooo0?ooo`0C0?ooo`030000003oool0oooo00H0oooo0P0000001@3oool0
00000?ooo`3oool000000280oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`080?oo
o`<00000303oool00`000000oooo0?ooo`0F0?ooo`<000001`3oool00`000000oooo0?ooo`060?oo
o`030000003oool0oooo0140oooo00<000000?ooo`3oool05@3oool00`000000oooo0?ooo`0d0?oo
o`030000003oool0oooo03L0oooo00<000000?ooo`000000:P3oool00`000000oooo0?ooo`090?oo
o`030000003oool0oooo00L0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`150?oo
o`030000003oool0oooo00d0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`0?0?oo
o`030000003oool0oooo00L0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`060?oo
o`030000003oool0oooo0180oooo00<000000?ooo`3oool05`3oool00`000000oooo0?ooo`050?oo
o`030000003oool0oooo00<0oooo0P00000V0?ooo`030000003oool0oooo00H0oooo00<000000?oo
o`3oool01`3oool010000000oooo0000000000060?ooo`030000003oool0oooo0180oooo00<00000
0?ooo`3oool05P3oool001D0oooo00<000000?ooo`3oool04P3oool2000001d0oooo00<000000?oo
o`3oool00P3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo01<0oooo00<000000?oo
o`3oool01P3oool2000000050?ooo`000000oooo0?ooo`0000008P3oool00`000000oooo0?ooo`05
0?ooo`030000003oool0oooo00P0oooo0`00000<0?ooo`030000003oool0oooo01H0oooo0`000007
0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool04@3oool00`000000oooo0?ooo`0E
0?ooo`030000003oool0oooo03@0oooo00<000000?ooo`3oool0=`3oool00`000000oooo0000000Z
0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`03
0?ooo`030000003oool0oooo04D0oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`0:
0?ooo`030000003oool0oooo00l0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`08
0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool04P3oool00`000000oooo0?ooo`0G
0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool00`3oool2000002H0oooo00<00000
0?ooo`3oool01P3oool00`000000oooo0?ooo`070?ooo`040000003oool00000000000H0oooo00<0
00000?ooo`3oool04P3oool00`000000oooo0?ooo`0F0?ooo`005@3oool00`000000oooo0?ooo`0B
0?ooo`8000007@3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00<0oooo00<00000
0?ooo`3oool04`3oool00`000000oooo0?ooo`060?ooo`80000000D0oooo0000003oool0oooo0000
000R0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool0203oool3000000`0oooo00<0
00000?ooo`3oool05P3oool3000000L0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?oo
o`0A0?ooo`030000003oool0oooo01D0oooo00<000000?ooo`3oool0=03oool00`000000oooo0?oo
o`0g0?ooo`030000003oool0000002X0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?oo
o`070?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0A@3oool00`000000oooo0?oo
o`0=0?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool03`3oool00`000000oooo0?oo
o`070?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?oo
o`0B0?ooo`030000003oool0oooo01L0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?oo
o`030?ooo`8000009P3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00L0oooo00@0
00000?ooo`00000000001P3oool00`000000oooo0?ooo`0B0?ooo`030000003oool0oooo01H0oooo
000E0?ooo`030000003oool0oooo0180oooo0P00000M0?ooo`030000003oool0oooo0080oooo00<0
00000?ooo`3oool00`3oool00`000000oooo0?ooo`0C0?ooo`030000003oool0oooo00H0oooo0P00
00001@3oool000000?ooo`3oool000000280oooo00<000000?ooo`3oool01@3oool00`000000oooo
0?ooo`080?ooo`<00000303oool00`000000oooo0?ooo`0F0?ooo`<000001`3oool00`000000oooo
0?ooo`060?ooo`030000003oool0oooo0140oooo00<000000?ooo`3oool05@3oool00`000000oooo
0?ooo`0d0?ooo`030000003oool0oooo03L0oooo00<000000?ooo`000000:P3oool00`000000oooo
0?ooo`090?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool00`3oool00`000000oooo
0?ooo`150?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool02P3oool00`000000oooo
0?ooo`0?0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool0203oool00`000000oooo
0?ooo`060?ooo`030000003oool0oooo0180oooo00<000000?ooo`3oool05`3oool00`000000oooo
0?ooo`050?ooo`030000003oool0oooo00<0oooo0P00000V0?ooo`030000003oool0oooo00H0oooo
00<000000?ooo`3oool01`3oool010000000oooo0000000000060?ooo`030000003oool0oooo0180
oooo00<000000?ooo`3oool05P3oool001D0oooo00<000000?ooo`3oool04P3oool2000001d0oooo
00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo01<0oooo
00<000000?ooo`3oool01P3oool2000000050?ooo`000000oooo0?ooo`0000008P3oool00`000000
oooo0?ooo`050?ooo`030000003oool0oooo00P0oooo0`00000<0?ooo`030000003oool0oooo01H0
oooo0`0000070?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool04@3oool00`000000
oooo0?ooo`0E0?ooo`030000003oool0oooo03@0oooo00<000000?ooo`3oool0=`3oool00`000000
oooo0000000Z0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool01`3oool00`000000
oooo0?ooo`030?ooo`030000003oool0oooo04D0oooo00<000000?ooo`3oool03@3oool00`000000
oooo0?ooo`0:0?ooo`030000003oool0oooo00l0oooo00<000000?ooo`3oool01`3oool00`000000
oooo0?ooo`080?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool04P3oool00`000000
oooo0?ooo`0G0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool00`3oool2000002H0
oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`070?ooo`040000003oool000000000
00H0oooo00<000000?ooo`3oool04P3oool00`000000oooo0?ooo`0F0?ooo`00503ooomP0?oo00<0
003o9@3oo`090000o`X0ool00P000?oo0?oo0>`0ool01`000?mM0?oo01D0oooo000E0?ooo`030000
003oool0oooo0180oooo0P00000M0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0
0`3oool00`000000oooo0?ooo`0C0?ooo`030000003oool0oooo00H0oooo0P0000001@3oool00000
0?ooo`3oool000000280oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`080?ooo`<0
0000303oool00`000000oooo0?ooo`0F0?ooo`<000001`3oool00`000000oooo0?ooo`060?ooo`03
0000003oool0oooo0140oooo00<000000?ooo`3oool05@3oool00`000000oooo0?ooo`0d0?ooo`03
0000003oool0oooo03L0oooo00<000000?ooo`000000:P3oool00`000000oooo0?ooo`090?ooo`03
0000003oool0oooo00L0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`150?ooo`03
0000003oool0oooo00d0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`0?0?ooo`03
0000003oool0oooo00L0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`060?ooo`03
0000003oool0oooo0180oooo00<000000?ooo`3oool05`3oool00`000000oooo0?ooo`050?ooo`03
0000003oool0oooo00<0oooo0P00000V0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3o
ool01`3oool010000000oooo0000000000060?ooo`030000003oool0oooo0180oooo00<000000?oo
o`3oool05P3oool001D0oooo00<000000?ooo`3oool04P3oool2000001d0oooo00<000000?ooo`3o
ool00P3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo01<0oooo00<000000?ooo`3o
ool01P3oool2000000050?ooo`000000oooo0?ooo`0000008P3oool00`000000oooo0?ooo`050?oo
o`030000003oool0oooo00P0oooo0`00000<0?ooo`030000003oool0oooo01H0oooo0`0000070?oo
o`030000003oool0oooo00H0oooo00<000000?ooo`3oool04@3oool00`000000oooo0?ooo`0E0?oo
o`030000003oool0oooo03@0oooo00<000000?ooo`3oool0=`3oool00`000000oooo0000000Z0?oo
o`030000003oool0oooo00T0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`030?oo
o`030000003oool0oooo04D0oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`0:0?oo
o`030000003oool0oooo00l0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`080?oo
o`030000003oool0oooo00H0oooo00<000000?ooo`3oool04P3oool00`000000oooo0?ooo`0G0?oo
o`030000003oool0oooo00D0oooo00<000000?ooo`3oool00`3oool2000002H0oooo00<000000?oo
o`3oool01P3oool00`000000oooo0?ooo`070?ooo`040000003oool00000000000H0oooo00<00000
0?ooo`3oool04P3oool00`000000oooo0?ooo`0F0?ooo`005@3oool00`000000oooo0?ooo`0B0?oo
o`8000007@3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00<0oooo00<000000?oo
o`3oool04`3oool00`000000oooo0?ooo`060?ooo`80000000D0oooo0000003oool0oooo0000000R
0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool0203oool3000000`0oooo00<00000
0?ooo`3oool05P3oool3000000L0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`0A
0?ooo`030000003oool0oooo01D0oooo00<000000?ooo`3oool0=03oool00`000000oooo0?ooo`0g
0?ooo`030000003oool0000002X0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`07
0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0A@3oool00`000000oooo0?ooo`0=
0?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool03`3oool00`000000oooo0?ooo`07
0?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`0B
0?ooo`030000003oool0oooo01L0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`03
0?ooo`8000009P3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00L0oooo00@00000
0?ooo`00000000001P3oool00`000000oooo0?ooo`0B0?ooo`030000003oool0oooo01H0oooo000E
0?ooo`030000003oool0oooo0180oooo0P00000M0?ooo`030000003oool0oooo0080oooo00<00000
0?ooo`3oool00`3oool00`000000oooo0?ooo`0C0?ooo`030000003oool0oooo00H0oooo0P000000
1@3oool000000?ooo`3oool000000280oooo00<000000?ooo`3oool01@3oool00`000000oooo0?oo
o`080?ooo`<00000303oool00`000000oooo0?ooo`0F0?ooo`<000001`3oool00`000000oooo0?oo
o`060?ooo`030000003oool0oooo0140oooo00<000000?ooo`3oool05@3oool00`000000oooo0?oo
o`0d0?ooo`030000003oool0oooo03L0oooo00<000000?ooo`000000:P3oool00`000000oooo0?oo
o`090?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?oo
o`150?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?oo
o`0?0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool0203oool00`000000oooo0?oo
o`060?ooo`030000003oool0oooo0180oooo00<000000?ooo`3oool05`3oool00`000000oooo0?oo
o`050?ooo`030000003oool0oooo00<0oooo0P00000V0?ooo`030000003oool0oooo00H0oooo00<0
00000?ooo`3oool01`3oool010000000oooo0000000000060?ooo`030000003oool0oooo0180oooo
00<000000?ooo`3oool05P3oool001D0oooo00<000000?ooo`3oool04P3oool2000001d0oooo00<0
00000?ooo`3oool00P3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo01<0oooo00<0
00000?ooo`3oool01P3oool2000000050?ooo`000000oooo0?ooo`0000008P3oool00`000000oooo
0?ooo`050?ooo`030000003oool0oooo00P0oooo0`00000<0?ooo`030000003oool0oooo01H0oooo
0`0000070?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool04@3oool00`000000oooo
0?ooo`0E0?ooo`030000003oool0oooo03@0oooo00<000000?ooo`3oool0=`3oool00`000000oooo
0000000Z0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool01`3oool00`000000oooo
0?ooo`030?ooo`030000003oool0oooo04D0oooo00<000000?ooo`3oool03@3oool00`000000oooo
0?ooo`0:0?ooo`030000003oool0oooo00l0oooo00<000000?ooo`3oool01`3oool00`000000oooo
0?ooo`080?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool04P3oool00`000000oooo
0?ooo`0G0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool00`3oool2000002H0oooo
00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`070?ooo`040000003oool00000000000H0
oooo00<000000?ooo`3oool04P3oool00`000000oooo0?ooo`0F0?ooo`005@3oool00`000000oooo
0?ooo`0B0?ooo`8000007@3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00<0oooo
00<000000?ooo`3oool04`3oool00`000000oooo0?ooo`060?ooo`80000000D0oooo0000003oool0
oooo0000000R0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool0203oool3000000`0
oooo00<000000?ooo`3oool05P3oool3000000L0oooo00<000000?ooo`3oool01P3oool00`000000
oooo0?ooo`0A0?ooo`030000003oool0oooo01D0oooo00<000000?ooo`3oool0=03oool00`000000
oooo0?ooo`0g0?ooo`030000003oool0000002X0oooo00<000000?ooo`3oool02@3oool00`000000
oooo0?ooo`070?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0A@3oool00`000000
oooo0?ooo`0=0?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool03`3oool00`000000
oooo0?ooo`070?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool01P3oool00`000000
oooo0?ooo`0B0?ooo`030000003oool0oooo01L0oooo00<000000?ooo`3oool01@3oool00`000000
oooo0?ooo`030?ooo`8000009P3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00L0
oooo00@000000?ooo`00000000001P3oool00`000000oooo0?ooo`0B0?ooo`030000003oool0oooo
01H0oooo000E0?ooo`030000003oool0oooo0180oooo0P00000M0?ooo`030000003oool0oooo0080
oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`0C0?ooo`030000003oool0oooo00H0
oooo0P0000001@3oool000000?ooo`3oool000000280oooo00<000000?ooo`3oool01@3oool00`00
0000oooo0?ooo`080?ooo`<00000303oool00`000000oooo0?ooo`0F0?ooo`<000001`3oool00`00
0000oooo0?ooo`060?ooo`030000003oool0oooo0140oooo00<000000?ooo`3oool05@3oool00`00
0000oooo0?ooo`0d0?ooo`030000003oool0oooo03L0oooo00<000000?ooo`000000:P3oool00`00
0000oooo0?ooo`090?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool00`3oool00`00
0000oooo0?ooo`150?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool02P3oool00`00
0000oooo0?ooo`0?0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool0203oool00`00
0000oooo0?ooo`060?ooo`030000003oool0oooo0180oooo00<000000?ooo`3oool05`3oool00`00
0000oooo0?ooo`050?ooo`030000003oool0oooo00<0oooo0P00000V0?ooo`030000003oool0oooo
00H0oooo00<000000?ooo`3oool01`3oool010000000oooo0000000000060?ooo`030000003oool0
oooo0180oooo00<000000?ooo`3oool05P3oool001@0ooooo`3oo`030?oo03P0003obP3oo`0A0000
ok@0ool02`000?lD0?oo00@0003o5@3oool001D0oooo00<000000?ooo`3oool04P3oool2000001d0
oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo01<0
oooo00<000000?ooo`3oool01P3oool2000000050?ooo`000000oooo0?ooo`0000008P3oool00`00
0000oooo0?ooo`050?ooo`030000003oool0oooo00P0oooo0`00000<0?ooo`030000003oool0oooo
01H0oooo0`0000070?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool04@3oool00`00
0000oooo0?ooo`0E0?ooo`030000003oool0oooo03@0oooo00<000000?ooo`3oool0=`3oool00`00
0000oooo0000000Z0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool01`3oool00`00
0000oooo0?ooo`030?ooo`030000003oool0oooo04D0oooo00<000000?ooo`3oool03@3oool00`00
0000oooo0?ooo`0:0?ooo`030000003oool0oooo00l0oooo00<000000?ooo`3oool01`3oool00`00
0000oooo0?ooo`080?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool04P3oool00`00
0000oooo0?ooo`0G0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool00`3oool20000
02H0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`070?ooo`040000003oool00000
000000H0oooo00<000000?ooo`3oool04P3oool00`000000oooo0?ooo`0F0?ooo`005@3oool00`00
0000oooo0?ooo`0B0?ooo`8000007@3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo
00<0oooo00<000000?ooo`3oool04`3oool00`000000oooo0?ooo`060?ooo`80000000D0oooo0000
003oool0oooo0000000R0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool0203oool3
000000`0oooo00<000000?ooo`3oool05P3oool3000000L0oooo00<000000?ooo`3oool01P3oool0
0`000000oooo0?ooo`0A0?ooo`030000003oool0oooo01D0oooo00<000000?ooo`3oool0=03oool0
0`000000oooo0?ooo`0g0?ooo`030000003oool0000002X0oooo00<000000?ooo`3oool02@3oool0
0`000000oooo0?ooo`070?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0A@3oool0
0`000000oooo0?ooo`0=0?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool03`3oool0
0`000000oooo0?ooo`070?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool01P3oool0
0`000000oooo0?ooo`0B0?ooo`030000003oool0oooo01L0oooo00<000000?ooo`3oool01@3oool0
0`000000oooo0?ooo`030?ooo`8000009P3oool00`000000oooo0?ooo`060?ooo`030000003oool0
oooo00L0oooo00@000000?ooo`00000000001P3oool00`000000oooo0?ooo`0B0?ooo`030000003o
ool0oooo01H0oooo000E0?ooo`030000003oool0oooo0180oooo0P00000M0?ooo`030000003oool0
oooo0080oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`0C0?ooo`030000003oool0
oooo00H0oooo0P0000001@3oool000000?ooo`3oool000000280oooo00<000000?ooo`3oool01@3o
ool00`000000oooo0?ooo`080?ooo`<00000303oool00`000000oooo0?ooo`0F0?ooo`<000001`3o
ool00`000000oooo0?ooo`060?ooo`030000003oool0oooo0140oooo00<000000?ooo`3oool05@3o
ool00`000000oooo0?ooo`0d0?ooo`030000003oool0oooo03L0oooo00<000000?ooo`000000:P3o
ool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool00`3o
ool00`000000oooo0?ooo`150?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool02P3o
ool00`000000oooo0?ooo`0?0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool0203o
ool00`000000oooo0?ooo`060?ooo`030000003oool0oooo0180oooo00<000000?ooo`3oool05`3o
ool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00<0oooo0P00000V0?ooo`030000003o
ool0oooo00H0oooo00<000000?ooo`3oool01`3oool010000000oooo0000000000060?ooo`030000
003oool0oooo0180oooo00<000000?ooo`3oool05P3oool001D0oooo00<000000?ooo`3oool04P3o
ool2000001d0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`030?ooo`030000003o
ool0oooo01<0oooo00<000000?ooo`3oool01P3oool2000000050?ooo`000000oooo0?ooo`000000
8P3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00P0oooo0`00000<0?ooo`030000
003oool0oooo01H0oooo0`0000070?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool0
4@3oool00`000000oooo0?ooo`0E0?ooo`030000003oool0oooo03@0oooo00<000000?ooo`3oool0
=`3oool00`000000oooo0000000Z0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool0
1`3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo04D0oooo00<000000?ooo`3oool0
3@3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo00l0oooo00<000000?ooo`3oool0
1`3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool0
4P3oool00`000000oooo0?ooo`0G0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool0
0`3oool2000002H0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`070?ooo`040000
003oool00000000000H0oooo00<000000?ooo`3oool04P3oool00`000000oooo0?ooo`0F0?ooo`00
5@3oool00`000000oooo0?ooo`0B0?ooo`8000007@3oool00`000000oooo0?ooo`020?ooo`030000
003oool0oooo00<0oooo00<000000?ooo`3oool04`3oool00`000000oooo0?ooo`060?ooo`800000
00D0oooo0000003oool0oooo0000000R0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3o
ool0203oool3000000`0oooo00<000000?ooo`3oool05P3oool3000000L0oooo00<000000?ooo`3o
ool01P3oool00`000000oooo0?ooo`0A0?ooo`030000003oool0oooo01D0oooo00<000000?ooo`3o
ool0=03oool00`000000oooo0?ooo`0g0?ooo`030000003oool0000002X0oooo00<000000?ooo`3o
ool02@3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3o
ool0A@3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3o
ool03`3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3o
ool01P3oool00`000000oooo0?ooo`0B0?ooo`030000003oool0oooo01L0oooo00<000000?ooo`3o
ool01@3oool00`000000oooo0?ooo`030?ooo`8000009P3oool00`000000oooo0?ooo`060?ooo`03
0000003oool0oooo00L0oooo00@000000?ooo`00000000001P3oool00`000000oooo0?ooo`0B0?oo
o`030000003oool0oooo01H0oooo000E0?ooo`030000003oool0oooo0180oooo0P00000M0?ooo`03
0000003oool0oooo0080oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`0C0?ooo`03
0000003oool0oooo00H0oooo0P0000001@3oool000000?ooo`3oool000000280oooo00<000000?oo
o`3oool01@3oool00`000000oooo0?ooo`080?ooo`<00000303oool00`000000oooo0?ooo`0F0?oo
o`<000001`3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo0140oooo00<000000?oo
o`3oool05@3oool00`000000oooo0?ooo`0d0?ooo`030000003oool0oooo03L0oooo00<000000?oo
o`000000:P3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00L0oooo00<000000?oo
o`3oool00`3oool00`000000oooo0?ooo`150?ooo`030000003oool0oooo00d0oooo00<000000?oo
o`3oool02P3oool00`000000oooo0?ooo`0?0?ooo`030000003oool0oooo00L0oooo00<000000?oo
o`3oool0203oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo0180oooo00<000000?oo
o`3oool05`3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00<0oooo0P00000V0?oo
o`030000003oool0oooo00H0oooo00<000000?ooo`3oool01`3oool010000000oooo000000000006
0?ooo`030000003oool0oooo0180oooo00<000000?ooo`3oool05P3oool001D0oooo00<000000?oo
o`3oool04P3oool2000001d0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`030?oo
o`030000003oool0oooo01<0oooo00<000000?ooo`3oool01P3oool2000000050?ooo`000000oooo
0?ooo`0000008P3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00P0oooo0`00000<
0?ooo`030000003oool0oooo01H0oooo0`0000070?ooo`030000003oool0oooo00H0oooo00<00000
0?ooo`3oool04@3oool00`000000oooo0?ooo`0E0?ooo`030000003oool0oooo03@0oooo00<00000
0?ooo`3oool0=`3oool00`000000oooo0000000Z0?ooo`030000003oool0oooo00T0oooo00<00000
0?ooo`3oool01`3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo04D0oooo00<00000
0?ooo`3oool03@3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo00l0oooo00<00000
0?ooo`3oool01`3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo00H0oooo00<00000
0?ooo`3oool04P3oool00`000000oooo0?ooo`0G0?ooo`030000003oool0oooo00D0oooo00<00000
0?ooo`3oool00`3oool2000002H0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`07
0?ooo`040000003oool00000000000H0oooo00<000000?ooo`3oool04P3oool00`000000oooo0?oo
o`0F0?ooo`00503ooolF0?oo0080003oo`3oo`3o0?oo0=H0ool05@3oool001D0oooo00<000000?oo
o`3oool04P3oool2000001d0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`030?oo
o`030000003oool0oooo01<0oooo00<000000?ooo`3oool01P3oool2000000050?ooo`000000oooo
0?ooo`0000008P3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00P0oooo0`00000<
0?ooo`030000003oool0oooo01H0oooo0`0000070?ooo`030000003oool0oooo00H0oooo00<00000
0?ooo`3oool04@3oool00`000000oooo0?ooo`0E0?ooo`030000003oool0oooo03@0oooo00<00000
0?ooo`3oool0=`3oool00`000000oooo0000000Z0?ooo`030000003oool0oooo00T0oooo00<00000
0?ooo`3oool01`3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo04D0oooo00<00000
0?ooo`3oool03@3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo00l0oooo00<00000
0?ooo`3oool01`3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo00H0oooo00<00000
0?ooo`3oool04P3oool00`000000oooo0?ooo`0G0?ooo`030000003oool0oooo00D0oooo00<00000
0?ooo`3oool00`3oool2000002H0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`07
0?ooo`040000003oool00000000000H0oooo00<000000?ooo`3oool04P3oool00`000000oooo0?oo
o`0F0?ooo`005@3oool00`000000oooo0?ooo`0B0?ooo`8000007@3oool00`000000oooo0?ooo`02
0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool04`3oool00`000000oooo0?ooo`06
0?ooo`80000000D0oooo0000003oool0oooo0000000R0?ooo`030000003oool0oooo00D0oooo00<0
00000?ooo`3oool0203oool3000000`0oooo00<000000?ooo`3oool05P3oool3000000L0oooo00<0
00000?ooo`3oool01P3oool00`000000oooo0?ooo`0A0?ooo`030000003oool0oooo01D0oooo00<0
00000?ooo`3oool0=03oool00`000000oooo0?ooo`0g0?ooo`030000003oool0000002X0oooo00<0
00000?ooo`3oool02@3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00<0oooo00<0
00000?ooo`3oool0A@3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo00X0oooo00<0
00000?ooo`3oool03`3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00P0oooo00<0
00000?ooo`3oool01P3oool00`000000oooo0?ooo`0B0?ooo`030000003oool0oooo01L0oooo00<0
00000?ooo`3oool01@3oool00`000000oooo0?ooo`030?ooo`8000009P3oool00`000000oooo0?oo
o`060?ooo`030000003oool0oooo00L0oooo00@000000?ooo`00000000001P3oool00`000000oooo
0?ooo`0B0?ooo`030000003oool0oooo01H0oooo000E0?ooo`030000003oool0oooo0180oooo0P00
000M0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool00`3oool00`000000oooo0?oo
o`0C0?ooo`030000003oool0oooo00H0oooo0P0000001@3oool000000?ooo`3oool000000280oooo
00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`080?ooo`<00000303oool00`000000oooo
0?ooo`0F0?ooo`<000001`3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo0140oooo
00<000000?ooo`3oool05@3oool00`000000oooo0?ooo`0d0?ooo`030000003oool0oooo03L0oooo
00<000000?ooo`000000:P3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00L0oooo
00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`150?ooo`030000003oool0oooo00d0oooo
00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`0?0?ooo`030000003oool0oooo00L0oooo
00<000000?ooo`3oool0203oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo0180oooo
00<000000?ooo`3oool05`3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00<0oooo
0P00000V0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool01`3oool010000000oooo
0000000000060?ooo`030000003oool0oooo0180oooo00<000000?ooo`3oool05P3oool001D0oooo
00<000000?ooo`3oool04P3oool2000001d0oooo00<000000?ooo`3oool00P3oool00`000000oooo
0?ooo`030?ooo`030000003oool0oooo01<0oooo00<000000?ooo`3oool01P3oool2000000050?oo
o`000000oooo0?ooo`0000008P3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00P0
oooo0`00000<0?ooo`030000003oool0oooo01H0oooo0`0000070?ooo`030000003oool0oooo00H0
oooo00<000000?ooo`3oool04@3oool00`000000oooo0?ooo`0E0?ooo`030000003oool0oooo03@0
oooo00<000000?ooo`3oool0=`3oool00`000000oooo0000000Z0?ooo`030000003oool0oooo00T0
oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo04D0
oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo00l0
oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo00H0
oooo00<000000?ooo`3oool04P3oool00`000000oooo0?ooo`0G0?ooo`030000003oool0oooo00D0
oooo00<000000?ooo`3oool00`3oool2000002H0oooo00<000000?ooo`3oool01P3oool00`000000
oooo0?ooo`070?ooo`040000003oool00000000000H0oooo00<000000?ooo`3oool04P3oool00`00
0000oooo0?ooo`0F0?ooo`005@3oool00`000000oooo0?ooo`0B0?ooo`8000007@3oool00`000000
oooo0?ooo`020?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool04`3oool00`000000
oooo0?ooo`060?ooo`80000000D0oooo0000003oool0oooo0000000R0?ooo`030000003oool0oooo
00D0oooo00<000000?ooo`3oool0203oool3000000`0oooo00<000000?ooo`3oool05P3oool30000
00L0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`0A0?ooo`030000003oool0oooo
01D0oooo00<000000?ooo`3oool0=03oool00`000000oooo0?ooo`0g0?ooo`030000003oool00000
02X0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo
00<0oooo00<000000?ooo`3oool0A@3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo
00X0oooo00<000000?ooo`3oool03`3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo
00P0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`0B0?ooo`030000003oool0oooo
01L0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`030?ooo`8000009P3oool00`00
0000oooo0?ooo`060?ooo`030000003oool0oooo00L0oooo00@000000?ooo`00000000001P3oool0
0`000000oooo0?ooo`0B0?ooo`030000003oool0oooo01H0oooo000E0?ooo`030000003oool0oooo
0180oooo0P00000M0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool00`3oool00`00
0000oooo0?ooo`0C0?ooo`030000003oool0oooo00H0oooo0P0000001@3oool000000?ooo`3oool0
00000280oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`080?ooo`<00000303oool0
0`000000oooo0?ooo`0F0?ooo`<000001`3oool00`000000oooo0?ooo`060?ooo`030000003oool0
oooo0140oooo00<000000?ooo`3oool05@3oool00`000000oooo0?ooo`0d0?ooo`030000003oool0
oooo03L0oooo00<000000?ooo`000000:P3oool00`000000oooo0?ooo`090?ooo`030000003oool0
oooo00L0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`150?ooo`030000003oool0
oooo00d0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`0?0?ooo`030000003oool0
oooo00L0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`060?ooo`030000003oool0
oooo0180oooo00<000000?ooo`3oool05`3oool00`000000oooo0?ooo`050?ooo`030000003oool0
oooo00<0oooo0P00000V0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool01`3oool0
10000000oooo0000000000060?ooo`030000003oool0oooo0180oooo00<000000?ooo`3oool05P3o
ool001D0oooo00<000000?ooo`3oool04P3oool2000001d0oooo00<000000?ooo`3oool00P3oool0
0`000000oooo0?ooo`030?ooo`030000003oool0oooo01<0oooo00<000000?ooo`3oool01P3oool2
000000050?ooo`000000oooo0?ooo`0000008P3oool00`000000oooo0?ooo`050?ooo`030000003o
ool0oooo00P0oooo0`00000<0?ooo`030000003oool0oooo01H0oooo0`0000070?ooo`030000003o
ool0oooo00H0oooo00<000000?ooo`3oool04@3oool00`000000oooo0?ooo`0E0?ooo`030000003o
ool0oooo03@0oooo00<000000?ooo`3oool0=`3oool00`000000oooo0000000Z0?ooo`030000003o
ool0oooo00T0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`030?ooo`030000003o
ool0oooo04D0oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`0:0?ooo`030000003o
ool0oooo00l0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`080?ooo`030000003o
ool0oooo00H0oooo00<000000?ooo`3oool04P3oool00`000000oooo0?ooo`0G0?ooo`030000003o
ool0oooo00D0oooo00<000000?ooo`3oool00`3oool2000002H0oooo00<000000?ooo`3oool01P3o
ool00`000000oooo0?ooo`070?ooo`040000003oool00000000000H0oooo00<000000?ooo`3oool0
4P3oool00`000000oooo0?ooo`0F0?ooo`00503ooolj0?oo00L0003oo`3oo`3o0?oo0:d0ool05@3o
ool001D0oooo00<000000?ooo`3oool04P3oool2000001d0oooo00<000000?ooo`3oool00P3oool0
0`000000oooo0?ooo`030?ooo`030000003oool0oooo01<0oooo00<000000?ooo`3oool01P3oool2
000000050?ooo`000000oooo0?ooo`0000008P3oool00`000000oooo0?ooo`050?ooo`030000003o
ool0oooo00P0oooo0`00000<0?ooo`030000003oool0oooo01H0oooo0`0000070?ooo`030000003o
ool0oooo00H0oooo00<000000?ooo`3oool04@3oool00`000000oooo0?ooo`0E0?ooo`030000003o
ool0oooo03@0oooo00<000000?ooo`3oool0=`3oool00`000000oooo0000000Z0?ooo`030000003o
ool0oooo00T0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`030?ooo`030000003o
ool0oooo04D0oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`0:0?ooo`030000003o
ool0oooo00l0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`080?ooo`030000003o
ool0oooo00H0oooo00<000000?ooo`3oool04P3oool00`000000oooo0?ooo`0G0?ooo`030000003o
ool0oooo00D0oooo00<000000?ooo`3oool00`3oool2000002H0oooo00<000000?ooo`3oool01P3o
ool00`000000oooo0?ooo`070?ooo`040000003oool00000000000H0oooo00<000000?ooo`3oool0
4P3oool00`000000oooo0?ooo`0F0?ooo`005@3oool00`000000oooo0?ooo`0B0?ooo`8000007@3o
ool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool04`3o
ool00`000000oooo0?ooo`060?ooo`80000000D0oooo0000003oool0oooo0000000R0?ooo`030000
003oool0oooo00D0oooo00<000000?ooo`3oool0203oool3000000`0oooo00<000000?ooo`3oool0
5P3oool3000000L0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`0A0?ooo`030000
003oool0oooo01D0oooo00<000000?ooo`3oool0=03oool00`000000oooo0?ooo`0g0?ooo`030000
003oool0000002X0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`070?ooo`030000
003oool0oooo00<0oooo00<000000?ooo`3oool0A@3oool00`000000oooo0?ooo`0=0?ooo`030000
003oool0oooo00X0oooo00<000000?ooo`3oool03`3oool00`000000oooo0?ooo`070?ooo`030000
003oool0oooo00P0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`0B0?ooo`030000
003oool0oooo01L0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`030?ooo`800000
9P3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00L0oooo00@000000?ooo`000000
00001P3oool00`000000oooo0?ooo`0B0?ooo`030000003oool0oooo01H0oooo000E0?ooo`030000
003oool0oooo0180oooo0P00000M0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0
0`3oool00`000000oooo0?ooo`0C0?ooo`030000003oool0oooo00H0oooo0P0000001@3oool00000
0?ooo`3oool000000280oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`080?ooo`<0
0000303oool00`000000oooo0?ooo`0F0?ooo`<000001`3oool00`000000oooo0?ooo`060?ooo`03
0000003oool0oooo0140oooo00<000000?ooo`3oool05@3oool00`000000oooo0?ooo`0d0?ooo`03
0000003oool0oooo03L0oooo00<000000?ooo`000000:P3oool00`000000oooo0?ooo`090?ooo`03
0000003oool0oooo00L0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`150?ooo`03
0000003oool0oooo00d0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`0?0?ooo`03
0000003oool0oooo00L0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`060?ooo`03
0000003oool0oooo0180oooo00<000000?ooo`3oool05`3oool00`000000oooo0?ooo`050?ooo`03
0000003oool0oooo00<0oooo0P00000V0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3o
ool01`3oool010000000oooo0000000000060?ooo`030000003oool0oooo0180oooo00<000000?oo
o`3oool05P3oool001D0oooo00<000000?ooo`3oool04P3oool2000001d0oooo00<000000?ooo`3o
ool00P3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo01<0oooo00<000000?ooo`3o
ool01P3oool2000000050?ooo`000000oooo0?ooo`0000008P3oool00`000000oooo0?ooo`050?oo
o`030000003oool0oooo00P0oooo0`00000<0?ooo`030000003oool0oooo01H0oooo0`0000070?oo
o`030000003oool0oooo00H0oooo00<000000?ooo`3oool04@3oool00`000000oooo0?ooo`0E0?oo
o`030000003oool0oooo03@0oooo00<000000?ooo`3oool0=`3oool00`000000oooo0000000Z0?oo
o`030000003oool0oooo00T0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`030?oo
o`030000003oool0oooo04D0oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`0:0?oo
o`030000003oool0oooo00l0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`080?oo
o`030000003oool0oooo00H0oooo00<000000?ooo`3oool04P3oool00`000000oooo0?ooo`0G0?oo
o`030000003oool0oooo00D0oooo00<000000?ooo`3oool00`3oool2000002H0oooo00<000000?oo
o`3oool01P3oool00`000000oooo0?ooo`070?ooo`040000003oool00000000000H0oooo00<00000
0?ooo`3oool04P3oool00`000000oooo0?ooo`0F0?ooo`005@3oool00`000000oooo0?ooo`0B0?oo
o`8000007@3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00<0oooo00<000000?oo
o`3oool04`3oool00`000000oooo0?ooo`060?ooo`80000000D0oooo0000003oool0oooo0000000R
0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool0203oool3000000`0oooo00<00000
0?ooo`3oool05P3oool3000000L0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`0A
0?ooo`030000003oool0oooo01D0oooo00<000000?ooo`3oool0=03oool00`000000oooo0?ooo`0g
0?ooo`030000003oool0000002X0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`07
0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0A@3oool00`000000oooo0?ooo`0=
0?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool03`3oool00`000000oooo0?ooo`07
0?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`0B
0?ooo`030000003oool0oooo01L0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`03
0?ooo`8000009P3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00L0oooo00@00000
0?ooo`00000000001P3oool00`000000oooo0?ooo`0B0?ooo`030000003oool0oooo01H0oooo000E
0?ooo`030000003oool0oooo0180oooo0P00000M0?ooo`030000003oool0oooo0080oooo00<00000
0?ooo`3oool00`3oool00`000000oooo0?ooo`0C0?ooo`030000003oool0oooo00H0oooo0P000000
1@3oool000000?ooo`3oool000000280oooo00<000000?ooo`3oool01@3oool00`000000oooo0?oo
o`080?ooo`<00000303oool00`000000oooo0?ooo`0F0?ooo`<000001`3oool00`000000oooo0?oo
o`060?ooo`030000003oool0oooo0140oooo00<000000?ooo`3oool05@3oool00`000000oooo0?oo
o`0d0?ooo`030000003oool0oooo03L0oooo00<000000?ooo`000000:P3oool00`000000oooo0?oo
o`090?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?oo
o`150?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?oo
o`0?0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool0203oool00`000000oooo0?oo
o`060?ooo`030000003oool0oooo0180oooo00<000000?ooo`3oool05`3oool00`000000oooo0?oo
o`050?ooo`030000003oool0oooo00<0oooo0P00000V0?ooo`030000003oool0oooo00H0oooo00<0
00000?ooo`3oool01`3oool010000000oooo0000000000060?ooo`030000003oool0oooo0180oooo
00<000000?ooo`3oool05P3oool001D0oooo00<000000?ooo`3oool04P3oool2000001d0oooo00<0
00000?ooo`3oool00P3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo01<0oooo00<0
00000?ooo`3oool01P3oool2000000050?ooo`000000oooo0?ooo`0000008P3oool00`000000oooo
0?ooo`050?ooo`030000003oool0oooo00P0oooo0`00000<0?ooo`030000003oool0oooo01H0oooo
0`0000070?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool04@3oool00`000000oooo
0?ooo`0E0?ooo`030000003oool0oooo03@0oooo00<000000?ooo`3oool0=`3oool00`000000oooo
0000000Z0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool01`3oool00`000000oooo
0?ooo`030?ooo`030000003oool0oooo04D0oooo00<000000?ooo`3oool03@3oool00`000000oooo
0?ooo`0:0?ooo`030000003oool0oooo00l0oooo00<000000?ooo`3oool01`3oool00`000000oooo
0?ooo`080?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool04P3oool00`000000oooo
0?ooo`0G0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool00`3oool2000002H0oooo
00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`070?ooo`040000003oool00000000000H0
oooo00<000000?ooo`3oool04P3oool00`000000oooo0?ooo`0F0?ooo`00503ooooF0?oo01D0003o
o`3oo`3o0?oo00<0ool05@3oool001D0oooo00<000000?ooo`3oool04P3oool2000001d0oooo00<0
00000?ooo`3oool00P3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo01<0oooo00<0
00000?ooo`3oool01P3oool2000000050?ooo`000000oooo0?ooo`0000008P3oool00`000000oooo
0?ooo`050?ooo`030000003oool0oooo00P0oooo0`00000<0?ooo`030000003oool0oooo01H0oooo
0`0000070?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool04@3oool00`000000oooo
0?ooo`0E0?ooo`030000003oool0oooo03@0oooo00<000000?ooo`3oool0=`3oool00`000000oooo
0000000Z0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool01`3oool00`000000oooo
0?ooo`030?ooo`030000003oool0oooo04D0oooo00<000000?ooo`3oool03@3oool00`000000oooo
0?ooo`0:0?ooo`030000003oool0oooo00l0oooo00<000000?ooo`3oool01`3oool00`000000oooo
0?ooo`080?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool04P3oool00`000000oooo
0?ooo`0G0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool00`3oool2000002H0oooo
00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`070?ooo`040000003oool00000000000H0
oooo00<000000?ooo`3oool04P3oool00`000000oooo0?ooo`0F0?ooo`005@3oool00`000000oooo
0?ooo`0B0?ooo`8000007@3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00<0oooo
00<000000?ooo`3oool04`3oool00`000000oooo0?ooo`060?ooo`80000000D0oooo0000003oool0
oooo0000000R0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool0203oool3000000`0
oooo00<000000?ooo`3oool05P3oool3000000L0oooo00<000000?ooo`3oool01P3oool00`000000
oooo0?ooo`0A0?ooo`030000003oool0oooo01D0oooo00<000000?ooo`3oool0=03oool00`000000
oooo0?ooo`0g0?ooo`030000003oool0000002X0oooo00<000000?ooo`3oool02@3oool00`000000
oooo0?ooo`070?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0A@3oool00`000000
oooo0?ooo`0=0?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool03`3oool00`000000
oooo0?ooo`070?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool01P3oool00`000000
oooo0?ooo`0B0?ooo`030000003oool0oooo01L0oooo00<000000?ooo`3oool01@3oool00`000000
oooo0?ooo`030?ooo`8000009P3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00L0
oooo00@000000?ooo`00000000001P3oool00`000000oooo0?ooo`0B0?ooo`030000003oool0oooo
01H0oooo000E0?ooo`030000003oool0oooo0180oooo0P00000M0?ooo`030000003oool0oooo0080
oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`0C0?ooo`030000003oool0oooo00H0
oooo0P0000001@3oool000000?ooo`3oool000000280oooo00<000000?ooo`3oool01@3oool00`00
0000oooo0?ooo`080?ooo`<00000303oool00`000000oooo0?ooo`0F0?ooo`<000001`3oool00`00
0000oooo0?ooo`060?ooo`030000003oool0oooo0140oooo00<000000?ooo`3oool05@3oool00`00
0000oooo0?ooo`0d0?ooo`030000003oool0oooo03L0oooo00<000000?ooo`000000:P3oool00`00
0000oooo0?ooo`090?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool00`3oool00`00
0000oooo0?ooo`150?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool02P3oool00`00
0000oooo0?ooo`0?0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool0203oool00`00
0000oooo0?ooo`060?ooo`030000003oool0oooo0180oooo00<000000?ooo`3oool05`3oool00`00
0000oooo0?ooo`050?ooo`030000003oool0oooo00<0oooo0P00000V0?ooo`030000003oool0oooo
00H0oooo00<000000?ooo`3oool01`3oool010000000oooo0000000000060?ooo`030000003oool0
oooo0180oooo00<000000?ooo`3oool05P3oool001D0oooo00<000000?ooo`3oool04P3oool20000
01d0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo
01<0oooo00<000000?ooo`3oool01P3oool2000000050?ooo`000000oooo0?ooo`0000008P3oool0
0`000000oooo0?ooo`050?ooo`030000003oool0oooo00P0oooo0`00000<0?ooo`030000003oool0
oooo01H0oooo0`0000070?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool04@3oool0
0`000000oooo0?ooo`0E0?ooo`030000003oool0oooo03@0oooo00<000000?ooo`3oool0=`3oool0
0`000000oooo0000000Z0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool01`3oool0
0`000000oooo0?ooo`030?ooo`030000003oool0oooo04D0oooo00<000000?ooo`3oool03@3oool0
0`000000oooo0?ooo`0:0?ooo`030000003oool0oooo00l0oooo00<000000?ooo`3oool01`3oool0
0`000000oooo0?ooo`080?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool04P3oool0
0`000000oooo0?ooo`0G0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool00`3oool2
000002H0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`070?ooo`040000003oool0
0000000000H0oooo00<000000?ooo`3oool04P3oool00`000000oooo0?ooo`0F0?ooo`005@3oool0
0`000000oooo0?ooo`0B0?ooo`8000007@3oool00`000000oooo0?ooo`020?ooo`030000003oool0
oooo00<0oooo00<000000?ooo`3oool04`3oool00`000000oooo0?ooo`060?ooo`80000000D0oooo
0000003oool0oooo0000000R0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool0203o
ool3000000`0oooo00<000000?ooo`3oool05P3oool3000000L0oooo00<000000?ooo`3oool01P3o
ool00`000000oooo0?ooo`0A0?ooo`030000003oool0oooo01D0oooo00<000000?ooo`3oool0=03o
ool00`000000oooo0?ooo`0g0?ooo`030000003oool0000002X0oooo00<000000?ooo`3oool02@3o
ool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0A@3o
ool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool03`3o
ool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool01P3o
ool00`000000oooo0?ooo`0B0?ooo`030000003oool0oooo01L0oooo00<000000?ooo`3oool01@3o
ool00`000000oooo0?ooo`030?ooo`8000009P3oool00`000000oooo0?ooo`060?ooo`030000003o
ool0oooo00L0oooo00@000000?ooo`00000000001P3oool00`000000oooo0?ooo`0B0?ooo`030000
003oool0oooo01H0oooo000E0?ooo`030000003oool0oooo0180oooo0P00000M0?ooo`030000003o
ool0oooo0080oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`0C0?ooo`030000003o
ool0oooo00H0oooo0P0000001@3oool000000?ooo`3oool000000280oooo00<000000?ooo`3oool0
1@3oool00`000000oooo0?ooo`080?ooo`<00000303oool00`000000oooo0?ooo`0F0?ooo`<00000
1`3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo0140oooo00<000000?ooo`3oool0
5@3oool00`000000oooo0?ooo`0d0?ooo`030000003oool0oooo03L0oooo00<000000?ooo`000000
:P3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool0
0`3oool00`000000oooo0?ooo`150?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool0
2P3oool00`000000oooo0?ooo`0?0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool0
203oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo0180oooo00<000000?ooo`3oool0
5`3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00<0oooo0P00000V0?ooo`030000
003oool0oooo00H0oooo00<000000?ooo`3oool01`3oool010000000oooo0000000000060?ooo`03
0000003oool0oooo0180oooo00<000000?ooo`3oool05P3oool001@0ooooo`3oo`1d0?oo00<0003o
:P3oo`0=0000o`T0ool01`000?mT0?oo01<0003o2@3oo`0<0000oj<0ool05@3oool001D0oooo00<0
00000?ooo`3oool04P3oool2000001d0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?oo
o`030?ooo`030000003oool0oooo01<0oooo00<000000?ooo`3oool01P3oool2000000050?ooo`00
0000oooo0?ooo`0000008P3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00P0oooo
0`00000<0?ooo`030000003oool0oooo01H0oooo0`0000070?ooo`030000003oool0oooo00H0oooo
00<000000?ooo`3oool04@3oool00`000000oooo0?ooo`0E0?ooo`030000003oool0oooo03@0oooo
00<000000?ooo`3oool0=`3oool00`000000oooo0000000Z0?ooo`030000003oool0oooo00T0oooo
00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo04D0oooo
00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo00l0oooo
00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo00H0oooo
00<000000?ooo`3oool04P3oool00`000000oooo0?ooo`0G0?ooo`030000003oool0oooo00D0oooo
00<000000?ooo`3oool00`3oool2000002H0oooo00<000000?ooo`3oool01P3oool00`000000oooo
0?ooo`070?ooo`040000003oool00000000000H0oooo00<000000?ooo`3oool04P3oool00`000000
oooo0?ooo`0F0?ooo`005@3oool00`000000oooo0?ooo`0B0?ooo`8000007@3oool00`000000oooo
0?ooo`020?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool04`3oool00`000000oooo
0?ooo`060?ooo`80000000D0oooo0000003oool0oooo0000000R0?ooo`030000003oool0oooo00D0
oooo00<000000?ooo`3oool0203oool3000000`0oooo00<000000?ooo`3oool05P3oool3000000L0
oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`0A0?ooo`030000003oool0oooo01D0
oooo00<000000?ooo`3oool0=03oool00`000000oooo0?ooo`0g0?ooo`030000003oool0000002X0
oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00<0
oooo00<000000?ooo`3oool0A@3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo00X0
oooo00<000000?ooo`3oool03`3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00P0
oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`0B0?ooo`030000003oool0oooo01L0
oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`030?ooo`8000009P3oool00`000000
oooo0?ooo`060?ooo`030000003oool0oooo00L0oooo00@000000?ooo`00000000001P3oool00`00
0000oooo0?ooo`0B0?ooo`030000003oool0oooo01H0oooo000E0?ooo`030000003oool0oooo0180
oooo0P00000M0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool00`3oool00`000000
oooo0?ooo`0C0?ooo`030000003oool0oooo00H0oooo0P0000001@3oool000000?ooo`3oool00000
0280oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`080?ooo`<00000303oool00`00
0000oooo0?ooo`0F0?ooo`<000001`3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo
0140oooo00<000000?ooo`3oool05@3oool00`000000oooo0?ooo`0d0?ooo`030000003oool0oooo
03L0oooo00<000000?ooo`000000:P3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo
00L0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`150?ooo`030000003oool0oooo
00d0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`0?0?ooo`030000003oool0oooo
00L0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo
0180oooo00<000000?ooo`3oool05`3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo
00<0oooo0P00000V0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool01`3oool01000
0000oooo0000000000060?ooo`030000003oool0oooo0180oooo00<000000?ooo`3oool05P3oool0
01D0oooo00<000000?ooo`3oool04P3oool2000001d0oooo00<000000?ooo`3oool00P3oool00`00
0000oooo0?ooo`030?ooo`030000003oool0oooo01<0oooo00<000000?ooo`3oool01P3oool20000
00050?ooo`000000oooo0?ooo`0000008P3oool00`000000oooo0?ooo`050?ooo`030000003oool0
oooo00P0oooo0`00000<0?ooo`030000003oool0oooo01H0oooo0`0000070?ooo`030000003oool0
oooo00H0oooo00<000000?ooo`3oool04@3oool00`000000oooo0?ooo`0E0?ooo`030000003oool0
oooo03@0oooo00<000000?ooo`3oool0=`3oool00`000000oooo0000000Z0?ooo`030000003oool0
oooo00T0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`030?ooo`030000003oool0
oooo04D0oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0
oooo00l0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`080?ooo`030000003oool0
oooo00H0oooo00<000000?ooo`3oool04P3oool00`000000oooo0?ooo`0G0?ooo`030000003oool0
oooo00D0oooo00<000000?ooo`3oool00`3oool2000002H0oooo00<000000?ooo`3oool01P3oool0
0`000000oooo0?ooo`070?ooo`040000003oool00000000000H0oooo00<000000?ooo`3oool04P3o
ool00`000000oooo0?ooo`0F0?ooo`005@3oool00`000000oooo0?ooo`0B0?ooo`8000007@3oool0
0`000000oooo0?ooo`020?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool04`3oool0
0`000000oooo0?ooo`060?ooo`80000000D0oooo0000003oool0oooo0000000R0?ooo`030000003o
ool0oooo00D0oooo00<000000?ooo`3oool0203oool3000000`0oooo00<000000?ooo`3oool05P3o
ool3000000L0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`0A0?ooo`030000003o
ool0oooo01D0oooo00<000000?ooo`3oool0=03oool00`000000oooo0?ooo`0g0?ooo`030000003o
ool0000002X0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`070?ooo`030000003o
ool0oooo00<0oooo00<000000?ooo`3oool0A@3oool00`000000oooo0?ooo`0=0?ooo`030000003o
ool0oooo00X0oooo00<000000?ooo`3oool03`3oool00`000000oooo0?ooo`070?ooo`030000003o
ool0oooo00P0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`0B0?ooo`030000003o
ool0oooo01L0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`030?ooo`8000009P3o
ool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00L0oooo00@000000?ooo`0000000000
1P3oool00`000000oooo0?ooo`0B0?ooo`030000003oool0oooo01H0oooo000E0?ooo`030000003o
ool0oooo0180oooo0P00000M0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool00`3o
ool00`000000oooo0?ooo`0C0?ooo`030000003oool0oooo00H0oooo0P0000001@3oool000000?oo
o`3oool000000280oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`080?ooo`<00000
303oool00`000000oooo0?ooo`0F0?ooo`<000001`3oool00`000000oooo0?ooo`060?ooo`030000
003oool0oooo0140oooo00<000000?ooo`3oool05@3oool00`000000oooo0?ooo`0d0?ooo`030000
003oool0oooo03L0oooo00<000000?ooo`000000:P3oool00`000000oooo0?ooo`090?ooo`030000
003oool0oooo00L0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`150?ooo`030000
003oool0oooo00d0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`0?0?ooo`030000
003oool0oooo00L0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`060?ooo`030000
003oool0oooo0180oooo00<000000?ooo`3oool05`3oool00`000000oooo0?ooo`050?ooo`030000
003oool0oooo00<0oooo0P00000V0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool0
1`3oool010000000oooo0000000000060?ooo`030000003oool0oooo0180oooo00<000000?ooo`3o
ool05P3oool001D0oooo00<000000?ooo`3oool04P3oool2000001d0oooo00<000000?ooo`3oool0
0P3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo01<0oooo00<000000?ooo`3oool0
1P3oool2000000050?ooo`000000oooo0?ooo`0000008P3oool00`000000oooo0?ooo`050?ooo`03
0000003oool0oooo00P0oooo0`00000<0?ooo`030000003oool0oooo01H0oooo0`0000070?ooo`03
0000003oool0oooo00H0oooo00<000000?ooo`3oool04@3oool00`000000oooo0?ooo`0E0?ooo`03
0000003oool0oooo03@0oooo00<000000?ooo`3oool0=`3oool00`000000oooo0000000Z0?ooo`03
0000003oool0oooo00T0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`030?ooo`03
0000003oool0oooo04D0oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`0:0?ooo`03
0000003oool0oooo00l0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`080?ooo`03
0000003oool0oooo00H0oooo00<000000?ooo`3oool04P3oool00`000000oooo0?ooo`0G0?ooo`03
0000003oool0oooo00D0oooo00<000000?ooo`3oool00`3oool2000002H0oooo00<000000?ooo`3o
ool01P3oool00`000000oooo0?ooo`070?ooo`040000003oool00000000000H0oooo00<000000?oo
o`3oool04P3oool00`000000oooo0?ooo`0F0?ooo`00503ooooo0?oo07H0ool0;0000?l;0?oo00/0
003o1@3oo`190000o`l0ool03P000?o:0?oo01D0oooo000E0?ooo`030000003oool0oooo0180oooo
0P00000M0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool00`3oool00`000000oooo
0?ooo`0C0?ooo`030000003oool0oooo00H0oooo0P0000001@3oool000000?ooo`3oool000000280
oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`080?ooo`<00000303oool00`000000
oooo0?ooo`0F0?ooo`<000001`3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo0140
oooo00<000000?ooo`3oool05@3oool00`000000oooo0?ooo`0d0?ooo`030000003oool0oooo03L0
oooo00<000000?ooo`000000:P3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00L0
oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`150?ooo`030000003oool0oooo00d0
oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`0?0?ooo`030000003oool0oooo00L0
oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo0180
oooo00<000000?ooo`3oool05`3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00<0
oooo0P00000V0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool01`3oool010000000
oooo0000000000060?ooo`030000003oool0oooo0180oooo00<000000?ooo`3oool05P3oool001D0
oooo00<000000?ooo`3oool04P3oool2000001d0oooo00<000000?ooo`3oool00P3oool00`000000
oooo0?ooo`030?ooo`030000003oool0oooo01<0oooo00<000000?ooo`3oool01P3oool200000005
0?ooo`000000oooo0?ooo`0000008P3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo
00P0oooo0`00000<0?ooo`030000003oool0oooo01H0oooo0`0000070?ooo`030000003oool0oooo
00H0oooo00<000000?ooo`3oool04@3oool00`000000oooo0?ooo`0E0?ooo`030000003oool0oooo
03@0oooo00<000000?ooo`3oool0=`3oool00`000000oooo0000000Z0?ooo`030000003oool0oooo
00T0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo
04D0oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo
00l0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo
00H0oooo00<000000?ooo`3oool04P3oool00`000000oooo0?ooo`0G0?ooo`030000003oool0oooo
00D0oooo00<000000?ooo`3oool00`3oool2000002H0oooo00<000000?ooo`3oool01P3oool00`00
0000oooo0?ooo`070?ooo`040000003oool00000000000H0oooo00<000000?ooo`3oool04P3oool0
0`000000oooo0?ooo`0F0?ooo`005@3oool00`000000oooo0?ooo`0B0?ooo`8000007@3oool00`00
0000oooo0?ooo`020?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool04`3oool00`00
0000oooo0?ooo`060?ooo`80000000D0oooo0000003oool0oooo0000000R0?ooo`030000003oool0
oooo00D0oooo00<000000?ooo`3oool0203oool3000000`0oooo00<000000?ooo`3oool05P3oool3
000000L0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`0A0?ooo`030000003oool0
oooo01D0oooo00<000000?ooo`3oool0=03oool00`000000oooo0?ooo`0g0?ooo`030000003oool0
000002X0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`070?ooo`030000003oool0
oooo00<0oooo00<000000?ooo`3oool0A@3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0
oooo00X0oooo00<000000?ooo`3oool03`3oool00`000000oooo0?ooo`070?ooo`030000003oool0
oooo00P0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`0B0?ooo`030000003oool0
oooo01L0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`030?ooo`8000009P3oool0
0`000000oooo0?ooo`060?ooo`030000003oool0oooo00L0oooo00@000000?ooo`00000000001P3o
ool00`000000oooo0?ooo`0B0?ooo`030000003oool0oooo01H0oooo000E0?ooo`030000003oool0
oooo0180oooo0P00000M0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool00`3oool0
0`000000oooo0?ooo`0C0?ooo`030000003oool0oooo00H0oooo0P0000001@3oool000000?ooo`3o
ool000000280oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`080?ooo`<00000303o
ool00`000000oooo0?ooo`0F0?ooo`<000001`3oool00`000000oooo0?ooo`060?ooo`030000003o
ool0oooo0140oooo00<000000?ooo`3oool05@3oool00`000000oooo0?ooo`0d0?ooo`030000003o
ool0oooo03L0oooo00<000000?ooo`000000:P3oool00`000000oooo0?ooo`090?ooo`030000003o
ool0oooo00L0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`150?ooo`030000003o
ool0oooo00d0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`0?0?ooo`030000003o
ool0oooo00L0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`060?ooo`030000003o
ool0oooo0180oooo00<000000?ooo`3oool05`3oool00`000000oooo0?ooo`050?ooo`030000003o
ool0oooo00<0oooo0P00000V0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool01`3o
ool010000000oooo0000000000060?ooo`030000003oool0oooo0180oooo00<000000?ooo`3oool0
5P3oool001D0oooo00<000000?ooo`3oool04P3oool2000001d0oooo00<000000?ooo`3oool00P3o
ool00`000000oooo0?ooo`030?ooo`030000003oool0oooo01<0oooo00<000000?ooo`3oool01P3o
ool2000000050?ooo`000000oooo0?ooo`0000008P3oool00`000000oooo0?ooo`050?ooo`030000
003oool0oooo00P0oooo0`00000<0?ooo`030000003oool0oooo01H0oooo0`0000070?ooo`030000
003oool0oooo00H0oooo00<000000?ooo`3oool04@3oool00`000000oooo0?ooo`0E0?ooo`030000
003oool0oooo03@0oooo00<000000?ooo`3oool0=`3oool00`000000oooo0000000Z0?ooo`030000
003oool0oooo00T0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`030?ooo`030000
003oool0oooo04D0oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`0:0?ooo`030000
003oool0oooo00l0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`080?ooo`030000
003oool0oooo00H0oooo00<000000?ooo`3oool04P3oool00`000000oooo0?ooo`0G0?ooo`030000
003oool0oooo00D0oooo00<000000?ooo`3oool00`3oool2000002H0oooo00<000000?ooo`3oool0
1P3oool00`000000oooo0?ooo`070?ooo`040000003oool00000000000H0oooo00<000000?ooo`3o
ool04P3oool00`000000oooo0?ooo`0F0?ooo`005@3oool00`000000oooo0?ooo`0B0?ooo`800000
7@3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0
4`3oool00`000000oooo0?ooo`060?ooo`80000000D0oooo0000003oool0oooo0000000R0?ooo`03
0000003oool0oooo00D0oooo00<000000?ooo`3oool0203oool3000000`0oooo00<000000?ooo`3o
ool05P3oool3000000L0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`0A0?ooo`03
0000003oool0oooo01D0oooo00<000000?ooo`3oool0=03oool00`000000oooo0?ooo`0g0?ooo`03
0000003oool0000002X0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`070?ooo`03
0000003oool0oooo00<0oooo00<000000?ooo`3oool0A@3oool00`000000oooo0?ooo`0=0?ooo`03
0000003oool0oooo00X0oooo00<000000?ooo`3oool03`3oool00`000000oooo0?ooo`070?ooo`03
0000003oool0oooo00P0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`0B0?ooo`03
0000003oool0oooo01L0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`030?ooo`80
00009P3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00L0oooo00@000000?ooo`00
000000001P3oool00`000000oooo0?ooo`0B0?ooo`030000003oool0oooo01H0oooo000E0?ooo`03
0000003oool0oooo0180oooo0P00000M0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3o
ool00`3oool00`000000oooo0?ooo`0C0?ooo`030000003oool0oooo00H0oooo0P0000001@3oool0
00000?ooo`3oool000000280oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`080?oo
o`<00000303oool00`000000oooo0?ooo`0F0?ooo`<000001`3oool00`000000oooo0?ooo`060?oo
o`030000003oool0oooo0140oooo00<000000?ooo`3oool05@3oool00`000000oooo0?ooo`0d0?oo
o`030000003oool0oooo03L0oooo00<000000?ooo`000000:P3oool00`000000oooo0?ooo`090?oo
o`030000003oool0oooo00L0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`150?oo
o`030000003oool0oooo00d0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`0?0?oo
o`030000003oool0oooo00L0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`060?oo
o`030000003oool0oooo0180oooo00<000000?ooo`3oool05`3oool00`000000oooo0?ooo`050?oo
o`030000003oool0oooo00<0oooo0P00000V0?ooo`030000003oool0oooo00H0oooo00<000000?oo
o`3oool01`3oool010000000oooo0000000000060?ooo`030000003oool0oooo0180oooo00<00000
0?ooo`3oool05P3oool001@0ooooo`3oo`3o0?oo03D0ool02`000?l:0?oo00X0003oVP3oo`0E0?oo
o`005@3oool00`000000oooo0?ooo`0B0?ooo`8000007@3oool00`000000oooo0?ooo`020?ooo`03
0000003oool0oooo00<0oooo00<000000?ooo`3oool04`3oool00`000000oooo0?ooo`060?ooo`80
000000D0oooo0000003oool0oooo0000000R0?ooo`030000003oool0oooo00D0oooo00<000000?oo
o`3oool0203oool3000000`0oooo00<000000?ooo`3oool05P3oool3000000L0oooo00<000000?oo
o`3oool01P3oool00`000000oooo0?ooo`0A0?ooo`030000003oool0oooo01D0oooo00<000000?oo
o`3oool0=03oool00`000000oooo0?ooo`0g0?ooo`030000003oool0000002X0oooo00<000000?oo
o`3oool02@3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00<0oooo00<000000?oo
o`3oool0A@3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo00X0oooo00<000000?oo
o`3oool03`3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00P0oooo00<000000?oo
o`3oool01P3oool00`000000oooo0?ooo`0B0?ooo`030000003oool0oooo01L0oooo00<000000?oo
o`3oool01@3oool00`000000oooo0?ooo`030?ooo`8000009P3oool00`000000oooo0?ooo`060?oo
o`030000003oool0oooo00L0oooo00@000000?ooo`00000000001P3oool00`000000oooo0?ooo`0B
0?ooo`030000003oool0oooo01H0oooo000E0?ooo`030000003oool0oooo0180oooo0P00000M0?oo
o`030000003oool0oooo0080oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`0C0?oo
o`030000003oool0oooo00H0oooo0P0000001@3oool000000?ooo`3oool000000280oooo00<00000
0?ooo`3oool01@3oool00`000000oooo0?ooo`080?ooo`<00000303oool00`000000oooo0?ooo`0F
0?ooo`<000001`3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo0140oooo00<00000
0?ooo`3oool05@3oool00`000000oooo0?ooo`0d0?ooo`030000003oool0oooo03L0oooo00<00000
0?ooo`000000:P3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00L0oooo00<00000
0?ooo`3oool00`3oool00`000000oooo0?ooo`150?ooo`030000003oool0oooo00d0oooo00<00000
0?ooo`3oool02P3oool00`000000oooo0?ooo`0?0?ooo`030000003oool0oooo00L0oooo00<00000
0?ooo`3oool0203oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo0180oooo00<00000
0?ooo`3oool05`3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00<0oooo0P00000V
0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool01`3oool010000000oooo00000000
00060?ooo`030000003oool0oooo0180oooo00<000000?ooo`3oool05P3oool001D0oooo00<00000
0?ooo`3oool04P3oool2000001d0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`03
0?ooo`030000003oool0oooo01<0oooo00<000000?ooo`3oool01P3oool2000000050?ooo`000000
oooo0?ooo`0000008P3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00P0oooo0`00
000<0?ooo`030000003oool0oooo01H0oooo0`0000070?ooo`030000003oool0oooo00H0oooo00<0
00000?ooo`3oool04@3oool00`000000oooo0?ooo`0E0?ooo`030000003oool0oooo03@0oooo00<0
00000?ooo`3oool0=`3oool00`000000oooo0000000Z0?ooo`030000003oool0oooo00T0oooo00<0
00000?ooo`3oool01`3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo04D0oooo00<0
00000?ooo`3oool03@3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo00l0oooo00<0
00000?ooo`3oool01`3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo00H0oooo00<0
00000?ooo`3oool04P3oool00`000000oooo0?ooo`0G0?ooo`030000003oool0oooo00D0oooo00<0
00000?ooo`3oool00`3oool2000002H0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?oo
o`070?ooo`040000003oool00000000000H0oooo00<000000?ooo`3oool04P3oool00`000000oooo
0?ooo`0F0?ooo`005@3oool00`000000oooo0?ooo`0B0?ooo`8000007@3oool00`000000oooo0?oo
o`020?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool04`3oool00`000000oooo0?oo
o`060?ooo`80000000D0oooo0000003oool0oooo0000000R0?ooo`030000003oool0oooo00D0oooo
00<000000?ooo`3oool0203oool3000000`0oooo00<000000?ooo`3oool05P3oool3000000L0oooo
00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`0A0?ooo`030000003oool0oooo01D0oooo
00<000000?ooo`3oool0=03oool00`000000oooo0?ooo`0g0?ooo`030000003oool0000002X0oooo
00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00<0oooo
00<000000?ooo`3oool0A@3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo00X0oooo
00<000000?ooo`3oool03`3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00P0oooo
00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`0B0?ooo`030000003oool0oooo01L0oooo
00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`030?ooo`8000009P3oool00`000000oooo
0?ooo`060?ooo`030000003oool0oooo00L0oooo00@000000?ooo`00000000001P3oool00`000000
oooo0?ooo`0B0?ooo`030000003oool0oooo01H0oooo000E0?ooo`030000003oool0oooo0180oooo
0P00000M0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool00`3oool00`000000oooo
0?ooo`0C0?ooo`030000003oool0oooo00H0oooo0P0000001@3oool000000?ooo`3oool000000280
oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`080?ooo`<00000303oool00`000000
oooo0?ooo`0F0?ooo`<000001`3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo0140
oooo00<000000?ooo`3oool05@3oool00`000000oooo0?ooo`0d0?ooo`030000003oool0oooo03L0
oooo00<000000?ooo`000000:P3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00L0
oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`150?ooo`030000003oool0oooo00d0
oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`0?0?ooo`030000003oool0oooo00L0
oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo0180
oooo00<000000?ooo`3oool05`3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00<0
oooo0P00000V0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool01`3oool010000000
oooo0000000000060?ooo`030000003oool0oooo0180oooo00<000000?ooo`3oool05P3oool001D0
oooo00<000000?ooo`3oool04P3oool2000001d0oooo00<000000?ooo`3oool00P3oool00`000000
oooo0?ooo`030?ooo`030000003oool0oooo01<0oooo00<000000?ooo`3oool01P3oool200000005
0?ooo`000000oooo0?ooo`0000008P3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo
00P0oooo0`00000<0?ooo`030000003oool0oooo01H0oooo0`0000070?ooo`030000003oool0oooo
00H0oooo00<000000?ooo`3oool04@3oool00`000000oooo0?ooo`0E0?ooo`030000003oool0oooo
03@0oooo00<000000?ooo`3oool0=`3oool00`000000oooo0000000Z0?ooo`030000003oool0oooo
00T0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo
04D0oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo
00l0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo
00H0oooo00<000000?ooo`3oool04P3oool00`000000oooo0?ooo`0G0?ooo`030000003oool0oooo
00D0oooo00<000000?ooo`3oool00`3oool2000002H0oooo00<000000?ooo`3oool01P3oool00`00
0000oooo0?ooo`070?ooo`040000003oool00000000000H0oooo00<000000?ooo`3oool04P3oool0
0`000000oooo0?ooo`0F0?ooo`005@3oool00`000000oooo0?ooo`0B0?ooo`8000007@3oool00`00
0000oooo0?ooo`020?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool04`3oool00`00
0000oooo0?ooo`060?ooo`80000000D0oooo0000003oool0oooo0000000R0?ooo`030000003oool0
oooo00D0oooo00<000000?ooo`3oool0203oool3000000`0oooo00<000000?ooo`3oool05P3oool3
000000L0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`0A0?ooo`030000003oool0
oooo01D0oooo00<000000?ooo`3oool0=03oool00`000000oooo0?ooo`0g0?ooo`030000003oool0
000002X0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`070?ooo`030000003oool0
oooo00<0oooo00<000000?ooo`3oool0A@3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0
oooo00X0oooo00<000000?ooo`3oool03`3oool00`000000oooo0?ooo`070?ooo`030000003oool0
oooo00P0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`0B0?ooo`030000003oool0
oooo01L0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`030?ooo`8000009P3oool0
0`000000oooo0?ooo`060?ooo`030000003oool0oooo00L0oooo00@000000?ooo`00000000001P3o
ool00`000000oooo0?ooo`0B0?ooo`030000003oool0oooo01H0oooo000D0?ooool0ool0o`3oo`31
0?oo00/0003o8P3oo`0E0?ooo`005@3oool00`000000oooo0?ooo`0B0?ooo`8000007@3oool00`00
0000oooo0?ooo`020?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool04`3oool00`00
0000oooo0?ooo`060?ooo`80000000D0oooo0000003oool0oooo0000000R0?ooo`030000003oool0
oooo00D0oooo00<000000?ooo`3oool0203oool3000000`0oooo00<000000?ooo`3oool05P3oool3
000000L0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`0A0?ooo`030000003oool0
oooo01D0oooo00<000000?ooo`3oool0=03oool00`000000oooo0?ooo`0g0?ooo`030000003oool0
000002X0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`070?ooo`030000003oool0
oooo00<0oooo00<000000?ooo`3oool0A@3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0
oooo00X0oooo00<000000?ooo`3oool03`3oool00`000000oooo0?ooo`070?ooo`030000003oool0
oooo00P0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`0B0?ooo`030000003oool0
oooo01L0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`030?ooo`8000009P3oool0
0`000000oooo0?ooo`060?ooo`030000003oool0oooo00L0oooo00@000000?ooo`00000000001P3o
ool00`000000oooo0?ooo`0B0?ooo`030000003oool0oooo01H0oooo000E0?ooo`030000003oool0
oooo0180oooo0P00000M0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool00`3oool0
0`000000oooo0?ooo`0C0?ooo`030000003oool0oooo00H0oooo0P0000001@3oool000000?ooo`3o
ool000000280oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`080?ooo`<00000303o
ool00`000000oooo0?ooo`0F0?ooo`<000001`3oool00`000000oooo0?ooo`060?ooo`030000003o
ool0oooo0140oooo00<000000?ooo`3oool05@3oool00`000000oooo0?ooo`0d0?ooo`030000003o
ool0oooo03L0oooo00<000000?ooo`000000:P3oool00`000000oooo0?ooo`090?ooo`030000003o
ool0oooo00L0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`150?ooo`030000003o
ool0oooo00d0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`0?0?ooo`030000003o
ool0oooo00L0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`060?ooo`030000003o
ool0oooo0180oooo00<000000?ooo`3oool05`3oool00`000000oooo0?ooo`050?ooo`030000003o
ool0oooo00<0oooo0P00000V0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool01`3o
ool010000000oooo0000000000060?ooo`030000003oool0oooo0180oooo00<000000?ooo`3oool0
5P3oool001D0oooo00<000000?ooo`3oool04P3oool2000001d0oooo00<000000?ooo`3oool00P3o
ool00`000000oooo0?ooo`030?ooo`030000003oool0oooo01<0oooo00<000000?ooo`3oool01P3o
ool2000000050?ooo`000000oooo0?ooo`0000008P3oool00`000000oooo0?ooo`050?ooo`030000
003oool0oooo00P0oooo0`00000<0?ooo`030000003oool0oooo01H0oooo0`0000070?ooo`030000
003oool0oooo00H0oooo00<000000?ooo`3oool04@3oool00`000000oooo0?ooo`0E0?ooo`030000
003oool0oooo03@0oooo00<000000?ooo`3oool0=`3oool00`000000oooo0000000Z0?ooo`030000
003oool0oooo00T0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`030?ooo`030000
003oool0oooo04D0oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`0:0?ooo`030000
003oool0oooo00l0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`080?ooo`030000
003oool0oooo00H0oooo00<000000?ooo`3oool04P3oool00`000000oooo0?ooo`0G0?ooo`030000
003oool0oooo00D0oooo00<000000?ooo`3oool00`3oool2000002H0oooo00<000000?ooo`3oool0
1P3oool00`000000oooo0?ooo`070?ooo`040000003oool00000000000H0oooo00<000000?ooo`3o
ool04P3oool00`000000oooo0?ooo`0F0?ooo`005@3oool00`000000oooo0?ooo`0B0?ooo`800000
7@3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0
4`3oool00`000000oooo0?ooo`060?ooo`80000000D0oooo0000003oool0oooo0000000R0?ooo`03
0000003oool0oooo00D0oooo00<000000?ooo`3oool0203oool3000000`0oooo00<000000?ooo`3o
ool05P3oool3000000L0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`0A0?ooo`03
0000003oool0oooo01D0oooo00<000000?ooo`3oool0=03oool00`000000oooo0?ooo`0g0?ooo`03
0000003oool0000002X0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`070?ooo`03
0000003oool0oooo00<0oooo00<000000?ooo`3oool0A@3oool00`000000oooo0?ooo`0=0?ooo`03
0000003oool0oooo00X0oooo00<000000?ooo`3oool03`3oool00`000000oooo0?ooo`070?ooo`03
0000003oool0oooo00P0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`0B0?ooo`03
0000003oool0oooo01L0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`030?ooo`80
00009P3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00L0oooo00@000000?ooo`00
000000001P3oool00`000000oooo0?ooo`0B0?ooo`030000003oool0oooo01H0oooo000E0?ooo`03
0000003oool0oooo0180oooo0P00000M0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3o
ool00`3oool00`000000oooo0?ooo`0C0?ooo`030000003oool0oooo00H0oooo0P0000001@3oool0
00000?ooo`3oool000000280oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`080?oo
o`<00000303oool00`000000oooo0?ooo`0F0?ooo`<000001`3oool00`000000oooo0?ooo`060?oo
o`030000003oool0oooo0140oooo00<000000?ooo`3oool05@3oool00`000000oooo0?ooo`0d0?oo
o`030000003oool0oooo03L0oooo00<000000?ooo`000000:P3oool00`000000oooo0?ooo`090?oo
o`030000003oool0oooo00L0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`150?oo
o`030000003oool0oooo00d0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`0?0?oo
o`030000003oool0oooo00L0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`060?oo
o`030000003oool0oooo0180oooo00<000000?ooo`3oool05`3oool00`000000oooo0?ooo`050?oo
o`030000003oool0oooo00<0oooo0P00000V0?ooo`030000003oool0oooo00H0oooo00<000000?oo
o`3oool01`3oool010000000oooo0000000000060?ooo`030000003oool0oooo0180oooo00<00000
0?ooo`3oool05P3oool001D0oooo00<000000?ooo`3oool04P3oool2000001d0oooo00<000000?oo
o`3oool00P3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo01<0oooo00<000000?oo
o`3oool01P3oool2000000050?ooo`000000oooo0?ooo`0000008P3oool00`000000oooo0?ooo`05
0?ooo`030000003oool0oooo00P0oooo0`00000<0?ooo`030000003oool0oooo01H0oooo0`000007
0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool04@3oool00`000000oooo0?ooo`0E
0?ooo`030000003oool0oooo03@0oooo00<000000?ooo`3oool0=`3oool00`000000oooo0000000Z
0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`03
0?ooo`030000003oool0oooo04D0oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`0:
0?ooo`030000003oool0oooo00l0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`08
0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool04P3oool00`000000oooo0?ooo`0G
0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool00`3oool2000002H0oooo00<00000
0?ooo`3oool01P3oool00`000000oooo0?ooo`070?ooo`040000003oool00000000000H0oooo00<0
00000?ooo`3oool04P3oool00`000000oooo0?ooo`0F0?ooo`005@3oool00`000000oooo0?ooo`0B
0?ooo`8000007@3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00<0oooo00<00000
0?ooo`3oool04`3oool00`000000oooo0?ooo`060?ooo`80000000D0oooo0000003oool0oooo0000
000R0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool0203oool3000000`0oooo00<0
00000?ooo`3oool05P3oool3000000L0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?oo
o`0A0?ooo`030000003oool0oooo01D0oooo00<000000?ooo`3oool0=03oool00`000000oooo0?oo
o`0g0?ooo`030000003oool0000002X0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?oo
o`070?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0A@3oool00`000000oooo0?oo
o`0=0?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool03`3oool00`000000oooo0?oo
o`070?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?oo
o`0B0?ooo`030000003oool0oooo01L0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?oo
o`030?ooo`8000009P3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00L0oooo00@0
00000?ooo`00000000001P3oool00`000000oooo0?ooo`0B0?ooo`030000003oool0oooo01H0oooo
000D0?oooel0ool00P000?l00`3oo`00003o0000o`020000obX0ool03P000?l<0?oo02@0003oo`3o
o`3Y0?oo00X0003o2`3oo`020000oal0ool05@3oool001D0oooo00<000000?ooo`3oool04P3oool2
000001d0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`030?ooo`030000003oool0
oooo01<0oooo00<000000?ooo`3oool01P3oool2000000050?ooo`000000oooo0?ooo`0000008P3o
ool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00P0oooo0`00000<0?ooo`030000003o
ool0oooo01H0oooo0`0000070?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool04@3o
ool00`000000oooo0?ooo`0E0?ooo`030000003oool0oooo03@0oooo00<000000?ooo`3oool0=`3o
ool00`000000oooo0000000Z0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool01`3o
ool00`000000oooo0?ooo`030?ooo`030000003oool0oooo04D0oooo00<000000?ooo`3oool03@3o
ool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo00l0oooo00<000000?ooo`3oool01`3o
ool00`000000oooo0?ooo`080?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool04P3o
ool00`000000oooo0?ooo`0G0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool00`3o
ool2000002H0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`070?ooo`040000003o
ool00000000000H0oooo00<000000?ooo`3oool04P3oool00`000000oooo0?ooo`0F0?ooo`005@3o
ool00`000000oooo0?ooo`0B0?ooo`8000007@3oool00`000000oooo0?ooo`020?ooo`030000003o
ool0oooo00<0oooo00<000000?ooo`3oool04`3oool00`000000oooo0?ooo`060?ooo`80000000D0
oooo0000003oool0oooo0000000R0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool0
203oool3000000`0oooo00<000000?ooo`3oool05P3oool3000000L0oooo00<000000?ooo`3oool0
1P3oool00`000000oooo0?ooo`0A0?ooo`030000003oool0oooo01D0oooo00<000000?ooo`3oool0
=03oool00`000000oooo0?ooo`0g0?ooo`030000003oool0000002X0oooo00<000000?ooo`3oool0
2@3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0
A@3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool0
3`3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool0
1P3oool00`000000oooo0?ooo`0B0?ooo`030000003oool0oooo01L0oooo00<000000?ooo`3oool0
1@3oool00`000000oooo0?ooo`030?ooo`8000009P3oool00`000000oooo0?ooo`060?ooo`030000
003oool0oooo00L0oooo00@000000?ooo`00000000001P3oool00`000000oooo0?ooo`0B0?ooo`03
0000003oool0oooo01H0oooo000E0?ooo`030000003oool0oooo0180oooo0P00000M0?ooo`030000
003oool0oooo0080oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`0C0?ooo`030000
003oool0oooo00H0oooo0P0000001@3oool000000?ooo`3oool000000280oooo00<000000?ooo`3o
ool01@3oool00`000000oooo0?ooo`080?ooo`<00000303oool00`000000oooo0?ooo`0F0?ooo`<0
00001`3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo0140oooo00<000000?ooo`3o
ool05@3oool00`000000oooo0?ooo`0d0?ooo`030000003oool0oooo03L0oooo00<000000?ooo`00
0000:P3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3o
ool00`3oool00`000000oooo0?ooo`150?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3o
ool02P3oool00`000000oooo0?ooo`0?0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3o
ool0203oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo0180oooo00<000000?ooo`3o
ool05`3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00<0oooo0P00000V0?ooo`03
0000003oool0oooo00H0oooo00<000000?ooo`3oool01`3oool010000000oooo0000000000060?oo
o`030000003oool0oooo0180oooo00<000000?ooo`3oool05P3oool001D0oooo00<000000?ooo`3o
ool04P3oool2000001d0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`030?ooo`03
0000003oool0oooo01<0oooo00<000000?ooo`3oool01P3oool2000000050?ooo`000000oooo0?oo
o`0000008P3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00P0oooo0`00000<0?oo
o`030000003oool0oooo01H0oooo0`0000070?ooo`030000003oool0oooo00H0oooo00<000000?oo
o`3oool04@3oool00`000000oooo0?ooo`0E0?ooo`030000003oool0oooo03@0oooo00<000000?oo
o`3oool0=`3oool00`000000oooo0000000Z0?ooo`030000003oool0oooo00T0oooo00<000000?oo
o`3oool01`3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo04D0oooo00<000000?oo
o`3oool03@3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo00l0oooo00<000000?oo
o`3oool01`3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo00H0oooo00<000000?oo
o`3oool04P3oool00`000000oooo0?ooo`0G0?ooo`030000003oool0oooo00D0oooo00<000000?oo
o`3oool00`3oool2000002H0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`070?oo
o`040000003oool00000000000H0oooo00<000000?ooo`3oool04P3oool00`000000oooo0?ooo`0F
0?ooo`005@3oool00`000000oooo0?ooo`0B0?ooo`8000007@3oool00`000000oooo0?ooo`020?oo
o`030000003oool0oooo00<0oooo00<000000?ooo`3oool04`3oool00`000000oooo0?ooo`060?oo
o`80000000D0oooo0000003oool0oooo0000000R0?ooo`030000003oool0oooo00D0oooo00<00000
0?ooo`3oool0203oool3000000`0oooo00<000000?ooo`3oool05P3oool3000000L0oooo00<00000
0?ooo`3oool01P3oool00`000000oooo0?ooo`0A0?ooo`030000003oool0oooo01D0oooo00<00000
0?ooo`3oool0=03oool00`000000oooo0?ooo`0g0?ooo`030000003oool0000002X0oooo00<00000
0?ooo`3oool02@3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00<0oooo00<00000
0?ooo`3oool0A@3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo00X0oooo00<00000
0?ooo`3oool03`3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00P0oooo00<00000
0?ooo`3oool01P3oool00`000000oooo0?ooo`0B0?ooo`030000003oool0oooo01L0oooo00<00000
0?ooo`3oool01@3oool00`000000oooo0?ooo`030?ooo`8000009P3oool00`000000oooo0?ooo`06
0?ooo`030000003oool0oooo00L0oooo00@000000?ooo`00000000001P3oool00`000000oooo0?oo
o`0B0?ooo`030000003oool0oooo01H0oooo000E0?ooo`030000003oool0oooo0180oooo0P00000M
0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`0C
0?ooo`030000003oool0oooo00H0oooo0P0000001@3oool000000?ooo`3oool000000280oooo00<0
00000?ooo`3oool01@3oool00`000000oooo0?ooo`080?ooo`<00000303oool00`000000oooo0?oo
o`0F0?ooo`<000001`3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo0140oooo00<0
00000?ooo`3oool05@3oool00`000000oooo0?ooo`0d0?ooo`030000003oool0oooo03L0oooo00<0
00000?ooo`000000:P3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00L0oooo00<0
00000?ooo`3oool00`3oool00`000000oooo0?ooo`150?ooo`030000003oool0oooo00d0oooo00<0
00000?ooo`3oool02P3oool00`000000oooo0?ooo`0?0?ooo`030000003oool0oooo00L0oooo00<0
00000?ooo`3oool0203oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo0180oooo00<0
00000?ooo`3oool05`3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00<0oooo0P00
000V0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool01`3oool010000000oooo0000
000000060?ooo`030000003oool0oooo0180oooo00<000000?ooo`3oool05P3oool001D0oooo00<0
00000?ooo`3oool04P3oool2000001d0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?oo
o`030?ooo`030000003oool0oooo01<0oooo00<000000?ooo`3oool01P3oool2000000050?ooo`00
0000oooo0?ooo`0000008P3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00P0oooo
0`00000<0?ooo`030000003oool0oooo01H0oooo0`0000070?ooo`030000003oool0oooo00H0oooo
00<000000?ooo`3oool04@3oool00`000000oooo0?ooo`0E0?ooo`030000003oool0oooo03@0oooo
00<000000?ooo`3oool0=`3oool00`000000oooo0000000Z0?ooo`030000003oool0oooo00T0oooo
00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo04D0oooo
00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo00l0oooo
00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo00H0oooo
00<000000?ooo`3oool04P3oool00`000000oooo0?ooo`0G0?ooo`030000003oool0oooo00D0oooo
00<000000?ooo`3oool00`3oool2000002H0oooo00<000000?ooo`3oool01P3oool00`000000oooo
0?ooo`070?ooo`040000003oool00000000000H0oooo00<000000?ooo`3oool04P3oool00`000000
oooo0?ooo`0F0?ooo`00503oool00`3oo`00003o0000o`0c0000ob00ool02P000?lm0?oo00h0003o
603oo`030000ool0ool0o`3oo`0X0?oo01D0oooo003o0?ooool0ooooo`3ooolH0?ooo`00o`3ooooo
0?ooool0oooo603oool00?l0ooooo`3ooooo0?oooaP0oooo0000\
\>"],
  ImageRangeCache->{{{0, 788}, {156.688, 0}} -> {-1.40314, -0.0250052, \
0.0670131, 0.00670131}}]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["Lifespan of junctions", "SubsubsectionIcon"],

Cell["\<\
** There is a problem here: especially early on, junction pairs \
last much less time than they should.  This is puzzling, because only a \
coalescence between the two should terminate them, and such coalescences \
should occur with an exponential distribution.  I cannot see what is wrong \
with the algorithm, but on the other hand, cannot see an easy way to check \
it.\
\>", "Text"],

Cell["There are 492 junctions in the whole graph:", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(jj = Junctions[ng3]; Length[jj]\)], "Input",
  CellLabel->"In[117]:="],

Cell[BoxData[
    \(492\)], "Output",
  CellLabel->"Out[117]="]
}, Open  ]],

Cell["\<\
This lists the timespan of each of those junctions that are not yet \
unfinished (50 or so were still extant)\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(tsList = \(TimespanOfJunction[ng3, #] &\) /@ jj;\)\), "\n", 
    \(\(tsjj = 
        Transpose[
          DeleteCases[
            Transpose[{jj, tsList}], {_, {_, \[Infinity]}}]];\)\), "\n", 
    \(ts2 = tsjj\[LeftDoubleBracket]2\[RightDoubleBracket]; 
    jj2 = tsjj\[LeftDoubleBracket]1\[RightDoubleBracket]; 
    jj2 // Length\)}], "Input",
  CellLabel->"In[133]:="],

Cell[BoxData[
    \(448\)], "Output",
  CellLabel->"Out[143]="]
}, Open  ]],

Cell["\<\
The mean & variance of lifespan issubstantially reduced, but this \
may be an artefact of truncating at a definite time.\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(Sort[\((\(-Subtract @@ #\) &)\) /@ ts2]\)], "Input",
  CellLabel->"In[145]:="],

Cell[BoxData[
    \({0.0004528612454457459`, 0.0026128887040473003`, 0.005988117929308867`, 
      0.006121803946079751`, 0.007323214500809527`, 0.0075758347949540505`, 
      0.012014783312201516`, 0.012340227786955538`, 0.016320537653507827`, 
      0.018236046315844856`, 0.01872920713430304`, 0.019095401141432378`, 
      0.023311735263845`, 0.024270079041037285`, 0.028824130819206317`, 
      0.02912665604577569`, 0.03253078741677129`, 0.03287698142310802`, 
      0.038447264491637156`, 0.03930744443587786`, 0.03935368627829927`, 
      0.04090137848831965`, 0.04118058289887294`, 0.043978373600854326`, 
      0.04797815926150939`, 0.04977393046133294`, 0.04994683659192267`, 
      0.05719523431290874`, 0.057626585170900135`, 0.05942542884436541`, 
      0.06180171918545874`, 0.06249292357171221`, 0.06309775335440282`, 
      0.06320611992691383`, 0.06512443198458673`, 0.07079647435819858`, 
      0.07185674593672786`, 0.07645710758025981`, 0.07979005549058885`, 
      0.08119922805744961`, 0.08578242774606415`, 0.08890230027651924`, 
      0.08917226704099557`, 0.08993681271764586`, 0.09017576616039213`, 
      0.09380677048330632`, 0.09420830959171056`, 0.10086659781849194`, 
      0.10805796457113281`, 0.10972766399720335`, 0.11067839415690162`, 
      0.1140535575411028`, 0.11972469662689234`, 0.12084355361760069`, 
      0.1239667566559094`, 0.12473602860187061`, 0.13299969293268266`, 
      0.1383285050616907`, 0.1407305191131365`, 0.1410120320440027`, 
      0.14137429194046458`, 0.1459601262461696`, 0.14852390821250427`, 
      0.14992497334787735`, 0.1509532694106086`, 0.15445009579810431`, 
      0.15527866159891968`, 0.16263654328619825`, 0.16426668288530277`, 
      0.17013168677818502`, 0.1705312387233503`, 0.17230680833400935`, 
      0.17414734891693495`, 0.17660965287491948`, 0.18409155415937573`, 
      0.1875216834582325`, 0.19132342922605616`, 0.19738173024086336`, 
      0.19816499784495`, 0.20017710307567782`, 0.20283021205115936`, 
      0.2058155849792218`, 0.20607200326501118`, 0.20998716342984025`, 
      0.21072749252676282`, 0.21503260505570942`, 0.21851754507153132`, 
      0.21934858444924643`, 0.22163860896264254`, 0.22176707391635553`, 
      0.22251367842726033`, 0.22461482519378428`, 0.2261946286254677`, 
      0.22665754470015997`, 0.22701152844134675`, 0.2289557121600151`, 
      0.23461325287057244`, 0.2384863158019237`, 0.24002649681114185`, 
      0.24062608359153392`, 0.24206898275137423`, 0.24382016605553947`, 
      0.24665970289320427`, 0.2480012215812044`, 0.24849233188616493`, 
      0.2486586882994497`, 0.2503112285058382`, 0.2579097399306405`, 
      0.25960989671809465`, 0.2708526420644377`, 0.27219807306097366`, 
      0.27325530317821967`, 0.2734868664950003`, 0.2781416869225559`, 
      0.27944810236410733`, 0.2795647889476971`, 0.27970420096723636`, 
      0.2797591369511334`, 0.2824181613369521`, 0.28691148751505224`, 
      0.2879815712723177`, 0.28872717229299427`, 0.2917592720876226`, 
      0.29345127047766995`, 0.29484296751039596`, 0.2951281694493617`, 
      0.295769104883703`, 0.2957780045326581`, 0.300134118931898`, 
      0.3109097694132066`, 0.31469755180333703`, 0.3147913021413249`, 
      0.31539517998486133`, 0.3181928816959152`, 0.32175117288109023`, 
      0.322013393145717`, 0.32983652139515884`, 0.3316324221717166`, 
      0.33317890153103935`, 0.33409461768890236`, 0.335816895006559`, 
      0.3375024197173855`, 0.34126880530440395`, 0.3466894104443986`, 
      0.35179679764240745`, 0.35244157669205123`, 0.35389535275293693`, 
      0.3541821559873325`, 0.35492010441768773`, 0.3569676214227546`, 
      0.3625139279384193`, 0.36268949872961187`, 0.36450158782485875`, 
      0.3677422361810514`, 0.3688845056592944`, 0.3689856205742599`, 
      0.36952441261287383`, 0.37090773993921733`, 0.37489311191292085`, 
      0.37708626159130265`, 0.37854964248791223`, 0.3790784445749857`, 
      0.38717254958302094`, 0.39120426841084566`, 0.39848429983732636`, 
      0.40032572732545635`, 0.4021001311184387`, 0.404439611106882`, 
      0.40666406466043625`, 0.40736172947082583`, 0.4131752314736348`, 
      0.4138219147698683`, 0.4190516782394962`, 0.4195181742172247`, 
      0.42414614044985965`, 0.4262494233996237`, 0.4283048907747733`, 
      0.4322357564349115`, 0.4352914119653226`, 0.44212632734957924`, 
      0.44489260087865734`, 0.4503677819741174`, 0.4542240998970255`, 
      0.4563940371687547`, 0.4639232641699065`, 0.4644157792926915`, 
      0.4696627025241984`, 0.47217355149319484`, 0.4775429259367172`, 
      0.4780502476263577`, 0.47948828110786135`, 0.48666163752688174`, 
      0.4889421505674596`, 0.48899364626234076`, 0.4891500380484892`, 
      0.49340777755380927`, 0.49869500325587346`, 0.4993374143475915`, 
      0.4997087392937818`, 0.500832802514048`, 0.5041259170512902`, 
      0.5081136851677157`, 0.5123852674256408`, 0.5134686305842946`, 
      0.5173444790571198`, 0.5182626202899026`, 0.5189888152621416`, 
      0.5329012704446829`, 0.5350183066162586`, 0.5362038444716597`, 
      0.5378072201048938`, 0.5382318922742622`, 0.5390753629306415`, 
      0.5417638657592487`, 0.5446900092943014`, 0.5479675324373221`, 
      0.5495780959318433`, 0.552345738191359`, 0.5593173634970303`, 
      0.5803715198566151`, 0.5812836823406249`, 0.5995920036118569`, 
      0.6037800409563099`, 0.6054869967710541`, 0.6062456853525993`, 
      0.6067832131087458`, 0.6085798604848831`, 0.6087820178661639`, 
      0.6170982766941702`, 0.6171694678692635`, 0.6193688041829573`, 
      0.622147658902608`, 0.6285006254067755`, 0.628717682204607`, 
      0.6288975726817023`, 0.6303658494543019`, 0.6456787141045757`, 
      0.6603652509070983`, 0.6670711666371987`, 0.6762522176496035`, 
      0.6772442605530431`, 0.6830298641885628`, 0.6832138715155884`, 
      0.6836183276084435`, 0.6881067926216864`, 0.6885538546755048`, 
      0.6890221592823949`, 0.6894820979953158`, 0.6895229742230615`, 
      0.690218440194712`, 0.6913659798496146`, 0.6914280017246917`, 
      0.6969606451621857`, 0.6986635481668659`, 0.6997172454523817`, 
      0.7120960939537246`, 0.7150660483299891`, 0.7182117100051058`, 
      0.7376456633885069`, 0.7445285961418775`, 0.7446732334356305`, 
      0.746059361334245`, 0.7478048184161754`, 0.7515877335522383`, 
      0.75967032781152`, 0.763485730860225`, 0.7643485039915925`, 
      0.7650807253608143`, 0.7736843876049604`, 0.7759640031281152`, 
      0.7762738780812235`, 0.7763043816195632`, 0.7771987913816583`, 
      0.7778376922608814`, 0.7850679807414546`, 0.7883641564983805`, 
      0.7950064675675346`, 0.7968184244812777`, 0.8004532992738236`, 
      0.8018229023016721`, 0.8133051946655612`, 0.8156200478268443`, 
      0.8255620089801914`, 0.8356152383065667`, 0.8397807528198449`, 
      0.850962404482777`, 0.8577737998710511`, 0.8663846772197519`, 
      0.8756778830253893`, 0.8786457131094885`, 0.8792342840665539`, 
      0.8813382963524328`, 0.8939053878735461`, 0.8959518766358947`, 
      0.8971975127682259`, 0.9052655616809799`, 0.9161410393224632`, 
      0.9251208027328861`, 0.9329782115280174`, 0.9331157050050072`, 
      0.9331903288443648`, 0.9405019073297245`, 0.9554580204214598`, 
      0.9639612726132523`, 0.9885347634791897`, 0.9889985883306881`, 
      0.9914375126365815`, 1.0065790140334603`, 1.0133866307402455`, 
      1.0210174803579601`, 1.0245724571309873`, 1.0302534950555513`, 
      1.0385161016739488`, 1.0511923470871993`, 1.0533431135003184`, 
      1.053734185935724`, 1.0586682643934768`, 1.0687741950819856`, 
      1.0784649829932906`, 1.0786021687732807`, 1.0871083384875053`, 
      1.093069567828055`, 1.09850670805517`, 1.0986118589710667`, 
      1.1124150071687287`, 1.1125422312657385`, 1.1183116932839012`, 
      1.123459401780318`, 1.1284533411152173`, 1.130429573773518`, 
      1.1366110851875324`, 1.1667946922651207`, 1.1755458151031477`, 
      1.1777278467879837`, 1.179531620186166`, 1.1817713131787273`, 
      1.191412073837876`, 1.1936046529524345`, 1.2016779091799172`, 
      1.2153243168416656`, 1.21918291606677`, 1.2352185449226027`, 
      1.2417512027558675`, 1.2463046878581232`, 1.249750120959006`, 
      1.2533839131823816`, 1.254628700298729`, 1.2578709221456368`, 
      1.2666390722990721`, 1.267627090053256`, 1.2678369349570557`, 
      1.2766316923866876`, 1.2795545698083215`, 1.3110845693853181`, 
      1.3231591870720179`, 1.3265052876979606`, 1.3278226922022456`, 
      1.3377411178576128`, 1.3500249013549652`, 1.3509271112122176`, 
      1.3717244119016812`, 1.374549417043621`, 1.3756770600577686`, 
      1.383726696752702`, 1.387702188455565`, 1.4069560560927465`, 
      1.4171129605454693`, 1.4533018085132117`, 1.466038601025079`, 
      1.4886552447461092`, 1.5117227031279281`, 1.5132992014711322`, 
      1.5170885041419`, 1.533003409008459`, 1.5432694674740457`, 
      1.5438864798890093`, 1.5463006512263435`, 1.558017909046118`, 
      1.596945670786086`, 1.615014856966691`, 1.6167475459633311`, 
      1.6272611459067665`, 1.6284914432736244`, 1.6634691377913629`, 
      1.6947521043167662`, 1.714050652107347`, 1.7170674451337398`, 
      1.762380414636728`, 1.8119732155747084`, 1.812983737100057`, 
      1.82031990991654`, 1.8498558618876668`, 1.8531210369105855`, 
      1.8593380971156597`, 1.872740196981857`, 1.890686971634305`, 
      1.9044905856457182`, 1.9148988836334349`, 1.928507965272238`, 
      1.994266819071147`, 1.9954843601992263`, 2.000330946507982`, 
      2.021822430506292`, 2.052946508516636`, 2.0709464361572216`, 
      2.0837026507124374`, 2.08536689535617`, 2.156709896358446`, 
      2.1844982256646297`, 2.187780989754285`, 2.198960191626597`, 
      2.234849244321051`, 2.261157685044804`, 2.2622737524236367`, 
      2.2675142517110163`, 2.3364251242515355`, 2.377041121722069`, 
      2.3987174776294444`, 2.476090710441578`, 2.4933700668521137`, 
      2.5004430971109346`, 2.502879842907997`, 2.5302655194492067`, 
      2.5517384115850152`, 2.612253131959604`, 2.6230037955639585`, 
      2.6233282960233293`, 2.6276452665500045`, 2.640359255948101`, 
      2.6942559798009436`, 2.7800777114401507`, 2.812116097976353`, 
      2.890280919696916`, 2.9136579455631555`, 2.919991657557752`, 
      2.9593000766728768`, 3.114535983702422`, 3.1285491425924343`, 
      3.2133843352938483`, 3.327745097625896`, 3.4960922596983828`, 
      3.534136277996587`, 3.566735043039042`, 3.7207394017785442`, 
      4.051105309282232`, 4.075184070238678`, 4.173797231439526`, 
      4.498346238086297`}\)], "Output",
  CellLabel->"Out[145]="]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    \({Mean[\((\(-Subtract @@ #\) &)\) /@ ts2], 
      Variance[\((\(-Subtract @@ #\) &)\) /@ ts2]}\)], "Input",
  CellLabel->"In[147]:="],

Cell[BoxData[
    \({0.8567506414214866`, 0.6797614793165695`}\)], "Output",
  CellLabel->"Out[147]="]
}, Open  ]],

Cell["\<\
Take junctions present between 2.9 and 5.0- all extinct by the \
end\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(ng3\[LeftDoubleBracket]{1000, 2000}\[RightDoubleBracket]\)], "Input",
  CellLabel->"In[163]:="],

Cell[BoxData[
    \({AncestralLineage[
        999, {2.8615824173408217`, 
          3.002559881247985`}, {{}, {a}, {}}, {41.94157268407036`, 
          42.873895208475545`, 50}, {}], 
      AncestralLineage[
        1999, {5.018402019615087`, 
          5.032520412564008`}, {{}, {a}, {}, {a}, {}, {a}, {}, {a}, {}}, \
{30.814373114060118`, 31.175551011404657`, 31.28744821706748`, 
          32.09075991133042`, 35.80775087053483`, 36.30143747074588`, 
          36.907506545358466`, 37.78052752510611`, 50}, {}]}\)], "Output",
  CellLabel->"Out[163]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(jj = Junctions[Take[ng3, {1000, 2000}]]; Length[jj]\)], "Input",
  CellLabel->"In[152]:="],

Cell[BoxData[
    \(164\)], "Output",
  CellLabel->"Out[152]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(tsList = \(TimespanOfJunction[ng3, #] &\) /@ jj;\)\), "\n", 
    \(\(tsjj = 
        Transpose[
          DeleteCases[
            Transpose[{jj, tsList}], {_, {_, \[Infinity]}}]];\)\), "\n", 
    \(ts2 = tsjj\[LeftDoubleBracket]2\[RightDoubleBracket]; 
    jj2 = tsjj\[LeftDoubleBracket]1\[RightDoubleBracket]; 
    jj2 // Length\)}], "Input",
  CellLabel->"In[153]:="],

Cell[BoxData[
    \(164\)], "Output",
  CellLabel->"Out[155]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(zz = Sort[\((\(-Subtract @@ #\) &)\) /@ ts2]\)], "Input",
  CellLabel->"In[158]:="],

Cell[BoxData[
    \({0.03253078741677129`, 0.043978373600854326`, 0.04994683659192267`, 
      0.06180171918545874`, 0.06512443198458673`, 0.08917226704099557`, 
      0.12473602860187061`, 0.1383285050616907`, 0.1407305191131365`, 
      0.1459601262461696`, 0.14852390821250427`, 0.15527866159891968`, 
      0.17660965287491948`, 0.18409155415937573`, 0.1875216834582325`, 
      0.19132342922605616`, 0.20283021205115936`, 0.20998716342984025`, 
      0.21072749252676282`, 0.21503260505570942`, 0.23461325287057244`, 
      0.2384863158019237`, 0.24062608359153392`, 0.24849233188616493`, 
      0.2486586882994497`, 0.2579097399306405`, 0.2708526420644377`, 
      0.27325530317821967`, 0.2795647889476971`, 0.2824181613369521`, 
      0.2951281694493617`, 0.295769104883703`, 0.300134118931898`, 
      0.3109097694132066`, 0.31469755180333703`, 0.32175117288109023`, 
      0.3375024197173855`, 0.34126880530440395`, 0.3569676214227546`, 
      0.3688845056592944`, 0.37854964248791223`, 0.39120426841084566`, 
      0.39848429983732636`, 0.4021001311184387`, 0.4190516782394962`, 
      0.42414614044985965`, 0.4262494233996237`, 0.4283048907747733`, 
      0.44489260087865734`, 0.4503677819741174`, 0.4780502476263577`, 
      0.47948828110786135`, 0.4891500380484892`, 0.49340777755380927`, 
      0.5173444790571198`, 0.5182626202899026`, 0.5189888152621416`, 
      0.5329012704446829`, 0.5378072201048938`, 0.5382318922742622`, 
      0.5390753629306415`, 0.5593173634970303`, 0.5812836823406249`, 
      0.6193688041829573`, 0.628717682204607`, 0.6603652509070983`, 
      0.6762522176496035`, 0.6832138715155884`, 0.6890221592823949`, 
      0.6914280017246917`, 0.6997172454523817`, 0.7120960939537246`, 
      0.7150660483299891`, 0.7376456633885069`, 0.7445285961418775`, 
      0.75967032781152`, 0.7762738780812235`, 0.7883641564983805`, 
      0.8156200478268443`, 0.8356152383065667`, 0.850962404482777`, 
      0.8663846772197519`, 0.8786457131094885`, 0.8813382963524328`, 
      0.8959518766358947`, 0.9161410393224632`, 0.9405019073297245`, 
      0.9554580204214598`, 1.0210174803579601`, 1.0302534950555513`, 
      1.0511923470871993`, 1.0586682643934768`, 1.093069567828055`, 
      1.09850670805517`, 1.1124150071687287`, 1.1125422312657385`, 
      1.1183116932839012`, 1.123459401780318`, 1.1366110851875324`, 
      1.1667946922651207`, 1.1755458151031477`, 1.2016779091799172`, 
      1.2352185449226027`, 1.2417512027558675`, 1.2463046878581232`, 
      1.249750120959006`, 1.254628700298729`, 1.267627090053256`, 
      1.3110845693853181`, 1.3231591870720179`, 1.3265052876979606`, 
      1.3278226922022456`, 1.3717244119016812`, 1.374549417043621`, 
      1.3756770600577686`, 1.387702188455565`, 1.466038601025079`, 
      1.533003409008459`, 1.5438864798890093`, 1.615014856966691`, 
      1.6167475459633311`, 1.6634691377913629`, 1.6947521043167662`, 
      1.714050652107347`, 1.762380414636728`, 1.812983737100057`, 
      1.8498558618876668`, 1.8531210369105855`, 1.872740196981857`, 
      1.9044905856457182`, 1.928507965272238`, 1.994266819071147`, 
      1.9954843601992263`, 2.052946508516636`, 2.0837026507124374`, 
      2.156709896358446`, 2.187780989754285`, 2.234849244321051`, 
      2.2622737524236367`, 2.2675142517110163`, 2.3987174776294444`, 
      2.476090710441578`, 2.4933700668521137`, 2.5004430971109346`, 
      2.502879842907997`, 2.5302655194492067`, 2.5517384115850152`, 
      2.612253131959604`, 2.6230037955639585`, 2.6233282960233293`, 
      2.640359255948101`, 2.7800777114401507`, 2.890280919696916`, 
      2.9136579455631555`, 2.919991657557752`, 3.114535983702422`, 
      3.1285491425924343`, 3.2133843352938483`, 3.534136277996587`, 
      3.7207394017785442`, 4.051105309282232`, 4.075184070238678`, 
      4.173797231439526`, 4.498346238086297`}\)], "Output",
  CellLabel->"Out[158]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \({Mean[\((\(-Subtract @@ #\) &)\) /@ ts2], 
      Variance[\((\(-Subtract @@ #\) &)\) /@ ts2]}\)], "Input",
  CellLabel->"In[157]:="],

Cell[BoxData[
    \({1.1633141059660852`, 0.9754590794863287`}\)], "Output",
  CellLabel->"Out[157]="]
}, Open  ]],

Cell["\<\
The distribution is close to exponential, but with a substantially \
longer mean lifetime upto t~2.5, and then a faster decline.  It is possible \
that this is just a random fluctuation.\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(Show[LinearLogListPlot[Transpose[{zz, 1 - Range[0, 163]/164}]], 
        LinearLogPlot[Exp[\(-x\)], {x, 0, 5}]];\)\)], "Input",
  CellLabel->"In[164]:="],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.211718 0.603319 0.265754 [
[.02381 -0.0125 -3 -9 ]
[.02381 -0.0125 3 0 ]
[.23553 -0.0125 -3 -9 ]
[.23553 -0.0125 3 0 ]
[.44725 -0.0125 -3 -9 ]
[.44725 -0.0125 3 0 ]
[.65896 -0.0125 -3 -9 ]
[.65896 -0.0125 3 0 ]
[.87068 -0.0125 -3 -9 ]
[.87068 -0.0125 3 0 ]
[-0.0125 .07181 -28 -6 ]
[-0.0125 .07181 0 6 ]
[-0.0125 .15181 -28 -6 ]
[-0.0125 .15181 0 6 ]
[-0.0125 .25756 -28 -6 ]
[-0.0125 .25756 0 6 ]
[-0.0125 .33756 -22 -6 ]
[-0.0125 .33756 0 6 ]
[-0.0125 .41756 -22 -6 ]
[-0.0125 .41756 0 6 ]
[-0.0125 .52332 -22 -6 ]
[-0.0125 .52332 0 6 ]
[-0.0125 .60332 -10 -6 ]
[-0.0125 .60332 0 6 ]
[ -0.0005 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 0 m
.02381 .00625 L
s
[(0)] .02381 -0.0125 0 1 Mshowa
.23553 0 m
.23553 .00625 L
s
[(1)] .23553 -0.0125 0 1 Mshowa
.44725 0 m
.44725 .00625 L
s
[(2)] .44725 -0.0125 0 1 Mshowa
.65896 0 m
.65896 .00625 L
s
[(3)] .65896 -0.0125 0 1 Mshowa
.87068 0 m
.87068 .00625 L
s
[(4)] .87068 -0.0125 0 1 Mshowa
.125 Mabswid
.06615 0 m
.06615 .00375 L
s
.1085 0 m
.1085 .00375 L
s
.15084 0 m
.15084 .00375 L
s
.19318 0 m
.19318 .00375 L
s
.27787 0 m
.27787 .00375 L
s
.32021 0 m
.32021 .00375 L
s
.36256 0 m
.36256 .00375 L
s
.4049 0 m
.4049 .00375 L
s
.48959 0 m
.48959 .00375 L
s
.53193 0 m
.53193 .00375 L
s
.57428 0 m
.57428 .00375 L
s
.61662 0 m
.61662 .00375 L
s
.70131 0 m
.70131 .00375 L
s
.74365 0 m
.74365 .00375 L
s
.78599 0 m
.78599 .00375 L
s
.82834 0 m
.82834 .00375 L
s
.91303 0 m
.91303 .00375 L
s
.95537 0 m
.95537 .00375 L
s
.99771 0 m
.99771 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .07181 m
.00625 .07181 L
s
gsave
-0.0125 .07181 -89 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.01) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 .15181 m
.00625 .15181 L
s
gsave
-0.0125 .15181 -89 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.02) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 .25756 m
.00625 .25756 L
s
gsave
-0.0125 .25756 -89 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.05) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 .33756 m
.00625 .33756 L
s
gsave
-0.0125 .33756 -83 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.1) show
81.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 .41756 m
.00625 .41756 L
s
gsave
-0.0125 .41756 -83 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.2) show
81.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 .52332 m
.00625 .52332 L
s
gsave
-0.0125 .52332 -83 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.5) show
81.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 .60332 m
.00625 .60332 L
s
gsave
-0.0125 .60332 -71 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.001 w
0 .19861 m
.00375 .19861 L
s
0 .23181 m
.00375 .23181 L
s
0 .27861 m
.00375 .27861 L
s
0 .2964 m
.00375 .2964 L
s
0 .31181 m
.00375 .31181 L
s
0 .3254 m
.00375 .3254 L
s
0 .46436 m
.00375 .46436 L
s
0 .49756 m
.00375 .49756 L
s
0 .54436 m
.00375 .54436 L
s
0 .56215 m
.00375 .56215 L
s
0 .57756 m
.00375 .57756 L
s
0 .59116 m
.00375 .59116 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.008 w
.0307 .60332 Mdot
.03312 .60261 Mdot
.03438 .6019 Mdot
.03689 .60119 Mdot
.0376 .60047 Mdot
.04269 .59975 Mdot
.05022 .59902 Mdot
.0531 .59828 Mdot
.0536 .59755 Mdot
.05471 .5968 Mdot
.05525 .59606 Mdot
.05668 .59531 Mdot
.0612 .59455 Mdot
.06279 .59379 Mdot
.06351 .59302 Mdot
.06432 .59225 Mdot
.06675 .59147 Mdot
.06827 .59069 Mdot
.06842 .5899 Mdot
.06934 .58911 Mdot
.07348 .58831 Mdot
.0743 .5875 Mdot
.07475 .58669 Mdot
.07642 .58588 Mdot
.07646 .58506 Mdot
.07841 .58423 Mdot
.08115 .5834 Mdot
.08166 .58256 Mdot
.083 .58171 Mdot
.0836 .58086 Mdot
.08629 .58 Mdot
.08643 .57914 Mdot
.08735 .57827 Mdot
.08963 .57739 Mdot
.09044 .5765 Mdot
.09193 .57561 Mdot
.09526 .57471 Mdot
.09606 .57381 Mdot
.09939 .5729 Mdot
.10191 .57198 Mdot
.10396 .57105 Mdot
.10663 .57012 Mdot
.10818 .56917 Mdot
.10894 .56822 Mdot
.11253 .56727 Mdot
.11361 .5663 Mdot
.11405 .56533 Mdot
.11449 .56434 Mdot
.118 .56335 Mdot
.11916 .56235 Mdot
.12502 .56135 Mdot
.12533 .56033 Mdot
.12737 .5593 Mdot
.12827 .55827 Mdot
.13334 .55722 Mdot
.13354 .55617 Mdot
.13369 .55511 Mdot
.13663 .55403 Mdot
.13767 .55295 Mdot
.13776 .55185 Mdot
.13794 .55075 Mdot
.14223 .54963 Mdot
.14688 .54851 Mdot
.15494 .54737 Mdot
.15692 .54622 Mdot
.16362 .54506 Mdot
.16698 .54389 Mdot
.16846 .54271 Mdot
.16969 .54151 Mdot
.1702 .5403 Mdot
.17195 .53908 Mdot
.17457 .53785 Mdot
.1752 .5366 Mdot
.17998 .53534 Mdot
.18144 .53406 Mdot
.18465 .53277 Mdot
.18816 .53147 Mdot
.19072 .53015 Mdot
.19649 .52882 Mdot
.20072 .52747 Mdot
.20397 .5261 Mdot
.20724 .52472 Mdot
.20983 .52332 Mdot
.2104 .5219 Mdot
.2135 .52047 Mdot
.21777 .51902 Mdot
.22293 .51755 Mdot
.2261 .51606 Mdot
.23998 .51455 Mdot
.24193 .51302 Mdot
.24637 .51147 Mdot
.24795 .5099 Mdot
.25523 .50831 Mdot
.25638 .50669 Mdot
.25933 .50506 Mdot
.25935 .5034 Mdot
.26058 .50171 Mdot
.26167 .5 Mdot
.26445 .49827 Mdot
.27084 .4965 Mdot
.27269 .49471 Mdot
.27823 .4929 Mdot
.28533 .49105 Mdot
.28671 .48917 Mdot
.28767 .48727 Mdot
.2884 .48533 Mdot
.28944 .48335 Mdot
.29219 .48135 Mdot
.30139 .4793 Mdot
.30395 .47722 Mdot
.30465 .47511 Mdot
.30493 .47295 Mdot
.31423 .47075 Mdot
.31483 .46851 Mdot
.31507 .46622 Mdot
.31761 .46389 Mdot
.3342 .46151 Mdot
.34837 .45908 Mdot
.35068 .4566 Mdot
.36574 .45406 Mdot
.3661 .45147 Mdot
.376 .44882 Mdot
.38262 .4461 Mdot
.3867 .44332 Mdot
.39694 .44047 Mdot
.40765 .43755 Mdot
.41546 .43455 Mdot
.41615 .43147 Mdot
.4203 .42831 Mdot
.42702 .42506 Mdot
.43211 .42171 Mdot
.44603 .41827 Mdot
.44629 .41471 Mdot
.45846 .41105 Mdot
.46497 .40727 Mdot
.48042 .40335 Mdot
.487 .3993 Mdot
.49697 .39511 Mdot
.50277 .39075 Mdot
.50388 .38622 Mdot
.53166 .38151 Mdot
.54804 .3766 Mdot
.5517 .37147 Mdot
.5532 .3661 Mdot
.55371 .36047 Mdot
.55951 .35455 Mdot
.56406 .34831 Mdot
.57687 .34171 Mdot
.57915 .33471 Mdot
.57922 .32727 Mdot
.58282 .3193 Mdot
.6124 .31075 Mdot
.63573 .30151 Mdot
.64068 .29147 Mdot
.64202 .28047 Mdot
.68321 .26831 Mdot
.68618 .25471 Mdot
.70414 .2393 Mdot
.77205 .22151 Mdot
.81156 .20047 Mdot
.8815 .17471 Mdot
.8866 .14151 Mdot
.90748 .09472 Mdot
.97619 .01472 Mdot
.5 Mabswid
.02381 .60332 m
.06675 .57991 L
.11359 .55438 L
.15757 .5304 L
.19987 .50734 L
.2449 .48279 L
.28824 .45917 L
.33431 .43405 L
.37869 .40986 L
.42139 .38658 L
.46681 .36182 L
.51055 .33798 L
.55261 .31505 L
.59739 .29064 L
.64048 .26715 L
.6863 .24217 L
.73044 .21811 L
.77289 .19496 L
.81807 .17034 L
.86156 .14663 L
.90778 .12143 L
.95232 .09715 L
.99517 .07379 L
s
.99517 .07379 m
1 .07116 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[164]:=",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/B000`400?l00000o`00003oo`3ooolQ
0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00903oool2000003<0oooo0`00000b0?ooo`D00000
<P3oool3000003@0oooo0`00000Q0?ooo`008`3oool010000000oooo0?ooo`00000c0?ooo`030000
003oool0oooo0380oooo00@000000?ooo`3oool00000<@3oool01@000000oooo0?ooo`3oool00000
03@0oooo00<000000?ooo`3oool0803oool002<0oooo00@000000?ooo`3oool00000<`3oool00`00
0000oooo0?ooo`0c0?ooo`030000003oool0oooo03D0oooo00<000000?ooo`3oool0;`3oool50000
0240oooo000S0?ooo`040000003oool0oooo000003<0oooo00<000000?ooo`3oool0=03oool00`00
0000oooo0?ooo`0b0?ooo`800000<P3oool010000000oooo0?ooo`00000R0?ooo`008`3oool01000
0000oooo0?ooo`00000c0?ooo`030000003oool0oooo0340oooo00D000000?ooo`3oool0oooo0000
000e0?ooo`030000003oool0oooo0300oooo00<000000?ooo`0000008P3oool002<0oooo00@00000
0?ooo`3oool00000<P3oool2000003<0oooo00D000000?ooo`3oool0oooo0000000a0?ooo`050000
003oool0oooo0?ooo`000000<`3oool200000280oooo000T0?ooo`800000=03oool00`000000oooo
0?ooo`0b0?ooo`<00000<`3oool3000003D0oooo00<000000?ooo`3oool0803oool00?l0oooo8@3o
ool00?l0oooo8@3oool00?l0oooo8@3oool00?l0oooo8@3oool001l0ooooo`000002000000007`3o
ool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool01`3o
ool00`000000oooo0?ooo`080?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool0203o
ool00`000000oooo0?ooo`080?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool01`3o
ool00`000000oooo0?ooo`080?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool0203o
ool00`000000oooo0?ooo`080?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool01`3o
ool00`000000oooo0?ooo`080?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool0203o
ool00`000000oooo0?ooo`080?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool01`3o
ool00`000000oooo0?ooo`080?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool0203o
ool100000040oooo000O0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0<`3oool0
0`000000oooo0?ooo`0c0?ooo`030000003oool0oooo03<0oooo00<000000?ooo`3oool0<`3oool0
0`000000oooo0?ooo`0P0?ooo`007`3oool00`000000oooo0?ooo`3f0?ooo`8000001P3oool001l0
oooo00<000000?ooo`3oool0mP3oool2000000H0oooo000O0?ooo`030000003oool0oooo0?h0oooo
000O0?ooo`030000003oool0oooo0?h0oooo000O0?ooo`030000003oool0oooo0?h0oooo000O0?oo
o`030000003oool0oooo0?h0oooo000O0?ooo`030000003oool0oooo0?h0oooo000O0?ooo`030000
003oool0oooo0?h0oooo000O0?ooo`030000003oool0oooo0?h0oooo000O0?ooo`030000003oool0
oooo0?h0oooo000O0?ooo`030000003oool0oooo0?h0oooo000O0?ooo`030000003oool0oooo0?h0
oooo000O0?ooo`030000003oool0oooo0?h0oooo00040?ooo`800000103oool00`000000oooo0?oo
o`030?ooo`8000000`3oool3000000L0oooo00<000000?ooo`3oool0oP3oool000<0oooo00@00000
0?ooo`3oool00000203oool010000000oooo0?ooo`0000030?ooo`030000003oool0oooo00H0oooo
00<000000?ooo`3oool0oP3oool000<0oooo00@000000?ooo`3oool00000203oool010000000oooo
0?ooo`0000030?ooo`030000003oool0oooo00H0oooo0P00003m0?ooo`80000000030?ooo`040000
003oool0oooo000000P0oooo00@000000?ooo`3oool000000`3oool00`000000oooo0?ooo`060?oo
o`030000003oool0oooo0?X0oooo0P0000020?ooo`000`3oool010000000oooo0?ooo`0000080?oo
o`040000003oool0oooo000000<0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`3h
0?ooo`800000103oool000<0oooo00@000000?ooo`3oool00000203oool010000000oooo0?ooo`00
00020?ooo`800000203oool00`000000oooo0?ooo`3f0?ooo`8000001P3oool000@0oooo0P00000:
0?ooo`800000103oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo0?D0oooo00<00000
0?ooo`3oool01P3oool001l0oooo00<000000?ooo`3oool0l`3oool2000000T0oooo000O0?ooo`03
0000003oool0oooo0>@0oooo0P00000;0?ooo`8000002`3oool001l0oooo00<000000?ooo`3oool0
i03oool2000000T0oooo0P00000=0?ooo`007`3oool00`000000oooo0?ooo`3]0?ooo`8000003`3o
ool001l0oooo00<000000?ooo`3oool0j`3oool200000140oooo000O0?ooo`030000003oool0oooo
0>X0oooo00<000000?ooo`3oool04@3oool001l0oooo00<000000?ooo`3oool0j03oool2000001@0
oooo000O0?ooo`030000003oool0oooo0>H0oooo0P00000F0?ooo`007`3oool00`000000oooo0?oo
o`3T0?ooo`800000603oool001l0oooo00<000000?ooo`3oool0hP3oool2000001X0oooo000O0?oo
o`030000003oool0oooo0>00oooo0P00000L0?ooo`007`3oool00`000000oooo0?ooo`3N0?ooo`80
00007P3oool001l0oooo00<000000?ooo`3oool0g03oool200000200oooo000O0?ooo`030000003o
ool0oooo0=X0oooo0P0000030?ooo`8000007@3oool000@0oooo0P0000040?ooo`030000003oool0
oooo00<0oooo0P0000020?ooo`D000001P3oool00`000000oooo0?ooo`3H0?ooo`8000001@3oool2
000001d0oooo00030?ooo`040000003oool0oooo000000P0oooo00@000000?ooo`3oool000000P3o
ool010000000oooo0?ooo`0000060?ooo`030000003oool0oooo0=L0oooo00<000000?ooo`3oool0
903oool000<0oooo00@000000?ooo`3oool00000203oool010000000oooo0?ooo`0000030?ooo`03
0000003oool0oooo00H0oooo0P00003F0?ooo`8000009`3oool000<0oooo00@000000?ooo`3oool0
0000203oool010000000oooo0?ooo`0000040?ooo`030000003oool0oooo00D0oooo00<000000?oo
o`3oool0d`3oool2000002T0oooo00030?ooo`040000003oool0oooo000000P0oooo00H000000?oo
o`3oool000000?ooo`0000030?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0dP3o
ool00`000000oooo0?ooo`0Y0?ooo`000`3oool010000000oooo0?ooo`0000080?ooo`060000003o
ool0oooo0000003oool000000`3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo0=00
oooo0P00000/0?ooo`00103oool2000000X0oooo0P0000030?ooo`<000001`3oool00`000000oooo
0?ooo`3?0?ooo`030000003oool0oooo02`0oooo000O0?ooo`030000003oool0oooo0<d0oooo0P00
000?0?ooo`8000007P3oool001l0oooo00<000000?ooo`3oool0b`3oool200000140oooo0P00000N
0?ooo`007`3oool00`000000oooo0?ooo`390?ooo`800000<`3oool001l0oooo00<000000?ooo`3o
ool0a`3oool2000003D0oooo000O0?ooo`030000003oool0oooo0<D0oooo0P00000g0?ooo`007`3o
ool00`000000oooo0?ooo`330?ooo`800000>@3oool001l0oooo00<000000?ooo`3oool0`@3oool2
000003/0oooo000O0?ooo`800000`03oool2000000/0oooo0P00000`0?ooo`007`3oool00`000000
oooo0?ooo`2n0?ooo`030000003oool0oooo00/0oooo0P00000`0?ooo`007`3oool00`000000oooo
0?ooo`2l0?ooo`800000@03oool001l0oooo00<000000?ooo`3oool0^P3oool200000480oooo000O
0?ooo`030000003oool0oooo0;T0oooo00<000000?ooo`3oool0@P3oool001l0oooo00<000000?oo
o`3oool0]`3oool2000000T0oooo0P00000j0?ooo`007`3oool00`000000oooo0?ooo`2e0?ooo`80
00002`3oool2000003X0oooo000O0?ooo`030000003oool0oooo0;<0oooo0P0000190?ooo`007`3o
ool200000;80oooo0P00001;0?ooo`007`3oool00`000000oooo0?ooo`2_0?ooo`800000C@3oool0
01l0oooo00<000000?ooo`3oool0[@3oool2000000030?ooo`000000000004`0oooo000O0?ooo`03
0000003oool0oooo0:/0oooo0P0000030?ooo`800000C03oool001l0oooo00<000000?ooo`3oool0
Z@3oool2000005<0oooo00040?ooo`800000103oool00`000000oooo0?ooo`030?ooo`8000000`3o
ool3000000L0oooo00<000000?ooo`3oool0Y`3oool2000005D0oooo00030?ooo`040000003oool0
oooo000000P0oooo00H000000?ooo`3oool000000?ooo`0000030?ooo`030000003oool0oooo00@0
oooo00<000000?ooo`3oool0YP3oool00`000000oooo0?ooo`030?ooo`800000D03oool000<0oooo
00@000000?ooo`3oool00000203oool010000000oooo0?ooo`0000050?ooo`030000003oool0oooo
00@0oooo0P00002U0?ooo`8000001P3oool200000500oooo00030?ooo`040000003oool0oooo0000
00P0oooo00@000000?ooo`3oool000001@3oool00`000000oooo0?ooo`040?ooo`030000003oool0
oooo0:80oooo0P00001J0?ooo`000`3oool010000000oooo0?ooo`0000080?ooo`050000003oool0
oooo0000003oool0100000070?ooo`030000003oool0oooo0:00oooo0P0000090?ooo`800000D@3o
ool000<0oooo00@000000?ooo`3oool00000203oool01P000000oooo0?ooo`000000oooo000000X0
oooo00<000000?ooo`3oool0WP3oool2000000/0oooo0P00001A0?ooo`00103oool2000000X0oooo
0P0000020?ooo`D000001P3oool00`000000oooo0?ooo`2L0?ooo`800000H03oool001l0oooo0P00
002L0?ooo`030000003oool0oooo0080oooo0P00001L0?ooo`007`3oool00`000000oooo0?ooo`2I
0?ooo`8000001@3oool2000005`0oooo000O0?ooo`030000003oool0oooo09L0oooo0P00001U0?oo
o`007`3oool00`000000oooo0?ooo`2E0?ooo`8000002@3oool2000005`0oooo000O0?ooo`030000
003oool0oooo09<0oooo0P00000;0?ooo`800000G03oool001l0oooo0P00002C0?ooo`030000003o
ool0oooo06T0oooo000O0?ooo`030000003oool0oooo0900oooo0P00000=0?ooo`800000G@3oool0
01l0oooo00<000000?ooo`3oool0SP3oool2000000l0oooo0P00001M0?ooo`007`3oool00`000000
oooo0?ooo`2=0?ooo`030000003oool0oooo00T0oooo0P00001S0?ooo`007`3oool2000008`0oooo
0P00000<0?ooo`800000H`3oool001l0oooo00<000000?ooo`3oool0R@3oool2000000H0oooo0P00
001[0?ooo`007`3oool00`000000oooo0?ooo`270?ooo`800000203oool2000006/0oooo000O0?oo
o`800000Q@3oool3000000T0oooo0P00001/0?ooo`002P3oool2000000@0oooo00<000000?ooo`3o
ool00P3oool3000000L0oooo00<000000?ooo`3oool0PP3oool2000000`0oooo0P00001/0?ooo`00
2@3oool010000000oooo0?ooo`0000090?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3o
ool0P03oool2000000h0oooo0P00001/0?ooo`002@3oool010000000oooo0?ooo`0000090?ooo`03
0000003oool0oooo00H0oooo0P00001o0?ooo`800000403oool2000006`0oooo00090?ooo`040000
003oool0oooo000000T0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`1m0?ooo`03
0000003oool0oooo0100oooo0P00001/0?ooo`002@3oool010000000oooo0?ooo`0000090?ooo`03
0000003oool0oooo00H0oooo00<000000?ooo`3oool0N`3oool2000001<0oooo0P00001/0?ooo`00
2@3oool010000000oooo0?ooo`0000080?ooo`800000203oool00`000000oooo0?ooo`1i0?ooo`80
00004@3oool200000700oooo000:0?ooo`8000002P3oool00`000000oooo0?ooo`060?ooo`030000
003oool0oooo07P0oooo00<000000?ooo`3oool0403oool300000700oooo000O0?ooo`030000003o
ool0oooo07H0oooo0P00000C0?ooo`800000L@3oool001l0oooo00<000000?ooo`3oool0M@3oool0
0`000000oooo0?ooo`0B0?ooo`800000LP3oool001l0oooo00<000000?ooo`3oool0L`3oool20000
01D0oooo0P00001b0?ooo`007`3oool00`000000oooo0?ooo`1a0?ooo`8000005P3oool300000780
oooo000O0?ooo`030000003oool0oooo06l0oooo0P00000H0?ooo`800000L`3oool001l0oooo00<0
00000?ooo`3oool0K@3oool2000001T0oooo0P00001d0?ooo`007`3oool00`000000oooo0?ooo`1[
0?ooo`8000005`3oool200000080oooo0P00001d0?ooo`007`3oool00`000000oooo0?ooo`1Y0?oo
o`8000004P3oool2000000D0oooo0P00001h0?ooo`007`3oool00`000000oooo0?ooo`1W0?ooo`80
0000503oool2000007l0oooo000O0?ooo`030000003oool0oooo06D0oooo0P00000F0?ooo`800000
O`3oool001l0oooo00<000000?ooo`3oool0I03oool00`000000oooo0?ooo`0D0?ooo`800000P@3o
ool001l0oooo00<000000?ooo`3oool0HP3oool2000001D0oooo100000210?ooo`007`3oool00`00
0000oooo0?ooo`1P0?ooo`8000005@3oool4000008<0oooo000O0?ooo`030000003oool0oooo05l0
oooo00<000000?ooo`3oool04@3oool200000080oooo0P0000250?ooo`002P3oool2000000@0oooo
00@000000?ooo`3oool0oooo1@0000060?ooo`030000003oool0oooo05d0oooo0P00000B0?ooo`@0
0000R@3oool000T0oooo00@000000?ooo`3oool00000203oool010000000oooo0?ooo`0000060?oo
o`030000003oool0oooo05/0oooo0P00000A0?ooo`80000000<0oooo000000000000R`3oool000T0
oooo00@000000?ooo`3oool000002@3oool00`000000oooo0?ooo`060?ooo`800000FP3oool20000
0100oooo0P0000000`3oool000000000002>0?ooo`002@3oool010000000oooo0?ooo`00000:0?oo
o`030000003oool0oooo00D0oooo00<000000?ooo`3oool0E`3oool200000100oooo1000002A0?oo
o`002@3oool010000000oooo0?ooo`0000070?ooo`050000003oool0oooo0?ooo`0000001P3oool0
0`000000oooo0?ooo`1E0?ooo`8000004@3oool3000009<0oooo00090?ooo`040000003oool0oooo
000000L0oooo00D000000?ooo`3oool0oooo000000060?ooo`030000003oool0oooo05<0oooo0P00
000B0?ooo`<00000U03oool000X0oooo0P0000090?ooo`<000001`3oool00`000000oooo0?ooo`1A
0?ooo`8000004@3oool5000009D0oooo000O0?ooo`030000003oool0oooo04l0oooo0P00000A0?oo
o`H00000UP3oool001l0oooo00<000000?ooo`3oool0C@3oool200000100oooo0P0000000`3oool0
00000000002J0?ooo`007`3oool00`000000oooo0?ooo`1;0?ooo`8000003`3oool5000009d0oooo
000O0?ooo`030000003oool0oooo04T0oooo0P00000?0?ooo`H00000WP3oool001l0oooo00<00000
0?ooo`3oool0A`3oool2000000d0oooo0P0000020?ooo`800000XP3oool001l0oooo00<000000?oo
o`3oool0A@3oool2000000h0oooo0`0000020?ooo`800000XP3oool001l0oooo00<000000?ooo`3o
ool0@`3oool2000000P0oooo0P0000030?ooo`80000000<0oooo000000000000Y`3oool001l0oooo
0P0000120?ooo`8000002P3oool2000000<0oooo0P00002Z0?ooo`007`3oool00`000000oooo0?oo
o`100?ooo`030000003oool0oooo00L0oooo0P0000000`3oool000000000002_0?ooo`007`3oool0
0`000000oooo0?ooo`0n0?ooo`8000002P3oool2000000030?ooo`00000000000:l0oooo000O0?oo
o`030000003oool0oooo03`0oooo0P00000;0?ooo`<00000/P3oool001l0oooo00<000000?ooo`3o
ool0>P3oool2000000X0oooo1P00002b0?ooo`007`3oool00`000000oooo0?ooo`0i0?ooo`030000
003oool0oooo00X0oooo0`00002e0?ooo`007`3oool00`000000oooo0?ooo`0g0?ooo`800000303o
ool300000;H0oooo000O0?ooo`030000003oool0oooo03D0oooo0P00000:0?ooo`L00000]P3oool0
01l0oooo0P00000e0?ooo`030000003oool0oooo00P0oooo1P00002i0?ooo`007`3oool00`000000
oooo0?ooo`0b0?ooo`8000002`3oool300000;`0oooo000O0?ooo`030000003oool0oooo0340oooo
00<000000?ooo`3oool02@3oool400000;d0oooo000O0?ooo`030000003oool0oooo02l0oooo0P00
000:0?ooo`H00000_@3oool001l0oooo00<000000?ooo`3oool0;@3oool2000000L0oooo0P000002
0?ooo`@00000`03oool000X0oooo0P0000040?ooo`030000003oool0oooo0080oooo0`0000070?oo
o`030000003oool0oooo02/0oooo0P0000070?ooo`@000000P3oool200000<80oooo00090?ooo`04
0000003oool0oooo000000L0oooo00D000000?ooo`3oool0oooo000000060?ooo`030000003oool0
oooo02X0oooo00<000000?ooo`3oool01@3oool500000<L0oooo00090?ooo`040000003oool0oooo
000000/0oooo00<000000?ooo`3oool0103oool2000002T0oooo0P0000060?ooo`D00000b@3oool0
00T0oooo00@000000?ooo`3oool000002`3oool00`000000oooo0?ooo`040?ooo`030000003oool0
oooo02H0oooo0P0000040?ooo`L00000b`3oool000T0oooo00@000000?ooo`3oool000001`3oool4
000000L0oooo00<000000?ooo`3oool0903oool2000000@0oooo1P00003>0?ooo`002@3oool01000
0000oooo0?ooo`0000070?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool08P3oool2
000000@0oooo1@00003A0?ooo`002P3oool2000000P0oooo1@0000060?ooo`030000003oool0oooo
0200oooo0P0000050?ooo`@00000d`3oool001l0oooo0P00000P0?ooo`030000003oool0oooo0080
oooo1P00003D0?ooo`007`3oool00`000000oooo0?ooo`0M0?ooo``00000e@3oool001l0oooo00<0
00000?ooo`3oool06`3oool2000000030?ooo`000000000000@00000fP3oool001l0oooo00<00000
0?ooo`3oool06@3oool200000080oooo1000003M0?ooo`007`3oool00`000000oooo0?ooo`0G0?oo
o`8000000P3oool500000=h0oooo000O0?ooo`8000005P3oool200000080oooo1P00003O0?ooo`00
7`3oool00`000000oooo0?ooo`0C0?ooo`8000000P3oool500000>80oooo000O0?ooo`030000003o
ool0oooo0140oooo0P0000020?ooo`H00000h`3oool001l0oooo00<000000?ooo`3oool03`3oool2
00000080oooo1P00003U0?ooo`007`3oool2000000h0oooo0P0000020?ooo`D00000j03oool001l0
oooo00<000000?ooo`3oool02`3oool2000000<0oooo1000003Z0?ooo`007`3oool00`000000oooo
0?ooo`090?ooo`8000000`3oool500000>/0oooo000O0?ooo`8000002@3oool010000000oooo0?oo
o`3oool500000>d0oooo000E0?ooo`<000001`3oool00`000000oooo0?ooo`060?ooo`8000000P3o
ool600000>h0oooo000F0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool0103oool:
00000?00oooo000F0?ooo`030000003oool0oooo00H0oooo0P0000040?ooo`T00000lP3oool001H0
oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`040?ooo`<00000m`3oool001H0oooo
00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`3n0?ooo`005@3oool2000000P0oooo00<0
00000?ooo`3oool0oP3oool001H0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`3n
0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.688534, -2.48209, \
0.0184647, 0.0147102}}]
}, Open  ]],

Cell["Now, take 93 earlier junctions:", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(jj2 = Complement[Junctions[Take[ng3, {1, 1000}]], jj]; 
    Length[jj2]\)], "Input",
  CellLabel->"In[175]:="],

Cell[BoxData[
    \(93\)], "Output",
  CellLabel->"Out[175]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(tsList = \(TimespanOfJunction[ng3, #] &\) /@ jj2;\)\), "\n", 
    \(\(tsjj = 
        Transpose[
          DeleteCases[
            Transpose[{jj2, tsList}], {_, {_, \[Infinity]}}]];\)\), "\n", 
    \(ts2 = tsjj\[LeftDoubleBracket]2\[RightDoubleBracket]; 
    jj2 = tsjj\[LeftDoubleBracket]1\[RightDoubleBracket]; 
    jj2 // Length\)}], "Input",
  CellLabel->"In[168]:="],

Cell[BoxData[
    \(93\)], "Output",
  CellLabel->"Out[177]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(zz = Sort[\((\(-Subtract @@ #\) &)\) /@ ts2]\)], "Input",
  CellLabel->"In[178]:="],

Cell[BoxData[
    \({0.0004528612454457459`, 0.005988117929308867`, 0.0075758347949540505`, 
      0.018236046315844856`, 0.01872920713430304`, 0.019095401141432378`, 
      0.03930744443587786`, 0.057626585170900135`, 0.07979005549058885`, 
      0.08119922805744961`, 0.08578242774606415`, 0.09017576616039213`, 
      0.10086659781849194`, 0.11067839415690162`, 0.1140535575411028`, 
      0.11972469662689234`, 0.12084355361760069`, 0.1239667566559094`, 
      0.1410120320440027`, 0.1509532694106086`, 0.16426668288530277`, 
      0.1705312387233503`, 0.2289557121600151`, 0.27944810236410733`, 
      0.28691148751505224`, 0.28872717229299427`, 0.2917592720876226`, 
      0.29345127047766995`, 0.29484296751039596`, 0.3147913021413249`, 
      0.32983652139515884`, 0.3316324221717166`, 0.33409461768890236`, 
      0.3466894104443986`, 0.35179679764240745`, 0.35389535275293693`, 
      0.3541821559873325`, 0.36450158782485875`, 0.3790784445749857`, 
      0.38717254958302094`, 0.404439611106882`, 0.44212632734957924`, 
      0.4542240998970255`, 0.4639232641699065`, 0.4696627025241984`, 
      0.48666163752688174`, 0.48899364626234076`, 0.5081136851677157`, 
      0.5134686305842946`, 0.5362038444716597`, 0.5479675324373221`, 
      0.552345738191359`, 0.5995920036118569`, 0.6037800409563099`, 
      0.6062456853525993`, 0.6087820178661639`, 0.6171694678692635`, 
      0.622147658902608`, 0.6285006254067755`, 0.6670711666371987`, 
      0.6772442605530431`, 0.6881067926216864`, 0.6885538546755048`, 
      0.690218440194712`, 0.6913659798496146`, 0.6986635481668659`, 
      0.7182117100051058`, 0.7478048184161754`, 0.7736843876049604`, 
      0.7759640031281152`, 0.7763043816195632`, 0.7850679807414546`, 
      0.7950064675675346`, 0.8018229023016721`, 0.8133051946655612`, 
      0.8792342840665539`, 0.8939053878735461`, 0.8971975127682259`, 
      0.9052655616809799`, 0.9329782115280174`, 0.9889985883306881`, 
      1.0065790140334603`, 1.0133866307402455`, 1.0533431135003184`, 
      1.053734185935724`, 1.0687741950819856`, 1.0986118589710667`, 
      1.179531620186166`, 1.1817713131787273`, 1.1936046529524345`, 
      1.2578709221456368`, 1.2795545698083215`, 
      1.4171129605454693`}\)], "Output",
  CellLabel->"Out[178]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \({Mean[\((\(-Subtract @@ #\) &)\) /@ ts2], 
      Variance[\((\(-Subtract @@ #\) &)\) /@ ts2]}\)], "Input",
  CellLabel->"In[179]:="],

Cell[BoxData[
    \({0.5255572214349319`, 0.1279015673121796`}\)], "Output",
  CellLabel->"Out[179]="]
}, Open  ]],

Cell["\<\
These earlier junctions decay much faster at long times: none seem \
tolast longer than t=1.4, when 25% should do so.\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(Show[LinearLogListPlot[Transpose[{zz, 1 - Range[0, 92]/93}]], 
        LinearLogPlot[Exp[\(-x\)], {x, 0, 5}]];\)\)], "Input",
  CellLabel->"In[180]:="],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.672057 0.603319 0.299014 [
[.02381 -0.0125 -3 -9 ]
[.02381 -0.0125 3 0 ]
[.15822 -0.0125 -9 -9 ]
[.15822 -0.0125 9 0 ]
[.29263 -0.0125 -9 -9 ]
[.29263 -0.0125 9 0 ]
[.42704 -0.0125 -9 -9 ]
[.42704 -0.0125 9 0 ]
[.56146 -0.0125 -9 -9 ]
[.56146 -0.0125 9 0 ]
[.69587 -0.0125 -3 -9 ]
[.69587 -0.0125 3 0 ]
[.83028 -0.0125 -9 -9 ]
[.83028 -0.0125 9 0 ]
[.96469 -0.0125 -9 -9 ]
[.96469 -0.0125 9 0 ]
[-0.0125 .00529 -28 -6 ]
[-0.0125 .00529 0 6 ]
[-0.0125 .0953 -28 -6 ]
[-0.0125 .0953 0 6 ]
[-0.0125 .21429 -28 -6 ]
[-0.0125 .21429 0 6 ]
[-0.0125 .3043 -22 -6 ]
[-0.0125 .3043 0 6 ]
[-0.0125 .39432 -22 -6 ]
[-0.0125 .39432 0 6 ]
[-0.0125 .51331 -22 -6 ]
[-0.0125 .51331 0 6 ]
[-0.0125 .60332 -10 -6 ]
[-0.0125 .60332 0 6 ]
[ -0.0005 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 0 m
.02381 .00625 L
s
[(0)] .02381 -0.0125 0 1 Mshowa
.15822 0 m
.15822 .00625 L
s
[(0.2)] .15822 -0.0125 0 1 Mshowa
.29263 0 m
.29263 .00625 L
s
[(0.4)] .29263 -0.0125 0 1 Mshowa
.42704 0 m
.42704 .00625 L
s
[(0.6)] .42704 -0.0125 0 1 Mshowa
.56146 0 m
.56146 .00625 L
s
[(0.8)] .56146 -0.0125 0 1 Mshowa
.69587 0 m
.69587 .00625 L
s
[(1)] .69587 -0.0125 0 1 Mshowa
.83028 0 m
.83028 .00625 L
s
[(1.2)] .83028 -0.0125 0 1 Mshowa
.96469 0 m
.96469 .00625 L
s
[(1.4)] .96469 -0.0125 0 1 Mshowa
.125 Mabswid
.05741 0 m
.05741 .00375 L
s
.09102 0 m
.09102 .00375 L
s
.12462 0 m
.12462 .00375 L
s
.19182 0 m
.19182 .00375 L
s
.22543 0 m
.22543 .00375 L
s
.25903 0 m
.25903 .00375 L
s
.32624 0 m
.32624 .00375 L
s
.35984 0 m
.35984 .00375 L
s
.39344 0 m
.39344 .00375 L
s
.46065 0 m
.46065 .00375 L
s
.49425 0 m
.49425 .00375 L
s
.52785 0 m
.52785 .00375 L
s
.59506 0 m
.59506 .00375 L
s
.62866 0 m
.62866 .00375 L
s
.66226 0 m
.66226 .00375 L
s
.72947 0 m
.72947 .00375 L
s
.76307 0 m
.76307 .00375 L
s
.79668 0 m
.79668 .00375 L
s
.86388 0 m
.86388 .00375 L
s
.89748 0 m
.89748 .00375 L
s
.93109 0 m
.93109 .00375 L
s
.99829 0 m
.99829 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .00529 m
.00625 .00529 L
s
gsave
-0.0125 .00529 -89 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.01) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 .0953 m
.00625 .0953 L
s
gsave
-0.0125 .0953 -89 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.02) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 .21429 m
.00625 .21429 L
s
gsave
-0.0125 .21429 -89 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.05) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 .3043 m
.00625 .3043 L
s
gsave
-0.0125 .3043 -83 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.1) show
81.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 .39432 m
.00625 .39432 L
s
gsave
-0.0125 .39432 -83 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.2) show
81.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 .51331 m
.00625 .51331 L
s
gsave
-0.0125 .51331 -83 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.5) show
81.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 .60332 m
.00625 .60332 L
s
gsave
-0.0125 .60332 -71 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.001 w
0 .14796 m
.00375 .14796 L
s
0 .18532 m
.00375 .18532 L
s
0 .23797 m
.00375 .23797 L
s
0 .25799 m
.00375 .25799 L
s
0 .27533 m
.00375 .27533 L
s
0 .29062 m
.00375 .29062 L
s
0 .44697 m
.00375 .44697 L
s
0 .48433 m
.00375 .48433 L
s
0 .53698 m
.00375 .53698 L
s
0 .557 m
.00375 .557 L
s
0 .57434 m
.00375 .57434 L
s
0 .58964 m
.00375 .58964 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.008 w
.02411 .60332 Mdot
.02783 .60191 Mdot
.0289 .6005 Mdot
.03607 .59906 Mdot
.0364 .59761 Mdot
.03664 .59614 Mdot
.05023 .59466 Mdot
.06254 .59316 Mdot
.07743 .59164 Mdot
.07838 .5901 Mdot
.08146 .58855 Mdot
.08441 .58697 Mdot
.0916 .58538 Mdot
.09819 .58377 Mdot
.10046 .58213 Mdot
.10427 .58048 Mdot
.10502 .5788 Mdot
.10712 .5771 Mdot
.11858 .57538 Mdot
.12526 .57364 Mdot
.13421 .57187 Mdot
.13842 .57008 Mdot
.17768 .56827 Mdot
.21161 .56643 Mdot
.21663 .56456 Mdot
.21785 .56266 Mdot
.21989 .56074 Mdot
.22103 .55878 Mdot
.22196 .5568 Mdot
.23537 .55479 Mdot
.24548 .55274 Mdot
.24669 .55067 Mdot
.24834 .54855 Mdot
.2568 .54641 Mdot
.26024 .54422 Mdot
.26165 .542 Mdot
.26184 .53975 Mdot
.26878 .53745 Mdot
.27857 .53511 Mdot
.28401 .53272 Mdot
.29562 .5303 Mdot
.32094 .52782 Mdot
.32907 .5253 Mdot
.33559 .52273 Mdot
.33945 .52011 Mdot
.35087 .51743 Mdot
.35244 .5147 Mdot
.36529 .5119 Mdot
.36889 .50905 Mdot
.38417 .50613 Mdot
.39208 .50314 Mdot
.39502 .50009 Mdot
.42677 .49696 Mdot
.42958 .49375 Mdot
.43124 .49047 Mdot
.43295 .48709 Mdot
.43858 .48363 Mdot
.44193 .48007 Mdot
.4462 .47641 Mdot
.47212 .47265 Mdot
.47896 .46877 Mdot
.48626 .46478 Mdot
.48656 .46065 Mdot
.48768 .45639 Mdot
.48845 .45199 Mdot
.49335 .44744 Mdot
.50649 .44271 Mdot
.52638 .43781 Mdot
.54377 .43272 Mdot
.5453 .42742 Mdot
.54553 .42189 Mdot
.55142 .41612 Mdot
.5581 .41008 Mdot
.56268 .40374 Mdot
.5704 .39708 Mdot
.61471 .39006 Mdot
.62457 .38264 Mdot
.62678 .37476 Mdot
.6322 .36638 Mdot
.65082 .35742 Mdot
.68847 .3478 Mdot
.70029 .33741 Mdot
.70486 .32611 Mdot
.73172 .31373 Mdot
.73198 .30005 Mdot
.74209 .28475 Mdot
.76214 .26741 Mdot
.81652 .24739 Mdot
.81803 .22372 Mdot
.82598 .19474 Mdot
.86917 .15738 Mdot
.88374 .10473 Mdot
.97619 .01472 Mdot
.5 Mabswid
.02381 .60332 m
.16013 .57698 L
.30879 .54825 L
.44841 .52127 L
.58269 .49533 L
.72561 .46771 L
.86319 .44113 L
s
.86319 .44113 m
1 .41469 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[180]:=",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/B000`400?l00000o`00003oo`3ooolQ
0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00903oool2000001X0oooo0P0000040?ooo`040000
003oool0oooo0?ooo`D00000503oool2000000@0oooo00<000000?ooo`3oool00`3oool3000001<0
oooo0P0000040?ooo`030000003oool0oooo0080oooo0`00000D0?ooo`800000103oool00`000000
oooo0?ooo`020?ooo`<000006P3oool3000001T0oooo0`0000040?ooo`040000003oool0oooo0?oo
o`D000004P3oool3000000@0oooo00<000000?ooo`3oool00`3oool3000000<0oooo000S0?ooo`04
0000003oool0oooo000001P0oooo00@000000?ooo`3oool00000203oool010000000oooo0?ooo`00
000C0?ooo`040000003oool0oooo000000X0oooo00<000000?ooo`3oool04@3oool010000000oooo
0?ooo`0000070?ooo`050000003oool0oooo0?ooo`0000004P3oool010000000oooo0?ooo`000007
0?ooo`050000003oool0oooo0?ooo`0000006P3oool00`000000oooo0?ooo`0I0?ooo`030000003o
ool0oooo00P0oooo00@000000?ooo`3oool000004`3oool00`000000oooo0?ooo`0:0?ooo`030000
003oool0oooo0080oooo000S0?ooo`040000003oool0oooo000001P0oooo00@000000?ooo`3oool0
00002@3oool00`000000oooo0?ooo`0C0?ooo`040000003oool0oooo000000L0oooo1@00000B0?oo
o`040000003oool0oooo000000L0oooo00D000000?ooo`3oool0oooo0000000B0?ooo`040000003o
ool0oooo000000L0oooo00D000000?ooo`3oool0oooo0000000J0?ooo`030000003oool0oooo01T0
oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`0C0?ooo`030000003oool0oooo00L0
oooo1@0000030?ooo`008`3oool010000000oooo0?ooo`00000H0?ooo`040000003oool0oooo0000
00X0oooo00<000000?ooo`3oool04P3oool010000000oooo0?ooo`0000070?ooo`040000003oool0
oooo000001<0oooo00@000000?ooo`3oool000001`3oool4000001<0oooo00@000000?ooo`3oool0
0000203oool3000001/0oooo00<000000?ooo`3oool06@3oool00`000000oooo0?ooo`0:0?ooo`03
0000003oool0oooo0180oooo00<000000?ooo`3oool01`3oool010000000oooo0?ooo`0000040?oo
o`008`3oool010000000oooo0?ooo`00000H0?ooo`040000003oool0oooo000000L0oooo00D00000
0?ooo`3oool0oooo0000000C0?ooo`040000003oool0oooo000000P0oooo00<000000?ooo`000000
4`3oool010000000oooo0?ooo`0000070?ooo`030000003oool0oooo01@0oooo00@000000?ooo`3o
ool000001`3oool01@000000oooo0?ooo`3oool0000001X0oooo00<000000?ooo`3oool06@3oool0
0`000000oooo0?ooo`070?ooo`050000003oool0oooo0?ooo`0000004`3oool00`000000oooo0?oo
o`080?ooo`030000003oool0000000@0oooo000S0?ooo`040000003oool0oooo000001P0oooo00@0
00000?ooo`3oool000001`3oool01@000000oooo0?ooo`3oool0000001<0oooo00@000000?ooo`3o
ool000002@3oool2000001<0oooo00@000000?ooo`3oool00000203oool00`000000oooo0?ooo`0C
0?ooo`040000003oool0oooo000000L0oooo00D000000?ooo`3oool0oooo0000000I0?ooo`800000
6P3oool2000000T0oooo00D000000?ooo`3oool0oooo0000000B0?ooo`8000002`3oool2000000@0
oooo000T0?ooo`8000006P3oool2000000T0oooo0`00000E0?ooo`8000002`3oool00`000000oooo
0?ooo`0B0?ooo`8000002P3oool2000001@0oooo0P0000090?ooo`<000006`3oool00`000000oooo
0?ooo`0I0?ooo`030000003oool0oooo00P0oooo0`00000D0?ooo`030000003oool0oooo00X0oooo
00<000000?ooo`3oool00P3oool00?l0oooo8@3oool00?l0oooo8@3oool00?l0oooo8@3oool000@0
oooo0P0000040?ooo`030000003oool0oooo00<0oooo0P0000030?ooo`<00000o`3oool90?ooo`00
0`3oool010000000oooo0?ooo`0000080?ooo`040000003oool0oooo000000<0oooo00<000000?oo
o`3oool01P3ooooo00000080000000030?ooo`040000003oool0oooo000000P0oooo00@000000?oo
o`3oool000000`3oool00`000000oooo0?ooo`060?ooo`800000103oool00`000000oooo0?ooo`05
0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`05
0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`06
0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`06
0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`06
0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`05
0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`05
0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`06
0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`06
0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`05
0?ooo`030000003oool0oooo00H0oooo0@0000010?ooo`000`3oool010000000oooo0?ooo`000008
0?ooo`040000003oool0oooo000000<0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?oo
o`030?ooo`030000003oool0oooo01l0oooo00<000000?ooo`3oool0803oool00`000000oooo0?oo
o`0O0?ooo`030000003oool0oooo01l0oooo00<000000?ooo`3oool0803oool00`000000oooo0?oo
o`0O0?ooo`030000003oool0oooo01l0oooo00<000000?ooo`3oool0203oool000<0oooo00@00000
0?ooo`3oool00000203oool010000000oooo0?ooo`0000030?ooo`030000003oool0oooo00H0oooo
00<000000?ooo`3oool0mP3oool2000000H0oooo00030?ooo`040000003oool0oooo000000P0oooo
00@000000?ooo`3oool000000P3oool2000000P0oooo00<000000?ooo`3oool0mP3oool2000000H0
oooo00040?ooo`8000002P3oool2000000@0oooo00<000000?ooo`3oool01P3oool00`000000oooo
0?ooo`3n0?ooo`007`3oool00`000000oooo0?ooo`3n0?ooo`007`3oool00`000000oooo0?ooo`3n
0?ooo`007`3oool00`000000oooo0?ooo`3n0?ooo`007`3oool00`000000oooo0?ooo`3n0?ooo`00
7`3oool00`000000oooo0?ooo`3n0?ooo`007`3oool00`000000oooo0?ooo`3n0?ooo`007`3oool0
0`000000oooo0?ooo`3n0?ooo`007`3oool00`000000oooo0?ooo`3n0?ooo`007`3oool00`000000
oooo0?ooo`3n0?ooo`007`3oool00`000000oooo0?ooo`3n0?ooo`007`3oool00`000000oooo0?oo
o`3n0?ooo`007`3oool00`000000oooo0?ooo`3n0?ooo`007`3oool00`000000oooo0?ooo`3n0?oo
o`007`3oool00`000000oooo0?ooo`3n0?ooo`007`3oool00`000000oooo0?ooo`3n0?ooo`007`3o
ool00`000000oooo0?ooo`3n0?ooo`00103oool2000000@0oooo00<000000?ooo`3oool00`3oool2
00000080oooo1@0000060?ooo`030000003oool0oooo0?h0oooo00030?ooo`040000003oool0oooo
000000P0oooo00@000000?ooo`3oool000000P3oool010000000oooo0?ooo`0000060?ooo`030000
003oool0oooo0?h0oooo00030?ooo`040000003oool0oooo000000P0oooo00@000000?ooo`3oool0
00000`3oool00`000000oooo0?ooo`060?ooo`800000o`3oool000<0oooo00@000000?ooo`3oool0
0000203oool010000000oooo0?ooo`0000040?ooo`030000003oool0oooo00D0oooo00<000000?oo
o`3oool0oP3oool000<0oooo00@000000?ooo`3oool00000203oool01P000000oooo0?ooo`000000
oooo000000<0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`3N0?ooo`8000007P3o
ool000<0oooo00@000000?ooo`3oool00000203oool01P000000oooo0?ooo`000000oooo000000<0
oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`3N0?ooo`8000007P3oool000@0oooo
0P00000:0?ooo`8000000`3oool3000000L0oooo00<000000?ooo`3oool0oP3oool001l0oooo00<0
00000?ooo`3oool0oP3oool001l0oooo00<000000?ooo`3oool0oP3oool001l0oooo00<000000?oo
o`3oool0oP3oool001l0oooo00<000000?ooo`3oool0oP3oool001l0oooo00<000000?ooo`3oool0
oP3oool001l0oooo00<000000?ooo`3oool0oP3oool001l0oooo00<000000?ooo`3oool0oP3oool0
01l0oooo00<000000?ooo`3oool0oP3oool001l0oooo00<000000?ooo`3oool0oP3oool001l0oooo
0P00003o0?ooo`007`3oool00`000000oooo0?ooo`3n0?ooo`007`3oool00`000000oooo0?ooo`3K
0?ooo`8000008@3oool001l0oooo00<000000?ooo`3oool0f`3oool200000240oooo000O0?ooo`03
0000003oool0oooo0?h0oooo000O0?ooo`030000003oool0oooo0?h0oooo000O0?ooo`030000003o
ool0oooo0?h0oooo000O0?ooo`030000003oool0oooo0?h0oooo000O0?ooo`030000003oool0oooo
0?h0oooo000O0?ooo`800000o`3oool001l0oooo00<000000?ooo`3oool0oP3oool001l0oooo00<0
00000?ooo`3oool0c`3oool2000002d0oooo000O0?ooo`030000003oool0oooo0<l0oooo0P00000]
0?ooo`007`3oool00`000000oooo0?ooo`3n0?ooo`007`3oool00`000000oooo0?ooo`3n0?ooo`00
103oool2000000@0oooo00<000000?ooo`3oool00`3oool2000000<0oooo0`0000070?ooo`030000
003oool0oooo0?h0oooo00030?ooo`040000003oool0oooo000000P0oooo00H000000?ooo`3oool0
00000?ooo`0000030?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0oP3oool000<0
oooo00@000000?ooo`3oool00000203oool010000000oooo0?ooo`0000050?ooo`030000003oool0
oooo00@0oooo0P00003o0?ooo`000`3oool010000000oooo0?ooo`0000080?ooo`040000003oool0
oooo000000D0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`3n0?ooo`000`3oool0
10000000oooo0?ooo`0000080?ooo`050000003oool0oooo0000003oool0100000070?ooo`030000
003oool0oooo0<d0oooo0P00000_0?ooo`000`3oool010000000oooo0?ooo`0000080?ooo`060000
003oool0oooo0000003oool000002P3oool00`000000oooo0?ooo`3=0?ooo`800000;`3oool000@0
oooo0P00000:0?ooo`8000000P3oool5000000H0oooo00<000000?ooo`3oool0oP3oool001l0oooo
00<000000?ooo`3oool0oP3oool001l0oooo0P00003o0?ooo`007`3oool00`000000oooo0?ooo`3n
0?ooo`007`3oool00`000000oooo0?ooo`3=0?ooo`800000;`3oool001l0oooo00<000000?ooo`3o
ool0c@3oool2000002l0oooo000O0?ooo`030000003oool0oooo0?h0oooo000O0?ooo`800000o`3o
ool001l0oooo00<000000?ooo`3oool0oP3oool001l0oooo00<000000?ooo`3oool0_`3oool20000
03d0oooo000O0?ooo`030000003oool0oooo0;l0oooo0P00000m0?ooo`007`3oool200000?l0oooo
000O0?ooo`030000003oool0oooo0?h0oooo000O0?ooo`030000003oool0oooo0;X0oooo0P000012
0?ooo`007`3oool00`000000oooo0?ooo`2j0?ooo`800000@P3oool001l0oooo0P00003o0?ooo`00
7`3oool00`000000oooo0?ooo`3n0?ooo`002P3oool2000000@0oooo00<000000?ooo`3oool00P3o
ool3000000L0oooo00<000000?ooo`3oool0]`3oool2000004D0oooo00090?ooo`040000003oool0
oooo000000T0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`2g0?ooo`800000A@3o
ool000T0oooo00@000000?ooo`3oool000002@3oool00`000000oooo0?ooo`060?ooo`800000o`3o
ool000T0oooo00@000000?ooo`3oool000002@3oool00`000000oooo0?ooo`060?ooo`030000003o
ool0oooo0?h0oooo00090?ooo`040000003oool0oooo000000T0oooo00<000000?ooo`3oool01P3o
ool00`000000oooo0?ooo`2g0?ooo`800000A@3oool000T0oooo00@000000?ooo`3oool00000203o
ool2000000P0oooo00<000000?ooo`3oool0]`3oool2000004D0oooo000:0?ooo`8000002P3oool0
0`000000oooo0?ooo`060?ooo`030000003oool0oooo0?h0oooo000O0?ooo`030000003oool0oooo
0;40oooo0P00001;0?ooo`007`3oool00`000000oooo0?ooo`2a0?ooo`800000B`3oool001l0oooo
00<000000?ooo`3oool0oP3oool001l0oooo00<000000?ooo`3oool0[`3oool2000004d0oooo000O
0?ooo`030000003oool0oooo0:l0oooo0P00001=0?ooo`007`3oool00`000000oooo0?ooo`2/0?oo
o`800000D03oool001l0oooo00<000000?ooo`3oool0[03oool200000500oooo000O0?ooo`030000
003oool0oooo0?h0oooo000O0?ooo`030000003oool0oooo0:<0oooo0P00001I0?ooo`007`3oool0
0`000000oooo0?ooo`2S0?ooo`800000F@3oool001l0oooo00<000000?ooo`3oool0WP3oool20000
05h0oooo000O0?ooo`030000003oool0oooo09h0oooo0P00001N0?ooo`007`3oool00`000000oooo
0?ooo`2M0?ooo`800000G`3oool001l0oooo00<000000?ooo`3oool0W@3oool2000005l0oooo000O
0?ooo`030000003oool0oooo09`0oooo0P00001P0?ooo`007`3oool00`000000oooo0?ooo`2L0?oo
o`800000H03oool000X0oooo0P0000040?ooo`040000003oool0oooo0?ooo`D000001P3oool00`00
0000oooo0?ooo`2I0?ooo`800000H`3oool000T0oooo00@000000?ooo`3oool00000203oool01000
0000oooo0?ooo`0000060?ooo`030000003oool0oooo09T0oooo0P00001S0?ooo`002@3oool01000
0000oooo0?ooo`0000090?ooo`030000003oool0oooo00H0oooo0P00002?0?ooo`800000KP3oool0
00T0oooo00@000000?ooo`3oool000002P3oool00`000000oooo0?ooo`050?ooo`030000003oool0
oooo08h0oooo0P00001^0?ooo`002@3oool010000000oooo0?ooo`0000070?ooo`050000003oool0
oooo0?ooo`0000001P3oool00`000000oooo0?ooo`2<0?ooo`800000L03oool000T0oooo00@00000
0?ooo`3oool000001`3oool01@000000oooo0?ooo`3oool0000000H0oooo00<000000?ooo`3oool0
R`3oool300000700oooo000:0?ooo`8000002@3oool3000000L0oooo00<000000?ooo`3oool0R`3o
ool200000740oooo000O0?ooo`030000003oool0oooo08T0oooo0P00001`0?ooo`<00000000O0?oo
o`030000003oool0oooo08P0oooo0`00001[0?ooo`D000000`3oool001l0oooo00<000000?ooo`3o
ool0R03oool2000006L0oooo1@0000080?ooo`007`3oool00`000000oooo0?ooo`280?ooo`800000
HP3oool5000000d0oooo000O0?ooo`030000003oool0oooo08L0oooo0`00001M0?ooo`D000004P3o
ool001l0oooo00<000000?ooo`3oool0P`3oool200000080oooo0P00001I0?ooo`D000005`3oool0
01l0oooo00<000000?ooo`3oool0P`3oool2000005P0oooo1@00000L0?ooo`007`3oool00`000000
oooo0?ooo`1n0?ooo`800000E`3oool600000240oooo000O0?ooo`800000N`3oool200000080oooo
0P00001B0?ooo`D000009`3oool001l0oooo00<000000?ooo`3oool0N@3oool300000540oooo1@00
000/0?ooo`007`3oool00`000000oooo0?ooo`1i0?ooo`800000C@3oool500000340oooo000O0?oo
o`030000003oool0oooo07T0oooo0P0000180?ooo`D00000=P3oool001l0oooo00<000000?ooo`3o
ool0N@3oool2000004<0oooo1@00000k0?ooo`007`3oool00`000000oooo0?ooo`1g0?ooo`@00000
?P3oool500000400oooo000O0?ooo`030000003oool0oooo07D0oooo1000000j0?ooo`H00000A@3o
ool001l0oooo00<000000?ooo`3oool0KP3oool2000000D0oooo0P00000g0?ooo`D00000B`3oool0
01l0oooo00<000000?ooo`3oool0K@3oool3000003T0oooo1@00001@0?ooo`007`3oool00`000000
oooo0?ooo`1/0?ooo`<00000=@3oool5000005D0oooo000O0?ooo`800000K03oool300000340oooo
1@00001J0?ooo`007`3oool00`000000oooo0?ooo`1[0?ooo`800000;@3oool5000005l0oooo000O
0?ooo`030000003oool0oooo06X0oooo0`00000X0?ooo`D00000I03oool001l0oooo00<000000?oo
o`3oool0H@3oool2000000H0oooo0`00000S0?ooo`H00000J@3oool001l0oooo00<000000?ooo`3o
ool0H03oool3000000H0oooo0P00000N0?ooo`H00000K`3oool000X0oooo0P0000040?ooo`030000
003oool0oooo0080oooo0`0000070?ooo`030000003oool0oooo05h0oooo1000000Q0?ooo`H00000
M@3oool000T0oooo00@000000?ooo`3oool000001`3oool01@000000oooo0?ooo`3oool0000000H0
oooo00<000000?ooo`3oool0FP3oool3000000030?ooo`000000000001h0oooo1@00001k0?ooo`00
2@3oool010000000oooo0?ooo`00000;0?ooo`030000003oool0oooo00@0oooo0P00001G0?ooo`80
00000P3oool3000001/0oooo1P0000200?ooo`002@3oool010000000oooo0?ooo`00000;0?ooo`03
0000003oool0oooo00@0oooo00<000000?ooo`3oool0EP3oool2000001X0oooo1P0000260?ooo`00
2@3oool010000000oooo0?ooo`0000070?ooo`@000001`3oool00`000000oooo0?ooo`1B0?ooo`<0
000000<0oooo0000000000005@3oool5000008`0oooo00090?ooo`040000003oool0oooo000000L0
oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`1>0?ooo`L000004`3oool500000940
oooo000:0?ooo`800000203oool5000000H0oooo00<000000?ooo`3oool0B03oool2000000@0oooo
1000000A0?ooo`D00000UP3oool001l0oooo00<000000?ooo`3oool0@`3oool4000000030?ooo`00
0000000001@0oooo1@00002K0?ooo`007`3oool200000480oooo1P00000B0?ooo`D00000X03oool0
01l0oooo00<000000?ooo`3oool0?`3oool400000140oooo1@00002U0?ooo`007`3oool00`000000
oooo0?ooo`0n0?ooo`<000003P3oool500000:X0oooo000O0?ooo`030000003oool0oooo03/0oooo
1P0000090?ooo`D00000[`3oool001l0oooo00<000000?ooo`3oool0>03oool2000000040?ooo`00
00000000000000L0oooo1@00002d0?ooo`007`3oool2000003H0oooo0P000000103oool000000000
003oool2000000<0oooo1@00002i0?ooo`007`3oool00`000000oooo0?ooo`0d0?ooo`<00000103o
ool500000;h0oooo000O0?ooo`030000003oool0oooo0380oooo100000000`3oool0000000000002
00000<<0oooo000O0?ooo`030000003oool0oooo0200oooo0P0000080?ooo`8000001P3oool50000
0<L0oooo000O0?ooo`030000003oool0oooo01`0oooo0P000000103oool000000000000000080?oo
o`80000000<0oooo0000000000000`00003<0?ooo`007`3oool2000001T0oooo0P0000001@3oool0
0000000000000000oooo008000001`3oool500000=40oooo000O0?ooo`030000003oool0oooo01H0
oooo100000000`3oool00000000000060?ooo`D00000eP3oool001l0oooo00<000000?ooo`3oool0
503oool5000000@0oooo1P00003K0?ooo`007`3oool00`000000oooo0?ooo`0@0?ooo`d00000h@3o
ool001l0oooo0P00000=0?ooo`8000000P3oool700000>L0oooo000E0?ooo`<000001`3oool00`00
0000oooo0?ooo`060?ooo`80000000@0oooo000000000000oooo1P00003/0?ooo`005P3oool00`00
0000oooo0?ooo`060?ooo`030000003oool0oooo00<0oooo2@00003b0?ooo`005P3oool00`000000
oooo0?ooo`060?ooo`8000000`3oool500000?L0oooo000F0?ooo`030000003oool0oooo00H0oooo
00<000000?ooo`3oool00P3oool200000?X0oooo000F0?ooo`030000003oool0oooo00H0oooo00<0
00000?ooo`3oool0oP3oool001D0oooo0P0000080?ooo`030000003oool0oooo0?h0oooo000F0?oo
o`030000003oool0oooo00H0oooo00<000000?ooo`3oool0oP3oool00?l0oooo8@3oool00?l0oooo
8@3oool00?l0oooo8@3oool00?l0oooo8@3oool00001\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.216909, -2.206, \
0.00581693, 0.013074}}]
}, Open  ]],

Cell["\<\
Any junction  can be divided intotwolineages which eventually \
coalesce.  It seems that the rate of recombination & coalescence events which \
are experienced by a junction are clustered; it is unclear tome why that \
should be: 12/35 jumps, expect 17.5 maybe NS.\
\>", "Text"],

Cell[BoxData[
    \(ln = 
      Cases[ng3, 
            AncestralLineage[_, {_, _}, _, {___, 
                jj2\[LeftDoubleBracket]1\[RightDoubleBracket], ___}, _]] /. 
          AncestralLineage[_, {t0_, t1_}, _, _, _] \[RuleDelayed] {t0, t1} // 
        TableForm\)], "Input",
  CellLabel->"In[185]:="],

Cell[BoxData[
    TagBox[GridBox[{
          {
            StyleBox["0.329931463107078`",
              FontWeight->"Bold"], 
            StyleBox["0.4568003998260901`",
              FontWeight->"Bold"]},
          {"0.329931463107078`", "0.38364369685911537`"},
          {"0.38364369685911537`", "0.42744314121156557`"},
          {"0.42744314121156557`", "0.507768462805349`"},
          {
            StyleBox["0.4568003998260901`",
              FontWeight->"Bold"], 
            StyleBox["0.5209151607445`",
              FontWeight->"Bold"]},
          {"0.507768462805349`", "0.5830446807395154`"},
          {
            StyleBox["0.5209151607445`",
              FontWeight->"Bold"], 
            StyleBox["0.5293619453348968`",
              FontWeight->"Bold"]},
          {
            StyleBox["0.5293619453348968`",
              FontWeight->"Bold"], 
            StyleBox["0.7020832066440357`",
              FontWeight->"Bold"]},
          {"0.5830446807395154`", "0.6222840055386949`"},
          {"0.6222840055386949`", "0.6523618159041582`"},
          {"0.6523618159041582`", "0.668031024515994`"},
          {"0.668031024515994`", "0.6784208156310324`"},
          {"0.6784208156310324`", "0.6946654678999733`"},
          {"0.6946654678999733`", "0.708095109264615`"},
          {
            StyleBox["0.7020832066440357`",
              FontWeight->"Bold"], 
            StyleBox["0.7516690243229127`",
              FontWeight->"Bold"]},
          {"0.708095109264615`", "0.8090690177371749`"},
          {
            StyleBox["0.7516690243229127`",
              FontWeight->"Bold"], 
            StyleBox["0.7734335480543457`",
              FontWeight->"Bold"]},
          {
            StyleBox["0.7734335480543457`",
              FontWeight->"Bold"], 
            StyleBox["0.8002587389665864`",
              FontWeight->"Bold"]},
          {
            StyleBox["0.8002587389665864`",
              FontWeight->"Bold"], 
            StyleBox["0.803134888607892`",
              FontWeight->"Bold"]},
          {
            StyleBox["0.803134888607892`",
              FontWeight->"Bold"], 
            StyleBox["0.9786686415039456`",
              FontWeight->"Bold"]},
          {"0.8090690177371749`", "0.8202479317821718`"},
          {"0.8202479317821718`", "0.9449519007429196`"},
          {"0.9449519007429196`", "0.9497433316644266`"},
          {"0.9497433316644266`", "0.9534091339738535`"},
          {"0.9534091339738535`", "0.9990512263485568`"},
          {
            StyleBox["0.9786686415039456`",
              FontWeight->"Bold"], 
            StyleBox["0.9807454371136447`",
              FontWeight->"Bold"]},
          {
            StyleBox["0.9807454371136447`",
              FontWeight->"Bold"], 
            StyleBox["0.9822081564681514`",
              FontWeight->"Bold"]},
          {
            StyleBox["0.9822081564681514`",
              FontWeight->"Bold"], 
            StyleBox["0.9975516841036635`",
              FontWeight->"Bold"]},
          {
            StyleBox["0.9975516841036635`",
              FontWeight->"Bold"], 
            StyleBox["1.0379355689133114`",
              FontWeight->"Bold"]},
          {"0.9990512263485568`", "1.0192173508044078`"},
          {"1.0192173508044078`", "1.0348101591672474`"},
          {"1.0348101591672474`", "1.1249379306746126`"},
          {
            StyleBox["1.0379355689133114`",
              FontWeight->"Bold"], 
            StyleBox["1.1018700428338397`",
              FontWeight->"Bold"]},
          {
            StyleBox["1.1018700428338397`",
              FontWeight->"Bold"], 
            StyleBox["1.1195335051040434`",
              FontWeight->"Bold"]},
          {
            StyleBox["1.1195335051040434`",
              FontWeight->"Bold"], 
            StyleBox["1.1208450962946976`",
              FontWeight->"Bold"]},
          {
            StyleBox["1.1208450962946976`",
              FontWeight->"Bold"], 
            StyleBox["1.1249379306746126`",
              FontWeight->"Bold"]}
          },
        RowSpacings->1,
        ColumnSpacings->3,
        RowAlignments->Baseline,
        ColumnAlignments->{Left}],
      (TableForm[ #]&)]], "Text",
  CellLabel->"Out[185]//TableForm="],

Cell[BoxData[
    \(ln = 
      Cases[ng3, 
            AncestralLineage[_, {_, _}, _, {___, 
                jj2\[LeftDoubleBracket]61\[RightDoubleBracket], ___}, _]] /. 
          AncestralLineage[_, {t0_, t1_}, _, _, _] \[RuleDelayed] {t0, t1} // 
        TableForm\)], "Input",
  CellLabel->"In[190]:="],

Cell[BoxData[
    TagBox[GridBox[{
          {
            StyleBox["0.1559361293631408`",
              FontWeight->"Bold"], 
            StyleBox["0.160334250292317`",
              FontWeight->"Bold"]},
          {"0.1559361293631408`", "0.21709701483661317`"},
          {
            StyleBox["0.160334250292317`",
              FontWeight->"Bold"], 
            StyleBox["0.1642880659078308`",
              FontWeight->"Bold"]},
          {
            StyleBox["0.1642880659078308`",
              FontWeight->"Bold"], 
            StyleBox["0.23275030859470994`",
              FontWeight->"Bold"]},
          {"0.21709701483661317`", "0.260724084246132`"},
          {
            StyleBox["0.23275030859470994`",
              FontWeight->"Bold"], 
            StyleBox["0.25956603295619035`",
              FontWeight->"Bold"]},
          {
            StyleBox["0.25956603295619035`",
              FontWeight->"Bold"], 
            StyleBox["0.26150061125509316`",
              FontWeight->"Bold"]},
          {"0.260724084246132`", "0.2846840471563729`"},
          {
            StyleBox["0.26150061125509316`",
              FontWeight->"Bold"], 
            StyleBox["0.37555416879619596`",
              FontWeight->"Bold"]},
          {"0.2846840471563729`", "0.4372776607394767`"},
          {
            StyleBox["0.37555416879619596`",
              FontWeight->"Bold"], 
            StyleBox["0.706321091066409`",
              FontWeight->"Bold"]},
          {"0.4372776607394767`", "0.45232724665320645`"},
          {"0.45232724665320645`", "0.4560746927310513`"},
          {"0.4560746927310513`", "0.5729435939257148`"},
          {"0.5729435939257148`", "0.5959983108766256`"},
          {"0.5959983108766256`", "0.6512440220117621`"},
          {"0.6512440220117621`", "0.6637624917313586`"},
          {"0.6637624917313586`", "0.668031024515994`"},
          {"0.668031024515994`", "0.6784208156310324`"},
          {"0.6784208156310324`", "0.6858320874042798`"},
          {"0.6858320874042798`", "0.701182850457972`"},
          {"0.701182850457972`", "0.7182533138949982`"},
          {
            StyleBox["0.706321091066409`",
              FontWeight->"Bold"], 
            StyleBox["0.7254164922078413`",
              FontWeight->"Bold"]},
          {"0.7182533138949982`", "0.7818093180482938`"},
          {
            StyleBox["0.7254164922078413`",
              FontWeight->"Bold"], 
            StyleBox["0.7528220981891484`",
              FontWeight->"Bold"]},
          {
            StyleBox["0.7528220981891484`",
              FontWeight->"Bold"], 
            StyleBox["0.8002587389665864`",
              FontWeight->"Bold"]},
          {"0.7818093180482938`", "0.7821209779332101`"},
          {"0.7821209779332101`", "0.7889344090363858`"},
          {"0.7889344090363858`", "0.8090690177371749`"},
          {
            StyleBox["0.8002587389665864`",
              FontWeight->"Bold"], 
            StyleBox["0.803134888607892`",
              FontWeight->"Bold"]},
          {
            StyleBox["0.803134888607892`",
              FontWeight->"Bold"], 
            StyleBox["0.8134021717202482`",
              FontWeight->"Bold"]},
          {"0.8090690177371749`", "0.8202479317821718`"},
          {
            StyleBox["0.8134021717202482`",
              FontWeight->"Bold"], 
            StyleBox["0.8431185790336898`",
              FontWeight->"Bold"]},
          {"0.8202479317821718`", "0.9285949049471538`"},
          {
            StyleBox["0.8431185790336898`",
              FontWeight->"Bold"], 
            StyleBox["0.8575183333012459`",
              FontWeight->"Bold"]},
          {
            StyleBox["0.8575183333012459`",
              FontWeight->"Bold"], 
            StyleBox["0.8994223068813056`",
              FontWeight->"Bold"]},
          {
            StyleBox["0.8994223068813056`",
              FontWeight->"Bold"], 
            StyleBox["0.9277857301520099`",
              FontWeight->"Bold"]},
          {
            StyleBox["0.9277857301520099`",
              FontWeight->"Bold"], 
            StyleBox["0.9586648717502044`",
              FontWeight->"Bold"]},
          {"0.9285949049471538`", "0.9647520150844745`"},
          {
            StyleBox["0.9586648717502044`",
              FontWeight->"Bold"], 
            StyleBox["0.9805702838766691`",
              FontWeight->"Bold"]},
          {"0.9647520150844745`", "0.9807454371136447`"},
          {
            StyleBox["0.9805702838766691`",
              FontWeight->"Bold"], 
            StyleBox["0.9843090139358366`",
              FontWeight->"Bold"]},
          {"0.9807454371136447`", "0.9822081564681514`"},
          {"0.9822081564681514`", "1.0165681734512617`"},
          {
            StyleBox["0.9843090139358366`",
              FontWeight->"Bold"], 
            StyleBox["1.01188949948083`",
              FontWeight->"Bold"]},
          {
            StyleBox["1.01188949948083`",
              FontWeight->"Bold"], 
            StyleBox["1.0331756711699087`",
              FontWeight->"Bold"]},
          {"1.0165681734512617`", "1.030097911840865`"},
          {"1.030097911840865`", "1.1371514870979105`"},
          {
            StyleBox["1.0331756711699087`",
              FontWeight->"Bold"], 
            StyleBox["1.1273117692729726`",
              FontWeight->"Bold"]},
          {
            StyleBox["1.1273117692729726`",
              FontWeight->"Bold"], 
            StyleBox["1.1529659092838744`",
              FontWeight->"Bold"]},
          {"1.1371514870979105`", "1.438981785366448`"},
          {
            StyleBox["1.1529659092838744`",
              FontWeight->"Bold"], 
            StyleBox["1.3508739900529942`",
              FontWeight->"Bold"]},
          {
            StyleBox["1.3508739900529942`",
              FontWeight->"Bold"], 
            StyleBox["1.3662131863982554`",
              FontWeight->"Bold"]},
          {
            StyleBox["1.3662131863982554`",
              FontWeight->"Bold"], 
            StyleBox["1.3692897554417993`",
              FontWeight->"Bold"]},
          {
            StyleBox["1.3692897554417993`",
              FontWeight->"Bold"], 
            StyleBox["1.4097190591344955`",
              FontWeight->"Bold"]},
          {
            StyleBox["1.4097190591344955`",
              FontWeight->"Bold"], 
            StyleBox["1.4173535673418782`",
              FontWeight->"Bold"]},
          {
            StyleBox["1.4173535673418782`",
              FontWeight->"Bold"], 
            StyleBox["1.4463615613515206`",
              FontWeight->"Bold"]},
          {"1.438981785366448`", "1.4415653805013102`"},
          {"1.4415653805013102`", "1.4519427892392354`"},
          {
            StyleBox["1.4463615613515206`",
              FontWeight->"Bold"], 
            StyleBox["1.5145964429299605`",
              FontWeight->"Bold"]},
          {"1.4519427892392354`", "1.482873323748218`"},
          {"1.482873323748218`", "1.57304908990861`"},
          {
            StyleBox["1.5145964429299605`",
              FontWeight->"Bold"], 
            StyleBox["1.5307384223609708`",
              FontWeight->"Bold"]},
          {
            StyleBox["1.5307384223609708`",
              FontWeight->"Bold"], 
            StyleBox["1.544494757125082`",
              FontWeight->"Bold"]},
          {
            StyleBox["1.544494757125082`",
              FontWeight->"Bold"], 
            StyleBox["1.57304908990861`",
              FontWeight->"Bold"]}
          },
        RowSpacings->1,
        ColumnSpacings->3,
        RowAlignments->Baseline,
        ColumnAlignments->{Left}],
      (TableForm[ #]&)]], "Text",
  CellLabel->"Out[190]//TableForm="]
}, Closed]],

Cell[CellGroupData[{

Cell["Timing of coalescence events", "SubsubsectionIcon"],

Cell["\<\
There is no simple way to check that the rate of coalescence is as \
it should be, because there is a competition with recombination, which has an \
imponderable distribution\
\>", "Text"],

Cell[BoxData[
    \(\(ae = AllEvents[ng3];\)\)], "Input",
  CellLabel->"In[201]:="],

Cell[BoxData[
    \(\(te = TimesOfEvents[ng3];\)\)], "Input",
  CellLabel->"In[213]:="],

Cell[CellGroupData[{

Cell[BoxData[
    \(re = RecombinationEvents[ng3]; Length[re]\)], "Input",
  CellLabel->"In[205]:="],

Cell[BoxData[
    \(1504\)], "Output",
  CellLabel->"Out[205]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(ce = CoalescenceEvents[ng3]; Length[ce]\)], "Input",
  CellLabel->"In[203]:="],

Cell[BoxData[
    \(1487\)], "Output",
  CellLabel->"Out[203]="]
}, Open  ]],

Cell["\<\
This tabulates the # of lineages present before each coalesacence \
event, and the time to coalescence:\
\>", "Text"],

Cell[BoxData[
    \(\(ktbl = \({Length[
                LineagesPresent[
                  ng3, #\[LeftDoubleBracket]1\[RightDoubleBracket] - 
                    10\^\(-6\)]], #\[LeftDoubleBracket]1\[RightDoubleBracket] \
- te\[LeftDoubleBracket]\(Position[
                        te, #\[LeftDoubleBracket]1\[RightDoubleBracket]]\)\
\[LeftDoubleBracket]1, 1\[RightDoubleBracket] - 1\[RightDoubleBracket]} &\) /@ 
          ce;\)\)], "Input",
  CellLabel->"In[218]:="],

Cell["Most of the time, there are around 20 extant lineages.", "Text"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(tt = 
        Table[cc = Last /@ Cases[ktbl, {j, _}]; {j, Length[cc], Mean[cc], 
            Variance[cc]}, {j, 29}];\)\), "\[IndentingNewLine]", 
    \(tt = DeleteCases[tt, {_, 0 | 1, __}]; tt // TableForm\)}], "Input",
  CellLabel->"In[228]:="],

Cell[BoxData[
    TagBox[GridBox[{
          {"6", "2", "0.020457219897701467`", "0.0007616782648240041`"},
          {"9", "3", "0.004457095629845291`", "0.00001308821462481826`"},
          {"10", "2", "0.008586384308289008`", "0.00012076480577861169`"},
          {"11", "5", "0.007771043987141285`", "0.00011860204250116715`"},
          {"12", "26", "0.004050804933091053`", "0.000013523435879156649`"},
          {"13", "32", "0.006195948040013515`", "0.00003951052140873601`"},
          {"14", "53", "0.004379358058425848`", "0.00001936881235728373`"},
          {"15", "74", "0.003679079722746429`", "0.000011164418486835251`"},
          {"16", "83", "0.004086545483333891`", "0.000013609228605317105`"},
          {"17", "113", "0.0033223927831127526`", 
            "0.000014348535021112539`"},
          {"18", "141", "0.00280427435153651`", "9.589652339298686`*^-6"},
          {"19", "162", "0.0033122472681614374`", 
            "0.000013098646808263622`"},
          {"20", "181", "0.0032214624571473456`", 
            "0.000012625424322348193`"},
          {"21", "199", "0.00293817509228076`", "8.639929484056306`*^-6"},
          {"22", "135", "0.0023077520979281367`", "5.547295262266332`*^-6"},
          {"23", "103", "0.002440692875849073`", "5.681403075125813`*^-6"},
          {"24", "71", "0.0024241487483747386`", "4.709987973539936`*^-6"},
          {"25", "54", "0.0023926888606624207`", "4.183377611024071`*^-6"},
          {"26", "31", "0.0017804482875149374`", "2.2449923830852404`*^-6"},
          {"27", "12", "0.00149353389840301`", "2.7804427019692783`*^-6"},
          {"28", "3", "0.001232162496896431`", "1.0983880942186418`*^-6"}
          },
        RowSpacings->1,
        ColumnSpacings->3,
        RowAlignments->Baseline,
        ColumnAlignments->{Left}],
      (TableForm[ #]&)]], "Output",
  CellLabel->"Out[229]//TableForm="]
}, Open  ]],

Cell["\<\
The mean time to coalescence is approximately ~ 1/k, rather than \
the expected 2/k(k-1); not surprising,since recombination competes with \
coalescence.\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(ListPlot[
        Transpose[\(Transpose[tt]\)\[LeftDoubleBracket]{1, 
                3}\[RightDoubleBracket]] /. {k_, t_} \[RuleDelayed] {k, 
              t\ \ k}, PlotJoined \[Rule] True];\)\)], "Input",
  CellLabel->"In[234]:="],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.235931 0.04329 -0.215413 6.67028 [
[.19697 .43911 -6 -9 ]
[.19697 .43911 6 0 ]
[.41342 .43911 -6 -9 ]
[.41342 .43911 6 0 ]
[.62987 .43911 -6 -9 ]
[.62987 .43911 6 0 ]
[.84632 .43911 -6 -9 ]
[.84632 .43911 6 0 ]
[.14118 .0514 -24 -4.5 ]
[.14118 .0514 0 4.5 ]
[.14118 .1848 -24 -4.5 ]
[.14118 .1848 0 4.5 ]
[.14118 .31821 -24 -4.5 ]
[.14118 .31821 0 4.5 ]
[.14118 .58502 -24 -4.5 ]
[.14118 .58502 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.19697 .45161 m
.19697 .45786 L
s
[(10)] .19697 .43911 0 1 Mshowa
.41342 .45161 m
.41342 .45786 L
s
[(15)] .41342 .43911 0 1 Mshowa
.62987 .45161 m
.62987 .45786 L
s
[(20)] .62987 .43911 0 1 Mshowa
.84632 .45161 m
.84632 .45786 L
s
[(25)] .84632 .43911 0 1 Mshowa
.125 Mabswid
.24026 .45161 m
.24026 .45536 L
s
.28355 .45161 m
.28355 .45536 L
s
.32684 .45161 m
.32684 .45536 L
s
.37013 .45161 m
.37013 .45536 L
s
.45671 .45161 m
.45671 .45536 L
s
.5 .45161 m
.5 .45536 L
s
.54329 .45161 m
.54329 .45536 L
s
.58658 .45161 m
.58658 .45536 L
s
.67316 .45161 m
.67316 .45536 L
s
.71645 .45161 m
.71645 .45536 L
s
.75974 .45161 m
.75974 .45536 L
s
.80303 .45161 m
.80303 .45536 L
s
.11039 .45161 m
.11039 .45536 L
s
.0671 .45161 m
.0671 .45536 L
s
.02381 .45161 m
.02381 .45536 L
s
.88961 .45161 m
.88961 .45536 L
s
.9329 .45161 m
.9329 .45536 L
s
.97619 .45161 m
.97619 .45536 L
s
.25 Mabswid
0 .45161 m
1 .45161 L
s
.15368 .0514 m
.15993 .0514 L
s
[(0.04)] .14118 .0514 1 0 Mshowa
.15368 .1848 m
.15993 .1848 L
s
[(0.06)] .14118 .1848 1 0 Mshowa
.15368 .31821 m
.15993 .31821 L
s
[(0.08)] .14118 .31821 1 0 Mshowa
.15368 .58502 m
.15993 .58502 L
s
[(0.12)] .14118 .58502 1 0 Mshowa
.125 Mabswid
.15368 .08475 m
.15743 .08475 L
s
.15368 .1181 m
.15743 .1181 L
s
.15368 .15145 m
.15743 .15145 L
s
.15368 .21815 m
.15743 .21815 L
s
.15368 .25151 m
.15743 .25151 L
s
.15368 .28486 m
.15743 .28486 L
s
.15368 .35156 m
.15743 .35156 L
s
.15368 .38491 m
.15743 .38491 L
s
.15368 .41826 m
.15743 .41826 L
s
.15368 .48497 m
.15743 .48497 L
s
.15368 .51832 m
.15743 .51832 L
s
.15368 .55167 m
.15743 .55167 L
s
.15368 .01805 m
.15743 .01805 L
s
.25 Mabswid
.15368 0 m
.15368 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .60332 m
.15368 .05216 L
.19697 .35732 L
.24026 .35477 L
.28355 .10883 L
.32684 .32186 L
.37013 .19355 L
.41342 .15269 L
.45671 .22072 L
.5 .16133 L
.54329 .12128 L
.58658 .20437 L
.62987 .21435 L
.67316 .19615 L
.71645 .12324 L
.75974 .15903 L
.80303 .17266 L
.84632 .18358 L
.88961 .09337 L
.9329 .05357 L
.97619 .01472 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[234]:=",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/B000`400?l00000o`00003o;03oool0
0`000000oooo0?ooo`3a0?ooo`00;03oool00`000000oooo0?ooo`3a0?ooo`00;03oool00`000000
oooo0?ooo`3a0?ooo`00;03oool00`000000oooo0?ooo`3a0?ooo`00;03oool00`000000oooo0?oo
o`3W0?ooo`800000203oool002`0oooo0P00003W0?ooo`030000003oool0oooo00P0oooo000/0?oo
o`030000003oool0oooo0>D0oooo00<000000?ooo`3oool02@3oool002`0oooo00<000000?ooo`3o
ool0i03oool00`000000oooo0?ooo`0:0?ooo`00;03oool00`000000oooo0?ooo`3S0?ooo`030000
003oool0oooo00/0oooo000/0?ooo`030000003oool0oooo0>80oooo00<000000?ooo`3oool0303o
ool002`0oooo00<000000?ooo`3oool0h@3oool00`000000oooo0?ooo`0=0?ooo`00;03oool00`00
0000oooo0?ooo`3P0?ooo`030000003oool0oooo00h0oooo000B0?ooo`800000103oool00`000000
oooo0?ooo`030?ooo`800000103oool3000000D0oooo00<000000?ooo`3oool0g`3oool00`000000
oooo0?ooo`0?0?ooo`004@3oool010000000oooo0?ooo`0000080?ooo`040000003oool0oooo0000
00@0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`3N0?ooo`030000003oool0oooo
0100oooo000A0?ooo`040000003oool0oooo000000P0oooo00D000000?ooo`3oool000000?ooo`05
000000D0oooo0`00003M0?ooo`030000003oool0oooo0140oooo000A0?ooo`040000003oool0oooo
000000P0oooo00H000000?ooo`3oool000000?ooo`0000020?ooo`030000003oool0oooo00@0oooo
00<000000?ooo`3oool0f`3oool2000001@0oooo000A0?ooo`040000003oool0oooo000000P0oooo
00@000000?ooo`3oool000000P3oool00`000000oooo000000060?ooo`030000003oool0oooo0=X0
oooo00<000000?ooo`3oool0503oool00140oooo00@000000?ooo`3oool00000203oool010000000
oooo0?ooo`0000030?ooo`8000001@3oool200000=/0oooo00<000000?ooo`3oool05@3oool00180
oooo0P00000:0?ooo`8000001@3oool00`000000oooo0?ooo`030?ooo`800000fP3oool00`000000
oooo0?ooo`0F0?ooo`00:`3oool300000=P0oooo00<000000?ooo`3oool05`3oool002/0oooo0`00
003G0?ooo`030000003oool0oooo01P0oooo000Z0?ooo`040000003oool0000000000=H0oooo00<0
00000?ooo`3oool06@3oool002X0oooo00@000000?ooo`0000000000e@3oool00`000000oooo0?oo
o`0J0?ooo`00:P3oool010000000oooo00000000003D0?ooo`030000003oool0oooo01/0oooo000Z
0?ooo`040000003oool0000000000=<0oooo00<000000?ooo`3oool0703oool002X0oooo00@00000
0?ooo`0000000000dP3oool00`000000oooo0?ooo`0M0?ooo`00:@3oool01P000000oooo0?ooo`00
0000oooo00000=00oooo00<000000?ooo`3oool07P3oool002T0oooo00H000000?ooo`3oool00000
0?ooo`00003@0?ooo`030000003oool0oooo01h0oooo000Y0?ooo`060000003oool0oooo0000003o
ool00000c`3oool00`000000oooo0?ooo`0O0?ooo`00:@3oool01P000000oooo0?ooo`000000oooo
00000<l0oooo00<000000?ooo`3oool07`3oool002P0oooo00L000000?ooo`3oool0oooo0000003o
ool000000<h0oooo00<000000?ooo`3oool0803oool002P0oooo00L000000?ooo`3oool0oooo0000
003oool000000280oooo00<000000?ooo`3oool0Z@3oool00`000000oooo0?ooo`0P0?ooo`00:03o
ool01`000000oooo0?ooo`3oool000000?ooo`0000008P3oool00`000000oooo0?ooo`2X0?ooo`03
0000003oool0oooo0240oooo000X0?ooo`040000003oool0oooo0?ooo`80000000<0oooo0000003o
ool0803oool00`000000oooo0?ooo`2X0?ooo`030000003oool0oooo0240oooo000W0?ooo`030000
003oool0oooo0080oooo00@000000?ooo`3oool000008@3oool00`000000oooo0?ooo`170?ooo`03
0000003oool0oooo05d0oooo00<000000?ooo`3oool08P3oool002L0oooo00<000000?ooo`3oool0
0P3oool010000000oooo0?ooo`00000P0?ooo`030000003oool0000004L0oooo0P00000a0?ooo`80
0000;03oool00`000000oooo0?ooo`0R0?ooo`009`3oool00`000000oooo0?ooo`020?ooo`040000
003oool0oooo00000200oooo00<000000?ooo`000000AP3oool010000000oooo0?ooo`00000`0?oo
o`030000003oool0000002X0oooo00<000000?ooo`3oool08`3oool002L0oooo00<000000?ooo`3o
ool00P3oool010000000oooo0?ooo`00000P0?ooo`030000003oool0000004D0oooo00D000000?oo
o`3oool0oooo0000000_0?ooo`050000003oool0oooo0?ooo`000000:@3oool00`000000oooo0?oo
o`0S0?ooo`009P3oool00`000000oooo0?ooo`030?ooo`040000003oool0oooo00000200oooo00<0
00000?ooo`000000A03oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo02`0oooo00<0
00000?ooo`3oool00P3oool00`000000oooo0?ooo`0U0?ooo`030000003oool0oooo02@0oooo000V
0?ooo`030000003oool0oooo00<0oooo00@000000?ooo`3oool00000803oool00`000000oooo0000
00130?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0:`3oool00`000000oooo0?oo
o`040?ooo`030000003oool0oooo02@0oooo00<000000?ooo`3oool0903oool002H0oooo00<00000
0?ooo`3oool00`3oool010000000oooo0?ooo`00000P0?ooo`040000003oool0oooo00000440oooo
00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`0Y0?ooo`030000003oool0oooo00H0oooo
0P00000S0?ooo`030000003oool0oooo02D0oooo000V0?ooo`030000003oool0oooo00<0oooo00D0
00000?ooo`3oool0oooo0000000N0?ooo`050000003oool0oooo0?ooo`000000@03oool00`000000
oooo0?ooo`080?ooo`030000003oool0oooo02P0oooo00<000000?ooo`3oool0203oool00`000000
oooo0?ooo`0P0?ooo`030000003oool0oooo02D0oooo000V0?ooo`030000003oool0oooo00<0oooo
00D000000?ooo`3oool0oooo0000000N0?ooo`050000003oool0oooo0?ooo`000000?`3oool00`00
0000oooo0?ooo`090?ooo`030000003oool0oooo02L0oooo00<000000?ooo`3oool02P3oool00`00
0000oooo0?ooo`0N0?ooo`030000003oool0oooo02H0oooo000U0?ooo`030000003oool0oooo00@0
oooo0P0000020?ooo`030000003oool0oooo01`0oooo00D000000?ooo`3oool0oooo0000000R0?oo
o`030000003oool0oooo01T0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`0V0?oo
o`030000003oool0oooo00/0oooo00<000000?ooo`3oool07@3oool00`000000oooo0?ooo`0V0?oo
o`009@3oool00`000000oooo0?ooo`040?ooo`050000003oool0oooo0?ooo`0000007P3oool01@00
0000oooo0?ooo`3oool000000240oooo0P00000J0?ooo`030000003oool0oooo00`0oooo00<00000
0?ooo`3oool09@3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo01/0oooo00<00000
0?ooo`3oool09`3oool002D0oooo00<000000?ooo`3oool0103oool01@000000oooo0?ooo`3oool0
000001h0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0M0?ooo`040000003oool0
oooo000001P0oooo00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`0T0?ooo`030000003o
ool0oooo00h0oooo0`00000J0?ooo`030000003oool0oooo02L0oooo000U0?ooo`030000003oool0
oooo00@0oooo00D000000?ooo`3oool0oooo0000000N0?ooo`030000003oool0oooo0080oooo00<0
00000?ooo`3oool0703oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo01@0oooo00<0
00000?ooo`3oool03`3oool00`000000oooo0?ooo`0S0?ooo`030000003oool0oooo0180oooo0`00
000F0?ooo`030000003oool0oooo02P0oooo000T0?ooo`030000003oool0oooo00D0oooo00D00000
0?ooo`3oool0oooo0000000M0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool06`3o
ool00`000000oooo0?ooo`030?ooo`030000003oool0oooo01@0oooo00<000000?ooo`3oool0403o
ool00`000000oooo0?ooo`0Q0?ooo`030000003oool0oooo01H0oooo0`00000C0?ooo`030000003o
ool0oooo02P0oooo000T0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool00P3oool0
0`000000oooo0?ooo`0J0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool06P3oool0
0`000000oooo0?ooo`050?ooo`030000003oool0oooo0180oooo00<000000?ooo`3oool04@3oool0
0`000000oooo0?ooo`0Q0?ooo`030000003oool0oooo01T0oooo0`00000?0?ooo`030000003oool0
oooo02T0oooo000T0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool00P3oool00`00
0000oooo0?ooo`0J0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool06@3oool00`00
0000oooo0?ooo`070?ooo`030000003oool0oooo0100oooo00<000000?ooo`3oool04`3oool00`00
0000oooo0?ooo`0O0?ooo`030000003oool0oooo01d0oooo1000000;0?ooo`030000003oool0oooo
02T0oooo000B0?ooo`800000103oool00`000000oooo0?ooo`030?ooo`8000000`3oool3000000H0
oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0J0?ooo`030000003oool0oooo00@0
oooo00<000000?ooo`3oool05`3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo0100
oooo00<000000?ooo`3oool04`3oool00`000000oooo0?ooo`0O0?ooo`030000003oool0oooo0240
oooo100000060?ooo`030000003oool0oooo02X0oooo000A0?ooo`040000003oool0oooo000000P0
oooo00D000000?ooo`3oool000000?ooo`0200000080oooo00<000000?ooo`3oool00`3oool00`00
0000oooo0?ooo`020?ooo`030000003oool0oooo01X0oooo00<000000?ooo`3oool0103oool00`00
0000oooo0?ooo`0F0?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool03P3oool00`00
0000oooo0?ooo`0E0?ooo`030000003oool0oooo01d0oooo00<000000?ooo`3oool09P3oool40000
0080oooo00<000000?ooo`3oool0:P3oool00140oooo00@000000?ooo`3oool00000203oool01@00
0000oooo0?ooo`000000oooo008000000P3oool00`000000oooo0?ooo`030?ooo`<000000P3oool0
0`000000oooo0?ooo`0I0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool05@3oool0
0`000000oooo0?ooo`0<0?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool05P3oool0
0`000000oooo0?ooo`0M0?ooo`030000003oool0oooo02X0oooo0P00000]0?ooo`004@3oool01000
0000oooo0?ooo`0000080?ooo`050000003oool0oooo0000003oool0100000060?ooo`030000003o
ool0oooo0080oooo00<000000?ooo`3oool06@3oool00`000000oooo0?ooo`050?ooo`030000003o
ool0oooo01@0oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`0;0?ooo`030000003o
ool0oooo01P0oooo00<000000?ooo`3oool06`3oool00`000000oooo0?ooo`1J0?ooo`004@3oool0
10000000oooo0?ooo`0000080?ooo`050000003oool0oooo0000003oool00P0000080?ooo`030000
003oool0oooo0080oooo00<000000?ooo`3oool06@3oool00`000000oooo0?ooo`050?ooo`030000
003oool0oooo01<0oooo00<000000?ooo`3oool03`3oool00`000000oooo0?ooo`0:0?ooo`030000
003oool0oooo01T0oooo00<000000?ooo`3oool06@3oool00`000000oooo0?ooo`1K0?ooo`004@3o
ool010000000oooo0?ooo`0000080?ooo`040000003oool0oooo00000080oooo00<000000?ooo`3o
ool01P3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo01P0oooo00<000000?ooo`3o
ool01P3oool00`000000oooo0?ooo`0A0?ooo`030000003oool0oooo0100oooo00<000000?ooo`3o
ool02@3oool00`000000oooo0?ooo`0J0?ooo`030000003oool0oooo01T0oooo00<000000?ooo`3o
ool0F`3oool00180oooo0P00000:0?ooo`8000000P3oool010000000oooo0000000000060?ooo`03
0000003oool0oooo00<0oooo00<000000?ooo`3oool0603oool00`000000oooo0?ooo`060?ooo`03
0000003oool0oooo0140oooo00<000000?ooo`3oool04@3oool00`000000oooo0?ooo`070?ooo`03
0000003oool0oooo01`0oooo00<000000?ooo`3oool05P3oool2000005h0oooo000R0?ooo`030000
003oool0oooo00L0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`0H0?ooo`030000
003oool0oooo00H0oooo00<000000?ooo`3oool0403oool00`000000oooo0?ooo`0C0?ooo`030000
003oool0oooo00H0oooo00<000000?ooo`3oool0703oool00`000000oooo0?ooo`0C0?ooo`<00000
H03oool00280oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`030?ooo`030000003o
ool0oooo01L0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`0@0?ooo`030000003o
ool0oooo01<0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`0N0?ooo`<000003`3o
ool3000006<0oooo000R0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool00`3oool0
0`000000oooo0?ooo`0G0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool0403oool0
0`000000oooo0?ooo`0D0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool08P3oool4
000000T0oooo0P00001V0?ooo`008@3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo
00<0oooo00<000000?ooo`3oool05`3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo
00h0oooo00<000000?ooo`3oool05P3oool01@000000oooo0?ooo`3oool0000002T0oooo10000002
0?ooo`<00000J03oool00240oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`030?oo
o`030000003oool0oooo01L0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`0>0?oo
o`030000003oool0oooo01H0oooo00D000000?ooo`3oool0oooo0000000]0?ooo`800000J`3oool0
0240oooo00<000000?ooo`3oool0203oool2000000@0oooo00<000000?ooo`3oool05`3oool00`00
0000oooo0?ooo`080?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3oool05`3oool00`00
0000oooo0000002K0?ooo`008@3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo00@0
oooo00<000000?ooo`3oool05P3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo00d0
oooo00<000000?ooo`3oool06@3oool00`000000oooo0?ooo`2J0?ooo`00803oool00`000000oooo
0?ooo`090?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool05@3oool00`000000oooo
0?ooo`090?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool0]P3oool00200oooo00<0
00000?ooo`3oool02@3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo01D0oooo00<0
00000?ooo`3oool02P3oool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo0;H0oooo000P
0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`0E
0?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`2g
0?ooo`00803oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00@0oooo00<000000?oo
o`3oool05@3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo00/0oooo00<000000?oo
o`3oool0]`3oool001l0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`040?ooo`03
0000003oool0oooo01D0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`0;0?ooo`03
0000003oool0oooo0;L0oooo000O0?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool0
103oool00`000000oooo0?ooo`0E0?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool0
2P3oool00`000000oooo0?ooo`2h0?ooo`007`3oool00`000000oooo0?ooo`0:0?ooo`030000003o
ool0oooo00D0oooo00<000000?ooo`3oool04`3oool00`000000oooo0?ooo`0<0?ooo`030000003o
ool0oooo00T0oooo00<000000?ooo`3oool0^03oool001l0oooo00<000000?ooo`3oool02P3oool0
0`000000oooo0?ooo`050?ooo`030000003oool0oooo01<0oooo00<000000?ooo`3oool0303oool0
0`000000oooo0?ooo`090?ooo`030000003oool0oooo0;P0oooo000O0?ooo`030000003oool0oooo
00X0oooo0P0000060?ooo`030000003oool0oooo01<0oooo00<000000?ooo`3oool0303oool00`00
0000oooo0?ooo`080?ooo`030000003oool0oooo0;T0oooo000N0?ooo`030000003oool0oooo00/0
oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`0C0?ooo`030000003oool0oooo00`0
oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`2i0?ooo`007P3oool00`000000oooo
0?ooo`0;0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool04`3oool00`000000oooo
0?ooo`0<0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool0^P3oool001h0oooo00<0
00000?ooo`3oool02`3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo01<0oooo00<0
00000?ooo`3oool03@3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo0;X0oooo000N
0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`0B
0?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`2j
0?ooo`007@3oool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo00H0oooo00<000000?oo
o`3oool04@3oool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo00D0oooo00<000000?oo
o`3oool0^`3oool001d0oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`060?ooo`03
0000003oool0oooo0140oooo00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`050?ooo`03
0000003oool0oooo0;/0oooo000M0?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool0
1P3oool00`000000oooo0?ooo`0A0?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3oool0
1@3oool00`000000oooo0?ooo`2k0?ooo`007@3oool00`000000oooo0?ooo`0<0?ooo`030000003o
ool0oooo00H0oooo00<000000?ooo`3oool04@3oool00`000000oooo0?ooo`0?0?ooo`030000003o
ool0oooo00<0oooo00<000000?ooo`3oool0_03oool001`0oooo00<000000?ooo`3oool03@3oool2
000000L0oooo00<000000?ooo`3oool04@3oool00`000000oooo0?ooo`0?0?ooo`030000003oool0
oooo00<0oooo00<000000?ooo`3oool0_03oool001`0oooo00<000000?ooo`3oool03@3oool00`00
0000oooo0?ooo`060?ooo`030000003oool0oooo0100oooo00<000000?ooo`3oool0403oool00`00
0000oooo0?ooo`030?ooo`030000003oool0oooo0;`0oooo000L0?ooo`030000003oool0oooo00d0
oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`0@0?ooo`030000003oool0oooo0100
oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`2m0?ooo`00703oool00`000000oooo
0?ooo`0=0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool0403oool00`000000oooo
0?ooo`0@0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0_@3oool001/0oooo00<0
00000?ooo`3oool03P3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00l0oooo00<0
00000?ooo`3oool04@3oool01@000000oooo0?ooo`3oool000000;l0oooo000K0?ooo`030000003o
ool0oooo00h0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`0?0?ooo`030000003o
ool0oooo0140oooo00@000000?ooo`3oool00000`03oool001/0oooo00<000000?ooo`3oool03P3o
ool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3oool04P3o
ool010000000oooo0?ooo`0000300?ooo`004P3oool2000000@0oooo00@000000?ooo`3oool00000
0P3oool2000000<0oooo0`0000060?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool0
3P3oool00`000000oooo0?ooo`0B0?ooo`040000003oool0oooo00000<00oooo000A0?ooo`040000
003oool0oooo000000H0oooo00<000000?ooo`0000000P3oool00`000000oooo000000030?ooo`03
0000003oool0oooo00<0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`0>0?ooo`03
0000003oool0oooo0180oooo00<000000?ooo`000000`@3oool00140oooo00@000000?ooo`3oool0
00001@3oool010000000oooo0?ooo`0000020?ooo`030000003oool0000000<0oooo00<000000?oo
o`3oool00`3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00h0oooo00<000000?oo
o`3oool04`3oool200000<40oooo000A0?ooo`040000003oool0oooo000000D0oooo00@000000?oo
o`3oool000000P3oool00`000000oooo0?ooo`03000000H0oooo0`0000070?ooo`030000003oool0
oooo00h0oooo00<000000?ooo`3oool04`3oool200000<40oooo000A0?ooo`040000003oool0oooo
000000D0oooo00@000000?ooo`3oool000000P3oool00`000000oooo000000030?ooo`030000003o
ool0oooo00<0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`0=0?ooo`030000003o
ool0oooo01<0oooo00<000000?ooo`3oool0`03oool00140oooo00@000000?ooo`3oool000001@3o
ool010000000oooo0?ooo`0000020?ooo`030000003oool0000000<0oooo00<000000?ooo`3oool0
0`3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool0
e`3oool00180oooo0P0000050?ooo`030000003oool0oooo0080oooo0P0000030?ooo`<000001P3o
ool00`000000oooo0?ooo`080?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool0e`3o
ool001T0oooo00<000000?ooo`3oool0403oool00`000000oooo0?ooo`080?ooo`030000003oool0
oooo00`0oooo00<000000?ooo`3oool0e`3oool001T0oooo00<000000?ooo`3oool0403oool00`00
0000oooo0?ooo`080?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool0e`3oool001T0
oooo00<000000?ooo`3oool0403oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo00`0
oooo00<000000?ooo`3oool0e`3oool001P0oooo00<000000?ooo`3oool04@3oool00`000000oooo
0?ooo`080?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool0e`3oool001P0oooo00<0
00000?ooo`3oool04@3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00X0oooo00<0
00000?ooo`3oool0f03oool001P0oooo00<000000?ooo`3oool04@3oool2000000X0oooo00<00000
0?ooo`3oool02P3oool00`000000oooo0?ooo`3H0?ooo`00603oool00`000000oooo0?ooo`0A0?oo
o`030000003oool0oooo00T0oooo00<000000?ooo`3oool0103oool700000=X0oooo000H0?ooo`03
0000003oool0oooo0140oooo00<000000?ooo`3oool02@3oool700000>40oooo000G0?ooo`030000
003oool0oooo0180oooo00<000000?ooo`3oool0l@3oool001L0oooo00<000000?ooo`3oool04P3o
ool00`000000oooo0?ooo`3a0?ooo`005`3oool00`000000oooo0?ooo`0B0?ooo`030000003oool0
oooo0?40oooo000G0?ooo`030000003oool0oooo0180oooo00<000000?ooo`3oool0l@3oool001H0
oooo00<000000?ooo`3oool04`3oool00`000000oooo0?ooo`3a0?ooo`005P3oool00`000000oooo
0?ooo`0C0?ooo`030000003oool0oooo0?40oooo000F0?ooo`030000003oool0oooo01<0oooo00<0
00000?ooo`3oool0l@3oool001H0oooo00<000000?ooo`3oool04`3oool200000?80oooo000E0?oo
o`030000003oool0oooo01@0oooo00<000000?ooo`3oool0l@3oool001D0oooo00<000000?ooo`3o
ool0503oool00`000000oooo0?ooo`3a0?ooo`005@3oool00`000000oooo0?ooo`0D0?ooo`030000
003oool0oooo0?40oooo000E0?ooo`030000003oool0oooo01@0oooo00<000000?ooo`3oool0l@3o
ool001@0oooo00<000000?ooo`3oool05@3oool00`000000oooo0?ooo`3a0?ooo`00503oool00`00
0000oooo0?ooo`0E0?ooo`030000003oool0oooo0?40oooo000D0?ooo`030000003oool0oooo01D0
oooo00<000000?ooo`3oool0103oool3000000@0oooo0P00000e0?ooo`<000000`3oool3000003@0
oooo1@0000030?ooo`800000=03oool500000080oooo0`00000Z0?ooo`00503oool00`000000oooo
0?ooo`0E0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool00P3oool010000000oooo
0?ooo`00000e0?ooo`050000003oool0oooo0?ooo`0000000`3oool00`000000oooo0?ooo`0b0?oo
o`040000003oool0oooo00000080oooo00@000000?ooo`3oool00000=03oool01P000000oooo0?oo
o`000000oooo000000<0oooo00<000000?ooo`3oool09`3oool001@0oooo00<000000?ooo`3oool0
5@3oool2000000H0oooo00<000000?ooo`3oool00P3oool010000000oooo0?ooo`00000e0?ooo`03
0000003oool0oooo00D0oooo00<000000?ooo`3oool0<`3oool00`000000oooo0?ooo`020?ooo`04
0000003oool0oooo000003D0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`0W0?oo
o`004`3oool00`000000oooo0?ooo`0F0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3o
ool00P3oool010000000oooo0?ooo`00000e0?ooo`030000003oool0oooo00D0oooo00<000000?oo
o`3oool0=03oool01@000000oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool0=03oool0
0`000000oooo0?ooo`040?ooo`030000003oool0oooo02L0oooo000C0?ooo`030000003oool0oooo
01H0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`020?ooo`040000003oool0oooo
000003D0oooo00@000000?ooo`3oool0oooo1000000d0?ooo`050000003oool0oooo0?ooo`000000
0P3oool010000000oooo0?ooo`00000c0?ooo`060000003oool0oooo0?ooo`000000oooo1000000Z
0?ooo`004`3oool00`000000oooo0?ooo`0F0?ooo`030000003oool0oooo00@0oooo0P0000040?oo
o`040000003oool0oooo000003@0oooo0P0000030?ooo`030000003oool0oooo03D0oooo00D00000
0?ooo`3oool0oooo000000020?ooo`040000003oool0oooo000003<0oooo00L000000?ooo`3oool0
oooo0000003oool0000002d0oooo000C0?ooo`030000003oool0oooo01H0oooo00<000000?ooo`3o
ool01@3oool00`000000oooo0?ooo`030?ooo`800000=P3oool010000000oooo0?ooo`3oool50000
03@0oooo0`0000040?ooo`800000=@3oool300000080oooo1@00000Y0?ooo`004P3oool00`000000
oooo0?ooo`0G0?ooo`030000003oool0oooo0?40oooo000B0?ooo`030000003oool0oooo01L0oooo
00<000000?ooo`3oool0l@3oool00180oooo00<000000?ooo`3oool05`3oool00`000000oooo0?oo
o`3a0?ooo`004P3oool00`000000oooo0?ooo`0G0?ooo`030000003oool0oooo0?40oooo000A0?oo
o`030000003oool0oooo01P0oooo00<000000?ooo`3oool0l@3oool00?l00000800000010?ooo`00
1`3oool00`000000oooo0?ooo`070?ooo`030000003oool0000000/0oooo00<000000?ooo`3oool0
2P3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool0
2@3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool0
2@3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool0
2@3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool0
2P3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool0
2P3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool0
2@3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00H0oooo000A0?ooo`030000003o
ool0oooo01P0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`0k0?ooo`030000003o
ool0oooo03/0oooo00<000000?ooo`3oool0>`3oool00`000000oooo0?ooo`0[0?ooo`00403oool0
0`000000oooo0?ooo`0I0?ooo`030000003oool0oooo0?40oooo000@0?ooo`030000003oool0oooo
01T0oooo00<000000?ooo`3oool0l@3oool00100oooo00<000000?ooo`3oool06@3oool00`000000
oooo0?ooo`3a0?ooo`00403oool00`000000oooo0?ooo`0I0?ooo`030000003oool0oooo0?40oooo
000@0?ooo`030000003oool0oooo01T0oooo00<000000?ooo`3oool0l@3oool000l0oooo00<00000
0?ooo`3oool06P3oool00`000000oooo0?ooo`3a0?ooo`003`3oool00`000000oooo0?ooo`0J0?oo
o`800000lP3oool000l0oooo00<000000?ooo`3oool06P3oool00`000000oooo0?ooo`3a0?ooo`00
3`3oool00`000000oooo0?ooo`0J0?ooo`030000003oool0oooo0?40oooo000>0?ooo`030000003o
ool0oooo01/0oooo00<000000?ooo`3oool0l@3oool000h0oooo00<000000?ooo`3oool06`3oool0
0`000000oooo0?ooo`3a0?ooo`003P3oool00`000000oooo0?ooo`0K0?ooo`030000003oool0oooo
0?40oooo000>0?ooo`030000003oool0oooo01/0oooo00<000000?ooo`3oool0l@3oool000d0oooo
00<000000?ooo`3oool0703oool00`000000oooo0?ooo`3a0?ooo`003@3oool00`000000oooo0?oo
o`0L0?ooo`030000003oool0oooo0?40oooo000=0?ooo`030000003oool0oooo01`0oooo00<00000
0?ooo`3oool0l@3oool000d0oooo00<000000?ooo`3oool0703oool200000?80oooo000=0?ooo`03
0000003oool0oooo01`0oooo00<000000?ooo`3oool0l@3oool000`0oooo00<000000?ooo`3oool0
7@3oool00`000000oooo0?ooo`3a0?ooo`00303oool00`000000oooo0?ooo`0M0?ooo`030000003o
ool0oooo0?40oooo000<0?ooo`030000003oool0oooo01d0oooo00<000000?ooo`3oool0l@3oool0
00`0oooo00<000000?ooo`3oool07@3oool00`000000oooo0?ooo`3a0?ooo`002`3oool00`000000
oooo0?ooo`0N0?ooo`030000003oool0oooo0?40oooo000;0?ooo`030000003oool0oooo01h0oooo
00<000000?ooo`3oool0l@3oool000/0oooo00<000000?ooo`3oool07P3oool00`000000oooo0?oo
o`3a0?ooo`002`3oool00`000000oooo0?ooo`0N0?ooo`800000lP3oool000X0oooo00<000000?oo
o`3oool07`3oool00`000000oooo0?ooo`3a0?ooo`002P3oool00`000000oooo0?ooo`0O0?ooo`03
0000003oool0oooo0?40oooo000:0?ooo`030000003oool0oooo01l0oooo00<000000?ooo`3oool0
l@3oool000X0oooo00<000000?ooo`3oool07`3oool00`000000oooo0?ooo`3a0?ooo`002@3oool0
0`000000oooo0?ooo`0P0?ooo`030000003oool0oooo0?40oooo00090?ooo`030000003oool0oooo
0200oooo00<000000?ooo`3oool0l@3oool000T0oooo00<000000?ooo`3oool0803oool00`000000
oooo0?ooo`3a0?ooo`002@3oool00`000000oooo0?ooo`060?ooo`800000103oool00`000000oooo
0?ooo`020?ooo`<000000P3oool5000000D0oooo00<000000?ooo`3oool0l@3oool000T0oooo00<0
00000?ooo`3oool01@3oool010000000oooo0?ooo`0000090?ooo`030000003oool0oooo0080oooo
00@000000?ooo`3oool000001@3oool00`000000oooo0?ooo`3a0?ooo`00203oool00`000000oooo
0?ooo`060?ooo`040000003oool0oooo000000T0oooo00<000000?ooo`3oool00`3oool00`000000
oooo0?ooo`050?ooo`<00000l@3oool000P0oooo00<000000?ooo`3oool01P3oool010000000oooo
0?ooo`0000090?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0103oool00`000000
oooo0?ooo`3a0?ooo`00203oool00`000000oooo0?ooo`060?ooo`040000003oool0oooo000000T0
oooo00D000000?ooo`3oool0oooo000000030?ooo`030000003oool0oooo00<0oooo00<000000?oo
o`3oool0l@3oool000P0oooo00<000000?ooo`3oool01P3oool010000000oooo0?ooo`0000080?oo
o`8000000`3oool01@000000oooo0?ooo`3oool0000000D0oooo00<000000?ooo`3oool0l@3oool0
00L0oooo00<000000?ooo`3oool0203oool2000000X0oooo00<000000?ooo`3oool00P3oool30000
00H0oooo00<000000?ooo`3oool0l@3oool000L0oooo00<000000?ooo`3oool08P3oool00`000000
oooo0?ooo`3a0?ooo`00;03oool00`000000oooo0?ooo`3a0?ooo`00;03oool00`000000oooo0?oo
o`3a0?ooo`00;03oool00`000000oooo0?ooo`3a0?ooo`00;03oool00`000000oooo0?ooo`3a0?oo
o`00\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {5.42136, 0.032294, \
0.0806875, 0.000523661}}]
}, Open  ]]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["Generating functions", "SubsectionIcon"],

Cell[CellGroupData[{

Cell["One locus", "SubsubsectionIcon"],

Cell[TextData[{
  "Suppose that we have a genealogy with a set of nodes, labelled ",
  Cell[BoxData[
      \(TraditionalForm\`k\)]],
  ".  The coalescence events occur in a known order (for example, {a,b} then \
{c,d} then {a,b,c,d}).   We work with the generating function for the number \
of mutations ",
  Cell[BoxData[
      \(TraditionalForm\`j\_k\)]],
  " leading down to node ",
  Cell[BoxData[
      \(TraditionalForm\`k\)]],
  ":"
}], "Text"],

Cell[BoxData[
    \(TextForm\`\(P\&~\)[\[Omega]\+_] \[Congruent] 
      E[\[Product]\+k \[Omega]\_k\%j\_k]\)], "NumberedEquation"],

Cell["\<\
In this example, the set of nodes is {{a},{b},{c},{d},{a,b},{c,d}}. \
 Mutations before the common ancestor are ignored, and by convention, there \
are no mutations shared by {a,c} etc.\
\>", "Text"],

Cell[TextData[{
  "The generating function is related to the Laplace Transform of the \
timespans of the lineages leading down to each node, ",
  Cell[BoxData[
      \(TraditionalForm\`t\_k\)]],
  ":"
}], "Text"],

Cell[BoxData[
    \(TextForm\`\(P\&~\)[\[Omega]\+_] \[Congruent] 
        E[\[Product]\+k\(\[Sum]\+\(j\_k\)\(\[ExponentialE]\^\(\(-\[Theta]\)\ \
t\_k/2\)\/\(j\_k!\)\) \(\((\(\[Theta]\ t\_k\)\/2)\)\^j\_k\) \[Omega]\_k\%j\_k\
\)] = \(E[
          Exp[\(-\(\[Theta]\/2\)\) \(\[Sum]\+k\( 
                      t\_k\) \((1 - \[Omega]\_k)\)\)]] = \(E[
              Exp[\(-\(\[Sum]\(\[Nu]\_k\) 
                      t\_k\)\)]]\ \ \ where\ \[Nu]\_k = \(\[Theta]\/2\) \((1 \
- \[Omega]\_k)\)\)\)\)], "NumberedEquation"],

Cell[TextData[{
  "Though the packages work with ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          
          FormBox[\(\[Omega]\_k, \ \(\(I\)\(\ \)\(will\)\(\ \)\(use\)\(\ \
\)\(here\)\(\ \)\)\),
            "TraditionalForm"], \(\[Nu]\_k\)}], TraditionalForm]]],
  " as being more direct.  "
}], "Text"],

Cell[TextData[{
  "The recursion for ",
  Cell[BoxData[
      \(\(P\&~\)[\[Nu]\+_]\)]],
  " is simple.  The time \[Tau] back to the previous coalescence is \
exponential, with rate ",
  Cell[BoxData[
      RowBox[{"(", GridBox[{
            {"k"},
            {"2"}
            }], ")"}]]],
  ", and a chance ",
  Cell[BoxData[
      RowBox[{"1", "/", 
        RowBox[{"(", GridBox[{
              {"k"},
              {"2"}
              }], ")"}]}]]],
  " that any particular pair will coalesce.  If pair 1, 2 (say) coalesce, \
then an additional time \[Tau] is added to all leaves, and we have:"
}], "Text"],

Cell[BoxData[
    FormBox[
      RowBox[{\(\(P\&~\)\_k[\[Nu]\+_]\), "=", 
        RowBox[{
          RowBox[{\(\[Sum]\_pairs\), 
            RowBox[{
              FractionBox["1", 
                RowBox[{"(", GridBox[{
                      {"k"},
                      {"2"}
                      }], 
                  ")"}]], \(\(P\&~\)\_\(k - 1\)[\[Nu]\+_]\), \(E\_\[Tau][
                Exp[\(-\(\[Sum]\+\(k \[Element] leaves\)\(\[Nu]\_k\) \[Tau]\)\
\)]]\)}]}], "=", 
          RowBox[{\(\[Sum]\_pairs\), 
            FractionBox[\(\(P\&~\)\_\(k - 1\)[\[Nu]\+_]\), 
              RowBox[{
                RowBox[{"(", GridBox[{
                      {"k"},
                      {"2"}
                      }], ")"}], 
                "+", \(\[Sum]\+\(k \[Element] leaves\)\[Nu]\_k\)}]]}]}]}], 
      TextForm]], "NumberedEquation"],

Cell[TextData[{
  "This is the LT summed over all possible coalescences, and so overall gives \
1 when all the ",
  Cell[BoxData[
      \(TraditionalForm\`\[Nu]\_k\)]],
  " are set to zero (as it must).  "
}], "Text"]
}, Closed]],

Cell[CellGroupData[{

Cell["Two loci", "SubsubsectionIcon"],

Cell[TextData[{
  "Now, suppose we have two loci, labelled 1, 2.  The leaves are labelled ",
  Cell[BoxData[
      \(TraditionalForm\`{a\_1}\)]],
  ", ",
  Cell[BoxData[
      \(TraditionalForm\`{a\_2}\)]],
  " etc.  We must track the LT for configurations in which the leaves are \
separate, or are linked together in the same ancestor.  For example, we could \
consider sets ",
  Cell[BoxData[
      \(TraditionalForm\`{{a\_1}, {a\_2}}\)]],
  " (i.e. two genomes, one ancestral to ",
  Cell[BoxData[
      \(TraditionalForm\`a\_1\)]],
  "at locua 1, and one ancestral to ",
  Cell[BoxData[
      \(TraditionalForm\`a\_2\)]],
  " at locus 2), ",
  Cell[BoxData[
      \(TraditionalForm\`{{a\_1, a\_2}}\)]],
  " (i.e. one genome ancestral to both ",
  Cell[BoxData[
      \(TraditionalForm\`a\_1\)]],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`a\_2\)]],
  ") and so on.  "
}], "Text"],

Cell[TextData[{
  "As before, we track the time down to a node, which may be different for \
the two loci.  In principle, we could track separately the times during which \
",
  Cell[BoxData[
      \(TraditionalForm\`a\_1\)]],
  "and ",
  Cell[BoxData[
      \(TraditionalForm\`a\_2\ \ are\ carried\ in\ the\ same\ genome, \ 
      and\ the\ times\ for\ which\ they\ are\ carried\ \
\(\(separately\)\(.\)\(\ \)\)\)]],
  "This would involve times of the form ",
  Cell[BoxData[
      \(TraditionalForm\`t\_{{a\_1, a\_2}}\)]],
  ".  However, these times do not affect observable configurations of \
mutations, and so we concentrate here on the structures of the separate \
genealogies; these are described by times down to the nodes at each locus \
separately, of the form ",
  Cell[BoxData[
      \(TraditionalForm\`t\_{a\_1}, \ t\_{a\_1, b\_1}\)]],
  " etc."
}], "Text"],

Cell[TextData[{
  "Suppose that there are ",
  Cell[BoxData[
      \(TraditionalForm\`k\_1 + k\_2 + k\_12 \[Congruent] \(k\_ . \)\)]],
  " lineages extant.  Going backwards, there may be either a recombination or \
a coalescence.  Recombinations occur at total rate ",
  Cell[BoxData[
      \(TraditionalForm\`r\[VeryThinSpace]k\_12\)]],
  ", and are equally likely between any of the ",
  Cell[BoxData[
      \(TraditionalForm\`k\_12\)]],
  " lineages carrying genes at both loci. Their effect is to separate the two \
genes (e.g. ",
  Cell[BoxData[
      \(TraditionalForm\`\(\({{a\_1, a\_2}}\)\(\[Rule]\)\)\)]],
  Cell[BoxData[
      \(TraditionalForm\`{{a\_1}, {a\_2}}\)]],
  ".  Coalescences at a rate ",
  Cell[BoxData[
      RowBox[{"(", GridBox[{
            {\(k\_ . \)},
            {"2"}
            }], ")"}]]],
  ", and are equally likely between any pairs."
}], "Text"],

Cell[TextData[{
  "Because we ignore mutations before any common ancestor, we have ",
  Cell[BoxData[
      \(TraditionalForm\`P\&~[{{a\_1, a\_2}}] = 1\)]],
  ",  ",
  Cell[BoxData[
      \(TraditionalForm\`P\&~[{{a\_1}, {a\_2}}] = 1\)]],
  ". Moreover, any GF for a configuration in which there is only one 'leaf' \
at a locus is equivalent to the GF for the other locus separately."
}], "Text"],

Cell[TextData[{
  " We now find recursions connecting more complex configurations.  Each \
recombination event links back to the LT for the separate lineages  (e.g.{\
\[Ellipsis] ",
  Cell[BoxData[
      \(TraditionalForm\`{a\_1, a\_2}\)]],
  "\[Ellipsis]}links back to ",
  Cell[BoxData[
      \(TraditionalForm\`{\[Ellipsis] {a\_1}, {a\_2}, \[Ellipsis]}\)]],
  ").  Thus we have a contribution\n",
  Cell[BoxData[
      \(TraditionalForm\`\(\(\(P\&~\)[{\[Ellipsis] {a\_1, 
                    a\_2}} \[Ellipsis]}, \[Nu]\+_\)\(]\)\) = \(P\&~\)[{\
\[Ellipsis] {a\_1}, {a\_2} \[Ellipsis]}, \[Nu]\+_] \(\(E\)\([\)\(Exp[\(-\(\
\[Sum]\_i\(\[Sum]\+\(k \[Element] l\_i\)\(\[Nu]\_k\) \[Tau]\)\)\)]\)\)\)], 
    "NumberedEquation"]
}], "Text"],

Cell[TextData[{
  "where the sumis over the ",
  Cell[BoxData[
      \(TraditionalForm\`\(\(l\_i\)\(\ \)\)\)]],
  "leaves at locus ",
  Cell[BoxData[
      \(TraditionalForm\`i\)]],
  ". In this expression, ",
  Cell[BoxData[
      \(TraditionalForm\`\[Nu]\_{a\_1}\)]],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`\[Nu]\_{a\_2}\)]],
  " in ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          RowBox[{
            
            FormBox[\(\(P\&~\)\([\)\({\[Ellipsis] {a\_1}, {a\_2} \[Ellipsis]}\
\)\),
              "TraditionalForm"], ",", \(\[Nu]\+_\)}], "]"}], 
        TraditionalForm]]],
  " are unaffected, since the lineages at each locus separately are \
unaffected by recombination."
}], "Text"],

Cell["Coalescence events give a contribution:", "Text"],

Cell[BoxData[
    \(TraditionalForm\`\(\(P\&~[{\[Ellipsis] {a\_1, a\_2}, {b\_1, 
                  b\_2} \[Ellipsis]}, \[Nu]\+_] = 
          P\&~[{\[Ellipsis] {\(a\_1\) b\_1, \(a\_2\) 
                      b\_2}} \[Ellipsis]}, \[Nu]\+_\)\(]\)\) \
\(\(E\)\([\)\(Exp[\(-\(\[Sum]\_i\(\[Sum]\+\(k \[Element] l\_i\)\(\[Nu]\_k\) \
\[Tau]\)\)\)]\)\)\)], "NumberedEquation"],

Cell[TextData[{
  "We now need to account for the distribution of the time \[Tau].  This has \
total rate ",
  Cell[BoxData[
      RowBox[{
        FormBox[\(\(r\[VeryThinSpace]k\_12\)\(+\)\),
          "TraditionalForm"], 
        RowBox[{"(", GridBox[{
              {\(k\_ . \)},
              {"2"}
              }], ")"}]}]]],
  ".  Weighting the probabilities of the various events appropriately::"
}], "Text"],

Cell[BoxData[
    FormBox[
      RowBox[{\(P\&~[g\+_, \[Nu]\+_]\), "=", 
        RowBox[{
          RowBox[{\(\[Sum]\_\(linked\[IndentingNewLine]
                leaves\)\), 
            RowBox[{\(P\&~[g\+_\^R, \[Nu]\+_]\), 
              FractionBox["r", 
                RowBox[{
                  RowBox[{
                    FormBox[\(\(r\[VeryThinSpace]k\_12\)\(+\)\),
                      "TraditionalForm"], 
                    RowBox[{"(", GridBox[{
                          {\(k\_ . \)},
                          {"2"}
                          }], ")"}]}], 
                  "+", \(\[Sum]\_i\(\[Sum]\+\(k \[Element] \
l\_i\)\[Nu]\_k\)\)}]]}]}], "+", 
          RowBox[{\(\[Sum]\_pairs\), 
            RowBox[{\(P\&~[g\+_\^C, \[Nu]\+_]\), 
              FractionBox["1", 
                RowBox[{
                  RowBox[{
                    FormBox[\(\(r\[VeryThinSpace]k\_12\)\(+\)\),
                      "TraditionalForm"], 
                    RowBox[{"(", GridBox[{
                          {\(k\_ . \)},
                          {"2"}
                          }], ")"}]}], 
                  "+", \(\[Sum]\_i\(\[Sum]\+\(k \[Element] \
l\_i\)\[Nu]\_k\)\)}]]}]}]}]}], TraditionalForm]], "NumberedEquation"],

Cell["\<\
Rather than giving a sequence leading back through simpler and \
simpler forms, this leads both forwards and backwards, greatly complicating \
evaluation.\
\>", "Text"]
}, Closed]],

Cell[CellGroupData[{

Cell["ReduceMGF", "SubsubsectionIcon"],

Cell[BoxData[
    \(\(ReduceMGF::usage = "\<ReduceMGF[{\[Ellipsis]},\[Omega]] gives a \
simpler form for the MGF if possible; returns $Failed if not\>";\)\)], "Input"],

Cell[BoxData[
    \(\(ReduceMGF[{g__List}, \[Omega]_] := \[IndentingNewLine]If[
          Length[{g}] == 
            1, \[IndentingNewLine]1, \[IndentingNewLine]Switch[\(Length[
                  DeleteCases[#, {}]] &\) /@ 
              Transpose[{g}], \[IndentingNewLine]{0 | 1, 
              0 | 1}, \[IndentingNewLine]1, \[IndentingNewLine]{0 | 
                1, _}, \[IndentingNewLine]MomentGeneratingFunction[
              DeleteCases[
                Replace[{g}, {{___}, a_List} \[RuleDelayed] a, 
                  1], {}], \((1 - \[Omega][#])\) &, 
              2], \[IndentingNewLine]{_, 
              0 | 1}, \[IndentingNewLine]MomentGeneratingFunction[
              DeleteCases[
                Replace[{g}, {a_List, {___}} \[RuleDelayed] a, 
                  1], {}], \((1 - \[Omega][#])\) &, 
              2], \[IndentingNewLine]_, \[IndentingNewLine]$Failed]];\)\)], \
"Input",
  CellLabel->"In[184]:="]
}, Closed]],

Cell[CellGroupData[{

Cell["DeriveMGF", "SubsubsectionIcon"],

Cell[BoxData[
    \(\(DeriveMGF::usage = "\<DeriveMGF[{{a1,{}},{{b1},{b2}},\[Ellipsis]},p,\
\[Omega],r] gives the MGF for a two-locus configuration,in terms of other MGF \
p[{\[Ellipsis]}] and variables \[Omega][{a1\[Ellipsis]}]\>";\)\)], "Input",
  CellLabel->"In[153]:="],

Cell[BoxData[
    \(\(DeriveMGF[{g__List}, p_, \[Omega]_, 
          r_] := \[IndentingNewLine]Module[{sm = 
              ReduceMGF[{g}, \[Omega]], \[Lambda], ng, gl, rl, i, j, 
            n = Length[{g}], rm}, \[IndentingNewLine]If[
            sm === $Failed, \[IndentingNewLine]\[Lambda] = \(n \((n - \
1)\)\)\/2; \[IndentingNewLine]rl = 
              DeleteCases[{g}, {_, {}} | {{}, _}]; \[IndentingNewLine]k12 = 
              Length[rl]; \[IndentingNewLine]\ 
            gl = Flatten[
                Table[Sort[{{g}\[LeftDoubleBracket]
                        i\[RightDoubleBracket], {g}\[LeftDoubleBracket]
                        j\[RightDoubleBracket]}], {i, 2, n}, {j, i - 1}], 
                1]; \n\t\t1\/\((r\ k12 + \[Lambda] + \((Plus @@ \
\((\(\[Omega][Sort[#]] &\) /@ DeleteCases[Flatten[{g}, 1], \
{}])\))\))\)*\((Plus @@ \((\(\((ng = {g} /. {{x___, #\[LeftDoubleBracket]1\
\[RightDoubleBracket], y___, #\[LeftDoubleBracket]2\[RightDoubleBracket], 
                                      z___} :> 
                                    Sort[{x, \(Join @@ # &\) /@ 
                                        Transpose[{#\[LeftDoubleBracket]1\
\[RightDoubleBracket], #\[LeftDoubleBracket]2\[RightDoubleBracket]}], y, 
                                        z}], {x___, #\[LeftDoubleBracket]2\
\[RightDoubleBracket], y___, #\[LeftDoubleBracket]1\[RightDoubleBracket], 
                                      z___} :> 
                                    Sort[{x, \(Join @@ # &\) /@ 
                                        Transpose[{#\[LeftDoubleBracket]1\
\[RightDoubleBracket], #\[LeftDoubleBracket]2\[RightDoubleBracket]}], y, 
                                        z}]}; \[IndentingNewLine]rm = 
                              ReduceMGF[ng, \[Omega]]; \[IndentingNewLine]If[
                              rm === $Failed, p[ng], rm])\) &\) /@ 
                        gl)\) + \[IndentingNewLine]r \((Plus @@ \((\(\((ng = \
{g} /. {x___, #, z___} :> 
                                      Sort[{x, {#\[LeftDoubleBracket]1\
\[RightDoubleBracket], {}}, {{}, \
#\[LeftDoubleBracket]2\[RightDoubleBracket]}, z}]; \[IndentingNewLine]rm = 
                                  ReduceMGF[
                                    ng, \[Omega]]; \[IndentingNewLine]If[
                                  rm === $Failed, p[ng], rm])\) &\) /@ 
                            rl)\))\))\), \[IndentingNewLine]sm]];\)\)], \
"Input",
  CellLabel->"In[219]:="]
}, Closed]],

Cell[CellGroupData[{

Cell["Working for two individuals", "SubsubsectionIcon"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(<< Utilities`SetManipulation`;\)\), "\n", 
    \(\(<< DiscreteMath`Combinatorica`;\)\), "\[IndentingNewLine]", 
    \(\(<< Genealogies`Genealogies`;\)\)}], "Input",
  CellLabel->"In[44]:="],

Cell[BoxData[
    \(Ordering::"shdw" \(\(:\)\(\ \)\) 
      "Symbol \!\(\"Ordering\"\) appears in multiple contexts \
\!\({\"Statistics`DataManipulation`\", \"DiscreteMath`Permutations`\"}\); \
definitions in context \!\(\"Statistics`DataManipulation`\"\) may shadow or \
be shadowed by other definitions."\)], "Message",
  CellLabel->"From In[44]:="],

Cell[BoxData[
    \(IncidenceMatrix::"shdw" \(\(:\)\(\ \)\) 
      "Symbol \!\(\"IncidenceMatrix\"\) appears in multiple contexts \
\!\({\"Genealogies`Genealogies`\", \"DiscreteMath`Combinatorica`\"}\); \
definitions in context \!\(\"Genealogies`Genealogies`\"\) may shadow or be \
shadowed by other definitions."\)], "Message",
  CellLabel->"From In[44]:="]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    \(cs = ConfigurationSet[{{a1, b1}, {a2, b2}}]\)], "Input",
  CellLabel->"In[164]:="],

Cell[BoxData[
    \({{{{a1, b1}, {a2, b2}}}, {{{}, {a2}}, {{a1, 
            b1}, {b2}}}, {{{}, {b2}}, {{a1, b1}, {a2}}}, {{{}, {a2, 
            b2}}, {{a1, b1}, {}}}, {{{a1}, {}}, {{b1}, {a2, 
            b2}}}, {{{a1}, {a2}}, {{b1}, {b2}}}, {{{a1}, {b2}}, {{b1}, \
{a2}}}, {{{a1}, {a2, b2}}, {{b1}, {}}}, {{{}, {a2}}, {{}, {b2}}, {{a1, 
            b1}, {}}}, {{{}, {a2}}, {{a1}, {}}, {{b1}, {b2}}}, {{{}, {a2}}, \
{{a1}, {b2}}, {{b1}, {}}}, {{{}, {b2}}, {{a1}, {}}, {{b1}, {a2}}}, {{{}, \
{b2}}, {{a1}, {a2}}, {{b1}, {}}}, {{{}, {a2, 
            b2}}, {{a1}, {}}, {{b1}, {}}}, {{{}, {a2}}, {{}, {b2}}, {{a1}, \
{}}, {{b1}, {}}}}\)], "Output",
  CellLabel->"Out[164]="]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    \(cs2 = 
      Select[cs, \((Min[\(Length[DeleteCases[#, {}]] &\) /@ Transpose[#]] > 
              1)\) &]\)], "Input",
  CellLabel->"In[177]:="],

Cell[BoxData[
    \({{{{a1}, {a2}}, {{b1}, {b2}}}, {{{a1}, {b2}}, {{b1}, {a2}}}, {{{}, \
{a2}}, {{a1}, {}}, {{b1}, {b2}}}, {{{}, {a2}}, {{a1}, {b2}}, {{b1}, {}}}, \
{{{}, {b2}}, {{a1}, {}}, {{b1}, {a2}}}, {{{}, {b2}}, {{a1}, {a2}}, {{b1}, \
{}}}, {{{}, {a2}}, {{}, {b2}}, {{a1}, {}}, {{b1}, {}}}}\)], "Output",
  CellLabel->"Out[177]="]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    \(eqns = \((\(p[#] \[Equal] Simplify[DeriveMGF[#, p, w, r]] &\) /@ 
          cs2)\)\)], "Input",
  CellLabel->"In[229]:="],

Cell[BoxData[
    \({p[{{{a1}, {a2}}, {{b1}, {b2}}}] == \(1 + r\ \((p[{{{}, {a2}}, {{a1}, \
{}}, {{b1}, {b2}}}] + p[{{{}, {b2}}, {{a1}, {a2}}, {{b1}, {}}}])\)\)\/\(1 + 2\
\ r + w[{a1}] + w[{a2}] + w[{b1}] + w[{b2}]\), 
      p[{{{a1}, {b2}}, {{b1}, {a2}}}] == \(1 + r\ \((p[{{{}, {a2}}, {{a1}, \
{b2}}, {{b1}, {}}}] + p[{{{}, {b2}}, {{a1}, {}}, {{b1}, {a2}}}])\)\)\/\(1 + 2\
\ r + w[{a1}] + w[{a2}] + w[{b1}] + w[{b2}]\), 
      p[{{{}, {a2}}, {{a1}, {}}, {{b1}, {b2}}}] == \(p[{{{a1}, {a2}}, {{b1}, \
{b2}}}] + r\ p[{{{}, {a2}}, {{}, {b2}}, {{a1}, {}}, {{b1}, {}}}] + 1\/\(1 + \
w[{a1}] + w[{b1}]\) + 1\/\(1 + w[{a2}] + w[{b2}]\)\)\/\(3 + r + w[{a1}] + \
w[{a2}] + w[{b1}] + w[{b2}]\), 
      p[{{{}, {a2}}, {{a1}, {b2}}, {{b1}, {}}}] == \(p[{{{a1}, {b2}}, {{b1}, \
{a2}}}] + r\ p[{{{}, {a2}}, {{}, {b2}}, {{a1}, {}}, {{b1}, {}}}] + 1\/\(1 + \
w[{a1}] + w[{b1}]\) + 1\/\(1 + w[{a2}] + w[{b2}]\)\)\/\(3 + r + w[{a1}] + \
w[{a2}] + w[{b1}] + w[{b2}]\), 
      p[{{{}, {b2}}, {{a1}, {}}, {{b1}, {a2}}}] == \(p[{{{a1}, {b2}}, {{b1}, \
{a2}}}] + r\ p[{{{}, {a2}}, {{}, {b2}}, {{a1}, {}}, {{b1}, {}}}] + 1\/\(1 + \
w[{a1}] + w[{b1}]\) + 1\/\(1 + w[{a2}] + w[{b2}]\)\)\/\(3 + r + w[{a1}] + \
w[{a2}] + w[{b1}] + w[{b2}]\), 
      p[{{{}, {b2}}, {{a1}, {a2}}, {{b1}, {}}}] == \(p[{{{a1}, {a2}}, {{b1}, \
{b2}}}] + r\ p[{{{}, {a2}}, {{}, {b2}}, {{a1}, {}}, {{b1}, {}}}] + 1\/\(1 + \
w[{a1}] + w[{b1}]\) + 1\/\(1 + w[{a2}] + w[{b2}]\)\)\/\(3 + r + w[{a1}] + \
w[{a2}] + w[{b1}] + w[{b2}]\), 
      p[{{{}, {a2}}, {{}, {b2}}, {{a1}, {}}, {{b1}, {}}}] == \((p[{{{}, \
{a2}}, {{a1}, {}}, {{b1}, {b2}}}] + 
              p[{{{}, {a2}}, {{a1}, {b2}}, {{b1}, {}}}] + 
              p[{{{}, {b2}}, {{a1}, {}}, {{b1}, {a2}}}] + 
              p[{{{}, {b2}}, {{a1}, {a2}}, {{b1}, {}}}] + 
              1\/\(1 + w[{a1}] + w[{b1}]\) + 
              1\/\(1 + w[{a2}] + w[{b2}]\))\)/\((6 + w[{a1}] + w[{a2}] + 
              w[{b1}] + w[{b2}])\)}\)], "Output",
  CellLabel->"Out[229]="]
}, Closed]],

Cell[BoxData[
    \(\(soln = \(Solve[eqns, 
            p /@ cs2]\)\[LeftDoubleBracket]1\[RightDoubleBracket];\)\)], \
"Input",
  CellLabel->"In[230]:="],

Cell[BoxData[
    \(\(vt = \(vars /. soln\) /. {w[{a1}] \[RuleDelayed] S1 - w[{b1}], 
              w[{a2}] \[RuleDelayed] S2 - w[{b2}]} // Simplify;\)\)], "Input",\

  CellLabel->"In[249]:="],

Cell[CellGroupData[{

Cell[BoxData[
    \(vt[\([1]\)]\)], "Input",
  CellLabel->"In[250]:="],

Cell[BoxData[
    \(\((2\ r\^2\ \((2 + S1 + S2)\) + \((1 + S1)\)\ \((1 + S2)\)\ \((18 + 
                S1\^2 + 9\ S2 + S2\^2 + S1\ \((9 + 2\ S2)\))\) + 
          r\ \((26 + 19\ S2 + 3\ S2\^2 + S1\^2\ \((3 + S2)\) + 
                S1\ \((19 + 8\ S2 + S2\^2)\))\))\)/\((\((1 + S1)\)\ \((1 + 
              S2)\)\ \((18 + S1\^3 + 27\ S2 + 10\ S2\^2 + S2\^3 + 
              2\ r\^2\ \((2 + S1 + S2)\) + S1\^2\ \((10 + 3\ S2)\) + 
              S1\ \((27 + 20\ S2 + 3\ S2\^2)\) + 
              r\ \((26 + 3\ S1\^2 + 19\ S2 + 3\ S2\^2 + 
                    S1\ \((19 + 6\ S2)\))\))\))\)\)], "Output",
  CellLabel->"Out[250]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(vt[\([3]\)] /. {w[{a1}] \[RuleDelayed] S1 - w[{b1}], 
          w[{a2}] \[RuleDelayed] S2 - w[{b2}]} // Simplify\)], "Input",
  CellLabel->"In[251]:="],

Cell[BoxData[
    \(\((18 + S1\^3 + 27\ S2 + 10\ S2\^2 + S2\^3 + 
          2\ r\^2\ \((2 + S1 + S2)\) + 2\ S1\^2\ \((5 + 2\ S2)\) + 
          S1\ \((27 + 26\ S2 + 4\ S2\^2)\) + 
          r\ \((26 + 3\ S1\^2 + 19\ S2 + 3\ S2\^2 + 
                S1\ \((19 + 6\ S2)\))\))\)/\((\((1 + S1)\)\ \((1 + 
              S2)\)\ \((18 + S1\^3 + 27\ S2 + 10\ S2\^2 + S2\^3 + 
              2\ r\^2\ \((2 + S1 + S2)\) + S1\^2\ \((10 + 3\ S2)\) + 
              S1\ \((27 + 20\ S2 + 3\ S2\^2)\) + 
              r\ \((26 + 3\ S1\^2 + 19\ S2 + 3\ S2\^2 + 
                    S1\ \((19 + 6\ S2)\))\))\))\)\)], "Output",
  CellLabel->"Out[251]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(vt[\([7]\)] /. {w[{a1}] \[RuleDelayed] S1 - w[{b1}], 
          w[{a2}] \[RuleDelayed] S2 - w[{b2}]} // Simplify\)], "Input",
  CellLabel->"In[252]:="],

Cell[BoxData[
    \(\((18 + S1\^3 + 27\ S2 + 10\ S2\^2 + S2\^3 + 
          2\ r\^2\ \((2 + S1 + S2)\) + S1\^2\ \((10 + 3\ S2)\) + 
          3\ S1\ \((9 + 8\ S2 + S2\^2)\) + 
          r\ \((26 + 3\ S1\^2 + 19\ S2 + 3\ S2\^2 + 
                S1\ \((19 + 6\ S2)\))\))\)/\((\((1 + S1)\)\ \((1 + 
              S2)\)\ \((18 + S1\^3 + 27\ S2 + 10\ S2\^2 + S2\^3 + 
              2\ r\^2\ \((2 + S1 + S2)\) + S1\^2\ \((10 + 3\ S2)\) + 
              S1\ \((27 + 20\ S2 + 3\ S2\^2)\) + 
              r\ \((26 + 3\ S1\^2 + 19\ S2 + 3\ S2\^2 + 
                    S1\ \((19 + 6\ S2)\))\))\))\)\)], "Output",
  CellLabel->"Out[252]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(Simplify /@ Collect[Numerator[vt[\([7]\)]], r]\)], "Input",
  CellLabel->"In[297]:="],

Cell[BoxData[
    \(18 + S1\^3 + 27\ S2 + 10\ S2\^2 + S2\^3 + 2\ r\^2\ \((2 + S1 + S2)\) + 
      S1\^2\ \((10 + 3\ S2)\) + 3\ S1\ \((9 + 8\ S2 + S2\^2)\) + 
      r\ \((26 + 3\ S1\^2 + 19\ S2 + 3\ S2\^2 + 
            S1\ \((19 + 6\ S2)\))\)\)], "Output",
  CellLabel->"Out[297]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(\((2 + S)\) \((\((1 + S)\)\ \((7 + S)\) + r \((1 + S)\) + 
                2  r\ \((6 + \ S + r)\)\ )\) + \ 
          4 \((1 + S1)\) \((1 + S2)\) - Numerator[vt[\([7]\)]] /. 
        S \[Rule] S1 + S2 // Simplify\)], "Input",
  CellLabel->"In[307]:="],

Cell[BoxData[
    \(0\)], "Output",
  CellLabel->"Out[307]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(\((1 + S + 2  r)\)\ \((2 + S)\)\ \((6 + S + r)\) + \((1 + S1)\) \((1 + 
                S2)\)\ \((6 + S)\) - Numerator[vt[\([3]\)]] /. 
        S \[Rule] S1 + S2 // Simplify\)], "Input",
  CellLabel->"In[292]:="],

Cell[BoxData[
    \(0\)], "Output",
  CellLabel->"Out[292]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(\(\ \)\(2  
            r \((2 + S)\)\ \((6 + S + r)\) + \ \((1 + S1)\)\ \((1 + 
                S2)\) \((\((3 + S)\)\ \((6 + S)\) + r \((2 + S)\))\) - 
          Numerator[vt[\([1]\)]] /. S \[Rule] S1 + S2 // 
      Simplify\)\)\)], "Input",
  CellLabel->"In[296]:="],

Cell[BoxData[
    \(0\)], "Output",
  CellLabel->"Out[296]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(\((1 + S1)\)\ \((1 + 
                S2)\) \((\((1 + S)\)\ \ \((6 + S)\) + \((1 + S + 
                      2  r)\)\ \((2 + S)\)\ \((6 + S + r)\))\) - 
          Denominator[vt[\([1]\)]] /. S \[Rule] S1 + S2 // 
      Simplify\)], "Input",
  CellLabel->"In[312]:="],

Cell[BoxData[
    \(0\)], "Output",
  CellLabel->"Out[312]="]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["Results for two individuals", "SubsubsectionIcon"],

Cell[BoxData[{
    \(\(P\&~\)[{{a\_1, a\_2}, {b\_1, 
            b\_2}}] = \(\(\ \)\(2  r \((2 + S)\)\ \((6 + S + r)\) + Z \((\((6 \
+ S)\) + \((2 + S)\)\ \((6 + S + r)\))\)\)\)\/\(Z \((\((1 + S)\)\ \ \((6 + S)\
\) + \((1 + S + 2  r)\)\ \((2 + S)\)\ \((6 + S + r)\))\)\)\), "\
\[IndentingNewLine]", 
    \(\(P\&~\)[{{a\_1}, {a\_2}, {b\_1, 
            b\_2}}] = \(\(\ \)\(\((1 + S + 2  r)\)\ \((2 + S)\)\ \((6 + S + \
r)\) + Z\ \((6 + S)\)\)\)\/\(Z \((\((1 + S)\)\ \ \((6 + S)\) + \((1 + S + 2  \
r)\)\ \((2 + S)\)\ \((6 + S + r)\))\)\)\), "\[IndentingNewLine]", 
    \(\(P\&~\)[{{a\_1}, {a\_2}, {b\_1}, {b\_2}}] = \(\((2 + S)\) \((\((1 + S)\
\)\ \((7 + S)\) + r \((1 + S)\) + 2  r\ \((6 + \ S + r)\)\ )\) + \ 4  \
Z\)\/\(Z \((\((1 + S)\)\ \ \((6 + S)\) + \((1 + S + 2  r)\)\ \((2 + S)\)\ \
\((6 + S + r)\))\)\)\), "\[IndentingNewLine]", 
    \(where\ S = \(\[Omega]\_\(a\_1\) + \[Omega]\_\(b\_1\) + \[Omega]\_\(a\_2\
\) + \[Omega]\_\(b\_2\)\ \ and\ Z = \((1 + \[Omega]\_\(a\_1\) + \[Omega]\_\(b\
\_1\))\) \((1 + \[Omega]\_\(a\_2\) + \[Omega]\_\(b\_2\))\)\)\)}], \
"NumberedEquation"],

Cell[TextData[{
  "There are seven distinct configurations, but they all have the same \
functional form.  (This actually allows a drastic simplification of the \
results).  We see that the GF is a function only of ",
  Cell[BoxData[
      \(\[Omega]\_\(a\_1\) + \[Omega]\_\(b\_1\)\)]],
  "and ",
  Cell[BoxData[
      \(\[Omega]\_\(a\_2\) + \[Omega]\_\(b\_2\)\)]],
  ".  This is necessarily so, because the time from ",
  Cell[BoxData[
      \(TraditionalForm\`a\_1\ and\ b\_1\)]],
  "back to their common ancestor is the same.  We also see that setting the \
\[Omega] for one locus to zero gives the correct marginal one locus GF: ",
  Cell[BoxData[
      \(TraditionalForm\`1\/\(1 + \[Omega]\_\(a\_1\) + \
\[Omega]\_\(b\_1\)\)\)]],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`1\/\(1 + \[Omega]\_\(a\_2\) + \
\[Omega]\_\(b\_2\)\)\)]],
  " for all three two-locus configurations.  The correlation between \
coalescence times at the two loci is obtained by differentiating, as:"
}], "Text"],

Cell[BoxData[GridBox[{
        {\(corrln[t\_1, 
              t\_2] = \(9 + r\)\/\(9 + 13\ r + 2\ r\^2\)\ for\ {{a\_1, 
                  a\_2}, {b\_1, b\_2}}\[IndentingNewLine]
          
          corrln[t\_1, t\_2] = 
            3\/\(9 + 13\ r + 2\ r\^2\)\ for\ {{a\_1}, {a\_2}, {b\_1, 
                  b\_2}}\[IndentingNewLine]
          
          corrln[t\_1, t\_2] = 
            2\/\(9 + 13\ r + 2\ r\^2\)\ for\ {{a\_1}, {a\_2}, {b\_1}, {b\_2}}\
\), Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-2.77556e-17 0.2 0 0.618034 [
[.2 -0.0125 -3 -9 ]
[.2 -0.0125 3 0 ]
[.4 -0.0125 -3 -9 ]
[.4 -0.0125 3 0 ]
[.6 -0.0125 -3 -9 ]
[.6 -0.0125 3 0 ]
[.8 -0.0125 -3 -9 ]
[.8 -0.0125 3 0 ]
[1 -0.0125 -3 -9 ]
[1 -0.0125 3 0 ]
[-0.0125 .12361 -18 -4.5 ]
[-0.0125 .12361 0 4.5 ]
[-0.0125 .24721 -18 -4.5 ]
[-0.0125 .24721 0 4.5 ]
[-0.0125 .37082 -18 -4.5 ]
[-0.0125 .37082 0 4.5 ]
[-0.0125 .49443 -18 -4.5 ]
[-0.0125 .49443 0 4.5 ]
[-0.0125 .61803 -6 -4.5 ]
[-0.0125 .61803 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 0 m
.2 .00625 L
s
[(1)] .2 -0.0125 0 1 Mshowa
.4 0 m
.4 .00625 L
s
[(2)] .4 -0.0125 0 1 Mshowa
.6 0 m
.6 .00625 L
s
[(3)] .6 -0.0125 0 1 Mshowa
.8 0 m
.8 .00625 L
s
[(4)] .8 -0.0125 0 1 Mshowa
1 0 m
1 .00625 L
s
[(5)] 1 -0.0125 0 1 Mshowa
.125 Mabswid
.04 0 m
.04 .00375 L
s
.08 0 m
.08 .00375 L
s
.12 0 m
.12 .00375 L
s
.16 0 m
.16 .00375 L
s
.24 0 m
.24 .00375 L
s
.28 0 m
.28 .00375 L
s
.32 0 m
.32 .00375 L
s
.36 0 m
.36 .00375 L
s
.44 0 m
.44 .00375 L
s
.48 0 m
.48 .00375 L
s
.52 0 m
.52 .00375 L
s
.56 0 m
.56 .00375 L
s
.64 0 m
.64 .00375 L
s
.68 0 m
.68 .00375 L
s
.72 0 m
.72 .00375 L
s
.76 0 m
.76 .00375 L
s
.84 0 m
.84 .00375 L
s
.88 0 m
.88 .00375 L
s
.92 0 m
.92 .00375 L
s
.96 0 m
.96 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .12361 m
.00625 .12361 L
s
[(0.2)] -0.0125 .12361 1 0 Mshowa
0 .24721 m
.00625 .24721 L
s
[(0.4)] -0.0125 .24721 1 0 Mshowa
0 .37082 m
.00625 .37082 L
s
[(0.6)] -0.0125 .37082 1 0 Mshowa
0 .49443 m
.00625 .49443 L
s
[(0.8)] -0.0125 .49443 1 0 Mshowa
0 .61803 m
.00625 .61803 L
s
[(1)] -0.0125 .61803 1 0 Mshowa
.125 Mabswid
0 .0309 m
.00375 .0309 L
s
0 .0618 m
.00375 .0618 L
s
0 .09271 m
.00375 .09271 L
s
0 .15451 m
.00375 .15451 L
s
0 .18541 m
.00375 .18541 L
s
0 .21631 m
.00375 .21631 L
s
0 .27812 m
.00375 .27812 L
s
0 .30902 m
.00375 .30902 L
s
0 .33992 m
.00375 .33992 L
s
0 .40172 m
.00375 .40172 L
s
0 .43262 m
.00375 .43262 L
s
0 .46353 m
.00375 .46353 L
s
0 .52533 m
.00375 .52533 L
s
0 .55623 m
.00375 .55623 L
s
0 .58713 m
.00375 .58713 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
1 0 0 r
.5 Mabswid
0 .61803 m
.01975 .54579 L
.04057 .48533 L
.06347 .43209 L
.08481 .39163 L
.12477 .3325 L
.16571 .28728 L
.20923 .25047 L
.25115 .22256 L
.29149 .20075 L
.3344 .18156 L
.37572 .16609 L
.41544 .15338 L
.45775 .14172 L
.49846 .13196 L
.54174 .12288 L
.58344 .11518 L
.62354 .10859 L
.66622 .1023 L
.7073 .09686 L
.75096 .09165 L
.79303 .0871 L
.83351 .08311 L
.87657 .07923 L
.91803 .0758 L
.9579 .07275 L
1 .06978 L
s
0 0 1 r
0 .20601 m
.01975 .17996 L
.04057 .15821 L
.06347 .13912 L
.08481 .12467 L
.12477 .10365 L
.16571 .08769 L
.20923 .0748 L
.25115 .0651 L
.29149 .05759 L
.3344 .05104 L
.37572 .0458 L
.41544 .04154 L
.45775 .03766 L
.49846 .03445 L
.54174 .03149 L
.58344 .029 L
.62354 .02688 L
.66622 .02489 L
.7073 .02318 L
.75096 .02156 L
.79303 .02015 L
.83351 .01894 L
.87657 .01776 L
.91803 .01673 L
.9579 .01583 L
1 .01495 L
s
0 0 0 r
0 .13734 m
.01975 .11997 L
.04057 .10547 L
.06347 .09275 L
.08481 .08311 L
.12477 .0691 L
.16571 .05846 L
.20923 .04986 L
.25115 .0434 L
.29149 .03839 L
.3344 .03403 L
.37572 .03054 L
.41544 .02769 L
.45775 .02511 L
.49846 .02297 L
.54174 .02099 L
.58344 .01933 L
.62354 .01792 L
.66622 .01659 L
.7073 .01545 L
.75096 .01437 L
.79303 .01344 L
.83351 .01262 L
.87657 .01184 L
.91803 .01115 L
.9579 .01055 L
1 .00997 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
            ImageSize->{288, 177.938},
            ImageMargins->{{0, 0}, {0, 0}},
            ImageRegion->{{0, 1}, {0, 1}},
            ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/B000`400?l00000o`00003oo`3ooolQ
0?ooo`00B03oool300000300oooo1@00000`0?ooo`<00000<P3oool300000300oooo0`0000050?oo
o`00B@3oool00`000000oooo0?ooo`0`0?ooo`040000003oool0oooo000002l0oooo00D000000?oo
o`3oool0oooo0000000b0?ooo`030000003oool0oooo02h0oooo00D000000?ooo`3oool0oooo0000
00040?ooo`00B@3oool00`000000oooo0?ooo`0a0?ooo`030000003oool0oooo03<0oooo00<00000
0?ooo`3oool0;@3oool5000003<0oooo00<000000?ooo`3oool00P3oool004T0oooo00<000000?oo
o`3oool0<P3oool00`000000oooo0?ooo`0`0?ooo`800000<03oool010000000oooo0?ooo`00000d
0?ooo`030000003oool0oooo0080oooo00190?ooo`030000003oool0oooo02l0oooo00D000000?oo
o`3oool0oooo0000000c0?ooo`030000003oool0oooo02h0oooo00<000000?ooo`000000<03oool4
000000D0oooo00180?ooo`800000<@3oool01@000000oooo0?ooo`3oool0000002l0oooo00D00000
0?ooo`3oool0oooo0000000a0?ooo`800000<03oool00`000000oooo0?ooo`060?ooo`00B@3oool0
0`000000oooo0?ooo`0`0?ooo`<00000<@3oool3000003<0oooo00<000000?ooo`3oool0;P3oool5
000000@0oooo003o0?ooob40oooo003o0?ooob40oooo003o0?ooob40oooo003o0?ooob40oooo000G
0?ooool000001@0000050?ooo`005`3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo
00L0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo
00L0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo
00L0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo
00P0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo
00P0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo
00P0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo
00L0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo
00L0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo
00<0oooo000G0?ooo`030000003oool0oooo0?/0oooo1P0000050?ooo`005`3oool00`000000oooo
0?ooo`350?ooocH000002`3oool001L0oooo00<000000?ooo`3oool0V@3oool/000001H0oooo9P00
0?l50?ooo`005`3oool00`000000oooo0?ooo`240?oooaD000008@3ooolQ0000ob/0oooo000G0?oo
o`030000003oool0oooo06h0oooo5P00000P0?oooaH0003oC03oool001L0oooo00<000000?ooo`3o
ool0H`3oool;00000240oooo5@000?mR0?ooo`005`3oool00`000000oooo0?ooo`1I0?ooo`X00000
8@3oool;0000ogL0oooo000G0?ooo`030000003oool0oooo04h0oooo2`00000P0?ooo`/0003oPP3o
ool001L0oooo00<000000?ooo`3oool0@`3oool;00000200oooo2`000?n=0?ooo`005`3oool00`00
0000oooo0?ooo`0k0?ooo`P00000803oool;0000oiP0oooo000G0?ooo`030000003oool0oooo03H0
oooo1@00000N0?ooo`X0003oX`3oool001L0oooo00<000000?ooo`3oool0<03oool6000001X0oooo
2@000?n]0?ooo`005`3oool00`000000oooo0?ooo`0Z0?ooo`H000006`3oool50000okH0oooo000G
0?ooo`030000003oool0oooo02D0oooo1@00000L0?ooo`D0003o^`3oool001L0oooo00<000000?oo
o`3oool08P3oool3000001`0oooo1@000?o00?ooo`005`3oool00`000000oooo0?ooo`0O0?ooo`<0
00006@3oool60000olD0oooo000G0?ooo`030000003oool0oooo01/0oooo1000000G0?ooo`D0003o
`03oool60?l000D0oooo000G0?ooo`030000003oool0oooo01P0oooo0`00000G0?ooo`@0003o[`3o
oolF0?l000/0oooo000G0?ooo`030000003oool0oooo01D0oooo0`00000G0?ooo`<0003oZ@3oool:
0?l00240oooo000G0?ooo`030000003oool0oooo0180oooo0`00000G0?ooo`<0003oX@3oool;0?l0
02/0oooo000G0?ooo`030000003oool0oooo0100oooo0P00000G0?ooo`<0003oV`3oool90?l003H0
oooo000G0?ooo`030000003oool0oooo00h0oooo0P00000F0?ooo`<0003oV@3oool50?l003l0oooo
000G0?ooo`030000003oool0oooo00`0oooo0P00000E0?ooo`<0003oU03oool80?l004@0oooo000G
0?ooo`030000003oool0oooo00X0oooo0P00000E0?ooo`80003oS03oool;0?l004`0oooo000G0?oo
o`030000003oool0oooo00P0oooo0P00000D0?ooo`<0003oQ@3oool90?l005L0oooo000G0?ooo`03
0000003oool0oooo00H0oooo0P00000D0?ooo`80003oP`3oool50?l00600oooo000G0?ooo`030000
003oool0oooo00D0oooo00<000000?ooo`3oool04P3oool20000oh00oooo1@3o001U0?ooo`000`3o
ool2000000@0oooo00@000000?ooo`3oool0oooo1@0000050?ooo`030000003oool0oooo00@0oooo
00<000000?ooo`3oool04@3oool20000ogd0oooo1@3o001Z0?ooo`000P3oool010000000oooo0?oo
o`0000080?ooo`040000003oool0oooo000000D0oooo00<000000?ooo`3oool00`3oool00`000000
oooo0?ooo`0@0?ooo`80003oN@3oool60?l006l0oooo00020?ooo`040000003oool0oooo000000T0
oooo00<000000?ooo`3oool01@3oool010000000oooo0?ooo`3oool200000140oooo0P000?mf0?oo
o`D0o`00M@3oool00080oooo00@000000?ooo`3oool000002P3oool00`000000oooo0?ooo`040?oo
o`80000000<0oooo0000003oool0403oool20000og80oooo1P3o001j0?ooo`000P3oool010000000
oooo0?ooo`0000070?ooo`050000003oool0oooo0?ooo`0000001@3oool00`000000oooo0000000A
0?ooo`030000o`3oool0oooo06d0oooo1@3o00200?ooo`000P3oool010000000oooo0?ooo`000007
0?ooo`050000003oool0oooo0?ooo`0000001@3oool200000100oooo0P000?m[0?ooo`D0o`00Q@3o
ool000<0oooo0P0000090?ooo`<000001P3oool00`000000oooo0?ooo`0>0?ooo`030000o`3oool0
oooo06L0oooo103o002:0?ooo`005`3oool00`000000oooo0?ooo`0<0?ooo`80003oI`3oool30?l0
08h0oooo000G0?ooo`030000003oool0oooo00/0oooo00<0003o0?ooo`3oool0H`3oool40?l00940
oooo000G0?ooo`030000003oool0oooo00X0oooo00<0003o0?ooo`3oool0H03oool40?l009D0oooo
000G0?ooo`030000003oool0oooo00T0oooo00<0003o0?ooo`3oool0GP3oool30?l009T0oooo000G
0?ooo`030000003oool0oooo00P0oooo00<0003o0?ooo`3oool0F`3oool40?l009`0oooo000G0?oo
o`030000003oool0oooo00L0oooo00<0003o0?ooo`3oool0F@3oool30?l00:00oooo000G0?ooo`03
0000003oool0oooo00H0oooo00<0003o0?ooo`3oool0E`3oool30?l00:<0oooo000G0?ooo`030000
003oool0oooo00D0oooo00<0003o0?ooo`3oool0E@3oool30?l00:H0oooo000G0?ooo`030000003o
ool0oooo00@0oooo00<0003o0?ooo`3oool0D`3oool30?l00:T0oooo000G0?ooo`030000003oool0
oooo00<0oooo00<0003o0?ooo`3oool0D@3oool30?l00:`0oooo000G0?ooo`030000003oool0oooo
0080oooo00<0003o0?ooo`3oool0C`3oool30?l00:l0oooo000G0?ooo`030000003oool0oooo0080
oooo00<0003o0?ooo`3oool0C@3oool20?l00;80oooo000G0?ooo`050000003oool0oooo0?ooo`00
0?l0CP3oool20?l00;@0oooo000G0?ooo`040000003oool0oooo0000od`0oooo0`3o002f0?ooo`00
5`3oool00`000000oooo0000o`1;0?ooo`80o`00^@3oool001L0oooo00<000000?ooo`000?l0B@3o
ool20?l00;/0oooo000G0?ooo`03000000000?l0oooo04L0oooo0P3o002m0?ooo`005`3oool00`00
0?l0oooo0?ooo`150?ooo`80o`00_`3oool001L0oooo00<000000?ooo`3oool0@`3oool20?l00<40
oooo000G0?ooo`030000003oool0oooo0440oooo0P3o00330?ooo`005`3oool00`000000oooo0?oo
o`0o0?ooo`80o`00a@3oool001L0oooo00<000000?ooo`3oool0?@3oool20?l00<L0oooo000G0?oo
o`030000003oool0oooo03`0oooo00<0o`000?ooo`3oool0a`3oool001L0oooo00<000000?ooo`3o
ool0>`3oool00`3o0000oooo0?ooo`380?ooo`005`3oool00`000000oooo0?ooo`0i0?ooo`80o`00
b`3oool000<0oooo0P0000040?ooo`030000003oool0oooo00<0oooo0`0000050?ooo`030000003o
ool0oooo03P0oooo00<0o`000?ooo`3oool0b`3oool00080oooo00@000000?ooo`3oool000002P3o
ool00`000000oooo0?ooo`040?ooo`030000003oool0oooo03H0oooo0P3o003>0?ooo`000P3oool0
10000000oooo0?ooo`0000070?ooo`D000001@3oool00`000000oooo0?ooo`0e0?ooo`030?l0003o
ool0oooo0<h0oooo00020?ooo`040000003oool0oooo000000L0oooo00@000000?ooo`3oool00000
1P3oool2000003D0oooo00<0o`000?ooo`3oool0c`3oool00080oooo00@000000?ooo`3oool00000
203oool00`000000oooo000000060?ooo`030000003oool0oooo0380oooo0P3o003B0?ooo`000P3o
ool010000000oooo0?ooo`0000090?ooo`8000001P3oool00`000000oooo0?ooo`0a0?ooo`030?l0
003oool0oooo0=80oooo00030?ooo`8000002`3oool00`000000oooo0?ooo`040?ooo`030000003o
ool0oooo0300oooo00<0o`000?ooo`3oool0d`3oool001L0oooo00<000000?ooo`3oool0;P3oool2
0?l00=H0oooo000G0?ooo`030000003oool0oooo02d0oooo00<0o`000?ooo`3oool0eP3oool001L0
oooo00<000000?ooo`3oool0;03oool00`3o0000oooo0?ooo`3G0?ooo`005`3oool00`000000oooo
0?ooo`0Z0?ooo`80o`00fP3oool001L0oooo00<000000?ooo`3oool0:@3oool00`3o0000oooo0?oo
o`3J0?ooo`005`3oool00`000000oooo0?ooo`0X0?ooo`030?l0003oool0oooo0=/0oooo000G0?oo
o`030000003oool0oooo02L0oooo00<0o`000?ooo`3oool0g03oool001L0oooo00<000000?ooo`3o
ool09`3oool00`3o0000oooo0?ooo`3L0?ooo`005`3oool00`000000oooo0?ooo`0V0?ooo`030?l0
003oool0oooo0=d0oooo000G0?ooo`030000003oool0oooo02D0oooo00<0o`000?ooo`3oool0gP3o
ool001L0oooo00<000000?ooo`3oool0903oool00`3o0000oooo0?ooo`3O0?ooo`005`3oool00`00
0000oooo0?ooo`0S0?ooo`030?l0003oool0oooo0>00oooo000G0?ooo`030000003oool0oooo0280
oooo00<0o`000?ooo`3oool0h@3oool001L0oooo00<000000?ooo`3oool08P3oool00`3o0000oooo
0?ooo`3Q0?ooo`005`3oool00`000000oooo0?ooo`0Q0?ooo`030?l0003oool0oooo0>80oooo000G
0?ooo`030000003oool0oooo0200oooo00<0o`000?ooo`3oool0h`3oool001L0oooo00<000000?oo
o`3oool07`3oool00`3o0000oooo0?ooo`3T0?ooo`005`3oool00`000000oooo0?ooo`0N0?ooo`03
0?l0003oool0oooo0>D0oooo000G0?ooo`030000003oool0oooo01d0oooo00<0o`000?ooo`3oool0
iP3oool001L0oooo00<000000?ooo`3oool07@3oool00`3o0000oooo0?ooo`3V0?ooo`005`3oool0
0`000000oooo0?ooo`0L0?ooo`030?l0003oool0oooo0>L0oooo000G0?ooo`030000003oool0oooo
01/0oooo00<0o`000?ooo`3oool0j03oool001L0oooo00<000000?ooo`3oool06`3oool00`3o0000
oooo0?ooo`3X0?ooo`005`3oool00`000000oooo0?ooo`0J0?ooo`030?l0003oool0oooo0>T0oooo
000G0?ooo`030000003oool0oooo01T0oooo00<0o`000?ooo`3oool0jP3oool000<0oooo0P000004
0?ooo`030000003oool0oooo0080oooo0`0000060?ooo`030000003oool0oooo01T0oooo00<0o`00
0?ooo`3oool0jP3oool00080oooo00@000000?ooo`3oool000001`3oool01@000000oooo0?ooo`3o
ool0000000D0oooo00<000000?ooo`3oool0603oool00`3o0000oooo0?ooo`3[0?ooo`000P3oool0
10000000oooo0?ooo`0000070?ooo`050000003oool0oooo0?ooo`0000001@3oool00`000000oooo
0?ooo`0G0?ooo`030?l0003oool0oooo0>`0oooo00020?ooo`040000003oool0oooo000000L0oooo
100000060?ooo`800000603oool00`3o0000oooo0?ooo`3/0?ooo`000P3oool010000000oooo0?oo
o`0000070?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool05P3oool00`3o0000oooo
0?ooo`3]0?ooo`000P3oool010000000oooo0?ooo`0000080?ooo`030000003oool0oooo00H0oooo
00<000000?ooo`3oool05@3oool00`3o0000oooo0?ooo`3^0?ooo`000`3oool2000000X0oooo0P00
00060?ooo`030000003oool0oooo01D0oooo00<0o`000?ooo`3oool0kP3oool001L0oooo00<00000
0?ooo`3oool0503oool00`3o0000oooo0?ooo`3_0?ooo`005`3oool00`000000oooo0?ooo`0C0?oo
o`030?l0003oool0oooo0?00oooo000G0?ooo`030000003oool0oooo01<0oooo00<0o`000?ooo`3o
ool0l03oool001L0oooo00<000000?ooo`3oool04P3oool00`3o0000oooo0?ooo`3a0?ooo`005`3o
ool00`000000oooo0?ooo`0B0?ooo`030?l0003oool0oooo0?40oooo000G0?ooo`030000003oool0
oooo0140oooo00<0o`000?ooo`3oool0lP3oool001L0oooo00<000000?ooo`3oool04@3oool00`3o
0000oooo0?ooo`3b0?ooo`005`3oool00`000000oooo0?ooo`0@0?ooo`030?l0003oool0oooo0?<0
oooo000G0?ooo`030000003oool0oooo00l0oooo00<0o`000?ooo`3oool0m03oool001L0oooo00<0
00000?ooo`3oool03`3oool00`3o0000oooo0?ooo`3d0?ooo`005`3oool00`000000oooo0?ooo`0>
0?ooo`030?l0003oool0oooo0?D0oooo000G0?ooo`030000003oool0oooo00h0oooo00<0o`000?oo
o`3oool0m@3oool001L0oooo00<000000?ooo`3oool03@3oool00`3o0000oooo0?ooo`3f0?ooo`00
5`3oool00`000000oooo0?ooo`0=0?ooo`030?l0003oool0oooo0?H0oooo000G0?ooo`030000003o
ool0oooo00`0oooo00<0o`000?ooo`3oool0m`3oool001L0oooo00<000000?ooo`3oool0303oool0
0`3o0000oooo0?ooo`3g0?ooo`005`3oool00`000000oooo0?ooo`0;0?ooo`030?l0003oool0oooo
0?P0oooo000G0?ooo`030000003oool0oooo00/0oooo00<0o`000?ooo`3oool0n03oool001L0oooo
00<000000?ooo`3oool02`3oool00`3o0000oooo0?ooo`3h0?ooo`005`3oool00`000000oooo0?oo
o`0:0?ooo`030?l0003oool0oooo0?T0oooo000G0?ooo`030000003oool0oooo00X0oooo00<0o`00
0?ooo`3oool0n@3oool001L0oooo00<000000?ooo`3oool02@3oool00`3o0000oooo0?ooo`3j0?oo
o`005`3oool00`000000oooo0?ooo`090?ooo`030?l0003oool0oooo0?X0oooo000G0?ooo`030000
003oool0oooo00P0oooo00<0o`000?ooo`3oool0n`3oool001L0oooo00<000000?ooo`3oool0203o
ool00`3o0000oooo0?ooo`3k0?ooo`000`3oool2000000@0oooo00<000000?ooo`3oool00P3oool3
000000H0oooo00<000000?ooo`3oool0203oool00`3o0000oooo0?ooo`3k0?ooo`000P3oool01000
0000oooo0?ooo`0000070?ooo`050000003oool0oooo0?ooo`0000001@3oool00`000000oooo0?oo
o`070?ooo`030?l0003oool0oooo0?`0oooo00020?ooo`040000003oool0oooo000000L0oooo00D0
00000?ooo`3oool0oooo000000050?ooo`030000003oool0oooo00L0oooo00<0o`000?ooo`3oool0
o03oool00080oooo00@000000?ooo`3oool00000203oool3000000H0oooo0P0000070?ooo`030?l0
003oool0oooo0?d0oooo00020?ooo`040000003oool0oooo000000L0oooo00D000000?ooo`3oool0
oooo000000050?ooo`030000003oool0oooo00H0oooo00<0o`000?ooo`3oool0o@3oool00080oooo
00@000000?ooo`3oool000001`3oool01@000000oooo0?ooo`3oool0000000D0oooo00<000000?oo
o`3oool01P3oool00`3o0000oooo0?ooo`3m0?ooo`000`3oool2000000T0oooo0`0000060?ooo`03
0000003oool0oooo00D0oooo00<0o`000?ooo`3oool0oP3oool001L0oooo00<000000?ooo`3oool0
1@3oool00`3o0000oooo0?ooo`3n0?ooo`005`3oool00`000000oooo0?ooo`050?ooo`030?l0003o
ool0oooo0?h0oooo000G0?ooo`030000003oool0oooo00@0oooo00<0o`000?ooo`3oool0o`3oool0
01L0oooo00<000000?ooo`3oool0103oool00`3o0000oooo0?ooo`3o0?ooo`005`3oool00`000000
oooo0?ooo`040?ooo`030?l0003oool0oooo0?l0oooo000G0?ooo`030000003oool0oooo00<0oooo
00<0o`000?ooo`3oool0o`3oool10?ooo`005`3oool00`000000oooo0?ooo`030?ooo`030?l0003o
ool0oooo0?l0oooo0@3oool001L0oooo00<000000?ooo`3oool00`3oool00`3o0000oooo0?ooo`3o
0?ooo`40oooo000G0?ooo`030000003oool0oooo0080oooo00<0o`000?ooo`3oool0o`3oool20?oo
o`005`3oool00`000000oooo0?ooo`020?ooo`030?l0003oool0oooo0?l0oooo0P3oool001L0oooo
00<000000?ooo`3oool00P3oool00`3o0000oooo0?ooo`3o0?ooo`80oooo000G0?ooo`030000003o
ool0oooo0080oooo00<0o`000?ooo`3oool0o`3oool20?ooo`005`3oool01@000000oooo0?ooo`3o
ool0o`000?l0oooo1@3oool001L0oooo00D000000?ooo`3oool0oooo0?l0003o0?ooo`D0oooo000G
0?ooo`050000003oool0oooo0?ooo`3o0000o`3oool50?ooo`005`3oool01@000000oooo0?ooo`3o
ool0o`000?l0oooo1@3oool001L0oooo00@000000?ooo`3oool0o`00o`3oool60?ooo`005`3oool0
10000000oooo0?ooo`3o003o0?ooo`H0oooo000G0?ooo`040000003oool0oooo0?l00?l0oooo1P3o
ool001L0oooo00<000000?ooo`3o0000o`3oool70?ooo`005`3oool00`000000oooo0?l0003o0?oo
o`L0oooo000G0?ooo`030000003oool0o`000?l0oooo1`3oool001L0oooo00<000000?ooo`3o0000
o`3oool70?ooo`005`3oool00`000000o`000?ooo`3o0?ooo`L0oooo000G0?ooo`030000003o0000
oooo0?l0oooo1`3oool000h0oooo0`0000060?ooo`030000003o0000oooo0?l0oooo1`3oool000l0
oooo00<000000?ooo`3oool01@3oool00`000000o`000?ooo`3o0?ooo`L0oooo000?0?ooo`030000
003oool0oooo00D0oooo00<0o`000?ooo`3oool0o`3oool70?ooo`003`3oool00`000000oooo0?oo
o`050?ooo`030?l000000000oooo0?l0oooo1`3oool000l0oooo00<000000?ooo`3oool0o`3oool?
0?ooo`003P3oool200000?l0oooo4@3oool000l0oooo00<000000?ooo`3oool0o`3oool?0?ooo`00
o`3ooolQ0?ooo`00\
\>"],
            ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {0, 0, 0, 0}}]}
        }]], "NumberedEquation"],

Cell[TextData[{
  "As one would expect, the correlation is highest when both pairs of genes \
are linked together, but is still appreciable when one or both are sampled \
from separate genomes.  As r\[Rule]0, the correlation tends to ",
  Cell[BoxData[
      \(TraditionalForm\`{1, 1\/3, \ 2\/9}\)]],
  ", respectively."
}], "Text"],

Cell["\<\
To get further, I need to make the obvious simplifications using \
symmetries among equivalent configurations.  A natural way to do this is to \
treat the variables as \[Omega][\[DoubleStruckCapitalP]], defined as \
\[Omega][{a},{b},{c,d}]=\[Omega][{a}]+\[Omega][{b}]+\[Omega][{c,d}].  It is \
not clear that this is any simpler, as there may be more variables of this \
sort than before.\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(cs2 // MatrixForm\)], "Input",
  CellLabel->"In[238]:="],

Cell[BoxData[
    InterpretationBox[
      RowBox[{"(", "\[NoBreak]", GridBox[{
            {\({{{a1}, {a2}}, {{b1}, {b2}}}\)},
            {\({{{a1}, {b2}}, {{b1}, {a2}}}\)},
            {\({{{}, {a2}}, {{a1}, {}}, {{b1}, {b2}}}\)},
            {\({{{}, {a2}}, {{a1}, {b2}}, {{b1}, {}}}\)},
            {\({{{}, {b2}}, {{a1}, {}}, {{b1}, {a2}}}\)},
            {\({{{}, {b2}}, {{a1}, {a2}}, {{b1}, {}}}\)},
            {\({{{}, {a2}}, {{}, {b2}}, {{a1}, {}}, {{b1}, {}}}\)}
            }], "\[NoBreak]", ")"}],
      MatrixForm[ {{{{a1}, {a2}}, {{b1}, {b2}}}, {{{a1}, {b2}}, {{b1}, {
        a2}}}, {{{}, {a2}}, {{a1}, {}}, {{b1}, {b2}}}, {{{}, {a2}}, {{a1}, {
        b2}}, {{b1}, {}}}, {{{}, {b2}}, {{a1}, {}}, {{b1}, {a2}}}, {{{}, {
        b2}}, {{a1}, {a2}}, {{b1}, {}}}, {{{}, {a2}}, {{}, {b2}}, {{
        a1}, {}}, {{b1}, {}}}}]]], "Output",
  CellLabel->"Out[238]//MatrixForm="]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["Working for three individuals", "SubsubsectionIcon"],

Cell["Now, try three individuals:", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(cs = ConfigurationSet[{{a1, b1, c1}, {a2, b2, c2}}]\)], "Input",
  CellLabel->"In[334]:="],

Cell[BoxData[
    \({{{{a1, b1}, {a2, b2}}}, {{{}, {a2}}, {{a1, 
            b1}, {b2}}}, {{{}, {b2}}, {{a1, b1}, {a2}}}, {{{}, {a2, 
            b2}}, {{a1, b1}, {}}}, {{{a1}, {}}, {{b1}, {a2, 
            b2}}}, {{{a1}, {a2}}, {{b1}, {b2}}}, {{{a1}, {b2}}, {{b1}, \
{a2}}}, {{{a1}, {a2, b2}}, {{b1}, {}}}, {{{}, {a2}}, {{}, {b2}}, {{a1, 
            b1}, {}}}, {{{}, {a2}}, {{a1}, {}}, {{b1}, {b2}}}, {{{}, {a2}}, \
{{a1}, {b2}}, {{b1}, {}}}, {{{}, {b2}}, {{a1}, {}}, {{b1}, {a2}}}, {{{}, \
{b2}}, {{a1}, {a2}}, {{b1}, {}}}, {{{}, {a2, 
            b2}}, {{a1}, {}}, {{b1}, {}}}, {{{}, {a2}}, {{}, {b2}}, {{a1}, \
{}}, {{b1}, {}}}}\)], "Output",
  CellLabel->"Out[164]="]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    \(cs2 = 
      Select[cs, \((Min[\(Length[DeleteCases[#, {}]] &\) /@ Transpose[#]] > 
              1)\) &]\)], "Input",
  CellLabel->"In[177]:="],

Cell[BoxData[
    \({{{{a1}, {a2}}, {{b1}, {b2}}}, {{{a1}, {b2}}, {{b1}, {a2}}}, {{{}, \
{a2}}, {{a1}, {}}, {{b1}, {b2}}}, {{{}, {a2}}, {{a1}, {b2}}, {{b1}, {}}}, \
{{{}, {b2}}, {{a1}, {}}, {{b1}, {a2}}}, {{{}, {b2}}, {{a1}, {a2}}, {{b1}, \
{}}}, {{{}, {a2}}, {{}, {b2}}, {{a1}, {}}, {{b1}, {}}}}\)], "Output",
  CellLabel->"Out[177]="]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(eqns = \((\(p[#] \[Equal] Simplify[DeriveMGF[#, p, w, r]] &\) /@ 
            cs2)\);\)\)], "Input",
  CellLabel->"In[229]:="],

Cell[BoxData[
    \({p[{{{a1}, {a2}}, {{b1}, {b2}}}] == \(1 + r\ \((p[{{{}, {a2}}, {{a1}, \
{}}, {{b1}, {b2}}}] + p[{{{}, {b2}}, {{a1}, {a2}}, {{b1}, {}}}])\)\)\/\(1 + 2\
\ r + w[{a1}] + w[{a2}] + w[{b1}] + w[{b2}]\), 
      p[{{{a1}, {b2}}, {{b1}, {a2}}}] == \(1 + r\ \((p[{{{}, {a2}}, {{a1}, \
{b2}}, {{b1}, {}}}] + p[{{{}, {b2}}, {{a1}, {}}, {{b1}, {a2}}}])\)\)\/\(1 + 2\
\ r + w[{a1}] + w[{a2}] + w[{b1}] + w[{b2}]\), 
      p[{{{}, {a2}}, {{a1}, {}}, {{b1}, {b2}}}] == \(p[{{{a1}, {a2}}, {{b1}, \
{b2}}}] + r\ p[{{{}, {a2}}, {{}, {b2}}, {{a1}, {}}, {{b1}, {}}}] + 1\/\(1 + \
w[{a1}] + w[{b1}]\) + 1\/\(1 + w[{a2}] + w[{b2}]\)\)\/\(3 + r + w[{a1}] + \
w[{a2}] + w[{b1}] + w[{b2}]\), 
      p[{{{}, {a2}}, {{a1}, {b2}}, {{b1}, {}}}] == \(p[{{{a1}, {b2}}, {{b1}, \
{a2}}}] + r\ p[{{{}, {a2}}, {{}, {b2}}, {{a1}, {}}, {{b1}, {}}}] + 1\/\(1 + \
w[{a1}] + w[{b1}]\) + 1\/\(1 + w[{a2}] + w[{b2}]\)\)\/\(3 + r + w[{a1}] + \
w[{a2}] + w[{b1}] + w[{b2}]\), 
      p[{{{}, {b2}}, {{a1}, {}}, {{b1}, {a2}}}] == \(p[{{{a1}, {b2}}, {{b1}, \
{a2}}}] + r\ p[{{{}, {a2}}, {{}, {b2}}, {{a1}, {}}, {{b1}, {}}}] + 1\/\(1 + \
w[{a1}] + w[{b1}]\) + 1\/\(1 + w[{a2}] + w[{b2}]\)\)\/\(3 + r + w[{a1}] + \
w[{a2}] + w[{b1}] + w[{b2}]\), 
      p[{{{}, {b2}}, {{a1}, {a2}}, {{b1}, {}}}] == \(p[{{{a1}, {a2}}, {{b1}, \
{b2}}}] + r\ p[{{{}, {a2}}, {{}, {b2}}, {{a1}, {}}, {{b1}, {}}}] + 1\/\(1 + \
w[{a1}] + w[{b1}]\) + 1\/\(1 + w[{a2}] + w[{b2}]\)\)\/\(3 + r + w[{a1}] + \
w[{a2}] + w[{b1}] + w[{b2}]\), 
      p[{{{}, {a2}}, {{}, {b2}}, {{a1}, {}}, {{b1}, {}}}] == \((p[{{{}, \
{a2}}, {{a1}, {}}, {{b1}, {b2}}}] + 
              p[{{{}, {a2}}, {{a1}, {b2}}, {{b1}, {}}}] + 
              p[{{{}, {b2}}, {{a1}, {}}, {{b1}, {a2}}}] + 
              p[{{{}, {b2}}, {{a1}, {a2}}, {{b1}, {}}}] + 
              1\/\(1 + w[{a1}] + w[{b1}]\) + 
              1\/\(1 + w[{a2}] + w[{b2}]\))\)/\((6 + w[{a1}] + w[{a2}] + 
              w[{b1}] + w[{b2}])\)}\)], "Output",
  CellLabel->"Out[229]="]
}, Closed]],

Cell[BoxData[
    \(\(soln = \(Solve[eqns, 
            p /@ cs2]\)\[LeftDoubleBracket]1\[RightDoubleBracket];\)\)], \
"Input",
  CellLabel->"In[230]:="],

Cell[BoxData[
    \(\(vt = \(vars /. soln\) /. {w[{a1}] \[RuleDelayed] S1 - w[{b1}], 
              w[{a2}] \[RuleDelayed] S2 - w[{b2}]} // Simplify;\)\)], "Input",\

  CellLabel->"In[249]:="],

Cell[CellGroupData[{

Cell[BoxData[
    \(vt[\([1]\)]\)], "Input",
  CellLabel->"In[250]:="],

Cell[BoxData[
    \(\((2\ r\^2\ \((2 + S1 + S2)\) + \((1 + S1)\)\ \((1 + S2)\)\ \((18 + 
                S1\^2 + 9\ S2 + S2\^2 + S1\ \((9 + 2\ S2)\))\) + 
          r\ \((26 + 19\ S2 + 3\ S2\^2 + S1\^2\ \((3 + S2)\) + 
                S1\ \((19 + 8\ S2 + S2\^2)\))\))\)/\((\((1 + S1)\)\ \((1 + 
              S2)\)\ \((18 + S1\^3 + 27\ S2 + 10\ S2\^2 + S2\^3 + 
              2\ r\^2\ \((2 + S1 + S2)\) + S1\^2\ \((10 + 3\ S2)\) + 
              S1\ \((27 + 20\ S2 + 3\ S2\^2)\) + 
              r\ \((26 + 3\ S1\^2 + 19\ S2 + 3\ S2\^2 + 
                    S1\ \((19 + 6\ S2)\))\))\))\)\)], "Output",
  CellLabel->"Out[250]="]
}, Open  ]]
}, Closed]]
}, Open  ]]
},
FrontEndVersion->"4.0 for Macintosh",
ScreenRectangle->{{0, 1024}, {0, 748}},
AutoGeneratedPackage->None,
WindowSize->{960, 698},
WindowMargins->{{Automatic, 23}, {Automatic, 0}},
Visible->True,
InputAliases->{"notation"->RowBox[ {"Notation", "[", 
        RowBox[ {
          TagBox[ 
          "\[Placeholder]", NotationBoxTag, TagStyle -> 
            "NotationTemplateStyle"], " ", "\[DoubleLongLeftRightArrow]", " ",
           
          TagBox[ 
          "\[Placeholder]", NotationBoxTag, TagStyle -> 
            "NotationTemplateStyle"]}], "]"}], 
    "notation>"->RowBox[ {"Notation", "[", 
        RowBox[ {
          TagBox[ 
          "\[Placeholder]", NotationBoxTag, TagStyle -> 
            "NotationTemplateStyle"], " ", "\[DoubleLongRightArrow]", " ", 
          TagBox[ 
          "\[Placeholder]", NotationBoxTag, TagStyle -> 
            "NotationTemplateStyle"]}], "]"}], 
    "notation<"->RowBox[ {"Notation", "[", 
        RowBox[ {
          TagBox[ 
          "\[Placeholder]", NotationBoxTag, TagStyle -> 
            "NotationTemplateStyle"], " ", "\[DoubleLongLeftArrow]", " ", 
          TagBox[ 
          "\[Placeholder]", NotationBoxTag, TagStyle -> 
            "NotationTemplateStyle"]}], "]"}], 
    "symb"->RowBox[ {"Symbolize", "[", 
        TagBox[ 
        "\[Placeholder]", NotationBoxTag, TagStyle -> 
          "NotationTemplateStyle"], "]"}], 
    "infixnotation"->RowBox[ {"InfixNotation", "[", 
        RowBox[ {
          TagBox[ 
          "\[Placeholder]", NotationBoxTag, TagStyle -> 
            "NotationTemplateStyle"], ",", "\[Placeholder]"}], "]"}], 
    "addia"->RowBox[ {"AddInputAlias", "[", 
        RowBox[ {"\[Placeholder]", "\[Rule]", 
          TagBox[ 
          "\[Placeholder]", NotationBoxTag, TagStyle -> 
            "NotationTemplateStyle"]}], "]"}], 
    "pattwraper"->TagBox[ 
      "\[Placeholder]", NotationPatternTag, TagStyle -> 
        "NotationPatternWrapperStyle"], 
    "madeboxeswraper"->TagBox[ 
      "\[Placeholder]", NotationMadeBoxesTag, TagStyle -> 
        "NotationMadeBoxesWrapperStyle"]},
StyleDefinitions -> Notebook[{
  
  Cell[CellGroupData[{
  Cell["Style Definitions for On-line Help", "Subtitle"],
  
  Cell["\<\
These styles are carefully tuned for all aspects of the online \
help. It's recommended that they remain unchanged.\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell["Style Environment Names", "Subsubsection"],
  
  Cell[StyleData[All, "Working"],
    PageWidth->WindowWidth,
    ShowCellBracket->False,
    ShowAutoStyles->False,
    ScriptMinSize->9],
  
  Cell[StyleData[All, "Brackets"],
    PageWidth->WindowWidth,
    ShowAutoStyles->False,
    ScriptMinSize->9],
  
  Cell[StyleData[All, "Printout"],
    PageWidth->PaperWidth,
    ShowAutoStyles->False,
    ScriptMinSize->5,
    PrivateFontOptions->{"FontType"->"Outline"}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Notebook Options", "Subsubsection"],
  
  Cell["\<\
  The options defined for the style below will be used at the \
Notebook level.  \
\>", "Text"],
  
  Cell[StyleData["Notebook"],
    PageHeaders->{{Cell[ 
            TextData[ {
              CounterBox[ "Page"]}], "PageNumber"], None, Cell[ 
            TextData[ {"Printed from the ", 
              StyleBox[ "Mathematica", FontSlant -> "Italic"], 
              " Help Browser"}], "PageHeader"]}, {Cell[ 
            TextData[ {"Printed from the ", 
              StyleBox[ "Mathematica", FontSlant -> "Italic"], 
              " Help Browser"}], "PageHeader"], None, Cell[ 
            TextData[ {
              CounterBox[ "Page"]}], "PageNumber"]}},
    PageFooters->{{None, Cell[ 
            
            TextData[ {
              "\[Copyright]1999 Wolfram Research, Inc. All rights \
reserved."}], "PageFooter"], None}, {None, Cell[ 
            
            TextData[ {
              "\[Copyright]1999 Wolfram Research, Inc. All rights \
reserved."}], "PageFooter"], None}},
    PageHeaderLines->{True, True},
    PageFooterLines->{True, True},
    PrintingOptions->{"FacingPages"->True},
    CellLabelAutoDelete->False,
    StyleMenuListing->None]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Headings", "Subsubsection"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Chapter"],
    CellMargins->{{10, 4}, {4, 24}},
    ConversionRules:>{"HTML" -> {
      "<FONT SIZE=\"+3\" FACE=\"Helvetica, Arial\"><P><B>", 
      "</B></P></FONT>\n"}},
    InputAutoReplacements->{"TeX"->StyleBox[ 
            RowBox[ {"T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.074999999999999997, \
-0.085000000000000006}, {0, 0}}, BoxBaselineShift -> 0.5], "X"}]], 
        "LaTeX"->StyleBox[ 
            RowBox[ {"L", 
              StyleBox[ 
                AdjustmentBox[ 
                "A", BoxMargins -> {{-0.35999999999999999, \
-0.10000000000000001}, {0, 0}}, BoxBaselineShift -> -0.20000000000000001], 
                FontSize -> Smaller], "T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.074999999999999997, \
-0.085000000000000006}, {0, 0}}, BoxBaselineShift -> 0.5], "X"}]], 
        "mma"->"Mathematica", "Mma"->"Mathematica", "MMA"->"Mathematica"},
    FontFamily->"Helvetica",
    FontSize->24,
    FontWeight->"Bold"],
  
  Cell[StyleData["Chapter", "Printout"],
    CellMargins->{{2, 0}, {0, 18}},
    PageBreakBelow->False,
    FontSize->22]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Section"],
    CellMargins->{{10, 4}, {12, 18}},
    ConversionRules:>{"HTML" -> {
      "<FONT SIZE=\"+2\" FACE=\"Helvetica, Arial\"><P><B>", 
      "</B></P></FONT>\n"}},
    InputAutoReplacements->{"TeX"->StyleBox[ 
            RowBox[ {"T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.074999999999999997, \
-0.085000000000000006}, {0, 0}}, BoxBaselineShift -> 0.5], "X"}]], 
        "LaTeX"->StyleBox[ 
            RowBox[ {"L", 
              StyleBox[ 
                AdjustmentBox[ 
                "A", BoxMargins -> {{-0.35999999999999999, \
-0.10000000000000001}, {0, 0}}, BoxBaselineShift -> -0.20000000000000001], 
                FontSize -> Smaller], "T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.074999999999999997, \
-0.085000000000000006}, {0, 0}}, BoxBaselineShift -> 0.5], "X"}]], 
        "mma"->"Mathematica", "Mma"->"Mathematica", "MMA"->"Mathematica"},
    FontFamily->"Helvetica",
    FontSize->20,
    FontWeight->"Bold"],
  
  Cell[StyleData["Section", "Printout"],
    CellMargins->{{2, 0}, {0, 18}},
    PageBreakBelow->False,
    FontSize->18]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Subsection"],
    CellDingbat->"\[FilledSquare]",
    CellMargins->{{24, 4}, {0, 18}},
    CellElementSpacings->{"ClosedGroupTopMargin"->18},
    ConversionRules:>{"HTML" -> {
      "<LI TYPE=\"SQUARE\"><FONT SIZE=\"+1\" FACE=\"Helvetica, \
Arial\"><P><B>", "</B></P></FONT>\n"}},
    CellFrameLabelMargins->6,
    InputAutoReplacements->{"TeX"->StyleBox[ 
            RowBox[ {"T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.074999999999999997, \
-0.085000000000000006}, {0, 0}}, BoxBaselineShift -> 0.5], "X"}]], 
        "LaTeX"->StyleBox[ 
            RowBox[ {"L", 
              StyleBox[ 
                AdjustmentBox[ 
                "A", BoxMargins -> {{-0.35999999999999999, \
-0.10000000000000001}, {0, 0}}, BoxBaselineShift -> -0.20000000000000001], 
                FontSize -> Smaller], "T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.074999999999999997, \
-0.085000000000000006}, {0, 0}}, BoxBaselineShift -> 0.5], "X"}]], 
        "mma"->"Mathematica", "Mma"->"Mathematica", "MMA"->"Mathematica"},
    FontFamily->"Helvetica",
    FontSize->16,
    FontWeight->"Bold"],
  
  Cell[StyleData["Subsection", "Printout"],
    CellMargins->{{16, 0}, {0, 18}},
    PageBreakBelow->False,
    FontSize->14]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Subsubsection"],
    CellMargins->{{10, 4}, {0, 18}},
    CellElementSpacings->{"ClosedGroupTopMargin"->18},
    ConversionRules:>{"HTML" -> {"<FONT FACE=\"Helvetica, Arial\"><P><B>", 
      "</B></P></FONT>\n"}},
    InputAutoReplacements->{"TeX"->StyleBox[ 
            RowBox[ {"T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.074999999999999997, \
-0.085000000000000006}, {0, 0}}, BoxBaselineShift -> 0.5], "X"}]], 
        "LaTeX"->StyleBox[ 
            RowBox[ {"L", 
              StyleBox[ 
                AdjustmentBox[ 
                "A", BoxMargins -> {{-0.35999999999999999, \
-0.10000000000000001}, {0, 0}}, BoxBaselineShift -> -0.20000000000000001], 
                FontSize -> Smaller], "T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.074999999999999997, \
-0.085000000000000006}, {0, 0}}, BoxBaselineShift -> 0.5], "X"}]], 
        "mma"->"Mathematica", "Mma"->"Mathematica", "MMA"->"Mathematica"},
    FontFamily->"Helvetica",
    FontSize->12,
    FontWeight->"Bold"],
  
  Cell[StyleData["Subsubsection", "Printout"],
    CellMargins->{{2, 0}, {0, 18}},
    PageBreakBelow->False,
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["SubsubsectionColor"],
    CellMargins->{{10, 4}, {0, 18}},
    CellElementSpacings->{"ClosedGroupTopMargin"->18},
    ConversionRules:>{"HTML" -> {
      "<FONT FACE=\"Helvetica, Arial\" COLOR=\"660099\"><P><B>", 
      "</B></P></FONT>\n"}},
    InputAutoReplacements->{"TeX"->StyleBox[ 
            RowBox[ {"T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.074999999999999997, \
-0.085000000000000006}, {0, 0}}, BoxBaselineShift -> 0.5], "X"}]], 
        "LaTeX"->StyleBox[ 
            RowBox[ {"L", 
              StyleBox[ 
                AdjustmentBox[ 
                "A", BoxMargins -> {{-0.35999999999999999, \
-0.10000000000000001}, {0, 0}}, BoxBaselineShift -> -0.20000000000000001], 
                FontSize -> Smaller], "T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.074999999999999997, \
-0.085000000000000006}, {0, 0}}, BoxBaselineShift -> 0.5], "X"}]], 
        "mma"->"Mathematica", "Mma"->"Mathematica", "MMA"->"Mathematica"},
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->12,
    FontWeight->"Bold",
    FontColor->RGBColor[0.297993, 0, 0.454994]],
  
  Cell[StyleData["SubsubsectionColor", "Printout"],
    CellMargins->{{2, 0}, {0, 18}},
    PageBreakBelow->False,
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["SubsectionIcon"],
    ShowGroupOpenCloseIcon->True,
    CellMargins->{{24, 4}, {0, 18}},
    CellElementSpacings->{"ClosedGroupTopMargin"->8},
    CellGroupingRules->{"SectionGrouping", 50},
    ConversionRules:>{"HTML" -> {
      "<LI TYPE=\"SQUARE\"><FONT FACE=\"Helvetica, Arial\"><P><B>", 
      "</B></P></FONT>\n"}},
    InputAutoReplacements->{"TeX"->StyleBox[ 
            RowBox[ {"T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.074999999999999997, \
-0.085000000000000006}, {0, 0}}, BoxBaselineShift -> 0.5], "X"}]], 
        "LaTeX"->StyleBox[ 
            RowBox[ {"L", 
              StyleBox[ 
                AdjustmentBox[ 
                "A", BoxMargins -> {{-0.35999999999999999, \
-0.10000000000000001}, {0, 0}}, BoxBaselineShift -> -0.20000000000000001], 
                FontSize -> Smaller], "T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.074999999999999997, \
-0.085000000000000006}, {0, 0}}, BoxBaselineShift -> 0.5], "X"}]], 
        "mma"->"Mathematica", "Mma"->"Mathematica", "MMA"->"Mathematica"},
    CounterIncrements->"Section",
    FontFamily->"Helvetica",
    FontSize->16,
    FontWeight->"Bold"],
  
  Cell[StyleData["SubsectionIcon", "Printout"],
    CellDingbat->"\[FilledSquare]",
    ShowGroupOpenCloseIcon->False,
    CellMargins->{{16, 0}, {0, 18}},
    PageBreakBelow->False,
    FontSize->14]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["SubsubsectionIcon"],
    ShowGroupOpenCloseIcon->True,
    CellMargins->{{24, 4}, {0, 8}},
    CellElementSpacings->{"ClosedGroupTopMargin"->4},
    CellGroupingRules->{"SectionGrouping", 60},
    ConversionRules:>{"HTML" -> {
      "<LI TYPE=\"SQUARE\"><FONT FACE=\"Helvetica, Arial\"><P><B>", 
      "</B></P></FONT>\n"}},
    InputAutoReplacements->{"TeX"->StyleBox[ 
            RowBox[ {"T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.074999999999999997, \
-0.085000000000000006}, {0, 0}}, BoxBaselineShift -> 0.5], "X"}]], 
        "LaTeX"->StyleBox[ 
            RowBox[ {"L", 
              StyleBox[ 
                AdjustmentBox[ 
                "A", BoxMargins -> {{-0.35999999999999999, \
-0.10000000000000001}, {0, 0}}, BoxBaselineShift -> -0.20000000000000001], 
                FontSize -> Smaller], "T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.074999999999999997, \
-0.085000000000000006}, {0, 0}}, BoxBaselineShift -> 0.5], "X"}]], 
        "mma"->"Mathematica", "Mma"->"Mathematica", "MMA"->"Mathematica"},
    CounterIncrements->"Subsection",
    CounterAssignments->{{"Subsubection", 0}},
    FontFamily->"Helvetica",
    FontSize->12,
    FontWeight->"Bold"],
  
  Cell[StyleData["SubsubsectionIcon", "Printout"],
    ShowGroupOpenCloseIcon->False,
    CellMargins->{{2, 0}, {0, 18}},
    PageBreakBelow->False,
    FontSize->10]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Text", "Subsubsection"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Text"],
    CellMargins->{{10, 4}, {0, 8}},
    ConversionRules:>{"HTML" -> {"<P>", "</P>"}},
    CellHorizontalScrolling->True,
    InputAutoReplacements->{"TeX"->StyleBox[ 
            RowBox[ {"T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.074999999999999997, \
-0.085000000000000006}, {0, 0}}, BoxBaselineShift -> 0.5], "X"}]], 
        "LaTeX"->StyleBox[ 
            RowBox[ {"L", 
              StyleBox[ 
                AdjustmentBox[ 
                "A", BoxMargins -> {{-0.35999999999999999, \
-0.10000000000000001}, {0, 0}}, BoxBaselineShift -> -0.20000000000000001], 
                FontSize -> Smaller], "T", 
              AdjustmentBox[ 
              "E", 
                BoxMargins -> {{-0.074999999999999997, \
-0.085000000000000006}, {0, 0}}, BoxBaselineShift -> 0.5], "X"}]], 
        "mma"->"Mathematica", "Mma"->"Mathematica", "MMA"->"Mathematica"},
    Hyphenation->True,
    ParagraphSpacing->{0, 8}],
  
  Cell[StyleData["Text", "Printout"],
    CellMargins->{{2, 0}, {0, 8}},
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["CompactText"],
    CellMargins->{{10, 4}, {0, 8}},
    ConversionRules:>{"HTML" -> {"<FONT SIZE=\"-1\">", "</FONT>\n"}},
    Hyphenation->True,
    ParagraphSpacing->{0, 0},
    StyleMenuListing->None,
    FontSize->10],
  
  Cell[StyleData["CompactText", "Printout"],
    CellMargins->{{2, 0}, {0, 8}},
    FontSize->8]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Compact12Text"],
    CellMargins->{{10, 4}, {0, 8}},
    ConversionRules:>{"HTML" -> {"<P>", "</P>"}},
    Hyphenation->True,
    ParagraphSpacing->{0, 0},
    StyleMenuListing->None],
  
  Cell[StyleData["Compact12Text", "Printout"],
    CellMargins->{{2, 0}, {0, 8}},
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["TextSans"],
    CellMargins->{{10, 4}, {0, 8}},
    ConversionRules:>{"HTML" -> {
      "<FONT SIZE=\"-1\" FACE=\"Helvetica, Arial\">", "</FONT>\n"}},
    CellHorizontalScrolling->True,
    Hyphenation->True,
    ParagraphSpacing->{0, 8},
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->10],
  
  Cell[StyleData["TextSans", "Printout"],
    CellMargins->{{2, 0}, {0, 8}},
    FontSize->8]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["ItemizedText"],
    CellMargins->{{20, 4}, {0, 8}},
    ConversionRules:>{"HTML" -> {"<BLOCKQUOTE>", "</BLOCKQUOTE>"}},
    Hyphenation->True,
    ParagraphSpacing->{0, 8},
    ParagraphIndent->-15,
    StyleMenuListing->None],
  
  Cell[StyleData["ItemizedText", "Printout"],
    CellMargins->{{12, 0}, {0, 8}},
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["ItemizedTextNote"],
    CellMargins->{{35, 4}, {0, 4}},
    ConversionRules:>{"HTML" -> {"<BLOCKQUOTE>", "</BLOCKQUOTE>"}},
    Hyphenation->True,
    ParagraphSpacing->{0, 8},
    StyleMenuListing->None],
  
  Cell[StyleData["ItemizedTextNote", "Printout"],
    CellMargins->{{27, 0}, {0, 4}},
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["IndentedText"],
    CellMargins->{{20, 4}, {0, 6}},
    ConversionRules:>{"HTML" -> {"<BLOCKQUOTE>", "</BLOCKQUOTE>"}},
    Hyphenation->True,
    ParagraphSpacing->{0, 8},
    StyleMenuListing->None],
  
  Cell[StyleData["IndentedText", "Printout"],
    CellMargins->{{12, 0}, {0, 6}},
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["MathCaption"],
    CellDingbat->"\[FilledSmallSquare]",
    CellMargins->{{19, 62}, {0, 14}},
    ConversionRules:>{"HTML" -> {
      "<LI TYPE=\"SQUARE\"><P><FONT COLOR=\"000066\">", "</FONT></P></LI>"}},
    PageBreakBelow->False,
    CellFrameLabelMargins->4,
    Hyphenation->True,
    LineSpacing->{1, 1},
    ParagraphSpacing->{0, 8},
    FontColor->RGBColor[0, 0, 0.4]],
  
  Cell[StyleData["MathCaption", "Printout"],
    CellMargins->{{9, 0}, {0, 14}},
    FontSize->9,
    FontColor->GrayLevel[0]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["SmallText"],
    CellMargins->{{10, 4}, {0, 8}},
    ConversionRules:>{"HTML" -> {"<FONT SIZE=\"1\"><P>", "</P></FONT>"}},
    Hyphenation->True,
    LineSpacing->{1, 3},
    ParagraphSpacing->{0.7, 0},
    CounterIncrements->"SmallText",
    FontSize->9],
  
  Cell[StyleData["SmallText", "Printout"],
    CellMargins->{{2, 0}, {0, 8}},
    TextJustification->1,
    FontSize->7]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Input/Output", "Subsubsection"],
  
  Cell["\<\
The cells in this section define styles used for input and output \
to the kernel.  Be careful when modifying, renaming, or removing these \
styles, because the front end associates special meanings with these style \
names.    \
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Input"],
    ShowCellBracket->True,
    CellMargins->{{46, 4}, {3, 8}},
    Evaluatable->True,
    CellGroupingRules->"InputGrouping",
    PageBreakWithin->False,
    GroupPageBreakWithin->False,
    CellLabelAutoDelete->False,
    CellLabelMargins->{{14, Inherited}, {Inherited, Inherited}},
    DefaultFormatType->DefaultInputFormatType,
    ShowSpecialCharacters->Automatic,
    HyphenationOptions->{"HyphenationCharacter"->"\[Continuation]"},
    LanguageCategory->"Formula",
    FormatType->StandardForm,
    ShowStringCharacters->True,
    NumberMarks->True,
    FontWeight->"Bold"],
  
  Cell[StyleData["Input", "Printout"],
    FontSize->9]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Output"],
    ShowCellBracket->True,
    CellMargins->{{47, 4}, {4, 2}},
    CellEditDuplicate->True,
    CellGroupingRules->"OutputGrouping",
    CellHorizontalScrolling->True,
    PageBreakWithin->False,
    GroupPageBreakWithin->False,
    GeneratedCell->True,
    CellAutoOverwrite->True,
    CellLabelAutoDelete->False,
    CellLabelMargins->{{14, Inherited}, {Inherited, Inherited}},
    DefaultFormatType->DefaultOutputFormatType,
    HyphenationOptions->{"HyphenationCharacter"->"\[Continuation]"},
    LanguageCategory->"Formula",
    FormatType->StandardForm],
  
  Cell[StyleData["Output", "Printout"],
    FontSize->9]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Message"],
    ShowCellBracket->True,
    CellMargins->{{47, 4}, {4, 2}},
    CellGroupingRules->"OutputGrouping",
    PageBreakWithin->False,
    GroupPageBreakWithin->False,
    GeneratedCell->True,
    CellAutoOverwrite->True,
    ShowCellLabel->False,
    CellLabelMargins->{{14, Inherited}, {Inherited, Inherited}},
    DefaultFormatType->DefaultOutputFormatType,
    HyphenationOptions->{"HyphenationCharacter"->"\[Continuation]"},
    FormatType->InputForm,
    StyleMenuListing->None,
    FontColor->RGBColor[0, 0, 1]],
  
  Cell[StyleData["Message", "Printout"],
    FontSize->9,
    FontColor->GrayLevel[0]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Print"],
    ShowCellBracket->True,
    CellMargins->{{47, 4}, {4, 2}},
    CellGroupingRules->"OutputGrouping",
    PageBreakWithin->False,
    GroupPageBreakWithin->False,
    GeneratedCell->True,
    CellAutoOverwrite->True,
    ShowCellLabel->False,
    CellLabelMargins->{{14, Inherited}, {Inherited, Inherited}},
    DefaultFormatType->DefaultOutputFormatType,
    HyphenationOptions->{"HyphenationCharacter"->"\[Continuation]"},
    FormatType->InputForm,
    StyleMenuListing->None],
  
  Cell[StyleData["Print", "Printout"],
    FontSize->9]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Graphics"],
    ShowCellBracket->True,
    CellMargins->{{47, 4}, {4, 2}},
    CellGroupingRules->"GraphicsGrouping",
    PageBreakWithin->False,
    GeneratedCell->True,
    CellAutoOverwrite->True,
    ShowCellLabel->False,
    DefaultFormatType->Utilities`Notation`Private`DefaultFormatTypeForOutput,
    FormatType->InputForm,
    StyleMenuListing->None,
    FontWeight->"Plain"],
  
  Cell[StyleData["Graphics", "Printout"],
    FontSize->9]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["CellLabel"],
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->9,
    FontWeight->"Plain",
    FontColor->RGBColor[0, 0, 1]],
  
  Cell[StyleData["CellLabel", "Printout"],
    FontFamily->"Courier",
    FontSize->7,
    FontSlant->"Italic",
    FontColor->GrayLevel[0]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Name"],
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->9,
    FontWeight->"Plain",
    FontSlant->"Italic",
    FontColor->RGBColor[0, 0, 1]],
  
  Cell[StyleData["Name", "Printout"],
    FontSize->7,
    FontColor->GrayLevel[0]]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Hyperlinks", "Subsubsection"],
  
  Cell["\<\
The cells below define styles useful for making hypertext \
ButtonBoxes.  The \"Hyperlink\" style is for links within the same Notebook, \
or between Notebooks. The others point to the various sections of the help \
browser. These styles will modify individual words or letters in a cell \
exclusive of the cell tag.\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Hyperlink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontColor->RGBColor[0, 0, 1],
    FontVariations->{"Underline"->True},
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`NotebookLocate[ #2]}]&),
    Active->True,
    ButtonFrame->"None",
    ButtonNote->ButtonData}],
  
  Cell[StyleData["Hyperlink", "Printout"],
    FontSize->10,
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["MainBookLink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontColor->RGBColor[0, 0, 1],
    FontVariations->{"Underline"->True},
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`HelpBrowserLookup[ "MainBook", #]}]&),
    Active->True,
    ButtonFrame->"None"}],
  
  Cell[StyleData["MainBookLink", "Printout"],
    FontSize->10,
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["MainBookLinkMR"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontFamily->"Courier",
    FontColor->RGBColor[0, 0, 1],
    FontVariations->{"Underline"->True},
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`HelpBrowserLookup[ "MainBook", #]}]&),
    Active->True,
    ButtonFrame->"None"}],
  
  Cell[StyleData["MainBookLinkMR", "Printout"],
    FontSize->10,
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["AddOnsLink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontFamily->"Courier",
    FontColor->RGBColor[0, 0, 1],
    FontVariations->{"Underline"->True},
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`HelpBrowserLookup[ "AddOns", #]}]&),
    Active->True,
    ButtonFrame->"None"}],
  
  Cell[StyleData["AddOnLink", "Printout"],
    FontSize->10,
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["RefGuideLink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontFamily->"Courier",
    FontColor->RGBColor[0, 0, 1],
    FontVariations->{"Underline"->True},
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`HelpBrowserLookup[ "RefGuideLink", #]}]&),
    Active->True,
    ButtonFrame->"None"}],
  
  Cell[StyleData["RefGuideLink", "Printout"],
    FontSize->10,
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["GettingStartedLink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontColor->RGBColor[0, 0, 1],
    FontVariations->{"Underline"->True},
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`HelpBrowserLookup[ "GettingStarted", #]}]&),
    Active->True,
    ButtonFrame->"None"}],
  
  Cell[StyleData["GettingStartedLink", "Printout"],
    FontSize->10,
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["OtherInformationLink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontColor->RGBColor[0, 0, 1],
    FontVariations->{"Underline"->True},
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`HelpBrowserLookup[ "OtherInformation", #]}]&),
    Active->True,
    ButtonFrame->"None"}],
  
  Cell[StyleData["OtherInformationLink", "Printout"],
    FontSize->10,
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["OtherInformationLinkMR"],
    StyleMenuListing->None,
    FontFamily->"Courier",
    FontColor->RGBColor[0, 0, 1],
    FontVariations->{"Underline"->True},
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`HelpBrowserLookup[ "OtherInformation", #]}]&),
    Active->True,
    ButtonFrame->"None"}],
  
  Cell[StyleData["OtherInformationLinkMR", "Printout"],
    FontSize->10,
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Palette Styles", "Subsubsection"],
  
  Cell["\<\
The cells below define styles that define standard \
ButtonFunctions, for use in palette buttons.\
\>", "Text"],
  
  Cell[StyleData["Paste"],
    StyleMenuListing->Automatic,
    ButtonStyleMenuListing->Automatic,
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`NotebookApply[ 
          FrontEnd`InputNotebook[ ], #, After]}]&)}],
  
  Cell[StyleData["Evaluate"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`NotebookApply[ 
          FrontEnd`InputNotebook[ ], #, All], 
        SelectionEvaluate[ 
          FrontEnd`InputNotebook[ ], All]}]&)}],
  
  Cell[StyleData["EvaluateCell"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`NotebookApply[ 
          FrontEnd`InputNotebook[ ], #, All], 
        FrontEnd`SelectionMove[ 
          FrontEnd`InputNotebook[ ], All, Cell, 1], 
        FrontEnd`SelectionEvaluateCreateCell[ 
          FrontEnd`InputNotebook[ ], All]}]&)}],
  
  Cell[StyleData["CopyEvaluate"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`SelectionCreateCell[ 
          FrontEnd`InputNotebook[ ], All], 
        FrontEnd`NotebookApply[ 
          FrontEnd`InputNotebook[ ], #, All], 
        FrontEnd`SelectionEvaluate[ 
          FrontEnd`InputNotebook[ ], All]}]&)}],
  
  Cell[StyleData["CopyEvaluateCell"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`SelectionCreateCell[ 
          FrontEnd`InputNotebook[ ], All], 
        FrontEnd`NotebookApply[ 
          FrontEnd`InputNotebook[ ], #, All], 
        FrontEnd`SelectionEvaluateCreateCell[ 
          FrontEnd`InputNotebook[ ], All]}]&)}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Inline Formatting", "Subsubsection"],
  
  Cell["\<\
These styles are for modifying individual words or letters in a \
cell exclusive of the cell tag.\
\>", "Text"],
  
  Cell[StyleData["JT"],
    StyleMenuListing->None,
    FontFamily->"JFontText"],
  
  Cell[StyleData["JS"],
    StyleMenuListing->None,
    FontFamily->"JFontSans"],
  
  Cell[StyleData["JSB"],
    StyleMenuListing->None,
    FontFamily->"JFontSansBold"],
  
  Cell[StyleData["RM"],
    StyleMenuListing->None,
    FontWeight->"Plain",
    FontSlant->"Plain"],
  
  Cell[StyleData["BF"],
    StyleMenuListing->None,
    FontWeight->"Bold"],
  
  Cell[StyleData["IT"],
    StyleMenuListing->None,
    FontSlant->"Italic"],
  
  Cell[StyleData["TR"],
    StyleMenuListing->None,
    FontFamily->"Times",
    FontWeight->"Plain",
    FontSlant->"Plain"],
  
  Cell[StyleData["TI"],
    StyleMenuListing->None,
    FontFamily->"Times",
    FontWeight->"Plain",
    FontSlant->"Italic"],
  
  Cell[StyleData["TB"],
    StyleMenuListing->None,
    FontFamily->"Times",
    FontWeight->"Bold",
    FontSlant->"Plain"],
  
  Cell[StyleData["TBI"],
    StyleMenuListing->None,
    FontFamily->"Times",
    FontWeight->"Bold",
    FontSlant->"Italic"],
  
  Cell[StyleData["MR"],
    StyleMenuListing->None,
    FontFamily->"Courier",
    FontWeight->"Plain",
    FontSlant->"Plain"],
  
  Cell[StyleData["MO"],
    StyleMenuListing->None,
    FontFamily->"Courier",
    FontWeight->"Plain",
    FontSlant->"Italic"],
  
  Cell[StyleData["MB"],
    StyleMenuListing->None,
    FontFamily->"Courier",
    FontWeight->"Bold",
    FontSlant->"Plain"],
  
  Cell[StyleData["MBO"],
    StyleMenuListing->None,
    FontFamily->"Courier",
    FontWeight->"Bold",
    FontSlant->"Italic"],
  
  Cell[StyleData["SR"],
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontWeight->"Plain",
    FontSlant->"Plain"],
  
  Cell[StyleData["SO"],
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontWeight->"Plain",
    FontSlant->"Italic"],
  
  Cell[StyleData["SB"],
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontWeight->"Bold",
    FontSlant->"Plain"],
  
  Cell[StyleData["SBO"],
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontWeight->"Bold",
    FontSlant->"Italic"],
  
  Cell[StyleData["M4"],
    ShowCellBracket->True,
    StyleMenuListing->None,
    FontFamily->"Math4",
    CharacterEncoding->"Math4"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["SO10"],
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->10,
    FontWeight->"Plain",
    FontSlant->"Italic"],
  
  Cell[StyleData["SO10", "Printout"],
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->7,
    FontWeight->"Plain",
    FontSlant->"Italic"]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["C1"],
    StyleMenuListing->None,
    FontColor->RGBColor[0.4, 0, 1]],
  
  Cell[StyleData["C1", "Printout"],
    FontColor->GrayLevel[0]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["C1MR"],
    StyleMenuListing->None,
    FontFamily->"Courier",
    FontColor->RGBColor[0.4, 0, 1]],
  
  Cell[StyleData["C1MR", "Printout"],
    FontColor->GrayLevel[0]]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Emphasis Boxes and Pictures", "Subsubsection"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Box"],
    CellMargins->{{10, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    StyleMenuListing->None,
    Background->RGBColor[1, 0.6, 0.6],
    FrameBoxOptions->{BoxMargins->{{1, 1}, {1.5, 1.5}}},
    GridBoxOptions->{ColumnSpacings->1}],
  
  Cell[StyleData["Box", "Printout"],
    CellMargins->{{2, 0}, {0, 8}},
    FontSize->10,
    Background->GrayLevel[0.900008]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["DoubleBox"],
    CellMargins->{{10, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    StyleMenuListing->None,
    Background->RGBColor[1, 0.6, 0.6],
    FrameBoxOptions->{BoxMargins->{{1, 1}, {1.5, 1.5}}},
    GridBoxOptions->{ColumnSpacings->2,
    RowAlignments->Top}],
  
  Cell[StyleData["DoubleBox", "Printout"],
    CellMargins->{{2, 0}, {0, 8}},
    FontSize->10,
    Background->GrayLevel[0.900008]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["1ColumnBox"],
    CellMargins->{{10, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    LineIndent->0,
    StyleMenuListing->None,
    Background->RGBColor[1, 0.6, 0.6],
    FrameBoxOptions->{BoxMargins->{{1, 1}, {1.5, 1.5}}},
    GridBoxOptions->{ColumnSpacings->1}],
  
  Cell[StyleData["1ColumnBox", "Printout"],
    CellMargins->{{2, 0}, {0, 8}},
    FontSize->10,
    Background->GrayLevel[0.900008]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["2ColumnBox"],
    CellMargins->{{10, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    LineIndent->0,
    StyleMenuListing->None,
    Background->RGBColor[1, 0.6, 0.6],
    FrameBoxOptions->{BoxMargins->{{1, 1}, {1.5, 1.5}}},
    GridBoxOptions->{ColumnWidths->{0.31, 0.62}}],
  
  Cell[StyleData["2ColumnBox", "Printout"],
    CellMargins->{{2, 0}, {0, 8}},
    FontSize->10,
    Background->GrayLevel[0.900008]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["2ColumnEvenBox"],
    CellMargins->{{10, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    LineIndent->0,
    StyleMenuListing->None,
    Background->RGBColor[1, 0.6, 0.6],
    FrameBoxOptions->{BoxMargins->{{1, 1}, {1.5, 1.5}}},
    GridBoxOptions->{ColumnWidths->0.46}],
  
  Cell[StyleData["2ColumnEvenBox", "Printout"],
    CellMargins->{{2, 0}, {0, 8}},
    FontSize->10,
    Background->GrayLevel[0.900008]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["2ColumnSmallBox"],
    CellMargins->{{10, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    LineIndent->0,
    StyleMenuListing->None,
    Background->RGBColor[1, 0.6, 0.6],
    FrameBoxOptions->{BoxMargins->{{1, 1}, {1.5, 1.5}}},
    GridBoxOptions->{ColumnSpacings->1.5,
    ColumnWidths->0.35,
    ColumnAlignments->{Right, Left}}],
  
  Cell[StyleData["2ColumnSmallBox", "Printout"],
    CellMargins->{{2, 0}, {0, 8}},
    FontSize->10,
    Background->GrayLevel[0.900008]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["3ColumnBox"],
    CellMargins->{{10, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    LineIndent->0,
    StyleMenuListing->None,
    Background->RGBColor[1, 0.6, 0.6],
    FrameBoxOptions->{BoxMargins->{{1, 1}, {1.5, 1.5}}},
    GridBoxOptions->{ColumnWidths->0.31}],
  
  Cell[StyleData["3ColumnBox", "Printout"],
    CellMargins->{{2, 0}, {0, 8}},
    FontSize->10,
    Background->GrayLevel[0.900008]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["3ColumnSmallBox"],
    CellMargins->{{10, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    LineIndent->0,
    StyleMenuListing->None,
    Background->RGBColor[1, 0.6, 0.6],
    FrameBoxOptions->{BoxMargins->{{1, 1}, {1.5, 1.5}}},
    GridBoxOptions->{ColumnSpacings->1.5,
    ColumnWidths->0.24,
    ColumnAlignments->{Right, Center, Left}}],
  
  Cell[StyleData["3ColumnSmallBox", "Printout"],
    CellMargins->{{2, 0}, {0, 8}},
    FontSize->10,
    Background->GrayLevel[0.900008]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["4ColumnBox"],
    CellMargins->{{10, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    LineIndent->0,
    StyleMenuListing->None,
    Background->RGBColor[1, 0.6, 0.6],
    FrameBoxOptions->{BoxMargins->{{1, 1}, {1.5, 1.5}}},
    GridBoxOptions->{ColumnWidths->{0.13, 0.33, 0.13, 0.33}}],
  
  Cell[StyleData["4ColumnBox", "Printout"],
    CellMargins->{{2, 0}, {0, 8}},
    FontSize->10,
    Background->GrayLevel[0.900008]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["5ColumnBox"],
    CellMargins->{{10, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    LineIndent->0,
    StyleMenuListing->None,
    Background->RGBColor[1, 0.6, 0.6],
    FrameBoxOptions->{BoxMargins->{{1, 1}, {1.5, 1.5}}},
    GridBoxOptions->{ColumnWidths->0.194}],
  
  Cell[StyleData["5ColumnBox", "Printout"],
    CellMargins->{{2, 0}, {0, 8}},
    FontSize->10,
    Background->GrayLevel[0.900008]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["6ColumnBox"],
    CellMargins->{{10, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    LineIndent->0,
    StyleMenuListing->None,
    Background->RGBColor[1, 0.6, 0.6],
    FrameBoxOptions->{BoxMargins->{{1, 1}, {1.5, 1.5}}},
    GridBoxOptions->{ColumnWidths->{0.12, 0.22, 0.12, 0.12, 0.22, 0.12}}],
  
  Cell[StyleData["6ColumnBox", "Printout"],
    CellMargins->{{2, 0}, {0, 8}},
    FontSize->10,
    Background->GrayLevel[0.900008]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["ItemizedNoteBox"],
    CellFrame->0.5,
    CellMargins->{{37, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    LineIndent->0,
    StyleMenuListing->None,
    Background->RGBColor[1, 0.6, 0.6],
    FrameBoxOptions->{BoxMargins->{{1, 1}, {1.5, 1.5}}},
    GridBoxOptions->{ColumnSpacings->1}],
  
  Cell[StyleData["ItemizedNoteBox", "Printout"],
    FontSize->10,
    Background->GrayLevel[0.900008]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["DefinitionBox"],
    CellFrame->0.5,
    CellMargins->{{10, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    AutoIndent->False,
    AutoSpacing->False,
    LineIndent->0,
    FontWeight->"Plain",
    Background->RGBColor[1, 0.6, 0.6],
    GridBoxOptions->{RowSpacings->1.5,
    ColumnSpacings->1,
    ColumnWidths->{0.4, 0.6},
    ColumnAlignments->{Left}}],
  
  Cell[StyleData["DefinitionBox", "Printout"],
    CellMargins->{{2, 4}, {0, 8}},
    FontSize->10,
    Background->GrayLevel[0.900008]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["DefinitionBox3Col"],
    CellFrame->0.5,
    CellMargins->{{10, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    AutoIndent->False,
    AutoSpacing->False,
    LineIndent->0,
    FontWeight->"Plain",
    Background->RGBColor[1, 0.6, 0.6],
    GridBoxOptions->{RowSpacings->1.5,
    ColumnSpacings->1,
    ColumnWidths->{0.35, 0.2, 0.45},
    ColumnAlignments->{Left}}],
  
  Cell[StyleData["DefinitionBox3Col", "Printout"],
    CellMargins->{{2, 4}, {0, 8}},
    FontSize->10,
    Background->GrayLevel[0.900008]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["DefinitionBox4Col"],
    CellFrame->0.5,
    CellMargins->{{10, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    AutoIndent->False,
    AutoSpacing->False,
    LineIndent->0,
    FontWeight->"Plain",
    Background->RGBColor[1, 0.6, 0.6],
    GridBoxOptions->{RowSpacings->1.5,
    ColumnSpacings->1,
    ColumnWidths->{0.15, 0.35, 0.15, 0.35},
    ColumnAlignments->{Left}}],
  
  Cell[StyleData["DefinitionBox4Col", "Printout"],
    CellMargins->{{2, 4}, {0, 8}},
    FontSize->10,
    Background->GrayLevel[0.900008]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["DefinitionBox5Col"],
    CellFrame->0.5,
    CellMargins->{{10, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    AutoIndent->False,
    AutoSpacing->False,
    LineIndent->0,
    FontWeight->"Plain",
    Background->RGBColor[1, 0.6, 0.6],
    GridBoxOptions->{RowSpacings->1.5,
    ColumnSpacings->1,
    ColumnWidths->0.2,
    ColumnAlignments->{Left}}],
  
  Cell[StyleData["DefinitionBox5Col", "Printout"],
    CellMargins->{{2, 4}, {0, 8}},
    FontSize->10,
    Background->GrayLevel[0.900008]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["DefinitionBox6Col"],
    CellFrame->0.5,
    CellMargins->{{10, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    AutoIndent->False,
    AutoSpacing->False,
    LineIndent->0,
    FontWeight->"Plain",
    Background->RGBColor[1, 0.6, 0.6],
    GridBoxOptions->{RowSpacings->1.5,
    ColumnSpacings->1,
    ColumnWidths->{0.13, 0.24, 0.13, 0.13, 0.24, 0.13},
    ColumnAlignments->{Left}}],
  
  Cell[StyleData["DefinitionBox6Col", "Printout"],
    CellMargins->{{2, 4}, {0, 8}},
    FontSize->10,
    Background->GrayLevel[0.900008]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["TopBox"],
    CellFrame->{{0.5, 0.5}, {0, 0.5}},
    CellMargins->{{11, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    PageBreakBelow->False,
    AutoIndent->False,
    AutoSpacing->False,
    LineIndent->0,
    StyleMenuListing->None,
    FontWeight->"Plain",
    Background->RGBColor[1, 0.6, 0.6],
    GridBoxOptions->{RowSpacings->1.5,
    ColumnSpacings->1,
    ColumnWidths->{0.31, 0.62},
    ColumnAlignments->{Left}}],
  
  Cell[StyleData["TopBox", "Printout"],
    CellMargins->{{2, 0}, {0, 8}},
    FontSize->10,
    Background->GrayLevel[0.900008]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["MiddleBox"],
    CellFrame->{{0.5, 0.5}, {0, 0}},
    CellMargins->{{11, 4}, {0, -7}},
    CellHorizontalScrolling->True,
    PageBreakBelow->False,
    AutoIndent->False,
    AutoSpacing->False,
    LineIndent->0,
    StyleMenuListing->None,
    FontWeight->"Plain",
    Background->RGBColor[1, 0.6, 0.6],
    GridBoxOptions->{RowSpacings->1.5,
    ColumnSpacings->1,
    ColumnWidths->{0.31, 0.62},
    ColumnAlignments->{Left}}],
  
  Cell[StyleData["MiddleBox", "Printout"],
    CellMargins->{{2, 0}, {0, 0}},
    FontSize->10,
    Background->GrayLevel[0.900008]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["BottomBox"],
    CellFrame->{{0.5, 0.5}, {0.5, 0}},
    CellMargins->{{11, 4}, {0, -7}},
    CellHorizontalScrolling->True,
    PageBreakBelow->False,
    AutoIndent->False,
    AutoSpacing->False,
    LineIndent->0,
    StyleMenuListing->None,
    FontWeight->"Plain",
    Background->RGBColor[1, 0.6, 0.6],
    GridBoxOptions->{RowSpacings->1.5,
    ColumnSpacings->1,
    ColumnWidths->{0.31, 0.62},
    ColumnAlignments->{Left}}],
  
  Cell[StyleData["BottomBox", "Printout"],
    CellMargins->{{2, 4}, {0, 0}},
    FontSize->10,
    Background->GrayLevel[0.900008]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["TopSpanBox"],
    CellFrame->{{0.5, 0.5}, {0, 0.5}},
    CellMargins->{{11, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    PageBreakBelow->False,
    AutoIndent->False,
    AutoSpacing->False,
    LineIndent->0,
    StyleMenuListing->None,
    FontWeight->"Plain",
    Background->RGBColor[1, 0.6, 0.6],
    GridBoxOptions->{RowSpacings->1.5,
    ColumnSpacings->1,
    ColumnWidths->{0.9, 0.03},
    ColumnAlignments->{Left}}],
  
  Cell[StyleData["TopSpanBox", "Printout"],
    CellMargins->{{2, 0}, {0, 8}},
    FontSize->10,
    Background->GrayLevel[0.900008]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["MiddleSpanBox"],
    CellFrame->{{0.5, 0.5}, {0, 0}},
    CellMargins->{{11, 4}, {0, 0}},
    CellHorizontalScrolling->True,
    PageBreakBelow->False,
    AutoIndent->False,
    AutoSpacing->False,
    LineIndent->0,
    StyleMenuListing->None,
    FontWeight->"Plain",
    Background->RGBColor[1, 0.6, 0.6],
    GridBoxOptions->{RowSpacings->1.5,
    ColumnSpacings->1,
    ColumnWidths->{0.9, 0.03},
    ColumnAlignments->{Left}}],
  
  Cell[StyleData["MiddleSpanBox", "Printout"],
    CellMargins->{{2, 4}, {0, 8}},
    FontSize->10,
    Background->GrayLevel[0.900008]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Picture"],
    CellMargins->{{10, Inherited}, {0, 8}},
    CellHorizontalScrolling->True,
    StyleMenuListing->None],
  
  Cell[StyleData["Picture", "Printout"],
    CellMargins->{{2, 0}, {0, 8}}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["ItemizedPicture"],
    CellMargins->{{35, 4}, {0, 4}},
    CellGroupingRules->"GraphicsGrouping",
    CellHorizontalScrolling->True,
    StyleMenuListing->None],
  
  Cell[StyleData["ItemizedPicture", "Printout"],
    CellMargins->{{27, 0}, {0, 4}},
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["PictureGroup"],
    CellMargins->{{10, Inherited}, {0, 8}},
    CellGroupingRules->"GraphicsGrouping",
    CellHorizontalScrolling->True,
    StyleMenuListing->None],
  
  Cell[StyleData["PictureGroup", "Printout"],
    CellMargins->{{2, 0}, {0, 8}},
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Sound"],
    ShowCellBracket->True,
    CellMargins->{{10, Inherited}, {0, 8}},
    StyleMenuListing->None],
  
  Cell[StyleData["Sound", "Printout"],
    CellMargins->{{2, 0}, {0, 8}},
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Caption"],
    CellMargins->{{10, 4}, {0, 3}},
    PageBreakAbove->False,
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->9],
  
  Cell[StyleData["Caption", "Printout"],
    CellMargins->{{2, 0}, {0, 3}},
    FontSize->7]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Tables", "Subsubsection"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["2ColumnTable"],
    CellMargins->{{10, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    LineIndent->0,
    StyleMenuListing->None,
    GridBoxOptions->{ColumnWidths->{0.34, 0.64},
    ColumnAlignments->{Left}}],
  
  Cell[StyleData["2ColumnTable", "Printout"],
    CellMargins->{{2, 0}, {0, 8}},
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["2ColumnEvenTable"],
    CellMargins->{{10, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    LineIndent->0,
    StyleMenuListing->None,
    GridBoxOptions->{ColumnWidths->0.49,
    ColumnAlignments->{Left}}],
  
  Cell[StyleData["2ColumnEvenTable", "Printout"],
    CellMargins->{{2, 0}, {0, 8}},
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["3ColumnTable"],
    CellMargins->{{10, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    LineIndent->0,
    StyleMenuListing->None,
    GridBoxOptions->{ColumnWidths->{0.28, 0.28, 0.43},
    ColumnAlignments->{Left}}],
  
  Cell[StyleData["3ColumnTable", "Printout"],
    CellMargins->{{2, 0}, {0, 8}},
    FontSize->10]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Formulas and Programming", "Subsubsection"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["InlineFormula"],
    CellMargins->{{10, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    HyphenationOptions->{"HyphenationCharacter"->"\[Continuation]"},
    ScriptLevel->1,
    SingleLetterItalics->True,
    SpanMaxSize->Infinity,
    StyleMenuListing->None,
    GridBoxOptions->{ColumnWidths->Automatic}],
  
  Cell[StyleData["InlineFormula", "Printout"],
    CellMargins->{{2, 0}, {0, 8}},
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["InlineOutput"],
    CellMargins->{{10, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    HyphenationOptions->{"HyphenationCharacter"->"\[Continuation]"},
    StyleMenuListing->None,
    FontFamily->"Courier"],
  
  Cell[StyleData["InlineOutput", "Printout"],
    CellMargins->{{2, 0}, {0, 8}},
    FontSize->9.5]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["DisplayFormula"],
    CellMargins->{{42, Inherited}, {Inherited, 10}},
    CellHorizontalScrolling->True,
    HyphenationOptions->{"HyphenationCharacter"->"\[Continuation]"},
    LanguageCategory->"Formula",
    ScriptLevel->0,
    SingleLetterItalics->True,
    SpanMaxSize->Infinity,
    StyleMenuListing->None,
    UnderoverscriptBoxOptions->{LimitsPositioning->True},
    GridBoxOptions->{ColumnWidths->Automatic}],
  
  Cell[StyleData["DisplayFormula", "Printout"],
    CellMargins->{{34, Inherited}, {Inherited, 10}},
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["DisplayMath"],
    CellMargins->{{42, 10}, {7, 7}},
    Evaluatable->False,
    CellGroupingRules->"InputGrouping",
    CellHorizontalScrolling->True,
    PageBreakWithin->False,
    GroupPageBreakWithin->False,
    DefaultFormatType->DefaultInputFormatType,
    HyphenationOptions->{"HyphenationCharacter"->"\[Continuation]"},
    AutoItalicWords->{},
    LanguageCategory->"Formula",
    FormatType->InputForm,
    ShowStringCharacters->True,
    NumberMarks->True,
    CounterIncrements->"Input"],
  
  Cell[StyleData["DisplayMath", "Printout"],
    CellMargins->{{39, 0}, {6, 6}},
    FontSize->9]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["NumberedEquation"],
    CellMargins->{{42, 10}, {7, 7}},
    CellFrameLabels->{{None, Cell[ 
            TextData[ {"(", 
              CounterBox[ "NumberedEquation"], ")"}]]}, {None, None}},
    DefaultFormatType->DefaultInputFormatType,
    HyphenationOptions->{"HyphenationCharacter"->"\[Continuation]"},
    LanguageCategory->"Formula",
    CounterIncrements->"NumberedEquation",
    FormatTypeAutoConvert->False],
  
  Cell[StyleData["NumberedEquation", "Printout"],
    CellMargins->{{34, 55}, {0, 10}},
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["EquationNumber"],
    LineSpacing->{1.83, 0},
    LanguageCategory->"Formula"],
  
  Cell[StyleData["EquationNumber", "Printout"],
    LineSpacing->{1.7, 0},
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Program"],
    CellMargins->{{16, Inherited}, {Inherited, 10}},
    CellHorizontalScrolling->True,
    LanguageCategory->"Formula",
    StyleMenuListing->None,
    FontFamily->"Courier"],
  
  Cell[StyleData["Program", "Printout"],
    CellMargins->{{8, Inherited}, {Inherited, 10}},
    FontSize->9.5]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Unique Help Browser Styles", "Subsubsection"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["InspectorLevel1"],
    ShowGroupOpenCloseIcon->True,
    CellMargins->{{12, 10}, {2, 7}},
    CellGroupingRules->{"SectionGrouping", 60},
    ParagraphIndent->-38,
    FontFamily->"Helvetica",
    FontSize->16,
    FontWeight->"Bold"],
  
  Cell[StyleData["InspectorLevel1", "Brackets"]],
  
  Cell[StyleData["InspectorLevel1", "Printout"],
    FontSize->14]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["InspectorLevel2"],
    ShowGroupOpenCloseIcon->True,
    CellMargins->{{10, 4}, {0, 14}},
    FontFamily->"Helvetica",
    FontSize->14,
    FontWeight->"Bold"],
  
  Cell[StyleData["InspectorLevel2", "Brackets"],
    ShowGroupOpenCloseIcon->True,
    CellMargins->{{48, 10}, {2, 12}},
    CellGroupingRules->{"SectionGrouping", 70},
    ParagraphIndent->-27,
    FontFamily->"Helvetica",
    FontSize->14,
    FontWeight->"Bold"],
  
  Cell[StyleData["InspectorLevel2", "Printout"],
    FontSize->12]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["ObjectName"],
    CellMargins->{{10, 4}, {1, 10}},
    FontFamily->"Courier",
    FontSize->16,
    FontWeight->"Bold"],
  
  Cell[StyleData["ObjectName", "Brackets"],
    CellMargins->{{72, 4}, {1, 14}},
    CellGroupingRules->{"SectionGrouping", 90},
    StyleMenuListing->None,
    FontFamily->"Courier",
    FontSize->12,
    FontWeight->"Bold"],
  
  Cell[StyleData["ObjectName", "Printout"],
    CellMargins->{{2, 0}, {1, 10}},
    FontSize->12]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["SubObjectNameClosed"],
    ShowGroupOpenCloseIcon->True,
    CellMargins->{{10, 4}, {1, 10}},
    PrivateCellOptions->{"DefaultCellGroupOpen"->False},
    CellGroupingRules->{"SectionGrouping", 90},
    FontFamily->"Courier",
    FontSize->14,
    FontWeight->"Bold"],
  
  Cell[StyleData["SubObjectNameClosed", "Brackets"],
    CellMargins->{{72, 4}, {1, 14}},
    StyleMenuListing->None,
    FontFamily->"Courier",
    FontSize->12,
    FontWeight->"Bold"],
  
  Cell[StyleData["SubObjectNameClosed", "Printout"],
    CellMargins->{{2, 0}, {1, 10}},
    FontSize->12]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["SubObjectName"],
    ShowGroupOpenCloseIcon->True,
    CellMargins->{{24, 4}, {1, 10}},
    FontFamily->"Courier",
    FontSize->16,
    FontWeight->"Bold"],
  
  Cell[StyleData["SubObjectName", "Brackets"],
    ShowGroupOpenCloseIcon->True,
    CellMargins->{{90, 4}, {1, 14}},
    FontFamily->"Courier",
    FontSize->12],
  
  Cell[StyleData["SubObjectName", "Printout"],
    CellMargins->{{2, 0}, {1, 10}},
    FontFamily->"Courier",
    FontSize->12]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["GroupObjectName"],
    ShowGroupOpenCloseIcon->True,
    CellMargins->{{10, 4}, {0, 14}},
    FontFamily->"Courier",
    FontSize->16,
    FontWeight->"Bold"],
  
  Cell[StyleData["GroupObjectName", "Brackets"],
    ShowGroupOpenCloseIcon->True,
    CellMargins->{{72, 10}, {2, 12}},
    CellGroupingRules->{"SectionGrouping", 70},
    ParagraphIndent->-27,
    CounterIncrements->"Outline2",
    FontFamily->"Courier",
    FontSize->12,
    FontWeight->"Bold"],
  
  Cell[StyleData["GroupObjectName", "Printout"],
    FontSize->14]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["GroupObjectNameClosed"],
    ShowGroupOpenCloseIcon->True,
    CellMargins->{{10, 4}, {0, 14}},
    PrivateCellOptions->{"DefaultCellGroupOpen"->False},
    CellGroupingRules->{"SectionGrouping", 80},
    FontFamily->"Courier",
    FontSize->16,
    FontWeight->"Bold"],
  
  Cell[StyleData["GroupObjectNameClosed", "Brackets"],
    ShowGroupOpenCloseIcon->True,
    CellMargins->{{72, 10}, {2, 12}},
    CellGroupingRules->{"SectionGrouping", 70},
    ParagraphIndent->-27,
    CounterIncrements->"Outline2",
    FontFamily->"Courier",
    FontSize->12,
    FontWeight->"Bold"],
  
  Cell[StyleData["GroupObjectNameClosed", "Printout"],
    FontSize->14]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["ObjectNameWarningMessages"],
    CellMargins->{{10, 4}, {1, 10}},
    CellGroupingRules->{"SectionGrouping", 65},
    FontFamily->"Courier",
    FontSize->16,
    FontWeight->"Bold"],
  
  Cell[StyleData["ObjectNameWarningMessages", "Brackets"],
    CellMargins->{{10, 4}, {1, 10}},
    CellGroupingRules->{"SectionGrouping", 65},
    FontFamily->"Courier",
    FontSize->16,
    FontWeight->"Bold"],
  
  Cell[StyleData["ObjectNameWarningMessages", "Printout"],
    CellMargins->{{2, 0}, {1, 10}},
    FontSize->12]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Command"],
    CellMargins->{{10, 4}, {0, 14}},
    CounterIncrements->"Section",
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->16,
    FontWeight->"Bold"],
  
  Cell[StyleData["Command", "Printout"],
    CellMargins->{{2, 0}, {0, 14}},
    PageBreakBelow->False,
    FontSize->14]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["CharacterName"],
    CellFrame->{{0, 0}, {0.5, 0.5}},
    CellMargins->{{10, 4}, {0, 4}},
    CellFrameMargins->4,
    StyleMenuListing->None],
  
  Cell[StyleData["CharacterName", "Brackets"],
    CellMargins->{{72, 4}, {1, 14}},
    CellGroupingRules->{"SectionGrouping", 90},
    StyleMenuListing->None,
    FontFamily->"Courier",
    FontSize->12,
    FontWeight->"Bold"],
  
  Cell[StyleData["CharacterName", "Printout"],
    CellMargins->{{2, 0}, {0, 4}},
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Usage"],
    CellFrame->{{0, 0}, {0.5, 0.5}},
    CellMargins->{{10, 4}, {0, 4}},
    CellFrameMargins->5,
    Hyphenation->True,
    ParagraphSpacing->{0, 6},
    ParagraphIndent->-10,
    StyleMenuListing->None],
  
  Cell[StyleData["Usage", "Brackets"],
    CellFrame->{{0, 0}, {0.5, 0.5}},
    CellMargins->{{72, 4}, {0, 4}},
    CellFrameMargins->5,
    ParagraphSpacing->{0, 6},
    ParagraphIndent->-10,
    StyleMenuListing->None],
  
  Cell[StyleData["Usage", "Printout"],
    CellMargins->{{2, 0}, {0, 4}},
    FontSize->10,
    FontWeight->"Plain"]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["ErrorMessage"],
    CellFrame->{{0, 0}, {0.5, 0.5}},
    ShowCellBracket->True,
    CellMargins->{{10, 4}, {0, 4}},
    CellGroupingRules->"OutputGrouping",
    PageBreakWithin->False,
    GroupPageBreakWithin->False,
    GeneratedCell->True,
    CellAutoOverwrite->True,
    ShowCellLabel->False,
    CellLabelMargins->{{14, Inherited}, {Inherited, Inherited}},
    CellFrameMargins->5,
    DefaultFormatType->DefaultOutputFormatType,
    FormatType->InputForm,
    StyleMenuListing->None,
    FontColor->RGBColor[0, 0, 1]],
  
  Cell[StyleData["ErrorMessage", "Brackets"],
    CellMargins->{{72, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    StyleMenuListing->None],
  
  Cell[StyleData["ErrorMessage", "Printout"],
    FontSize->9,
    FontColor->GrayLevel[0]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Notes"],
    CellMargins->{{10, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    Hyphenation->True,
    ParagraphSpacing->{0, 6},
    ParagraphIndent->-10,
    StyleMenuListing->None,
    FontFamily->"Times"],
  
  Cell[StyleData["Notes", "Brackets"],
    CellMargins->{{72, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    ParagraphSpacing->{0, 6},
    ParagraphIndent->-10,
    StyleMenuListing->None,
    FontFamily->"Times"],
  
  Cell[StyleData["Notes", "Printout"],
    CellMargins->{{2, 0}, {0, 8}},
    FontSize->9]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["NotesList"],
    CellMargins->{{20, 4}, {2, 8}},
    CellHorizontalScrolling->True,
    Hyphenation->True,
    ScriptLevel->1,
    SingleLetterItalics->True,
    StyleMenuListing->None,
    FontFamily->"Times"],
  
  Cell[StyleData["NotesList", "Brackets"],
    CellMargins->{{82, 4}, {2, 8}},
    CellHorizontalScrolling->True,
    ScriptLevel->1,
    SingleLetterItalics->True,
    StyleMenuListing->None,
    FontFamily->"Times"],
  
  Cell[StyleData["NotesList", "Printout"],
    CellMargins->{{12, 0}, {2, 8}},
    FontSize->9]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["ExampleSection"],
    CellFrame->{{0, 0}, {0, 0.5}},
    ShowGroupOpenCloseIcon->True,
    CellMargins->{{11, 4}, {0, 10}},
    CellGroupingRules->{"SectionGrouping", 70},
    CellFrameMargins->12,
    StyleMenuListing->None,
    FontSize->13,
    FontWeight->"Bold",
    FontSlant->"Italic",
    FontColor->RGBColor[0, 0, 0.4]],
  
  Cell[StyleData["ExampleSection", "Printout"],
    CellMargins->{{3, 0}, {0, 10}},
    PageBreakBelow->False,
    FontSize->9,
    FontColor->GrayLevel[0]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["ExampleText"],
    CellMargins->{{20, 40}, {0, 18}},
    Hyphenation->True,
    ParagraphSpacing->{0, 6},
    StyleMenuListing->None,
    FontColor->RGBColor[0, 0, 0.4]],
  
  Cell[StyleData["ExampleText", "Printout"],
    CellMargins->{{2, 80}, {0, 8}},
    PageBreakBelow->False,
    FontSize->8,
    FontColor->GrayLevel[0]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["ExampleSubsection"],
    ShowCellBracket->True,
    CellMargins->{{20, 4}, {0, 16}},
    CellGroupingRules->{"SectionGrouping", 80},
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->10,
    FontWeight->"Bold"],
  
  Cell[StyleData["ExampleSubsection", "Printout"],
    CellMargins->{{12, 0}, {0, 16}},
    PageBreakBelow->False,
    FontSize->7]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["LineHead"],
    CellFrame->{{0, 0}, {0.5, 0}},
    CellMargins->{{10, 4}, {8, 18}},
    CounterIncrements->"Subsection",
    CounterAssignments->{{"Subsubection", 0}},
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->12,
    FontWeight->"Bold"],
  
  Cell[StyleData["LineHead", "Printout"],
    CellMargins->{{2, 0}, {8, 18}},
    PageBreakBelow->False,
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["FlushInput"],
    CellMargins->{{10, 4}, {1, 4}},
    Evaluatable->True,
    CellGroupingRules->"InputGrouping",
    CellHorizontalScrolling->True,
    PageBreakWithin->False,
    GroupPageBreakWithin->False,
    CellLabelAutoDelete->False,
    CellLabelMargins->{{23, Inherited}, {Inherited, Inherited}},
    DefaultFormatType->DefaultInputFormatType,
    ShowSpecialCharacters->Automatic,
    FormatType->StandardForm,
    ShowStringCharacters->True,
    NumberMarks->True,
    StyleMenuListing->None,
    FontWeight->"Bold"],
  
  Cell[StyleData["FlushInput", "Printout"],
    CellMargins->{{2, 0}, {1, 4}},
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["FlushOutput"],
    CellMargins->{{10, Inherited}, {Inherited, Inherited}},
    CellEditDuplicate->True,
    CellGroupingRules->"OutputGrouping",
    CellHorizontalScrolling->True,
    PageBreakWithin->False,
    GroupPageBreakWithin->False,
    GeneratedCell->True,
    CellAutoOverwrite->True,
    CellLabelAutoDelete->False,
    CellLabelMargins->{{23, Inherited}, {Inherited, Inherited}},
    DefaultFormatType->DefaultOutputFormatType,
    FormatType->StandardForm,
    StyleMenuListing->None],
  
  Cell[StyleData["FlushOutput", "Printout"],
    CellMargins->{{2, Inherited}, {Inherited, Inherited}},
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["DialogItem"],
    CellDingbat->"\[EmptyDiamond]",
    CellMargins->{{20, 4}, {0, 12}},
    CellGroupingRules->{"SectionGrouping", 70},
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->10,
    FontWeight->"Bold"],
  
  Cell[StyleData["DialogItem", "Printout"],
    CellMargins->{{12, 0}, {0, 12}},
    PageBreakBelow->False,
    FontSize->8]
  }, Closed]],
  
  Cell[StyleData["GroupDivider"],
    CellMargins->{{10, Inherited}, {Inherited, Inherited}},
    CellEditDuplicate->True,
    CellGroupingRules->{"TitleGrouping", 0},
    StyleMenuListing->None],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Highlight"],
    CellMargins->{{10, 4}, {0, 18}},
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->12,
    Background->GrayLevel[0.900008]],
  
  Cell[StyleData["Highlight", "Printout"],
    CellMargins->{{2, 0}, {0, 18}},
    LineSpacing->{1, 3}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["UserNotes"],
    CellFrame->{{2, 0}, {0, 0.25}},
    CellMargins->{{10, 4}, {0, 4}},
    Hyphenation->True,
    ParagraphIndent->-7,
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->10],
  
  Cell[StyleData["UserNotes", "Printout"],
    CellMargins->{{2, 0}, {0, 4}},
    LineSpacing->{1, 3},
    FontSize->8]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["MoreInfo"],
    CellMargins->{{10, 4}, {0, 4}},
    Hyphenation->True,
    ParagraphIndent->-7,
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->10,
    FontColor->GrayLevel[1],
    Background->RGBColor[0.700008, 0.4, 0.100008]],
  
  Cell[StyleData["MoreInfo", "Printout"],
    CellMargins->{{2, 0}, {0, 4}},
    LineSpacing->{1, 3},
    FontSize->8]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["UserTips"],
    CellFrame->{{2, 0}, {0, 0.25}},
    CellMargins->{{10, 4}, {0, 4}},
    Hyphenation->True,
    ParagraphIndent->-7,
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->10,
    FontColor->GrayLevel[1],
    Background->RGBColor[0.2, 0.500008, 0.700008]],
  
  Cell[StyleData["UserTips", "Printout"],
    CellMargins->{{2, 0}, {0, 4}},
    LineSpacing->{1, 3},
    FontSize->8,
    Background->GrayLevel[0.700008]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Theorem"],
    CellFrame->{{4, 0}, {0, 0}},
    CellMargins->{{12, 62}, {0, 14}},
    CellFrameMargins->4,
    CellFrameColor->RGBColor[0, 0, 0.8],
    LineSpacing->{1, 1},
    ParagraphSpacing->{0, 8}],
  
  Cell[StyleData["Theorem", "Printout"],
    CellMargins->{{2, 0}, {0, 14}},
    CellFrameMargins->3,
    CellFrameColor->GrayLevel[0.8],
    FontSize->9,
    FontColor->GrayLevel[0]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Commentary"],
    CellFrame->{{2, 0}, {0, 0}},
    CellMargins->{{36, 10}, {7, 7}},
    PageBreakBelow->False,
    CellFrameMargins->8,
    CellFrameColor->RGBColor[0, 0.2, 1],
    Hyphenation->True,
    LineSpacing->{1, 3},
    ParagraphSpacing->{0, 8},
    FontSlant->"Italic"],
  
  Cell[StyleData["Commentary", "Printout"],
    CellMargins->{{32, 0}, {6, 6}},
    CellFrameColor->GrayLevel[0.8],
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Level1Icon"],
    ShowGroupOpenCloseIcon->True,
    CellMargins->{{10, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    ParagraphSpacing->{0, 8},
    StyleMenuListing->None],
  
  Cell[StyleData["Level1Icon", "Printout"],
    CellMargins->{{2, 0}, {0, 8}},
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Level2Icon"],
    ShowGroupOpenCloseIcon->True,
    CellMargins->{{10, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    ParagraphSpacing->{0, 8},
    StyleMenuListing->None],
  
  Cell[StyleData["Level2Icon", "Printout"],
    CellMargins->{{2, 0}, {0, 8}},
    FontSize->10]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Contents and Index", "Subsubsection"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["ContentsTitle"],
    CellMargins->{{10, 4}, {0, 18}},
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->18,
    FontWeight->"Bold"],
  
  Cell[StyleData["ContentsTitle", "Printout"],
    CellMargins->{{2, 0}, {0, 18}},
    PageBreakBelow->False,
    FontSize->18]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["ContentsSection"],
    CellDingbat->"\[FilledSquare]",
    CellMargins->{{20, 4}, {3, 18}},
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->12,
    FontWeight->"Bold"],
  
  Cell[StyleData["ContentsSection", "Printout"],
    CellMargins->{{12, 0}, {3, 18}},
    PageBreakBelow->False]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["IndexSection"],
    CellDingbat->"\[FilledSquare]",
    CellMargins->{{20, 4}, {5, 20}},
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->12,
    FontWeight->"Bold"],
  
  Cell[StyleData["IndexSection", "Printout"],
    CellMargins->{{12, 0}, {5, 20}},
    PageBreakBelow->False,
    FontSize->12]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Contents"],
    CellMargins->{{21, 4}, {0, 8}},
    StyleMenuListing->None],
  
  Cell[StyleData["Contents", "Printout"],
    CellMargins->{{13, 0}, {0, 8}},
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Index"],
    CellMargins->{{21, 4}, {0, 0}},
    ParagraphIndent->-48,
    StyleMenuListing->None],
  
  Cell[StyleData["Index", "Printout"],
    CellMargins->{{13, 0}, {0, 0}},
    FontSize->9]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["IndexSubentry"],
    CellMargins->{{36, 4}, {0, 0}},
    ParagraphIndent->-48,
    StyleMenuListing->None],
  
  Cell[StyleData["IndexSubentry", "Printout"],
    CellMargins->{{24, 0}, {0, 0}},
    FontSize->9]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Horizontal Lines", "Subsubsection"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Line1"],
    CellFrame->{{0, 0}, {0, 0.5}},
    CellMargins->{{10, 4}, {-16, 9}},
    StyleMenuListing->None,
    FontSize->2],
  
  Cell[StyleData["Line1", "Printout"],
    CellMargins->{{2, 0}, {-16, 9}}]
  }, Closed]],
  
  Cell["\<\

The item above is horizontal 0.5 pt line\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["ProgramTop"],
    CellFrame->{{0.5, 0.5}, {0, 0.5}},
    CellMargins->{{10, 4}, {-18, 18}},
    LineSpacing->{1, -4},
    StyleMenuListing->None,
    FontSize->4],
  
  Cell[StyleData["ProgramTop", "Printout"],
    CellMargins->{{2, 0}, {-18, 18}}]
  }, Closed]],
  
  Cell["\<\

The item above is a ProgramTop line
\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["ProgramBottom"],
    CellFrame->{{0.5, 0.5}, {0.5, 0}},
    CellMargins->{{10, 4}, {-10, -2}},
    LineSpacing->{1, -4},
    StyleMenuListing->None,
    FontSize->4],
  
  Cell[StyleData["ProgramBottom", "Printout"],
    CellMargins->{{2, 0}, {-10, -2}}]
  }, Closed]],
  
  Cell["\<\

The item above is a ProgramBottom line
\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["SessionLabel"],
    CellFrame->{{0.5, 0}, {0, 0.5}},
    CellMargins->{{10, 4}, {-4, 18}},
    LineSpacing->{1, -3},
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->9],
  
  Cell[StyleData["SessionLabel", "Printout"],
    CellMargins->{{2, 0}, {-4, 18}},
    FontSize->7]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Page Headers and Footers", "Subsubsection"],
  
  Cell[StyleData["PageHeader"],
    CellMargins->{{0, 0}, {2, 0}},
    StyleMenuListing->None,
    FontSize->8,
    FontSlant->"Italic"],
  
  Cell[StyleData["PageNumber"],
    CellMargins->{{0, 0}, {2, 0}},
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->8,
    FontWeight->"Bold"],
  
  Cell[StyleData["PageFooter"],
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->6]
  }, Closed]]
  }, Open  ]],
  
  Cell[CellGroupData[{
  
  Cell["Notation Package Styles", "Section",
    GeneratedCell->True,
    CellTags->"NotationPackage"],
  
  Cell["\<\
The cells below define certain styles needed by the Notation \
package. These styles serve to make visible otherwise invisible \
tagboxes.\
\>", "Text",
    GeneratedCell->True,
    CellTags->"NotationPackage"],
  
  Cell[StyleData["NotationTemplateStyle"],
    GeneratedCell->True,
    StyleMenuListing->None,
    Background->RGBColor[1, 1, 0.850004],
    TagBoxOptions->{SyntaxForm->"symbol"},
    CellTags->"NotationPackage"],
  
  Cell[StyleData["NotationPatternWrapperStyle"],
    GeneratedCell->True,
    StyleMenuListing->None,
    Background->RGBColor[1, 0.900008, 0.979995],
    TagBoxOptions->{SyntaxForm->"symbol"},
    CellTags->"NotationPackage"],
  
  Cell[StyleData["NotationMadeBoxesWrapperStyle"],
    GeneratedCell->True,
    StyleMenuListing->None,
    Background->RGBColor[0.900008, 0.889998, 1],
    TagBoxOptions->{SyntaxForm->"symbol"},
    CellTags->"NotationPackage"]
  }, Closed]]
  }],
MacintoshSystemPageSetup->"\<\
00<0001804P000000`d26_oQon@3:`8g0dL5N`?P0080001804P000000]P2:001
0000I00000400`<30?l00BL?00400@0000000000000006P801T1T00000000000
00000000004000000000000000000000\>"
]


(***********************************************************************
Cached data follows.  If you edit this Notebook file directly, not using
Mathematica, you must remove the line containing CacheID at the top of 
the file.  The cache data will then be recreated when you save this file 
from within Mathematica.
***********************************************************************)

(*CellTagsOutline
CellTagsIndex->{}
*)

(*CellTagsIndex
CellTagsIndex->{}
*)

(*NotebookFileOutline
Notebook[{

Cell[CellGroupData[{
Cell[1739, 51, 41, 0, 24, "SubsubsectionIcon"],
Cell[1783, 53, 658, 11, 52, "Text"],
Cell[2444, 66, 994, 21, 78, "Text"],
Cell[3441, 89, 487, 8, 50, "Text"]
}, Closed]],

Cell[CellGroupData[{
Cell[3965, 102, 60, 0, 20, "SubsubsectionIcon"],
Cell[4028, 104, 1883, 41, 96, "DefinitionBox"],
Cell[5914, 147, 917, 26, 52, "Text"],
Cell[6834, 175, 401, 7, 36, "Text"],
Cell[7238, 184, 598, 17, 40, "Text"],
Cell[7839, 203, 194, 4, 22, "Text"],
Cell[8036, 209, 1141, 18, 94, "Text"]
}, Closed]],

Cell[CellGroupData[{
Cell[9214, 232, 65, 1, 26, "SubsectionIcon",
  InitializationCell->True],

Cell[CellGroupData[{
Cell[9304, 237, 62, 1, 24, "SubsubsectionIcon",
  InitializationCell->True],
Cell[9369, 240, 299, 7, 22, "Text",
  InitializationCell->True],
Cell[9671, 249, 174, 4, 22, "Text",
  InitializationCell->True],
Cell[9848, 255, 249, 5, 22, "Text",
  InitializationCell->True],
Cell[10100, 262, 492, 8, 50, "Text"]
}, Closed]],

Cell[CellGroupData[{
Cell[10629, 275, 70, 1, 20, "SubsubsectionIcon",
  InitializationCell->True],
Cell[10702, 278, 117, 3, 26, "Input",
  InitializationCell->True],
Cell[10822, 283, 114, 3, 26, "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{
Cell[10973, 291, 78, 1, 20, "SubsubsectionIcon",
  InitializationCell->True],
Cell[11054, 294, 308, 6, 58, "Input",
  InitializationCell->True],
Cell[11365, 302, 146, 4, 26, "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{
Cell[11548, 311, 80, 1, 20, "SubsubsectionIcon",
  InitializationCell->True],
Cell[11631, 314, 201, 4, 26, "Input",
  InitializationCell->True],
Cell[11835, 320, 173, 4, 26, "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{
Cell[12045, 329, 79, 1, 20, "SubsubsectionIcon",
  InitializationCell->True],
Cell[12127, 332, 578, 9, 90, "Input",
  InitializationCell->True],
Cell[12708, 343, 487, 9, 110, "Input",
  InitializationCell->True],
Cell[13198, 354, 419, 8, 42, "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{
Cell[13654, 367, 69, 1, 20, "SubsubsectionIcon",
  InitializationCell->True],
Cell[13726, 370, 207, 4, 70, "Input",
  InitializationCell->True],
Cell[13936, 376, 202, 5, 70, "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{
Cell[14175, 386, 73, 1, 20, "SubsubsectionIcon",
  InitializationCell->True],
Cell[14251, 389, 487, 9, 70, "Input",
  InitializationCell->True],
Cell[14741, 400, 185, 5, 70, "Input",
  InitializationCell->True],
Cell[14929, 407, 210, 4, 70, "Input",
  InitializationCell->True],
Cell[15142, 413, 2071, 39, 70, "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{
Cell[17250, 457, 76, 1, 20, "SubsubsectionIcon",
  InitializationCell->True],
Cell[17329, 460, 296, 6, 70, "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{
Cell[17662, 471, 73, 1, 20, "SubsubsectionIcon",
  InitializationCell->True],
Cell[17738, 474, 421, 7, 74, "Input",
  InitializationCell->True],
Cell[18162, 483, 195, 5, 26, "Input",
  InitializationCell->True],

Cell[CellGroupData[{
Cell[18382, 492, 1922, 36, 186, "Input",
  InitializationCell->True],
Cell[20307, 530, 209, 4, 20, "Message"],
Cell[20519, 536, 210, 4, 20, "Message"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{
Cell[20778, 546, 66, 1, 20, "SubsubsectionIcon",
  InitializationCell->True],
Cell[20847, 549, 318, 6, 70, "Input",
  InitializationCell->True],
Cell[21168, 557, 299, 6, 70, "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{
Cell[21504, 568, 66, 1, 20, "SubsubsectionIcon",
  InitializationCell->True],
Cell[21573, 571, 243, 5, 42, "Input",
  InitializationCell->True],
Cell[21819, 578, 166, 4, 26, "Input",
  InitializationCell->True],
Cell[21988, 584, 539, 11, 106, "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{
Cell[22564, 600, 72, 1, 20, "SubsubsectionIcon",
  InitializationCell->True],
Cell[22639, 603, 315, 6, 70, "Input",
  InitializationCell->True],
Cell[22957, 611, 493, 9, 70, "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{
Cell[23487, 625, 63, 1, 20, "SubsubsectionIcon",
  InitializationCell->True],

Cell[CellGroupData[{
Cell[23575, 630, 213, 4, 70, "Input",
  InitializationCell->True],
Cell[23791, 636, 182, 3, 70, "Output"]
}, Open  ]],
Cell[23988, 642, 173, 4, 70, "Input",
  InitializationCell->True],
Cell[24164, 648, 480, 9, 70, "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{
Cell[24681, 662, 76, 1, 20, "SubsubsectionIcon",
  InitializationCell->True],
Cell[24760, 665, 257, 5, 70, "Input",
  InitializationCell->True],
Cell[25020, 672, 200, 4, 70, "Input",
  InitializationCell->True],
Cell[25223, 678, 515, 9, 70, "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{
Cell[25775, 692, 75, 1, 20, "SubsubsectionIcon",
  InitializationCell->True],
Cell[25853, 695, 261, 5, 70, "Input",
  InitializationCell->True],
Cell[26117, 702, 198, 4, 70, "Input",
  InitializationCell->True],
Cell[26318, 708, 511, 9, 70, "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{
Cell[26866, 722, 69, 1, 20, "SubsubsectionIcon",
  InitializationCell->True],
Cell[26938, 725, 234, 5, 70, "Input",
  InitializationCell->True],
Cell[27175, 732, 186, 4, 70, "Input",
  InitializationCell->True],
Cell[27364, 738, 481, 9, 70, "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{
Cell[27882, 752, 75, 1, 20, "SubsubsectionIcon",
  InitializationCell->True],
Cell[27960, 755, 179, 4, 70, "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{
Cell[28176, 764, 71, 1, 20, "SubsubsectionIcon",
  InitializationCell->True],
Cell[28250, 767, 389, 7, 70, "Input",
  InitializationCell->True],
Cell[28642, 776, 171, 4, 70, "Input",
  InitializationCell->True],
Cell[28816, 782, 184, 4, 70, "Input",
  InitializationCell->True],
Cell[29003, 788, 186, 4, 70, "Input",
  InitializationCell->True],
Cell[29192, 794, 632, 13, 70, "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{
Cell[29861, 812, 81, 1, 20, "SubsubsectionIcon",
  InitializationCell->True],
Cell[29945, 815, 417, 7, 70, "Input",
  InitializationCell->True],
Cell[30365, 824, 299, 6, 70, "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{
Cell[30701, 835, 83, 1, 20, "SubsubsectionIcon",
  InitializationCell->True],
Cell[30787, 838, 418, 7, 70, "Input",
  InitializationCell->True],
Cell[31208, 847, 301, 6, 70, "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{
Cell[31546, 858, 70, 1, 20, "SubsubsectionIcon",
  InitializationCell->True],
Cell[31619, 861, 233, 5, 70, "Input",
  InitializationCell->True],
Cell[31855, 868, 294, 7, 70, "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{
Cell[32186, 880, 66, 1, 20, "SubsubsectionIcon",
  InitializationCell->True],
Cell[32255, 883, 365, 6, 58, "Input",
  InitializationCell->True],
Cell[32623, 891, 207, 4, 42, "Input",
  InitializationCell->True],
Cell[32833, 897, 189, 4, 26, "Input",
  InitializationCell->True],
Cell[33025, 903, 2629, 45, 266, "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{
Cell[35691, 953, 74, 1, 20, "SubsubsectionIcon",
  InitializationCell->True],
Cell[35768, 956, 341, 7, 43, "Input",
  InitializationCell->True],
Cell[36112, 965, 188, 4, 26, "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{
Cell[36337, 974, 41, 0, 20, "SubsubsectionIcon"],
Cell[36381, 976, 208, 4, 42, "Input",
  InitializationCell->True],
Cell[36592, 982, 265, 6, 42, "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{
Cell[36894, 993, 76, 1, 20, "SubsubsectionIcon",
  InitializationCell->True],
Cell[36973, 996, 352, 7, 43, "Input",
  InitializationCell->True],
Cell[37328, 1005, 232, 5, 42, "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{
Cell[37597, 1015, 80, 1, 20, "SubsubsectionIcon",
  InitializationCell->True],
Cell[37680, 1018, 403, 7, 59, "Input",
  InitializationCell->True],
Cell[38086, 1027, 253, 6, 42, "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{
Cell[38376, 1038, 67, 1, 20, "SubsubsectionIcon",
  InitializationCell->True],
Cell[38446, 1041, 225, 5, 70, "Input",
  InitializationCell->True],
Cell[38674, 1048, 200, 4, 70, "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{
Cell[38911, 1057, 67, 1, 20, "SubsubsectionIcon",
  InitializationCell->True],
Cell[38981, 1060, 226, 5, 70, "Input",
  InitializationCell->True],
Cell[39210, 1067, 200, 4, 70, "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{
Cell[39447, 1076, 74, 1, 20, "SubsubsectionIcon",
  InitializationCell->True],
Cell[39524, 1079, 244, 5, 70, "Input",
  InitializationCell->True],
Cell[39771, 1086, 233, 5, 70, "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{
Cell[40041, 1096, 68, 1, 20, "SubsubsectionIcon",
  InitializationCell->True],
Cell[40112, 1099, 239, 5, 70, "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{
Cell[40388, 1109, 68, 1, 20, "SubsubsectionIcon",
  InitializationCell->True],
Cell[40459, 1112, 499, 9, 70, "Input",
  InitializationCell->True],
Cell[40961, 1123, 180, 4, 70, "Input",
  InitializationCell->True],
Cell[41144, 1129, 163, 4, 70, "Input",
  InitializationCell->True],
Cell[41310, 1135, 2120, 36, 70, "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{
Cell[43467, 1176, 71, 1, 20, "SubsubsectionIcon",
  InitializationCell->True],
Cell[43541, 1179, 174, 4, 70, "Input",
  InitializationCell->True],
Cell[43718, 1185, 435, 10, 70, "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{
Cell[44190, 1200, 69, 1, 20, "SubsubsectionIcon",
  InitializationCell->True],
Cell[44262, 1203, 201, 4, 70, "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{
Cell[44500, 1212, 66, 1, 20, "SubsubsectionIcon",
  InitializationCell->True],
Cell[44569, 1215, 480, 8, 42, "Input",
  InitializationCell->True],
Cell[45052, 1225, 180, 4, 27, "Input",
  InitializationCell->True],
Cell[45235, 1231, 161, 4, 27, "Input",
  InitializationCell->True],
Cell[45399, 1237, 2022, 34, 297, "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{
Cell[47458, 1276, 51, 0, 20, "SubsubsectionIcon"],

Cell[CellGroupData[{
Cell[47534, 1280, 362, 7, 42, "Input"],
Cell[47899, 1289, 10718, 165, 1085, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[58654, 1459, 245, 4, 22, "Input"],
Cell[58902, 1465, 65, 2, 20, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[59004, 1472, 247, 4, 42, "Input"],
Cell[59254, 1478, 64, 2, 20, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[59355, 1485, 104, 2, 26, "Input"],
Cell[59462, 1489, 67, 2, 20, "Print"],
Cell[59532, 1493, 67, 2, 20, "Print"],
Cell[59602, 1497, 70, 2, 20, "Print"],
Cell[59675, 1501, 67, 2, 20, "Print"],
Cell[59745, 1505, 71, 2, 20, "Print"],
Cell[59819, 1509, 76, 2, 20, "Print"],
Cell[59898, 1513, 80, 2, 20, "Print"],
Cell[59981, 1517, 72, 2, 20, "Print"],
Cell[60056, 1521, 80, 2, 20, "Print"],
Cell[60139, 1525, 80, 2, 20, "Print"],
Cell[60222, 1529, 84, 2, 20, "Print"],
Cell[60309, 1533, 88, 2, 20, "Print"],
Cell[60400, 1537, 104, 2, 20, "Print"],
Cell[60507, 1541, 96, 2, 20, "Print"],
Cell[60606, 1545, 96, 2, 20, "Print"],
Cell[60705, 1549, 100, 2, 20, "Print"],
Cell[60808, 1553, 100, 2, 20, "Print"],
Cell[60911, 1557, 96, 2, 20, "Print"],
Cell[61010, 1561, 92, 2, 20, "Print"],
Cell[61105, 1565, 96, 2, 20, "Print"],
Cell[61204, 1569, 92, 2, 20, "Print"],
Cell[61299, 1573, 92, 2, 20, "Print"],
Cell[61394, 1577, 96, 2, 20, "Print"],
Cell[61493, 1581, 92, 2, 20, "Print"],
Cell[61588, 1585, 88, 2, 20, "Print"],
Cell[61679, 1589, 88, 2, 20, "Print"],
Cell[61770, 1593, 84, 2, 20, "Print"],
Cell[61857, 1597, 80, 2, 20, "Print"],
Cell[61940, 1601, 76, 2, 20, "Print"],
Cell[62019, 1605, 76, 2, 20, "Print"],
Cell[62098, 1609, 62, 2, 20, "Output"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{
Cell[62209, 1617, 69, 1, 20, "SubsubsectionIcon",
  InitializationCell->True],
Cell[62281, 1620, 168, 4, 26, "Input",
  InitializationCell->True],
Cell[62452, 1626, 420, 9, 58, "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{
Cell[62909, 1640, 73, 1, 20, "SubsubsectionIcon",
  InitializationCell->True],
Cell[62985, 1643, 518, 8, 90, "Input",
  InitializationCell->True],
Cell[63506, 1653, 217, 4, 42, "Input",
  InitializationCell->True],
Cell[63726, 1659, 1126, 20, 170, "Input",
  InitializationCell->True],
Cell[64855, 1681, 1129, 21, 186, "Input",
  InitializationCell->True],
Cell[65987, 1704, 319, 7, 61, "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{
Cell[66343, 1716, 47, 0, 20, "SubsubsectionIcon"],
Cell[66393, 1718, 286, 5, 42, "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{
Cell[66716, 1728, 79, 1, 20, "SubsubsectionIcon",
  InitializationCell->True],
Cell[66798, 1731, 313, 6, 58, "Input",
  InitializationCell->True],
Cell[67114, 1739, 183, 5, 26, "Input",
  InitializationCell->True],
Cell[67300, 1746, 839, 15, 90, "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{
Cell[68176, 1766, 77, 1, 20, "SubsubsectionIcon",
  InitializationCell->True],
Cell[68256, 1769, 250, 5, 27, "Input",
  InitializationCell->True],
Cell[68509, 1776, 481, 10, 42, "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{
Cell[69027, 1791, 41, 0, 20, "SubsubsectionIcon"],
Cell[69071, 1793, 166, 4, 27, "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{
Cell[69274, 1802, 72, 1, 20, "SubsubsectionIcon",
  InitializationCell->True],
Cell[69349, 1805, 609, 10, 90, "Input",
  InitializationCell->True],
Cell[69961, 1817, 221, 5, 26, "Input",
  InitializationCell->True],
Cell[70185, 1824, 335, 6, 42, "Input",
  InitializationCell->True],
Cell[70523, 1832, 2159, 37, 346, "Input",
  InitializationCell->True],
Cell[72685, 1871, 1984, 34, 298, "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{
Cell[74706, 1910, 37, 0, 20, "SubsubsectionIcon"],
Cell[74746, 1912, 307, 6, 42, "Input",
  InitializationCell->True],
Cell[75056, 1920, 1017, 18, 154, "Input",
  InitializationCell->True],
Cell[76076, 1940, 173, 4, 26, "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{
Cell[76286, 1949, 41, 0, 20, "SubsubsectionIcon"],
Cell[76330, 1951, 570, 10, 90, "Input",
  InitializationCell->True],
Cell[76903, 1963, 252, 5, 42, "Input",
  InitializationCell->True],
Cell[77158, 1970, 240, 5, 42, "Input",
  InitializationCell->True],
Cell[77401, 1977, 244, 5, 42, "Input",
  InitializationCell->True],
Cell[77648, 1984, 232, 5, 26, "Input",
  InitializationCell->True],
Cell[77883, 1991, 713, 12, 122, "Input",
  InitializationCell->True],
Cell[78599, 2005, 1209, 22, 234, "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{
Cell[79845, 2032, 48, 0, 20, "SubsubsectionIcon"],
Cell[79896, 2034, 237, 5, 42, "Input",
  InitializationCell->True],
Cell[80136, 2041, 558, 12, 74, "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{
Cell[80731, 2058, 45, 0, 20, "SubsubsectionIcon"],
Cell[80779, 2060, 420, 6, 74, "Input"],
Cell[81202, 2068, 124, 3, 22, "Text"],
Cell[81329, 2073, 395, 7, 58, "Input"],
Cell[81727, 2082, 668, 11, 74, "Input"],
Cell[82398, 2095, 193, 4, 26, "Input"],
Cell[82594, 2101, 184, 4, 26, "Input"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[82827, 2111, 33, 0, 26, "SubsectionIcon"],

Cell[CellGroupData[{
Cell[82885, 2115, 61, 0, 24, "SubsubsectionIcon"],

Cell[CellGroupData[{
Cell[82971, 2119, 97, 2, 27, "Input"],
Cell[83071, 2123, 1928, 35, 110, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[85036, 2163, 194, 4, 23, "Input"],
Cell[85233, 2169, 25566, 551, 184, 3572, 274, "GraphicsData", "PostScript", \
"Graphics",
  ImageCacheValid->False]
}, Closed]],

Cell[CellGroupData[{
Cell[110836, 2725, 101, 2, 23, "Input"],
Cell[110940, 2729, 96, 2, 20, "Print"],
Cell[111039, 2733, 319, 7, 20, "Print"],
Cell[111361, 2742, 1862, 40, 50, "Print"],
Cell[113226, 2784, 95, 2, 20, "Print"],
Cell[113324, 2788, 306, 6, 20, "Print"],
Cell[113633, 2796, 1873, 39, 50, "Print"],
Cell[115509, 2837, 111, 2, 20, "Print"],
Cell[115623, 2841, 272, 5, 20, "Print"],
Cell[115898, 2848, 2753, 58, 95, "Print"],
Cell[118654, 2908, 109, 2, 20, "Print"],
Cell[118766, 2912, 278, 5, 20, "Print"],
Cell[119047, 2919, 3524, 74, 110, "Print"],
Cell[122574, 2995, 95, 2, 20, "Print"],
Cell[122672, 2999, 319, 7, 20, "Print"],
Cell[122994, 3008, 3642, 77, 140, "Print"],
Cell[126639, 3087, 94, 2, 20, "Print"],
Cell[126736, 3091, 306, 6, 20, "Print"],
Cell[127045, 3099, 3748, 79, 155, "Print"],
Cell[130796, 3180, 94, 2, 20, "Print"],
Cell[130893, 3184, 289, 5, 20, "Print"],
Cell[131185, 3191, 3778, 79, 170, "Print"],
Cell[134966, 3272, 109, 2, 20, "Print"],
Cell[135078, 3276, 266, 5, 20, "Print"],
Cell[135347, 3283, 4690, 100, 200, "Print"],
Cell[140040, 3385, 109, 2, 20, "Print"],
Cell[140152, 3389, 278, 5, 20, "Print"],
Cell[140433, 3396, 5452, 115, 215, "Print"],
Cell[145888, 3513, 109, 2, 20, "Print"],
Cell[146000, 3517, 286, 5, 20, "Print"],
Cell[146289, 3524, 6227, 131, 245, "Print"],
Cell[152519, 3657, 94, 2, 20, "Print"],
Cell[152616, 3661, 331, 7, 20, "Print"],
Cell[152950, 3670, 6354, 135, 260, "Print"],
Cell[159307, 3807, 94, 2, 20, "Print"],
Cell[159404, 3811, 323, 7, 20, "Print"],
Cell[159730, 3820, 6359, 133, 275, "Print"],
Cell[166092, 3955, 110, 2, 20, "Print"],
Cell[166205, 3959, 278, 5, 20, "Print"],
Cell[166486, 3966, 7023, 146, 290, "Print"],
Cell[173512, 4114, 93, 2, 20, "Print"],
Cell[173608, 4118, 323, 7, 20, "Print"],
Cell[173934, 4127, 7060, 148, 290, "Print"],
Cell[180997, 4277, 94, 2, 20, "Print"],
Cell[181094, 4281, 315, 7, 20, "Print"],
Cell[181412, 4290, 7094, 149, 305, "Print"],
Cell[188509, 4441, 109, 2, 20, "Print"],
Cell[188621, 4445, 270, 5, 20, "Print"],
Cell[188894, 4452, 8006, 170, 335, "Print"],
Cell[196903, 4624, 94, 2, 20, "Print"],
Cell[197000, 4628, 315, 7, 20, "Print"],
Cell[197318, 4637, 8024, 169, 350, "Print"],
Cell[205345, 4808, 109, 2, 20, "Print"],
Cell[205457, 4812, 270, 5, 20, "Print"],
Cell[205730, 4819, 8935, 190, 380, "Print"],
Cell[214668, 5011, 93, 2, 20, "Print"],
Cell[214764, 5015, 315, 7, 20, "Print"],
Cell[215082, 5024, 8950, 189, 395, "Print"],
Cell[224035, 5215, 108, 2, 20, "Print"],
Cell[224146, 5219, 270, 5, 20, "Print"],
Cell[224419, 5226, 9859, 210, 425, "Print"],
Cell[234281, 5438, 93, 2, 20, "Print"],
Cell[234377, 5442, 315, 7, 20, "Print"],
Cell[234695, 5451, 9874, 209, 440, "Print"],
Cell[244572, 5662, 108, 2, 20, "Print"],
Cell[244683, 5666, 270, 5, 20, "Print"],
Cell[244956, 5673, 10783, 230, 470, "Print"],
Cell[255742, 5905, 93, 2, 20, "Print"],
Cell[255838, 5909, 315, 7, 20, "Print"],
Cell[256156, 5918, 10798, 229, 485, "Print"],
Cell[266957, 6149, 109, 2, 20, "Print"],
Cell[267069, 6153, 270, 5, 20, "Print"],
Cell[267342, 6160, 11704, 250, 515, "Print"],
Cell[279049, 6412, 109, 2, 20, "Print"],
Cell[279161, 6416, 278, 5, 20, "Print"],
Cell[279442, 6423, 12488, 266, 530, "Print"],
Cell[291933, 6691, 109, 2, 20, "Print"],
Cell[292045, 6695, 286, 5, 20, "Print"],
Cell[292334, 6702, 13257, 281, 560, "Print"],
Cell[305594, 6985, 108, 2, 20, "Print"],
Cell[305705, 6989, 301, 6, 20, "Print"],
Cell[306009, 6997, 13938, 295, 575, "Print"],
Cell[319950, 7294, 94, 2, 20, "Print"],
Cell[320047, 7298, 339, 7, 20, "Print"],
Cell[320389, 7307, 14055, 298, 590, "Print"],
Cell[334447, 7607, 109, 2, 20, "Print"],
Cell[334559, 7611, 301, 6, 20, "Print"],
Cell[334863, 7619, 14738, 312, 605, "Print"],
Cell[349604, 7933, 94, 2, 20, "Print"],
Cell[349701, 7937, 339, 7, 20, "Print"],
Cell[350043, 7946, 14767, 312, 620, "Print"],
Cell[364813, 8260, 109, 2, 20, "Print"],
Cell[364925, 8264, 301, 6, 20, "Print"],
Cell[365229, 8272, 15448, 326, 635, "Print"],
Cell[380680, 8600, 94, 2, 20, "Print"],
Cell[380777, 8604, 339, 7, 20, "Print"],
Cell[381119, 8613, 15497, 328, 635, "Print"],
Cell[396619, 8943, 109, 2, 20, "Print"],
Cell[396731, 8947, 301, 6, 20, "Print"],
Cell[397035, 8955, 16409, 349, 665, "Print"],
Cell[413447, 9306, 94, 2, 20, "Print"],
Cell[413544, 9310, 339, 7, 20, "Print"],
Cell[413886, 9319, 16429, 350, 665, "Print"],
Cell[430318, 9671, 110, 2, 20, "Print"],
Cell[430431, 9675, 301, 6, 20, "Print"],
Cell[430735, 9683, 17110, 364, 680, "Print"],
Cell[447848, 10049, 94, 2, 20, "Print"],
Cell[447945, 10053, 339, 7, 20, "Print"],
Cell[448287, 10062, 17128, 365, 695, "Print"],
Cell[465418, 10429, 109, 2, 20, "Print"],
Cell[465530, 10433, 301, 6, 20, "Print"],
Cell[465834, 10441, 17799, 379, 710, "Print"],
Cell[483636, 10822, 107, 2, 20, "Print"],
Cell[483746, 10826, 309, 6, 20, "Print"],
Cell[484058, 10834, 18464, 393, 725, "Print"],
Cell[502525, 11229, 94, 2, 20, "Print"],
Cell[502622, 11233, 356, 8, 20, "Print"],
Cell[502981, 11243, 18563, 395, 740, "Print"],
Cell[521547, 11640, 94, 2, 20, "Print"],
Cell[521644, 11644, 339, 7, 20, "Print"],
Cell[521986, 11653, 18638, 395, 755, "Print"],
Cell[540627, 12050, 9723, 214, 785, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[550387, 12269, 115, 2, 23, "Input"],
Cell[550505, 12273, 2816, 57, 98, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[553358, 12335, 86, 2, 27, "Input"],
Cell[553447, 12339, 655, 13, 46, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[554139, 12357, 114, 2, 27, "Input"],
Cell[554256, 12361, 427, 10, 33, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[554720, 12376, 72, 2, 27, "Input"],
Cell[554795, 12380, 245, 4, 20, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[555077, 12389, 72, 2, 27, "Input"],
Cell[555152, 12393, 2905, 48, 124, "Output"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{
Cell[558106, 12447, 61, 0, 20, "SubsubsectionIcon"],

Cell[CellGroupData[{
Cell[558192, 12451, 150, 4, 27, "Input"],
Cell[558345, 12457, 110, 2, 20, "Print"],
Cell[558458, 12461, 284, 5, 20, "Print"],
Cell[558745, 12468, 2662, 57, 65, "Print"],
Cell[561410, 12527, 95, 2, 20, "Print"],
Cell[561508, 12531, 325, 7, 20, "Print"],
Cell[561836, 12540, 2715, 60, 65, "Print"],
Cell[564554, 12602, 95, 2, 20, "Print"],
Cell[564652, 12606, 319, 7, 20, "Print"],
Cell[564974, 12615, 2691, 57, 80, "Print"],
Cell[567668, 12674, 95, 2, 20, "Print"],
Cell[567766, 12678, 306, 6, 20, "Print"],
Cell[568075, 12686, 2704, 57, 95, "Print"],
Cell[570782, 12745, 110, 2, 20, "Print"],
Cell[570895, 12749, 272, 5, 20, "Print"],
Cell[571170, 12756, 3567, 75, 125, "Print"],
Cell[574740, 12833, 95, 2, 20, "Print"],
Cell[574838, 12837, 306, 6, 20, "Print"],
Cell[575147, 12845, 3597, 76, 140, "Print"],
Cell[578747, 12923, 110, 2, 20, "Print"],
Cell[578860, 12927, 272, 5, 20, "Print"],
Cell[579135, 12934, 4457, 94, 170, "Print"],
Cell[583595, 13030, 95, 2, 20, "Print"],
Cell[583693, 13034, 315, 7, 20, "Print"],
Cell[584011, 13043, 4560, 96, 185, "Print"],
Cell[588574, 13141, 109, 2, 20, "Print"],
Cell[588686, 13145, 278, 5, 20, "Print"],
Cell[588967, 13152, 5460, 113, 215, "Print"],
Cell[594430, 13267, 95, 2, 20, "Print"],
Cell[594528, 13271, 323, 7, 20, "Print"],
Cell[594854, 13280, 5605, 118, 230, "Print"],
Cell[600462, 13400, 110, 2, 20, "Print"],
Cell[600575, 13404, 278, 5, 20, "Print"],
Cell[600856, 13411, 5605, 118, 230, "Print"],
Cell[606464, 13531, 111, 2, 20, "Print"],
Cell[606578, 13535, 278, 5, 20, "Print"],
Cell[606859, 13542, 5605, 118, 230, "Print"],
Cell[612467, 13662, 110, 2, 20, "Print"],
Cell[612580, 13666, 278, 5, 20, "Print"],
Cell[612861, 13673, 6561, 137, 260, "Print"],
Cell[619425, 13812, 94, 2, 20, "Print"],
Cell[619522, 13816, 323, 7, 20, "Print"],
Cell[619848, 13825, 6675, 140, 275, "Print"],
Cell[626526, 13967, 109, 2, 20, "Print"],
Cell[626638, 13971, 278, 5, 20, "Print"],
Cell[626919, 13978, 7625, 159, 305, "Print"],
Cell[634547, 14139, 96, 2, 20, "Print"],
Cell[634646, 14143, 323, 7, 20, "Print"],
Cell[634972, 14152, 7737, 162, 320, "Print"],
Cell[642712, 14316, 109, 2, 20, "Print"],
Cell[642824, 14320, 278, 5, 20, "Print"],
Cell[643105, 14327, 7737, 162, 320, "Print"],
Cell[650845, 14491, 111, 2, 20, "Print"],
Cell[650959, 14495, 278, 5, 20, "Print"],
Cell[651240, 14502, 7737, 162, 320, "Print"],
Cell[658980, 14666, 110, 2, 20, "Print"],
Cell[659093, 14670, 278, 5, 20, "Print"],
Cell[659374, 14677, 8633, 179, 350, "Print"],
Cell[668010, 14858, 95, 2, 20, "Print"],
Cell[668108, 14862, 323, 7, 20, "Print"],
Cell[668434, 14871, 8778, 184, 365, "Print"],
Cell[677215, 15057, 109, 2, 20, "Print"],
Cell[677327, 15061, 278, 5, 20, "Print"],
Cell[677608, 15068, 9710, 202, 395, "Print"],
Cell[687321, 15272, 110, 2, 20, "Print"],
Cell[687434, 15276, 286, 5, 20, "Print"],
Cell[687723, 15283, 10668, 222, 425, "Print"],
Cell[698394, 15507, 107, 2, 20, "Print"],
Cell[698504, 15511, 301, 6, 20, "Print"],
Cell[698808, 15519, 11593, 241, 455, "Print"],
Cell[710404, 15762, 108, 2, 20, "Print"],
Cell[710515, 15766, 309, 6, 20, "Print"],
Cell[710827, 15774, 11593, 241, 455, "Print"],
Cell[722423, 16017, 94, 2, 20, "Print"],
Cell[722520, 16021, 339, 7, 20, "Print"],
Cell[722862, 16030, 11830, 245, 470, "Print"],
Cell[734695, 16277, 95, 2, 20, "Print"],
Cell[734793, 16281, 331, 7, 20, "Print"],
Cell[735127, 16290, 12073, 249, 485, "Print"],
Cell[747203, 16541, 95, 2, 20, "Print"],
Cell[747301, 16545, 323, 7, 20, "Print"],
Cell[747627, 16554, 12266, 253, 500, "Print"],
Cell[759896, 16809, 111, 2, 70, "Print"],
Cell[760010, 16813, 278, 5, 70, "Print"],
Cell[760291, 16820, 13292, 274, 70, "Print"],
Cell[773586, 17096, 109, 2, 70, "Print"],
Cell[773698, 17100, 286, 5, 70, "Print"],
Cell[773987, 17107, 14212, 292, 70, "Print"],
Cell[788202, 17401, 110, 2, 70, "Print"],
Cell[788315, 17405, 301, 6, 70, "Print"],
Cell[788619, 17413, 14212, 292, 70, "Print"],
Cell[802834, 17707, 112, 2, 70, "Print"],
Cell[802949, 17711, 301, 6, 70, "Print"],
Cell[803253, 17719, 14212, 292, 70, "Print"],
Cell[817468, 18013, 96, 2, 70, "Print"],
Cell[817567, 18017, 331, 7, 70, "Print"],
Cell[817901, 18026, 14394, 295, 70, "Print"],
Cell[832298, 18323, 95, 2, 70, "Print"],
Cell[832396, 18327, 323, 7, 70, "Print"],
Cell[832722, 18336, 14592, 299, 70, "Print"],
Cell[847317, 18637, 109, 2, 70, "Print"],
Cell[847429, 18641, 278, 5, 70, "Print"],
Cell[847710, 18648, 15459, 317, 70, "Print"],
Cell[863172, 18967, 109, 2, 70, "Print"],
Cell[863284, 18971, 286, 5, 70, "Print"],
Cell[863573, 18978, 16395, 336, 70, "Print"],
Cell[879971, 19316, 96, 2, 70, "Print"],
Cell[880070, 19320, 331, 7, 70, "Print"],
Cell[880404, 19329, 16573, 338, 70, "Print"],
Cell[896980, 19669, 95, 2, 70, "Print"],
Cell[897078, 19673, 323, 7, 70, "Print"],
Cell[897404, 19682, 16768, 342, 70, "Print"],
Cell[914175, 20026, 95, 2, 70, "Print"],
Cell[914273, 20030, 315, 7, 70, "Print"],
Cell[914591, 20039, 16787, 342, 70, "Print"],
Cell[931381, 20383, 110, 2, 70, "Print"],
Cell[931494, 20387, 270, 5, 70, "Print"],
Cell[931767, 20394, 17688, 362, 70, "Print"],
Cell[949458, 20758, 110, 2, 70, "Print"],
Cell[949571, 20762, 278, 5, 70, "Print"],
Cell[949852, 20769, 18637, 381, 70, "Print"],
Cell[968492, 21152, 9664, 212, 70, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[978193, 21369, 62, 2, 23, "Input"],
Cell[978258, 21373, 8597, 192, 665, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[986892, 21570, 73, 2, 23, "Input"],
Cell[986968, 21574, 247, 4, 20, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[987252, 21583, 76, 2, 27, "Input"],
Cell[987331, 21587, 62, 2, 20, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[987430, 21594, 116, 2, 27, "Input"],
Cell[987549, 21598, 1756, 38, 65, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[989342, 21641, 103, 2, 23, "Input"],
Cell[989448, 21645, 598, 14, 50, "Output"]
}, Closed]],
Cell[990061, 21662, 118, 3, 18, "Text"],

Cell[CellGroupData[{
Cell[990204, 21669, 96, 2, 27, "Input"],
Cell[990303, 21673, 8875, 247, 463, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[999215, 21925, 100, 2, 23, "Input"],
Cell[999318, 21929, 1253, 37, 71, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[1000608, 21971, 94, 2, 23, "Input"],
Cell[1000705, 21975, 8921, 257, 491, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[1009663, 22237, 87, 2, 23, "Input"],
Cell[1009753, 22241, 627, 20, 67, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[1010417, 22266, 87, 2, 23, "Input"],
Cell[1010507, 22270, 713, 22, 55, "Output"]
}, Closed]],
Cell[1011235, 22295, 90, 3, 18, "Text"],

Cell[CellGroupData[{
Cell[1011350, 22302, 86, 2, 27, "Input"],
Cell[1011439, 22306, 68, 2, 20, "Print"],
Cell[1011510, 22310, 2351, 37, 140, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[1013898, 22352, 90, 2, 23, "Input"],
Cell[1013991, 22356, 68, 2, 20, "Print"],
Cell[1014062, 22360, 68, 2, 20, "Print"],
Cell[1014133, 22364, 68, 2, 20, "Print"],
Cell[1014204, 22368, 68, 2, 20, "Print"],
Cell[1014275, 22372, 68, 2, 20, "Print"],
Cell[1014346, 22376, 68, 2, 20, "Print"],
Cell[1014417, 22380, 68, 2, 20, "Print"],
Cell[1014488, 22384, 68, 2, 20, "Print"],
Cell[1014559, 22388, 68, 2, 20, "Print"],
Cell[1014630, 22392, 68, 2, 20, "Print"],
Cell[1014701, 22396, 68, 2, 20, "Print"],
Cell[1014772, 22400, 68, 2, 20, "Print"],
Cell[1014843, 22404, 68, 2, 20, "Print"],
Cell[1014914, 22408, 68, 2, 20, "Print"],
Cell[1014985, 22412, 68, 2, 20, "Print"]
}, Closed]],

Cell[CellGroupData[{
Cell[1015090, 22419, 98, 2, 23, "Input"],

Cell[CellGroupData[{
Cell[1015213, 22425, 19811, 473, 184, 4633, 280, "GraphicsData", \
"PostScript", "Graphics"],
Cell[1035027, 22900, 19807, 473, 184, 4633, 280, "GraphicsData", \
"PostScript", "Graphics"],
Cell[1054837, 23375, 19843, 473, 184, 4633, 280, "GraphicsData", \
"PostScript", "Graphics"],
Cell[1074683, 23850, 19623, 474, 184, 4692, 284, "GraphicsData", \
"PostScript", "Graphics"],
Cell[1094309, 24326, 19623, 474, 184, 4692, 284, "GraphicsData", \
"PostScript", "Graphics"],
Cell[1113935, 24802, 19598, 473, 184, 4692, 284, "GraphicsData", \
"PostScript", "Graphics"],
Cell[1133536, 25277, 19028, 446, 184, 4369, 260, "GraphicsData", \
"PostScript", "Graphics"],
Cell[1152567, 25725, 18820, 440, 184, 4307, 256, "GraphicsData", \
"PostScript", "Graphics"],
Cell[1171390, 26167, 18837, 441, 184, 4307, 256, "GraphicsData", \
"PostScript", "Graphics"],
Cell[1190230, 26610, 19089, 447, 184, 4369, 260, "GraphicsData", \
"PostScript", "Graphics"],
Cell[1209322, 27059, 19069, 447, 184, 4369, 260, "GraphicsData", \
"PostScript", "Graphics"],
Cell[1228394, 27508, 23380, 520, 184, 4695, 284, "GraphicsData", \
"PostScript", "Graphics"],
Cell[1251777, 28030, 23360, 520, 184, 4695, 284, "GraphicsData", \
"PostScript", "Graphics"],
Cell[1275140, 28552, 23400, 520, 184, 4695, 284, "GraphicsData", \
"PostScript", "Graphics"],
Cell[1298543, 29074, 23327, 519, 184, 4695, 284, "GraphicsData", \
"PostScript", "Graphics"]
}, Closed]]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{
Cell[1321931, 29600, 56, 0, 20, "SubsubsectionIcon"],

Cell[CellGroupData[{
Cell[1322012, 29604, 84, 2, 70, "Input"],
Cell[1322099, 29608, 285, 7, 70, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[1322421, 29620, 86, 2, 70, "Input"],
Cell[1322510, 29624, 15542, 343, 70, 3377, 188, "GraphicsData", "PostScript", \
"Graphics",
  ImageCacheValid->False]
}, Open  ]],

Cell[CellGroupData[{
Cell[1338089, 29972, 103, 2, 70, "Input"],
Cell[1338195, 29976, 194, 4, 70, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[1338426, 29985, 86, 2, 70, "Input"],
Cell[1338515, 29989, 13314, 306, 70, 3219, 176, "GraphicsData", "PostScript", \
"Graphics",
  ImageCacheValid->False]
}, Open  ]],

Cell[CellGroupData[{
Cell[1351866, 30300, 79, 2, 70, "Input"],
Cell[1351948, 30304, 855, 19, 70, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[1352840, 30328, 97, 2, 70, "Input"],

Cell[CellGroupData[{
Cell[1352962, 30334, 16576, 359, 70, 3431, 192, "GraphicsData", "PostScript", \
"Graphics",
  ImageCacheValid->False],
Cell[1369541, 30695, 15542, 343, 70, 3377, 188, "GraphicsData", "PostScript", \
"Graphics",
  ImageCacheValid->False],
Cell[1385086, 31040, 14876, 338, 70, 3436, 192, "GraphicsData", "PostScript", \
"Graphics",
  ImageCacheValid->False]
}, Open  ]]
}, Closed]],
Cell[1399989, 31382, 1294, 23, 70, "Input"]
}, Closed]],

Cell[CellGroupData[{
Cell[1401320, 31410, 36, 0, 20, "SubsubsectionIcon"],
Cell[1401359, 31412, 91, 2, 70, "Input"],

Cell[CellGroupData[{
Cell[1401475, 31418, 245, 5, 70, "Input"],
Cell[1401723, 31425, 752, 20, 70, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[1402512, 31450, 69, 2, 70, "Input"],
Cell[1402584, 31454, 328, 5, 70, "Print"]
}, Open  ]],
Cell[1402927, 31462, 240, 4, 70, "NumberedEquation"],
Cell[1403170, 31468, 232, 4, 70, "NumberedEquation"],
Cell[1403405, 31474, 74, 2, 70, "Input"],
Cell[1403482, 31478, 821, 15, 70, "Input"],

Cell[CellGroupData[{
Cell[1404328, 31497, 403, 7, 70, "Input"],
Cell[1404734, 31506, 74775, 6230, 70, 63084, 6081, "GraphicsData", \
"PostScript", "Graphics",
  ImageCacheValid->False],
Cell[1479512, 37738, 616, 11, 70, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[1480165, 37754, 401, 7, 70, "Input"],
Cell[1480569, 37763, 85419, 6891, 70, 72010, 6720, "GraphicsData", \
"PostScript", "Graphics",
  ImageCacheValid->False],
Cell[1565991, 44656, 594, 10, 70, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[1566622, 44671, 403, 7, 70, "Input"],
Cell[1567028, 44680, 73906, 4434, 70, 51775, 4156, "GraphicsData", \
"PostScript", "Graphics",
  ImageCacheValid->False],
Cell[1640937, 49116, 569, 9, 70, "Output"]
}, Open  ]],
Cell[1641521, 49128, 86, 2, 70, "Input"],

Cell[CellGroupData[{
Cell[1641632, 49134, 203, 4, 70, "Input"],
Cell[1641838, 49140, 83, 2, 70, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[1641958, 49147, 231, 5, 70, "Input"],
Cell[1642192, 49154, 223, 5, 70, "Output"]
}, Open  ]],
Cell[1642430, 49162, 348, 8, 70, "Input"],

Cell[CellGroupData[{
Cell[1642803, 49174, 70, 2, 70, "Input"],
Cell[1642876, 49178, 248, 5, 70, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[1643161, 49188, 144, 3, 70, "Input"],
Cell[1643308, 49193, 136, 3, 70, "Output"]
}, Open  ]]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[1643505, 49203, 34, 0, 26, "SubsectionIcon"],

Cell[CellGroupData[{
Cell[1643564, 49207, 50, 0, 24, "SubsubsectionIcon"],
Cell[1643617, 49209, 177, 4, 22, "Text"],
Cell[1643797, 49215, 234, 4, 44, "NumberedEquation"],
Cell[1644034, 49221, 116, 3, 22, "Text"],
Cell[1644153, 49226, 170, 2, 49, "NumberedEquation"],
Cell[1644326, 49230, 399, 13, 22, "Text"],

Cell[CellGroupData[{
Cell[1644750, 49247, 618, 13, 19, "Input",
  CellOpen->False],
Cell[1645371, 49262, 27033, 770, 211, 6783, 515, "GraphicsData", \
"PostScript", "Graphics"]
}, Open  ]],
Cell[1672419, 50035, 430, 13, 43, "Text"],
Cell[1672852, 50050, 856, 14, 126, "NumberedEquation"],
Cell[1673711, 50066, 443, 9, 36, "Text"],
Cell[1674157, 50077, 83, 1, 28, "MathCaption"],
Cell[1674243, 50080, 65247, 4327, 184, 51775, 4156, "GraphicsData", \
"PostScript", "Graphics"],
Cell[1739493, 54409, 569, 9, 35, "Output"],
Cell[1740065, 54420, 130, 3, 22, "Text"]
}, Closed]],

Cell[CellGroupData[{
Cell[1740232, 54428, 43, 0, 20, "SubsubsectionIcon"],
Cell[1740278, 54430, 361, 6, 36, "Text"],
Cell[1740642, 54438, 317, 6, 36, "Text"],
Cell[1740962, 54446, 151, 2, 28, "NumberedEquation"],
Cell[1741116, 54450, 168, 4, 22, "Text"],
Cell[1741287, 54456, 501, 8, 50, "Text"]
}, Closed]],

Cell[CellGroupData[{
Cell[1741825, 54469, 44, 0, 20, "SubsubsectionIcon"],
Cell[1741872, 54471, 477, 8, 50, "Text"],
Cell[1742352, 54481, 295, 5, 36, "Text"],
Cell[1742650, 54488, 274, 4, 47, "NumberedEquation"],
Cell[1742927, 54494, 202, 6, 37, "Text"],
Cell[1743132, 54502, 289, 4, 44, "NumberedEquation"],
Cell[1743424, 54508, 63, 2, 22, "Text"],
Cell[1743490, 54512, 3531, 80, 57, "NumberedEquation"],
Cell[1747024, 54594, 214, 6, 36, "Text"]
}, Closed]],

Cell[CellGroupData[{
Cell[1747275, 54605, 36, 0, 20, "SubsubsectionIcon"],
Cell[1747314, 54607, 33, 0, 22, "Text"],
Cell[1747350, 54609, 254, 5, 43, "Input"],

Cell[CellGroupData[{
Cell[1747629, 54618, 224, 4, 42, "Input"],
Cell[1747856, 54624, 21792, 521, 184, 4399, 301, "GraphicsData", \
"PostScript", "Graphics"]
}, Open  ]],

Cell[CellGroupData[{
Cell[1769685, 55150, 136, 3, 26, "Input"],
Cell[1769824, 55155, 82, 2, 20, "Output"]
}, Open  ]],
Cell[1769921, 55160, 26, 0, 26, "Input"],
Cell[1769950, 55162, 341, 8, 39, "Input"],

Cell[CellGroupData[{
Cell[1770316, 55174, 85, 2, 26, "Input"],
Cell[1770404, 55178, 79, 2, 20, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[1770520, 55185, 324, 6, 79, "Input"],
Cell[1770847, 55193, 21504, 544, 184, 4828, 333, "GraphicsData", \
"PostScript", "Graphics"]
}, Open  ]],

Cell[CellGroupData[{
Cell[1792388, 55742, 229, 5, 30, "Input"],
Cell[1792620, 55749, 270, 4, 38, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[1792927, 55758, 321, 5, 43, "Input"],
Cell[1793251, 55765, 171, 3, 41, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[1793459, 55773, 71, 2, 26, "Input"],
Cell[1793533, 55777, 176, 3, 20, "Print"]
}, Open  ]],

Cell[CellGroupData[{
Cell[1793746, 55785, 107, 2, 26, "Input"],
Cell[1793856, 55789, 108, 2, 20, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[1794001, 55796, 89, 2, 26, "Input"],
Cell[1794093, 55800, 79, 2, 20, "Output"]
}, Open  ]],
Cell[1794187, 55805, 210, 5, 43, "Input"],

Cell[CellGroupData[{
Cell[1794422, 55814, 101, 2, 26, "Input"],
Cell[1794526, 55818, 73, 2, 36, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[1794636, 55825, 102, 2, 26, "Input"],
Cell[1794741, 55829, 83, 2, 20, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[1794861, 55836, 76, 2, 26, "Input"],
Cell[1794940, 55840, 79, 2, 20, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[1795056, 55847, 129, 3, 26, "Input"],
Cell[1795188, 55852, 61, 2, 20, "Output"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{
Cell[1795298, 55860, 43, 0, 20, "SubsubsectionIcon"],
Cell[1795344, 55862, 559, 10, 50, "Text"],
Cell[1795906, 55874, 598, 9, 50, "NumberedEquation"],
Cell[1796507, 55885, 350, 7, 36, "Text"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[1796906, 55898, 71, 0, 36, "SubsectionIcon"],

Cell[CellGroupData[{
Cell[1797002, 55902, 39, 0, 24, "SubsubsectionIcon"],
Cell[1797044, 55904, 48, 0, 22, "Text"],

Cell[CellGroupData[{
Cell[1797117, 55908, 175, 4, 26, "Input"],
Cell[1797295, 55914, 157, 4, 32, "Output"]
}, Open  ]],
Cell[1797467, 55921, 153, 6, 30, "MathCaption"],
Cell[1797623, 55929, 355, 8, 44, "Input"],
Cell[1797981, 55939, 85, 2, 26, "Input"],
Cell[1798069, 55943, 91, 2, 26, "Input"],
Cell[1798163, 55947, 192, 4, 42, "Input"]
}, Closed]],

Cell[CellGroupData[{
Cell[1798392, 55956, 106, 3, 20, "SubsubsectionIcon"],

Cell[CellGroupData[{
Cell[1798523, 55963, 451, 9, 57, "Input"],
Cell[1798977, 55974, 75436, 3630, 184, 50861, 3321, "GraphicsData", \
"PostScript", "Graphics"],
Cell[1874416, 59606, 79, 2, 20, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[1874532, 59613, 272, 5, 45, "Input"],
Cell[1874807, 59620, 66885, 1361, 370, 7576, 624, "GraphicsData", \
"PostScript", "Graphics"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{
Cell[1941741, 60987, 56, 0, 20, "SubsubsectionIcon"],

Cell[CellGroupData[{
Cell[1941822, 60991, 246, 5, 58, "Input"],
Cell[1942071, 60998, 99484, 3875, 184, 51123, 3273, "GraphicsData", \
"PostScript", "Graphics"],
Cell[2041558, 64875, 79, 2, 20, "Output"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{
Cell[2041686, 64883, 123, 3, 20, "SubsubsectionIcon"],

Cell[CellGroupData[{
Cell[2041834, 64890, 320, 7, 42, "Input"],
Cell[2042157, 64899, 187440, 2384, 13319, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[2229634, 67288, 89, 2, 22, "Input"],
Cell[2229726, 67292, 161, 3, 20, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[2229924, 67300, 112, 2, 26, "Input"],
Cell[2230039, 67304, 30665, 814, 184, 5609, 499, "GraphicsData", \
"PostScript", "Graphics"]
}, Open  ]],

Cell[CellGroupData[{
Cell[2260741, 68123, 103, 2, 26, "Input"],
Cell[2260847, 68127, 99, 2, 20, "Output"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{
Cell[2260995, 68135, 58, 0, 20, "SubsubsectionIcon"],
Cell[2261056, 68137, 136, 3, 22, "Text"],

Cell[CellGroupData[{
Cell[2261217, 68144, 299, 7, 42, "Input"],
Cell[2261519, 68153, 1783, 24, 200, "Output"]
}, Closed]],
Cell[2263317, 68180, 248, 5, 32, "Text"],

Cell[CellGroupData[{
Cell[2263590, 68189, 476, 10, 91, "Input"],
Cell[2264069, 68201, 108702, 2670, 334, 16356, 1525, "GraphicsData", \
"PostScript", "Graphics"],
Cell[2372774, 70873, 79, 2, 20, "Output"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{
Cell[2372902, 70881, 48, 0, 20, "SubsubsectionIcon"],

Cell[CellGroupData[{
Cell[2372975, 70885, 191, 4, 26, "Input"],
Cell[2373169, 70891, 147138, 2198, 160, 5130, 440, "GraphicsData", \
"PostScript", "Graphics"]
}, Open  ]],

Cell[CellGroupData[{
Cell[2520344, 73094, 191, 4, 26, "Input"],
Cell[2520538, 73100, 137078, 2048, 164, 4802, 410, "GraphicsData", \
"PostScript", "Graphics"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{
Cell[2657665, 75154, 50, 0, 20, "SubsubsectionIcon"],
Cell[2657718, 75156, 396, 7, 36, "Text"],
Cell[2658117, 75165, 59, 0, 22, "Text"],

Cell[CellGroupData[{
Cell[2658201, 75169, 90, 2, 26, "Input"],
Cell[2658294, 75173, 63, 2, 20, "Output"]
}, Open  ]],
Cell[2658372, 75178, 133, 3, 22, "Text"],

Cell[CellGroupData[{
Cell[2658530, 75185, 393, 9, 58, "Input"],
Cell[2658926, 75196, 63, 2, 20, "Output"]
}, Open  ]],
Cell[2659004, 75201, 144, 3, 22, "Text"],

Cell[CellGroupData[{
Cell[2659173, 75208, 98, 2, 26, "Input"],
Cell[2659274, 75212, 10584, 151, 575, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[2669895, 75368, 152, 3, 22, "Input"],
Cell[2670050, 75373, 102, 2, 20, "Output"]
}, Open  ]],
Cell[2670167, 75378, 92, 3, 22, "Text"],

Cell[CellGroupData[{
Cell[2670284, 75385, 115, 2, 26, "Input"],
Cell[2670402, 75389, 555, 11, 50, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[2670994, 75405, 110, 2, 26, "Input"],
Cell[2671107, 75409, 63, 2, 20, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[2671207, 75416, 393, 9, 58, "Input"],
Cell[2671603, 75427, 63, 2, 20, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[2671703, 75434, 103, 2, 26, "Input"],
Cell[2671809, 75438, 3873, 56, 215, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[2675719, 75499, 152, 3, 26, "Input"],
Cell[2675874, 75504, 102, 2, 20, "Output"]
}, Open  ]],
Cell[2675991, 75509, 210, 4, 22, "Text"],

Cell[CellGroupData[{
Cell[2676226, 75517, 175, 3, 26, "Input"],
Cell[2676404, 75522, 27478, 884, 184, 13039, 701, "GraphicsData", \
"PostScript", "Graphics"]
}, Open  ]],
Cell[2703897, 76409, 47, 0, 22, "Text"],

Cell[CellGroupData[{
Cell[2703969, 76413, 130, 3, 26, "Input"],
Cell[2704102, 76418, 62, 2, 20, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[2704201, 76425, 395, 9, 58, "Input"],
Cell[2704599, 76436, 62, 2, 20, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[2704698, 76443, 103, 2, 26, "Input"],
Cell[2704804, 76447, 2263, 33, 125, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[2707104, 76485, 152, 3, 26, "Input"],
Cell[2707259, 76490, 102, 2, 20, "Output"]
}, Open  ]],
Cell[2707376, 76495, 141, 3, 22, "Text"],

Cell[CellGroupData[{
Cell[2707542, 76502, 173, 3, 26, "Input"],
Cell[2707718, 76507, 26787, 830, 184, 11892, 641, "GraphicsData", \
"PostScript", "Graphics"]
}, Open  ]],
Cell[2734520, 77340, 288, 5, 36, "Text"],
Cell[2734811, 77347, 306, 7, 42, "Input"],
Cell[2735120, 77356, 4250, 112, 593, "Text"],
Cell[2739373, 77470, 307, 7, 42, "Input"],
Cell[2739683, 77479, 7752, 205, 1057, "Text"]
}, Closed]],

Cell[CellGroupData[{
Cell[2747472, 77689, 57, 0, 20, "SubsubsectionIcon"],
Cell[2747532, 77691, 198, 4, 22, "Text"],
Cell[2747733, 77697, 83, 2, 26, "Input"],
Cell[2747819, 77701, 87, 2, 26, "Input"],

Cell[CellGroupData[{
Cell[2747931, 77707, 100, 2, 26, "Input"],
Cell[2748034, 77711, 64, 2, 20, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[2748135, 77718, 98, 2, 26, "Input"],
Cell[2748236, 77722, 64, 2, 20, "Output"]
}, Open  ]],
Cell[2748315, 77727, 127, 3, 22, "Text"],
Cell[2748445, 77732, 469, 9, 30, "Input"],
Cell[2748917, 77743, 70, 0, 22, "Text"],

Cell[CellGroupData[{
Cell[2749012, 77747, 269, 5, 42, "Input"],
Cell[2749284, 77754, 1876, 32, 377, "Output"]
}, Open  ]],
Cell[2751175, 77789, 177, 4, 22, "Text"],

Cell[CellGroupData[{
Cell[2751377, 77797, 254, 5, 26, "Input"],
Cell[2751634, 77804, 27426, 520, 184, 3011, 213, "GraphicsData", \
"PostScript", "Graphics"]
}, Open  ]]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[2779121, 78331, 46, 0, 26, "SubsectionIcon"],

Cell[CellGroupData[{
Cell[2779192, 78335, 38, 0, 24, "SubsubsectionIcon"],
Cell[2779233, 78337, 451, 13, 36, "Text"],
Cell[2779687, 78352, 130, 2, 45, "NumberedEquation"],
Cell[2779820, 78356, 209, 4, 22, "Text"],
Cell[2780032, 78362, 212, 6, 22, "Text"],
Cell[2780247, 78370, 513, 9, 60, "NumberedEquation"],
Cell[2780763, 78381, 316, 10, 22, "Text"],
Cell[2781082, 78393, 610, 20, 49, "Text"],
Cell[2781695, 78415, 840, 22, 65, "NumberedEquation"],
Cell[2782538, 78439, 217, 6, 22, "Text"]
}, Closed]],

Cell[CellGroupData[{
Cell[2782792, 78450, 37, 0, 20, "SubsubsectionIcon"],
Cell[2782832, 78452, 893, 28, 50, "Text"],
Cell[2783728, 78482, 870, 21, 52, "Text"],
Cell[2784601, 78505, 883, 24, 63, "Text"],
Cell[2785487, 78531, 396, 9, 39, "Text"],
Cell[2785886, 78542, 735, 16, 75, "Text"],
Cell[2786624, 78560, 718, 25, 40, "Text"],
Cell[2787345, 78587, 55, 0, 22, "Text"],
Cell[2787403, 78589, 368, 6, 47, "NumberedEquation"],
Cell[2787774, 78597, 416, 12, 35, "Text"],
Cell[2788193, 78611, 1231, 30, 60, "NumberedEquation"],
Cell[2789427, 78643, 178, 4, 22, "Text"]
}, Closed]],

Cell[CellGroupData[{
Cell[2789642, 78652, 38, 0, 20, "SubsubsectionIcon"],
Cell[2789683, 78654, 167, 2, 27, "Input"],
Cell[2789853, 78658, 929, 18, 192, "Input"]
}, Closed]],

Cell[CellGroupData[{
Cell[2790819, 78681, 38, 0, 20, "SubsubsectionIcon"],
Cell[2790860, 78683, 273, 4, 42, "Input"],
Cell[2791136, 78689, 2452, 40, 301, "Input"]
}, Closed]],

Cell[CellGroupData[{
Cell[2793625, 78734, 56, 0, 20, "SubsubsectionIcon"],

Cell[CellGroupData[{
Cell[2793706, 78738, 212, 4, 58, "Input"],
Cell[2793921, 78744, 351, 6, 35, "Message"],
Cell[2794275, 78752, 358, 6, 50, "Message"]
}, Closed]],

Cell[CellGroupData[{
Cell[2794670, 78763, 102, 2, 22, "Input"],
Cell[2794775, 78767, 673, 11, 80, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[2795485, 78783, 164, 4, 22, "Input"],
Cell[2795652, 78789, 336, 5, 50, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[2796025, 78799, 141, 3, 22, "Input"],
Cell[2796169, 78804, 1966, 31, 431, "Output"]
}, Closed]],
Cell[2798150, 78838, 153, 4, 22, "Input"],
Cell[2798306, 78844, 192, 4, 26, "Input"],

Cell[CellGroupData[{
Cell[2798523, 78852, 70, 2, 26, "Input"],
Cell[2798596, 78856, 628, 10, 56, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[2799261, 78871, 171, 3, 26, "Input"],
Cell[2799435, 78876, 634, 11, 56, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[2800106, 78892, 171, 3, 26, "Input"],
Cell[2800280, 78897, 630, 11, 56, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[2800947, 78913, 105, 2, 26, "Input"],
Cell[2801055, 78917, 282, 5, 22, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[2801374, 78927, 272, 5, 26, "Input"],
Cell[2801649, 78934, 61, 2, 20, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[2801747, 78941, 232, 4, 26, "Input"],
Cell[2801982, 78947, 61, 2, 20, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[2802080, 78954, 290, 6, 26, "Input"],
Cell[2802373, 78962, 61, 2, 20, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[2802471, 78969, 287, 6, 26, "Input"],
Cell[2802761, 78977, 61, 2, 20, "Output"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{
Cell[2802871, 78985, 56, 0, 20, "SubsubsectionIcon"],
Cell[2802930, 78987, 1084, 17, 121, "NumberedEquation"],
Cell[2804017, 79006, 998, 23, 71, "Text"],
Cell[2805018, 79031, 18173, 488, 239, "NumberedEquation"],
Cell[2823194, 79521, 332, 7, 50, "Text"],
Cell[2823529, 79530, 412, 7, 36, "Text"],

Cell[CellGroupData[{
Cell[2823966, 79541, 76, 2, 27, "Input"],
Cell[2824045, 79545, 888, 16, 115, "Output"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{
Cell[2824982, 79567, 58, 0, 20, "SubsubsectionIcon"],
Cell[2825043, 79569, 43, 0, 22, "Text"],

Cell[CellGroupData[{
Cell[2825111, 79573, 110, 2, 27, "Input"],
Cell[2825224, 79577, 673, 11, 80, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[2825934, 79593, 164, 4, 23, "Input"],
Cell[2826101, 79599, 336, 5, 50, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[2826474, 79609, 148, 3, 23, "Input"],
Cell[2826625, 79614, 1966, 31, 431, "Output"]
}, Closed]],
Cell[2828606, 79648, 153, 4, 23, "Input"],
Cell[2828762, 79654, 192, 4, 27, "Input"],

Cell[CellGroupData[{
Cell[2828979, 79662, 70, 2, 26, "Input"],
Cell[2829052, 79666, 628, 10, 56, "Output"]
}, Open  ]]
}, Closed]]
}, Open  ]]
}
]
*)




(***********************************************************************
End of Mathematica Notebook file.
***********************************************************************)

