(***********************************************************************

                    Mathematica-Compatible Notebook

This notebook can be used on any computer system with Mathematica 4.0,
MathReader 4.0, or any compatible application. The data for the notebook 
starts with the line containing stars above.

To get the notebook into a Mathematica-compatible application, do one of 
the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing the 
word CacheID, otherwise Mathematica-compatible applications may try to 
use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
***********************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[     27356,        641]*)
(*NotebookOutlinePosition[     28966,        687]*)
(*  CellTagsIndexPosition[     28773,        678]*)
(*WindowFrame->Normal*)



Notebook[{

Cell[CellGroupData[{
Cell["RandomCoalescenceTimes, RandomGenealogy", "SubsubsectionIcon"],

Cell[TextData[Cell[BoxData[
    FormBox[GridBox[{
          {
            RowBox[{"RandomCoalescenceTimes", "[", 
              RowBox[{"n", ",", 
                FormBox[\(\(k, R\)\(]\)\),
                  
                  "TraditionalForm"]}]}], \(generates\ a\ sequence\ of\ n\ \
coalescences\ and\ recombinations, \ 
            starting\ with\ k\ lineages\ at\ t = 0; \ 
            gives\ a\ list\ of\ the\ form\ {t, \ k, \ x}\ where\ 0 < x < 
              R\ is\ the\ map\ position\ \((None\ for\ a\ coalescence\ event)\
\), \ and\ k\ is\ the\ number\ of\ lineages\ after\ the\ \(\(event\)\(.\)\(\ \
\)\)\)},
          {\(RandomCoalescenceTimes[n, R]\), \(generates\ a\ single\ item, \ 
            with\ rate\ \(k \((k - 1)\)\)\/2\ of\ coalescence\ and\ k\
\[VeryThinSpace]R\ of\ recombination\)}
          }], TraditionalForm]]]], "DefinitionBox",
  CellTags->"RandomCoalescenceTimes"],

Cell["This generates 20 events, the last of which is at t=1.66:", \
"MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[
    \(RandomCoalescenceTimes[20, 1, 2]\)], "Input",
  CellLabel->"In[2]:=  (18:22:26 on 5/12/02)"],

Cell[BoxData[
    \({{1.0975217747253834`, 2, 1.1836613948952326`}, {1.124389031599261`, 3, 
        1.9648223065105053`}, {1.2347025430272507`, 2, 
        None}, {1.4364655105993274`, 3, 
        1.6071276919921305`}, {1.4389102431477503`, 4, 
        1.0621080284534412`}, {1.5227519664700695`, 5, 
        1.5809129718306647`}, {1.5822432256873682`, 6, 
        0.23763897983628376`}, {1.6558207635330362`, 5, 
        None}, {1.8092459040110476`, 6, 
        0.05161631487220181`}, {1.8318447315834434`, 5, 
        None}, {1.919346121004915`, 4, None}, {1.960653614081735`, 5, 
        0.6322580735810266`}, {1.9857072741309114`, 6, 
        0.561132875706636`}, {2.025893604488443`, 7, 
        1.426905703109289`}, {2.026723491242351`, 8, 
        0.9487581730892964`}, {2.0470326737817426`, 7, 
        None}, {2.047256524379324`, 8, 
        1.2629701230454102`}, {2.0523359849668874`, 7, 
        None}, {2.0856687828716094`, 8, 
        0.6901157347058302`}, {2.0915982204356283`, 9, 
        1.0547548028857066`}}\)], "Output",
  CellLabel->"Out[2]=  (18:22:26 on 5/12/02)"]
}, Open  ]],

Cell["\<\
The sequence starts with a single lineage at t=0, and the \
recombination rate is R=2.  (Recall that time is scaled relative to \
2N).\
\>", "Text"],

Cell[TextData[Cell[BoxData[
    FormBox[GridBox[{
          {\(RandomGenealogy[{leaf\_1, \[Ellipsis]}, n, 
              R]\), \(\("gives a random realisation of the coalescent process \
with recombination; there are n events. "\)\(\ \)\)},
          {"\<\"DeleteNullLineages->True\"\>", "\<\"ignores null \
events.\"\>"},
          {\(RandomGenealogy[{leaf\_1, \[Ellipsis]}, {{t\_1, k\_1, 
                    x\_1} \[Ellipsis]}, 
              R]\), \(\("gives a random realisation for a specific sequence \
of events, generated by RandomCoalescenceTimes[n,k,R]; this preserves null \
lineages."\)\(\ \)\)},
          {\(PrintDetails \[Rule] 
              True\), \(prints\ details\ of\ the\ construction\)}
          }], TraditionalForm]]]], "DefinitionBox",
  CellTags->{"DeleteNullLineages", "RandomGenealogy", "PrintDetails"}],

Cell["\<\
This generates an ancestral graph, starting with a single lineage \
labelled a, and tracing back through 30 events; map length is R=2:\
\>", \
"MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[
    \(ng = RandomGenealogy[{a}, 30, 2]\)], "Input",
  CellLabel->"In[14]:=  (18:54:07 on 5/12/02)"],

Cell[BoxData[
    RowBox[{"{", 
      RowBox[{\(AncestralLineage[
          a, {0, 0.3697568713189574`}, {{a}}, {2}, {}]\), 
        ",", \(AncestralLineage[
          1, {0.3697568713189574`, 
            0.388875875515884`}, {{a}, {}}, {1.6107431062896134`, 2}, {}]\), 
        ",", \(AncestralLineage[
          2, {0.3697568713189574`, 
            0.5060161905575102`}, {{}, {a}}, {1.6107431062896134`, 2}, {}]\), 
        ",", \(AncestralLineage[
          3, {0.388875875515884`, 
            0.5743076183743029`}, {{a}, {}}, {0.8146771088761907`, 2}, {}]\), 
        ",", \(AncestralLineage[
          4, {0.388875875515884`, 
            0.717852782752764`}, {{}, {a}, {}}, {0.8146771088761907`, 
            1.6107431062896134`, 2}, {}]\), 
        ",", \(AncestralLineage[
          5, {0.5060161905575102`, 0.5921666558700702`}, {{}}, {2}, {}]\), 
        ",", \(AncestralLineage[
          6, {0.5060161905575102`, 
            0.5388977426772114`}, {{}, {a}}, {1.6107431062896134`, 2}, {}]\), 
        ",", \(AncestralLineage[
          7, {0.5388977426772114`, 1.063929294587509`}, {{}}, {2}, {}]\), 
        ",", \(AncestralLineage[
          8, {0.5388977426772114`, 
            0.5921666558700702`}, {{}, {a}}, {1.6107431062896134`, 2}, {}]\), 
        ",", \(AncestralLineage[
          9, {0.5743076183743029`, 
            0.598537598263687`}, {{a}, {}}, {0.6596846816554831`, 2}, {}]\), 
        ",", \(AncestralLineage[
          10, {0.5743076183743029`, 
            0.598537598263687`}, {{}, {a}, {}}, {0.6596846816554831`, 
            0.8146771088761907`, 2}, {}]\), 
        ",", \(AncestralLineage[
          11, {0.5921666558700702`, 
            0.6233548507988124`}, {{}, {a}}, {1.6107431062896134`, 2}, {}]\), 
        ",", \(AncestralLineage[
          12, {0.598537598263687`, 
            0.6233548507988124`}, {{a}, {}}, {0.8146771088761907`, 2}, {}]\), 
        ",", \(AncestralLineage[
          13, {0.6233548507988124`, 
            0.9413092147955694`}, {{a}, {}, {a}}, {0.8146771088761907`, 
            1.6107431062896134`, 2}, {}]\), 
        ",", \(AncestralLineage[
          14, {0.717852782752764`, 0.9303571554911366`}, {{}}, {2}, {}]\), 
        ",", \(AncestralLineage[
          15, {0.717852782752764`, 
            0.8394953689829183`}, {{}, {a}, {}}, {0.8146771088761907`, 
            1.6107431062896134`, 2}, {}]\), 
        ",", \(AncestralLineage[
          16, {0.8394953689829183`, 
            0.9303571554911366`}, {{}, {a}, {}}, {0.8146771088761907`, 
            1.5116060607945212`, 2}, {}]\), 
        ",", \(AncestralLineage[
          17, {0.8394953689829183`, 
            1.0764337193661422`}, {{}, {a}, {}}, {1.5116060607945212`, 
            1.6107431062896134`, 2}, {}]\), 
        ",", \(AncestralLineage[
          18, {0.9303571554911366`, 
            1.0493216003842252`}, {{}, {a}, {}}, {0.8146771088761907`, 
            1.5116060607945212`, 2}, {}]\), 
        ",", \(AncestralLineage[
          19, {0.9413092147955694`, 
            1.063929294587509`}, {{a}, {}}, {0.8146771088761907`, 2}, {}]\), 
        ",", \(AncestralLineage[
          20, {0.9413092147955694`, 
            1.3709354225624915`}, {{}, {a}}, {1.6107431062896134`, 2}, {}]\), 
        ",", \(AncestralLineage[
          21, {1.0493216003842252`, 1.0764337193661422`}, {{}}, {2}, {}]\), 
        ",", \(AncestralLineage[
          22, {1.0493216003842252`, 
            1.3430627465792209`}, {{}, {a}, {}}, {0.8146771088761907`, 
            1.5116060607945212`, 2}, {}]\), 
        ",", \(AncestralLineage[
          23, {1.063929294587509`, 
            1.465878748649976`}, {{a}, {}}, {0.8146771088761907`, 2}, {}]\), 
        ",", \(AncestralLineage[
          24, {1.0764337193661422`, 
            1.2814930035527659`}, {{}, {a}, {}}, {1.5116060607945212`, 
            1.6107431062896134`, 2}, {}]\), 
        ",", \(AncestralLineage[
          25, {1.2814930035527659`, 
            1.434789070946392`}, {{}, {a}, {}}, {1.5116060607945212`, 
            1.6107431062896134`, 2}, {}]\), 
        ",", \(AncestralLineage[
          26, {1.2814930035527659`, 1.3709354225624915`}, {{}}, {2}, {}]\), 
        ",", \(AncestralLineage[
          27, {1.3430627465792209`, 
            1.5034577395336226`}, {{}, {a}, {}}, {0.8146771088761907`, 
            0.9810315458288946`, 2}, {}]\), 
        ",", \(AncestralLineage[
          28, {1.3430627465792209`, 
            1.465878748649976`}, {{}, {a}, {}}, {0.9810315458288946`, 
            1.5116060607945212`, 2}, {}]\), 
        ",", \(AncestralLineage[
          29, {1.3709354225624915`, 
            1.4357302799337293`}, {{}, {a}}, {1.6107431062896134`, 2}, {}]\), 
        ",", \(AncestralLineage[
          30, {1.434789070946392`, 1.6576341498730573`}, {{}}, {2}, {}]\), 
        ",", \(AncestralLineage[
          31, {1.434789070946392`, 
            1.5034577395336226`}, {{}, {a}, {}}, {1.5116060607945212`, 
            1.6107431062896134`, 2}, {}]\), 
        ",", \(AncestralLineage[
          32, {1.4357302799337293`, 1.7008529752339288`}, {{}}, {2}, {}]\), 
        ",", \(AncestralLineage[
          33, {1.4357302799337293`, 
            1.7262665113133913`}, {{}, {a}}, {1.6107431062896134`, 2}, {}]\), 
        ",", \(AncestralLineage[
          34, {1.465878748649976`, 
            1.6089138593201835`}, {{a}, {}, {a}, {}}, {0.8146771088761907`, 
            0.9810315458288946`, 1.5116060607945212`, 2}, {}]\), 
        ",", \(AncestralLineage[
          35, {1.5034577395336226`, 
            1.6144638251375172`}, {{}, {a}, {}, {a}, {}}, \
{0.8146771088761907`, 0.9810315458288946`, 1.5116060607945212`, 
            1.6107431062896134`, 2}, {}]\), ",", 
        RowBox[{"AncestralLineage", "[", 
          RowBox[{"36", ",", 
            RowBox[{"{", 
              RowBox[{"1.6089138593201835`", ",", 
                InterpretationBox["\[Infinity]",
                  DirectedInfinity[ 1]]}], "}"}], ",", \({{a}, {}, {a}, {}}\),
             ",", \({0.8146771088761907`, 0.9810315458288946`, 
              1.3769127927069162`, 2}\), ",", \({}\)}], "]"}], 
        ",", \(AncestralLineage[
          37, {1.6089138593201835`, 
            1.6275831180991058`}, {{}, {a}, {}}, {1.3769127927069162`, 
            1.5116060607945212`, 2}, {}]\), 
        ",", \(AncestralLineage[
          38, {1.6144638251375172`, 
            1.7186917372208284`}, {{}, {a}, {}}, {0.8146771088761907`, 
            0.9810315458288946`, 2}, {}]\), 
        ",", \(AncestralLineage[
          39, {1.6144638251375172`, 
            1.6275831180991058`}, {{}, {a}, {}}, {1.5116060607945212`, 
            1.6107431062896134`, 2}, {}]\), ",", 
        RowBox[{"AncestralLineage", "[", 
          RowBox[{"40", ",", 
            RowBox[{"{", 
              RowBox[{"1.6275831180991058`", ",", 
                InterpretationBox["\[Infinity]",
                  DirectedInfinity[ 1]]}], "}"}], ",", \({{}, {a}, {}}\), 
            ",", \({1.3769127927069162`, 1.6107431062896134`, 2}\), 
            ",", \({}\)}], "]"}], ",", 
        RowBox[{"AncestralLineage", "[", 
          RowBox[{"41", ",", 
            RowBox[{"{", 
              RowBox[{"1.6576341498730573`", ",", 
                InterpretationBox["\[Infinity]",
                  DirectedInfinity[ 1]]}], "}"}], ",", \({{}}\), ",", \({2}\),
             ",", \({}\)}], "]"}], 
        ",", \(AncestralLineage[
          42, {1.6576341498730573`, 1.7008529752339288`}, {{}}, {2}, {}]\), 
        ",", \(AncestralLineage[
          43, {1.7008529752339288`, 1.730732045011957`}, {{}}, {2}, {}]\), 
        ",", \(AncestralLineage[
          44, {1.7186917372208284`, 
            1.7262665113133913`}, {{}, {a}, {}}, {0.8146771088761907`, 
            0.9810315458288946`, 2}, {}]\), ",", 
        RowBox[{"AncestralLineage", "[", 
          RowBox[{"45", ",", 
            RowBox[{"{", 
              RowBox[{"1.7186917372208284`", ",", 
                InterpretationBox["\[Infinity]",
                  DirectedInfinity[ 1]]}], "}"}], ",", \({{}}\), ",", \({2}\),
             ",", \({}\)}], "]"}], ",", 
        RowBox[{"AncestralLineage", "[", 
          RowBox[{"46", ",", 
            RowBox[{"{", 
              RowBox[{"1.7262665113133913`", ",", 
                InterpretationBox["\[Infinity]",
                  DirectedInfinity[ 1]]}], "}"}], ",", \({{}, {a}, {}, {a}}\),
             ",", \({0.8146771088761907`, 0.9810315458288946`, 
              1.6107431062896134`, 2}\), ",", \({}\)}], "]"}], ",", 
        RowBox[{"AncestralLineage", "[", 
          RowBox[{"47", ",", 
            RowBox[{"{", 
              RowBox[{"1.730732045011957`", ",", 
                InterpretationBox["\[Infinity]",
                  DirectedInfinity[ 1]]}], "}"}], ",", \({{}}\), ",", \({2}\),
             ",", \({}\)}], "]"}], ",", 
        RowBox[{"AncestralLineage", "[", 
          RowBox[{"48", ",", 
            RowBox[{"{", 
              RowBox[{"1.730732045011957`", ",", 
                InterpretationBox["\[Infinity]",
                  DirectedInfinity[ 1]]}], "}"}], ",", \({{}}\), ",", \({2}\),
             ",", \({}\)}], "]"}]}], "}"}]], "Output",
  CellLabel->"Out[14]=  (18:54:07 on 5/12/02)"]
}, Closed]],

Cell["\<\
This generates 48 new lineages, as a result of 18 recombination \
events and 12 coalescences:\
\>", "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[
    \(Length /@ {RecombinationEvents[ng], CoalescenceEvents[ng]}\)], "Input",
  CellLabel->"In[15]:=  (18:54:20 on 5/12/02)"],

Cell[BoxData[
    \({18, 12}\)], "Output",
  CellLabel->"Out[15]=  (18:54:20 on 5/12/02)"]
}, Open  ]],

Cell["\<\
Note that there are 13 null lineages, which do not carry any \
material ancestral to leaf a:\
\>", "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[
    \(NullLineages[ng]\)], "Input",
  CellLabel->"In[16]:=  (18:54:26 on 5/12/02)"],

Cell[BoxData[
    RowBox[{"{", 
      RowBox[{\(AncestralLineage[
          5, {0.5060161905575102`, 0.5921666558700702`}, {{}}, {2}, {}]\), 
        ",", \(AncestralLineage[
          7, {0.5388977426772114`, 1.063929294587509`}, {{}}, {2}, {}]\), 
        ",", \(AncestralLineage[
          14, {0.717852782752764`, 0.9303571554911366`}, {{}}, {2}, {}]\), 
        ",", \(AncestralLineage[
          21, {1.0493216003842252`, 1.0764337193661422`}, {{}}, {2}, {}]\), 
        ",", \(AncestralLineage[
          26, {1.2814930035527659`, 1.3709354225624915`}, {{}}, {2}, {}]\), 
        ",", \(AncestralLineage[
          30, {1.434789070946392`, 1.6576341498730573`}, {{}}, {2}, {}]\), 
        ",", \(AncestralLineage[
          32, {1.4357302799337293`, 1.7008529752339288`}, {{}}, {2}, {}]\), 
        ",", 
        RowBox[{"AncestralLineage", "[", 
          RowBox[{"41", ",", 
            RowBox[{"{", 
              RowBox[{"1.6576341498730573`", ",", 
                InterpretationBox["\[Infinity]",
                  DirectedInfinity[ 1]]}], "}"}], ",", \({{}}\), ",", \({2}\),
             ",", \({}\)}], "]"}], 
        ",", \(AncestralLineage[
          42, {1.6576341498730573`, 1.7008529752339288`}, {{}}, {2}, {}]\), 
        ",", \(AncestralLineage[
          43, {1.7008529752339288`, 1.730732045011957`}, {{}}, {2}, {}]\), 
        ",", 
        RowBox[{"AncestralLineage", "[", 
          RowBox[{"45", ",", 
            RowBox[{"{", 
              RowBox[{"1.7186917372208284`", ",", 
                InterpretationBox["\[Infinity]",
                  DirectedInfinity[ 1]]}], "}"}], ",", \({{}}\), ",", \({2}\),
             ",", \({}\)}], "]"}], ",", 
        RowBox[{"AncestralLineage", "[", 
          RowBox[{"47", ",", 
            RowBox[{"{", 
              RowBox[{"1.730732045011957`", ",", 
                InterpretationBox["\[Infinity]",
                  DirectedInfinity[ 1]]}], "}"}], ",", \({{}}\), ",", \({2}\),
             ",", \({}\)}], "]"}], ",", 
        RowBox[{"AncestralLineage", "[", 
          RowBox[{"48", ",", 
            RowBox[{"{", 
              RowBox[{"1.730732045011957`", ",", 
                InterpretationBox["\[Infinity]",
                  DirectedInfinity[ 1]]}], "}"}], ",", \({{}}\), ",", \({2}\),
             ",", \({}\)}], "]"}]}], "}"}]], "Output",
  CellLabel->"Out[16]=  (18:54:26 on 5/12/02)"]
}, Open  ]],

Cell["These can be discarded automatically:", "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[
    \(ng2 = 
      RandomGenealogy[{a}, 30, 2, DeleteNullLineages -> True]\)], "Input",
  CellLabel->"In[18]:=  (18:54:48 on 5/12/02)"],

Cell[BoxData[
    RowBox[{"{", 
      RowBox[{\(AncestralLineage[
          a, {0, 1.2931102825833642`}, {{a}}, {2}, {}]\), 
        ",", \(AncestralLineage[
          1, {1.2931102825833642`, 
            1.5418592121020798`}, {{a}, {}}, {1.65888301529052`, 2}, {}]\), 
        ",", \(AncestralLineage[
          2, {1.2931102825833642`, 
            1.5418592121020798`}, {{}, {a}}, {1.65888301529052`, 2}, {}]\), 
        ",", \(AncestralLineage[
          3, {1.5418592121020798`, 1.5439100112127189`}, {{a}}, {2}, {}]\), 
        ",", \(AncestralLineage[
          4, {1.5439100112127189`, 
            3.0217805333322842`}, {{a}, {}}, {0.5155289291793688`, 2}, {}]\), 
        ",", \(AncestralLineage[
          5, {1.5439100112127189`, 
            2.7511430040675675`}, {{}, {a}}, {0.5155289291793688`, 2}, {}]\), 
        ",", \(AncestralLineage[
          6, {2.7511430040675675`, 
            2.9871060694683367`}, {{}, {a}, {}}, {0.5155289291793688`, 
            1.017767946409759`, 2}, {}]\), 
        ",", \(AncestralLineage[
          7, {2.7511430040675675`, 
            3.2874063739108395`}, {{}, {a}}, {1.017767946409759`, 2}, {}]\), 
        ",", \(AncestralLineage[
          8, {2.9871060694683367`, 
            3.0217805333322842`}, {{}, {a}, {}}, {0.5155289291793688`, 
            0.5596675042147172`, 2}, {}]\), 
        ",", \(AncestralLineage[
          9, {2.9871060694683367`, 
            3.0492090269144883`}, {{}, {a}, {}}, {0.5596675042147172`, 
            1.017767946409759`, 2}, {}]\), 
        ",", \(AncestralLineage[
          10, {3.0217805333322842`, 
            3.0492090269144883`}, {{a}, {}}, {0.5596675042147172`, 2}, {}]\), 
        ",", \(AncestralLineage[
          11, {3.0492090269144883`, 
            3.329394572796431`}, {{a}, {}}, {1.017767946409759`, 2}, {}]\), 
        ",", \(AncestralLineage[
          12, {3.2874063739108395`, 
            3.339788725611383`}, {{}, {a}, {}}, {1.017767946409759`, 
            1.596485271930735`, 2}, {}]\), 
        ",", \(AncestralLineage[
          13, {3.2874063739108395`, 
            3.329394572796431`}, {{}, {a}}, {1.596485271930735`, 2}, {}]\), 
        ",", \(AncestralLineage[
          14, {3.329394572796431`, 
            3.339788725611383`}, {{a}, {}, {a}}, {1.017767946409759`, 
            1.596485271930735`, 2}, {}]\), 
        ",", \(AncestralLineage[
          15, {3.339788725611383`, 5.142169409293015`}, {{a}}, {2}, {}]\), 
        ",", \(AncestralLineage[
          16, {5.142169409293015`, 
            5.3452196725517975`}, {{a}, {}}, {1.8349171870073442`, 2}, {}]\), 
        ",", \(AncestralLineage[
          17, {5.142169409293015`, 
            5.370066237137177`}, {{}, {a}}, {1.8349171870073442`, 2}, {}]\), 
        ",", \(AncestralLineage[
          18, {5.3452196725517975`, 
            5.370066237137177`}, {{a}, {}}, {1.4285766863998894`, 2}, {}]\), 
        ",", 
        RowBox[{"AncestralLineage", "[", 
          RowBox[{"19", ",", 
            RowBox[{"{", 
              RowBox[{"5.3452196725517975`", ",", 
                InterpretationBox["\[Infinity]",
                  DirectedInfinity[ 1]]}], "}"}], ",", \({{}, {a}, {}}\), 
            ",", \({1.4285766863998894`, 1.8349171870073442`, 2}\), 
            ",", \({}\)}], "]"}], 
        ",", \(AncestralLineage[
          20, {5.370066237137177`, 
            5.95289627485502`}, {{a}, {}, {a}}, {1.4285766863998894`, 
            1.8349171870073442`, 2}, {}]\), 
        ",", \(AncestralLineage[
          21, {5.95289627485502`, 
            6.1046808447868015`}, {{a}, {}}, {1.3412740579995084`, 2}, {}]\), 
        ",", 
        RowBox[{"AncestralLineage", "[", 
          RowBox[{"22", ",", 
            RowBox[{"{", 
              RowBox[{"5.95289627485502`", ",", 
                InterpretationBox["\[Infinity]",
                  DirectedInfinity[ 1]]}], "}"}], ",", \({{}, {a}, {}, {a}}\),
             ",", \({1.3412740579995084`, 1.4285766863998894`, 
              1.8349171870073442`, 2}\), ",", \({}\)}], "]"}], ",", 
        RowBox[{"AncestralLineage", "[", 
          RowBox[{"23", ",", 
            RowBox[{"{", 
              RowBox[{"6.1046808447868015`", ",", 
                InterpretationBox["\[Infinity]",
                  DirectedInfinity[ 1]]}], "}"}], ",", \({{a}, {}}\), 
            ",", \({0.18365840256476587`, 2}\), ",", \({}\)}], "]"}], ",", 
        RowBox[{"AncestralLineage", "[", 
          RowBox[{"24", ",", 
            RowBox[{"{", 
              RowBox[{"6.1046808447868015`", ",", 
                InterpretationBox["\[Infinity]",
                  DirectedInfinity[ 1]]}], "}"}], ",", \({{}, {a}, {}}\), 
            ",", \({0.18365840256476587`, 1.3412740579995084`, 2}\), 
            ",", \({}\)}], "]"}]}], "}"}]], "Output",
  CellLabel->"Out[18]=  (18:54:48 on 5/12/02)"]
}, Open  ]],

Cell["\<\
It is possible to specify a sequence of times and map \
positions:\
\>", "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[
    \(rct = RandomCoalescenceTimes[10, 1, 2]\)], "Input",
  CellLabel->"In[8]:=  (18:49:21 on 5/12/02)"],

Cell[BoxData[
    \({{1.0834710899574316`, 2, 0.5514937589378298`}, {1.3016369895154458`, 
        3, 0.28048770078529417`}, {1.3371610243153924`, 4, 
        1.5093690623324933`}, {1.3931068672950018`, 5, 
        1.7569512269596672`}, {1.4057695726794919`, 6, 
        0.6577367316082029`}, {1.4904439300235195`, 7, 
        1.8979880201401085`}, {1.512485734204744`, 8, 
        1.1353658261113813`}, {1.5169115402735052`, 7, 
        None}, {1.5228165484843137`, 6, None}, {1.524887635253425`, 5, 
        None}}\)], "Output",
  CellLabel->"Out[8]=  (18:49:21 on 5/12/02)"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(ng3 = RandomGenealogy[{a}, rct, 2]\)], "Input",
  CellLabel->"In[9]:=  (18:49:23 on 5/12/02)"],

Cell[BoxData[
    RowBox[{"{", 
      RowBox[{\(AncestralLineage[
          a, {0, 1.0834710899574316`}, {{a}}, {2}, {}]\), 
        ",", \(AncestralLineage[
          1, {1.0834710899574316`, 
            1.3016369895154458`}, {{a}, {}}, {0.5514937589378298`, 2}, {}]\), 
        ",", \(AncestralLineage[
          2, {1.0834710899574316`, 
            1.3371610243153924`}, {{}, {a}}, {0.5514937589378298`, 2}, {}]\), 
        ",", \(AncestralLineage[
          3, {1.3016369895154458`, 
            1.4904439300235195`}, {{a}, {}}, {0.28048770078529417`, 2}, {}]\),
         ",", \(AncestralLineage[
          4, {1.3016369895154458`, 
            1.5169115402735052`}, {{}, {a}, {}}, {0.28048770078529417`, 
            0.5514937589378298`, 2}, {}]\), 
        ",", \(AncestralLineage[
          5, {1.3371610243153924`, 
            1.3931068672950018`}, {{}, {a}, {}}, {0.5514937589378298`, 
            1.5093690623324933`, 2}, {}]\), 
        ",", \(AncestralLineage[
          6, {1.3371610243153924`, 
            1.5228165484843137`}, {{}, {a}}, {1.5093690623324933`, 2}, {}]\), 
        ",", \(AncestralLineage[
          7, {1.3931068672950018`, 
            1.524887635253425`}, {{}, {a}, {}}, {0.5514937589378298`, 
            1.5093690623324933`, 2}, {}]\), 
        ",", \(AncestralLineage[
          8, {1.3931068672950018`, 1.4057695726794919`}, {{}}, {2}, {}]\), 
        ",", 
        RowBox[{"AncestralLineage", "[", 
          RowBox[{"9", ",", 
            RowBox[{"{", 
              RowBox[{"1.4057695726794919`", ",", 
                InterpretationBox["\[Infinity]",
                  DirectedInfinity[ 1]]}], "}"}], ",", \({{}}\), ",", \({2}\),
             ",", \({}\)}], "]"}], ",", 
        RowBox[{"AncestralLineage", "[", 
          RowBox[{"10", ",", 
            RowBox[{"{", 
              RowBox[{"1.4057695726794919`", ",", 
                InterpretationBox["\[Infinity]",
                  DirectedInfinity[ 1]]}], "}"}], ",", \({{}}\), ",", \({2}\),
             ",", \({}\)}], "]"}], 
        ",", \(AncestralLineage[
          11, {1.4904439300235195`, 
            1.512485734204744`}, {{a}, {}}, {0.28048770078529417`, 2}, {}]\), 
        ",", 
        RowBox[{"AncestralLineage", "[", 
          RowBox[{"12", ",", 
            RowBox[{"{", 
              RowBox[{"1.4904439300235195`", ",", 
                InterpretationBox["\[Infinity]",
                  DirectedInfinity[ 1]]}], "}"}], ",", \({{}}\), ",", \({2}\),
             ",", \({}\)}], "]"}], 
        ",", \(AncestralLineage[
          13, {1.512485734204744`, 
            1.5169115402735052`}, {{a}, {}}, {0.28048770078529417`, 2}, {}]\),
         ",", 
        RowBox[{"AncestralLineage", "[", 
          RowBox[{"14", ",", 
            RowBox[{"{", 
              RowBox[{"1.512485734204744`", ",", 
                InterpretationBox["\[Infinity]",
                  DirectedInfinity[ 1]]}], "}"}], ",", \({{}}\), ",", \({2}\),
             ",", \({}\)}], "]"}], 
        ",", \(AncestralLineage[
          15, {1.5169115402735052`, 
            1.5228165484843137`}, {{a}, {}}, {0.5514937589378298`, 2}, {}]\), 
        ",", \(AncestralLineage[
          16, {1.5228165484843137`, 
            1.524887635253425`}, {{a}, {}, {a}}, {0.5514937589378298`, 
            1.5093690623324933`, 2}, {}]\), ",", 
        RowBox[{"AncestralLineage", "[", 
          RowBox[{"17", ",", 
            RowBox[{"{", 
              RowBox[{"1.524887635253425`", ",", 
                InterpretationBox["\[Infinity]",
                  DirectedInfinity[ 1]]}], "}"}], ",", \({{a}}\), 
            ",", \({2}\), ",", \({}\)}], "]"}]}], "}"}]], "Output",
  CellLabel->"Out[9]=  (18:49:23 on 5/12/02)"]
}, Open  ]]
}, Closed]]
},
FrontEndVersion->"4.0 for Macintosh",
ScreenRectangle->{{0, 1024}, {0, 748}},
WindowSize->{520, 626},
WindowMargins->{{169, Automatic}, {Automatic, 1}},
StyleDefinitions -> "HelpBrowser.nb",
MacintoshSystemPageSetup->"\<\
00h0001804P000000b02<?oaonl3>@91H`85N0?N0@00005X0FP000003j0:l001
0@00I00100000@0200000BL?00400000000000000000010000000000000@0?ne
oj/@7@]500P1000000000000000001T1\>"
]


(***********************************************************************
Cached data follows.  If you edit this Notebook file directly, not using
Mathematica, you must remove the line containing CacheID at the top of 
the file.  The cache data will then be recreated when you save this file 
from within Mathematica.
***********************************************************************)

(*CellTagsOutline
CellTagsIndex->{
  "RandomCoalescenceTimes"->{
    Cell[1810, 53, 898, 18, 92, "DefinitionBox",
      CellTags->"RandomCoalescenceTimes"]},
  "DeleteNullLineages"->{
    Cell[4196, 111, 833, 15, 108, "DefinitionBox",
      CellTags->{"DeleteNullLineages", "RandomGenealogy", "PrintDetails"}]},
  "RandomGenealogy"->{
    Cell[4196, 111, 833, 15, 108, "DefinitionBox",
      CellTags->{"DeleteNullLineages", "RandomGenealogy", "PrintDetails"}]},
  "PrintDetails"->{
    Cell[4196, 111, 833, 15, 108, "DefinitionBox",
      CellTags->{"DeleteNullLineages", "RandomGenealogy", "PrintDetails"}]}
  }
*)

(*CellTagsIndex
CellTagsIndex->{
  {"RandomCoalescenceTimes", 28202, 662},
  {"DeleteNullLineages", 28321, 665},
  {"RandomGenealogy", 28472, 668},
  {"PrintDetails", 28620, 671}
  }
*)

(*NotebookFileOutline
Notebook[{

Cell[CellGroupData[{
Cell[1739, 51, 68, 0, 24, "SubsubsectionIcon"],
Cell[1810, 53, 898, 18, 92, "DefinitionBox",
  CellTags->"RandomCoalescenceTimes"],
Cell[2711, 73, 82, 1, 28, "MathCaption"],

Cell[CellGroupData[{
Cell[2818, 78, 112, 2, 27, "Input"],
Cell[2933, 82, 1087, 20, 59, "Output"]
}, Open  ]],
Cell[4035, 105, 158, 4, 22, "Text"],
Cell[4196, 111, 833, 15, 108, "DefinitionBox",
  CellTags->{"DeleteNullLineages", "RandomGenealogy", "PrintDetails"}],
Cell[5032, 128, 167, 4, 28, "MathCaption"],

Cell[CellGroupData[{
Cell[5224, 136, 113, 2, 27, "Input"],
Cell[5340, 140, 9195, 190, 410, "Output"]
}, Closed]],
Cell[14550, 333, 124, 3, 18, "MathCaption"],

Cell[CellGroupData[{
Cell[14699, 340, 139, 2, 27, "Input"],
Cell[14841, 344, 90, 2, 20, "Output"]
}, Open  ]],
Cell[14946, 349, 123, 3, 28, "MathCaption"],

Cell[CellGroupData[{
Cell[15094, 356, 97, 2, 27, "Input"],
Cell[15194, 360, 2371, 50, 85, "Output"]
}, Open  ]],
Cell[17580, 413, 60, 0, 28, "MathCaption"],

Cell[CellGroupData[{
Cell[17665, 417, 149, 3, 27, "Input"],
Cell[17817, 422, 4823, 101, 189, "Output"]
}, Open  ]],
Cell[22655, 526, 97, 3, 28, "MathCaption"],

Cell[CellGroupData[{
Cell[22777, 533, 118, 2, 27, "Input"],
Cell[22898, 537, 577, 10, 33, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[23512, 552, 114, 2, 27, "Input"],
Cell[23629, 556, 3699, 81, 137, "Output"]
}, Open  ]]
}, Closed]]
}
]
*)




(***********************************************************************
End of Mathematica Notebook file.
***********************************************************************)

