(************** Content-type: application/mathematica **************
                     CreatedBy='Mathematica 4.2'

                    Mathematica-Compatible Notebook

This notebook can be used with any Mathematica-compatible
application, such as Mathematica, MathReader or Publicon. The data
for the notebook starts with the line containing stars above.

To get the notebook into a Mathematica-compatible application, do
one of the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the
  application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing
the word CacheID, otherwise Mathematica-compatible applications may
try to use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
*******************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[    423801,       9436]*)
(*NotebookOutlinePosition[    424476,       9459]*)
(*  CellTagsIndexPosition[    424432,       9455]*)
(*WindowFrame->Normal*)



Notebook[{
Cell[TextData[{
  "Note: ",
  StyleBox["The values given here are examples only: to check results for \
your sample, just re-evaluate the input cells",
    FontWeight->"Plain"]
}], "Text",
  FontWeight->"Bold"],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Basic properties of the coalescent ",
  FontColor->RGBColor[0, 0, 1]]], "SubsectionIcon"],

Cell[CellGroupData[{

Cell[TextData[{
  StyleBox["Q1:",
    FontColor->RGBColor[0, 0, 1]],
  " Compare the mean depth, length, and pairwise divergence with the \
theoretical expectation"
}], "SubsubsectionIcon"],

Cell[TextData[{
  "The depth, D,  of the genealogy is the sum of the times for which there \
are ",
  Cell[BoxData[
      \(TraditionalForm\`\(\(k\)\(,\)\(\ \)\(k - 
        1\)\(,\)\(\[Ellipsis]\)\(,\)\(\ \)\(2\)\(\ \)\)\)]],
  "lineages.  The expected time for ",
  Cell[BoxData[
      \(TraditionalForm\`k\)]],
  " lineages to coalesce into ",
  Cell[BoxData[
      \(TraditionalForm\`k - 1\)]],
  " lineages is ",
  Cell[BoxData[
      \(TraditionalForm\`E[t\_k] = 2 \( N\_e\) 2\/\(k(k - 1)\)\)]],
  ".  Throughout, we scale time relative to ",
  Cell[BoxData[
      \(TraditionalForm\`2  N\_e\)]],
  ", so ",
  Cell[BoxData[
      \(TraditionalForm\`T\_k = \(\(t\_k\/\(2  N\_e\)\)\(=\)\)\)]],
  Cell[BoxData[
      \(TraditionalForm\`2\/\(k(k - 1)\)\)]],
  ".  Thus:"
}], "Text"],

Cell[BoxData[
    \(E[D]\  = \ \(\[Sum]\+\(j = 2\)\%k T\_j\  = \ \(\[Sum]\+\(j = 2\)\%k 2\/\
\(j \((j - 1)\)\)\  = \ \(\[Sum]\+\(j = 2\)\%k 
                2 \((1\/\(j - 1\) - 1\/j)\)\  = \ 
            2 \((1 - 1\/k)\)\)\)\)\)], "DisplayMath"],

Cell["\<\
The mean depth of the genealogy in the sample of 10 genes fits \
quite well:\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \({Mean[depthList], 2 \((1 - 1\/10. )\)}\)], "Input",
  CellLabel->"In[54]:="],

Cell[BoxData[
    \({1.870002776015909`, 1.8`}\)], "Output",
  CellLabel->"Out[54]="]
}, Open  ]],

Cell["A t-test for the deviation is not significant:", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\((Mean[depthList] - 2 \((1 - 1\/10. )\))\)/
      StandardErrorOfSampleMean[depthList]\)], "Input",
  CellLabel->"In[57]:="],

Cell[BoxData[
    \(0.8622380096396489`\)], "Output",
  CellLabel->"Out[57]="]
}, Open  ]],

Cell["\<\
The expected length, L,  of the genealogy is found in a similar \
way:\
\>", "Text"],

Cell[BoxData[
    \(E[L]\  = \ \(\[Sum]\+\(j = 2\)\%k 
            j\[VeryThinSpace]T\_j\  = \ \(\[Sum]\+\(j = 2\)\%k 2\/\(j - 1\)\  \
= 2 \((1 + 1\/2 + \[Ellipsis]  1\/\(k - 1\))\)~\ 2 
             Log[1.78\ k]\ for\ large\ k\)\)\)], "DisplayMath"],

Cell["\<\
The mean depth of the genealogy in the sample fits quite well, and \
a t-test is again not significant:\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \({Mean[
        lengthList], \ \[Sum]\+\(j = 2\)\%10 2. \/\(j - 1\), \((Mean[
              lengthList] - \[Sum]\+\(j = 2\)\%10 2. \/\(j - 1\))\)/
        StandardErrorOfSampleMean[lengthList]}\)], "Input",
  CellLabel->"In[60]:="],

Cell[BoxData[
    \({5.85805946444879`, 5.657936507936507`, 
      1.0961998156418904`}\)], "Output",
  CellLabel->"Out[60]="]
}, Open  ]],

Cell["\<\
The expected length, L,  of the genealogy is found in a similar \
way:\
\>", "Text"],

Cell[BoxData[
    \(E[L]\  = \ \(\[Sum]\+\(j = 2\)\%k 
            j\[VeryThinSpace]T\_j\  = \ \(\[Sum]\+\(j = 2\)\%k 2\/\(j - 1\)\  \
= 2 \((1 + 1\/2 + \[Ellipsis]  1\/\(k - 1\))\)~\ 2 
             Log[1.78\ k]\ for\ large\ k\)\)\)], "DisplayMath"],

Cell[TextData[{
  "The mean pairwise divergence time is just ",
  Cell[BoxData[
      \(TraditionalForm\`t = 2  N\_e\)]],
  ", or ",
  Cell[BoxData[
      \(TraditionalForm\`T = 1\)]],
  ".  Again, this fits well, and a t-test is again not significant:"
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \({Mean[pdList], 
      1, \((Mean[pdList] - 1)\)/StandardErrorOfSampleMean[pdList]}\)], "Input",\

  CellLabel->"In[64]:="],

Cell[BoxData[
    \({1.0176205502824094`, 1, 0.46771913934926135`}\)], "Output",
  CellLabel->"Out[64]="]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData[{
  StyleBox["Q2:",
    FontColor->RGBColor[0, 0, 1]],
  " How variable are these measures?  Would they become less variable if more \
genes were sampled (say, 20 instead of 10)?"
}], "SubsubsectionIcon"],

Cell["\<\
The distribution of depths is spread widely about the expected \
value of 1.8:\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(ListPlot[
        Transpose[{Range[0.1, 9.9, 0.2], 
            BinCounts[depthList, {0, 10, 0.2}]}], 
        PlotJoined \[Rule] True];\)\), "\[IndentingNewLine]", 
    \(Variance[depthList]\)}], "Input",
  CellLabel->"In[71]:="],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.0962001 0.0147151 0.0235442 [
[.21621 .00222 -3 -9 ]
[.21621 .00222 3 0 ]
[.40861 .00222 -3 -9 ]
[.40861 .00222 3 0 ]
[.60101 .00222 -3 -9 ]
[.60101 .00222 3 0 ]
[.79341 .00222 -3 -9 ]
[.79341 .00222 3 0 ]
[.98581 .00222 -6 -9 ]
[.98581 .00222 6 0 ]
[.01131 .13244 -6 -4.5 ]
[.01131 .13244 0 4.5 ]
[.01131 .25016 -12 -4.5 ]
[.01131 .25016 0 4.5 ]
[.01131 .36788 -12 -4.5 ]
[.01131 .36788 0 4.5 ]
[.01131 .4856 -12 -4.5 ]
[.01131 .4856 0 4.5 ]
[.01131 .60332 -12 -4.5 ]
[.01131 .60332 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.21621 .01472 m
.21621 .02097 L
s
[(2)] .21621 .00222 0 1 Mshowa
.40861 .01472 m
.40861 .02097 L
s
[(4)] .40861 .00222 0 1 Mshowa
.60101 .01472 m
.60101 .02097 L
s
[(6)] .60101 .00222 0 1 Mshowa
.79341 .01472 m
.79341 .02097 L
s
[(8)] .79341 .00222 0 1 Mshowa
.98581 .01472 m
.98581 .02097 L
s
[(10)] .98581 .00222 0 1 Mshowa
.125 Mabswid
.07191 .01472 m
.07191 .01847 L
s
.12001 .01472 m
.12001 .01847 L
s
.16811 .01472 m
.16811 .01847 L
s
.26431 .01472 m
.26431 .01847 L
s
.31241 .01472 m
.31241 .01847 L
s
.36051 .01472 m
.36051 .01847 L
s
.45671 .01472 m
.45671 .01847 L
s
.50481 .01472 m
.50481 .01847 L
s
.55291 .01472 m
.55291 .01847 L
s
.64911 .01472 m
.64911 .01847 L
s
.69721 .01472 m
.69721 .01847 L
s
.74531 .01472 m
.74531 .01847 L
s
.84151 .01472 m
.84151 .01847 L
s
.88961 .01472 m
.88961 .01847 L
s
.93771 .01472 m
.93771 .01847 L
s
.25 Mabswid
0 .01472 m
1 .01472 L
s
.02381 .13244 m
.03006 .13244 L
s
[(5)] .01131 .13244 1 0 Mshowa
.02381 .25016 m
.03006 .25016 L
s
[(10)] .01131 .25016 1 0 Mshowa
.02381 .36788 m
.03006 .36788 L
s
[(15)] .01131 .36788 1 0 Mshowa
.02381 .4856 m
.03006 .4856 L
s
[(20)] .01131 .4856 1 0 Mshowa
.02381 .60332 m
.03006 .60332 L
s
[(25)] .01131 .60332 1 0 Mshowa
.125 Mabswid
.02381 .03826 m
.02756 .03826 L
s
.02381 .0618 m
.02756 .0618 L
s
.02381 .08535 m
.02756 .08535 L
s
.02381 .10889 m
.02756 .10889 L
s
.02381 .15598 m
.02756 .15598 L
s
.02381 .17952 m
.02756 .17952 L
s
.02381 .20307 m
.02756 .20307 L
s
.02381 .22661 m
.02756 .22661 L
s
.02381 .2737 m
.02756 .2737 L
s
.02381 .29724 m
.02756 .29724 L
s
.02381 .32079 m
.02756 .32079 L
s
.02381 .34433 m
.02756 .34433 L
s
.02381 .39142 m
.02756 .39142 L
s
.02381 .41497 m
.02756 .41497 L
s
.02381 .43851 m
.02756 .43851 L
s
.02381 .46205 m
.02756 .46205 L
s
.02381 .50914 m
.02756 .50914 L
s
.02381 .53269 m
.02756 .53269 L
s
.02381 .55623 m
.02756 .55623 L
s
.02381 .57977 m
.02756 .57977 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.03343 .01472 m
.05267 .01472 L
.07191 .22661 L
.09115 .39142 L
.11039 .36788 L
.12963 .60332 L
.14887 .41497 L
.16811 .43851 L
.18735 .39142 L
.20659 .34433 L
.22583 .2737 L
.24507 .15598 L
.26431 .34433 L
.28355 .20307 L
.30279 .15598 L
.32203 .15598 L
.34127 .08535 L
.36051 .01472 L
.37975 .17952 L
.39899 .01472 L
.41823 .0618 L
.43747 .03826 L
.45671 .03826 L
.47595 .03826 L
.49519 .03826 L
.51443 .01472 L
.53367 .01472 L
.55291 .01472 L
.57215 .01472 L
.59139 .01472 L
.61063 .01472 L
.62987 .03826 L
.64911 .01472 L
.66835 .01472 L
.68759 .01472 L
.70683 .03826 L
.72607 .01472 L
.74531 .01472 L
.76455 .01472 L
.78379 .01472 L
.80303 .01472 L
.82227 .03826 L
.84151 .01472 L
.86075 .01472 L
.87999 .01472 L
.89923 .01472 L
.91847 .01472 L
.93771 .01472 L
.95695 .01472 L
.97619 .01472 L
Mistroke
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[71]:=",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/B000`400?l00000o`00003ooooooolQ
ooooo`00@_ooool5o`0003;ooooo0ol0000`ooooo`?o0000<Oooool3o`0002kooooo0ol00004oooo
o`;o00001_ooool004?ooooo00Co0000oooooooooooo0000<oooool00ol0003oooooooooo`0^oooo
o`05o`000?ooooooooooooooool00000;oooool01Ol0003ooooooooooooooooo000002kooooo00?o
0000ooooooooool00_ooool01?l0003oooooooooool00005ooooo`00A?ooool00ol0003ooooooooo
o`0`ooooo`Go0000;oooool01Ol0003ooooooooooooooooo000002oooooo00Go0000oooooooooooo
ooooo`00000^ooooo`03o`000?oooooooooo00;ooooo00Co0000oooooooooooo00001Oooool004Go
oooo00?o0000ooooooooool0;oooool01?l0003oooooooooool0000`ooooo`Co0000<Oooool3o`00
02oooooo00?o0000ooooooooool00_ooool01?l0003oooooooooool00005ooooo`00@_ooool01Ol0
003ooooooooooooooooo0000037ooooo00?o0000ooooool00000<?ooool00ol0003oooooooooo`0a
ooooo`05o`000?ooooooooooooooool00000;_ooool00ol0003oooooooooo`02ooooo`04o`000?oo
ooooooooo`0000Gooooo0012ooooo`05o`000?ooooooooooooooool00000<_ooool2o`00037ooooo
00?o0000ooooooooool0<?ooool01Ol0003ooooooooooooooooo000002gooooo0_l00004ooooo`04
o`000?ooooooooooo`0000Gooooo0013ooooo`?o0000=?ooool00ol0003oooooooooo`0`ooooo`;o
0000<Oooool3o`0002oooooo00?o0000ooooooooool00oooool2o`0000Kooooo000Aooooo`03o`00
0?oooooooooo0?oooooo3Oooool0017ooooo00?o0000ooooooooool0ooooool=ooooo`004Oooool0
0ol0003oooooooooo`3oooooo`gooooo000Aooooo`03o`000?oooooooooo0?oooooo3Oooool000[o
ooooool0000Bo`0000Gooooo000Aooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0
0_ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool0
2_ooool00`00003oooooooooo`0:ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool0
2_ooool00ol0003oooooooooo`08ooooo`04o`000?ooooooooooo`0000cooooo00?o0000oooooooo
ool02_ooool00ol0003oooooo`00000:ooooo`03o`000?oooooooooo00[ooooo00Co0000oooooooo
oooo00002Oooool00ol0003oooooooooo`08ooooo`03o`000?oooooo000000Oooooo00?o0000oooo
ooooool00_ooool00ol0003oooooooooo`0:ooooo`04o`000?ooooooooooo`0000Wooooo00?o0000
ooooooooool02_ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00[ooooo00?o0000
ooooooooool01oooool0017ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`0Yoooo
o`0300000?oooooooooo02Cooooo00?o0000ooooooooool02?ooool2o`000003ooooool0003ooooo
01Wooooo00?o0000ooooooooool05_ooool01Ol0003ooooooooooooooooo000000Oooooo00?o0000
ooooooooool02_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo013ooooo00Go0000
ooooooooooooooooo`000007ooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool01ooo
ool0017ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`1?ooooo`;o00002_ooool2
o`0001_ooooo00?o0000ooooooooool07?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooo
oooo00cooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`0Fooooo`03o`000?oooooo
oooo00?ooooo00?o0000ooooooooool0<?ooool0017ooooo00?o0000ooooooooool01Oooool00ol0
003oooooooooo`1?ooooo`;o00002_ooool2o`0001[ooooo00?o0000ooooooooool07_ooool01Ol0
003ooooooooooooooooo0000013ooooo00Go0000ooooooooooooooooo`00000Jooooo`05o`000?oo
ooooooooooooool00000<oooool0017ooooo00?o0000ooooooooool01Oooool00ol0003ooooooooo
o`1?ooooo`03o`000?oooooo000000Sooooo00Co0000oooooooooooo00006?ooool00ol0003ooooo
ooooo`0Pooooo`03o`000?oooooo000001;ooooo00?o0000ooooool000007?ooool00ol0003ooooo
o`00000dooooo`004Oooool2o`0000Kooooo00?o0000ooooooooool0Coooool00ol0003oooooo`00
0008ooooo`04o`000?ooooooooooo`0000Oooooo4Ol0000Tooooo`03o`000?oooooooooo01;ooooo
00?o0000ooooooooool07?ooool00ol0003oooooooooo`0cooooo`004Oooool00ol0003ooooooooo
o`06ooooo`03o`000?oooooooooo04gooooo00Co0000oooooooooooo00002?ooool01Ol0003ooooo
oooooooooooo000000Kooooo00?o0000ooooooooool0W?ooool0017ooooo00?o0000ooooooooool0
1_ooool00ol0003oooooooooo`1=ooooo`04o`000?ooooooooooo`0000Sooooo00Go0000oooooooo
ooooooooo`000005ooooo`03o`000?oooooooooo09gooooo000Aooooo`03o`000?oooooooooo00Ko
oooo00?o0000ooooooooool0COooool01?l0003oooooooooool00008ooooo`05o`000?oooooooooo
ooooool000001?ooool00ol0003oooooooooo`2Nooooo`004Oooool00ol0003oooooooooo`06oooo
o`03o`000?oooooooooo04cooooo00Go0000ooooooooooooooooo`000008ooooo`03o`000?oooooo
oooo00;ooooo00Co0000oooooooooooo0000XOooool0017ooooo00?o0000ooooooooool01_ooool0
0ol0003oooooooooo`1<ooooo`05o`000?ooooooooooooooool000002?ooool00ol0003ooooooooo
o`02ooooo`04o`000?ooooooooooo`000:7ooooo000Aooooo`03o`000?oooooooooo00Kooooo00?o
0000ooooooooool0C?ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Gooooo00?o
0000ooooooooool00_ooool00ol0003oooooo`00002Rooooo`004Oooool2o`0000Oooooo00?o0000
ooooooooool0C?ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Gooooo00?o0000
ooooooooool00oooool00ol0003oooooooooo`2Qooooo`004Oooool00ol0003oooooooooo`06oooo
o`03o`000?oooooooooo04_ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`04oooo
o`03o`000?oooooooooo0:Sooooo000Aooooo`03o`000?oooooooooo00Kooooo00?o0000oooooooo
ool0Boooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Cooooo00?o0000oooooooo
ool0Z?ooool0017ooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`1;ooooo`03o`00
0?oooooooooo00?ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`2Xooooo`004Ooo
ool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo04_ooooo00?o0000ooooooooool00ooo
ool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo0:Sooooo000Aooooo`03o`000?oooooo
oooo00Oooooo00?o0000ooooooooool0BOooool00ol0003oooooooooo`04ooooo`03o`000?oooooo
oooo00Cooooo00?o0000ooooooooool0Z?ooool0017ooooo0_l00008ooooo`03o`000?oooooooooo
04Wooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo
0:Sooooo000Aooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0BOooool00ol0003o
ooooooooo`05ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0Z?ooool0017ooooo
00?o0000ooooooooool01oooool00ol0003oooooooooo`19ooooo`03o`000?oooooooooo00Gooooo
00?o0000ooooooooool00oooool00ol0003oooooooooo`2Xooooo`004Oooool00ol0003ooooooooo
o`07ooooo`03o`000?oooooooooo04Sooooo00?o0000ooooooooool01_ooool00ol0003ooooooooo
o`03ooooo`03o`000?oooooooooo0:Sooooo000Aooooo`03o`000?oooooooooo00Oooooo00?o0000
ooooooooool0B?ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00;ooooo00?o0000
ooooooooool0ZOooool0017ooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`18oooo
o`03o`000?oooooooooo00Kooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`2Yoooo
o`004Oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo04Sooooo00?o0000oooooooo
ool01_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo0:Wooooo000Aooooo`;o0000
2?ooool00ol0003oooooooooo`17ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0
0_ooool00ol0003oooooooooo`2Yooooo`004Oooool00ol0003oooooooooo`07ooooo`03o`000?oo
oooooooo04Oooooo00?o0000ooooooooool02?ooool01Ol0003ooooooooooooooooo00000:_ooooo
000Aooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0Aoooool00ol0003ooooooooo
o`08ooooo`05o`000?ooooooooooooooool00000Zoooool000Wooooo0ol00005ooooo`03o`000?oo
oooooooo00Oooooo00?o0000ooooooooool0A_ooool00ol0003oooooooooo`09ooooo`05o`000?oo
ooooooooooooool00000Zoooool000Sooooo00Go0000ooooooooooooooooo`000004ooooo`03o`00
0?oooooooooo00Sooooo00?o0000ooooooooool0AOooool00ol0003oooooooooo`09ooooo`05o`00
0?ooooooooooooooool00000Zoooool000cooooo00?o0000ooooooooool00_ooool00ol0003ooooo
ooooo`08ooooo`03o`000?oooooooooo04Gooooo00?o0000ooooooooool02Oooool01Ol0003ooooo
oooooooooooo00000:_ooooo000<ooooo`03o`000?oooooooooo00;ooooo0ol00008ooooo`03o`00
0?oooooooooo04Gooooo00?o0000ooooooooool02Oooool01?l0003oooooooooool0002/ooooo`00
2?ooool4o`0000Gooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`14ooooo`03o`00
0?oooooooooo00[ooooo00Co0000oooooooooooo0000[?ooool000Sooooo00?o0000ooooooooool0
1_ooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo04Cooooo00?o0000ooooooooool0
2_ooool01?l0003oooooooooool0002/ooooo`002?ooool5o`0000Cooooo00?o0000ooooooooool0
2?ooool00ol0003oooooooooo`14ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooool00000
[?ooool0017ooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`14ooooo`03o`000?oo
oooooooo00_ooooo00?o0000ooooool00000[?ooool0017ooooo00?o0000ooooooooool02?ooool0
0ol0003oooooooooo`13ooooo`03o`000?oooooooooo00cooooo00?o0000ooooool00000[?ooool0
017ooooo0_l00009ooooo`03o`000?oooooooooo02kooooo00?o0000ooooooooool03Oooool6o`00
00kooooo00?o0000ooooool00000[?ooool0017ooooo00?o0000ooooooooool02?ooool00ol0003o
ooooooooo`0^ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool04Oooool00ol0003o
ooooo`00002/ooooo`004Oooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo02kooooo
00?o0000ooooooooool03?ooool00ol0003oooooooooo`0Booooo`03o`000?oooooo00000:cooooo
000Aooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool0;_ooool00ol0003ooooooooo
o`0<ooooo`03o`000?oooooooooo01;ooooo0_l0002]ooooo`004Oooool00ol0003oooooooooo`09
ooooo`03o`000?oooooooooo02cooooo0_l0000>ooooo`03o`000?oooooooooo01?ooooo00?o0000
ooooooooool0Zoooool0017ooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`0/oooo
o`;o00003Oooool00ol0003oooooooooo`0Dooooo`03o`000?oooooooooo0:_ooooo000Aooooo`03
o`000?oooooooooo00Wooooo00?o0000ooooooooool0;?ooool00ol0003oooooo`00000<ooooo`03
o`000?oooooooooo01Cooooo00?o0000ooooooooool0Zoooool0017ooooo0_l0000:ooooo`03o`00
0?oooooooooo02cooooo00?o0000ooooool000002oooool00ol0003oooooooooo`0Eooooo`03o`00
0?oooooooooo0:_ooooo000Aooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool0;?oo
ool00ol0003oooooo`00000;ooooo`03o`000?oooooooooo0<?ooooo000Aooooo`03o`000?oooooo
oooo00Wooooo00?o0000ooooooooool0;?ooool00ol0003oooooo`00000;ooooo`03o`000?oooooo
oooo0<?ooooo000Aooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool0;?ooool00ol0
003oooooo`00000:ooooo`03o`000?oooooooooo0<Cooooo000Aooooo`03o`000?oooooooooo00Wo
oooo00?o0000ooooooooool0:oooool01?l0003oooooooooool0000:ooooo`03o`000?oooooooooo
0<Cooooo000Aooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool0:oooool01?l0003o
ooooooooool0000:ooooo`03o`000?oooooooooo0<Cooooo000Aooooo`;o00002_ooool00ol0003o
ooooooooo`0[ooooo`04o`000?ooooooooooo`0000Wooooo00?o0000ooooooooool0aOooool0017o
oooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`0[ooooo`04o`000?ooooooooooo`00
00Wooooo00?o0000ooooooooool0aOooool0017ooooo00?o0000ooooooooool02_ooool00ol0003o
ooooooooo`0Zooooo`04o`000?ooooooooooo`0000Wooooo00?o0000ooooooooool0aOooool0017o
oooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`0Zooooo`04o`000?ooooooooooo`00
00Wooooo00?o0000ooooooooool0aOooool0017ooooo00?o0000ooooooooool02_ooool00ol0003o
ooooooooo`0Yooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01Oooool00ol0003o
ooooooooo`36ooooo`004Oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo02Wooooo
00?o0000ooooooooool00_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo0<Kooooo
000Aooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool0:Oooool00ol0003ooooooooo
o`02ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0a_ooool0017ooooo0_l0000;
ooooo`03o`000?oooooooooo02Wooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`05
ooooo`03o`000?oooooooooo0<Kooooo000Aooooo`03o`000?oooooooooo00[ooooo00?o0000oooo
ooooool0:Oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Gooooo00?o0000oooo
ooooool0a_ooool0017ooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`0Yooooo`03
o`000?oooooooooo00;ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`36ooooo`00
0oooool3o`0000Cooooo0_l00005ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool0
:?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0
a_ooool000Cooooo00?o0000ooooooooool00_ooool01?l0003oooooooooool00004ooooo`03o`00
0?oooooooooo00[ooooo00?o0000ooooooooool0:?ooool00ol0003oooooooooo`03ooooo`03o`00
0?oooooooooo00Cooooo00?o0000ooooooooool0aoooool000Cooooo00?o0000ooooooooool00_oo
ool01?l0003oooooooooool00004ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool0
9oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0
aoooool000Cooooo00?o0000ooooooooool00_ooool01?l0003oooooooooool00004ooooo`?o0000
2oooool00ol0003oooooooooo`0Wooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0
1?ooool00ol0003oooooooooo`37ooooo`001?ooool00ol0003oooooooooo`02ooooo`04o`000?oo
ooooooooo`0000Cooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0Wooooo`03o`00
0?oooooooooo00Cooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`37ooooo`000ooo
ool2o`0000Cooooo00Co0000oooooooooooo00001?ooool00ol0003oooooooooo`0;ooooo`03o`00
0?oooooooooo02Oooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`03ooooo`03o`00
0?oooooooooo0<Oooooo0004ooooo`03o`000?oooooooooo00?ooooo0_l00005ooooo`03o`000?oo
oooooooo00_ooooo00?o0000ooooooooool09oooool00ol0003oooooooooo`04ooooo`03o`000?oo
oooooooo00?ooooo00?o0000ooooooooool0aoooool0017ooooo00?o0000ooooooooool02oooool0
0ol0003oooooooooo`0Vooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool00_ooool0
0ol0003oooooooooo`38ooooo`004Oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo
02Kooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo
0<Sooooo000Aooooo`;o00003?ooool00ol0003oooooooooo`0Vooooo`03o`000?oooooooooo00Go
oooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`38ooooo`004Oooool00ol0003ooooo
ooooo`0;ooooo`03o`000?oooooooooo02Kooooo00?o0000ooooooooool01Oooool00ol0003ooooo
ooooo`02ooooo`03o`000?oooooooooo0<Sooooo000Aooooo`03o`000?oooooooooo00cooooo00?o
0000ooooooooool09Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00;ooooo00?o
0000ooooooooool0b?ooool0017ooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0T
ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`38
ooooo`004Oooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo02Cooooo00?o0000oooo
ooooool01_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo0<Sooooo000Aooooo`03
o`000?oooooooooo00cooooo00?o0000ooooooooool09?ooool00ol0003oooooooooo`07ooooo`04
o`000?ooooooooooo`000<_ooooo000Aooooo`03o`000?oooooooooo00cooooo00?o0000oooooooo
ool09?ooool00ol0003oooooooooo`07ooooo`04o`000?ooooooooooo`000<_ooooo000Aooooo`;o
00003Oooool00ol0003oooooooooo`0Sooooo`03o`000?oooooooooo00Sooooo00Co0000oooooooo
oooo0000boooool0017ooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0Sooooo`03
o`000?oooooooooo00Sooooo00Co0000oooooooooooo0000boooool0017ooooo00?o0000oooooooo
ool03?ooool00ol0003oooooooooo`0Sooooo`03o`000?oooooooooo00Sooooo00Co0000oooooooo
oooo0000boooool0017ooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0Sooooo`03
o`000?oooooooooo00Sooooo00Co0000oooooooooooo0000boooool0017ooooo00?o0000oooooooo
ool03Oooool00ol0003oooooooooo`0Qooooo`03o`000?oooooooooo00Wooooo00?o0000ooooool0
0000c?ooool0017ooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0Qooooo`03o`00
0?oooooooooo00Wooooo00?o0000ooooool00000c?ooool0017ooooo0_l0000>ooooo`03o`000?oo
oooooooo027ooooo00?o0000ooooooooool02Oooool00ol0003oooooo`00003<ooooo`004Oooool0
0ol0003oooooooooo`0=ooooo`03o`000?oooooooooo027ooooo00?o0000ooooooooool02Oooool0
0ol0003oooooo`00003<ooooo`004Oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo
023ooooo00?o0000ooooooooool02_ooool00ol0003oooooo`00003<ooooo`004Oooool00ol0003o
ooooooooo`0=ooooo`03o`000?oooooooooo023ooooo00?o0000ooooooooool02oooool2o`000<co
oooo000Aooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool08?ooool00ol0003ooooo
ooooo`0;ooooo`;o0000c?ooool0017ooooo00?o0000ooooooooool03Oooool00ol0003ooooooooo
o`0Pooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool0boooool0017ooooo00?o0000
ooooooooool03Oooool00ol0003oooooooooo`0Oooooo`03o`000?oooooooooo00cooooo00?o0000
ooooooooool0boooool0017ooooo0_l0000?ooooo`03o`000?oooooooooo01kooooo00?o0000oooo
ooooool03?ooool00ol0003oooooooooo`3;ooooo`004Oooool00ol0003oooooooooo`0>ooooo`03
o`000?oooooooooo01kooooo00?o0000ooooooooool0f_ooool0017ooooo00?o0000ooooooooool0
3_ooool00ol0003oooooooooo`0Mooooo`03o`000?oooooooooo0=_ooooo0003ooooo`?o00000ooo
ool3o`0000Gooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`0Mooooo`03o`000?oo
oooooooo0=_ooooo0004ooooo`05o`000?ooooooooooooooool000000oooool00ol0003ooooooooo
o`02ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool07?ooool00ol0003ooooooooo
o`3Looooo`001?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00;ooooo00?o0000
ooooooooool03_ooool00ol0003oooooooooo`0Looooo`03o`000?oooooooooo0=cooooo0004oooo
o`03o`000?oooooooooo00Gooooo00?o0000ooooooooool00_ooool3o`0000kooooo00?o0000oooo
ooooool00oooool00ol0003oooooooooo`0Eooooo`03o`000?oooooooooo0=gooooo0004ooooo`04
o`000?ooooooooooooooo`Co00001Oooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo
00?ooooo00?o0000ooooooooool05Oooool00ol0003oooooooooo`3Mooooo`000oooool2o`0000?o
oooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo00;o
oooo0_l0000Fooooo`03o`000?oooooooooo0=kooooo0004ooooo`04o`000?ooooooooooooooo`Go
00001?ooool00ol0003oooooooooo`0?ooooo`06o`000?ooooooooooo`000?oooooo00005_ooool0
0ol0003oooooooooo`3Nooooo`004Oooool00ol0003oooooooooo`0?ooooo`03o`000?oooooo0000
00;ooooo00?o0000ooooooooool04oooool00ol0003oooooooooo`3Oooooo`004Oooool00ol0003o
ooooooooo`0?ooooo`;o00000oooool00ol0003oooooooooo`0Cooooo`03o`000?oooooooooo0=oo
oooo000Aooooo`;o00004?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo017ooooo
00?o0000ooooooooool0h?ooool0017ooooo00?o0000ooooooooool05Oooool00ol0003ooooooooo
o`0Aooooo`03o`000?oooooooooo0>3ooooo000Aooooo`03o`000?oooooooooo01Gooooo00?o0000
ooooooooool04?ooool00ol0003oooooooooo`3Qooooo`004Oooool00ol0003oooooooooo`0Eoooo
o`03o`000?oooooooooo013ooooo00?o0000ooooooooool0hOooool0017ooooo00?o0000oooooooo
ool05Oooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo0>7ooooo000Aooooo`03o`00
0?oooooooooo01Gooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`3Rooooo`004Ooo
ool00ol0003oooooooooo`0Eooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool0h_oo
ool0017ooooo0_l0000Fooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01?ooool0
0ol0003oooooooooo`3Sooooo`004Oooool00ol0003oooooooooo`0Eooooo`03o`000?oooooooooo
00Oooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`3Sooooo`004Oooool00ol0003o
ooooooooo`0Eooooo`03o`000?oooooooooo00Oooooo0_l00005ooooo`03o`000?oooooooooo0>?o
oooo000Aooooo`03o`000?oooooooooo01Gooooo00?o0000ooooooooool01oooool00ol0003ooooo
o`000003ooooo`03o`000?oooooooooo0>Cooooo000Aooooo`03o`000?oooooooooo01Kooooo00?o
0000ooooooooool01_ooool01?l0003oooooooooool00002ooooo`03o`000?oooooooooo0>Cooooo
000Aooooo`03o`000?oooooooooo01Kooooo00?o0000ooooooooool01_ooool01ol0003ooooooooo
oooooooo0000ooooool00000i_ooool0017ooooo0_l0000Gooooo`03o`000?oooooooooo00Gooooo
00?o0000ooooooooool00oooool00ol0003oooooooooo`3Uooooo`004Oooool00ol0003ooooooooo
o`0Fooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0joooool0017ooooo00?o0000
ooooooooool05_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo0>_ooooo000Aoooo
o`03o`000?oooooooooo01Kooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`3[oooo
o`004Oooool00ol0003oooooooooo`0Fooooo`03o`000?oooooooooo00Gooooo00?o0000oooooooo
ool0joooool0017ooooo00?o0000ooooooooool05_ooool00ol0003oooooooooo`05ooooo`03o`00
0?oooooooooo0>_ooooo000Aooooo`03o`000?oooooooooo01Kooooo00?o0000ooooooooool01Ooo
ool00ol0003oooooooooo`3[ooooo`004Oooool2o`0001Oooooo00?o0000ooooooooool01Oooool0
0ol0003oooooooooo`3[ooooo`004Oooool00ol0003oooooooooo`0Fooooo`03o`000?oooooooooo
00Gooooo00?o0000ooooooooool0joooool0017ooooo00?o0000ooooooooool05oooool00ol0003o
ooooooooo`04ooooo`03o`000?oooooooooo0>_ooooo0002ooooo`Go00000oooool2o`0000Gooooo
00?o0000ooooooooool05oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo0>cooooo
0003ooooo`04o`000?ooooooooooo`0000;ooooo00Co0000oooooooooooo00001?ooool00ol0003o
ooooooooo`0Gooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0k?ooool000Cooooo
00?o0000ooooooooool00_ooool01?l0003oooooooooool00004ooooo`03o`000?oooooooooo01Oo
oooo00?o0000ooooooooool00oooool00ol0003oooooooooo`3/ooooo`001Oooool01Ol0003ooooo
oooooooooooo000000;ooooo00?o0000ooooooooool00_ooool3o`0001Oooooo00?o0000oooooooo
ool00oooool00ol0003oooooooooo`3/ooooo`000_ooool01Ol0003ooooooooooooooooo000000;o
oooo00Co0000oooooooooooo00001?ooool00ol0003oooooooooo`0Gooooo`03o`000?oooooooooo
00?ooooo00?o0000ooooooooool0k?ooool000;ooooo00Go0000ooooooooooooooooo`000002oooo
o`04o`000?ooooooooooo`0000Cooooo00?o0000ooooooooool05oooool00ol0003oooooooooo`03
ooooo`03o`000?oooooooooo0>cooooo0003ooooo`?o00001?ooool2o`0000Gooooo00?o0000oooo
ooooool05oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo0>cooooo000Aooooo`03
o`000?oooooooooo01Oooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`3/ooooo`00
4Oooool00ol0003oooooooooo`0Gooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0
k?ooool0017ooooo0_l0000Iooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0k?oo
ool0017ooooo00?o0000ooooooooool06?ooool01Ol0003ooooooooooooooooo00000>oooooo000A
ooooo`03o`000?oooooooooo01Sooooo00Go0000ooooooooooooooooo`00003_ooooo`004Oooool0
0ol0003oooooooooo`0Hooooo`05o`000?ooooooooooooooool00000koooool0017ooooo00?o0000
ooooooooool06?ooool01Ol0003ooooooooooooooooo00000>oooooo000Aooooo`03o`000?oooooo
oooo01Sooooo00Go0000ooooooooooooooooo`00003_ooooo`004Oooool00ol0003oooooooooo`0H
ooooo`05o`000?ooooooooooooooool00000koooool0017ooooo0_l0000Iooooo`05o`000?oooooo
ooooooooool00000koooool0017ooooo00?o0000ooooooooool06?ooool01Ol0003ooooooooooooo
oooo00000>oooooo000Aooooo`03o`000?oooooooooo01Sooooo00Go0000ooooooooooooooooo`00
003_ooooo`004Oooool00ol0003oooooooooo`0Hooooo`05o`000?ooooooooooooooool00000kooo
ool0017ooooo00?o0000ooooooooool06Oooool01?l0003oooooooooool0003_ooooo`004Oooool0
0ol0003oooooooooo`0Iooooo`03o`000?oooooo00000?3ooooo000Aooooo`;o00006_ooool00ol0
003oooooo`00003`ooooo`004Oooool00ol0003oooooooooo`0Iooooo`03o`000?oooooo00000?3o
oooo000Aooooo`03o`000?oooooooooo01Wooooo00?o0000ooooool00000l?ooool0017ooooo00?o
0000ooooooooool06Oooool00ol0003oooooo`00003`ooooo`004Oooool00ol0003oooooooooo`0I
ooooo`03o`000?oooooo00000?3ooooo000Aooooo`03o`000?oooooooooo01Wooooo00?o0000oooo
ool00000l?ooool0017ooooo00?o0000ooooooooool06Oooool00ol0003oooooo`00003`ooooo`00
4Oooool2o`0001[ooooo00?o0000ooooool00000l?ooool0017ooooo00?o0000ooooooooool06Ooo
ool00ol0003oooooo`00003`ooooo`004Oooool00ol0003oooooooooo`0Jooooo`03o`000?oooooo
oooo0>oooooo0002ooooo`Go00000_ooool3o`0000Gooooo00?o0000ooooooooool06_ooool00ol0
003oooooooooo`3_ooooo`000oooool01_l0003oooooooooool0003oooooo`0000?ooooo00?o0000
ooooooooool00_ooool00ol0003oooooooooo`0Jooooo`03o`000?oooooooooo0>oooooo0004oooo
o`03o`000?oooooooooo00Gooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`0Joooo
o`03o`000?oooooooooo0>oooooo0005ooooo`03o`000?oooooooooo00Cooooo00?o0000oooooooo
ool00_ooool3o`0001[ooooo00?o0000ooooooooool0koooool000;ooooo00Ko0000oooooooooooo
ooooo`000?ooool4o`0000Gooooo00?o0000ooooooooool0ooooool=ooooo`000_ooool01ol0003o
oooooooooooooooo0000ooooool000002?ooool00ol0003oooooooooo`3oooooo`gooooo0003oooo
o`?o00000_ooool5o`0000Cooooo00?o0000ooooooooool0ooooool=ooooo`004Oooool00ol0003o
ooooooooo`3oooooo`gooooo0000\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.665916, -1.93675, \
0.0382317, 0.156212}}],

Cell[BoxData[
    \(1.3182755383630866`\)], "Output",
  CellLabel->"Out[72]="]
}, Open  ]],

Cell[TextData[{
  "It is quite easy to work out the variance of time back to MRCA (i.e., of \
tree depth).  Because the depth is the sum of independent random times, ",
  Cell[BoxData[
      \(TraditionalForm\`T\_j\)]],
  ", its variance is just the sum of those variances.  The ",
  Cell[BoxData[
      \(TraditionalForm\`T\_j\)]],
  "'s are exponentially distributed, with rate ",
  Cell[BoxData[
      \(TraditionalForm\`\(j(j - 1)\)\/2\)]],
  ". Thus, ",
  Cell[BoxData[
      \(TraditionalForm\`E[T\_j] = 2\/\(j(j - 1)\)\)]],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`var(T\_j] = 4\/\(\(j\^2\)(j - 1)\)\^2\)]],
  ":"
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \({Mean[ExponentialDistribution[\(j \((j - 1)\)\)\/2]], 
      Variance[ExponentialDistribution[\(j \((j - 1)\)\)\/2]]}\)], "Input",
  CellLabel->"In[73]:="],

Cell[BoxData[
    \({2\/\(\((\(-1\) + j)\)\ j\), 
      4\/\(\((\(-1\) + j)\)\^2\ j\^2\)}\)], "Output",
  CellLabel->"Out[73]="]
}, Open  ]],

Cell["\<\
For k=10, the variance of tree depth matches the observation fairly \
well.  (In this example, t=1.9, which is not quite significant):\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \({Variance[
        depthList], \[Sum]\+\(j = 2\)\%10 4\/\(\(j\^2\) \((j - 1)\)\^2\) // 
        N, \((Variance[
              depthList] - \[Sum]\+\(j = 2\)\%10 4\/\(\(j\^2\) \((j - 1)\)\^2\
\))\)/StandardErrorOfSampleMean[depthList]}\)], "Input",
  CellLabel->"In[90]:="],

Cell[BoxData[
    \({1.3182755383630866`, 1.1581418493323254`, 
      1.9723982556743058`}\)], "Output",
  CellLabel->"Out[90]="]
}, Open  ]],

Cell[TextData[{
  "For a large number of genes, the variance of tree depth can be found \
explicitly; it is about 1.159.  Thus, even with a very large number of genes \
sampled, the time back to the MRCA is quite variable.  The random error here \
comes mainly from the time for the last two lineages to coalesce, which has \
mean and variance ",
  Cell[BoxData[
      \(TraditionalForm\`1\)]],
  ". (In real time, mean ",
  Cell[BoxData[
      \(TraditionalForm\`2  N\_e\)]],
  ", variance ",
  Cell[BoxData[
      \(TraditionalForm\`\((2  N\_e)\)\^2\)]],
  ")"
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\[Sum]\+\(j = 2\)\%\[Infinity] 4\/\(\(j\^2\) \((j - 1)\)\^2\)\)], \
"Input",
  CellLabel->"In[92]:="],

Cell[BoxData[
    \(4\/3\ \((\(-9\) + \[Pi]\^2)\)\)], "Output",
  CellLabel->"Out[92]="]
}, Open  ]],

Cell["\<\
We can look at the distribution of tree length in the same \
way:\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(ListPlot[
        Transpose[{Range[0.1, 19.9, 0.2], 
            BinCounts[lengthList, {0, 20, 0.2}]}], 
        PlotJoined \[Rule] True];\)\), "\[IndentingNewLine]", 
    \({Mean[lengthList], Variance[lengthList]}\)}], "Input",
  CellLabel->"In[97]:="],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.0478583 0.0147151 0.0392403 [
[.2631 .00222 -3 -9 ]
[.2631 .00222 3 0 ]
[.50239 .00222 -6 -9 ]
[.50239 .00222 6 0 ]
[.74168 .00222 -6 -9 ]
[.74168 .00222 6 0 ]
[.98098 .00222 -6 -9 ]
[.98098 .00222 6 0 ]
[.01131 .0932 -6 -4.5 ]
[.01131 .0932 0 4.5 ]
[.01131 .17168 -6 -4.5 ]
[.01131 .17168 0 4.5 ]
[.01131 .25016 -6 -4.5 ]
[.01131 .25016 0 4.5 ]
[.01131 .32864 -6 -4.5 ]
[.01131 .32864 0 4.5 ]
[.01131 .40712 -12 -4.5 ]
[.01131 .40712 0 4.5 ]
[.01131 .4856 -12 -4.5 ]
[.01131 .4856 0 4.5 ]
[.01131 .56408 -12 -4.5 ]
[.01131 .56408 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2631 .01472 m
.2631 .02097 L
s
[(5)] .2631 .00222 0 1 Mshowa
.50239 .01472 m
.50239 .02097 L
s
[(10)] .50239 .00222 0 1 Mshowa
.74168 .01472 m
.74168 .02097 L
s
[(15)] .74168 .00222 0 1 Mshowa
.98098 .01472 m
.98098 .02097 L
s
[(20)] .98098 .00222 0 1 Mshowa
.125 Mabswid
.07167 .01472 m
.07167 .01847 L
s
.11953 .01472 m
.11953 .01847 L
s
.16738 .01472 m
.16738 .01847 L
s
.21524 .01472 m
.21524 .01847 L
s
.31096 .01472 m
.31096 .01847 L
s
.35882 .01472 m
.35882 .01847 L
s
.40668 .01472 m
.40668 .01847 L
s
.45453 .01472 m
.45453 .01847 L
s
.55025 .01472 m
.55025 .01847 L
s
.59811 .01472 m
.59811 .01847 L
s
.64597 .01472 m
.64597 .01847 L
s
.69383 .01472 m
.69383 .01847 L
s
.78954 .01472 m
.78954 .01847 L
s
.8374 .01472 m
.8374 .01847 L
s
.88526 .01472 m
.88526 .01847 L
s
.93312 .01472 m
.93312 .01847 L
s
.25 Mabswid
0 .01472 m
1 .01472 L
s
.02381 .0932 m
.03006 .0932 L
s
[(2)] .01131 .0932 1 0 Mshowa
.02381 .17168 m
.03006 .17168 L
s
[(4)] .01131 .17168 1 0 Mshowa
.02381 .25016 m
.03006 .25016 L
s
[(6)] .01131 .25016 1 0 Mshowa
.02381 .32864 m
.03006 .32864 L
s
[(8)] .01131 .32864 1 0 Mshowa
.02381 .40712 m
.03006 .40712 L
s
[(10)] .01131 .40712 1 0 Mshowa
.02381 .4856 m
.03006 .4856 L
s
[(12)] .01131 .4856 1 0 Mshowa
.02381 .56408 m
.03006 .56408 L
s
[(14)] .01131 .56408 1 0 Mshowa
.125 Mabswid
.02381 .03434 m
.02756 .03434 L
s
.02381 .05396 m
.02756 .05396 L
s
.02381 .07358 m
.02756 .07358 L
s
.02381 .11282 m
.02756 .11282 L
s
.02381 .13244 m
.02756 .13244 L
s
.02381 .15206 m
.02756 .15206 L
s
.02381 .1913 m
.02756 .1913 L
s
.02381 .21092 m
.02756 .21092 L
s
.02381 .23054 m
.02756 .23054 L
s
.02381 .26978 m
.02756 .26978 L
s
.02381 .2894 m
.02756 .2894 L
s
.02381 .30902 m
.02756 .30902 L
s
.02381 .34826 m
.02756 .34826 L
s
.02381 .36788 m
.02756 .36788 L
s
.02381 .3875 m
.02756 .3875 L
s
.02381 .42674 m
.02756 .42674 L
s
.02381 .44636 m
.02756 .44636 L
s
.02381 .46598 m
.02756 .46598 L
s
.02381 .50522 m
.02756 .50522 L
s
.02381 .52484 m
.02756 .52484 L
s
.02381 .54446 m
.02756 .54446 L
s
.02381 .5837 m
.02756 .5837 L
s
.02381 .60332 m
.02756 .60332 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.0286 .01472 m
.03817 .01472 L
.04774 .01472 L
.05731 .01472 L
.06688 .01472 L
.07645 .01472 L
.08603 .01472 L
.0956 .01472 L
.10517 .01472 L
.11474 .05396 L
.12431 .0932 L
.13388 .13244 L
.14346 .17168 L
.15303 .32864 L
.1626 .17168 L
.17217 .17168 L
.18174 .2894 L
.19131 .13244 L
.20089 .25016 L
.21046 .25016 L
.22003 .21092 L
.2296 .32864 L
.23917 .25016 L
.24874 .2894 L
.25832 .32864 L
.26789 .60332 L
.27746 .2894 L
.28703 .13244 L
.2966 .36788 L
.30617 .17168 L
.31575 .2894 L
.32532 .25016 L
.33489 .13244 L
.34446 .17168 L
.35403 .0932 L
.3636 .21092 L
.37318 .13244 L
.38275 .05396 L
.39232 .36788 L
.40189 .17168 L
.41146 .17168 L
.42103 .21092 L
.43061 .13244 L
.44018 .0932 L
.44975 .05396 L
.45932 .01472 L
.46889 .13244 L
.47846 .05396 L
.48804 .25016 L
.49761 .05396 L
Mistroke
.50718 .05396 L
.51675 .01472 L
.52632 .01472 L
.53589 .0932 L
.54547 .05396 L
.55504 .01472 L
.56461 .01472 L
.57418 .0932 L
.58375 .05396 L
.59332 .01472 L
.6029 .01472 L
.61247 .01472 L
.62204 .01472 L
.63161 .01472 L
.64118 .01472 L
.65075 .01472 L
.66033 .01472 L
.6699 .01472 L
.67947 .01472 L
.68904 .01472 L
.69861 .01472 L
.70818 .01472 L
.71776 .01472 L
.72733 .01472 L
.7369 .01472 L
.74647 .01472 L
.75604 .01472 L
.76561 .05396 L
.77519 .01472 L
.78476 .01472 L
.79433 .01472 L
.8039 .01472 L
.81347 .05396 L
.82304 .01472 L
.83262 .01472 L
.84219 .01472 L
.85176 .01472 L
.86133 .01472 L
.8709 .01472 L
.88047 .01472 L
.89005 .05396 L
.89962 .01472 L
.90919 .01472 L
.91876 .01472 L
.92833 .01472 L
.9379 .01472 L
.94748 .01472 L
.95705 .01472 L
.96662 .01472 L
.97619 .01472 L
Mistroke
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[97]:=",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/B000`400?l00000o`00003ooooooolQ
ooooo`00D?ooool3o`0003cooooo0ol00004ooooo`;o0000>?ooool3o`0000?ooooo0ol0000goooo
o`Go00000oooool2o`0000Kooooo001?ooooo`05o`000?ooooooooooooooool00000??ooool00ol0
003oooooooooo`02ooooo`04o`000?ooooooooooo`0003Sooooo00Go0000ooooooooooooooooo`00
0003ooooo`03o`000?oooooooooo03Gooooo00Co0000oooooooooooo00000_ooool01?l0003ooooo
ooooool00005ooooo`00Doooool00ol0003oooooooooo`0jooooo`03o`000?oooooooooo00;ooooo
00Co0000oooooooooooo0000>?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo03Ko
oooo00?o0000ooooooooool00_ooool01?l0003oooooooooool00005ooooo`00Doooool00ol0003o
ooooooooo`0jooooo`03o`000?oooooooooo00;ooooo00Co0000oooooooooooo0000>?ooool00ol0
003oooooooooo`05ooooo`03o`000?oooooooooo03Oooooo00Go0000ooooooooooooooooo`000002
ooooo`03o`000?oooooooooo00?ooooo001?ooooo`Co0000?Oooool00ol0003oooooooooo`02oooo
o`04o`000?ooooooooooo`0003Sooooo00Co0000oooooooooooooooo1?l0000gooooo`05o`000?oo
ooooooooooooool000000_ooool01?l0003oooooooooool00005ooooo`00Coooool00ol0003ooooo
ooooo`0mooooo`;o00001?ooool01?l0003oooooooooool0000gooooo`;o00000oooool00ol0003o
ooooooooo`0hooooo`05o`000?ooooooooooooooool000000_ooool01?l0003oooooooooool00005
ooooo`00Coooool5o`0003cooooo00?o0000ooooooooool00oooool2o`0003Wooooo00Co0000oooo
oooooooooooo1Ol0000gooooo`?o00001?ooool2o`0000Kooooo000Aooooo`03o`000?oooooooooo
0?oooooo3Oooool0017ooooo00?o0000ooooooooool0ooooool=ooooo`004Oooool00ol0003ooooo
ooooo`3oooooo`gooooo000Aooooo`03o`000?oooooooooo0?oooooo3Oooool000_oooooool0000B
o`0000Cooooo000Aooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool01_ooool01Ol0
003ooooooooooooooooo000000cooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`0:
ooooo`0300000?oooooooooo00_ooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`0:
ooooo`03o`000?oooooooooo00[ooooo0_l0000;ooooo`07o`000?ooooooooooooooool0003ooooo
o`000006ooooo`;o00000_ooool00ol0003oooooooooo`05ooooo`;o00003?ooool00ol0003ooooo
ooooo`0:ooooo`03o`000?oooooooooo00[ooooo00Go0000ooooooooooooooooo`000004ooooo`05
o`000?ooooooooooooooool000000oooool00ol0003oooooooooo`02ooooo`05o`000?oooooooooo
ooooool000002oooool2o`0000?ooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`0:
ooooo`03o`000?oooooooooo00Oooooo000Aooooo`03o`000?oooooooooo01?ooooo00?o0000oooo
ooooool0:?ooool00`00003oooooooooo`0cooooo`03o`000?oooooooooo00Wooooo00Oo0000oooo
ooooooooooooo`000?oooooo000000Oooooo00Co0000oooooooooooo00001oooool00ol0003ooooo
ooooo`0Uooooo`05o`000?ooooooooooooooool000001?ooool00ol0003oooooooooo`05ooooo`03
o`000?oooooooooo00;ooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`02ooooo`03
o`000?oooooooooo01?ooooo00?o0000ooooooooool01oooool0017ooooo00?o0000ooooooooool0
5?ooool00ol0003oooooooooo`1Looooo`;o00003_ooool01?l0003oooooooooool00006ooooo`05
o`000?ooooooooooooooool000001_ooool00ol0003oooooooooo`0Zooooo`05o`000?oooooooooo
ooooool000002Oooool01Ol0003ooooooooooooooooo000000oooooo00Go0000oooooooooooooooo
o`00000Pooooo`004Oooool00ol0003oooooooooo`0Dooooo`03o`000?oooooooooo05cooooo0_l0
000>ooooo`05o`000?ooooooooooooooool000001Oooool01Ol0003ooooooooooooooooo000000Ko
oooo00?o0000ooooooooool0:oooool01?l0003oooooooooool00009ooooo`04o`000?oooooooooo
o`00017ooooo00Co0000oooooooooooo00008?ooool0017ooooo0_l0000Eooooo`03o`000?oooooo
oooo05cooooo0_l0000>ooooo`05o`000?ooooooooooooooool000001Oooool01Ol0003ooooooooo
oooooooo000000Kooooo00?o0000ooooooooool0:oooool01?l0003oooooooooool00009ooooo`04
o`000?ooooooooooo`00017ooooo00Co0000oooooooooooo00008?ooool0017ooooo00?o0000oooo
ooooool05Oooool00ol0003oooooooooo`1Jooooo`04o`000?ooooooooooo`0000cooooo00?o0000
ooooooooool00_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00?ooooo00?o0000
ooooooooool00_ooool00ol0003oooooooooo`0/ooooo`03o`000?oooooo000000_ooooo00?o0000
ooooool000004Oooool00ol0003oooooo`00000Qooooo`004Oooool00ol0003oooooooooo`0Eoooo
o`03o`000?oooooooooo05[ooooo00Co0000oooooooooooo00003?ooool00ol0003oooooooooo`02
ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`02
ooooo`03o`000?oooooooooo02cooooo00?o0000ooooool000002oooool00ol0003oooooo`00000A
ooooo`03o`000?oooooo0000027ooooo000Aooooo`03o`000?oooooooooo01Gooooo00?o0000oooo
ooooool0F_ooool01?l0003oooooooooool0000<ooooo`03o`000?oooooooooo00;ooooo00?o0000
ooooooooool00_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00;ooooo00?o0000
ooooooooool0;?ooool00ol0003oooooo`00000;ooooo`03o`000?oooooo0000017ooooo00?o0000
ooooool000008Oooool0017ooooo00?o0000ooooooooool05Oooool00ol0003oooooooooo`1Joooo
o`04o`000?ooooooooooo`0000cooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`02
ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`0]
ooooo`;o00002oooool2o`0001?ooooo0_l0000Qooooo`004Oooool00ol0003oooooooooo`0Foooo
o`03o`000?oooooooooo05Sooooo00Go0000ooooooooooooooooo`00000;ooooo`03o`000?oooooo
oooo00?ooooo00Go0000ooooooooooooooooo`000006ooooo`05o`000?ooooooooooooooool00000
<?ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool0
8?ooool0017ooooo0_l0000Gooooo`03o`000?oooooooooo04Kooooo00?o0000ooooooooool03ooo
ool01Ol0003ooooooooooooooooo000000?ooooo00?o0000ooooooooool00_ooool4o`0000Kooooo
00Co0000oooooooooooo00001_ooool01Ol0003ooooooooooooooooo0000033ooooo00?o0000oooo
ooooool02oooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo023ooooo000Aooooo`03
o`000?oooooooooo01Kooooo00?o0000ooooooooool0A_ooool00ol0003oooooooooo`0?ooooo`05
o`000?ooooooooooooooool000000oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo
00Oooooo00Co0000oooooooooooo00001_ooool01Ol0003ooooooooooooooooo000007Gooooo000A
ooooo`03o`000?oooooooooo01Kooooo00?o0000ooooooooool0A_ooool00ol0003oooooooooo`0?
ooooo`05o`000?ooooooooooooooool000000oooool00ol0003oooooooooo`02ooooo`03o`000?oo
oooooooo00Oooooo00Co0000oooooooooooo00001_ooool01Ol0003ooooooooooooooooo000007Go
oooo000Aooooo`03o`000?oooooooooo01Oooooo00?o0000ooooooooool0AOooool00ol0003ooooo
ooooo`0>ooooo`03o`000?oooooooooo00;ooooo00Go0000ooooooooooooooooo`000004ooooo`03
o`000?oooooooooo00Oooooo00?o0000ooooool000001oooool01?l0003oooooooooool0001foooo
o`004Oooool00ol0003oooooooooo`0Gooooo`03o`000?oooooooooo04Cooooo0_l0000@ooooo`03
o`000?oooooooooo00;ooooo00Go0000ooooooooooooooooo`000004ooooo`03o`000?oooooooooo
00Oooooo00?o0000ooooool000001oooool01?l0003oooooooooool0001fooooo`004Oooool2o`00
01Sooooo00?o0000ooooooooool0A?ooool2o`00013ooooo00?o0000ooooooooool00_ooool01Ol0
003ooooooooooooooooo000000Cooooo00?o0000ooooooooool01oooool00ol0003oooooo`000007
ooooo`04o`000?ooooooooooo`0007Kooooo000Aooooo`03o`000?oooooooooo01Sooooo00?o0000
ooooooooool0@oooool2o`00013ooooo00?o0000ooooooooool00oooool01?l0003oooooo`000?l0
0004ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooool000002?ooool2o`0007Oooooo000A
ooooo`03o`000?oooooooooo01Sooooo00?o0000ooooooooool0@oooool2o`00013ooooo00?o0000
ooooooooool00oooool01?l0003oooooo`000?l00004ooooo`03o`000?oooooooooo00Sooooo0_l0
0008ooooo`;o0000Moooool000Sooooo1Ol00004ooooo`03o`000?oooooooooo01Sooooo00?o0000
ooooooooool0@oooool2o`0000oooooo00?o0000ooooooooool01?ooool01?l0003oooooo`000?l0
0004ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool01oooool2o`0007Oooooo0009
ooooo`04o`000?ooooooooooo`0000Cooooo00?o0000ooooooooool06Oooool00ol0003ooooooooo
o`12ooooo`;o00003oooool00ol0003oooooooooo`04ooooo`04o`000?oooooo0000o`0000Cooooo
00?o0000ooooooooool02?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo07Kooooo
000:ooooo`03o`000?oooooooooo00Cooooo0ol0000Iooooo`03o`000?oooooooooo03_ooooo00?o
0000ooooooooool01?ooool2o`0000oooooo00?o0000ooooooooool01?ooool01Ol0003oooooo`00
0?oooooo000000?ooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`07ooooo`03o`00
0?oooooooooo07Kooooo000;ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool06Ooo
ool00ol0003oooooooooo`0kooooo`03o`000?oooooooooo00?ooooo00?o0000ooooool000003ooo
ool00ol0003oooooooooo`04ooooo`05o`000?oooooo0000ooooool000000oooool00ol0003ooooo
ooooo`2;ooooo`002?ooool01Ol0003ooooooooooooooooo000000Cooooo00?o0000ooooooooool0
6Oooool00ol0003oooooooooo`0kooooo`03o`000?oooooooooo00?ooooo00?o0000ooooool00000
3oooool00ol0003oooooooooo`04ooooo`05o`000?oooooo0000ooooool000000oooool00ol0003o
ooooooooo`2;ooooo`002?ooool01Ol0003ooooooooooooooooo000000Cooooo00?o0000oooooooo
ool06Oooool00ol0003oooooooooo`0kooooo`03o`000?oooooooooo00?ooooo00?o0000ooooool0
00003_ooool00ol0003oooooooooo`05ooooo`05o`000?oooooo0000ooooool000000oooool00ol0
003oooooooooo`2;ooooo`002Oooool3o`0000Gooooo00?o0000ooooooooool06_ooool00ol0003o
ooooooooo`0jooooo`03o`000?oooooooooo00?ooooo00?o0000ooooool000003_ooool00ol0003o
ooooooooo`05ooooo`05o`000?oooooo0000ooooool000000_ooool00ol0003oooooooooo`2<oooo
o`004Oooool00ol0003oooooooooo`0Jooooo`03o`000?oooooooooo03[ooooo00?o0000oooooooo
ool00oooool01?l0003oooooooooool0000=ooooo`03o`000?oooooooooo00Gooooo00Go0000oooo
ool0003oooooo`000002ooooo`03o`000?oooooooooo08cooooo000Aooooo`;o00006oooool00ol0
003oooooooooo`0iooooo`03o`000?oooooo000000Cooooo00Co0000oooooooooooo00003?ooool0
0ol0003oooooooooo`06ooooo`05o`000?oooooo0000ooooool000000_ooool00ol0003ooooooooo
o`2<ooooo`004Oooool00ol0003oooooooooo`0Jooooo`03o`000?oooooooooo03Wooooo00?o0000
ooooool000001?ooool01?l0003oooooooooool0000<ooooo`03o`000?oooooooooo00Oooooo00Co
0000oooooooooooo00000_ooool00ol0003oooooooooo`2<ooooo`004Oooool00ol0003ooooooooo
o`0Jooooo`03o`000?oooooooooo03Wooooo00?o0000ooooool000000oooool01Ol0003ooooooooo
oooooooo000000cooooo00?o0000ooooooooool01oooool01?l0003oooooooooool00002ooooo`03
o`000?oooooooooo08cooooo000Aooooo`03o`000?oooooooooo01_ooooo00?o0000ooooooooool0
>?ooool00ol0003oooooo`000003ooooo`05o`000?ooooooooooooooool000003?ooool00ol0003o
ooooooooo`07ooooo`04o`000?ooooooooooo`0000;ooooo00?o0000ooooooooool0S?ooool0017o
oooo00?o0000ooooooooool06oooool00ol0003oooooooooo`0hooooo`03o`000?oooooo000000?o
oooo00Go0000ooooooooooooooooo`00000;ooooo`03o`000?oooooooooo00Sooooo00Co0000oooo
oooooooo00000_ooool00ol0003oooooooooo`2<ooooo`004Oooool2o`0001cooooo00?o0000oooo
ooooool03Oooool00ol0003oooooooooo`0Gooooo`03o`000?oooooooooo00[ooooo00Oo0000oooo
ooooooooooooo`000?oooooo000000?ooooo00Go0000ooooooooooooooooo`00000;ooooo`03o`00
0?oooooooooo00Sooooo00Co0000oooooooooooo00000_ooool00ol0003oooooooooo`2<ooooo`00
4Oooool00ol0003oooooooooo`0Kooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool0
5oooool00ol0003oooooooooo`0:ooooo`07o`000?ooooooooooooooool0003oooooo`000003oooo
o`05o`000?ooooooooooooooool000002oooool00ol0003oooooooooo`0;ooooo`04o`000?oooooo
ooooo`0008kooooo000Aooooo`03o`000?oooooooooo01_ooooo00?o0000ooooooooool03Oooool0
0ol0003oooooooooo`0Gooooo`03o`000?oooooooooo00[ooooo00Oo0000ooooooooooooooooo`00
0?oooooo000000?ooooo00Go0000ooooooooooooooooo`00000;ooooo`03o`000?oooooooooo00_o
oooo00Co0000oooooooooooo0000S_ooool0017ooooo00?o0000ooooooooool07?ooool00ol0003o
ooooooooo`0<ooooo`03o`000?oooooooooo01Oooooo00?o0000ooooooooool02_ooool2o`0000;o
oooo00?o0000ooooool000000oooool01Ol0003ooooooooooooooooo000000_ooooo00?o0000oooo
ooooool02oooool01?l0003oooooooooool0002>ooooo`004Oooool00ol0003oooooooooo`0Loooo
o`03o`000?oooooooooo00cooooo00?o0000ooooooooool05oooool00ol0003oooooooooo`0:oooo
o`;o00000_ooool00ol0003oooooo`000003ooooo`05o`000?ooooooooooooooool000002oooool0
0ol0003oooooooooo`0;ooooo`04o`000?ooooooooooo`0008kooooo000Aooooo`;o00007Oooool0
0ol0003oooooooooo`0<ooooo`03o`000?oooooooooo01Oooooo00?o0000ooooooooool02_ooool2
o`0000;ooooo00?o0000ooooool000000oooool01Ol0003ooooooooooooooooo000000_ooooo00?o
0000ooooooooool02oooool01?l0003oooooooooool0002>ooooo`004Oooool00ol0003ooooooooo
o`0Mooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool05oooool00ol0003ooooooooo
o`09ooooo`03o`000?oooooooooo00;o00000oooool00ol0003oooooo`000004ooooo`03o`000?oo
oooooooo00Sooooo00?o0000ooooooooool03Oooool00ol0003oooooo`00002>ooooo`004Oooool0
0ol0003oooooooooo`0Mooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool05oooool0
0ol0003oooooooooo`09ooooo`03o`000?oooooooooo00;o00000oooool00ol0003oooooo`000004
ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool03Oooool00ol0003oooooo`00002>
ooooo`002_ooool3o`0000Cooooo00?o0000ooooooooool07Oooool00ol0003oooooooooo`0:oooo
o`;o00006?ooool2o`0000_ooooo00?o0000ooooooooool00_l00003ooooo`03o`000?oooooo0000
00Cooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooo0000
08kooooo000;ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool07Oooool00ol0003o
ooooooooo`0:ooooo`03o`000?oooooo000001Oooooo0_l0000;ooooo`03o`000?oooooooooo00;o
00000oooool00ol0003oooooo`000004ooooo`03o`000?oooooooooo00Sooooo00?o0000oooooooo
ool03Oooool00ol0003oooooo`00002>ooooo`002?ooool5o`0000Cooooo00?o0000ooooooooool0
7_ooool00ol0003oooooooooo`09ooooo`03o`000?oooooo000001Oooooo0_l0000;ooooo`05o`00
0?ooooooooooooooool000000oooool00ol0003oooooo`000004ooooo`03o`000?oooooooooo00So
oooo00?o0000ooooooooool03Oooool00ol0003oooooo`00002>ooooo`002?ooool01?l0003ooooo
ooooool00005ooooo`?o00007_ooool00ol0003oooooooooo`02ooooo`Co00000oooool00ol0003o
ooooo`00000Gooooo`;o00001?ooool00ol0003oooooooooo`04ooooo`05o`000?oooooooooooooo
ool000000oooool00ol0003oooooo`000004ooooo`04o`000?ooooooooooooooo`Co00000oooool0
0ol0003oooooooooo`0=ooooo`03o`000?oooooo000008kooooo0009ooooo`03o`000?oooooo0000
00Gooooo00?o0000ooooooooool07_ooool00ol0003oooooooooo`02ooooo`04o`000?oooooooooo
o`0000?ooooo00?o0000ooooool000005oooool00ol0003oooooo`000003ooooo`03o`000?oooooo
oooo00Cooooo00?o0000ooooooooool01Oooool00ol0003oooooo`000004ooooo`05o`000?oooooo
ooooooooool000000_ooool01Ol0003ooooooooooooooooo000000oooooo00?o0000ooooool00000
S_ooool000[ooooo0_l00005ooooo`03o`000?oooooooooo01kooooo00?o0000ooooooooool00_oo
ool01?l0003oooooooooool00003ooooo`03o`000?oooooo000001Oooooo00?o0000ooooool00000
0oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooool00000
1?ooool01Ol0003ooooooooooooooooo000000;ooooo00Go0000ooooooooooooooooo`00000?oooo
o`03o`000?oooooo000008kooooo000;ooooo`03o`000?oooooooooo00?ooooo00?o0000oooooooo
ool07_ooool00ol0003oooooooooo`02ooooo`04o`000?ooooooooooo`0000?ooooo00?o0000oooo
ool000005oooool00ol0003oooooo`000003ooooo`03o`000?oooooooooo00Cooooo00?o0000oooo
ooooool01Oooool00ol0003oooooo`000004ooooo`05o`000?ooooooooooooooool000000oooool0
1?l0003oooooooooool0000?ooooo`03o`000?oooooo000008kooooo000Aooooo`03o`000?oooooo
oooo01kooooo00?o0000ooooooooool00_ooool01?l0003oooooooooool00003ooooo`03o`000?oo
oooo000001Oooooo00?o0000ooooool000000oooool00ol0003oooooooooo`04ooooo`03o`000?oo
oooooooo00Gooooo00?o0000ooooool000001?ooool01Ol0003ooooooooooooooooo000000?ooooo
00Co0000oooooooooooo00003oooool00ol0003oooooo`00002>ooooo`004Oooool2o`0001oooooo
00?o0000ooooooooool00_ooool01?l0003oooooooooool00003ooooo`03o`000?oooooo000001Oo
oooo00?o0000ooooool000000oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Go
oooo00?o0000ooooool000001?ooool01Ol0003ooooooooooooooooo000000?ooooo00Co0000oooo
oooooooo00003oooool00ol0003oooooo`00002>ooooo`004Oooool00ol0003oooooooooo`0Noooo
o`03o`000?oooooooooo00;ooooo00Co0000oooooooooooo00000oooool00ol0003oooooo`00000G
ooooo`03o`000?oooooo000000?ooooo0_l00004ooooo`03o`000?oooooooooo00Oooooo00?o0000
ooooooooool00oooool01Ol0003ooooooooooooooooo000000Cooooo0_l0000@ooooo`03o`000?oo
oooo000008kooooo000Aooooo`03o`000?oooooooooo01kooooo00?o0000ooooooooool00_ooool0
1?l0003oooooooooool00003ooooo`03o`000?oooooo000001Oooooo00?o0000ooooool000000ooo
ool2o`0000Cooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`03ooooo`05o`000?oo
ooooooooooooool000001?ooool2o`00013ooooo00?o0000ooooool00000S_ooool0017ooooo00?o
0000ooooooooool07_ooool01Ol0003ooooooooooooooooo000000?ooooo00Oo0000oooooooooooo
ooooo`000?oooooo000001Oooooo00?o0000ooooool000000oooool2o`0000Cooooo00?o0000oooo
ooooool01oooool00ol0003oooooooooo`03ooooo`05o`000?ooooooooooooooool000001?ooool2
o`00013ooooo00?o0000ooooool00000S_ooool0017ooooo00?o0000ooooooooool07_ooool01Ol0
003ooooooooooooooooo000000Cooooo00Ko0000oooooooooooo0000ooooool0000Gooooo`03o`00
0?oooooo000000?ooooo0_l00004ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0
0oooool01Ol0003ooooooooooooooooo000000Gooooo00?o0000ooooooooool03_ooool2o`0008oo
oooo000Aooooo`;o00007oooool01Ol0003ooooooooooooooooo000000Cooooo00Ko0000oooooooo
oooo0000ooooool00006ooooo`03o`000?oooooooooo00kooooo00?o0000ooooool000000oooool2
o`0000Cooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`03ooooo`05o`000?oooooo
ooooooooool000001Oooool00ol0003oooooooooo`0>ooooo`;o0000Soooool0017ooooo00?o0000
ooooooooool07_ooool01Ol0003ooooooooooooooooo000000Cooooo00?o0000ooooool000000_oo
ool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00gooooo00Co0000oooooooooooo0000
0oooool2o`0000Cooooo00?o0000ooooooooool03_ooool01?l0003oooooooooool0000Fooooo`;o
0000Soooool0017ooooo00?o0000ooooooooool07oooool01?l0003oooooooooool00004ooooo`03
o`000?oooooo000000;ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`0=ooooo`04
o`000?ooooooooooo`0000?ooooo0_l00004ooooo`03o`000?oooooooooo00kooooo00Co0000oooo
oooooooo00005_ooool2o`0008oooooo000Aooooo`03o`000?oooooooooo01oooooo00Co0000oooo
oooooooo00001?ooool00ol0003oooooo`000002ooooo`03o`000?oooooooooo00?ooooo0_l0000?
ooooo`04o`000?ooooooooooo`0000?ooooo0_l00004ooooo`03o`000?oooooooooo00kooooo00Co
0000oooooooooooo00005oooool00ol0003oooooooooo`2=ooooo`004Oooool00ol0003ooooooooo
o`0Oooooo`04o`000?ooooooooooo`0000Cooooo00?o0000ooooool000000oooool00ol0003ooooo
ooooo`02ooooo`;o00003oooool01?l0003oooooooooool00002ooooo`03o`000?oooooo000000Co
oooo00?o0000ooooooooool03_ooool00ol0003oooooo`00000Hooooo`03o`000?oooooooooo08go
oooo000Aooooo`03o`000?oooooooooo01oooooo00Co0000oooooooooooo00001?ooool00ol0003o
ooooo`000003ooooo`03o`000?oooooooooo00;ooooo0_l0000?ooooo`04o`000?ooooooooooo`00
00;ooooo00?o0000ooooool000001?ooool00ol0003oooooooooo`0>ooooo`03o`000?oooooo0000
01Sooooo00?o0000ooooooooool0SOooool0017ooooo0_l0000Pooooo`04o`000?ooooooooooo`00
00Cooooo00?o0000ooooool000000oooool01ol0003ooooooooooooooooo0000ooooool000003ooo
ool01?l0003oooooooooool00002ooooo`03o`000?oooooo000000Cooooo00?o0000ooooooooool0
3_ooool00ol0003oooooo`00000Hooooo`03o`000?oooooooooo08gooooo000Aooooo`03o`000?oo
oooooooo01oooooo00Co0000oooooooooooo00001?ooool00ol0003oooooo`000003ooooo`07o`00
0?ooooooooooooooool0003oooooo`00000?ooooo`04o`000?ooooooooooo`0000;ooooo00Co0000
oooooooooooo00000_ooool00ol0003oooooooooo`0?ooooo`03o`000?oooooo000001Sooooo00?o
0000ooooooooool0SOooool0017ooooo00?o0000ooooooooool07oooool01?l0003oooooooooool0
0004ooooo`03o`000?oooooo000000?ooooo00Oo0000ooooooooooooooooo`000?oooooo000000oo
oooo00Co0000oooooooooooo00000_ooool01?l0003oooooooooool00002ooooo`03o`000?oooooo
oooo00oooooo00?o0000ooooool000006?ooool00ol0003oooooooooo`2=ooooo`002Oooool3o`00
00Gooooo00?o0000ooooooooool07oooool01?l0003oooooooooool00004ooooo`03o`000?oooooo
000000?ooooo00Go0000ooooooooooooooooo`000002ooooo`03o`000?oooooooooo00cooooo00Co
0000oooooooooooo00000_ooool01?l0003oooooooooool00002ooooo`03o`000?oooooooooo00oo
oooo00?o0000ooooool000006?ooool00ol0003oooooooooo`2=ooooo`002?ooool01Ol0003ooooo
oooooooooooo000000Cooooo00?o0000ooooooooool07oooool01?l0003oooooooooool00004oooo
o`03o`000?oooooo000000?ooooo00Co0000oooooooooooo00000oooool00ol0003oooooooooo`0<
ooooo`04o`000?ooooooooooo`0000;ooooo00Co0000oooooooooooo00000_ooool00ol0003ooooo
ooooo`0?ooooo`03o`000?oooooo000001Sooooo00?o0000ooooooooool0SOooool000Sooooo00Go
0000ooooooooooooooooo`000004ooooo`?o00007oooool01?l0003oooooooooool00004ooooo`03
o`000?oooooo000000?ooooo1?l00003ooooo`05o`000?ooooooooooooooool000002_ooool01?l0
003oooooooooool00002ooooo`04o`000?ooooooooooo`0000;ooooo00?o0000ooooooooool03ooo
ool00ol0003oooooo`00000Hooooo`03o`000?oooooooooo08gooooo0008ooooo`Co00001Oooool0
0ol0003oooooooooo`0Oooooo`03o`000?oooooo000000Gooooo00?o0000ooooool000002_ooool0
1Ol0003ooooooooooooooooo000000[ooooo00Oo0000ooooooooooooooooo`000?oooooo000000;o
oooo00Co0000oooooooooooo00004Oooool00ol0003oooooo`00002Xooooo`002?ooool00ol0003o
ooooooooo`06ooooo`03o`000?oooooooooo01oooooo00?o0000ooooool000001Oooool00ol0003o
ooooo`00000:ooooo`05o`000?ooooooooooooooool000002_ooool01ol0003ooooooooooooooooo
0000ooooool000000_ooool01?l0003oooooooooool0000Aooooo`03o`000?oooooo00000:Sooooo
0009ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool07oooool00ol0003oooooo`00
0005ooooo`03o`000?oooooo000000[ooooo00Co0000oooooooooooooooo0_l00009ooooo`07o`00
0?ooooooooooooooool0003oooooo`000002ooooo`04o`000?ooooooooooo`00017ooooo00?o0000
ooooool00000Z?ooool000[ooooo0_l00005ooooo`03o`000?oooooooooo01oooooo00?o0000oooo
ool000001_ooool2o`0000[ooooo00Co0000oooooooooooooooo0_l00009ooooo`07o`000?oooooo
ooooooooool0003oooooo`000002ooooo`03o`000?oooooo000001;ooooo00?o0000ooooool00000
Z?ooool0017ooooo00?o0000ooooooooool07oooool00ol0003oooooo`000006ooooo`03o`000?oo
oooooooo00Wooooo00Ko0000oooooooooooo0000ooooool00008ooooo`03o`000?oooooooooo00;o
oooo00?o0000ooooool000000_ooool00ol0003oooooo`00000Booooo`03o`000?oooooo00000:So
oooo000Aooooo`;o00008?ooool00ol0003oooooo`000006ooooo`03o`000?oooooooooo00Wooooo
00Co0000oooooooooooo00000_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00;o
oooo00?o0000ooooool000000_ooool00ol0003oooooo`00000Booooo`03o`000?oooooo00000:So
oooo000Aooooo`03o`000?oooooooooo01oooooo00?o0000ooooool000001_ooool00ol0003ooooo
ooooo`09ooooo`04o`000?ooooooooooo`0000;ooooo00?o0000ooooooooool01Oooool00ol0003o
ooooooooo`02ooooo`03o`000?oooooo000000?ooooo0_l0000Booooo`03o`000?oooooo00000:So
oooo000Aooooo`03o`000?oooooooooo01oooooo00?o0000ooooool000001_ooool00ol0003ooooo
ooooo`09ooooo`04o`000?ooooooooooo`0000;ooooo00?o0000ooooooooool01Oooool00ol0003o
ooooooooo`02ooooo`03o`000?oooooo000000?ooooo0_l0000Booooo`03o`000?oooooo00000:So
oooo000Aooooo`03o`000?oooooooooo01oooooo00?o0000ooooool000001_ooool00ol0003ooooo
ooooo`09ooooo`04o`000?ooooooooooo`0000;ooooo00?o0000ooooooooool01Oooool00ol0003o
ooooooooo`02ooooo`03o`000?oooooo000000?ooooo00?o0000ooooooooool04Oooool00ol0003o
ooooo`00002Xooooo`004Oooool00ol0003oooooooooo`0Oooooo`03o`000?oooooo000000Kooooo
00?o0000ooooooooool02Oooool01?l0003oooooooooool00003ooooo`03o`000?oooooooooo00Co
oooo00?o0000ooooooooool00_ooool00ol0003oooooo`000003ooooo`03o`000?oooooooooo017o
oooo00?o0000ooooool00000Z?ooool0017ooooo0_l0000Pooooo`03o`000?oooooo000000Kooooo
00?o0000ooooooooool02Oooool01?l0003oooooooooool00003ooooo`03o`000?oooooooooo00Co
oooo00?o0000ooooooooool00_ooool00ol0003oooooo`000003ooooo`03o`000?oooooooooo017o
oooo00?o0000ooooool00000Z?ooool0017ooooo00?o0000ooooooooool08?ooool2o`0001;ooooo
00?o0000ooooool000001?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00;ooooo
00?o0000ooooool000005oooool00ol0003oooooo`00002Xooooo`004Oooool00ol0003ooooooooo
o`0Pooooo`;o00004_ooool00ol0003oooooo`000004ooooo`03o`000?oooooooooo00Cooooo00?o
0000ooooooooool00_ooool00ol0003oooooo`00000Gooooo`03o`000?oooooo00000:Sooooo000A
ooooo`03o`000?oooooooooo023ooooo0_l0000Booooo`03o`000?oooooo000000Cooooo00?o0000
ooooooooool01?ooool00ol0003oooooooooo`02ooooo`03o`000?oooooo000001Oooooo00?o0000
ooooool00000Z?ooool0017ooooo00?o0000ooooooooool08?ooool2o`0001?ooooo0_l00005oooo
o`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00_ooool00ol0003oooooo`00000Goooo
o`03o`000?oooooo00000:Sooooo000Aooooo`;o00008Oooool00ol0003oooooooooo`0Booooo`;o
00001Oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooool0
00005oooool00ol0003oooooo`00002Xooooo`004Oooool00ol0003oooooooooo`0Pooooo`03o`00
0?oooooooooo01;ooooo0_l00005ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0
0_ooool00ol0003oooooo`00000Gooooo`03o`000?oooooo00000:Sooooo000Aooooo`03o`000?oo
oooooooo023ooooo00?o0000ooooooooool04_ooool2o`0000Gooooo00?o0000ooooooooool00ooo
ool00ol0003oooooooooo`02ooooo`03o`000?oooooo000001Oooooo00?o0000ooooool00000Z?oo
ool000Wooooo0ol00005ooooo`03o`000?oooooooooo023ooooo00?o0000ooooooooool04_ooool0
0ol0003oooooooooo`04ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00_ooool0
0ol0003oooooo`00000Hooooo`;o0000Z?ooool000Sooooo00Go0000ooooooooooooooooo`000004
ooooo`03o`000?oooooooooo023ooooo00?o0000ooooooooool04_ooool00ol0003oooooooooo`05
ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool00_ooool2o`0001Wooooo00?o0000
ooooooooool0Yoooool000Sooooo00Go0000ooooooooooooooooo`000004ooooo`03o`000?oooooo
oooo023ooooo00?o0000ooooooooool04_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooo
oooo00;ooooo00?o0000ooooooooool00_ooool2o`0001Wooooo00?o0000ooooooooool0Yoooool0
00Wooooo0ol00005ooooo`?o00008?ooool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo
00Gooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo
01Oooooo00?o0000ooooooooool0Yoooool000Sooooo00Go0000ooooooooooooooooo`000004oooo
o`03o`000?oooooooooo03gooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`03oooo
o`03o`000?oooooooooo01Oooooo00?o0000ooooooooool0Yoooool000Sooooo00Go0000oooooooo
ooooooooo`000004ooooo`03o`000?oooooooooo03gooooo00?o0000ooooooooool00_ooool00ol0
003oooooooooo`03ooooo`03o`000?oooooooooo01Oooooo00?o0000ooooooooool0Yoooool000Wo
oooo0ol00005ooooo`03o`000?oooooooooo03gooooo00?o0000ooooooooool00_ooool00ol0003o
ooooooooo`03ooooo`03o`000?oooooooooo01Oooooo00?o0000ooooooooool0Yoooool0017ooooo
00?o0000ooooooooool0?Oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00?ooooo
00?o0000ooooooooool05oooool00ol0003oooooooooo`2Wooooo`004Oooool2o`0003kooooo00?o
0000ooooooooool00_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo01Oooooo00?o
0000ooooooooool0Yoooool0017ooooo00?o0000ooooooooool0?Oooool00ol0003oooooooooo`02
ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool05oooool00ol0003oooooooooo`2W
ooooo`004Oooool00ol0003oooooooooo`0mooooo`03o`000?oooooooooo00;ooooo00?o0000oooo
ooooool00oooool00ol0003oooooooooo`0Gooooo`03o`000?oooooooooo0:Oooooo000Aooooo`03
o`000?oooooooooo03gooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`03ooooo`03
o`000?oooooooooo01Oooooo00?o0000ooooooooool0Yoooool0017ooooo00?o0000ooooooooool0
?Oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0
5oooool00ol0003oooooooooo`2Wooooo`004Oooool2o`0003kooooo00?o0000ooooooooool00_oo
ool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo01Oooooo00?o0000ooooooooool0Yooo
ool0017ooooo00?o0000ooooooooool0?Oooool01Ol0003ooooooooooooooooo00000<[ooooo000A
ooooo`03o`000?oooooooooo03gooooo00Go0000ooooooooooooooooo`00003:ooooo`004Oooool0
0ol0003oooooooooo`0nooooo`04o`000?ooooooooooo`000<[ooooo000Aooooo`03o`000?oooooo
oooo03kooooo00Co0000oooooooooooo0000b_ooool0017ooooo00?o0000ooooooooool0?_ooool0
1?l0003oooooooooool0003:ooooo`004Oooool2o`0003oooooo00Co0000oooooooooooo0000b_oo
ool0017ooooo00?o0000ooooooooool0?_ooool01?l0003oooooooooool0003:ooooo`000oooool3
o`0000Cooooo0_l00005ooooo`03o`000?oooooooooo03kooooo00Co0000oooooooooooo0000b_oo
ool000Cooooo00?o0000ooooooooool00_ooool01?l0003oooooooooool00004ooooo`03o`000?oo
oooooooo03kooooo00Co0000oooooooooooo0000b_ooool000Cooooo00?o0000ooooooooool00_oo
ool01?l0003oooooooooool00004ooooo`03o`000?oooooooooo03kooooo00Co0000oooooooooooo
0000b_ooool000Cooooo00?o0000ooooooooool00_ooool01?l0003oooooooooool00004ooooo`?o
0000?_ooool01?l0003oooooooooool0003:ooooo`001?ooool00ol0003oooooooooo`02ooooo`04
o`000?ooooooooooo`0000Cooooo00?o0000ooooooooool0?_ooool01?l0003oooooooooool0003:
ooooo`000oooool2o`0000Cooooo00Co0000oooooooooooo00001?ooool00ol0003oooooooooo`0n
ooooo`04o`000?ooooooooooo`000<[ooooo0004ooooo`03o`000?oooooooooo00?ooooo0_l00005
ooooo`03o`000?oooooooooo03kooooo00Co0000oooooooooooo0000b_ooool0017ooooo00?o0000
ooooooooool0?_ooool01?l0003oooooooooool0003:ooooo`004Oooool2o`0003oooooo00Co0000
oooooooooooo0000b_ooool0017ooooo00?o0000ooooooooool0?_ooool01?l0003oooooooooool0
003:ooooo`004Oooool00ol0003oooooooooo`0nooooo`04o`000?ooooooooooo`000<[ooooo000A
ooooo`03o`000?oooooooooo03kooooo00Co0000oooooooooooo0000b_ooool0017ooooo00?o0000
ooooooooool0?_ooool01?l0003oooooooooool0003:ooooo`004Oooool00ol0003oooooooooo`0n
ooooo`04o`000?ooooooooooo`000<[ooooo000Aooooo`;o0000?oooool01?l0003oooooooooool0
003:ooooo`004Oooool00ol0003oooooooooo`0nooooo`04o`000?ooooooooooo`000<[ooooo000A
ooooo`03o`000?oooooooooo03kooooo00Co0000oooooooooooo0000b_ooool0017ooooo00?o0000
ooooooooool0?_ooool01?l0003oooooooooool0003:ooooo`004Oooool00ol0003oooooooooo`0n
ooooo`04o`000?ooooooooooo`000<[ooooo000Aooooo`;o0000?oooool01?l0003oooooooooool0
003:ooooo`004Oooool00ol0003oooooooooo`0oooooo`03o`000?oooooo00000<[ooooo000Aoooo
o`03o`000?oooooooooo03oooooo00?o0000ooooool00000b_ooool000?ooooo0ol00002ooooo`Go
00001?ooool00ol0003oooooooooo`0oooooo`03o`000?oooooo00000<[ooooo0004ooooo`03o`00
0?oooooooooo00;ooooo00Co0000oooooooooooo00001?ooool00ol0003oooooooooo`0oooooo`03
o`000?oooooo00000<[ooooo0004ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0
1?ooool3o`0003oooooo00?o0000ooooool00000b_ooool000Cooooo00?o0000ooooooooool01?oo
ool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo03oooooo00?o0000ooooool00000b_oo
ool000Cooooo00Go0000ooooooooooooooooo`000003ooooo`03o`000?oooooooooo00;ooooo00?o
0000ooooooooool0?oooool00ol0003oooooo`00003:ooooo`000oooool2o`0000?ooooo00Go0000
ooooooooooooooooo`000004ooooo`03o`000?oooooooooo03oooooo00?o0000ooooool00000b_oo
ool000Cooooo00?o0000ooooooooool00_ooool3o`0000Gooooo00?o0000ooooooooool0?oooool0
0ol0003oooooo`00003:ooooo`004Oooool00ol0003oooooooooo`0oooooo`03o`000?oooooo0000
0<[ooooo000Aooooo`;o0000@?ooool00ol0003oooooo`00003:ooooo`004Oooool00ol0003ooooo
ooooo`0oooooo`03o`000?oooooo00000<[ooooo000Aooooo`03o`000?oooooooooo03oooooo00?o
0000ooooool00000b_ooool0017ooooo00?o0000ooooooooool0?oooool00ol0003oooooo`00003:
ooooo`004Oooool00ol0003oooooooooo`0oooooo`03o`000?oooooo00000<[ooooo000Aooooo`;o
0000@?ooool00ol0003oooooo`00003:ooooo`004Oooool00ol0003oooooooooo`0oooooo`;o0000
boooool0017ooooo00?o0000ooooooooool0?oooool2o`000<_ooooo000Aooooo`03o`000?oooooo
oooo03oooooo0_l0003;ooooo`004Oooool00ol0003oooooooooo`0oooooo`;o0000boooool0017o
oooo0_l00010ooooo`;o0000boooool0017ooooo00?o0000ooooooooool0?oooool2o`000<_ooooo
000Aooooo`03o`000?oooooooooo03oooooo0_l0003;ooooo`000oooool3o`0000Cooooo0ol00004
ooooo`03o`000?oooooooooo03oooooo0_l0003;ooooo`001?ooool00ol0003oooooooooo`04oooo
o`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0?oooool2o`000<_ooooo0004ooooo`04
o`000?ooooooooooooooo`Go00001?ooool00ol0003oooooooooo`10ooooo`03o`000?oooooooooo
0<Wooooo0004ooooo`05o`000?ooooooooooooooool000000_ooool00ol0003oooooooooo`03oooo
o`?o0000@?ooool00ol0003oooooooooo`39ooooo`001?ooool00ol0003oooooooooo`02ooooo`03
o`000?oooooo000000Gooooo00?o0000ooooooooool0@?ooool00ol0003oooooooooo`39ooooo`00
0oooool2o`0000Gooooo0_l00005ooooo`03o`000?oooooooooo043ooooo00?o0000ooooooooool0
bOooool000Cooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`03ooooo`03o`000?oo
oooooooo043ooooo00?o0000ooooooooool0bOooool0017ooooo00?o0000ooooooooool0@?ooool0
0ol0003oooooooooo`39ooooo`004Oooool2o`00047ooooo00?o0000ooooooooool0bOooool0017o
oooo00?o0000ooooooooool0@?ooool00ol0003oooooooooo`39ooooo`004Oooool00ol0003ooooo
ooooo`10ooooo`03o`000?oooooooooo0<Wooooo000Aooooo`03o`000?oooooooooo043ooooo00?o
0000ooooooooool0bOooool0017ooooo00?o0000ooooooooool0@?ooool00ol0003oooooooooo`39
ooooo`004Oooool2o`00047ooooo00?o0000ooooooooool0bOooool0017ooooo00?o0000oooooooo
ool0ooooool=ooooo`004Oooool00ol0003oooooooooo`3oooooo`gooooo000Aooooo`03o`000?oo
oooooooo0?oooooo3Oooool0017ooooo00?o0000ooooooooool0ooooool=ooooo`00\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-1.35547, -1.15954, \
0.0766207, 0.0934482}}],

Cell[BoxData[
    \({5.85805946444879`, 6.6656785613191385`}\)], "Output",
  CellLabel->"Out[98]="]
}, Open  ]],

Cell[TextData[{
  "The variance of tree length is ",
  Cell[BoxData[
      \(TraditionalForm\`\[Sum]\+\(j = 2\)\%k\( j\^2\) \(var(T\_j)\)\)]]
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \({Variance[
        lengthList], \[Sum]\+\(j = 2\)\%10\( j\^2\) 
            4\/\(\(j\^2\) \((j - 1)\)\^2\) // 
        N, \((Variance[
              lengthList] - \[Sum]\+\(j = 2\)\%10\( j\^2\) 
                4\/\(\(j\^2\) \((j - 1)\)\^2\))\)/
        StandardErrorOfSampleMean[lengthList]}\)], "Input",
  CellLabel->"In[99]:="],

Cell[BoxData[
    \({6.6656785613191385`, 6.159070924666163`, 
      2.7750099617765733`}\)], "Output",
  CellLabel->"Out[99]="]
}, Open  ]],

Cell["\<\
In this example, the variance of tree length is significantly lower \
than predicted, using a t test (t=2.77).  This is because the variance is not \
normally distributed: some trees are exceptionally long, and so large \
deviations are quite likely (see right-hand tail of distribution).\
\>", \
"Text"],

Cell[TextData[{
  "For large numbers of genes, the variance of tree length is about 6.57.  \
Because mean tree length increases as ",
  Cell[BoxData[
      \(TraditionalForm\`4 \( N\_e\) Log[1.78\ k]\)]],
  ", the standard deviation of L, ",
  StyleBox["relative to the mean",
    FontSlant->"Italic"],
  ",, becomes small for large ",
  Cell[BoxData[
      \(TraditionalForm\`k\)]],
  ".  This makes L (or its surrogate, the number of segregating sites) a \
better estimator than the tree depth or pairwise divergence"
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\[Sum]\+\(j = 2\)\%\[Infinity]\( j\^2\) 
        4\/\(\(j\^2\) \((j - 1)\)\^2\)\)], "Input",
  CellLabel->"In[100]:="],

Cell[BoxData[
    \(\(2\ \[Pi]\^2\)\/3\)], "Output",
  CellLabel->"Out[100]="]
}, Open  ]],

Cell["\<\
Finally, we can look at the pairwise divergence.  Overall, this \
follows an exponential distribution with mean 1:\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(DisplayTogether[
        Plot[200*45*0.04  Exp[\(-x\)], {x, 0, 3}, 
          PlotStyle \[Rule] Red], \[IndentingNewLine]PairwiseDivergencePlot[
          sample, {3, 0.04}, PlotJoined \[Rule] True]];\)\)], "Input",
  CellLabel->"In[107]:="],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.31746 0.0147151 0.00163501 [
[.18254 .00222 -9 -9 ]
[.18254 .00222 9 0 ]
[.34127 .00222 -3 -9 ]
[.34127 .00222 3 0 ]
[.5 .00222 -9 -9 ]
[.5 .00222 9 0 ]
[.65873 .00222 -3 -9 ]
[.65873 .00222 3 0 ]
[.81746 .00222 -9 -9 ]
[.81746 .00222 9 0 ]
[.97619 .00222 -3 -9 ]
[.97619 .00222 3 0 ]
[.01131 .09647 -12 -4.5 ]
[.01131 .09647 0 4.5 ]
[.01131 .17822 -18 -4.5 ]
[.01131 .17822 0 4.5 ]
[.01131 .25997 -18 -4.5 ]
[.01131 .25997 0 4.5 ]
[.01131 .34172 -18 -4.5 ]
[.01131 .34172 0 4.5 ]
[.01131 .42347 -18 -4.5 ]
[.01131 .42347 0 4.5 ]
[.01131 .50522 -18 -4.5 ]
[.01131 .50522 0 4.5 ]
[.01131 .58697 -18 -4.5 ]
[.01131 .58697 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.18254 .01472 m
.18254 .02097 L
s
[(0.5)] .18254 .00222 0 1 Mshowa
.34127 .01472 m
.34127 .02097 L
s
[(1)] .34127 .00222 0 1 Mshowa
.5 .01472 m
.5 .02097 L
s
[(1.5)] .5 .00222 0 1 Mshowa
.65873 .01472 m
.65873 .02097 L
s
[(2)] .65873 .00222 0 1 Mshowa
.81746 .01472 m
.81746 .02097 L
s
[(2.5)] .81746 .00222 0 1 Mshowa
.97619 .01472 m
.97619 .02097 L
s
[(3)] .97619 .00222 0 1 Mshowa
.125 Mabswid
.05556 .01472 m
.05556 .01847 L
s
.0873 .01472 m
.0873 .01847 L
s
.11905 .01472 m
.11905 .01847 L
s
.15079 .01472 m
.15079 .01847 L
s
.21429 .01472 m
.21429 .01847 L
s
.24603 .01472 m
.24603 .01847 L
s
.27778 .01472 m
.27778 .01847 L
s
.30952 .01472 m
.30952 .01847 L
s
.37302 .01472 m
.37302 .01847 L
s
.40476 .01472 m
.40476 .01847 L
s
.43651 .01472 m
.43651 .01847 L
s
.46825 .01472 m
.46825 .01847 L
s
.53175 .01472 m
.53175 .01847 L
s
.56349 .01472 m
.56349 .01847 L
s
.59524 .01472 m
.59524 .01847 L
s
.62698 .01472 m
.62698 .01847 L
s
.69048 .01472 m
.69048 .01847 L
s
.72222 .01472 m
.72222 .01847 L
s
.75397 .01472 m
.75397 .01847 L
s
.78571 .01472 m
.78571 .01847 L
s
.84921 .01472 m
.84921 .01847 L
s
.88095 .01472 m
.88095 .01847 L
s
.9127 .01472 m
.9127 .01847 L
s
.94444 .01472 m
.94444 .01847 L
s
.25 Mabswid
0 .01472 m
1 .01472 L
s
.02381 .09647 m
.03006 .09647 L
s
[(50)] .01131 .09647 1 0 Mshowa
.02381 .17822 m
.03006 .17822 L
s
[(100)] .01131 .17822 1 0 Mshowa
.02381 .25997 m
.03006 .25997 L
s
[(150)] .01131 .25997 1 0 Mshowa
.02381 .34172 m
.03006 .34172 L
s
[(200)] .01131 .34172 1 0 Mshowa
.02381 .42347 m
.03006 .42347 L
s
[(250)] .01131 .42347 1 0 Mshowa
.02381 .50522 m
.03006 .50522 L
s
[(300)] .01131 .50522 1 0 Mshowa
.02381 .58697 m
.03006 .58697 L
s
[(350)] .01131 .58697 1 0 Mshowa
.125 Mabswid
.02381 .03107 m
.02756 .03107 L
s
.02381 .04742 m
.02756 .04742 L
s
.02381 .06377 m
.02756 .06377 L
s
.02381 .08012 m
.02756 .08012 L
s
.02381 .11282 m
.02756 .11282 L
s
.02381 .12917 m
.02756 .12917 L
s
.02381 .14552 m
.02756 .14552 L
s
.02381 .16187 m
.02756 .16187 L
s
.02381 .19457 m
.02756 .19457 L
s
.02381 .21092 m
.02756 .21092 L
s
.02381 .22727 m
.02756 .22727 L
s
.02381 .24362 m
.02756 .24362 L
s
.02381 .27632 m
.02756 .27632 L
s
.02381 .29267 m
.02756 .29267 L
s
.02381 .30902 m
.02756 .30902 L
s
.02381 .32537 m
.02756 .32537 L
s
.02381 .35807 m
.02756 .35807 L
s
.02381 .37442 m
.02756 .37442 L
s
.02381 .39077 m
.02756 .39077 L
s
.02381 .40712 m
.02756 .40712 L
s
.02381 .43982 m
.02756 .43982 L
s
.02381 .45617 m
.02756 .45617 L
s
.02381 .47252 m
.02756 .47252 L
s
.02381 .48887 m
.02756 .48887 L
s
.02381 .52157 m
.02756 .52157 L
s
.02381 .53792 m
.02756 .53792 L
s
.02381 .55427 m
.02756 .55427 L
s
.02381 .57062 m
.02756 .57062 L
s
.02381 .60332 m
.02756 .60332 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
1 0 0 r
.5 Mabswid
.02381 .60332 m
.06244 .53587 L
.10458 .4711 L
.14415 .41761 L
.18221 .37209 L
.22272 .32928 L
.26171 .29292 L
.30316 .25887 L
.34309 .23002 L
.3815 .20548 L
.42237 .18244 L
.46172 .16288 L
.49955 .14624 L
.53984 .13056 L
.57861 .11724 L
.61984 .10476 L
.65954 .09417 L
.69774 .08516 L
.73838 .0767 L
.77751 .06951 L
.81909 .06278 L
.85916 .05708 L
.89771 .05224 L
.93871 .04769 L
.97619 .04402 L
s
0 g
.03016 .551 m
.04286 .56081 L
.05556 .56081 L
.06825 .46761 L
.08095 .54446 L
.09365 .58697 L
.10635 .4905 L
.11905 .34499 L
.13175 .39894 L
.14444 .30411 L
.15714 .42674 L
.16984 .3597 L
.18254 .45944 L
.19524 .46761 L
.20794 .37605 L
.22063 .33845 L
.23333 .19457 L
.24603 .22563 L
.25873 .2943 L
.27143 .4578 L
.28413 .30248 L
.29683 .23708 L
.30952 .33191 L
.32222 .19293 L
.33492 .12753 L
.34762 .28449 L
.36032 .2289 L
.37302 .34662 L
.38571 .26651 L
.39841 .11118 L
.41111 .18639 L
.42381 .12426 L
.43651 .13244 L
.44921 .11772 L
.4619 .11118 L
.4746 .14552 L
.4873 .14388 L
.5 .14388 L
.5127 .17658 L
.5254 .10464 L
.5381 .06213 L
.55079 .0654 L
.56349 .14388 L
.57619 .20438 L
.58889 .0932 L
.60159 .08175 L
.61429 .17331 L
.62698 .07521 L
.63968 .08339 L
.65238 .10464 L
Mistroke
.66508 .10955 L
.67778 .02943 L
.69048 .06377 L
.70317 .08012 L
.71587 .13407 L
.72857 .01472 L
.74127 .06704 L
.75397 .04905 L
.76667 .1635 L
.77937 .01472 L
.79206 .04905 L
.80476 .17331 L
.81746 .12263 L
.83016 .05396 L
.84286 .11936 L
.85556 .08993 L
.86825 .05886 L
.88095 .01472 L
.89365 .01472 L
.90635 .0932 L
.91905 .01472 L
.93175 .08339 L
.94444 .04088 L
.95714 .07031 L
.96984 .05396 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[107]:=",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/B000`400?l00000o`00003ooooooolQ
ooooo`00>Oooool2o`0000Cooooo00?o0000ooooooooool00_ooool3o`0002;ooooo0ol0000Roooo
o`?o00001?ooool00ol0003oooooooooo`02ooooo`?o00008_ooool5o`00023ooooo1Ol00003oooo
o`03o`000?oooooooooo00;ooooo0ol0000Rooooo`?o00001oooool003Sooooo00Co0000oooooooo
oooo00001oooool01Ol0003ooooooooooooooooo000002;ooooo00?o0000ooooooooool08_ooool0
0ol0003oooooooooo`07ooooo`05o`000?ooooooooooooooool000008_ooool01?l0003ooooooooo
ool0000Qooooo`04o`000?ooooooooooo`0000Oooooo00Go0000ooooooooooooooooo`00000Poooo
o`05o`000?ooooooooooooooool000001_ooool003Sooooo00Co0000oooooooooooo00002oooool0
0ol0003oooooooooo`0Pooooo`03o`000?oooooooooo02;ooooo00?o0000ooooooooool02oooool0
0ol0003oooooooooo`0Qooooo`03o`000?oooooooooo02;ooooo00?o0000ooooooooool02oooool0
0ol0003oooooooooo`0Rooooo`03o`000?oooooooooo00Cooooo000hooooo`04o`000?oooooooooo
o`0000_ooooo00?o0000ooooooooool08?ooool00ol0003oooooooooo`0Rooooo`03o`000?oooooo
oooo00_ooooo00?o0000ooooooooool08_ooool00ol0003oooooooooo`0Rooooo`03o`000?oooooo
oooo00[ooooo00?o0000ooooooooool08?ooool2o`0000Oooooo000hooooo`04o`000?oooooooooo
o`0000Oooooo1?l0000Sooooo`03o`000?oooooooooo02;ooooo00?o0000ooooooooool01oooool4
o`0002;ooooo00Go0000ooooooooooooooooo`00000Pooooo`05o`000?ooooooooooooooool00000
1oooool4o`0002Gooooo00?o0000ooooooooool01?ooool003Sooooo00Co0000oooooooooooo0000
1oooool00ol0003oooooooooo`0Sooooo`;o00008oooool2o`0000Wooooo00?o0000ooooooooool0
8oooool01Ol0003ooooooooooooooooo0000023ooooo00Go0000ooooooooooooooooo`000007oooo
o`03o`000?oooooooooo02;ooooo00Go0000ooooooooooooooooo`000006ooooo`00>Oooool2o`00
00Sooooo1Ol0000Rooooo`03o`000?oooooooooo02;ooooo00?o0000ooooooooool01oooool5o`00
02;ooooo0ol0000Rooooo`?o00002?ooool5o`00027ooooo0ol00007ooooo`005Oooool00ol0003o
ooooooooo`3oooooo`Wooooo000Eooooo`03o`000?oooooooooo0?oooooo2Oooool001Gooooo00?o
0000ooooooooool0ooooool9ooooo`005Oooool00ol0003oooooooooo`3oooooo`Wooooo000>oooo
olOo000000<00000o`000?l000002_l000000`00003o0000o`00000Io`0000D000001Ol000000`00
003o0000o`00000Eo`0000005Oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Go
oooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Ko
oooo00<00000ooooooooool01_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Ko
oooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Ko
oooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Ko
oooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Ko
oooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Ko
oooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`06ooooo`03o`000?ooool0000000Ko
oooo00?o0000ooooooooool00oooool00`00003oooooo`000008ooooo`03o`000?oooooooooo00Go
oooo00?o0000ooooooooool01_ooool01@00003oooooooooooooool0000000Cooooo00?o00000000
0?ooool01Oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Gooooo000Eooooo`03
o`000?oooooooooo02Sooooo00<00000ooooooooool0:?ooool00ol0003oooooooooo`0Xooooo`03
o`000?oooooooooo02Wooooo00?o0000ooooooooool04?ooool00`00003oooooooooo`0:ooooo`80
00002Oooool00ol0003oooooooooo`0>ooooo`0500000?ooooooooooooooo`0000001Oooool00`00
003oooooooooo`0=ooooo`03o`000?oooooooooo00Gooooo000Eooooo`03o`000?oooooooooo0;go
oooo0P00000;ooooo`8000006Oooool00`00003oooooooooo`02ooooo`0300000?oooooooooo00?o
oooo0P00000Fooooo`005Oooool00ol0003oooooooooo`2_ooooo`0300000?oooooooooo00_ooooo
0P00000;ooooo`0300000?ooool0000001Sooooo00<00000ooooooooool00_ooool00`00003ooooo
ooooo`03ooooo`8000005_ooool001Gooooo0_l0002`ooooo`0300000?oooooooooo00[ooooo00<0
0000ooooo`0000002oooool00`00003ooooo0000000Hooooo`0300000?oooooooooo00?ooooo00L0
0000oooooooooooooooo00000?ooool0000001Kooooo000Eooooo`03o`000?oooooooooo0:oooooo
00<00000ooooooooool02_ooool00`00003ooooo0000000;ooooo`0300000?ooool0000001Sooooo
00<00000ooooooooool00oooool01`00003oooooooooooooool00000ooooo`0000005_ooool001Go
oooo00?o0000ooooooooool0[oooool2000000_ooooo00<00000ooooo`0000002oooool01000003o
ooooooooo`00000Fooooo`0300000?oooooooooo00Cooooo00L00000oooooooooooooooo00000?oo
ool0000000Gooooo00<00000ooooooooool03_ooool001Gooooo00?o0000ooooooooool0[_ooool0
0`00003ooooo0000000;ooooo`0400000?oooooooooo000000Wooooo00D00000oooooooooooooooo
0000000Fooooo`0300000?oooooooooo00Cooooo00D00000oooooooooooooooo00000002ooooo`03
00000?oooooooooo00;ooooo00@00000oooooooooooooooo1_oo0007ooooo`005Oooool2o`000:oo
oooo00<00000ooooo`0000002oooool01000003oooooooooo`000004ooooo`0300000?oooooooooo
00;ooooo00<00000ooooooooool00_ooool00`00003oooooooooo`0Cooooo`0300000?oooooooooo
00Cooooo00P00000oooooooooooooooo00000?ooooooo`00000000Coo`000P000002ool000gooooo
000Eooooo`03o`000?oooooooooo0:kooooo00@00000ooooooooool000002_ooool01000003ooooo
ooooo`000004ooooo`0300000?oooooooooo00;ooooo00<00000ooooooooool00_ooool00`00003o
ooooooooo`0Cooooo`0400000?ooooooooooooooo`?oo`0000P00000ool00?oo003oo`0000000?oo
003ooooo000000?ooooo00<00000ooooo`0000003oooool001Gooooo00?o0000ooooooooool0[_oo
ool01000003oooooooooo`00000:ooooo`0400000?oooooooooo000000?ooooo0P000004ooooo`03
00000?oooooooooo00;ooooo00<00000ooooooooool01oooool00`00003oooooooooo`08ooooo`03
00000?oo003oo`0000;oo`000oooool01@00003oooooooooooooool0000000;ooooo00D00000oooo
oooooooooooo00000002ooooo`0300000?oooooooooo00;ooooo00<00000ooooooooool01oooool0
01Gooooo00?o0000ooooooooool0[_ooool01000003oooooooooo`00000:ooooo`0400000?oooooo
oooo000000;ooooo00<00000ooooo`0000001?ooool00`00003oooooooooo`02ooooo`0300000?oo
oooooooo00Oooooo00<00000ooooooooool02?oo00000`00003oooooooooo`06ooooo`0300000?oo
ool0000000?ooooo00D00000oooooooooooooooo00000002ooooo`0300000?oooooooooo00;ooooo
00<00000ooooooooool01oooool001Gooooo00?o0000ooooooooool0ROooool3o`00027ooooo00<0
0000ooooooooool00_ooool00`00003oooooooooo`06ooooo`0300000?oooooooooo00;ooooo0P00
0002ooooo`0300000?oooooooooo00;ooooo00<00000ooooooooool00_ooool01000003ooooooooo
ooooool6ool0000300000?oo003oo`0000Sooooo00<00000ooooooooool01_ooool00`00003ooooo
00000004ooooo`0400000?oooooooooo000000?ooooo00@00000ooooooooool000002_ooool001Go
oooo0_l0002:ooooo`04o`000?ooooooooooo`00023ooooo00<00000ooooooooool00_ooool00`00
003oooooooooo`06ooooo`0300000?oooooooooo00;ooooo00D00000oooooooooooooooo00000004
ooooo`0600000?oooooooooooooooooo000000000ooo0006ooooo`8000002?ooool00`00003ooooo
ooooo`07ooooo`0300000?ooool0000000Cooooo00<00000ooooo`0000001?ooool00`00003ooooo
0000000;ooooo`005Oooool00ol0003oooooooooo`28ooooo`05o`000?ooooooooooooooool00000
8?ooool00`00003oooooooooo`03ooooo`0300000?oooooooooo00Gooooo00<00000ooooooooool0
1oooool01@00003oooooool00?oo0000000000?oo`0000?ooooo00000?ooool01oooool00`00003o
oooo00000008ooooo`0300000?oooooooooo00Oooooo00<00000ooooo`0000001?ooool00`00003o
oooo00000005ooooo`0300000?oooooooooo00[ooooo000Eooooo`03o`000?oooooooooo08Sooooo
00Go0000ooooooooooooooooo`00000Pooooo`0300000?oooooooooo00Cooooo00<00000oooooooo
ool01?ooool00`00003oooooooooo`04ooooo`?oo`0000D00000ool00?oooooooooo00000005oooo
o`0300000?oooooooooo00Gooooo00<00000ooooo`0000001oooool00`00003oooooooooo`08oooo
o`0300000?ooool0000000Cooooo00<00000ooooo`0000004_ooool001Gooooo00?o0000oooooooo
ool0R?ooool01Ol0003ooooooooooooooooo000001Cooooo0_l0000:ooooo`0300000?oooooooooo
00Gooooo00<00000ooooooooool00oooool00`00003oo`00ool00004ool000?ooooo00D00000oooo
oooooooooooo00000005ooooo`0300000?oooooooooo00Gooooo00<00000ooooo`0000001oooool0
0`00003oooooooooo`08ooooo`0300000?ooool0000000Cooooo00<00000ooooo`0000004_ooool0
01Gooooo0_l00028ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool02_ooool00ol0
003oooooooooo`04ooooo`03o`000?oooooo000000Wooooo00<00000ooooooooool01_ooool00`00
003oo`00ool00002ool0000300000?oooooooooo00Oooooo00D00000oooooooooooooooo00000005
ooooo`0300000?oooooooooo00Gooooo00<00000ooooo`0000001oooool00`00003oooooooooo`08
ooooo`0300000?ooool0000000Gooooo00<00000ooooooooool04Oooool001Gooooo00?o0000oooo
ooooool0Qoooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00[ooooo00?o0000oooo
ooooool01?ooool01?l0003oooooooooool00007ooooo`0300000?oooooooooo00?ooooo1?oo0000
0`00003oooooooooo`02ooooo`0300000?oooooooooo00Oooooo00D00000oooooooooooooooo0000
0005ooooo`0300000?oooooooooo00Gooooo00@00000ooooooooool000001Oooool00`00003ooooo
ooooo`0:ooooo`0300000?oooooooooo00Cooooo00<00000ooooooooool04Oooool000Oooooo0ol0
0004ooooo`;o00001Oooool00ol0003oooooooooo`27ooooo`03o`000?oooooooooo00?ooooo00?o
0000ooooooooool02Oooool2o`0000Kooooo00Co0000oooooooooooo00001oooool00`00003ooooo
ooooo`03ool000Cooooo00<00000ooooooooool00_ooool00`00003oooooooooo`07ooooo`050000
0?ooooooooooooooo`0000001Oooool00`00003oooooooooo`05ooooo`0400000?oooooooooo0000
00Gooooo00<00000ooooooooool02_ooool00`00003oooooooooo`0Hooooo`001_ooool01Ol0003o
oooooooooooooooo000000;ooooo00Co0000oooooooooooo00001?ooool00ol0003oooooooooo`26
ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool02?ooool00ol0003oooooo`000006
ooooo`05o`000?ooooooooooooooool000001_ooool00`00003oo`00ool00008ooooo`0500000?oo
ooooooooooooo`0000002Oooool01000003oooooooooo`000006ooooo`0300000?oooooooooo00Co
oooo00D00000oooooooooooooooo00000004ooooo`0300000?oooooooooo00_ooooo00<00000oooo
ooooool06?ooool000[ooooo00Co0000oooooooooooo00000_ooool00ol0003oooooooooo`02oooo
o`?o0000Q_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Oooooo00Go0000oooo
ooooooooooooo`000004ooooo`03o`000?oooooooooo00?ooooo00?o0000oooooooo00000ooo0000
0`00003oooooooooo`08ooooo`0400000?oooooooooo000000[ooooo00@00000ooooooooool00000
1_ooool00`00003oooooooooo`04ooooo`0500000?ooooooooooooooo`0000001?ooool00`00003o
ooooooooo`0;ooooo`0300000?oooooooooo01Sooooo000:ooooo`04o`000?ooooooooooo`0000;o
oooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`26ooooo`03o`000?oooooooooo00Go
oooo00?o0000ooooooooool01_ooool01Ol0003ooooooooooooooooo000000Cooooo00Co0000oooo
oooooooooooo0_oo00000ol0003oo`00ooooo`03ooooo`0300000?oooooooooo00Sooooo00@00000
ooooooooool000002_ooool01000003oooooooooo`000006ooooo`0300000?oooooooooo00Cooooo
00<00000ooooooooool00_ooool01000003oooooooooo`00000Yooooo`001_ooool4o`0000?ooooo
00Co0000oooooooooooo00001?ooool00ol0003oooooooooo`25ooooo`03o`000?oooooooooo00Ko
oooo00?o0000ooooooooool01_ooool01Ol0003ooooooooooooooooo000000Cooooo00Co0000ool0
0?oo003oo`000oooool01Ol0003oooooooooooooool0000000_ooooo00@00000ooooooooool00000
2_ooool01000003oooooooooo`000006ooooo`0300000?oooooooooo00Cooooo00<00000oooooooo
ool00_ooool01000003oooooooooo`00000Yooooo`001_ooool00ol0003oooooooooo`04ooooo`04
o`000?ooooooooooo`0000Cooooo00?o0000ooooooooool0QOooool00ol0003oooooooooo`06oooo
o`03o`000?oooooooooo00Kooooo00Ko0000ooooooooooooooooo`000?ooool3ool00003o`000?oo
oooooooo00Gooooo1000000;ooooo`0400000?oooooooooo000000[ooooo00@00000ooooooooool0
00001_ooool00`00003oooooooooo`04ooooo`0300000?oooooooooo00;ooooo00@00000oooooooo
ool00000:Oooool000Kooooo1Ol00003ooooo`;o00001Oooool00ol0003oooooooooo`1Sooooo`03
o`000?oooooooooo00gooooo0_l0000@ooooo`03o`000?oooooooooo00Kooooo00?o0000oooooooo
ool01_ooool01_l0003oooooool00?oo003o0000ool000?ooooo00?o0000ooooooooool02?ooool0
0`00003oooooooooo`0:ooooo`0300000?ooool0000000_ooooo00<00000ooooo`0000001_ooool0
0`00003oooooooooo`04ooooo`0300000?oooooooooo00;ooooo00<00000ooooo`000000:_ooool0
01Gooooo0_l0001Tooooo`03o`000?oooooooooo00cooooo00?o0000ooooool000004?ooool00ol0
003oooooooooo`06ooooo`03o`000?oooooooooo00Gooooo00?o0000ool00?oo00000_ooool00ol0
003oooooooooo`02ooooo`03o`000?oooooooooo01Gooooo00<00000ooooo`0000002oooool00`00
003ooooo00000007ooooo`0300000?oooooooooo00?ooooo00<00000ooooooooool00_ooool00`00
003ooooo0000000Zooooo`005Oooool00ol0003oooooooooo`1Sooooo`03o`000?oooooooooo00_o
oooo00Go0000ooooooooooooooooo`00000?ooooo`03o`000?oooooooooo00Oooooo00Co0000oooo
oooooooooooo0ooo00000ol0003oooooooooo`03ooooo`05o`000?ooooooooooooooool000005ooo
ool00`00003ooooo0000000;ooooo`0300000?ooool0000000Oooooo00<00000ooooooooool00_oo
ool00`00003oooooooooo`04ooooo`800000:_ooool001Gooooo00?o0000ooooooooool0Hoooool0
0ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool03?ooool0
0ol0003oooooooooo`08ooooo`04o`000?oo003oo`00ool000?ooooo00?o0000ooooooooool00ooo
ool01Ol0003ooooooooooooooooo000001Oooooo00<00000ooooo`0000002oooool00`00003ooooo
00000007ooooo`0300000?oooooooooo00;ooooo00<00000ooooooooool01?ooool00`00003ooooo
ooooo`0Yooooo`005Oooool00ol0003oooooooooo`1Sooooo`;o00001Oooool2o`0000?ooooo00?o
0000ooooooooool00oooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00Kooooo0_oo
00000ol0003oooooooooo`04ooooo`03o`000?oooooooooo00?ooooo00Go0000oooooooooooooooo
o`00000Gooooo`8000003?ooool00`00003ooooo00000007ooooo`0300000?oooooooooo00;ooooo
00<00000ooooooooool0<?ooool001Gooooo0_l0001Cooooo`03o`000?oooooooooo00kooooo0_l0
0005ooooo`05o`000?oooooo0000ooooool000001oooool00ol0003oooooooooo`0;ooooo`03o`00
0?oooooooooo00?ooooo0ooo0002ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0
0oooool01?l0003oooooooooool0000Iooooo`0300000?oooooooooo00[ooooo00<00000ooooo`00
00001oooool00`00003oooooooooo`02ooooo`0300000?oooooooooo033ooooo000Eooooo`03o`00
0?oooooooooo05;ooooo00?o0000ooooooooool03Oooool00ol0003oooooo`000005ooooo`04o`00
0?ooooooooooo`0000Sooooo00?o0000ooooooooool02oooool01?l0003oooooooooooooool2ool0
00Gooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`03ooooo`04o`000?oooooooooo
o`0001Wooooo00<00000ooooooooool02_ooool00`00003ooooo00000007ooooo`0300000?oooooo
oooo00;ooooo00<00000ooooooooool0<?ooool001Gooooo00?o0000ooooooooool0D_ooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooo000000Cooooo00?o0000ooooooooool02oooool00ol0
003oooooooooo`0:ooooo`04o`000?oo003oo`00ool000Sooooo00?o0000ooooooooool00oooool0
0ol0003oooooooooo`03ooooo`04o`000?ooooooooooo`0001Wooooo00<00000ooooooooool02_oo
ool00`00003ooooo00000007ooooo`0500000?ooooooooooooooo`000000<oooool001Gooooo00?o
0000ooooooooool0DOooool2o`0000oooooo00?o0000ooooool000001?ooool00ol0003ooooooooo
o`0;ooooo`03o`000?oooooooooo00Sooooo0_oo00000ol0003oooooooooo`09ooooo`03o`000?oo
oooooooo00;ooooo00?o0000ooooooooool01?ooool01?l0003oooooooooool0000Vooooo`030000
0?ooool0000000Oooooo00D00000oooooooooooooooo0000000cooooo`005Oooool00ol0003ooooo
ooooo`1Aooooo`;o00003oooool00ol0003oooooo`000004ooooo`03o`000?oooooooooo00_ooooo
00?o0000ooooooooool01Ol00003ool00003ooooool0003ooooo00_ooooo00?o0000ooooooooool0
0_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooo000002Kooooo0P000008ooooo`050000
0?ooooooooooooooo`000000<oooool001Gooooo0_l0001Booooo`;o00003oooool00ol0003ooooo
o`000004ooooo`03o`000?oooooooooo00cooooo0_l00003ooooo`03ool00?l0003ooooo00?ooooo
00?o0000ooooooooool02_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Gooooo
00?o0000ooooool000009_ooool2000000Sooooo00@00000ooooooooool00000=?ooool001Gooooo
00?o0000ooooooooool0DOooool2o`0000oooooo00Co0000oooooooooooo00000_ooool00ol0003o
ooooooooo`0?ooooo`?oo`000_ooool01Ol0003ooooooooooooooooo000000cooooo00?o0000oooo
ooooool00_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooo000002Oooooo00<00000oooo
ooooool01_ooool01000003oooooooooo`00000dooooo`005Oooool00ol0003oooooooooo`1Aoooo
o`;o00003oooool01?l0003oooooooooool00002ooooo`03o`000?oooooooooo00gooooo0_oo0005
ooooo`05o`000?ooooooooooooooool000003?ooool00ol0003oooooooooo`02ooooo`03o`000?oo
oooooooo00Gooooo00?o0000ooooool000009oooool00`00003oooooooooo`07ooooo`0300000?oo
ool0000003Cooooo000Eooooo`03o`000?oooooooooo053ooooo00Co0000oooooooooooo00003_oo
ool01?l0003oooooooooool00002ooooo`03o`000?oooooooooo00[ooooo0ooo0008ooooo`04o`00
0?ooooooooooo`0000gooooo00Go0000ooooooooooooooooo`000007ooooo`03o`000?oooooo0000
02Oooooo00<00000ooooooooool01oooool2000003Gooooo000Eooooo`;o0000DOooool01?l0003o
ooooooooool0000>ooooo`04o`000?ooooooooooo`0000;ooooo00?o0000ooooooooool02?ooool2
ool000_ooooo00Co0000oooooooooooo00003Oooool01Ol0003ooooooooooooooooo000000Oooooo
0_l0000Xooooo`0300000?oooooooooo00Oooooo0P00000eooooo`005Oooool00ol0003ooooooooo
o`1@ooooo`04o`000?ooooooooooo`0000kooooo00Co0000oooooooooooo00000_ooool00ol0003o
ooooooooo`06ooooo`;oo`003Oooool01?l0003oooooooooool0000=ooooo`05o`000?oooooooooo
ooooool000002?ooool00ol0003oooooooooo`0Vooooo`0300000?oooooooooo00Oooooo0P00000e
ooooo`0000Coooooo`000?l0003o00001?ooool2o`0000Cooooo0_l00005ooooo`03o`000?oooooo
oooo053ooooo00Co0000oooooooooooo00003_ooool01_l0003oooooooooool0003oooooo`0000Oo
oooo0_oo000@ooooo`;o00003_ooool01?l0003oooooooooool00009ooooo`03o`000?oooooooooo
033ooooo00<00000ooooooooool0=?ooool000;ooooo00?o0000ooooooooool00_ooool01?l0003o
ooooooooool00002ooooo`04o`000?ooooooooooo`0000Cooooo00?o0000ooooooooool0Coooool0
1Ol0003ooooooooooooooooo000000gooooo00Oo0000ooooooooooooooooo`000?oooooo000000Ko
oooo00?oo`00ooooooooool04?ooool2o`0000kooooo00Co0000oooooooooooo00002Oooool00ol0
003oooooooooo`0`ooooo`0300000?oooooooooo03Cooooo0002ooooo`03o`000?oooooooooo00;o
oooo00Co0000oooooooooooo00000_ooool01?l0003oooooooooool00004ooooo`03o`000?oooooo
oooo04oooooo00Go0000ooooooooooooooooo`00000=ooooo`03o`000?oooooooooo00;ooooo0_l0
0004ooooo`;oo`005?ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooo000007?ooooo0002
ooooo`03o`000?oooooooooo00;ooooo00Co0000oooooooooooo00000_ooool01?l0003ooooooooo
ool00004ooooo`?o0000Coooool01Ol0003ooooooooooooooooo000000gooooo00?o0000oooooooo
ool00_ooool2o`0000;ooooo0_oo000Vooooo`03o`000?oooooo000007?ooooo0002ooooo`03o`00
0?oooooooooo00;ooooo00Co0000oooooooooooo00000_ooool01?l0003oooooooooool00004oooo
o`03o`000?oooooooooo04oooooo00Go0000ooooooooooooooooo`00000=ooooo`03o`000?oooooo
oooo00;ooooo00Co0000oooooooo003oo`00:?ooool00ol0003oooooo`00001cooooo`0000?ooooo
o`000?l000001?ooool01?l0003oooooooooool00002ooooo`04o`000?ooooooooooo`0000Cooooo
00?o0000ooooooooool0Coooool01Ol0003ooooooooooooooooo000000gooooo00?o0000oooooooo
ool00_ooool00ol0003oo`00ooooo`0Yooooo`03o`000?oooooo000007?ooooo0002ooooo`03o`00
0?oooooooooo00?ooooo0_l00004ooooo`;o00001Oooool00ol0003oooooooooo`1>ooooo`03o`00
0?oooooooooo00;ooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`02ool002cooooo
00?o0000ooooool00000Loooool001Gooooo0_l0000gooooo`03o`000?oooooooooo01Gooooo00?o
0000ooooooooool00_ooool00ol0003oooooooooo`0;ooooo`03o`000?ooooooo`0002kooooo0_l0
001dooooo`005Oooool00ol0003oooooooooo`0fooooo`03o`000?oooooooooo01Gooooo00?o0000
ooooooooool00_ooool00ol0003oooooooooo`0;ooooo`03o`000?oo003ooooo02oooooo00?o0000
ooooooooool0L_ooool001Gooooo00?o0000ooooooooool0=_ooool2o`0001Kooooo00?o0000oooo
ooooool00_ooool00ol0003oooooooooo`09ooooo`;oo`0000?o0000ooooooooool0;oooool00ol0
003oooooooooo`1booooo`005Oooool00ol0003oooooooooo`0fooooo`;o00005_ooool00ol0003o
ooooooooo`02ooooo`03o`000?oooooooooo00Oooooo0_oo0002ooooo`03o`000?oooooooooo02oo
oooo00?o0000ooooooooool0L_ooool001Gooooo00?o0000ooooooooool0=_ooool2o`0001Kooooo
00?o0000ooooooooool00oooool00ol0003oooooooooo`05ooooo`03ool00?oooooooooo00;ooooo
00?o0000ooooooooool0Y?ooool001Gooooo0_l0000gooooo`03o`000?oooooo000001Gooooo00?o
0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`;oo`001?ooool00ol0003ooooooooo
o`2Uooooo`005Oooool00ol0003oooooooooo`0eooooo`04o`000?ooooooooooo`0001Gooooo00?o
0000ooooooooool00oooool00ol0003oooooooooo`02ooooo`03ool00?oooooooooo00Cooooo00?o
0000ooooooooool0YOooool001Gooooo00?o0000ooooooooool0=Oooool01?l0003oooooooooool0
000Dooooo`03o`000?oooooooooo00Cooooo00Go0000ooooooooooooooooool00007ooooo`03o`00
0?oooooooooo0:Gooooo000Eooooo`03o`000?oooooooooo03Gooooo00Go0000oooooooooooooooo
o`00000Cooooo`03o`000?oooooooooo00Cooooo00Co0000oooooooo003oo`002?ooool00ol0003o
ooooooooo`2Uooooo`005Oooool2o`0003Kooooo00Go0000ooooooooooooooooo`00000Cooooo`03
o`000?oooooooooo00Cooooo00Go0000ool00?ooooooooooo`000007ooooo`03o`000?oooooooooo
0:Gooooo000Eooooo`03o`000?oooooooooo03Gooooo00Go0000ooooooooooooooooo`00000Coooo
o`03o`000?oooooooooo00?ooooo00?oo`00o`000?ooool00_ooool00ol0003oooooooooo`05oooo
o`03o`000?oooooooooo0:Gooooo000Eooooo`03o`000?oooooooooo03Gooooo00Go0000oooooooo
ooooooooo`00000Cooooo`03o`000?oooooooooo00;ooooo00?oo`00ooooool000000oooool00ol0
003oooooooooo`05ooooo`03o`000?oooooooooo0:Gooooo000Eooooo`03o`000?oooooooooo03Go
oooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00?o
oooo00Go0000ooooooooooooooooool00002ooooo`05o`000?ooooooooooooooool000001oooool0
0ol0003oooooooooo`2Uooooo`005Oooool2o`0003Kooooo00?o0000ooooooooool00_ooool00ol0
003oooooooooo`0:ooooo`03o`000?oooooooooo00?ooooo00Co0000oooooooo003oo`000oooool0
0ol0003oooooooooo`02o`0000Oooooo00?o0000ooooooooool0YOooool001Gooooo00?o0000oooo
ooooool0=Oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00[ooooo00?o0000oooo
ooooool00oooool00ol0003oo`00ooooo`04ooooo`06o`000?ooooooooooo`000?oooooo00001_oo
ool00ol0003oooooooooo`2Uooooo`0000Coooooo`000?l0003o00000oooool3o`0000Cooooo0_l0
0005ooooo`03o`000?oooooooooo03Gooooo00?o0000ooooooooool00_ooool00ol0003ooooooooo
o`0:ooooo`03o`000?oooooooooo00;ooooo00?oo`00o`000?ooool01Oooool01_l0003ooooooooo
ool0003oooooo`0000Kooooo00?o0000ooooooooool0YOooool000;ooooo00Go0000oooooooooooo
ooooo`000003ooooo`04o`000?ooooooooooo`0000;ooooo00?o0000ooooooooool00_ooool00ol0
003oooooooooo`0dooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool02Oooool00ol0
003oooooo`000002ooooo`03ool00?oooooo000000Kooooo00Ko0000oooooooooooo0000ooooool0
0005ooooo`03o`000?oooooooooo0:Kooooo0002ooooo`03o`000?oooooooooo00Gooooo00Co0000
oooooooooooo00000_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo03Cooooo00?o
0000ooooooooool01?ooool00ol0003oooooooooo`08ooooo`05o`000?oooooo0000oooooooo0000
0_ooool00ol0003oooooooooo`04ooooo`06o`000?ooooooooooo`000?oooooo00001Oooool00ol0
003oooooooooo`2Vooooo`000_ooool00ol0003oooooooooo`05ooooo`04o`000?ooooooooooo`00
00;ooooo00?o0000ooooooooool00_ooool3o`0003Cooooo00?o0000ooooooooool01?ooool00ol0
003oooooooooo`08ooooo`04o`000?oooooo0000ool000?ooooo00?o0000ooooooooool01?ooool0
0ol0003oooooo`000002ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0Y_ooool0
00;ooooo00Co0000oooooooooooooooo1?l00003ooooo`04o`000?ooooooooooo`0000Cooooo00?o
0000ooooooooool0=?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Sooooo00?o
0000ool00?l000000oooool00ol0003oooooooooo`06ooooo`;o00000_ooool00ol0003ooooooooo
o`03ooooo`03o`000?oooooooooo0:Kooooo00000ooooooo0000o`000003ooooo`03o`000?oooooo
oooo00Cooooo00Co0000oooooooooooo00001?ooool00ol0003oooooooooo`0dooooo`03o`000?oo
oooooooo00Cooooo00?o0000ooooooooool02?ooool00ol0003oooooo`000003ooooo`03o`000?oo
oooooooo00Kooooo0_l00002ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0Y_oo
ool000;ooooo00Co0000oooooooooooooooo1Ol00003ooooo`;o00001Oooool00ol0003ooooooooo
o`0dooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01_ooool01?l0003ooooooooo
ool00003ooooo`03o`000?oooooooooo00Kooooo0_l00002ooooo`03o`000?oooooooooo00?ooooo
00?o0000ooooooooool0Y_ooool001Gooooo0_l0000eooooo`03o`000?oooooooooo00Gooooo00?o
0000ooooooooool01?ooool2ool00005o`000?ooooooooooooooool000000_ooool00ol0003ooooo
ooooo`06ooooo`;o00000oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo0:Kooooo
000Eooooo`03o`000?oooooooooo03Cooooo00?o0000ooooooooool01Oooool00ol0003ooooooooo
o`03ooooo`04ool00?ooooooooooo`0000?ooooo00Co0000oooooooooooo00002?ooool00ol0003o
ooooooooo`02ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0Y_ooool001Gooooo
00?o0000ooooooooool0=?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00;ooooo
00Goo`00ooooooooooooooooo`000003ooooo`04o`000?ooooooooooo`0000Sooooo00?o0000oooo
ooooool00_ooool01Ol0003ooooooooooooooooo00000:Wooooo000Eooooo`03o`000?oooooooooo
03?ooooo00?o0000ooooooooool01_ooool01Ol0003oooooooooooooooooo`0000Cooooo00Go0000
ooooooooooooooooo`000002ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool00_oo
ool01Ol0003ooooooooooooooooo00000:Wooooo000Eooooo`03o`000?oooooooooo03?ooooo00?o
0000ooooooooool01oooool00ol0003oooooool00005ooooo`05o`000?ooooooooooooooool00000
0_ooool00ol0003oooooooooo`0;ooooo`05o`000?ooooooooooooooool00000ZOooool001Gooooo
0_l0000dooooo`03o`000?oooooooooo00Oooooo00?o0000ool00?ooool01?ooool00ol0003ooooo
ooooo`02ooooo`04o`000?ooooooooooo`0000gooooo00Go0000ooooooooooooooooo`00002Yoooo
o`005Oooool00ol0003oooooooooo`0cooooo`03o`000?oooooooooo00Kooooo00?oo`00o`000?oo
ool01Oooool00ol0003oooooooooo`02ooooo`04o`000?ooooooooooo`0000gooooo00Go0000oooo
ooooooooooooo`00002Yooooo`005Oooool00ol0003oooooooooo`0cooooo`03o`000?oooooooooo
00Gooooo00?oo`00ooooool000001_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooo0000
00gooooo00Go0000ooooooooooooooooo`00002Yooooo`005Oooool00ol0003oooooooooo`0Noooo
o`03o`000?oooooooooo01;ooooo00?o0000ooooooooool01?ooool01?oo003oooooooooool00006
ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooool000003_ooool01?l0003oooooooooool0
002Yooooo`005Oooool2o`0001oooooo00?o0000ooooooooool04_ooool00ol0003oooooooooo`03
ooooo`05ool00?ooooooooooooooool000001_ooool00ol0003oooooooooo`03ooooo`03o`000?oo
oooo000000kooooo00?o0000ooooool00000Z_ooool001Gooooo00?o0000ooooooooool07_ooool0
0ol0003oooooooooo`0Booooo`03o`000?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool0
0ol0003oooooooooo`04ooooo`03o`000?oooooooooo00?ooooo0_l0000?ooooo`03o`000?oooooo
00000:[ooooo000Eooooo`03o`000?oooooooooo01kooooo00?o0000ooooooooool04_ooool01Ol0
003oooooooooooooooooo`0000Gooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`03
ooooo`;o00003oooool00ol0003oooooo`00002Zooooo`005Oooool00ol0003oooooooooo`0Moooo
o`;o00005?ooool01?l0003ooooooooooooo0006ooooo`03o`000?oooooooooo00Cooooo00?o0000
ooooooooool00oooool2o`0000oooooo00?o0000ooooool00000Z_ooool001Gooooo00?o0000oooo
ooooool07Oooool2o`0001?ooooo00Co0000ooooooooooooo`002?ooool00ol0003oooooooooo`02
ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool03Oooool00ol0003oooooo`00002Z
ooooo`005Oooool2o`0001kooooo00?o0000ooooool000004_ooool00ol0003oooooool00009oooo
o`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`0=oooo
o`03o`000?oooooo00000:[ooooo000Eooooo`03o`000?oooooooooo01gooooo00?o0000ooooool0
00004_ooool00ol0003oo`00ooooo`09ooooo`03o`000?oooooooooo00;ooooo00?o0000oooooooo
ool01Oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooo00000:[ooooo0005o`0000?ooooo
0_l00004ooooo`;o00001Oooool00ol0003oooooooooo`0Mooooo`03o`000?oooooo000001;ooooo
00?o0000ooooooooool02Oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo01Kooooo
00?o0000ooooooooool0ZOooool00005ooooool0003oooooooooool000000_ooool01?l0003ooooo
ooooool00002ooooo`04o`000?ooooooooooo`0000Cooooo00?o0000ooooooooool07Oooool00ol0
003oooooo`00000Aooooo`03ool00?l0003ooooo00[ooooo00?o0000ooooooooool00_ooool00ol0
003oooooooooo`0Fooooo`03o`000?oooooooooo0:Wooooo0002ooooo`03o`000?oooooooooo00;o
oooo00Co0000oooooooooooo00000_ooool01?l0003oooooooooool00004ooooo`?o00007Oooool0
0ol0003oooooo`00000@ooooo`03ool00?oooooo000000_ooooo00?o0000ooooooooool00_ooool0
0ol0003oooooooooo`0Fooooo`03o`000?oooooooooo0:Wooooo0003ooooo`05o`000?oooooooooo
ooooool000000_ooool01?l0003oooooooooool00002ooooo`03o`000?oooooooooo00;ooooo00?o
0000ooooooooool05oooool00ol0003oooooooooo`02ooooo`04o`000?ooooooooooo`0000oooooo
00Coo`00oooooooooooo00002oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo01Ko
oooo00?o0000ooooooooool0ZOooool00005o`000?ooooooooooooooool000000_ooool01?l0003o
ooooooooool00002ooooo`04o`000?ooooooooooo`0000Cooooo00?o0000ooooooooool05oooool0
0ol0003oooooooooo`02ooooo`04o`000?ooooooooooo`0000kooooo00Coo`00oooooooooooo0000
3?ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo0<;ooooo00001Ol0003ooooooooo
oooooooo000000;ooooo00Co0000oooooooooooo00000_ooool01?l0003oooooooooool00004oooo
o`03o`000?oooooooooo01Oooooo00?o0000ooooooooool00_ooool01?l0003oooooooooool0000=
ooooo`05ool00?ooooooooooooooool000003?ooool00ol0003oooooooooo`02ooooo`03o`000?oo
oooooooo0<;ooooo00001?oooooo0000o`000?l00004ooooo`;o00001?ooool2o`0000Gooooo00?o
0000ooooooooool05oooool2o`0000?ooooo00Co0000oooooooooooo00003?ooool00ooo003ooooo
ooooo`02ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool00_ooool00ol0003ooooo
ooooo`32ooooo`005Oooool2o`0001Sooooo0_l00003ooooo`04o`000?ooooooooooo`0000Gooooo
00?o0000ooooooooool00oooool00ooo003oooooooooo`02ooooo`03o`000?oooooooooo00_ooooo
00?o0000ooooooooool00_ooool00ol0003oooooooooo`32ooooo`005Oooool00ol0003ooooooooo
o`0Gooooo`;o00000oooool01?l0003oooooooooool00005ooooo`03o`000?oooooooooo00;ooooo
00?oo`00ooooooooool00oooool00ol0003oooooooooo`0;ooooo`05o`000?ooooooooooooooool0
0000aOooool001Gooooo00?o0000ooooooooool05_ooool00ol0003oooooo`000002ooooo`03o`00
0?oooooooooo00;ooooo00?o0000ooooooooool00_ooool01Ol0003oooooooooooooooooo`0000Ko
oooo00?o0000ooooooooool02oooool01Ol0003ooooooooooooooooo00000<Gooooo000Eooooo`03
o`000?oooooooooo01Kooooo00?o0000ooooool000000_ooool00ol0003oooooooooo`02ooooo`04
o`000?ooooooooooooooo`;o00000_ooool00ooo003oooooooooo`04ooooo`03o`000?oooooooooo
00cooooo00Go0000ooooooooooooooooo`000035ooooo`005Oooool2o`0001Oooooo00Ko0000oooo
oooooooo0000ooooool00004ooooo`04o`000?ooooooooooooooo`;o00000_ooool00ooo003ooooo
ooooo`04ooooo`03o`000?oooooooooo00cooooo00Go0000ooooooooooooooooo`000035ooooo`00
5Oooool00ol0003oooooooooo`0Fooooo`06o`000?ooooooooooo`000?oooooo00001?ooool02?l0
003ooooooooooooooooo0000ooooool0003oo`001oooool00ol0003oooooooooo`0=ooooo`04o`00
0?ooooooooooo`000<Gooooo000Eooooo`03o`000?oooooooooo01Kooooo00Ko0000oooooooooooo
0000ooooool00004ooooo`07o`000?ooooooooooooooool0003oooooo`000008ooooo`03o`000?oo
oooooooo00gooooo00Co0000oooooooooooo0000aOooool001Gooooo00?o0000ooooooooool05_oo
ool01_l0003oooooooooool0003oooooo`0000Cooooo00Oo0000ooooooooooooooooo`000?oo003o
000000Sooooo00?o0000ooooooooool03Oooool01?l0003oooooooooool00035ooooo`005Oooool2
o`0001Oooooo00Ko0000oooooooooooo0000ooooool00004ooooo`07o`000?ooooooooooo`000?oo
ooooo`00o`000008ooooo`03o`000?oooooooooo00gooooo00Co0000oooooooooooo0000aOooool0
01Gooooo00?o0000ooooooooool05_ooool01Ol0003ooooooooooooooooo000000Gooooo00Oo0000
oooooooooooo0000ool00?oooooo000000Oooooo00?o0000ooooooooool03_ooool01?l0003ooooo
ooooool00035ooooo`005Oooool00ol0003oooooooooo`0Fooooo`05o`000?ooooooooooooooool0
00001Oooool01?l0003oooooooooool00002ooooo`03o`000?oooooooooo00Gooooo00?o0000oooo
ooooool03_ooool01?l0003oooooooooool00035ooooo`005Oooool00ol0003oooooooooo`0Foooo
o`05o`000?ooooooooooooooool000001Oooool01?l0003oooooool00?l00002ooooo`03o`000?oo
oooooooo00Gooooo00?o0000ooooooooool03_ooool01?l0003oooooooooool00035ooooo`005Ooo
ool00ol0003oooooooooo`0Eooooo`03o`000?oooooooooo00Sooooo00?o0000ool00?l000000ooo
ool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00kooooo00?o0000ooooool00000a_oo
ool001Gooooo0_l0000Fooooo`03o`000?oooooooooo00Wooooo0_l00003ooooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool03_ooool00ol0003oooooo`000036ooooo`005Oooool00ol0
003oooooooooo`0Eooooo`03o`000?oooooooooo00Sooooo00?oo`00o`000?l000001?ooool00ol0
003oooooooooo`04ooooo`03o`000?oooooooooo00kooooo00?o0000ooooool00000a_ooool000Go
00000_ooool3o`0000Cooooo0_l00005ooooo`03o`000?oooooooooo01Gooooo00?o0000oooooooo
ool01oooool01?oo003oooooo`000?l00004ooooo`03o`000?oooooooooo00Cooooo00?o0000oooo
ooooool03_ooool00ol0003oooooo`000036ooooo`0000Ooooooo`000?ooooooooooo`000?oooooo
000000?ooooo00Co0000oooooooooooo00000_ooool00ol0003oooooooooo`02ooooo`03o`000?oo
oooooooo01Gooooo00?o0000ooooooooool01_ooool00ooo003oooooooooo`02o`0000Cooooo00?o
0000ooooooooool01?ooool00ol0003oooooooooo`0>ooooo`03o`000?oooooo00000<Kooooo0002
ooooo`03o`000?oooooooooo00Gooooo00Co0000oooooooooooo00000_ooool00ol0003ooooooooo
o`02ooooo`?o00005Oooool00ol0003oooooooooo`06ooooo`04ool00?ooooooooooo`0000Gooooo
00?o0000ooooooooool00oooool00ol0003oooooooooo`0?ooooo`03o`000?oooooo00000<Kooooo
0003ooooo`03o`000?oooooooooo00Cooooo00Co0000oooooooooooo00000_ooool00ol0003ooooo
ooooo`02ooooo`03o`000?oooooooooo01Gooooo00?o0000ooooooooool01Oooool01Ooo003ooooo
oooooooooooo000000Gooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`0?ooooo`03
o`000?oooooo00000<Kooooo00001_l0003ooooooooooooooooo0000ooooo`Co00000oooool01?l0
003oooooooooool00004ooooo`03o`000?oooooooooo01Gooooo00?o0000ooooooooool01?ooool0
0ooo003oooooooooo`08ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool03oooool0
0ol0003oooooo`000036ooooo`0000Oo0000ooooooooooooooooo`000?oooooo000000Kooooo00Co
0000oooooooooooo00001?ooool00ol0003oooooooooo`0Eooooo`03o`000?oooooooooo00?ooooo
00?oo`00ooooooooool02Oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo013ooooo
0_l00036ooooo`0000Coooooo`000?l0003o00000_ooool5o`0000?ooooo0_l00005ooooo`03o`00
0?oooooooooo01Gooooo00?o0000ooooooooool00_ooool00ooo003oooooooooo`0:ooooo`03o`00
0?oooooooooo00?ooooo00?o0000ooooooooool04?ooool2o`000<Kooooo000Eooooo`;o00005Ooo
ool00ol0003oooooooooo`03ooooo`03ool00?oooooooooo00[ooooo00?o0000ooooooooool00ooo
ool00ol0003oooooooooo`0@ooooo`;o0000a_ooool001Gooooo00?o0000ooooooooool05?ooool0
0ol0003oooooooooo`02ooooo`03ool00?oooooooooo00cooooo00?o0000ooooooooool00_ooool0
0ol0003oooooooooo`0@ooooo`03o`000?oooooooooo0<Gooooo000Eooooo`03o`000?oooooooooo
01Cooooo00Go0000ooooooooooooooooool0000?ooooo`03o`000?oooooooooo00;ooooo00?o0000
ooooooooool04?ooool00ol0003oooooooooo`35ooooo`005Oooool00ol0003oooooooooo`0Doooo
o`04o`000?ooooooooooool0013ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`0@
ooooo`03o`000?oooooooooo0<Gooooo000Eooooo`;o00005Oooool01?l0003ooooooooooooo000@
ooooo`05o`000?ooooooooooooooool000004oooool00ol0003oooooooooo`35ooooo`005Oooool0
0ol0003oooooooooo`0Dooooo`03o`000?ooooooo`00017ooooo0_l00002ooooo`03o`000?oooooo
oooo017ooooo00?o0000ooooooooool0aOooool001Gooooo00?o0000ooooooooool05?ooool00ol0
003oo`00ooooo`0Cooooo`?o0000foooool001Gooooo00?o0000ooooooooool02Oooool00ol0003o
ooooooooo`08ooooo`03o`000?oooooooooo01Gooooo00?o0000ooooooooool0fOooool001Gooooo
00?o0000ooooooooool02Oooool00ol0003oooooooooo`07ooooo`03ool00?l0003ooooo0?;ooooo
000Eooooo`;o00002_ooool00ol0003oooooooooo`07ooooo`03ool00?l0003ooooo0?;ooooo000E
ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool01_ooool00ooo003o0000ooooo`3c
ooooo`005Oooool00ol0003oooooooooo`09ooooo`;o00001_ooool00ooo003oooooo`00003doooo
o`005Oooool00ol0003oooooooooo`08ooooo`03o`000?oooooo000000Kooooo00?oo`00ooooool0
0000m?ooool001Gooooo0_l00009ooooo`03o`000?oooooo000000Gooooo00Coo`00oooooooooooo
0000m?ooool001Gooooo00?o0000ooooooooool02?ooool00ol0003oooooo`000004ooooo`05ool0
0?ooooooooooooooool00000m?ooool00004ooooool0003o0000o`0000Cooooo0_l00004ooooo`;o
00001Oooool00ol0003oooooooooo`08ooooo`03o`000?oooooo000000Cooooo00Goo`00oooooooo
ooooooooo`00003dooooo`0000Go0000ooooooooooooooooo`000002ooooo`04o`000?oooooooooo
o`0000;ooooo00Co0000oooooooooooo00001?ooool00ol0003oooooooooo`08ooooo`03o`000?oo
oooo000000?ooooo00?oo`00ooooooooool00_ooool00ol0003oooooooooo`3booooo`001?ooool0
1?l0003oooooooooool00002ooooo`04o`000?ooooooooooo`0000;ooooo00?o0000ooooooooool0
0_ooool00ol0003oooooooooo`08ooooo`03o`000?oooooo000000;ooooo00?oo`00ooooooooool0
0oooool00ol0003oooooooooo`3booooo`000_ooool2o`0000?ooooo00Co0000oooooooooooo0000
0_ooool01?l0003oooooooooool00004ooooo`?o00002?ooool01_l0003oooooooooool0003ooooo
ool000Gooooo00?o0000ooooooooool0l_ooool000Cooooo00Co0000oooooooooooo00000_ooool0
1?l0003oooooooooool00002ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool02?oo
ool01Ol0003oooooooooool0003oo`0000Gooooo00?o0000ooooooooool0loooool00005o`000?oo
ooooooooooooool000000_ooool01?l0003oooooooooool00002ooooo`04o`000?ooooooooooo`00
00Cooooo00?o0000ooooooooool02?ooool01?l0003oooooooooool00006ooooo`03o`000?oooooo
oooo0??ooooo00001?oooooo0000o`000?l00004ooooo`;o00001?ooool2o`0000Gooooo00?o0000
ooooooooool01oooool01Ol0003ooooooooooooooooo000000Kooooo00?o0000ooooooooool0looo
ool001Gooooo0_l00008ooooo`05o`000?ooooooooooool00?l000001_ooool00ol0003ooooooooo
o`3cooooo`005Oooool00ol0003oooooooooo`07ooooo`05o`000?ooooooo`00ooooool000001_oo
ool00ol0003oooooooooo`3cooooo`005Oooool00ol0003oooooooooo`07ooooo`05o`000?oooooo
o`00ooooool000001_ooool00ol0003oooooooooo`3cooooo`005Oooool00ol0003oooooooooo`07
ooooo`03o`000?oo003ooooo00;ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`3c
ooooo`005Oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00;ooooo00?o0000oooo
ooooool00oooool00ol0003oooooooooo`3cooooo`005Oooool2o`0000Sooooo00?o0000oooooooo
ool00_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo0??ooooo000Eooooo`03o`00
0?oooooooooo00Kooooo00?oo`00o`000?ooool00oooool00ol0003oooooooooo`02ooooo`03o`00
0?oooooooooo0?Cooooo000Eooooo`03o`000?oooooooooo00Kooooo00?oo`00o`000?ooool00ooo
ool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo0?Cooooo000Eooooo`03o`000?oooooo
000000Gooooo00?oo`00o`000?ooool01Oooool01Ol0003ooooooooooooooooo00000?Kooooo000E
ooooo`;o000000?oooooo`000?ooool00_ooool00ooo003oooooo`000006ooooo`05o`000?oooooo
ooooooooool00000m_ooool001Gooooo00Go0000ooooooooooooooooo`000002ooooo`03ool00?oo
oooo000000Kooooo00Go0000ooooooooooooooooo`00003fooooo`005Oooool00ol0003ooooooooo
o`02ooooo`Go00001oooool01?l0003oooooooooool0003fooooo`005Oooool00ol0003ooooooooo
o`03ooooo`03ool00?oooooooooo00Sooooo00Co0000oooooooooooo0000m_ooool001Gooooo0_l0
0003ooooo`03ool00?oooooooooo00Wooooo00Co0000oooooooooooo0000m_ooool001Gooooo00?o
0000ooooooooool00_ooool00ooo003oooooooooo`0:ooooo`03o`000?oooooo00000?Kooooo0000
1?oooooo0000o`000?l00003ooooo`?o00001?ooool2o`0000Gooooo00Go0000oooooooooooooooo
ool0000=ooooo`;o0000moooool00007o`000?ooooooooooooooool0003oooooo`000003ooooo`04
o`000?ooooooooooo`0000;ooooo00?o0000ooooooooool00_ooool01Ol0003ooooooooooooooooo
o`0000gooooo0_l0003gooooo`001?ooool00ol0003oooooooooo`03ooooo`04o`000?oooooooooo
o`0000;ooooo00?o0000ooooooooool00_ooool01?l0003ooooooooooooo000?ooooo`03o`000?oo
oooooooo0?Gooooo0002ooooo`;o00001_ooool01?l0003oooooooooool00002ooooo`03o`000?oo
oooooooo00;ooooo0_l000000ooo003oooooooooo`0>ooooo`03o`000?oooooooooo0?Gooooo0004
ooooo`03o`000?oooooo000000?o00000oooool01?l0003oooooooooool00004ooooo`03o`000?oo
ooooo`000?oooooo2Oooool00007o`000?ooooooooooooooool0003oooooo`000006ooooo`04o`00
0?ooooooooooo`0000Cooooo00?o0000ool00?ooool0ooooool9ooooo`0000Coooooo`000?l0003o
00000_ooool5o`0000?ooooo0_l00005ooooo`03o`000?oo003ooooo0?oooooo2Oooool001Gooooo
00?oo`00o`000?ooool0ooooool9ooooo`005Oooool00ol0003oooooooooo`3oooooo`Wooooo000E
ooooo`03o`000?oooooooooo0?oooooo2Oooool001Gooooo00?o0000ooooooooool0ooooool9oooo
o`005Oooool00ol0003oooooooooo`3oooooo`Wooooo0000\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.247788, -28.3138, \
0.0115777, 2.24798}}]
}, Open  ]],

Cell[TextData[{
  "The variance of this distribution is 1.  However, what we are interesed in \
is the variance of the ",
  StyleBox["mean",
    FontSlant->"Italic"],
  " pairwise divergence across replicates - each mean being an average of 45 \
pairwise comparisons in each replicate.  This variance is much smaller:"
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(Variance[pdList]\)], "Input"],

Cell[BoxData[
    \(0.2838563710061785`\)], "Output",
  CellLabel->"Out[108]="]
}, Open  ]],

Cell[TextData[{
  "It is ",
  StyleBox["not",
    FontSlant->"Italic"],
  " easy to calculate the variance of the mean pairwise divergence across \
replicates, because each estimate is the average of ",
  Cell[BoxData[
      \(TraditionalForm\`\(10*9\)\/2 = 45\)]],
  "pairwise comparisons amongst ",
  Cell[BoxData[
      \(TraditionalForm\`k = 10\)]],
  "genes - and the comparisons are not independent of eachother.  However, it \
is the case that even extremely large samples ",
  Cell[BoxData[
      \(TraditionalForm\`\((k >> 10)\)\)]],
  "will still give uncertain estimates, because of the variance due to the \
deepest split."
}], "Text"],

Cell[TextData[{
  "This will generate ",
  Cell[BoxData[
      \(TraditionalForm\`nreps\)]],
  " replicates of genealogies with ",
  Cell[BoxData[
      \(TraditionalForm\`k\)]],
  " genes."
}], "Text"],

Cell[BoxData[
    \(\(sm[k_, nreps_] := 
        Table[RandomGenealogy[Array[xx, k]], {nreps}];\)\)], "Input",
  CellLabel->"In[109]:="],

Cell["\<\
This shows the mean and variance of pairwise divergence as the size \
of the genealogy increases:\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(Table[
        pl = MeanPairwiseDivergence /@ sm[k, 200]; {k, Mean[pl], 
          Variance[pl]}, {k, 5, 30, 5}] // TableForm\)], "Input",
  CellLabel->"In[114]:="],

Cell[BoxData[
    TagBox[GridBox[{
          {"5", "1.0198854597033384`", "0.4417127324445498`"},
          {"10", "0.9741966363729371`", "0.27609710780902424`"},
          {"15", "1.0396247312209093`", "0.2964943157361788`"},
          {"20", "0.9771925797850071`", "0.2652564333516284`"},
          {"25", "1.0222401274080415`", "0.26881846570988904`"},
          {"30", "0.9515016183581879`", "0.17879216250570457`"}
          },
        RowSpacings->1,
        ColumnSpacings->3,
        RowAlignments->Baseline,
        ColumnAlignments->{Left}],
      Function[ BoxForm`e$, 
        TableForm[ BoxForm`e$]]]], "Output",
  CellLabel->"Out[112]//TableForm="]
}, Open  ]],

Cell[TextData[{
  "Note:",
  StyleBox[" This is slow because large genealogies are being generated",
    FontWeight->"Plain"]
}], "Text",
  FontWeight->"Bold"],

Cell["\<\
Even for samples of many genes, the variance of mean pairwise \
divergence is high; it tends to a definite li it, rather than zero, \
\>", \
"Text"]
}, Closed]]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Sampling from a growing population",
  FontColor->RGBColor[0, 0, 1]]], "SubsectionIcon"],

Cell[CellGroupData[{

Cell[TextData[{
  StyleBox["Q3:",
    FontColor->RGBColor[0, 0, 1]],
  " Could you use the distribution of pairwise divergence times to detect a \
history of past population growth?  What sort of sample size would you need?"
}], "SubsubsectionIcon"],

Cell[TextData[{
  "We expect that the distribution of pairwise divergence times should be \
exponential, with mean and variance equal to 1 (in scaled time).  So, we \
might expect the ratio ",
  Cell[BoxData[
      \(TraditionalForm\`variance\/mean\^2\)]],
  "to equal 1 for steady population growth, and should be smaller if the \
population has been growing."
}], "Text"],

Cell["\<\
This is the distribution of the statistic with 200 replicates under \
the null hypothesis, of steady population size:\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(vmr = \(\((pl = PairwiseDivergence[#]; 
              Variance[pl]\/Mean[pl]\^2)\) &\) /@ sample // Sort\)], "Input",
  CellLabel->"(Dialog) In[115]:="],

Cell[BoxData[
    \({0.10186547914504226`, 0.11624970123216725`, 0.12928697695553223`, 
      0.14141309927950368`, 0.15050140947627438`, 0.15239981973008443`, 
      0.1531723978717828`, 0.15842596445819723`, 0.16305398730430187`, 
      0.1640269350172329`, 0.1668053172777889`, 0.17291680360956896`, 
      0.18071757135773375`, 0.18210338903632087`, 0.18731930629048907`, 
      0.1877329379302938`, 0.18789568307463655`, 0.18824728060141221`, 
      0.19418578365383637`, 0.1944067973500589`, 0.1951054249168828`, 
      0.19850465015926652`, 0.19963157109267807`, 0.2024108001720267`, 
      0.20308193028050375`, 0.20842448359133192`, 0.20965457674759735`, 
      0.21099232161538822`, 0.21116044579290016`, 0.21557475226380135`, 
      0.21755745907397314`, 0.22136152657472793`, 0.22143360641095353`, 
      0.22359907623951877`, 0.22604419474886397`, 0.23286463870722243`, 
      0.241349028950918`, 0.24158390793382023`, 0.24336132058713297`, 
      0.25257588120654384`, 0.25511451582499195`, 0.2564036490959706`, 
      0.26143817775199407`, 0.2732566937030942`, 0.274223217000108`, 
      0.2768230213764236`, 0.27755895645901774`, 0.2787504172877953`, 
      0.28087259625968547`, 0.28204397574697565`, 0.28268020881095113`, 
      0.28452270192346024`, 0.28694974912516624`, 0.28770565462901054`, 
      0.2878028577643963`, 0.29178474472928334`, 0.292730803558056`, 
      0.2964151420511489`, 0.2973418974405538`, 0.2994596682319425`, 
      0.301291398826091`, 0.30234638346223003`, 0.30652018458788205`, 
      0.3109346319644368`, 0.3120679639458607`, 0.3140291728412211`, 
      0.31656602375604814`, 0.3195389142970649`, 0.32123826483482915`, 
      0.32253331276170955`, 0.3237528708530885`, 0.3245552689250342`, 
      0.3268913418179815`, 0.3269212430045078`, 0.3272511549986225`, 
      0.3375526873844385`, 0.3376229742485573`, 0.3480154186110746`, 
      0.3488731173432652`, 0.35002565527991325`, 0.35513914207630853`, 
      0.3654274877015742`, 0.3667235596600992`, 0.36792372326248896`, 
      0.37267968676506796`, 0.374320268169583`, 0.37535764589603227`, 
      0.3771930772868933`, 0.3870305413171952`, 0.3937668669932856`, 
      0.39694205423992585`, 0.3994940824562278`, 0.404790923028891`, 
      0.40996756115937266`, 0.4140681949095069`, 0.420688179803711`, 
      0.4215006666403634`, 0.42372807181532013`, 0.4284290546411592`, 
      0.43463160240329257`, 0.44511937608339835`, 0.4475662197495963`, 
      0.45184272171322515`, 0.4530383237345038`, 0.455645732778639`, 
      0.456148508816627`, 0.46074998584397014`, 0.46362741440293476`, 
      0.4667420375737751`, 0.46971927172185446`, 0.4698109323727878`, 
      0.4724857603866245`, 0.4752001176400121`, 0.47841220841002624`, 
      0.4833171211197121`, 0.4870311495413665`, 0.49026536873996057`, 
      0.49315289999503004`, 0.498029775904745`, 0.49805030407663925`, 
      0.4991096058192573`, 0.503853782742355`, 0.5049337181077016`, 
      0.5065616822391718`, 0.5193232733735744`, 0.5242641482396675`, 
      0.5256609036137928`, 0.5313038167084128`, 0.5338934551101912`, 
      0.5340053145257309`, 0.5349974549239603`, 0.5413412061044983`, 
      0.5464263176852489`, 0.55312098374637`, 0.5549210937044416`, 
      0.5569650583244232`, 0.5617017207453342`, 0.5628958822065961`, 
      0.5643614069187693`, 0.5654813687300302`, 0.5707790448405202`, 
      0.5803930664498101`, 0.5810772990678724`, 0.5862562625793509`, 
      0.6054753651512429`, 0.6079951157694956`, 0.6092061938878894`, 
      0.6095544206610853`, 0.6109217119742401`, 0.6180247513443873`, 
      0.6225327978689859`, 0.6238620265565954`, 0.6256319197906912`, 
      0.6407805465792369`, 0.6495959323659419`, 0.6608980423501467`, 
      0.6983502713320717`, 0.7378841280026259`, 0.7440212125573294`, 
      0.7480549232174067`, 0.7505722377071963`, 0.761850794549066`, 
      0.7636512151786506`, 0.764679929202038`, 0.7670666530188391`, 
      0.7696659741380658`, 0.7794887376139484`, 0.7840206243332963`, 
      0.7928135726243792`, 0.7935361577176329`, 0.8062968042863745`, 
      0.8076969402752616`, 0.8117560397073277`, 0.8232355452722904`, 
      0.8271307039779899`, 0.8353414753264871`, 0.8425751170437864`, 
      0.8583464877619817`, 0.8585601124872767`, 0.8710126574589856`, 
      0.8760875536132191`, 0.8930627978871153`, 0.8975620400291751`, 
      0.9620258479970752`, 0.9686454871310356`, 1.049857772347212`, 
      1.0539002793995804`, 1.0617174117099413`, 1.0963510299849821`, 
      1.1236911929275863`, 1.1653926953133162`, 1.2628857795569337`, 
      1.2703997124026847`, 1.3482842087840299`, 1.4094898016747741`, 
      1.4171789337360792`, 1.7195102580535664`, 1.8292415325186244`, 
      1.9358724463383004`, 3.0346847482956516`}\)], "Output",
  CellLabel->"(Dialog) Out[113]="]
}, Open  ]],

Cell[TextData[{
  "The average of the test statistic is much less than 1.  This is because \
even though the expected value of the mean and the variance are 1, the \
expectation of the ",
  StyleBox["ratio",
    FontSlant->"Italic"],
  " ",
  Cell[BoxData[
      \(TraditionalForm\`variance\/mean\^2\)]],
  "is NOT the ratio of the expectations."
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \({Mean[vmr], Variance[vmr], StandardErrorOfSampleMean[vmr]}\)], "Input",
  CellLabel->"(Dialog) In[113]:="],

Cell[BoxData[
    \({0.5147935951318108`, 0.13213595993612973`, 
      0.025703692335550716`}\)], "Output",
  CellLabel->"(Dialog) Out[113]="]
}, Open  ]],

Cell["\<\
We can still use the statistic to try and distinguish between \
hypotheses.  Out of 200 replicates, only 5% (i.e., 10) give statistics \
smaller than 0.1668, so this would be our threshold for significance.\
\>", \
"Text"],

Cell[TextData[{
  "This gives the distribution of mean pairwise divergence for 200 replicates \
of a population growing at ",
  Cell[BoxData[
      \(TraditionalForm\`\(\[Lambda]\^*\) = \(2 \( N\_e\) \[Lambda] = 
          5\)\)]],
  ":"
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(vmrGrowing = \(\((pl = PairwiseDivergence[#]; 
              Variance[pl]\/Mean[pl]\^2)\) &\) /@ growingSample // 
        Sort\)], "Input",
  CellLabel->"In[126]:="],

Cell[BoxData[
    \({0.06341699478898058`, 0.06358784880561665`, 0.0762296482336504`, 
      0.07935288156750855`, 0.08023422262668038`, 0.0850573298140178`, 
      0.08602377667200313`, 0.08602799762443297`, 0.09156608746410891`, 
      0.09367023632432556`, 0.09397456088365175`, 0.09524269171809216`, 
      0.09540237829185118`, 0.09563153909103073`, 0.09631833669407715`, 
      0.0981052552978253`, 0.0982404767976311`, 0.10025880073720071`, 
      0.10321799651582718`, 0.10390774435028913`, 0.1053584232737792`, 
      0.10843779563149511`, 0.10882179115010542`, 0.11135408591369789`, 
      0.11369562036164375`, 0.11477781452699505`, 0.11593112412347853`, 
      0.11747457859118174`, 0.12100808329952735`, 0.12198527095344953`, 
      0.12216654550789223`, 0.12243033482633624`, 0.12263178199905239`, 
      0.12267619055808489`, 0.12307124399223451`, 0.12469454883406661`, 
      0.12503121086784125`, 0.1254483925050433`, 0.12681455528698976`, 
      0.13035817221435286`, 0.13057052190275048`, 0.13128765616299232`, 
      0.13155833551841567`, 0.13223893114601293`, 0.13408757606159916`, 
      0.13519961214112822`, 0.13559706884920836`, 0.13620961740973983`, 
      0.13682319858114791`, 0.13745698903847794`, 0.1384321788097419`, 
      0.1417026798632915`, 0.14188938796933462`, 0.14240636906971235`, 
      0.14762771475659137`, 0.14832754316591368`, 0.15090260021070706`, 
      0.15229714513023487`, 0.15304042636017867`, 0.1559376023405679`, 
      0.15608249762157717`, 0.15725309050609498`, 0.15729919745800508`, 
      0.15789406487410243`, 0.15857115957033424`, 0.15998130114796935`, 
      0.16060236617814044`, 0.16227651064899137`, 0.16244693018207013`, 
      0.1627001981823929`, 0.16289009791991282`, 0.1674379145603277`, 
      0.16979340021056033`, 0.17069385077105476`, 0.17261114083118953`, 
      0.17415691187866136`, 0.17453338320847117`, 0.174607264443515`, 
      0.17504958472585955`, 0.1752233166313331`, 0.1755631108978482`, 
      0.17754699380390412`, 0.1793695744072299`, 0.18076253918966625`, 
      0.18090903714633247`, 0.18391801532123792`, 0.18441803894118217`, 
      0.187758771279074`, 0.18810400366403152`, 0.19000302420877602`, 
      0.19152753973781547`, 0.19168453524807544`, 0.19207979052711477`, 
      0.19332326640067188`, 0.19345000211503047`, 0.19462384941048202`, 
      0.19467802891893315`, 0.19543554937907776`, 0.1957822304614175`, 
      0.19591542240966242`, 0.19686620343156042`, 0.2019954700114105`, 
      0.20208051757648046`, 0.20236903032393763`, 0.20284766189814024`, 
      0.20322131752843461`, 0.20712974989201208`, 0.20729725008895059`, 
      0.20915331158253897`, 0.21017414502317236`, 0.2118268824863607`, 
      0.21273323393305915`, 0.21420162659132067`, 0.21470380498989952`, 
      0.2168913387455847`, 0.21699100833191942`, 0.21919520390940458`, 
      0.22704030421551988`, 0.2271699429317118`, 0.22717901199828133`, 
      0.2272858748084508`, 0.23013130089523207`, 0.23246934545188527`, 
      0.23389930658861094`, 0.23506460362839388`, 0.23552648541296617`, 
      0.2378856752949361`, 0.24403136995662267`, 0.24457173271178936`, 
      0.24631430343431868`, 0.2481745542360272`, 0.25046079725960246`, 
      0.2505552863827191`, 0.25468461586577823`, 0.25557884433608913`, 
      0.25562515959864895`, 0.2568308580237905`, 0.2578275520471323`, 
      0.25803396325981054`, 0.25867521166699603`, 0.25921372029656703`, 
      0.26206725096835337`, 0.2630646708563216`, 0.26645112244355773`, 
      0.2695715917726944`, 0.2711231588302945`, 0.27244935229275336`, 
      0.27335926145884415`, 0.27809596338455955`, 0.2792721989152002`, 
      0.2804875216437494`, 0.281393745174625`, 0.28206119477099906`, 
      0.2837245967255593`, 0.2879325818410677`, 0.2887513293232866`, 
      0.2928308860205844`, 0.29750323005147206`, 0.30066088867959845`, 
      0.30152927916060485`, 0.30273660436306155`, 0.3057392213427028`, 
      0.30609683843191415`, 0.30773755572886086`, 0.30905681082066383`, 
      0.31005450728698564`, 0.3129486358980734`, 0.3138693191892218`, 
      0.3159926708623074`, 0.32382850125270773`, 0.3287614945047072`, 
      0.331911680763203`, 0.3331361552262577`, 0.33385629669057565`, 
      0.34268949425416234`, 0.35257410991544824`, 0.3572094765504558`, 
      0.3591170037817735`, 0.3615124292282901`, 0.36687828796812294`, 
      0.3711771510217751`, 0.37283717776848496`, 0.3803809884820333`, 
      0.38607686976246863`, 0.3879924518030955`, 0.38854276841583996`, 
      0.39099995051214576`, 0.40568162696424315`, 0.4064034723634364`, 
      0.41215340839054687`, 0.43770637263539663`, 0.45792314578670473`, 
      0.4697348073136889`, 0.4919609976881411`, 0.516923310200939`, 
      0.5536127960558087`, 0.5642243968574749`, 0.7324255498009651`, 
      0.7965367085402671`, 0.8010809399305266`}\)], "Output",
  CellLabel->"Out[126]="]
}, Open  ]],

Cell["\<\
The average of the test statistic is much smaller than for a steady \
population.  However, it is still higher than the threshold for significance \
(0.1668), and significance would be detected only 71/200=35.5% of the time.  \
That becomes obvious if one looks at examples of individual pairwise \
divergence plots.\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \({Mean[vmrGrowing], Variance[vmrGrowing], 
      StandardErrorOfSampleMean[vmrGrowing]}\)], "Input",
  CellLabel->"In[127]:="],

Cell[BoxData[
    \({0.22549252206767803`, 0.01442489150098403`, 
      0.008492611936555218`}\)], "Output",
  CellLabel->"Out[127]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(DisplayTogetherArray[{\[IndentingNewLine]PairwiseDivergencePlot[
            sample[\([1]\)], {5, 0.1}, 
            PlotJoined \[Rule] 
              True], \[IndentingNewLine]PairwiseDivergencePlot[
            growingSample[\([1]\)], {5, 0.1}, 
            PlotJoined \[Rule] True]}];\)\)], "Input",
  CellLabel->"In[141]:="],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .2943 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.47619 0.00700719 0.47619 [
[ 0 0 0 0 ]
[ 1 .2943 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .2943 L
0 .2943 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.00700719 0.477324 0.287295 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.1924 0.0147151 0.0367877 [
[.21621 .00222 -3 -9 ]
[.21621 .00222 3 0 ]
[.40861 .00222 -3 -9 ]
[.40861 .00222 3 0 ]
[.60101 .00222 -3 -9 ]
[.60101 .00222 3 0 ]
[.79341 .00222 -3 -9 ]
[.79341 .00222 3 0 ]
[.98581 .00222 -3 -9 ]
[.98581 .00222 3 0 ]
[.01131 .10668 -18 -4.5 ]
[.01131 .10668 0 4.5 ]
[.01131 .19865 -6 -4.5 ]
[.01131 .19865 0 4.5 ]
[.01131 .29062 -18 -4.5 ]
[.01131 .29062 0 4.5 ]
[.01131 .38259 -12 -4.5 ]
[.01131 .38259 0 4.5 ]
[.01131 .47456 -24 -4.5 ]
[.01131 .47456 0 4.5 ]
[.01131 .56653 -12 -4.5 ]
[.01131 .56653 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.21621 .01472 m
.21621 .02097 L
s
[(1)] .21621 .00222 0 1 Mshowa
.40861 .01472 m
.40861 .02097 L
s
[(2)] .40861 .00222 0 1 Mshowa
.60101 .01472 m
.60101 .02097 L
s
[(3)] .60101 .00222 0 1 Mshowa
.79341 .01472 m
.79341 .02097 L
s
[(4)] .79341 .00222 0 1 Mshowa
.98581 .01472 m
.98581 .02097 L
s
[(5)] .98581 .00222 0 1 Mshowa
.125 Mabswid
.06229 .01472 m
.06229 .01847 L
s
.10077 .01472 m
.10077 .01847 L
s
.13925 .01472 m
.13925 .01847 L
s
.17773 .01472 m
.17773 .01847 L
s
.25469 .01472 m
.25469 .01847 L
s
.29317 .01472 m
.29317 .01847 L
s
.33165 .01472 m
.33165 .01847 L
s
.37013 .01472 m
.37013 .01847 L
s
.44709 .01472 m
.44709 .01847 L
s
.48557 .01472 m
.48557 .01847 L
s
.52405 .01472 m
.52405 .01847 L
s
.56253 .01472 m
.56253 .01847 L
s
.63949 .01472 m
.63949 .01847 L
s
.67797 .01472 m
.67797 .01847 L
s
.71645 .01472 m
.71645 .01847 L
s
.75493 .01472 m
.75493 .01847 L
s
.83189 .01472 m
.83189 .01847 L
s
.87037 .01472 m
.87037 .01847 L
s
.90885 .01472 m
.90885 .01847 L
s
.94733 .01472 m
.94733 .01847 L
s
.25 Mabswid
0 .01472 m
1 .01472 L
s
.02381 .10668 m
.03006 .10668 L
s
[(2.5)] .01131 .10668 1 0 Mshowa
.02381 .19865 m
.03006 .19865 L
s
[(5)] .01131 .19865 1 0 Mshowa
.02381 .29062 m
.03006 .29062 L
s
[(7.5)] .01131 .29062 1 0 Mshowa
.02381 .38259 m
.03006 .38259 L
s
[(10)] .01131 .38259 1 0 Mshowa
.02381 .47456 m
.03006 .47456 L
s
[(12.5)] .01131 .47456 1 0 Mshowa
.02381 .56653 m
.03006 .56653 L
s
[(15)] .01131 .56653 1 0 Mshowa
.125 Mabswid
.02381 .03311 m
.02756 .03311 L
s
.02381 .0515 m
.02756 .0515 L
s
.02381 .0699 m
.02756 .0699 L
s
.02381 .08829 m
.02756 .08829 L
s
.02381 .12508 m
.02756 .12508 L
s
.02381 .14347 m
.02756 .14347 L
s
.02381 .16187 m
.02756 .16187 L
s
.02381 .18026 m
.02756 .18026 L
s
.02381 .21705 m
.02756 .21705 L
s
.02381 .23544 m
.02756 .23544 L
s
.02381 .25384 m
.02756 .25384 L
s
.02381 .27223 m
.02756 .27223 L
s
.02381 .30902 m
.02756 .30902 L
s
.02381 .32741 m
.02756 .32741 L
s
.02381 .3458 m
.02756 .3458 L
s
.02381 .3642 m
.02756 .3642 L
s
.02381 .40099 m
.02756 .40099 L
s
.02381 .41938 m
.02756 .41938 L
s
.02381 .43777 m
.02756 .43777 L
s
.02381 .45617 m
.02756 .45617 L
s
.02381 .49296 m
.02756 .49296 L
s
.02381 .51135 m
.02756 .51135 L
s
.02381 .52974 m
.02756 .52974 L
s
.02381 .54814 m
.02756 .54814 L
s
.02381 .58493 m
.02756 .58493 L
s
.02381 .60332 m
.02756 .60332 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.03343 .16187 m
.05267 .12508 L
.07191 .12508 L
.09115 .16187 L
.11039 .56653 L
.12963 .01472 L
.14887 .01472 L
.16811 .01472 L
.18735 .01472 L
.20659 .01472 L
.22583 .01472 L
.24507 .01472 L
.26431 .01472 L
.28355 .01472 L
.30279 .01472 L
.32203 .01472 L
.34127 .01472 L
.36051 .01472 L
.37975 .01472 L
.39899 .01472 L
.41823 .01472 L
.43747 .01472 L
.45671 .01472 L
.47595 .01472 L
.49519 .01472 L
.51443 .01472 L
.53367 .01472 L
.55291 .01472 L
.57215 .01472 L
.59139 .01472 L
.61063 .01472 L
.62987 .01472 L
.64911 .01472 L
.66835 .01472 L
.68759 .01472 L
.70683 .01472 L
.72607 .60332 L
.74531 .01472 L
.76455 .01472 L
.78379 .01472 L
.80303 .01472 L
.82227 .01472 L
.84151 .01472 L
.86075 .01472 L
.87999 .01472 L
.89923 .01472 L
.91847 .01472 L
.93771 .01472 L
.95695 .01472 L
.97619 .01472 L
Mistroke
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.522676 0.00700719 0.97619 0.287295 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.1924 0.0147151 0.0309791 [
[.21621 .00222 -3 -9 ]
[.21621 .00222 3 0 ]
[.40861 .00222 -3 -9 ]
[.40861 .00222 3 0 ]
[.60101 .00222 -3 -9 ]
[.60101 .00222 3 0 ]
[.79341 .00222 -3 -9 ]
[.79341 .00222 3 0 ]
[.98581 .00222 -3 -9 ]
[.98581 .00222 3 0 ]
[.01131 .09216 -18 -4.5 ]
[.01131 .09216 0 4.5 ]
[.01131 .16961 -6 -4.5 ]
[.01131 .16961 0 4.5 ]
[.01131 .24706 -18 -4.5 ]
[.01131 .24706 0 4.5 ]
[.01131 .32451 -12 -4.5 ]
[.01131 .32451 0 4.5 ]
[.01131 .40195 -24 -4.5 ]
[.01131 .40195 0 4.5 ]
[.01131 .4794 -12 -4.5 ]
[.01131 .4794 0 4.5 ]
[.01131 .55685 -24 -4.5 ]
[.01131 .55685 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.21621 .01472 m
.21621 .02097 L
s
[(1)] .21621 .00222 0 1 Mshowa
.40861 .01472 m
.40861 .02097 L
s
[(2)] .40861 .00222 0 1 Mshowa
.60101 .01472 m
.60101 .02097 L
s
[(3)] .60101 .00222 0 1 Mshowa
.79341 .01472 m
.79341 .02097 L
s
[(4)] .79341 .00222 0 1 Mshowa
.98581 .01472 m
.98581 .02097 L
s
[(5)] .98581 .00222 0 1 Mshowa
.125 Mabswid
.06229 .01472 m
.06229 .01847 L
s
.10077 .01472 m
.10077 .01847 L
s
.13925 .01472 m
.13925 .01847 L
s
.17773 .01472 m
.17773 .01847 L
s
.25469 .01472 m
.25469 .01847 L
s
.29317 .01472 m
.29317 .01847 L
s
.33165 .01472 m
.33165 .01847 L
s
.37013 .01472 m
.37013 .01847 L
s
.44709 .01472 m
.44709 .01847 L
s
.48557 .01472 m
.48557 .01847 L
s
.52405 .01472 m
.52405 .01847 L
s
.56253 .01472 m
.56253 .01847 L
s
.63949 .01472 m
.63949 .01847 L
s
.67797 .01472 m
.67797 .01847 L
s
.71645 .01472 m
.71645 .01847 L
s
.75493 .01472 m
.75493 .01847 L
s
.83189 .01472 m
.83189 .01847 L
s
.87037 .01472 m
.87037 .01847 L
s
.90885 .01472 m
.90885 .01847 L
s
.94733 .01472 m
.94733 .01847 L
s
.25 Mabswid
0 .01472 m
1 .01472 L
s
.02381 .09216 m
.03006 .09216 L
s
[(2.5)] .01131 .09216 1 0 Mshowa
.02381 .16961 m
.03006 .16961 L
s
[(5)] .01131 .16961 1 0 Mshowa
.02381 .24706 m
.03006 .24706 L
s
[(7.5)] .01131 .24706 1 0 Mshowa
.02381 .32451 m
.03006 .32451 L
s
[(10)] .01131 .32451 1 0 Mshowa
.02381 .40195 m
.03006 .40195 L
s
[(12.5)] .01131 .40195 1 0 Mshowa
.02381 .4794 m
.03006 .4794 L
s
[(15)] .01131 .4794 1 0 Mshowa
.02381 .55685 m
.03006 .55685 L
s
[(17.5)] .01131 .55685 1 0 Mshowa
.125 Mabswid
.02381 .0302 m
.02756 .0302 L
s
.02381 .04569 m
.02756 .04569 L
s
.02381 .06118 m
.02756 .06118 L
s
.02381 .07667 m
.02756 .07667 L
s
.02381 .10765 m
.02756 .10765 L
s
.02381 .12314 m
.02756 .12314 L
s
.02381 .13863 m
.02756 .13863 L
s
.02381 .15412 m
.02756 .15412 L
s
.02381 .1851 m
.02756 .1851 L
s
.02381 .20059 m
.02756 .20059 L
s
.02381 .21608 m
.02756 .21608 L
s
.02381 .23157 m
.02756 .23157 L
s
.02381 .26255 m
.02756 .26255 L
s
.02381 .27804 m
.02756 .27804 L
s
.02381 .29353 m
.02756 .29353 L
s
.02381 .30902 m
.02756 .30902 L
s
.02381 .34 m
.02756 .34 L
s
.02381 .35549 m
.02756 .35549 L
s
.02381 .37098 m
.02756 .37098 L
s
.02381 .38646 m
.02756 .38646 L
s
.02381 .41744 m
.02756 .41744 L
s
.02381 .43293 m
.02756 .43293 L
s
.02381 .44842 m
.02756 .44842 L
s
.02381 .46391 m
.02756 .46391 L
s
.02381 .49489 m
.02756 .49489 L
s
.02381 .51038 m
.02756 .51038 L
s
.02381 .52587 m
.02756 .52587 L
s
.02381 .54136 m
.02756 .54136 L
s
.02381 .57234 m
.02756 .57234 L
s
.02381 .58783 m
.02756 .58783 L
s
.02381 .60332 m
.02756 .60332 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.03343 .23157 m
.05267 .10765 L
.07191 .60332 L
.09115 .01472 L
.11039 .01472 L
.12963 .51038 L
.14887 .01472 L
.16811 .01472 L
.18735 .01472 L
.20659 .01472 L
.22583 .01472 L
.24507 .01472 L
.26431 .01472 L
.28355 .01472 L
.30279 .01472 L
.32203 .01472 L
.34127 .01472 L
.36051 .01472 L
.37975 .01472 L
.39899 .01472 L
.41823 .01472 L
.43747 .01472 L
.45671 .01472 L
.47595 .01472 L
.49519 .01472 L
.51443 .01472 L
.53367 .01472 L
.55291 .01472 L
.57215 .01472 L
.59139 .01472 L
.61063 .01472 L
.62987 .01472 L
.64911 .01472 L
.66835 .01472 L
.68759 .01472 L
.70683 .01472 L
.72607 .01472 L
.74531 .01472 L
.76455 .01472 L
.78379 .01472 L
.80303 .01472 L
.82227 .01472 L
.84151 .01472 L
.86075 .01472 L
.87999 .01472 L
.89923 .01472 L
.91847 .01472 L
.93771 .01472 L
.95695 .01472 L
.97619 .01472 L
Mistroke
Mfstroke
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[141]:=",
  ImageSize->{556, 163.562},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40008/0000Xb000`400?l00000o`00003ooooooooo
ooooobkooooo003ooooooooooooo;_ooool00?ooooooooooool^ooooo`00ooooooooooooobkooooo
003ooooooooooooo;_ooool00?ooooooooooool^ooooo`00ooooooooooooobkooooo001Cooooo`?o
0000:?ooool5o`0002Sooooo0ol0000Zooooo`?o0000:?ooool3o`00063ooooo0ol0000Yooooo`Go
0000:?ooool3o`0002[ooooo0ol0000Xooooo`?o00004_ooool005Cooooo00?o0000ooooooooool0
:?ooool01?l0003oooooooooool0000Wooooo`05o`000?ooooooooooooooool00000:_ooool00ol0
003oooooooooo`0Vooooo`05o`000?ooooooooooooooool00000H?ooool00ol0003oooooooooo`0Y
ooooo`04o`000?ooooooooooo`0002Oooooo00Go0000ooooooooooooooooo`00000Zooooo`03o`00
0?oooooooooo02Kooooo00Go0000ooooooooooooooooo`00000Aooooo`00E?ooool00ol0003ooooo
ooooo`0Yooooo`03o`000?oooooooooo02_ooooo00?o0000ooooooooool09Oooool5o`0002_ooooo
00?o0000ooooooooool0G_ooool00ol0003oooooooooo`0Zooooo`03o`000?oooooooooo02_ooooo
00?o0000ooooooooool09Oooool5o`0002_ooooo00?o0000ooooooooool03oooool005Cooooo00?o
0000ooooooooool0:_ooool00ol0003oooooooooo`0Xooooo`;o0000:?ooool01?l0003ooooooooo
ool0000/ooooo`03o`000?oooooooooo05kooooo00?o0000ooooooooool0:oooool00ol0003ooooo
ooooo`0Xooooo`;o0000:?ooool01?l0003oooooooooool0000/ooooo`03o`000?oooooooooo00oo
oooo001Dooooo`03o`000?oooooooooo02Oooooo00Go0000ooooooooooooooooo`00000[ooooo`03
o`000?oooooooooo02Kooooo00?o0000ooooool00000:?ooool4o`00067ooooo00?o0000oooooooo
ool0:?ooool01Ol0003ooooooooooooooooo000002_ooooo00?o0000ooooooooool09_ooool00ol0
003oooooo`00000Xooooo`Co00004_ooool005?ooooo0_l0000Yooooo`05o`000?oooooooooooooo
ool000009oooool01Ol0003ooooooooooooooooo000002Wooooo0_l0000Xooooo`03o`000?oooooo
oooo067ooooo0_l0000Zooooo`05o`000?ooooooooooooooool000009oooool01Ol0003ooooooooo
oooooooo000002Wooooo0_l0000Xooooo`03o`000?oooooooooo01?ooooo001Dooooo`03o`000?oo
oooooooo02Sooooo0ol0000Yooooo`?o0000:oooool00ol0003oooooooooo`0Vooooo`Go0000H?oo
ool00ol0003oooooooooo`0Yooooo`?o0000:Oooool3o`0002_ooooo00?o0000ooooooooool09_oo
ool5o`00017ooooo003ooooooooooooo;_ooool002Wooooo00?o0000ooooooooool0oooooolAoooo
o`03o`000?oooooooooo0>gooooo000Yooooo`03o`000?oooooooooo0?oooooo4Oooool00ol0003o
ooooooooo`3]ooooo`00:Oooool00ol0003oooooooooo`3ooooooa7ooooo00?o0000ooooooooool0
kOooool002?oooooi_l0000^ooooonKo00003oooool002Wooooo00?o0000ooooooooool01_ooool0
0ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooool000002?ooool0
0ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01_ooool0
0ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01_ooool0
0ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01Oooool0
0ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01_ooool0
0ol0003oooooooooo`06ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooool000001_ooool0
0ol0003oooooo`000008ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01_ooool0
0ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01_ooool0
0ol0003oooooooooo`0dooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01?ooool0
1Ol0003oooooo`000?oooooo000000Kooooo00?o0000ooooool000001_ooool00ol0003ooooooooo
o`05ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01_ooool00ol0003ooooooooo
o`06ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01_ooool00ol0003ooooooooo
o`05ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01_ooool00ol0003ooooooooo
o`06ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01Oooool00ol0003ooooooooo
o`06ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01_ooool00ol0003ooooooooo
o`06ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01_ooool00ol0003ooooooooo
o`06ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01_ooool00ol0003ooooooooo
o`0@ooooo`00:Oooool00ol0003oooooooooo`0Eooooo`03o`000?oooooooooo017ooooo00?o0000
ooooooooool0:Oooool00ol0003oooooooooo`0Yooooo`03o`000?oooooooooo01Gooooo00?o0000
ooooooooool01_ooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo02Wooooo00?o0000
ooooooooool0=?ooool00ol0003oooooooooo`0=ooooo`05o`000?ooooooooooooooool000002?oo
ool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo02[ooooo00?o0000ooooooooool0:Ooo
ool00ol0003oooooooooo`0Yooooo`03o`000?oooooooooo02Wooooo00?o0000ooooooooool04?oo
ool002Wooooo00?o0000ooooooooool05Oooool00ol0003oooooooooo`21ooooo`03o`000?oooooo
oooo00Kooooo00?o0000ooooooooool0Joooool00ol0003oooooooooo`0=ooooo`05o`000?oooooo
ooooooooool000002?ooool00ol0003oooooooooo`3@ooooo`00:Oooool2o`0001Kooooo00?o0000
ooooooooool0POooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo06_ooooo0_l0000>
ooooo`05o`000?ooooooooooooooool000002?ooool00ol0003oooooooooo`3@ooooo`00:Oooool0
0ol0003oooooooooo`0Eooooo`03o`000?oooooooooo087ooooo00?o0000ooooooooool01_ooool0
0ol0003oooooooooo`1[ooooo`03o`000?oooooooooo00gooooo00Go0000ooooooooooooooooo`00
0008ooooo`03o`000?oooooooooo0=3ooooo000Yooooo`03o`000?oooooooooo01Gooooo00?o0000
ooooooooool0POooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo06_ooooo00?o0000
ooooooooool03Oooool01Ol0003ooooooooooooooooo000000Sooooo00?o0000ooooooooool0d?oo
ool002Wooooo00?o0000ooooooooool05Oooool00ol0003oooooooooo`21ooooo`03o`000?oooooo
oooo00Kooooo00?o0000ooooooooool0Joooool2o`0000kooooo00Go0000ooooooooooooooooo`00
0008ooooo`03o`000?oooooooooo0=3ooooo000Yooooo`;o00005_ooool00ol0003oooooooooo`21
ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0Joooool00ol0003oooooooooo`0=
ooooo`05o`000?ooooooooooooooool000002?ooool00ol0003oooooooooo`3@ooooo`00:Oooool0
0ol0003oooooooooo`0Eooooo`03o`000?oooooooooo087ooooo00?o0000ooooooooool01_ooool0
0ol0003oooooooooo`1[ooooo`03o`000?oooooooooo00gooooo00Go0000ooooooooooooooooo`00
0008ooooo`03o`000?oooooooooo0=3ooooo000Yooooo`03o`000?oooooooooo01Gooooo00?o0000
ooooooooool0POooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo06_ooooo00?o0000
ooooooooool03Oooool01Ol0003ooooooooooooooooo000000Sooooo00?o0000ooooooooool0d?oo
ool002Wooooo00?o0000ooooooooool05Oooool00ol0003oooooooooo`21ooooo`03o`000?oooooo
oooo00Kooooo00?o0000ooooooooool0Joooool2o`0000kooooo00Go0000ooooooooooooooooo`00
0008ooooo`03o`000?oooooooooo0=3ooooo000Yooooo`03o`000?oooooooooo01Gooooo00?o0000
ooooooooool0POooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo06_ooooo00?o0000
ooooooooool03Oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Gooooo00?o0000
ooooooooool0d?ooool002Wooooo0_l0000Fooooo`03o`000?oooooooooo087ooooo00?o0000oooo
ooooool01_ooool00ol0003oooooooooo`1[ooooo`03o`000?oooooooooo00gooooo00?o0000oooo
ooooool00_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo0=3ooooo000Yooooo`03
o`000?oooooooooo01Gooooo00?o0000ooooooooool0P_ooool00ol0003oooooooooo`05ooooo`03
o`000?oooooooooo06_ooooo0_l0000=ooooo`03o`000?oooooooooo00?ooooo00?o0000oooooooo
ool01Oooool00ol0003oooooooooo`3@ooooo`00:Oooool00ol0003oooooooooo`0Eooooo`03o`00
0?oooooooooo08;ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`1Gooooo`Go0000
0oooool00ol0003oooooooooo`02ooooo`?o00001?ooool00ol0003oooooooooo`0<ooooo`03o`00
0?oooooooooo00?ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`3Aooooo`00:Ooo
ool00ol0003oooooooooo`0Eooooo`03o`000?oooooooooo08;ooooo00?o0000ooooooooool01Ooo
ool00ol0003oooooooooo`1Hooooo`04o`000?ooooooooooo`0000Oooooo00Go0000oooooooooooo
ooooo`000003ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool00oooool00ol0003o
ooooooooo`04ooooo`03o`000?oooooooooo0=7ooooo000Yooooo`;o00005Oooool00ol0003ooooo
ooooo`23ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0FOooool00ol0003ooooo
ooooo`0;ooooo`05o`000?ooooooooooooooool000003_ooool00ol0003oooooooooo`03ooooo`03
o`000?oooooooooo00Cooooo00?o0000ooooooooool0dOooool002Wooooo00?o0000ooooooooool0
5?ooool00ol0003oooooooooo`23ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0
Foooool00ol0003oooooooooo`0:ooooo`04o`000?ooooooooooooooo`?o00003?ooool00ol0003o
ooooooooo`03ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0dOooool001Cooooo
1Ol00003ooooo`03o`000?oooooooooo00;ooooo0ol00005ooooo`03o`000?oooooooooo01Cooooo
00?o0000ooooooooool0Poooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo05Sooooo
00Go0000ooooooooooooooooo`000007ooooo`Co00001?ooool00ol0003oooooooooo`0<ooooo`03
o`000?oooooooooo00?ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`3Aooooo`00
5Oooool01?l0003oooooooooool00007ooooo`05o`000?ooooooooooooooool000001?ooool00ol0
003oooooooooo`0Dooooo`03o`000?oooooooooo08?ooooo00?o0000ooooooooool01?ooool00ol0
003oooooooooo`1Hooooo`05o`000?ooooooooooooooool000001oooool00ol0003oooooooooo`05
ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`04
ooooo`03o`000?oooooooooo0=7ooooo000Fooooo`03o`000?oooooooooo00_ooooo00?o0000oooo
ooooool00_ooool2o`0001Gooooo00?o0000ooooooooool0Poooool00ol0003oooooooooo`04oooo
o`03o`000?oooooooooo05Wooooo0ol00008ooooo`Go00000oooool2o`0000Gooooo00?o0000oooo
ooooool01Oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Cooooo00?o0000oooo
ooooool0dOooool001Oooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`02ooooo`03
o`000?oooooooooo01Cooooo00?o0000ooooooooool0Poooool00ol0003oooooooooo`04ooooo`03
o`000?oooooooooo06cooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`05ooooo`03
o`000?oooooooooo00?ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`3Aooooo`00
5?ooool01Ol0003ooooooooooooooooo000000Oooooo1?l00005ooooo`03o`000?oooooooooo01Co
oooo00?o0000ooooooooool0Poooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo06co
oooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00?o
oooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`3Aooooo`005?ooool01Ol0003ooooo
oooooooooooo000000Oooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`0Dooooo`03
o`000?oooooooooo08?ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`1/ooooo`03
o`000?oooooooooo00Cooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`03ooooo`03
o`000?oooooooooo00Cooooo00?o0000ooooooooool0dOooool001Gooooo0ol00008ooooo`Go0000
1?ooool2o`0000Cooooo1_l0000;ooooo`03o`000?oooooooooo08?ooooo00?o0000ooooooooool0
1?ooool00ol0003oooooooooo`1/ooooo`;o00001Oooool00ol0003oooooooooo`05ooooo`03o`00
0?oooooooooo00?ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`3Aooooo`00:Ooo
ool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool02Ooo
ool00ol0003oooooooooo`23ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0K?oo
ool00ol0003oooooooooo`03ooooo`;o00001oooool00ol0003oooooooooo`03ooooo`03o`000?oo
oooooooo00Cooooo00?o0000ooooooooool0dOooool002Wooooo00?o0000ooooooooool00_ooool0
0ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool0Poooool0
0ol0003oooooooooo`04ooooo`03o`000?oooooooooo06cooooo00?o0000ooooooooool00oooool2
o`0000Oooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`04ooooo`03o`000?oooooo
oooo0=7ooooo000Yooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01?ooool00ol0
003oooooooooo`08ooooo`03o`000?oooooooooo08?ooooo00?o0000ooooooooool01?ooool00ol0
003oooooooooo`1/ooooo`;o00001?ooool2o`0000Oooooo00?o0000ooooooooool00oooool00ol0
003oooooooooo`04ooooo`03o`000?oooooooooo0=7ooooo000Yooooo`05o`000?oooooooooooooo
ool000002?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo08?ooooo00?o0000oooo
ooooool01?ooool00ol0003oooooooooo`1/ooooo`03o`000?oooooooooo00?ooooo0_l00007oooo
o`03o`000?oooooooooo00?ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`3Aoooo
o`00:Oooool2o`0000;ooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`07ooooo`03
o`000?oooooooooo08?ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`1/ooooo`03
o`000?oooooooooo00?ooooo0_l00007ooooo`03o`000?oooooooooo00?ooooo00?o0000oooooooo
ool01?ooool00ol0003oooooooooo`3Aooooo`00:Oooool01Ol0003ooooooooooooooooo000000So
oooo00?o0000ooooooooool01oooool00ol0003oooooooooo`23ooooo`03o`000?oooooooooo00Co
oooo00?o0000ooooooooool0K?ooool00ol0003oooooooooo`03ooooo`;o00001oooool00ol0003o
ooooooooo`03ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0dOooool002Wooooo
00Co0000oooooooooooo00002_ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo08?o
oooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`1/ooooo`;o00001?ooool2o`0000Oo
oooo00?o0000ooooooooool00oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo0=7o
oooo000Yooooo`04o`000?ooooooooooo`0000[ooooo00?o0000ooooooooool01_ooool00ol0003o
ooooooooo`23ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0IOooool3o`0000Co
oooo00?o0000ooooooooool00_ooool00ol0003oooooo`000007ooooo`03o`000?oooooooooo00?o
oooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`3Aooooo`00:Oooool3o`0000cooooo
00?o0000ooooooooool01Oooool00ol0003oooooooooo`23ooooo`03o`000?oooooooooo00Cooooo
00?o0000ooooooooool0I?ooool01Ol0003ooooooooooooooooo000000?ooooo00?o0000oooooooo
ool00_ooool00ol0003oooooo`000007ooooo`03o`000?oooooooooo00?ooooo00?o0000oooooooo
ool01?ooool00ol0003oooooooooo`3Aooooo`00:Oooool00ol0003oooooooooo`0<ooooo`03o`00
0?oooooooooo00Gooooo00?o0000ooooooooool0Poooool00ol0003oooooooooo`04ooooo`03o`00
0?oooooooooo06Sooooo00Go0000ooooooooooooooooo`000004ooooo`03o`000?oooooo000000Oo
oooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo0=7o
oooo000Yooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool01Oooool00ol0003ooooo
ooooo`23ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0J?ooool01?l0003ooooo
ooooooooool3o`0000;ooooo00Co0000oooooooooooo00001_ooool00ol0003oooooooooo`04oooo
o`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0dOooool002Wooooo00?o0000oooooooo
ool03?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo08?ooooo00?o0000oooooooo
ool01?ooool00ol0003oooooooooo`1Tooooo`Co00001?ooool00ol0003oooooooooo`02ooooo`04
o`000?ooooooooooo`0000Kooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`03oooo
o`03o`000?oooooooooo0=7ooooo000Yooooo`;o00003Oooool00ol0003oooooooooo`05ooooo`03
o`000?oooooooooo08?ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`1Tooooo`03
o`000?oooooooooo00Gooooo00?o0000ooooooooool00_ooool01?l0003oooooooooool00006oooo
o`03o`000?oooooooooo00Cooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`3Aoooo
o`00:Oooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00Gooooo00?o0000oooooooo
ool0Poooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo06Cooooo1Ol00003ooooo`;o
00000oooool01?l0003oooooooooool00006ooooo`03o`000?oooooooooo00Cooooo00?o0000oooo
ooooool00oooool00ol0003oooooooooo`3Aooooo`008Oooool3o`0000Gooooo00?o0000oooooooo
ool03?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo08?ooooo00?o0000oooooooo
ool01?ooool00ol0003oooooooooo`1/ooooo`05o`000?ooooooooooooooool000000oooool00ol0
003oooooooooo`04ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool00oooool00ol0
003oooooooooo`3Aooooo`008?ooool01Ol0003ooooooooooooooooo000000Cooooo00?o0000oooo
ooooool03?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo08Cooooo00?o0000oooo
ooooool00oooool00ol0003oooooooooo`1/ooooo`05o`000?ooooooooooooooool000000oooool0
0ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool00oooool0
0ol0003oooooooooo`3Aooooo`009?ooool00ol0003oooooooooo`02ooooo`;o00003Oooool00ol0
003oooooooooo`05ooooo`03o`000?oooooooooo08Cooooo00?o0000ooooooooool00oooool00ol0
003oooooooooo`1/ooooo`05o`000?ooooooooooooooool000000oooool00ol0003oooooooooo`03
ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`3A
ooooo`009?ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00cooooo00?o0000oooo
ooooool01Oooool00ol0003oooooooooo`24ooooo`03o`000?oooooooooo00?ooooo00?o0000oooo
ooooool0K?ooool2o`0000;ooooo00Go0000ooooooooooooooooo`000005ooooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`3Aooooo`008?ooool4o`00
00Gooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo
08Cooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`1/ooooo`05o`000?oooooooooo
ooooool000000oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Gooooo00?o0000
ooooooooool00_ooool00ol0003oooooooooo`3Booooo`008?ooool00ol0003oooooooooo`06oooo
o`03o`000?oooooooooo00gooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`24oooo
o`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0K?ooool01Ol0003ooooooooooooooooo
000000?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`05ooooo`03o`000?oooooo
oooo00;ooooo00?o0000ooooooooool0d_ooool0023ooooo1Ol00004ooooo`;o00003_ooool00ol0
003oooooooooo`04ooooo`03o`000?oooooooooo08Cooooo00?o0000ooooooooool00oooool00ol0
003oooooooooo`1/ooooo`;o00000_ooool01Ol0003ooooooooooooooooo000000Gooooo00?o0000
ooooooooool01Oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo0=;ooooo000Yoooo
o`03o`000?oooooooooo00gooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`24oooo
o`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0K?ooool01?l0003oooooooooool00004
ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`02
ooooo`03o`000?oooooooooo0=;ooooo000Yooooo`03o`000?oooooooooo00gooooo00?o0000oooo
ooooool00oooool00ol0003oooooooooo`25ooooo`03o`000?oooooooooo00?ooooo00?o0000oooo
ooooool0K?ooool01?l0003oooooooooool00004ooooo`03o`000?oooooooooo00?ooooo00?o0000
ooooooooool01Oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo0=;ooooo000Yoooo
o`03o`000?oooooooooo00gooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`25oooo
o`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0K?ooool01?l0003oooooooooool00004
ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`02
ooooo`03o`000?oooooooooo0=;ooooo000Yooooo`03o`000?oooooooooo00gooooo00?o0000oooo
ooooool00oooool00ol0003oooooooooo`25ooooo`03o`000?oooooooooo00?ooooo00?o0000oooo
ooooool0K?ooool2o`000003ooooool0003ooooo00?ooooo00?o0000ooooooooool00oooool00ol0
003oooooooooo`05ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0d_ooool002Wo
oooo0_l0000>ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0QOooool00ol0003o
ooooooooo`03ooooo`03o`000?oooooooooo05[ooooo00?o0000ooooooooool00oooool00ol0003o
ooooooooo`02ooooo`?o00001?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00?o
oooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo0=;o
oooo000Yooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool00oooool00ol0003ooooo
ooooo`25ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0Foooool00ol0003ooooo
ooooo`07ooooo`05o`000?ooooooooooooooool000000oooool00ol0003oooooooooo`05ooooo`03
o`000?oooooooooo00?ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`02ooooo`03
o`000?oooooooooo0=;ooooo000Yooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool0
0oooool00ol0003oooooooooo`25ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0
G?ooool00ol0003oooooooooo`0:ooooo`04o`000?ooooooooooooooo`?o00001Oooool00ol0003o
ooooooooo`03ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool00_ooool00ol0003o
ooooooooo`3Booooo`00:Oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00?ooooo
00?o0000ooooooooool0QOooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo05cooooo
00?o0000ooooooooool02_ooool01Ol0003ooooooooooooooooo000000Oooooo00?o0000oooooooo
ool00oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00;ooooo00?o0000oooooooo
ool0d_ooool002Wooooo0_l0000>ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0
QOooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo05gooooo00?o0000ooooooooool0
1Oooool4o`0000Cooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`03ooooo`03o`00
0?oooooooooo00Gooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`3Booooo`00:Ooo
ool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0QOoo
ool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo05Wooooo00Go0000oooooooooooooooo
o`000007ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003ooooo
ooooo`03ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool00_ooool00ol0003ooooo
ooooo`3Booooo`00:Oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00?ooooo00?o
0000ooooooooool0QOooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo05Wooooo1Ol0
0007ooooo`Go00000oooool2o`0000Kooooo00?o0000ooooooooool00oooool00ol0003ooooooooo
o`05ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0d_ooool002Wooooo00?o0000
ooooooooool03Oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo08Gooooo00?o0000
ooooooooool00_ooool00ol0003oooooooooo`1]ooooo`03o`000?oooooooooo00Gooooo00?o0000
ooooooooool00oooool00ol0003oooooooooo`06ooooo`05o`000?ooooooooooooooool00000e?oo
ool002Wooooo0_l0000>ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0QOooool0
0ol0003oooooooooo`02ooooo`03o`000?oooooooooo06gooooo00?o0000ooooooooool01Oooool0
0ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Kooooo00Go0000ooooooooooooooooo`00
003Dooooo`00:Oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00?ooooo00?o0000
ooooooooool0QOooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo06gooooo0_l00006
ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool01_ooool01Ol0003ooooooooooooo
oooo00000=Cooooo000Fooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00_ooool3
o`0000Gooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`03ooooo`03o`000?oooooo
oooo08Gooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`1]ooooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`06ooooo`05o`000?oooooo
ooooooooool00000e?ooool001Kooooo00?o0000ooooooooool01oooool01Ol0003ooooooooooooo
oooo000000Cooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`03ooooo`03o`000?oo
oooooooo08Gooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`1]ooooo`03o`000?oo
oooooooo00Gooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`06ooooo`05o`000?oo
ooooooooooooool00000e?ooool001Oooooo00?o0000ooooooooool02_ooool00ol0003ooooooooo
o`02ooooo`;o00003oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo08Gooooo00?o
0000ooooooooool00_ooool00ol0003oooooooooo`1]ooooo`03o`000?oooooooooo00Gooooo00?o
0000ooooooooool00oooool00ol0003oooooooooo`06ooooo`05o`000?ooooooooooooooool00000
e?ooool001Oooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`02ooooo`03o`000?oo
oooooooo00kooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`25ooooo`03o`000?oo
oooooooo00;ooooo00?o0000ooooooooool0KOooool2o`0000Kooooo00?o0000ooooooooool00ooo
ool00ol0003oooooooooo`06ooooo`05o`000?ooooooooooooooool00000e?ooool001Sooooo00?o
0000ooooooooool01Oooool4o`0000Gooooo00?o0000ooooooooool03_ooool00ol0003ooooooooo
o`02ooooo`03o`000?oooooooooo08Gooooo00?o0000ooooooooool00_ooool00ol0003ooooooooo
o`1]ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool00_ooool00ol0003ooooooooo
o`06ooooo`05o`000?ooooooooooooooool00000e?ooool001Cooooo00Go0000oooooooooooooooo
o`000007ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool03_ooool00ol0003ooooo
ooooo`02ooooo`03o`000?oooooooooo08Gooooo00?o0000ooooooooool00_ooool00ol0003ooooo
ooooo`1]ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool00_ooool00ol0003ooooo
ooooo`06ooooo`05o`000?ooooooooooooooool00000e?ooool001Cooooo1Ol00007ooooo`Go0000
1?ooool2o`0000oooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`25ooooo`03o`00
0?oooooooooo00;ooooo00?o0000ooooooooool0KOooool2o`0000Oooooo00?o0000ooooooooool0
0_ooool00ol0003oooooooooo`06ooooo`05o`000?ooooooooooooooool00000e?ooool002Wooooo
00?o0000ooooooooool03_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo08Kooooo
00Go0000ooooooooooooooooo`00001_ooooo`03o`000?oooooooooo00Kooooo00Go0000oooooooo
ooooooooo`000009ooooo`05o`000?ooooooooooooooool00000e?ooool002Wooooo00?o0000oooo
ooooool03_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo08Kooooo00Go0000oooo
ooooooooooooo`00001Rooooo`?o00001?ooool2o`0000Cooooo00?o0000ooooooooool01_ooool0
1Ol0003ooooooooooooooooo000000Wooooo00Go0000ooooooooooooooooo`00003Dooooo`00:Ooo
ool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0Q_oo
ool01Ol0003ooooooooooooooooo000006?ooooo00?o0000ooooooooool00_ooool01?l0003ooooo
ooooool00003ooooo`03o`000?oooooooooo00Kooooo00Go0000ooooooooooooooooo`000009oooo
o`05o`000?ooooooooooooooool00000e?ooool002Wooooo00?o0000ooooooooool03_ooool00ol0
003oooooooooo`02ooooo`03o`000?oooooooooo08Kooooo00Go0000ooooooooooooooooo`00001S
ooooo`03o`000?oooooooooo00;ooooo00Co0000oooooooooooo00000oooool3o`0000Kooooo00Go
0000ooooooooooooooooo`000009ooooo`05o`000?ooooooooooooooool00000e?ooool002Wooooo
0_l0000?ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0Q_ooool01Ol0003ooooo
oooooooooooo000006?ooooo00?o0000ooooooooool00_ooool01?l0003oooooooooool00003oooo
o`03o`000?oooooooooo00Kooooo00Go0000ooooooooooooooooo`000009ooooo`04o`000?oooooo
ooooo`000=Gooooo000Yooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool00_ooool0
0ol0003oooooooooo`26ooooo`05o`000?ooooooooooooooool00000Hoooool00ol0003ooooooooo
o`02ooooo`04o`000?ooooooooooo`0000?ooooo00?o0000ooooooooool01_ooool01Ol0003ooooo
oooooooooooo000000Wooooo00Co0000oooooooooooo0000eOooool002Wooooo00?o0000oooooooo
ool03_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo08Kooooo00Go0000oooooooo
ooooooooo`00001Rooooo`;o00001?ooool01?l0003oooooooooool00003ooooo`03o`000?oooooo
oooo00Kooooo00Go0000ooooooooooooooooo`000009ooooo`04o`000?ooooooooooo`000=Gooooo
000Yooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool00_ooool00ol0003ooooooooo
o`26ooooo`05o`000?ooooooooooooooool00000Hoooool00ol0003oooooooooo`03ooooo`;o0000
1?ooool2o`0000Oooooo00Go0000ooooooooooooooooo`000009ooooo`04o`000?ooooooooooo`00
0=Gooooo000Yooooo`;o00003oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo08Ko
oooo00Go0000ooooooooooooooooo`00001_ooooo`03o`000?oooooooooo00Kooooo00Go0000oooo
ooooooooooooo`000009ooooo`04o`000?ooooooooooo`000=Gooooo000Yooooo`03o`000?oooooo
oooo00kooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`26ooooo`05o`000?oooooo
ooooooooool00000Koooool00ol0003oooooooooo`06ooooo`05o`000?ooooooooooooooool00000
2Oooool01?l0003oooooooooool0003Eooooo`00:Oooool00ol0003oooooooooo`0>ooooo`03o`00
0?oooooooooo00;ooooo00?o0000ooooooooool0Q_ooool01Ol0003ooooooooooooooooo000006oo
oooo0_l00007ooooo`05o`000?ooooooooooooooool000002Oooool01?l0003oooooooooool0003E
ooooo`00:Oooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo00;ooooo00?o0000oooo
ooooool0Q_ooool01Ol0003ooooooooooooooooo000006oooooo00?o0000ooooooooool01_ooool0
1Ol0003ooooooooooooooooo000000Wooooo00Co0000oooooooooooo0000eOooool002Wooooo0_l0
000?ooooo`05o`000?ooooooooooooooool00000ROooool01Ol0003ooooooooooooooooo000006oo
oooo00?o0000ooooooooool01_ooool01Ol0003ooooooooooooooooo000000Wooooo00Co0000oooo
oooooooo0000eOooool002Wooooo00?o0000ooooooooool03oooool01?l0003oooooooooool00029
ooooo`05o`000?ooooooooooooooool00000Koooool00ol0003oooooooooo`06ooooo`05o`000?oo
ooooooooooooool000002_ooool00ol0003oooooo`00003Eooooo`006oooool3o`0000Cooooo0_l0
0005ooooo`03o`000?oooooooooo00oooooo00Co0000oooooooooooo0000ROooool01Ol0003ooooo
oooooooooooo000006oooooo0_l00007ooooo`05o`000?ooooooooooooooool000002_ooool00ol0
003oooooo`00003Eooooo`007?ooool00ol0003oooooooooo`02ooooo`04o`000?ooooooooooo`00
00Cooooo00?o0000ooooooooool03oooool01?l0003oooooooooool00029ooooo`05o`000?oooooo
ooooooooool00000Koooool00ol0003oooooooooo`06ooooo`05o`000?ooooooooooooooool00000
2_ooool00ol0003oooooo`00003Eooooo`007?ooool00ol0003oooooooooo`02ooooo`04o`000?oo
ooooooooo`0000Cooooo0_l0000@ooooo`04o`000?ooooooooooo`0008Wooooo00Go0000oooooooo
ooooooooo`00001_ooooo`03o`000?oooooooooo00Kooooo00Go0000ooooooooooooooooo`00000:
ooooo`03o`000?oooooo00000=Gooooo000Looooo`03o`000?oooooooooo00;ooooo00Co0000oooo
oooooooo00001?ooool00ol0003oooooooooo`0?ooooo`04o`000?ooooooooooo`0008Wooooo00Co
0000oooooooooooo0000L?ooool2o`0000Oooooo00Go0000ooooooooooooooooo`00000:ooooo`03
o`000?oooooo00000=Gooooo000Looooo`03o`000?oooooooooo00;ooooo00Co0000oooooooooooo
00001?ooool00ol0003oooooooooo`0?ooooo`04o`000?ooooooooooo`0008Wooooo00Co0000oooo
oooooooo0000Eoooool3o`0000;ooooo1Ol00003ooooo`03o`000?oooooooooo00;ooooo0ol00004
ooooo`03o`000?oooooooooo00Kooooo00Go0000ooooooooooooooooo`00000:ooooo`03o`000?oo
oooo00000=Gooooo000Kooooo`;o00001?ooool01?l0003oooooooooool00004ooooo`03o`000?oo
oooooooo00oooooo00Co0000oooooooooooo0000ROooool01?l0003oooooooooool0001Hooooo`03
o`000?oooooooooo00;ooooo00Co0000oooooooooooo00001oooool01Ol0003ooooooooooooooooo
000000?ooooo00?o0000ooooooooool01_ooool01Ol0003ooooooooooooooooo000000[ooooo00?o
0000ooooool00000eOooool001cooooo00?o0000ooooooooool00oooool2o`0000Gooooo00?o0000
ooooooooool03oooool01?l0003oooooooooool00029ooooo`04o`000?ooooooooooo`0005Sooooo
00?o0000ooooooooool00oooool00ol0003oooooooooo`0;ooooo`05o`000?ooooooooooooooool0
00002?ooool01Ol0003ooooooooooooooooo000000[ooooo00?o0000ooooool00000eOooool002Wo
oooo0_l0000@ooooo`04o`000?ooooooooooo`0008Wooooo00Co0000oooooooooooo0000F?ooool0
0ol0003oooooooooo`04ooooo`03o`000?oooooooooo00[ooooo00Co0000oooooooooooooooo0ol0
0006ooooo`05o`000?ooooooooooooooool000002_ooool00ol0003oooooo`00003Eooooo`00:Ooo
ool00ol0003oooooooooo`0?ooooo`04o`000?ooooooooooo`0008Wooooo00Co0000oooooooooooo
0000F?ooool01Ol0003ooooooooooooooooo000000?ooooo00?o0000ooooooooool01Oooool4o`00
00Cooooo00?o0000ooooooooool01_ooool01Ol0003ooooooooooooooooo000000[ooooo00?o0000
ooooool00000eOooool002Wooooo00?o0000ooooooooool03oooool01?l0003oooooooooool00029
ooooo`04o`000?ooooooooooo`0005Oooooo0_l00003ooooo`05o`000?ooooooooooooooool00000
1oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Kooooo00Go0000oooooooooooo
ooooo`00000:ooooo`03o`000?oooooo00000=Gooooo000Yooooo`03o`000?oooooooooo00oooooo
00Co0000oooooooooooo0000ROooool01?l0003oooooooooool0001Hooooo`03o`000?oooooooooo
00;ooooo0ol00008ooooo`Go00000oooool2o`0000Oooooo00Go0000ooooooooooooooooo`00000:
ooooo`03o`000?oooooo00000=Gooooo000Yooooo`;o00004?ooool01?l0003oooooooooool00029
ooooo`04o`000?ooooooooooo`00073ooooo00?o0000ooooooooool01oooool01?l0003ooooooooo
ool0000:ooooo`03o`000?oooooo00000=Gooooo000Yooooo`03o`000?oooooooooo00oooooo00Co
0000oooooooooooo0000ROooool01?l0003oooooooooool0001`ooooo`03o`000?oooooooooo00Oo
oooo00Co0000oooooooooooo00002_ooool00ol0003oooooo`00003Eooooo`00:Oooool00ol0003o
ooooooooo`0?ooooo`04o`000?ooooooooooo`0008[ooooo00?o0000ooooool00000L?ooool00ol0
003oooooooooo`07ooooo`03o`000?oooooo000000_ooooo00?o0000ooooool00000eOooool002Wo
oooo00?o0000ooooooooool03oooool01?l0003oooooooooool0002:ooooo`03o`000?oooooo0000
073ooooo0_l00008ooooo`03o`000?oooooo000000_ooooo00?o0000ooooool00000eOooool002Wo
oooo0_l0000@ooooo`04o`000?ooooooooooo`0008[ooooo00?o0000ooooool00000L?ooool00ol0
003oooooooooo`07ooooo`03o`000?oooooo000000_ooooo00?o0000ooooool00000eOooool002Wo
oooo00?o0000ooooooooool03oooool01?l0003oooooooooool0002:ooooo`03o`000?oooooo0000
073ooooo00?o0000ooooooooool01oooool00ol0003oooooo`00000;ooooo`03o`000?oooooo0000
0=Gooooo000Yooooo`03o`000?oooooooooo013ooooo00?o0000ooooool00000R_ooool00ol0003o
ooooo`00001`ooooo`;o00002?ooool00ol0003oooooo`00000;ooooo`03o`000?oooooo00000=Go
oooo000Yooooo`03o`000?oooooooooo013ooooo00?o0000ooooool00000R_ooool00ol0003ooooo
o`00001`ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooool000002oooool00ol0003ooooo
o`00003Eooooo`00:Oooool2o`00017ooooo00?o0000ooooool00000R_ooool00ol0003oooooo`00
001`ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooool000002oooool2o`000=Kooooo000Y
ooooo`03o`000?oooooooooo013ooooo00?o0000ooooool00000R_ooool00ol0003oooooo`00001`
ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooool000002oooool2o`000=Kooooo000?oooo
o`?o00000_ooool5o`0000?ooooo00?o0000ooooooooool00_ooool3o`0000Gooooo00?o0000oooo
ooooool04?ooool00ol0003oooooo`00002:ooooo`03o`000?oooooo0000073ooooo0_l00008oooo
o`03o`000?oooooo000000_ooooo0_l0003Fooooo`004?ooool00ol0003oooooooooo`02ooooo`04
o`000?ooooooooooo`0000Oooooo00Go0000ooooooooooooooooo`000004ooooo`03o`000?oooooo
oooo013ooooo00?o0000ooooool00000R_ooool00ol0003oooooo`00001Sooooo`?o00000oooool3
o`0000Cooooo00?o0000ooooooooool01oooool00ol0003oooooo`00000<ooooo`03o`000?oooooo
oooo0=Cooooo000@ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool02oooool00ol0
003oooooooooo`02ooooo`;o00004Oooool00ol0003oooooo`00002:ooooo`03o`000?oooooo0000
06Cooooo00Go0000ooooooooooooooooo`000003ooooo`05o`000?ooooooooooooooool000002Ooo
ool00ol0003oooooo`00000<ooooo`03o`000?oooooooooo0=Cooooo000@ooooo`03o`000?oooooo
oooo00Cooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooo
oooo013ooooo00?o0000ooooool00000R_ooool00ol0003oooooo`00001Tooooo`03o`000?oooooo
oooo00Gooooo00Go0000ooooooooooooooooo`000009ooooo`03o`000?oooooo000000cooooo00?o
0000ooooooooool0e?ooool0013ooooo00Go0000ooooooooooooooooo`000003ooooo`03o`000?oo
oooooooo00Gooooo1?l00005ooooo`03o`000?oooooooooo013ooooo00?o0000ooooool00000R_oo
ool00ol0003oooooo`00001Tooooo`03o`000?oooooooooo00Gooooo00Co0000oooooooooooooooo
0ol00007ooooo`03o`000?oooooo000000cooooo00?o0000ooooooooool0e?ooool000oooooo0_l0
0003ooooo`05o`000?ooooooooooooooool000001oooool00ol0003oooooooooo`06ooooo`03o`00
0?oooooooooo013ooooo00?o0000ooooool00000R_ooool00ol0003oooooo`00001Tooooo`04o`00
0?ooooooooooooooo`Co00001?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooo000000co
oooo00?o0000ooooooooool0e?ooool0013ooooo00?o0000ooooooooool00_ooool3o`0000Sooooo
1Ol00004ooooo`03o`000?oooooooooo013ooooo00?o0000ooooool00000R_ooool00ol0003ooooo
o`00001Sooooo`;o00000oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Oooooo
00?o0000ooooool000003?ooool00ol0003oooooooooo`3Dooooo`00:Oooool2o`00017ooooo00?o
0000ooooool00000R_ooool00ol0003oooooo`00001Tooooo`04o`000?ooooooooooooooo`Go0000
0oooool2o`0000Sooooo00?o0000ooooool000003?ooool00ol0003oooooooooo`3Dooooo`00:Ooo
ool00ol0003oooooooooo`0@ooooo`;o0000Roooool00ol0003oooooo`00001`ooooo`03o`000?oo
oooooooo00Oooooo00?o0000ooooool000003?ooool00ol0003oooooooooo`3Dooooo`00:Oooool0
0ol0003oooooooooo`0@ooooo`;o0000Roooool00ol0003oooooo`00001`ooooo`03o`000?oooooo
oooo00Oooooo00?o0000ooooool000003?ooool00ol0003oooooooooo`3Dooooo`00:Oooool00ol0
003oooooooooo`0@ooooo`;o0000Roooool00ol0003oooooo`00001`ooooo`03o`000?oooooooooo
00Oooooo00?o0000ooooool000003?ooool00ol0003oooooooooo`3Dooooo`00:Oooool2o`00017o
oooo0_l0002;ooooo`03o`000?oooooo0000073ooooo0_l00008ooooo`03o`000?oooooo000000co
oooo00?o0000ooooooooool0e?ooool002Wooooo00?o0000ooooooooool04?ooool2o`0008_ooooo
00?o0000ooooool00000L?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooo00000>?ooooo
000Yooooo`03o`000?oooooooooo013ooooo0_l0002;ooooo`03o`000?oooooo0000073ooooo00?o
0000ooooooooool01oooool00ol0003oooooo`00003Sooooo`00:Oooool00ol0003oooooooooo`0@
ooooo`;o0000Roooool00ol0003oooooo`00001`ooooo`;o00002?ooool00ol0003oooooo`00003S
ooooo`00:Oooool2o`0001;ooooo00?o0000ooooooooool0ROooool00ol0003oooooo`00001`oooo
o`03o`000?oooooooooo00Oooooo00?o0000ooooool00000hoooool002Wooooo00?o0000oooooooo
ool04Oooool00ol0003oooooooooo`29ooooo`;o0000LOooool00ol0003oooooooooo`07ooooo`03
o`000?oooooo00000>?ooooo000Yooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool0
ROooool2o`00077ooooo00?o0000ooooooooool01oooool00ol0003oooooo`00003Sooooo`00:Ooo
ool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo08Wooooo0_l0001aooooo`;o00002?oo
ool00ol0003oooooo`00003Sooooo`00:Oooool2o`0001;ooooo00?o0000ooooooooool0R_ooool0
0ol0003oooooooooo`1Fooooo`?o00001?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooo
oooo00;ooooo0ol00004ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool0h_ooool0
02Wooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`2:ooooo`03o`000?oooooooooo
05Oooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`07ooooo`05o`000?oooooooooo
ooooool000000oooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo0>;ooooo000Koooo
o`?o00000oooool3o`0000Gooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`2:oooo
o`03o`000?oooooooooo05Oooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`0:oooo
o`04o`000?ooooooooooooooo`?o00002?ooool00ol0003oooooooooo`3Rooooo`007?ooool01Ol0
003ooooooooooooooooo000000?ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`0A
ooooo`03o`000?oooooooooo08[ooooo00?o0000ooooooooool0Eoooool00ol0003oooooooooo`04
ooooo`03o`000?oooooooooo00[ooooo00Go0000ooooooooooooooooo`00000:ooooo`03o`000?oo
oooooooo0>;ooooo000Looooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool00_ooool2
o`0001;ooooo00?o0000ooooooooool0R_ooool00ol0003oooooooooo`1Gooooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool01Oooool4o`0000Cooooo00?o0000ooooooooool02?ooool0
0ol0003oooooooooo`3Rooooo`007?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo
00;ooooo00?o0000ooooooooool0W_ooool00ol0003oooooooooo`1Fooooo`;o00000oooool01Ol0
003ooooooooooooooooo000000Oooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`08
ooooo`03o`000?oooooooooo0>;ooooo000Looooo`04o`000?ooooooooooooooo`Co00001Oooool0
0ol0003oooooooooo`2Nooooo`03o`000?oooooooooo05Oooooo00Co0000oooooooooooooooo1Ol0
0007ooooo`Go00000oooool2o`0000Wooooo00?o0000ooooooooool0h_ooool001_ooooo0_l00003
ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0W_ooool00ol0003oooooooooo`1_
ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool0h_ooool001cooooo00Co0000oooo
oooooooooooo1Ol00004ooooo`03o`000?oooooooooo09kooooo00?o0000ooooooooool0Koooool0
0ol0003oooooooooo`08ooooo`03o`000?oooooooooo0>;ooooo000Yooooo`;o0000Woooool00ol0
003oooooooooo`1_ooooo`;o00002Oooool00ol0003oooooooooo`3Rooooo`00:Oooool00ol0003o
ooooooooo`2Nooooo`03o`000?oooooooooo06oooooo00?o0000ooooooooool02?ooool00ol0003o
ooooooooo`3Rooooo`00:Oooool00ol0003oooooooooo`2Nooooo`03o`000?oooooooooo06oooooo
00?o0000ooooooooool02?ooool00ol0003oooooooooo`3Rooooo`00:Oooool00ol0003ooooooooo
o`2Nooooo`03o`000?oooooooooo06oooooo00?o0000ooooooooool02?ooool00ol0003ooooooooo
o`3Rooooo`00:Oooool2o`0009oooooo00?o0000ooooooooool0Koooool2o`0000Wooooo00?o0000
ooooooooool0h_ooool002Wooooo00?o0000ooooooooool0oooooolAooooo`03o`000?oooooooooo
0>gooooo000Yooooo`03o`000?oooooooooo0?oooooo4Oooool00ol0003oooooooooo`3]ooooo`00
:Oooool00ol0003oooooooooo`3ooooooa7ooooo00?o0000ooooooooool0kOooool00?oooooooooo
ool^ooooo`00ooooooooooooobkooooo003ooooooooooooo;_ooool00?ooooooooooool^ooooo`00
ooooooooooooobkooooo003ooooooooooooo;_ooool00001\
\>"],
  ImageRangeCache->{{{0, 555}, {162.562, 0}} -> {-0.0549993, -0.0147151, \
0.0038018, 0.0038018}, {{14.4375, 264.938}, {158.688, 3.8125}} -> {-0.937052, \
-2.15213, 0.0226877, 0.118657}, {{290, 540.5}, {158.688, 3.8125}} -> \
{-7.18894, -2.55566, 0.0226877, 0.140905}}]
}, Open  ]],

Cell["\<\
The problems with pairwise divergence distributions are discussed \
by Donnelly and Tavar\[EAcute] (1995, p417)\
\>", "Text"]
}, Closed]]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Reconstructing genealogies",
  FontColor->RGBColor[0, 0, 1]]], "SubsectionIcon"],

Cell[CellGroupData[{

Cell[TextData[{
  StyleBox["Q4: ",
    FontColor->RGBColor[0, 0, 1]],
  "Can you reconstruct the genealogy from the observed mutation rate?  What \
mutation rate \[Theta] is needed for reconstruction to be possible most of \
the time?"
}], "SubsubsectionIcon"],

Cell["\<\
This is the genealogy given in the example - it was generated with \
10 leaves and \[Theta]=10 \
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(S = GenealogyToMatrix[rg, MutationLabels \[Rule] ms]; 
    S // MatrixForm\)], "Input",
  CellLabel->"In[45]:="],

Cell[BoxData[
    TagBox[
      RowBox[{"(", "\[NoBreak]", GridBox[{
            {"1", "1", "1", "1", "1", "1", "0", "0", "0", "0", "0", "0", "1", 
              "1", "1", "1", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0",
               "0", "0", "0", "0", "0", "0", "0", "0"},
            {"1", "1", "1", "1", "1", "1", "0", "0", "0", "0", "0", "0", "0", 
              "0", "0", "0", "0", "0", "0", "0", "1", "1", "1", "0", "0", "0",
               "0", "0", "0", "0", "0", "0", "0", "0"},
            {"0", "0", "0", "0", "0", "0", "1", "1", "1", "1", "1", "1", "0", 
              "0", "0", "0", "1", "1", "1", "1", "0", "0", "0", "1", "0", "0",
               "0", "0", "0", "0", "0", "0", "0", "0"},
            {"0", "0", "0", "0", "0", "0", "1", "1", "1", "1", "1", "1", "0", 
              "0", "0", "0", "1", "1", "1", "1", "0", "0", "0", "0", "0", "0",
               "0", "1", "0", "0", "0", "0", "0", "0"},
            {"0", "0", "0", "0", "0", "0", "1", "1", "1", "1", "1", "1", "0", 
              "0", "0", "0", "1", "1", "1", "1", "0", "0", "0", "0", "0", "0",
               "0", "1", "0", "0", "0", "0", "0", "0"},
            {"0", "0", "0", "0", "0", "0", "1", "1", "1", "1", "1", "1", "0", 
              "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "1", "1",
               "1", "0", "0", "0", "0", "0", "0", "0"},
            {"0", "0", "0", "0", "0", "0", "1", "1", "1", "1", "1", "1", "0", 
              "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0",
               "0", "0", "1", "1", "1", "0", "0", "0"},
            {"0", "0", "0", "0", "0", "0", "1", "1", "1", "1", "1", "1", "0", 
              "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0",
               "0", "0", "1", "1", "1", "0", "0", "0"},
            {"0", "0", "0", "0", "0", "0", "1", "1", "1", "1", "1", "1", "0", 
              "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0",
               "0", "0", "0", "0", "0", "1", "1", "1"},
            {"0", "0", "0", "0", "0", "0", "1", "1", "1", "1", "1", "1", "0", 
              "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0",
               "0", "0", "0", "0", "0", "1", "1", "0"}
            }], "\[NoBreak]", ")"}],
      Function[ BoxForm`e$, 
        MatrixForm[ BoxForm`e$]]]], "Output",
  CellLabel->"Out[45]//MatrixForm="]
}, Open  ]],

Cell[TextData[{
  "There are 34 mutations in the genealogy.  Each mutation defines a ",
  StyleBox["clade",
    FontSlant->"Italic"],
  " - a set of leaves who share a common ancestor that carried the mutation.  \
The shape of the genealogy can be reconstructed provided that at least one \
mutation has occurred on each internal branch.  The genealogy can be rooted \
provided that one knows which mutation is derived (eg through use of an ",
  StyleBox["outgroup",
    FontSlant->"Italic"],
  ")."
}], "Text"],

Cell[TextData[{
  "This is easy to do by hand. ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " will reconstruct the genealogy automatically.  On the left, the actual \
genealogy, on the right,m the estimate:"
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(gg = MatrixToGenealogy[S, lvs, Range[34]];\)\), "\n", 
    \(\(DisplayTogetherArray[{PlotGenealogy[rg], 
          PlotGenealogy[gg]}];\)\), "\[IndentingNewLine]", 
    \(gg\)}], "Input",
  CellLabel->"In[151]:="],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .2943 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.47619 0.00700719 0.47619 [
[ 0 0 0 0 ]
[ 1 .2943 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .2943 L
0 .2943 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.00700719 0.477324 0.287295 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0909091 0.0909091 0.0772542 0.0772542 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
0 g
.5 Mabswid
[ ] 0 setdash
.68182 .15451 m
.63636 .07725 L
s
.68182 .15451 m
.72727 .07725 L
s
.40909 .15451 m
.36364 .07725 L
s
.40909 .15451 m
.45455 .07725 L
s
.36364 .23176 m
.27273 .07725 L
s
.36364 .23176 m
.40909 .15451 L
s
.86364 .15451 m
.81818 .07725 L
s
.86364 .15451 m
.90909 .07725 L
s
.77273 .23176 m
.68182 .15451 L
s
.77273 .23176 m
.86364 .15451 L
s
.13636 .15451 m
.09091 .07725 L
s
.13636 .15451 m
.18182 .07725 L
s
.72727 .30902 m
.54545 .07725 L
s
.72727 .30902 m
.77273 .23176 L
s
.59091 .38627 m
.36364 .23176 L
s
.59091 .38627 m
.72727 .30902 L
s
.5 .46353 m
.13636 .15451 L
s
.5 .46353 m
.59091 .38627 L
s
.5 .54078 m
.5 .46353 L
s
[(1)] .66364 .16996 0 0 Mshowa
[(2)] .39091 .16996 0 0 Mshowa
[(3)] .34545 .24721 0 0 Mshowa
[(4)] .84545 .16996 0 0 Mshowa
[(5)] .75455 .24721 0 0 Mshowa
[(6)] .11818 .16996 0 0 Mshowa
[(7)] .70909 .32447 0 0 Mshowa
[(8)] .57273 .40172 0 0 Mshowa
[(9)] .48182 .47898 0 0 Mshowa
[(10)] .48182 .55623 0 0 Mshowa
gsave
.09091 .0618 -69 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x9) show
1.000 setlinewidth
grestore
gsave
.18182 .0618 -72 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x10) show
1.000 setlinewidth
grestore
gsave
.27273 .0618 -69 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x8) show
1.000 setlinewidth
grestore
gsave
.36364 .0618 -69 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x2) show
1.000 setlinewidth
grestore
gsave
.45455 .0618 -69 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x3) show
1.000 setlinewidth
grestore
gsave
.54545 .0618 -69 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x4) show
1.000 setlinewidth
grestore
gsave
.63636 .0618 -69 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x5) show
1.000 setlinewidth
grestore
gsave
.72727 .0618 -69 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x6) show
1.000 setlinewidth
grestore
gsave
.81818 .0618 -69 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x1) show
1.000 setlinewidth
grestore
gsave
.90909 .0618 -69 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x7) show
1.000 setlinewidth
grestore
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.522676 0.00700719 0.97619 0.287295 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0909091 0.0909091 0.103006 0.103006 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
0 g
.5 Mabswid
[ ] 0 setdash
.5 .51503 m
.13636 .20601 L
s
.5 .51503 m
.59091 .41202 L
s
.13636 .20601 m
.09091 .10301 L
s
.13636 .20601 m
.18182 .10301 L
s
.36364 .30902 m
.27273 .10301 L
s
.36364 .30902 m
.40909 .20601 L
s
.40909 .20601 m
.36364 .10301 L
s
.40909 .20601 m
.45455 .10301 L
s
.59091 .41202 m
.36364 .30902 L
s
.59091 .41202 m
.54545 .10301 L
s
.59091 .41202 m
.68182 .20601 L
s
.59091 .41202 m
.86364 .20601 L
s
.68182 .20601 m
.63636 .10301 L
s
.68182 .20601 m
.72727 .10301 L
s
.86364 .20601 m
.81818 .10301 L
s
.86364 .20601 m
.90909 .10301 L
s
[(1)] .48182 .53563 0 0 Mshowa
[(2)] .11818 .22661 0 0 Mshowa
[(3)] .34545 .32962 0 0 Mshowa
[(4)] .39091 .22661 0 0 Mshowa
[(5)] .57273 .43262 0 0 Mshowa
[(6)] .66364 .22661 0 0 Mshowa
[(7)] .84545 .22661 0 0 Mshowa
gsave
.09091 .0824 -69 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x1) show
1.000 setlinewidth
grestore
gsave
.18182 .0824 -69 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x2) show
1.000 setlinewidth
grestore
gsave
.27273 .0824 -69 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x3) show
1.000 setlinewidth
grestore
gsave
.36364 .0824 -69 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x4) show
1.000 setlinewidth
grestore
gsave
.45455 .0824 -69 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x5) show
1.000 setlinewidth
grestore
gsave
.54545 .0824 -69 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x6) show
1.000 setlinewidth
grestore
gsave
.63636 .0824 -69 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x7) show
1.000 setlinewidth
grestore
gsave
.72727 .0824 -69 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x8) show
1.000 setlinewidth
grestore
gsave
.81818 .0824 -69 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x9) show
1.000 setlinewidth
grestore
gsave
.90909 .0824 -72 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x10) show
1.000 setlinewidth
grestore
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[151]:=",
  ImageSize->{527, 155.062},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40008?0000Vb000`400?l00000o`00003ooooooooo
oooooa7ooooo003ooooooooooooo4Oooool00?oooooooooooolAooooo`00oooooooooooooa7ooooo
003ooooooooooooo4Oooool00?oooooooooooolAooooo`00oooooooooooooa7ooooo003ooooooooo
oooo4Oooool00?oooooooooooolAooooo`00oooooooooooooa7ooooo003ooooooooooooo4Oooool0
0?oooooooooooolAooooo`00oooooooooooooa7ooooo003ooooooooooooo4Oooool00?oooooooooo
oolAooooo`00oooooooooooooa7ooooo003ooooooooooooo4Oooool001gooooo0_l000000ooooooo
0000o`000002ooooo`;o00002Oooool2o`000003ooooool0003o000000;ooooo0ol00004ooooo`;o
00002Oooool2o`000003ooooool0003o000000;ooooo0ol0000<ooooo`;o000000Coooooo`000?l0
003ooooo1Ol0000:ooooo`;o000000?oooooo`000?l000000_ooool3o`0000cooooo0_l000000ooo
oooo0000o`000003ooooo`?o00002_ooool2o`000003ooooool0003o000000;ooooo0ol0000<oooo
o`;o000000?oooooo`000?l000000_ooool3o`0000_ooooo0_l000000ooooooo0000o`000002oooo
o`?o00003?ooool2o`000003ooooool0003o000000?ooooo00?o0000ooooooooool0oooooolVoooo
o`007_ooool00ol0003oooooo`000005ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooool0
00001?ooool00ol0003oooooooooo`02ooooo`04o`000?ooooooooooo`0000Wooooo00?o0000oooo
ool000000_ooool01Ol0003ooooooooooooooooo000000cooooo00?o0000ooooool000000oooool0
1?l0003oooooooooool0000;ooooo`03o`000?oooooo000000;ooooo00Go0000oooooooooooooooo
o`00000<ooooo`03o`000?oooooo000000Gooooo00?o0000ooooooooool02_ooool00ol0003ooooo
o`000002ooooo`05o`000?ooooooooooooooool000003?ooool00ol0003oooooo`000002ooooo`05
o`000?ooooooooooooooool000002oooool00ol0003oooooo`000004ooooo`03o`000?oooooooooo
00cooooo00?o0000ooooool000001?ooool00ol0003oooooooooo`3oooooobKooooo000Oooooo`03
o`000?oooooooooo00Gooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`03ooooo`03
o`000?oooooooooo00;ooooo00Co0000oooooooooooo00002_ooool01Ol0003ooooooooooooooooo
000000?ooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`03ooooo`03o`000?oooooo
oooo00cooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`0;ooooo`04o`000?oooooo
ooooooooo`Go00003?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00_ooooo00Go
0000ooooooooooooooooo`000003ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool0
0oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0
oooooolUooooo`007_ooool00ol0003oooooo`000003ooooo`Co00002?ooool00ol0003oooooo`00
0004ooooo`03o`000?oooooooooo00;ooooo00Co0000oooooooooooo00002Oooool00ol0003ooooo
o`000003ooooo`?o00003Oooool00ol0003oooooo`000005ooooo`03o`000?oooooooooo00[ooooo
00?o0000ooooool000001?ooool2o`0000gooooo00?o0000ooooool000000_ooool01?l0003ooooo
ooooool0000<ooooo`03o`000?oooooo000000Kooooo00?o0000ooooooooool02_ooool00ol0003o
ooooo`000002ooooo`Co00003?ooool00ol0003oooooo`000004ooooo`03o`000?oooooooooo00co
oooo00?o0000ooooool000001Oooool00ol0003oooooooooo`3oooooobGooooo000Mooooo`;o0000
00Goooooo`000?l0003oooooo`000003ooooo`03o`000?oooooooooo00Gooooo0_l000000ooooooo
0000o`000003ooooo`03o`000?oooooooooo00;ooooo00Co0000oooooooooooo00002?ooool2o`00
0005ooooool0003o0000ooooool000000oooool00ol0003oooooooooo`09ooooo`;o000000Gooooo
o`000?l0003oooooo`000003ooooo`03o`000?oooooooooo00Sooooo0_l000000ooooooo0000o`00
0005ooooo`03o`000?oooooooooo00Wooooo0_l000000ooooooo0000o`000002ooooo`03o`000?oo
oooo000000_ooooo0_l000001?oooooo0000o`000?ooool4o`0000cooooo0_l000001Ooooooo0000
o`000?oooooo000000kooooo0_l000000ooooooo0000o`000003ooooo`03o`000?oooooooooo00_o
oooo0_l000000ooooooo0000o`000005ooooo`03o`000?oooooooooo0?oooooo9?ooool002?ooooo
00Go0000ooooooooooooooooo`00000>ooooo`?o00000oooool01?l0003oooooooooool0000>oooo
o`05o`000?ooooooooooooooool000004Oooool01Ol0003ooooooooooooooooo0000013ooooo00Go
0000ooooooooooooooooo`00000Aooooo`04o`000?oooooo0000o`00017ooooo00?o0000oooooooo
ool04oooool2o`0001?ooooo0ol0000Cooooo`05o`000?ooooooooooooooool00000>?ooool2o`00
0003ooooool0003o000000;ooooo0ol0000;ooooo`;o000000Coooooo`000?l0003ooooo1Ol0000;
ooooo`;o000000?oooooo`000?l000000_ooool3o`0000cooooo0_l000000ooooooo0000o`000003
ooooo`?o00002_ooool2o`000003ooooool0003o000000;ooooo0ol0000<ooooo`;o000000?ooooo
o`000?l000000_ooool3o`0000_ooooo0_l000000ooooooo0000o`000003ooooo`03o`000?oooooo
oooo00_ooooo0_l000000ooooooo0000o`000002ooooo`?o00003?ooool2o`000003ooooool0003o
000000;ooooo0_l00009ooooo`;o000000?oooooo`000?l000000_ooool3o`0000Cooooo0_l0000N
ooooo`008oooool4o`00013ooooo0_l00004ooooo`;o00003oooool4o`0001;ooooo1?l0000Aoooo
o`Co00004_ooool01?l0003oooooooooool0000Aooooo`Go00004Oooool01?l0003oooooo`000?l0
000Aooooo`03o`000?oooooo000001?ooooo1Ol0000iooooo`03o`000?oooooo000000Cooooo00?o
0000ooooooooool02oooool00ol0003oooooo`000003ooooo`04o`000?ooooooooooo`0000cooooo
00?o0000ooooool000000_ooool01Ol0003ooooooooooooooooo000000cooooo00?o0000ooooool0
00001Oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooo000000;ooooo00Go0000oooooooo
ooooooooo`00000<ooooo`03o`000?oooooo000000;ooooo00Go0000ooooooooooooooooo`00000;
ooooo`03o`000?oooooo000000Cooooo00?o0000ooooooooool03?ooool00ol0003oooooo`000002
ooooo`05o`000?ooooooooooooooool000003?ooool00ol0003oooooo`000005ooooo`03o`000?oo
oooooooo00Oooooo00?o0000ooooool000001?ooool00ol0003oooooooooo`02ooooo`04o`000?oo
ooooooooo`0001gooooo000Tooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool05Ooo
ool00ol0003oooooooooo`0Cooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool05Ooo
ool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool05?oo
ool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo03gooooo00?o0000ooooooooool00ooo
ool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool03Ooo
ool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00_ooooo00Co0000oooooooooooooooo
1Ol0000<ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool02oooool01Ol0003ooooo
oooooooooooo000000?ooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`04ooooo`03
o`000?oooooooooo00cooooo00Go0000ooooooooooooooooo`000003ooooo`03o`000?oooooooooo
00_ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo
00?ooooo00?o0000ooooooooool00_ooool01?l0003oooooooooool0000Mooooo`009?ooool00ol0
003oooooooooo`0@ooooo`03o`000?oooooooooo01Gooooo00?o0000ooooooooool04oooool00ol0
003oooooooooo`0@ooooo`03o`000?oooooooooo01Kooooo00?o0000ooooooooool04Oooool00ol0
003oooooooooo`0Aooooo`03o`000?oooooooooo01Cooooo00?o0000ooooooooool04Oooool00ol0
003oooooooooo`0looooo`03o`000?oooooo000000Cooooo00?o0000ooooooooool02oooool00ol0
003oooooo`000005ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooool000001?ooool2o`00
00gooooo00?o0000ooooool000000_ooool01?l0003oooooooooool0000<ooooo`03o`000?oooooo
000000Kooooo00?o0000ooooooooool02_ooool00ol0003oooooo`000002ooooo`Co00003?ooool0
0ol0003oooooo`000005ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooool000000oooool3
o`0000gooooo00?o0000ooooool000000oooool4o`0000Sooooo00?o0000ooooool000001?ooool0
0ol0003oooooooooo`02ooooo`04o`000?ooooooooooo`0001gooooo000Uooooo`03o`000?oooooo
oooo00kooooo00?o0000ooooooooool05oooool00ol0003oooooooooo`0Cooooo`03o`000?oooooo
oooo00kooooo00?o0000ooooooooool06?ooool00ol0003oooooooooo`0Aooooo`03o`000?oooooo
oooo00oooooo00?o0000ooooooooool05_ooool00ol0003oooooooooo`0?ooooo`03o`000?oooooo
oooo03cooooo0_l000000ooooooo0000o`000003ooooo`03o`000?oooooooooo00[ooooo0_l00000
1Ooooooo0000o`000?oooooo000000?ooooo00?o0000ooooooooool02Oooool2o`000003ooooool0
003o000000Gooooo00?o0000ooooooooool02Oooool2o`000003ooooool0003o000000;ooooo00?o
0000ooooool000002oooool2o`000004ooooool0003o0000ooooo`Co00003?ooool2o`000005oooo
ool0003o0000ooooool000003_ooool2o`000003ooooool0003o000000Gooooo00?o0000oooooooo
ool02Oooool2o`000005ooooool0003o0000ooooool000000oooool00ol0003oooooooooo`09oooo
o`;o000000Goooooo`000?l0003oooooo`000003ooooo`03o`000?oooooooooo00Gooooo0_l00000
0ooooooo0000o`000003ooooo`03o`000?oooooooooo00;ooooo00Co0000oooooooooooo00007Ooo
ool002Kooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0Hooooo`03o`000?oooooo
oooo01;ooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0Jooooo`03o`000?oooooo
oooo017ooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0Hooooo`03o`000?oooooo
oooo00gooooo00?o0000ooooooooool0A?ooool2o`0001;ooooo00Go0000ooooooooooooooooo`00
000Aooooo`05o`000?ooooooooooooooool000004oooool2o`00017ooooo00?o0000ooooooooool0
5?ooool00ol0003oooooooooo`0Aooooo`05o`000?ooooooooooooooool000004Oooool01Ol0003o
oooooooooooooooo0000017ooooo00Go0000ooooooooooooooooo`00000>ooooo`;o00001?ooool0
1?l0003oooooooooool0000Mooooo`009_ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooo
oooo01Wooooo00?o0000ooooooooool04oooool00ol0003oooooooooo`0<ooooo`03o`000?oooooo
oooo01[ooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooo
oooo01Sooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`15ooooo`03o`000?oooooo
oooo017ooooo0ol0000Cooooo`?o00005Oooool00ol0003oooooooooo`0?ooooo`Go00004oooool2
o`00017ooooo1Ol0000Booooo`?o00004oooool3o`00013ooooo00?o0000ooooooooool00oooool2
o`0001kooooo000Wooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool06_ooool00ol0
003oooooooooo`0Booooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool07?ooool00ol0
003oooooooooo`0Aooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool06_ooool00ol0
003oooooooooo`0;ooooo`03o`000?oooooooooo04Cooooo00?o0000ooooooooool04_ooool00ol0
003oooooooooo`0Cooooo`03o`000?oooooooooo01?ooooo00?o0000ooooooooool04_ooool00ol0
003oooooooooo`0Cooooo`03o`000?oooooooooo01;ooooo00?o0000ooooooooool04oooool00ol0
003oooooooooo`0Cooooo`03o`000?oooooooooo01;ooooo00?o0000ooooooooool08_ooool002Oo
oooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`0Kooooo`03o`000?oooooooooo01?o
oooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`0Mooooo`03o`000?oooooooooo013o
oooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0Jooooo`03o`000?oooooooooo00_o
oooo00?o0000ooooooooool0A?ooool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo01?o
oooo00?o0000ooooooooool04oooool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo01?o
oooo00?o0000ooooooooool04_ooool00ol0003oooooooooo`0Cooooo`03o`000?oooooooooo01?o
oooo00?o0000ooooooooool04_ooool00ol0003oooooooooo`0Rooooo`00:?ooool00ol0003ooooo
ooooo`09ooooo`03o`000?oooooooooo01cooooo00?o0000ooooooooool04_ooool00ol0003ooooo
ooooo`09ooooo`03o`000?oooooooooo01oooooo00?o0000ooooooooool04?ooool00ol0003ooooo
ooooo`09ooooo`03o`000?oooooooooo01cooooo00?o0000ooooooooool02Oooool00ol0003ooooo
ooooo`16ooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool05Oooool00ol0003ooooo
ooooo`0Cooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool05?ooool00ol0003ooooo
ooooo`0Cooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool05Oooool00ol0003ooooo
ooooo`0@ooooo`03o`000?oooooooooo02?ooooo000Yooooo`03o`000?oooooooooo00Oooooo00?o
0000ooooooooool07_ooool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo00Oooooo00?o
0000ooooooooool08?ooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo00Oooooo00?o
0000ooooooooool07_ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo04Oooooo00?o
0000ooooooooool04?ooool00ol0003oooooooooo`0Eooooo`03o`000?oooooooooo01?ooooo00?o
0000ooooooooool04?ooool00ol0003oooooooooo`0Dooooo`03o`000?oooooooooo01?ooooo00?o
0000ooooooooool04Oooool00ol0003oooooooooo`0Eooooo`03o`000?oooooooooo013ooooo00?o
0000ooooooooool08oooool002Wooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`0O
ooooo`03o`000?oooooooooo01?ooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`0Q
ooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`0N
ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0B?ooool00ol0003oooooooooo`0?
ooooo`03o`000?oooooooooo01Kooooo00?o0000ooooooooool04_ooool00ol0003oooooooooo`0?
ooooo`03o`000?oooooooooo01Kooooo00?o0000ooooooooool04oooool00ol0003oooooooooo`0?
ooooo`03o`000?oooooooooo01Kooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`0T
ooooo`00:_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo023ooooo00?o0000oooo
ooooool04_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo02?ooooo00?o0000oooo
ooooool04?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo023ooooo00?o0000oooo
ooooool01Oooool00ol0003oooooooooo`19ooooo`03o`000?oooooooooo00kooooo00?o0000oooo
ooooool05oooool00ol0003oooooooooo`0Cooooo`03o`000?oooooooooo00kooooo00?o0000oooo
ooooool05_ooool00ol0003oooooooooo`0Cooooo`03o`000?oooooooooo00oooooo00?o0000oooo
ooooool05oooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo02Cooooo000Zooooo`03
o`000?oooooooooo00Cooooo00?o0000ooooooooool08Oooool00ol0003oooooooooo`0Cooooo`03
o`000?oooooooooo00Cooooo00?o0000ooooooooool09?ooool00ol0003oooooooooo`0?ooooo`03
o`000?oooooooooo00Gooooo00?o0000ooooooooool08?ooool00ol0003oooooooooo`05ooooo`03
o`000?oooooooooo04[ooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0Hooooo`03
o`000?oooooooooo01;ooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0Gooooo`03
o`000?oooooooooo01Cooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0Hooooo`03
o`000?oooooooooo00gooooo00?o0000ooooooooool09Oooool002_ooooo00?o0000ooooooooool0
0oooool00ol0003oooooooooo`0Rooooo`03o`000?oooooooooo01;ooooo00?o0000ooooooooool0
0oooool00ol0003oooooooooo`0Vooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool0
0oooool00ol0003oooooooooo`0Rooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0
Boooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo01Wooooo00?o0000ooooooooool0
4oooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo01Oooooo00?o0000ooooooooool0
5?ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo01Wooooo00?o0000ooooooooool0
3?ooool00ol0003oooooooooo`0Uooooo`00:oooool00ol0003oooooooooo`02ooooo`03o`000?oo
oooooooo02Cooooo00?o0000ooooooooool04_ooool00ol0003oooooooooo`02ooooo`03o`000?oo
oooooooo02Kooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`03ooooo`03o`000?oo
oooooooo02;ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`1;ooooo`03o`000?oo
oooooooo00cooooo00?o0000ooooooooool06Oooool00ol0003oooooooooo`0Cooooo`03o`000?oo
oooooooo00cooooo00?o0000ooooooooool05oooool00ol0003oooooooooo`0Dooooo`03o`000?oo
oooooooo00gooooo00?o0000ooooooooool06Oooool00ol0003oooooooooo`0<ooooo`03o`000?oo
oooooooo02Gooooo000/ooooo`05o`000?ooooooooooooooool000009_ooool00ol0003ooooooooo
o`0Booooo`05o`000?ooooooooooooooool00000:_ooool00ol0003oooooooooo`0?ooooo`05o`00
0?ooooooooooooooool000009_ooool01Ol0003ooooooooooooooooo000004oooooo00?o0000oooo
ooooool02_ooool00ol0003oooooooooo`0Kooooo`03o`000?oooooooooo01?ooooo00?o0000oooo
ooooool02_ooool00ol0003oooooooooo`0Hooooo`03o`000?oooooooooo01Gooooo00?o0000oooo
ooooool02oooool00ol0003oooooooooo`0Kooooo`03o`000?oooooooooo00[ooooo00?o0000oooo
ooooool09_ooool002gooooo00?o0000ooooool00000:?ooool00ol0003oooooooooo`0Booooo`03
o`000?oooooo000002cooooo00?o0000ooooooooool03oooool00ol0003oooooo`00000Xooooo`03
o`000?oooooo0000053ooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`0Kooooo`03
o`000?oooooooooo01?ooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`0Hooooo`03
o`000?oooooooooo01Gooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0Kooooo`03
o`000?oooooooooo00[ooooo00?o0000ooooooooool09_ooool002gooooo00?o0000ooooool00000
:?ooool00ol0003oooooooooo`0Booooo`03o`000?oooooo000002gooooo00?o0000ooooooooool0
3_ooool00ol0003oooooo`00000Xooooo`03o`000?oooooo0000057ooooo00?o0000ooooooooool0
2Oooool00ol0003oooooooooo`0Looooo`03o`000?oooooooooo01;ooooo00?o0000ooooooooool0
2Oooool00ol0003oooooooooo`0Jooooo`03o`000?oooooooooo01Gooooo00?o0000ooooooooool0
2Oooool00ol0003oooooooooo`0Looooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool0
9oooool002kooooo0_l0000Yooooo`03o`000?oooooooooo01;ooooo00?o0000ooooooooool0;?oo
ool00ol0003oooooooooo`0?ooooo`;o0000:?ooool2o`0005;ooooo00?o0000ooooooooool02?oo
ool00ol0003oooooooooo`0Mooooo`03o`000?oooooooooo01?ooooo00?o0000ooooooooool02?oo
ool00ol0003oooooooooo`0Jooooo`03o`000?oooooooooo01Gooooo00?o0000ooooooooool02Ooo
ool00ol0003oooooooooo`0Mooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool09ooo
ool002Oooooo0ol00006ooooo`03o`000?oooooooooo02Oooooo00?o0000ooooooooool02_ooool5
o`0000;ooooo00?o0000ooooooooool0;Oooool00ol0003oooooooooo`08ooooo`?o00001Oooool0
0ol0003oooooooooo`0Qooooo`Co0000EOooool00ol0003oooooooooo`07ooooo`03o`000?oooooo
oooo01kooooo00?o0000ooooooooool04_ooool00ol0003oooooooooo`07ooooo`03o`000?oooooo
oooo01_ooooo00?o0000ooooooooool05_ooool00ol0003oooooooooo`07ooooo`03o`000?oooooo
oooo01kooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`0Xooooo`009_ooool01Ol0
003ooooooooooooooooo000000Kooooo00?o0000ooooooooool09_ooool00ol0003oooooooooo`0;
ooooo`06o`000?ooooooooooo`000?oooooo0000<Oooool00ol0003oooooooooo`08ooooo`03o`00
0?oooooooooo00Gooooo00?o0000ooooooooool08Oooool2o`0005Kooooo00?o0000ooooooooool0
1_ooool00ol0003oooooooooo`0Oooooo`03o`000?oooooooooo01?ooooo00?o0000ooooooooool0
1_ooool00ol0003oooooooooo`0Kooooo`03o`000?oooooooooo01Kooooo00?o0000ooooooooool0
1oooool00ol0003oooooooooo`0Oooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0
:?ooool002Kooooo00Go0000ooooooooooooooooo`000007ooooo`03o`000?oooooooooo02Kooooo
00?o0000ooooooooool02oooool01Ol0003ooooooooooooooooo000003;ooooo00?o0000oooooooo
ool01oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo01gooooo1Ol0001Gooooo`03
o`000?oooooooooo00Gooooo00?o0000ooooooooool08?ooool00ol0003oooooooooo`0Booooo`03
o`000?oooooooooo00Gooooo00?o0000ooooooooool07?ooool00ol0003oooooooooo`0Gooooo`03
o`000?oooooooooo00Gooooo00?o0000ooooooooool08?ooool00ol0003oooooooooo`05ooooo`03
o`000?oooooooooo02Wooooo000Vooooo`Co00002Oooool00ol0003oooooooooo`0Uooooo`03o`00
0?oooooooooo00cooooo00?o0000ooooool00000=?ooool00ol0003oooooooooo`06ooooo`03o`00
0?oooooooooo00Oooooo0_l0000Mooooo`04o`000?oooooo0000o`0005Sooooo00?o0000oooooooo
ool01Oooool00ol0003oooooooooo`0Pooooo`03o`000?oooooooooo01;ooooo00?o0000oooooooo
ool01Oooool00ol0003oooooooooo`0Looooo`03o`000?oooooooooo01Oooooo00?o0000oooooooo
ool01Oooool00ol0003oooooooooo`0Pooooo`03o`000?oooooooooo00Gooooo00?o0000oooooooo
ool0:Oooool002Kooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0Uooooo`03o`00
0?oooooooooo00Sooooo00Go0000ooooooooooooooooo`00000eooooo`03o`000?oooooooooo00Ko
oooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`0Kooooo`03o`000?oooooo000005Wo
oooo00?o0000ooooooooool00oooool00ol0003oooooooooo`0Rooooo`03o`000?oooooooooo01;o
oooo00?o0000ooooooooool00oooool00ol0003oooooooooo`0Mooooo`03o`000?oooooooooo01So
oooo00?o0000ooooooooool00oooool00ol0003oooooooooo`0Rooooo`03o`000?oooooooooo00?o
oooo00?o0000ooooooooool0:_ooool002Oooooo00?o0000ooooooooool02oooool2o`0002Kooooo
00?o0000ooooooooool01oooool01Ol0003ooooooooooooooooo000003Kooooo00?o0000oooooooo
ool01?ooool2o`0000cooooo00?o0000ooooooooool06?ooool2o`000003ooooool0003o000005Wo
oooo00?o0000ooooooooool00oooool00ol0003oooooooooo`0Rooooo`03o`000?oooooooooo01;o
oooo00?o0000ooooooooool00oooool00ol0003oooooooooo`0Nooooo`03o`000?oooooooooo01Oo
oooo00?o0000ooooooooool00oooool00ol0003oooooooooo`0Rooooo`03o`000?oooooooooo00?o
oooo00?o0000ooooooooool0:_ooool002Sooooo0_l0000=ooooo`03o`000?oooooooooo02?ooooo
00?o0000ooooooooool02?ooool3o`0003Sooooo00?o0000ooooooooool01?ooool00ol0003ooooo
ooooo`0;ooooo`03o`000?oooooooooo01Kooooo00?o0000ooooooooool00_ooool00ol0003ooooo
ooooo`1Gooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool08oooool00ol0003ooooo
ooooo`0Cooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool07_ooool00ol0003ooooo
ooooo`0Gooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool08oooool00ol0003ooooo
ooooo`02ooooo`03o`000?oooooooooo02[ooooo000hooooo`03o`000?oooooooooo02?ooooo00?o
0000ooooooooool02Oooool00ol0003oooooooooo`0gooooo`03o`000?oooooooooo01;ooooo00?o
0000ooooooooool05?ooool00ol0003oooooooooo`1Nooooo`05o`000?ooooooooooooooool00000
9_ooool00ol0003oooooooooo`0Booooo`05o`000?ooooooooooooooool000008Oooool00ol0003o
ooooooooo`0Hooooo`05o`000?ooooooooooooooool000009_ooool01Ol0003ooooooooooooooooo
000002gooooo000iooooo`03o`000?oooooooooo02;ooooo00?o0000ooooooooool02?ooool00ol0
003oooooooooo`0iooooo`03o`000?oooooooooo01;ooooo0_l0000Cooooo`03o`000?oooooooooo
05oooooo00Co0000oooooooooooo00009oooool00ol0003oooooooooo`0Cooooo`04o`000?oooooo
ooooo`00027ooooo00?o0000ooooooooool06?ooool01Ol0003ooooooooooooooooo000002Oooooo
00Co0000oooooooooooo0000;Oooool003[ooooo00?o0000ooooooooool08_ooool00ol0003ooooo
ooooo`07ooooo`03o`000?oooooooooo03Wooooo00?o0000ooooooooool05?ooool00ol0003ooooo
ooooo`0?ooooo`03o`000?oooooooooo067ooooo00?o0000ooooool00000:?ooool00ol0003ooooo
ooooo`0Booooo`03o`000?oooooo000002;ooooo00?o0000ooooooooool06Oooool00ol0003ooooo
o`00000Xooooo`03o`000?oooooo000002kooooo000kooooo`;o00008oooool00ol0003ooooooooo
o`05ooooo`03o`000?oooooooooo03_ooooo00?o0000ooooooooool05?ooool00ol0003ooooooooo
o`0=ooooo`03o`000?oooooooooo06;ooooo00?o0000ooooool00000:?ooool00ol0003ooooooooo
o`0Booooo`03o`000?oooooo000002;ooooo00?o0000ooooooooool06Oooool00ol0003oooooo`00
000Xooooo`03o`000?oooooo000002kooooo000mooooo`03o`000?oooooooooo023ooooo00?o0000
ooooooooool01Oooool00ol0003oooooooooo`0looooo`03o`000?oooooooooo01Cooooo00?o0000
ooooooooool02_ooool2o`0006Kooooo0_l0000Yooooo`03o`000?oooooooooo01;ooooo00?o0000
ooooooooool08_ooool00ol0003oooooooooo`0Iooooo`03o`000?oooooooooo02Oooooo0_l0000_
ooooo`00?_ooool00ol0003oooooooooo`0Pooooo`03o`000?oooooooooo00?ooooo00?o0000oooo
ooooool0?_ooool00ol0003oooooooooo`0Dooooo`;o00002Oooool00ol0003oooooooooo`1Xoooo
o`03o`000?oooooooooo02Kooooo00?o0000ooooooooool04_ooool00ol0003oooooooooo`0Roooo
o`03o`000?oooooooooo01Wooooo00?o0000ooooooooool09_ooool00ol0003oooooooooo`0_oooo
o`00?oooool00ol0003oooooooooo`0Oooooo`03o`000?oooooooooo00;ooooo00?o0000oooooooo
ool0?oooool00ol0003oooooooooo`0Fooooo`03o`000?oooooooooo00Gooooo00?o0000oooooooo
ool0Goooool5o`0000Kooooo00?o0000ooooooooool09_ooool00ol0003oooooooooo`0<ooooo`?o
000000?oooooo`000?ooool09?ooool00ol0003oooooooooo`0Cooooo`?o00000_ooool00ol0003o
ooooooooo`0Tooooo`03o`000?oooooo000003;ooooo0010ooooo`03o`000?oooooooooo01oooooo
00Go0000ooooooooooooooooo`000012ooooo`03o`000?oooooooooo01Kooooo00?o0000oooooooo
ool00oooool00ol0003oooooooooo`1Qooooo`04o`000?ooooooooooo`0000Oooooo00?o0000oooo
ooooool09Oooool00ol0003oooooooooo`0=ooooo`04o`000?ooooooooooo`0002Gooooo00?o0000
ooooooooool04_ooool01ol0003ooooooooooooooooo0000ooooool000009_ooool2o`0003?ooooo
0011ooooo`03o`000?oooooooooo01oooooo00?o0000ooooool00000A?ooool00ol0003ooooooooo
o`0Fooooo`05o`000?ooooooooooooooool00000IOooool00ol0003oooooooooo`08ooooo`03o`00
0?oooooooooo02Gooooo00?o0000ooooooooool02Oooool5o`000003ooooool0003ooooo02Cooooo
00?o0000ooooooooool04_ooool01?l0003oooooooooooooool2o`0002Kooooo00?o0000ooooool0
0000<oooool004;ooooo0_l0000Oooooo`03o`000?oooooo000004Gooooo00?o0000ooooooooool0
5_ooool00ol0003oooooo`00001Wooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool0
9?ooool00ol0003oooooooooo`09ooooo`06o`000?ooooooooooo`000?oooooo00009_ooool00ol0
003oooooooooo`0Booooo`Co000000?oooooo`000?ooool09?ooool01?l0003oooooooooool0000c
ooooo`00A?ooool00ol0003oooooooooo`0Mooooo`;o0000A_ooool00ol0003oooooooooo`0Foooo
o`03o`000?oooooooooo06?ooooo00Go0000ooooooooooooooooo`00000:ooooo`;o00009Oooool0
0ol0003oooooooooo`09ooooo`05o`000?oooooo0000ooooool000009_ooool00ol0003ooooooooo
o`0Booooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool08_ooool00ol0003ooooooooo
o`02ooooo`03o`000?oooooooooo033ooooo0015ooooo`03o`000?oooooooooo01Gooooo0ol00006
ooooo`03o`000?oooooooooo04?ooooo00?o0000ooooooooool03oooool3o`0000Cooooo00?o0000
ooooooooool0Hoooool01Ol0003ooooooooooooooooo000000cooooo00?o0000ooooooooool08_oo
ool00ol0003oooooooooo`0:ooooo`?o0000:?ooool00ol0003oooooooooo`0Booooo`04o`000?oo
ooooooooo`0002?ooooo0_l000000ooooooo0000ooooo`02ooooo`03o`000?oooooooooo033ooooo
0016ooooo`03o`000?oooooooooo01?ooooo00Go0000ooooooooooooooooo`000006ooooo`;o0000
A?ooool00ol0003oooooooooo`0=ooooo`05o`000?ooooooooooooooool000000_ooool00ol0003o
ooooooooo`1Uooooo`?o00003_ooool00ol0003oooooooooo`0Qooooo`03o`000?oooooooooo00_o
oooo0_l0000Xooooo`03o`000?oooooooooo01?ooooo0ol0000Rooooo`04o`000?oooooooooooooo
o`Go0000<_ooool004Oooooo00?o0000ooooooooool05_ooool00ol0003oooooooooo`06ooooo`03
o`000?oooooooooo04;ooooo00?o0000ooooooooool04?ooool00ol0003oooooo`00001jooooo`03
o`000?oooooooooo027ooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`0Wooooo`03
o`000?oooooooooo01Cooooo00?o0000ooooooooool08?ooool00ol0003oooooooooo`0iooooo`00
B?ooool2o`0001Cooooo0_l0000:ooooo`03o`000?oooooooooo04;ooooo00?o0000ooooooooool0
3oooool00ol0003oooooo`00001kooooo`03o`000?oooooooooo023ooooo00?o0000ooooooooool0
2_ooool00ol0003oooooooooo`0Wooooo`03o`000?oooooooooo01Cooooo00?o0000ooooooooool0
7_ooool2o`0003cooooo001:ooooo`03o`000?oooooooooo01?ooooo00?o0000ooooooooool02?oo
ool2o`0004;ooooo00?o0000ooooooooool02oooool4o`000003ooooool0003ooooo07cooooo0_l0
000Qooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool09oooool00ol0003ooooooooo
o`0Cooooo`03o`000?oooooooooo01kooooo00?o0000ooooooooool0??ooool004_ooooo00?o0000
ooooooooool03_ooool01Ol0003ooooooooooooooooo000000cooooo00?o0000ooooooooool0@?oo
ool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0OOoo
ool00ol0003oooooooooo`0Nooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool0:?oo
ool00ol0003oooooooooo`0Cooooo`03o`000?oooooooooo01gooooo00?o0000ooooooooool0?Ooo
ool004cooooo00?o0000ooooooooool03_ooool3o`0000kooooo0_l00011ooooo`03o`000?oooooo
oooo00Wooooo1Ol00021ooooo`03o`000?oooooooooo01kooooo00?o0000ooooooooool01oooool0
0ol0003oooooooooo`0Yooooo`03o`000?oooooooooo01;ooooo00?o0000ooooooooool06oooool2
o`00043ooooo001=ooooo`03o`000?oooooooooo023ooooo00?o0000ooooooooool0?oooool00ol0
003oooooooooo`0;ooooo`03o`000?oooooooooo087ooooo00?o0000ooooooooool07Oooool00ol0
003oooooooooo`06ooooo`03o`000?oooooooooo02[ooooo00?o0000ooooooooool04Oooool00ol0
003oooooooooo`0Kooooo`03o`000?oooooooooo043ooooo001>ooooo`03o`000?oooooooooo023o
oooo0_l00010ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool0P_ooool00ol0003o
ooooooooo`0Mooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0:_ooool00ol0003o
ooooooooo`0Aooooo`03o`000?oooooooooo01[ooooo00?o0000ooooooooool0@Oooool004oooooo
0_l0000Rooooo`03o`000?oooooooooo03gooooo00?o0000ooooooooool02Oooool00ol0003ooooo
ooooo`24ooooo`03o`000?oooooooooo01cooooo00?o0000ooooooooool01Oooool00ol0003ooooo
ooooo`0Zooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool06Oooool2o`0004Cooooo
001Aooooo`03o`000?oooooooooo023ooooo00?o0000ooooooooool0?Oooool00ol0003ooooooooo
o`08ooooo`03o`000?oooooooooo08Gooooo0_l0000Mooooo`03o`000?oooooooooo00?ooooo00?o
0000ooooooooool0:oooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo01Sooooo00?o
0000ooooooooool0A?ooool005;ooooo00?o0000ooooooooool08?ooool2o`0003kooooo00?o0000
ooooooooool01_ooool00ol0003oooooooooo`28ooooo`03o`000?oooooooooo01[ooooo00?o0000
ooooooooool00oooool00ol0003oooooooooo`0[ooooo`03o`000?oooooooooo00oooooo00?o0000
ooooooooool06?ooool00ol0003oooooooooo`15ooooo`00Doooool00ol0003oooooooooo`0Qoooo
o`03o`000?oooooooooo03cooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`2:oooo
o`03o`000?oooooooooo01Wooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`0/oooo
o`03o`000?oooooooooo00oooooo00?o0000ooooooooool05oooool00ol0003oooooooooo`16oooo
o`00E?ooool00ol0003oooooooooo`0Qooooo`;o0000??ooool00ol0003oooooooooo`04ooooo`03
o`000?oooooooooo08_ooooo00?o0000ooooooooool06Oooool01Ol0003ooooooooooooooooo0000
02oooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`0Eooooo`;o0000BOooool005Go
oooo00?o0000ooooooooool08_ooool00ol0003oooooooooo`0jooooo`03o`000?oooooooooo00;o
oooo00?o0000ooooooooool0SOooool00ol0003oooooooooo`0Hooooo`04o`000?ooooooooooo`00
033ooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0Eooooo`03o`000?oooooooooo
04Wooooo001Fooooo`;o00008oooool2o`0003_ooooo00Go0000ooooooooooooooooo`00002@oooo
o`;o00006Oooool00ol0003oooooo`00000`ooooo`03o`000?oooooooooo00gooooo00?o0000oooo
ooooool05?ooool00ol0003oooooooooo`1:ooooo`00F?ooool00ol0003oooooooooo`0Rooooo`03
o`000?oooooooooo03Wooooo00?o0000ooooool00000Toooool00ol0003oooooooooo`0Fooooo`03
o`000?oooooo0000033ooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0Cooooo`;o
0000COooool005Wooooo00?o0000ooooooooool08_ooool2o`0003Wooooo0_l0002Eooooo`03o`00
0?oooooooooo01Kooooo0_l0000`ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool0
4_ooool00ol0003oooooooooo`1=ooooo`00F_ooool00ol0003oooooooooo`0Sooooo`03o`000?oo
oooooooo03Cooooo0_l0002Hooooo`03o`000?oooooooooo01Oooooo0_l0000^ooooo`03o`000?oo
oooooooo00_ooooo00?o0000ooooooooool04_ooool00ol0003oooooooooo`1>ooooo`00Foooool0
0ol0003oooooooooo`0Sooooo`03o`000?oooooooooo037ooooo0_l0002Kooooo`03o`000?oooooo
oooo01Sooooo0_l0000/ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool04?ooool2
o`00057ooooo001Looooo`;o00009?ooool2o`00033ooooo0_l0002Mooooo`03o`000?oooooooooo
00cooooo0ol0000:ooooo`?o0000:_ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo
00oooooo00?o0000ooooooooool0DOooool005kooooo00?o0000ooooooooool08oooool00ol0003o
ooooooooo`0[ooooo`;o00000_ooool00ol0003oooooooooo`2Kooooo`;o00002oooool01Ol0003o
oooooooooooooooo000000cooooo0_l0000Xooooo`03o`000?oooooooooo00Wooooo00?o0000oooo
ooooool03oooool00ol0003oooooooooo`1Booooo`00Goooool00ol0003oooooooooo`0Sooooo`;o
0000:Oooool2o`0000Cooooo00?o0000ooooooooool0WOooool00ol0003oooooooooo`0<ooooo`03
o`000?oooooooooo00cooooo0_l0000Vooooo`03o`000?oooooooooo00Wooooo00?o0000oooooooo
ool03Oooool2o`0005Gooooo001Pooooo`03o`000?oooooooooo02Cooooo00?o0000ooooooooool0
9Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo09gooooo00?o0000ooooooooool0
2Oooool2o`00017ooooo0_l0000Tooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool0
3Oooool00ol0003oooooooooo`1Eooooo`00HOooool00ol0003oooooooooo`0Tooooo`;o00008ooo
ool2o`0000Cooooo00Go0000ooooooooooooooooo`00002Pooooo`03o`000?oooooooooo00[ooooo
00?o0000ooooooooool04?ooool2o`0002;ooooo00?o0000ooooooooool02?ooool00ol0003ooooo
ooooo`0<ooooo`03o`000?oooooooooo05Kooooo001Rooooo`03o`000?oooooooooo02Gooooo00?o
0000ooooooooool07_ooool2o`0000Kooooo1Ol0002Qooooo`03o`000?oooooooooo00Gooooo00Go
0000ooooooooooooooooo`00000Dooooo`;o00008?ooool00ol0003oooooooooo`07ooooo`03o`00
0?oooooooooo00cooooo00?o0000ooooooooool0Eoooool006?ooooo0_l0000Vooooo`03o`000?oo
oooooooo01_ooooo0_l0002_ooooo`03o`000?oooooooooo00Gooooo0ol0000Gooooo`?o00007_oo
ool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00[ooooo0_l0001Jooooo`00IOooool0
0ol0003oooooooooo`0Tooooo`;o00006_ooool00ol0003oooooooooo`2`ooooo`;o00008_ooool2
o`0001cooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`09ooooo`03o`000?oooooo
oooo05[ooooo001Vooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool05Oooool2o`00
0;Gooooo00?o0000ooooooooool08Oooool2o`0001[ooooo00?o0000ooooooooool01Oooool00ol0
003oooooooooo`09ooooo`03o`000?oooooooooo05_ooooo001Wooooo`03o`000?oooooooooo02Go
oooo0_l0000Cooooo`;o0000^?ooool00ol0003oooooooooo`0Rooooo`;o00006?ooool00ol0003o
ooooooooo`05ooooo`03o`000?oooooooooo00Oooooo0_l0001Nooooo`00J?ooool00ol0003ooooo
ooooo`0Vooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool0^Oooool00ol0003ooooo
ooooo`0Sooooo`;o00005_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Oooooo
00?o0000ooooooooool0G_ooool006Wooooo00?o0000ooooooooool09_ooool2o`0000gooooo0_l0
002mooooo`03o`000?oooooooooo02Cooooo0_l0000Dooooo`03o`000?oooooooooo00Cooooo00?o
0000ooooooooool01_ooool00ol0003oooooooooo`1Oooooo`00J_ooool2o`0002Sooooo00?o0000
ooooooooool02?ooool2o`000<3ooooo0_l0000Vooooo`;o00004_ooool00ol0003oooooooooo`03
ooooo`03o`000?oooooooooo00Gooooo0_l0001Rooooo`00K?ooool00ol0003oooooooooo`0Voooo
o`03o`000?oooooooooo00Gooooo0_l00034ooooo`03o`000?oooooooooo02Gooooo0ol0000@oooo
o`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`1Roooo
o`00KOooool00ol0003oooooooooo`0Vooooo`;o00001?ooool00ol0003oooooooooo`35ooooo`03
o`000?oooooooooo02Oooooo0_l0000>ooooo`03o`000?oooooooooo00;ooooo00?o0000oooooooo
ool00oooool00ol0003oooooooooo`1Sooooo`00K_ooool00ol0003oooooooooo`0Wooooo`04o`00
0?oooooo0000o`000<Wooooo00?o0000ooooooooool0:?ooool2o`0000cooooo00Go0000oooooooo
ooooooooo`000004ooooo`;o0000I_ooool006oooooo00?o0000ooooooooool09_ooool2o`000<co
oooo00?o0000ooooooooool0:Oooool2o`0000[ooooo00Go0000ooooooooooooooooo`000003oooo
o`03o`000?oooooooooo06Kooooo001`ooooo`;o00008Oooool3o`000003ooooool0003ooooo0<ko
oooo00?o0000ooooooooool0:_ooool2o`0000Sooooo00Co0000oooooooooooo00000oooool00ol0
003oooooooooo`1Wooooo`00L_ooool00ol0003oooooooooo`0Mooooo`05o`000?oooooooooooooo
ool00000dOooool2o`0002cooooo0_l00006ooooo`04o`000?ooooooooooo`0000;ooooo00?o0000
ooooooooool0J?ooool007?ooooo00?o0000ooooooooool07?ooool00ol0003oooooooooo`02o`00
0=?ooooo00?o0000ooooooooool0:oooool3o`0000?ooooo00Co0000ooooool0003ooooo0_l0001[
ooooo`00M?ooool00ol0003oooooooooo`0Looooo`?o0000eOooool00ol0003oooooooooo`0]oooo
o`;o00000_ooool3o`0006gooooo001eooooo`03o`000?oooooooooo01[ooooo0_l00002ooooo`03
o`000?oooooooooo0=?ooooo00?o0000ooooooooool0;_ooool4o`0006kooooo001fooooo`03o`00
0?oooooooooo01Sooooo0_l00003ooooo`03o`000?oooooooooo0=Cooooo00?o0000ooooooooool0
;oooool00ol0003oooooooooo`1]ooooo`00Moooool2o`0001Oooooo00?o0000ooooooooool00ol0
003Hooooo`03o`000?oooooooooo02kooooo00?o0000ooooooooool0KOooool007Wooooo00?o0000
ooooooooool04oooool00ol0003oooooooooo`3Mooooo`;o00009oooool3o`0000?ooooo00?o0000
ooooooooool0K_ooool007[ooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`3Poooo
o`03o`000?oooooooooo02?ooooo00Oo0000ooooooooooooooooo`000?oooooo0000077ooooo001k
ooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool0h_ooool00ol0003oooooooooo`0V
ooooo`;o0000L_ooool007cooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`3Toooo
o`03o`000?oooooooooo02Gooooo00?o0000ooooooooool0LOooool007gooooo0_l0000;ooooo`;o
0000j?ooool00ol0003oooooooooo`0Pooooo`Co0000M?ooool007oooooo00?o0000ooooooooool0
1oooool00ol0003oooooooooo`3Yooooo`;o00008?ooool00ol0003oooooo`00001eooooo`00P?oo
ool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo0>cooooo00?o0000ooooooooool07Ooo
ool5o`0007?ooooo0021ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0k_ooool0
0ol0003oooooooooo`0Looooo`03o`000?oooooooooo07Gooooo0022ooooo`05o`000?oooooooooo
ooooool00000l_ooool00ol0003oooooooooo`0Jooooo`03o`000?oooooooooo07Kooooo0023oooo
o`03o`000?oooooo00000?Cooooo00?o0000ooooooooool06?ooool00ol0003oooooooooo`1goooo
o`00Q?ooool00ol0003oooooooooo`3dooooo`03o`000?oooooooooo01Kooooo00?o0000oooooooo
ool0N?ooool007kooooo0_l00004ooooo`03o`000?oooooooooo0?Gooooo0_l0000Fooooo`03o`00
0?oooooooooo07Sooooo0020ooooo`05o`000?ooooooooooooooool00000nOooool00ol0003ooooo
ooooo`0Booooo`03o`000?oooooooooo07Wooooo0021ooooo`04o`000?ooooooooooo`000?[ooooo
00?o0000ooooooooool04?ooool00ol0003oooooooooo`1jooooo`00O_ooool4o`0000;ooooo00?o
0000ooooooooool0nOooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo07_ooooo001m
ooooo`05o`000?ooooooooooooooool000000_ooool00ol0003oooooooooo`3jooooo`03o`000?oo
oooooooo00cooooo00?o0000ooooooooool0O?ooool007gooooo00Go0000ooooooooooooooooo`00
0002ooooo`03o`000?oooooooooo0?_ooooo0_l0000;ooooo`03o`000?oooooooooo07gooooo001n
ooooo`?o00000oooool00ol0003oooooooooo`3mooooo`03o`000?oooooooooo00Oooooo00?o0000
ooooooooool0O_ooool008Cooooo00?o0000ooooooooool0o_ooool00ol0003oooooooooo`05oooo
o`03o`000?oooooooooo07oooooo0024ooooo`03o`000?oooooooooo0?oooooo00?o0000oooooooo
ool00oooool00ol0003oooooooooo`20ooooo`00Q?ooool00ol0003oooooooooo`3oooooo`7ooooo
00Go0000ooooooooooooooooo`000023ooooo`00Q?ooool00ol0003oooooooooo`3oooooo`;ooooo
00?o0000ooooool00000Q?ooool008Cooooo00?o0000ooooooooool0ooooool3ooooo`03o`000?oo
oooooooo08?ooooo0024ooooo`03o`000?oooooooooo0?ooooooROooool008Cooooo00?o0000oooo
ooooool0oooooon9ooooo`00Q?ooool00ol0003oooooooooo`3looooo`?o0000ROooool008Cooooo
00?o0000ooooooooool0oOooool00ol0003oooooooooo`28ooooo`00Q?ooool00ol0003ooooooooo
o`3mooooo`03o`000?oooooooooo08Sooooo0024ooooo`03o`000?oooooooooo0?gooooo00?o0000
ooooooooool0R?ooool008Cooooo00?o0000ooooooooool0oOooool00ol0003oooooooooo`28oooo
o`00Noooool3o`0000Cooooo0_l0003oooooo`;o0000R_ooool007cooooo00?o0000ooooooooool0
0_ooool01?l0003oooooooooool0003oooooo`03o`000?oooooooooo08Sooooo001looooo`03o`00
0?oooooooooo00;ooooo00Co0000oooooooooooo0000oooooon;ooooo`00O?ooool00ol0003ooooo
ooooo`02ooooo`04o`000?ooooooooooo`000?ooooooRoooool007cooooo00?o0000ooooooooool0
0_ooool01?l0003oooooooooool0003ooooooh_ooooo001kooooo`;o00001?ooool01?l0003ooooo
ooooool0003ooooooh_ooooo001looooo`03o`000?oooooooooo00?ooooo0_l0003oooooohcooooo
003ooooooooooooo4Oooool00?oooooooooooolAooooo`00oooooooooooooa7ooooo003ooooooooo
oooo4Oooool00?oooooooooooolAooooo`00oooooooooooooa7ooooo003ooooooooooooo4Oooool0
0?oooooooooooolAooooo`00oooooooooooooa7ooooo003ooooooooooooo4Oooool00?oooooooooo
oolAooooo`00oooooooooooooa7ooooo003ooooooooooooo4Oooool00?oooooooooooolAooooo`00
\
\>"],
  ImageRangeCache->{{{0, 526}, {154.062, 0}} -> {-0.0550492, -0.0147182, \
0.0040116, 0.0040116}, {{13.6875, 251.125}, {150.375, 3.625}} -> {-1.63418, \
-1.20125, 0.0463284, 0.0545171}, {{274.812, 512.25}, {150.375, 3.625}} -> \
{-13.7317, -1.15094, 0.0463284, 0.0408877}}],

Cell[BoxData[
    \(Node[
      1, {0, {}}, {Node[
          2, {0, {1, 2, 3, 4, 5, 6}}, {Node[
              x1, {0, {1, 2, 3, 4, 5, 6, 13, 14, 15, 16}}, {}], 
            Node[x2, {0, {1, 2, 3, 4, 5, 6, 21, 22, 23}}, {}]}], 
        Node[5, {0, {7, 8, 9, 10, 11, 12}}, {Node[
              3, {0, {7, 8, 9, 10, 11, 12, 17, 18, 19, 20}}, {Node[
                  x3, {0, {7, 8, 9, 10, 11, 12, 17, 18, 19, 20, 24}}, {}], 
                Node[4, {0, {7, 8, 9, 10, 11, 12, 17, 18, 19, 20, 28}}, {Node[
                      x4, {0, {7, 8, 9, 10, 11, 12, 17, 18, 19, 20, 
                          28}}, {}], 
                    Node[x5, {0, {7, 8, 9, 10, 11, 12, 17, 18, 19, 20, 
                          28}}, {}]}]}], 
            Node[x6, {0, {7, 8, 9, 10, 11, 12, 25, 26, 27}}, {}], 
            Node[6, {0, {7, 8, 9, 10, 11, 12, 29, 30, 31}}, {Node[
                  x7, {0, {7, 8, 9, 10, 11, 12, 29, 30, 31}}, {}], 
                Node[x8, {0, {7, 8, 9, 10, 11, 12, 29, 30, 31}}, {}]}], 
            Node[7, {0, {7, 8, 9, 10, 11, 12, 32, 33}}, {Node[
                  x9, {0, {7, 8, 9, 10, 11, 12, 32, 33, 34}}, {}], 
                Node[x10, {0, {7, 8, 9, 10, 11, 12, 32, 
                      33}}, {}]}]}]}]\)], "Output",
  CellLabel->"Out[153]="]
}, Open  ]],

Cell[TextData[{
  "Note: ",
  StyleBox[" The node numbers are arbitrary, and so differ between the \
plots.",
    FontWeight->"Plain"]
}], "Text",
  FontWeight->"Bold"],

Cell["\<\
The genealogy is reconstructed succesfully, except that one node (5 \
in the new numbering) has 4 descendants.  This is because the old nodes 5, 8, \
7 carry the same set of mutations:\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(rg\)], "Input",
  CellLabel->"In[154]:="],

Cell[BoxData[
    \(Node[
      10, {2.119944149759364`, {}}, {Node[
          9, {2.119944149759364`, {}}, {Node[
              6, {0.35627402306150585`, {1, 2, 3, 4, 5, 6}}, {Node[
                  x9, {0, {1, 2, 3, 4, 5, 6, 13, 14, 15, 16}}, {}], 
                Node[x10, {0, {1, 2, 3, 4, 5, 6, 21, 22, 23}}, {}]}], 
            Node[8, {0.8732553053738877`, {7, 8, 9, 10, 11, 12}}, {Node[
                  3, {0.07330684875472837`, {7, 8, 9, 10, 11, 12, 17, 18, 19, 
                      20}}, {Node[
                      x8, {0, {7, 8, 9, 10, 11, 12, 17, 18, 19, 20, 
                          24}}, {}], 
                    Node[2, {0.0344741284830228`, {7, 8, 9, 10, 11, 12, 17, 
                          18, 19, 20, 28}}, {Node[
                          x2, {0, {7, 8, 9, 10, 11, 12, 17, 18, 19, 20, 
                              28}}, {}], 
                        Node[x3, {0, {7, 8, 9, 10, 11, 12, 17, 18, 19, 20, 
                              28}}, {}]}]}], 
                Node[7, {0.6305876052375985`, {7, 8, 9, 10, 11, 12}}, {Node[
                      x4, {0, {7, 8, 9, 10, 11, 12, 25, 26, 27}}, {}], 
                    Node[5, {0.2596284612441885`, {7, 8, 9, 10, 11, 
                          12}}, {Node[
                          1, {0.02712273966825519`, {7, 8, 9, 10, 11, 12, 29, 
                              30, 31}}, {Node[
                              x5, {0, {7, 8, 9, 10, 11, 12, 29, 30, 
                                  31}}, {}], 
                            Node[x6, {0, {7, 8, 9, 10, 11, 12, 29, 30, 
                                  31}}, {}]}], 
                        Node[4, {0.11485080094855135`, {7, 8, 9, 10, 11, 12, 
                              32, 33}}, {Node[
                              x1, {0, {7, 8, 9, 10, 11, 12, 32, 33, 
                                  34}}, {}], 
                            Node[x7, {0, {7, 8, 9, 10, 11, 12, 32, 
                                  33}}, {}]}]}]}]}]}]}]\)], "Output",
  CellLabel->"Out[154]="]
}, Open  ]]
}, Closed]]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Making a sample",
  FontColor->RGBColor[0, 0, 1]]], "SubsectionIcon"],

Cell[CellGroupData[{

Cell[TextData[{
  StyleBox["Q5: ",
    FontColor->RGBColor[0, 0, 1]],
  "What is the mean number of segregating sites?  How does it compare with \
the theoretical expectation?  Use this relation to estimate \[Theta] from \
these data.  How accurate are your estimates?"
}], "SubsubsectionIcon"],

Cell[TextData[{
  "The sample was generated with \[Theta]=10.  We expect the number of \
segregating sites to be \[Mu]\[VeryThinSpace]",
  Cell[BoxData[
      \(TraditionalForm\`E[L]\)]],
  " = ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          FormBox[\(4 \( N\_e\) \[Mu]\),
            "TraditionalForm"], \(\[Sum]\+\(j = 2\)\%k 1\/\(j - 1\)\)}], 
        TraditionalForm]]],
  "~",
  Cell[BoxData[
      \(TraditionalForm\`\[Theta]\ Log[1.78  k]\)]],
  ":"
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \({Mean[numberOfMutationsList], 
        10 \(\[Sum]\+\(j = 2\)\%10 1\/\(j - 1\)\), 
        10\ Log[1.78\[Times]10], \((Mean[numberOfMutationsList] - 10\ \
Log[1.78\[Times]10])\)\/StandardErrorOfSampleMean[numberOfMutationsList]} // 
      N\)], "Input",
  CellLabel->"In[163]:="],

Cell[BoxData[
    \({27.135`, 28.28968253968254`, 
      28.791984572980397`, \(-2.0425111526137414`\)}\)], "Output",
  CellLabel->"Out[163]="]
}, Open  ]],

Cell["\<\
The deviation is marginally significant in this example.  This may \
be chance, or may be because the distribution of number of segregating sites \
is not normal - so a t-test will be over-sensitive.\
\>", "Text"]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData[{
  StyleBox["Q6:",
    FontColor->RGBColor[0, 0, 1]],
  " How does the mean pairwise difference compare with theory?  How variable \
are estimates of \[Theta] based on pairwise divergence, relative to estimates \
based on the number of segregating sites?"
}], "SubsubsectionIcon"],

Cell["\<\
We expect the mean pairwise diffeence to be just \[Theta]. There is \
no significant deviation in this example:\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \({Mean[mpd], 10, \((Mean[mpd] - 10)\)\/StandardErrorOfSampleMean[mpd]} // 
      N\)], "Input",
  CellLabel->"In[164]:="],

Cell[BoxData[
    \({9.552888888888887`, 10.`, \(-1.3051412801569457`\)}\)], "Output",
  CellLabel->"Out[164]="]
}, Open  ]],

Cell[TextData[{
  "Our estimate of \[Theta] based on number of segregating sites is ",
  Cell[BoxData[
      \(TraditionalForm\`\[Theta]\_n = n\_s\/Log[1.78\ k]\)]],
  ".  Our estimate based on pairwise divergence is just ",
  Cell[BoxData[
      \(TraditionalForm\`\[Theta]\_\[Pi] = \[Pi]\)]],
  ".  Based on the simulations, the variance of these estimates is:"
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \({Variance[numberOfMutationsList]\/Log[1.78\[Times]10]\^2, 
        Variance[mpd]} // N\)], "Input",
  CellLabel->"In[168]:="],

Cell[BoxData[
    \({15.877965380479676`, 23.471771499472663`}\)], "Output",
  CellLabel->"Out[168]="]
}, Open  ]],

Cell[TextData[{
  "The number of segregating sites gives a much more accurate estimate.  This \
reflects the lower variance of tree length, relative to pairwise diversity, \
which we saw in Q2.  (Recall that the variance of tree length, relative to \
its mean, tends to zero for large ",
  Cell[BoxData[
      \(TraditionalForm\`k\)]],
  ", whereas pairwise divergence tends to a definite limit)."
}], "Text"]
}, Closed]],

Cell["Recombination", "Subsubsection"],

Cell[CellGroupData[{

Cell[TextData[{
  StyleBox["Q7: ",
    FontColor->RGBColor[0, 0, 1]],
  "How does the number of ancestral lineages depend on the length of the \
genome? (You can look at both the total number, and the number that actually \
carry material)"
}], "SubsubsectionIcon"],

Cell[TextData[{
  "This generates a random ancestral graph going back Tmax time units (i.e. \
",
  Cell[BoxData[
      \(TraditionalForm\`\(\(20  N\_e\ generations\)\()\)\)\)]],
  ", with map length ",
  Cell[BoxData[
      \(TraditionalForm\`R\)]],
  ".  It is simplest to start with one leaf; the graph should settle down \
over T~1 to a stationary distribution of numbers of ancestral lineages."
}], "Text"],

Cell[BoxData[
    \(\(aa[R_, Tmax_] := \(aa[R, Tmax] = 
          RandomGenealogy[{x1}, 10\^4, R, 
            MaxTime \[Rule] Tmax]\);\)\)], "Input",
  CellLabel->"In[205]:="],

Cell[TextData[{
  "The form",
  StyleBox[" aa[R_,Tmax_]:=aa[R,Tmax]=stuff ",
    FontWeight->"Bold"],
  " is a trick which calculates aa[R,Tmax] once and stores the result."
}], "Text"],

Cell["This is the mean number of lineages:", "Text"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(tbl = \({#, 
              Mean[Table[
                    Length[LineagesPresent[aa[#, 10], t]], {t, 2, 10, 0.1}]] // 
                N} &\) /@ {0.25, 0.5, 1, 2, 4, 6, 8};\)\), "\n", 
    \(\(DisplayTogether[
        Plot[\(2\ \[ExponentialE]\^\(2\ R\)\ R\)\/\(\(-1\) + \
\[ExponentialE]\^\(2\ R\)\), {R, 0, 10}, 
          PlotStyle \[Rule] Red], \[IndentingNewLine]ListPlot[tbl, 
          PlotJoined \[Rule] True]];\)\), "\n", 
    \(tbl // TableForm\)}], "Input",
  CellLabel->"In[241]:="],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.0952381 0.0147151 0.0294302 [
[.21429 .00222 -3 -9 ]
[.21429 .00222 3 0 ]
[.40476 .00222 -3 -9 ]
[.40476 .00222 3 0 ]
[.59524 .00222 -3 -9 ]
[.59524 .00222 3 0 ]
[.78571 .00222 -3 -9 ]
[.78571 .00222 3 0 ]
[.97619 .00222 -6 -9 ]
[.97619 .00222 6 0 ]
[.01131 .16187 -6 -4.5 ]
[.01131 .16187 0 4.5 ]
[.01131 .30902 -12 -4.5 ]
[.01131 .30902 0 4.5 ]
[.01131 .45617 -12 -4.5 ]
[.01131 .45617 0 4.5 ]
[.01131 .60332 -12 -4.5 ]
[.01131 .60332 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.21429 .01472 m
.21429 .02097 L
s
[(2)] .21429 .00222 0 1 Mshowa
.40476 .01472 m
.40476 .02097 L
s
[(4)] .40476 .00222 0 1 Mshowa
.59524 .01472 m
.59524 .02097 L
s
[(6)] .59524 .00222 0 1 Mshowa
.78571 .01472 m
.78571 .02097 L
s
[(8)] .78571 .00222 0 1 Mshowa
.97619 .01472 m
.97619 .02097 L
s
[(10)] .97619 .00222 0 1 Mshowa
.125 Mabswid
.07143 .01472 m
.07143 .01847 L
s
.11905 .01472 m
.11905 .01847 L
s
.16667 .01472 m
.16667 .01847 L
s
.2619 .01472 m
.2619 .01847 L
s
.30952 .01472 m
.30952 .01847 L
s
.35714 .01472 m
.35714 .01847 L
s
.45238 .01472 m
.45238 .01847 L
s
.5 .01472 m
.5 .01847 L
s
.54762 .01472 m
.54762 .01847 L
s
.64286 .01472 m
.64286 .01847 L
s
.69048 .01472 m
.69048 .01847 L
s
.7381 .01472 m
.7381 .01847 L
s
.83333 .01472 m
.83333 .01847 L
s
.88095 .01472 m
.88095 .01847 L
s
.92857 .01472 m
.92857 .01847 L
s
.25 Mabswid
0 .01472 m
1 .01472 L
s
.02381 .16187 m
.03006 .16187 L
s
[(5)] .01131 .16187 1 0 Mshowa
.02381 .30902 m
.03006 .30902 L
s
[(10)] .01131 .30902 1 0 Mshowa
.02381 .45617 m
.03006 .45617 L
s
[(15)] .01131 .45617 1 0 Mshowa
.02381 .60332 m
.03006 .60332 L
s
[(20)] .01131 .60332 1 0 Mshowa
.125 Mabswid
.02381 .04415 m
.02756 .04415 L
s
.02381 .07358 m
.02756 .07358 L
s
.02381 .10301 m
.02756 .10301 L
s
.02381 .13244 m
.02756 .13244 L
s
.02381 .1913 m
.02756 .1913 L
s
.02381 .22073 m
.02756 .22073 L
s
.02381 .25016 m
.02756 .25016 L
s
.02381 .27959 m
.02756 .27959 L
s
.02381 .33845 m
.02756 .33845 L
s
.02381 .36788 m
.02756 .36788 L
s
.02381 .39731 m
.02756 .39731 L
s
.02381 .42674 m
.02756 .42674 L
s
.02381 .4856 m
.02756 .4856 L
s
.02381 .51503 m
.02756 .51503 L
s
.02381 .54446 m
.02756 .54446 L
s
.02381 .57389 m
.02756 .57389 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
1 0 0 r
.5 Mabswid
.02381 .04415 m
.06244 .05768 L
.10458 .07584 L
.14415 .09555 L
.18221 .11626 L
.22272 .13956 L
.26171 .16275 L
.30316 .18785 L
.34309 .21228 L
.3815 .2359 L
.42237 .26109 L
.46172 .28538 L
.49955 .30875 L
.53984 .33365 L
.57861 .3576 L
.61984 .38308 L
.65954 .40762 L
.69774 .43123 L
.73838 .45635 L
.77751 .48053 L
.81909 .50623 L
.85916 .53099 L
.89771 .55482 L
.93871 .58016 L
.97619 .60332 L
s
0 g
.04762 .04851 m
.07143 .04923 L
.11905 .05432 L
.21429 .14842 L
.40476 .21746 L
.59524 .37478 L
.78571 .43836 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[255]:=",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/B000`400?l00000o`00003ooooooolQ
ooooo`00@oooool5o`00037ooooo0ol0000_ooooo`?o0000<Oooool3o`0002kooooo0ol00004oooo
o`;o00001oooool004Cooooo00Co0000oooooooooooo0000<_ooool00ol0003oooooooooo`0]oooo
o`05o`000?ooooooooooooooool00000;oooool01Ol0003ooooooooooooooooo000002kooooo00?o
0000ooooooooool00_ooool01?l0003oooooooooool00006ooooo`00AOooool00ol0003ooooooooo
o`0_ooooo`Go0000;_ooool01Ol0003ooooooooooooooooo000002oooooo00Go0000oooooooooooo
ooooo`00000^ooooo`03o`000?oooooooooo00;ooooo00Co0000oooooooooooo00001_ooool004Ko
oooo00?o0000ooooooooool0;_ooool01?l0003oooooooooool0000_ooooo`Co0000<Oooool3o`00
02oooooo00?o0000ooooooooool00_ooool01?l0003oooooooooool00006ooooo`00@oooool01Ol0
003ooooooooooooooooo0000033ooooo00?o0000ooooool00000;oooool00ol0003oooooooooo`0a
ooooo`05o`000?ooooooooooooooool00000;_ooool00ol0003oooooooooo`02ooooo`04o`000?oo
ooooooooo`0000Kooooo0013ooooo`05o`000?ooooooooooooooool00000<Oooool2o`00033ooooo
00?o0000ooooooooool0<?ooool01Ol0003ooooooooooooooooo000002gooooo0_l00004ooooo`04
o`000?ooooooooooo`0000Kooooo0014ooooo`?o0000<oooool00ol0003oooooooooo`0_ooooo`;o
0000<Oooool3o`0002oooooo00?o0000ooooooooool00oooool2o`0000Oooooo000Booooo`03o`00
0?oooooooooo0?oooooo3?ooool001;ooooo00?o0000ooooooooool0ooooool<ooooo`004_ooool0
0ol0003oooooooooo`3oooooo`cooooo000Booooo`03o`000?oooooooooo0?oooooo3?ooool000co
ooooool0000Ao`0000Cooooo000Booooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool0
2_ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00[ooooo00<00000ooooooooool0
2_ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool0
2_ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool0
2_ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool0
2_ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool0
2_ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool0
2_ooool00ol0003oooooooooo`08ooooo`004_ooool00ol0003oooooooooo`0aooooo`0300000?oo
oooooooo037ooooo00?o0000ooooooooool0<?ooool00ol0003oooooooooo`0aooooo`03o`000?oo
oooooooo037ooooo00?o0000ooooooooool02?ooool001;ooooo00?o0000ooooooooool0ooooool<
ooooo`004_ooool00ol0003oooooooooo`3oooooo`cooooo000Booooo`03o`000?oooooooooo0?oo
oooo3?ooool001;ooooo00?o0000ooooooooool0ooooool<ooooo`004_ooool00ol0003ooooooooo
o`3oooooo`cooooo000Booooo`;oo`00ooooool=ooooo`004_ooool00ol0003oooooool00002ool0
0003ooooool0003o000000Wo0000oOooool001;ooooo00?o0000ooooooooool00_ooool2ool000[o
oooo1ol0003fooooo`004_ooool00ol0003oooooooooo`04ooooo`?oo`003_ooool4o`000?;ooooo
000Booooo`03o`000?oooooooooo00Oooooo0_oo000@ooooo`03o`000?oooooooooo0>oooooo000B
ooooo`03o`000?oooooooooo00Wooooo0ooo000>ooooo`03o`000?oooooooooo0>kooooo000Boooo
o`03o`000?oooooooooo00cooooo0_oo000=ooooo`03o`000?oooooooooo0>gooooo000Booooo`03
o`000?oooooooooo00kooooo0_oo000<ooooo`03o`000?oooooooooo0>cooooo000Booooo`;o0000
4Oooool3ool000[ooooo00?o0000ooooooooool0joooool001;ooooo00?o0000ooooooooool04ooo
ool2ool000Wooooo00?o0000ooooooooool0j_ooool001;ooooo00?o0000ooooooooool05Oooool2
ool000Sooooo00?o0000ooooooooool0jOooool001;ooooo00?o0000ooooooooool05oooool3ool0
00Kooooo00?o0000ooooooooool0j?ooool001;ooooo00?o0000ooooooooool06_ooool2ool000Go
oooo00?o0000ooooooooool0ioooool001;ooooo00?o0000ooooooooool07?ooool2ool000Cooooo
00?o0000ooooooooool0i_ooool001;ooooo00?o0000ooooooooool07_ooool2ool000?ooooo00?o
0000ooooooooool0iOooool001;ooooo00?o0000ooooooooool08?ooool2ool000;ooooo00?o0000
ooooooooool0i?ooool001;ooooo0_l0000Sooooo`04ool00?ooooooooooo`000>Gooooo000Boooo
o`03o`000?oooooooooo02?ooooo0_oo00000ooooooo0000ooooo`3Sooooo`004_ooool00ol0003o
ooooooooo`0Uooooo`;oo`0000?o0000ooooooooool0hOooool001;ooooo00?o0000ooooooooool0
9oooool00ooo003o0000ooooo`3Qooooo`004_ooool00ol0003oooooooooo`0Xooooo`03ool00?l0
003ooooo0>3ooooo000Booooo`03o`000?oooooooooo02[ooooo00?o0000ool00?ooool0g_ooool0
01;ooooo00?o0000ooooooooool0:oooool00ol0003oo`00ool0003Mooooo`004_ooool00ol0003o
ooooooooo`0/ooooo`03o`000?ooooooo`000=cooooo000Booooo`;o0000;_ooool01?l0003ooooo
ool00?oo003Jooooo`004_ooool00ol0003oooooooooo`0^ooooo`03o`000?oooooooooo00;oo`00
f?ooool001;ooooo00?o0000ooooooooool0;oooool01?l0003oooooooooooooool2ool00=Kooooo
000Booooo`03o`000?oooooooooo033ooooo00?o0000ooooooooool00_ooool2ool00=Cooooo000B
ooooo`03o`000?oooooooooo037ooooo0_l00004ooooo`;oo`00d_ooool000[ooooo0ol00005oooo
o`03o`000?oooooooooo03?ooooo0ol00003ooooo`03ool00?oooooooooo0<oooooo0009ooooo`05
o`000?ooooooooooooooool000001?ooool00ol0003oooooooooo`0fooooo`?o000000?oooooool0
0?oo0000coooool000gooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`0iooooo`?o
00000_oo003=ooooo`003Oooool00ol0003oooooooooo`02ooooo`?o0000??ooool2o`0000;oo`00
boooool000Wooooo1?l00005ooooo`03o`000?oooooooooo03kooooo0ol0003:ooooo`002Oooool0
0ol0003oooooooooo`06ooooo`03o`000?oooooooooo047ooooo0ol00037ooooo`002Oooool5o`00
00Cooooo00?o0000ooooooooool0@oooool01?oo003o0000o`000?l00034ooooo`004_ooool00ol0
003oooooooooo`15ooooo`04ool00?oooooo0000o`000<;ooooo000Booooo`03o`000?oooooooooo
04Kooooo0_oo00001?oooooo0000o`000?l0002oooooo`004_ooool00ol0003oooooooooo`18oooo
o`04ool00?ooooooooooooooo`?o0000_?ooool001;ooooo00?o0000ooooooooool0BOooool2ool0
00Cooooo0_l0002jooooo`004_ooool2o`0004cooooo00?oo`00ooooooooool00oooool3o`000;Oo
oooo000Booooo`03o`000?oooooooooo04cooooo0_oo0006ooooo`?o0000]?ooool001;ooooo00?o
0000ooooooooool0C_ooool2ool000Oooooo0ol0002aooooo`004_ooool00ol0003oooooooooo`1@
ooooo`03ool00?oooooooooo00Oooooo0_l0002_ooooo`004_ooool00ol0003oooooooooo`1Aoooo
o`;oo`002Oooool3o`000:cooooo000Booooo`03o`000?oooooooooo05?ooooo00?oo`00oooooooo
ool02Oooool3o`000:Wooooo000Booooo`03o`000?oooooooooo05Cooooo0_oo000<ooooo`?o0000
Y_ooool001;ooooo00?o0000ooooooooool0E_ooool2ool000gooooo0_l0002Tooooo`004_ooool2
o`0005Wooooo00?oo`00ooooooooool03?ooool00ol0003oooooooooo`2Qooooo`004_ooool00ol0
003oooooooooo`1Iooooo`;oo`003Oooool00ol0003oooooooooo`2Pooooo`004_ooool00ol0003o
ooooooooo`1Kooooo`;oo`003?ooool00ol0003oooooooooo`2Oooooo`004_ooool00ol0003ooooo
ooooo`1Mooooo`03ool00?oooooooooo00[ooooo00?o0000ooooooooool0W_ooool001;ooooo00?o
0000ooooooooool0G_ooool2ool000_ooooo0_l0002Nooooo`004_ooool00ol0003oooooooooo`1P
ooooo`03ool00?oooooooooo00[ooooo00?o0000ooooooooool0Voooool001;ooooo00?o0000oooo
ooooool0HOooool2ool000_ooooo00?o0000ooooooooool0V_ooool001;ooooo00?o0000oooooooo
ool0Hoooool2ool000[ooooo00?o0000ooooooooool0VOooool001;ooooo0_l0001Vooooo`03ool0
0?oooooooooo00Sooooo00?o0000ooooooooool0V?ooool001;ooooo00?o0000ooooooooool0I_oo
ool2ool000Wooooo00?o0000ooooooooool0Uoooool001;ooooo00?o0000ooooooooool0J?ooool0
0ooo003oooooooooo`07ooooo`;o0000Uoooool001;ooooo00?o0000ooooooooool0JOooool2ool0
00Wooooo00?o0000ooooooooool0U?ooool001;ooooo00?o0000ooooooooool0Joooool00ooo003o
ooooooooo`07ooooo`03o`000?oooooooooo09?ooooo000Booooo`03o`000?oooooooooo06cooooo
0_oo0008ooooo`03o`000?oooooooooo09;ooooo000Booooo`03o`000?oooooooooo06kooooo0_oo
0007ooooo`03o`000?oooooooooo097ooooo000Booooo`03o`000?oooooooooo073ooooo00?oo`00
ooooooooool01Oooool2o`00097ooooo000Booooo`;o0000L_ooool2ool000Oooooo00?o0000oooo
ooooool0S_ooool001;ooooo00?o0000ooooooooool0Loooool00ooo003oooooooooo`05ooooo`03
o`000?oooooooooo08gooooo000Booooo`03o`000?oooooooooo07Cooooo0_oo0006ooooo`03o`00
0?oooooooooo08cooooo000Booooo`03o`000?oooooooooo07Kooooo0_oo0005ooooo`03o`000?oo
oooooooo08_ooooo000Booooo`03o`000?oooooooooo07Sooooo00?oo`00ooooooooool00oooool2
o`0008_ooooo0004ooooo`?o00001?ooool2o`0000Gooooo00?o0000ooooooooool0NOooool2ool0
00Gooooo00?o0000ooooooooool0R?ooool000Gooooo00?o0000ooooooooool00_ooool01?l0003o
ooooooooool00004ooooo`03o`000?oooooooooo07_ooooo0_oo0004ooooo`03o`000?oooooooooo
08Oooooo0005ooooo`03o`000?oooooooooo00;ooooo00Co0000oooooooooooo00001?ooool00ol0
003oooooooooo`1mooooo`03ool00?oooooooooo00;ooooo00?o0000ooooooooool0Q_ooool000Go
oooo00?o0000ooooooooool00_ooool01?l0003oooooooooool00004ooooo`?o0000O_ooool2ool0
00?ooooo00?o0000ooooooooool0QOooool000Gooooo00?o0000ooooooooool00_ooool01?l0003o
ooooooooool00004ooooo`03o`000?oooooooooo083ooooo00Goo`00ooooooooooooooooo`000026
ooooo`001?ooool2o`0000Cooooo00Co0000oooooooooooo00001?ooool00ol0003oooooooooo`21
ooooo`;oo`000_ooool2o`0008Cooooo0005ooooo`03o`000?oooooooooo00?ooooo0_l00005oooo
o`03o`000?oooooooooo08?ooooo0_oo0002ooooo`03o`000?oooooooooo087ooooo000Booooo`03
o`000?oooooooooo08Gooooo00Coo`00oooooooooooo0000P_ooool001;ooooo00?o0000oooooooo
ool0Q_ooool2ool00003ooooool0003ooooo083ooooo000Booooo`03o`000?oooooooooo08Sooooo
00?oo`00ooooool00000P?ooool001;ooooo00?o0000ooooooooool0ROooool2ool000;o0000O_oo
ool001;ooooo0_l0002<ooooo`;oo`0000?o0000ooooooooool0Noooool001;ooooo00?o0000oooo
ooooool0SOooool00ooo003o0000ooooo`1kooooo`004_ooool00ol0003oooooooooo`2?ooooo`03
o`000?oooooooooo07Wooooo000Booooo`03o`000?oooooooooo093ooooo00?o0000ool00?ooool0
N?ooool001;ooooo00?o0000ooooooooool0TOooool00ol0003oo`00ool0001gooooo`004_ooool0
0ol0003oooooooooo`2Booooo`;o00000_oo001eooooo`004_ooool00ol0003oooooooooo`2Doooo
o`03o`000?ooooooo`0007Cooooo000Booooo`03o`000?oooooooooo09Gooooo00Co0000oooooooo
003oo`00L_ooool001;ooooo0_l0002Gooooo`03o`000?oooooooooo00;oo`00L?ooool001;ooooo
00?o0000ooooooooool0Uoooool01Ol0003oooooooooooooooooo`0006oooooo000Booooo`03o`00
0?oooooooooo09Sooooo0ol000000oooooooo`00ool0001]ooooo`004_ooool00ol0003ooooooooo
o`2Kooooo`?o000000?oo`00ooooooooool0J_ooool001;ooooo00?o0000ooooooooool0W_ooool3
o`0006[ooooo000Booooo`03o`000?oooooooooo0:7ooooo0ol0001Wooooo`004_ooool00ol0003o
ooooooooo`2Rooooo`;oo`000ol0001Tooooo`004_ooool00ol0003oooooooooo`2Tooooo`;oo`00
00Coooooo`000?l0003o0000HOooool001;ooooo0_l0002Wooooo`04ool00?ooooooooooooooo`?o
0000G_ooool001;ooooo00?o0000ooooooooool0Yoooool2ool000Cooooo0ol0001Kooooo`004_oo
ool00ol0003oooooooooo`2Yooooo`03ool00?oooooooooo00Cooooo0ol0001Hooooo`004_ooool0
0ol0003oooooooooo`2Zooooo`;oo`001oooool3o`0005Gooooo000Booooo`03o`000?oooooooooo
0:cooooo0_oo0008ooooo`?o0000D_ooool001;ooooo00?o0000ooooooooool0[_ooool00ooo003o
ooooooooo`08ooooo`?o0000Coooool001;ooooo00?o0000ooooooooool0[oooool2ool000_ooooo
0ol0001<ooooo`004_ooool00ol0003oooooooooo`2aooooo`;oo`003?ooool3o`0004Wooooo000B
ooooo`;o0000]?ooool00ooo003oooooooooo`0<ooooo`?o0000A_ooool001;ooooo00?o0000oooo
ooooool0]?ooool2ool000oooooo0ol00013ooooo`004_ooool00ol0003oooooooooo`2fooooo`03
ool00?oooooooooo00oooooo0ol00010ooooo`004_ooool00ol0003oooooooooo`2gooooo`;oo`00
4_ooool2o`0003kooooo000Booooo`03o`000?oooooooooo0;Wooooo0_oo001@ooooo`001?ooool3
o`0000?ooooo0ol00005ooooo`03o`000?oooooooooo0;_ooooo00?oo`00ooooooooool0COooool0
00Gooooo00Go0000ooooooooooooooooo`000003ooooo`03o`000?oooooooooo00;ooooo00?o0000
ooooooooool0_?ooool2ool004gooooo0005ooooo`03o`000?oooooooooo00Gooooo00?o0000oooo
ooooool00_ooool00ol0003oooooooooo`2nooooo`03ool00?oooooooooo04[ooooo0005ooooo`03
o`000?oooooooooo00Gooooo00?o0000ooooooooool00_ooool3o`000;oooooo0_oo001:ooooo`00
1Oooool01?l0003oooooooooooooool4o`0000Gooooo00?o0000ooooooooool0`Oooool00ooo003o
ooooooooo`17ooooo`001?ooool2o`0000?ooooo00?o0000ooooooooool01_ooool00ol0003ooooo
ooooo`32ooooo`;oo`00Aoooool000Gooooo00Co0000oooooooooooooooo1Ol00004ooooo`03o`00
0?oooooooooo0<Cooooo0_oo0015ooooo`004_ooool00ol0003oooooooooo`36ooooo`03ool00?oo
oooooooo04;ooooo000Booooo`03o`000?oooooooooo0<Oooooo0_oo0012ooooo`004_ooool00ol0
003oooooooooo`39ooooo`03ool00?oooooooooo03oooooo000Booooo`03o`000?oooooooooo0<[o
oooo0_oo000oooooo`004_ooool2o`000<gooooo00?oo`00ooooooooool0??ooool001;ooooo00?o
0000ooooooooool0cOooool2ool003cooooo000Booooo`03o`000?oooooooooo0<oooooo0_oo000j
ooooo`004_ooool00ol0003oooooooooo`3Aooooo`03ool00?oooooooooo03Oooooo000Booooo`03
o`000?oooooooooo0=;ooooo0_oo000gooooo`004_ooool00ol0003oooooooooo`3Dooooo`03ool0
0?oooooooooo03Cooooo000Booooo`03o`000?oooooooooo0=Gooooo0_oo000dooooo`004_ooool0
0ol0003oooooooooo`3Gooooo`;oo`00<_ooool001;ooooo0_l0003Jooooo`;oo`00<?ooool001;o
oooo00?o0000ooooooooool0foooool00ooo003oooooooooo`0]ooooo`004_ooool00ol0003ooooo
ooooo`3Looooo`;oo`00;Oooool001;ooooo00?o0000ooooooooool0g_ooool2ool002_ooooo000B
ooooo`03o`000?oooooooooo0>3ooooo0_oo000Yooooo`004_ooool00ol0003oooooooooo`3Roooo
o`03ool00?oooooooooo02Kooooo000Booooo`03o`000?oooooooooo0>?ooooo0_oo000Vooooo`00
4_ooool00ol0003oooooooooo`3Uooooo`;oo`009?ooool001;ooooo0_l0003Xooooo`03ool00?oo
oooooooo027ooooo000Booooo`03o`000?oooooooooo0>Sooooo0_oo000Qooooo`004_ooool00ol0
003oooooooooo`3Zooooo`03ool00?oooooooooo01kooooo000Booooo`03o`000?oooooooooo0>_o
oooo0_oo000Nooooo`004_ooool00ol0003oooooooooo`3]ooooo`03ool00?oooooooooo01_ooooo
000Booooo`03o`000?oooooooooo0>kooooo0_oo000Kooooo`004_ooool00ol0003oooooooooo`3`
ooooo`;oo`006Oooool001;ooooo00?o0000ooooooooool0l_ooool00ooo003oooooooooo`0Foooo
o`004_ooool2o`000?Cooooo0_oo000Fooooo`004_ooool00ol0003oooooooooo`3eooooo`03ool0
0?oooooooooo01?ooooo000Booooo`03o`000?oooooooooo0?Kooooo0_oo000Cooooo`004_ooool0
0ol0003oooooooooo`3hooooo`;oo`004Oooool001;ooooo00?o0000ooooooooool0n_ooool00ooo
003oooooooooo`0>ooooo`000oooool5o`0000?ooooo0_l00005ooooo`03o`000?oooooooooo0?_o
oooo0_oo000>ooooo`001?ooool01?l0003oooooooooool00002ooooo`04o`000?ooooooooooo`00
00Cooooo00?o0000ooooooooool0oOooool2ool000cooooo0005ooooo`03o`000?oooooooooo00;o
oooo00Co0000oooooooooooo00001?ooool00ol0003oooooooooo`3oooooo`03ool00?oooooooooo
00Wooooo0006ooooo`05o`000?ooooooooooooooool000000_ooool00ol0003oooooooooo`02oooo
o`?o0000ooooool1ooooo`03ool00?oooooooooo00Sooooo0003ooooo`05o`000?oooooooooooooo
ool000000_ooool01?l0003oooooooooool00004ooooo`03o`000?oooooooooo0?oooooo3?ooool0
00?ooooo00Go0000ooooooooooooooooo`000002ooooo`04o`000?ooooooooooo`0000Cooooo00?o
0000ooooooooool0ooooool<ooooo`001?ooool3o`0000Cooooo0_l00005ooooo`03o`000?oooooo
oooo0?oooooo3?ooool001;ooooo00?o0000ooooooooool0ooooool<ooooo`00\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.713998, -1.5494, \
0.0386179, 0.12497}}],

Cell[BoxData[
    TagBox[GridBox[{
          {"0.25`", "1.1481481481481481`"},
          {"0.5`", "1.1728395061728396`"},
          {"1", "1.345679012345679`"},
          {"2", "4.54320987654321`"},
          {"4", "6.888888888888889`"},
          {"6", "12.234567901234568`"},
          {"8", "14.395061728395062`"}
          },
        RowSpacings->1,
        ColumnSpacings->3,
        RowAlignments->Baseline,
        ColumnAlignments->{Left}],
      Function[ BoxForm`e$, 
        TableForm[ BoxForm`e$]]]], "Output",
  CellLabel->"Out[256]//TableForm="]
}, Open  ]],

Cell["\<\
The averaging starts at T=2 to allow for the fact that  the number \
of lineages starts at 1 and increases.\
\>", "Text"],

Cell["\<\
This shows how the number of lineages that actually carry ancestral \
material increases.  It fiits badly with the Derrida & Jung-Muller prediction \
(in red):\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(tblNonNull = \({#, 
              Mean[Table[
                    Length[LineagesPresent[DeleteNullLineages[aa[#, 10]], 
                        t]], {t, 2, 10, 0.1}]] // N} &\) /@ {0.25, 0.5, 1, 2, 
            4, 6, 8};\)\), "\n", 
    \(\(DisplayTogether[
        Plot[1 + R - R\^2\/3 + \(13\/54\) R\^3, {R, 0, 2}, 
          PlotStyle \[Rule] Red], 
        ListPlot[tblNonNull, PlotJoined \[Rule] True]];\)\), "\n", 
    \(tblNonNull // TableForm\)}], "Input",
  CellLabel->"In[244]:="],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.221263 -0.139579 0.154294 [
[.24507 .00222 -3 -9 ]
[.24507 .00222 3 0 ]
[.46634 .00222 -3 -9 ]
[.46634 .00222 3 0 ]
[.6876 .00222 -3 -9 ]
[.6876 .00222 3 0 ]
[.90886 .00222 -3 -9 ]
[.90886 .00222 3 0 ]
[.01131 .16901 -6 -4.5 ]
[.01131 .16901 0 4.5 ]
[.01131 .3233 -6 -4.5 ]
[.01131 .3233 0 4.5 ]
[.01131 .4776 -6 -4.5 ]
[.01131 .4776 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.24507 .01472 m
.24507 .02097 L
s
[(1)] .24507 .00222 0 1 Mshowa
.46634 .01472 m
.46634 .02097 L
s
[(2)] .46634 .00222 0 1 Mshowa
.6876 .01472 m
.6876 .02097 L
s
[(3)] .6876 .00222 0 1 Mshowa
.90886 .01472 m
.90886 .02097 L
s
[(4)] .90886 .00222 0 1 Mshowa
.125 Mabswid
.06806 .01472 m
.06806 .01847 L
s
.11231 .01472 m
.11231 .01847 L
s
.15657 .01472 m
.15657 .01847 L
s
.20082 .01472 m
.20082 .01847 L
s
.28932 .01472 m
.28932 .01847 L
s
.33358 .01472 m
.33358 .01847 L
s
.37783 .01472 m
.37783 .01847 L
s
.42208 .01472 m
.42208 .01847 L
s
.51059 .01472 m
.51059 .01847 L
s
.55484 .01472 m
.55484 .01847 L
s
.59909 .01472 m
.59909 .01847 L
s
.64335 .01472 m
.64335 .01847 L
s
.73185 .01472 m
.73185 .01847 L
s
.7761 .01472 m
.7761 .01847 L
s
.82036 .01472 m
.82036 .01847 L
s
.86461 .01472 m
.86461 .01847 L
s
.95311 .01472 m
.95311 .01847 L
s
.99737 .01472 m
.99737 .01847 L
s
.25 Mabswid
0 .01472 m
1 .01472 L
s
.02381 .16901 m
.03006 .16901 L
s
[(2)] .01131 .16901 1 0 Mshowa
.02381 .3233 m
.03006 .3233 L
s
[(3)] .01131 .3233 1 0 Mshowa
.02381 .4776 m
.03006 .4776 L
s
[(4)] .01131 .4776 1 0 Mshowa
.125 Mabswid
.02381 .04557 m
.02756 .04557 L
s
.02381 .07643 m
.02756 .07643 L
s
.02381 .10729 m
.02756 .10729 L
s
.02381 .13815 m
.02756 .13815 L
s
.02381 .19987 m
.02756 .19987 L
s
.02381 .23073 m
.02756 .23073 L
s
.02381 .26159 m
.02756 .26159 L
s
.02381 .29244 m
.02756 .29244 L
s
.02381 .35416 m
.02756 .35416 L
s
.02381 .38502 m
.02756 .38502 L
s
.02381 .41588 m
.02756 .41588 L
s
.02381 .44674 m
.02756 .44674 L
s
.02381 .50846 m
.02756 .50846 L
s
.02381 .53932 m
.02756 .53932 L
s
.02381 .57017 m
.02756 .57017 L
s
.02381 .60103 m
.02756 .60103 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
1 0 0 r
.5 Mabswid
.02381 .01472 m
.04176 .02691 L
.06134 .03959 L
.07973 .05102 L
.09741 .06172 L
.11623 .0729 L
.13435 .08359 L
.15361 .09503 L
.17216 .10624 L
.19001 .11734 L
.209 .1296 L
.22728 .142 L
.24486 .15457 L
.26358 .16879 L
.2816 .18341 L
.30075 .2001 L
.3192 .21742 L
.33695 .23536 L
.35584 .25595 L
.37402 .27737 L
.39334 .30198 L
.41196 .32763 L
.42987 .35424 L
.44892 .38475 L
.46634 .41474 L
s
0 g
.07913 .03757 m
.13444 .04138 L
.24507 .03186 L
.46634 .30806 L
.90886 .36331 L
s
.90886 .36331 m
1 .40607 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[244]:=",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/B000`400?l00000o`00003ooooooolQ
ooooo`00BOooool3o`0003Sooooo1Ol0000iooooo`?o0000>_ooool3o`0001kooooo001:ooooo`03
o`000?oooooooooo03Sooooo00Co0000oooooooooooo0000>?ooool01Ol0003ooooooooooooooooo
000003[ooooo00?o0000ooooooooool07Oooool004[ooooo00?o0000ooooooooool0>Oooool00ol0
003oooooooooo`0looooo`03o`000?oooooooooo03Gooooo1Ol0000Nooooo`00B_ooool00ol0003o
ooooooooo`0jooooo`03o`000?oooooooooo03Wooooo0_l0000hooooo`04o`000?ooooooooooo`00
01oooooo001:ooooo`03o`000?oooooooooo03Oooooo00Go0000ooooooooooooooooo`00000loooo
o`03o`000?oooooooooo03Kooooo00?o0000ooooool000007oooool004Wooooo0_l0000iooooo`05
o`000?ooooooooooooooool00000>?ooool01Ol0003ooooooooooooooooo000003Wooooo0_l0000O
ooooo`00B_ooool00ol0003oooooooooo`0hooooo`?o0000>_ooool3o`0003_ooooo00?o0000oooo
ooooool07Oooool000oooooo00?o0000ooooooooool0ooooool?ooooo`003oooool00ol0003ooooo
ooooo`3oooooo`oooooo000?ooooo`03o`000?oooooooooo0?oooooo3oooool000oooooo00?o0000
ooooooooool0ooooool?ooooo`002?ooool7o`0000;oo`00ool0000:o`0000Kooooo000?ooooo`03
o`000?ooooooo`0000Wooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`09ooooo`03
o`000?oooooooooo00Wooooo00?o0000ooooooooool02Oooool00`00003oooooooooo`09ooooo`03
o`000?oooooooooo00Wooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`09ooooo`03
o`000?oooooooooo00Wooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`09ooooo`03
o`000?oooooooooo00Wooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`09ooooo`03
o`000?oooooooooo00Wooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`09ooooo`03
o`000?oooooooooo00Wooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`09ooooo`03
o`000?oooooooooo00Wooooo00?o0000ooooooooool01Oooool000oooooo00Co0000oooooooooooo
o`00>?ooool00`00003oooooooooo`0iooooo`03o`000?oooooooooo03[ooooo00?o0000oooooooo
ool0>Oooool00ol0003oooooooooo`0Mooooo`003oooool01?l0003oooooooooooooool2ool00?oo
oooo3?ooool000oooooo00?o0000ooooooooool00oooool00ooo003oooooooooo`3oooooo`Wooooo
000?ooooo`03o`000?oooooooooo00Cooooo0_oo000/ooooo`So0000e?ooool000oooooo00?o0000
ooooooooool01_ooool00ooo003oooooooooo`03ooooo`Wo00003_ooool?o`0000Oooooo00?o0000
ooooooooool0d_ooool000oooooo00?o0000ooooooooool01oooool2ool000cooooo3_l0000Goooo
o`03o`000?oooooooooo0=7ooooo000?ooooo`;o00002_ooool2ool0033ooooo00?o0000oooooooo
ool0d?ooool000oooooo00?o0000ooooooooool02oooool00ooo003oooooooooo`0^ooooo`03o`00
0?oooooooooo0<oooooo000?ooooo`03o`000?oooooooooo00cooooo0_oo000_ooooo`03o`000?oo
oooooooo0<kooooo000?ooooo`03o`000?oooooooooo00kooooo0_oo000]ooooo`03o`000?oooooo
oooo0<kooooo000?ooooo`03o`000?oooooooooo013ooooo00?oo`00ooooooooool0:oooool00ol0
003oooooooooo`3=ooooo`003oooool00ol0003oooooooooo`0Aooooo`;oo`00;?ooool00ol0003o
ooooooooo`3<ooooo`003oooool00ol0003oooooooooo`0Cooooo`;oo`00:oooool00ol0003ooooo
ooooo`3;ooooo`003oooool00ol0003oooooooooo`0Eooooo`03ool00?oooooooooo02Wooooo00?o
0000ooooooooool0b_ooool000oooooo00?o0000ooooooooool05_ooool2ool002Wooooo00?o0000
ooooooooool0b_ooool000oooooo0_l0000Iooooo`;oo`00:?ooool00ol0003oooooooooo`39oooo
o`003oooool00ol0003oooooooooo`0Jooooo`03ool00?oooooooooo02Kooooo00?o0000oooooooo
ool0b?ooool000oooooo00?o0000ooooooooool06oooool2ool002Oooooo00?o0000ooooooooool0
aoooool000oooooo00?o0000ooooooooool07Oooool2ool002Kooooo00?o0000ooooooooool0a_oo
ool000oooooo00?o0000ooooooooool07oooool00ooo003oooooooooo`0Sooooo`03o`000?oooooo
oooo0<Kooooo000?ooooo`03o`000?oooooooooo023ooooo0_oo000Tooooo`03o`000?oooooooooo
0<Gooooo000?ooooo`03o`000?oooooooooo02;ooooo0_oo000Sooooo`03o`000?oooooooooo0<Co
oooo000?ooooo`03o`000?oooooooooo02Cooooo00?oo`00ooooooooool08Oooool00ol0003ooooo
ooooo`33ooooo`003oooool2o`0002Kooooo0_oo000Rooooo`03o`000?oooooooooo0<;ooooo000?
ooooo`03o`000?oooooooooo02Oooooo0_oo000Pooooo`03o`000?oooooooooo0<;ooooo000?oooo
o`03o`000?oooooooooo02Wooooo00?oo`00ooooooooool07_ooool00ol0003oooooooooo`31oooo
o`003oooool00ol0003oooooooooo`0Zooooo`;oo`007oooool00ol0003oooooooooo`30ooooo`00
3oooool00ol0003oooooooooo`0/ooooo`;oo`007_ooool00ol0003oooooooooo`2oooooo`003ooo
ool00ol0003oooooooooo`0^ooooo`03ool00?oooooooooo01cooooo00?o0000ooooooooool0__oo
ool000oooooo00?o0000ooooooooool0;oooool2ool001cooooo00?o0000ooooooooool0__ooool0
00oooooo00?o0000ooooooooool0<Oooool00ooo003oooooooooo`0Jooooo`03o`000?oooooooooo
0;gooooo000?ooooo`03o`000?oooooooooo03;ooooo00?oo`00ooooooooool06_ooool00ol0003o
ooooooooo`2looooo`003oooool2o`0003Cooooo00?oo`00ooooooooool06_ooool00ol0003ooooo
ooooo`2kooooo`003oooool00ol0003oooooooooo`0dooooo`;oo`006oooool00ol0003ooooooooo
o`2jooooo`003oooool00ol0003oooooooooo`0fooooo`;oo`006Oooool00ol0003oooooooooo`2j
ooooo`003oooool00ol0003oooooooooo`0hooooo`03ool00?oooooooooo01Oooooo00?o0000oooo
ooooool0^Oooool000oooooo00?o0000ooooooooool0>Oooool2ool001Sooooo00?o0000oooooooo
ool0^?ooool000oooooo00?o0000ooooooooool0>oooool00ooo003oooooooooo`0Fooooo`03o`00
0?oooooooooo0;Oooooo0005ooooo`Go00001Oooool00ol0003oooooooooo`0looooo`03ool00?oo
oooooooo01Kooooo00?o0000ooooooooool0]_ooool000Kooooo00Co0000oooooooooooo00001Ooo
ool00ol0003oooooooooo`0mooooo`03ool00?oooooooooo01Gooooo00?o0000ooooooooool0]_oo
ool000Oooooo00?o0000ooooooooool01Oooool2o`0003oooooo0_oo000Fooooo`03o`000?oooooo
oooo0;Gooooo0008ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0@?ooool00ooo
003oooooooooo`0Dooooo`03o`000?oooooooooo0;Cooooo0005ooooo`05o`000?oooooooooooooo
ool000001Oooool00ol0003oooooooooo`11ooooo`03ool00?oooooooooo01Cooooo00?o0000oooo
ooooool0/oooool000Gooooo00Go0000ooooooooooooooooo`000005ooooo`03o`000?oooooooooo
04;ooooo00?oo`00ooooooooool05?ooool00ol0003oooooooooo`2booooo`001_ooool3o`0000Ko
oooo00?o0000ooooooooool0@oooool00ooo003oooooooooo`0Cooooo`03o`000?oooooooooo0;;o
oooo000?ooooo`03o`000?oooooooooo04Cooooo00?oo`00ooooooooool04oooool00ol0003ooooo
ooooo`2aooooo`003oooool00ol0003oooooooooo`15ooooo`03ool00?oooooooooo01?ooooo00?o
0000ooooooooool0/?ooool000oooooo00?o0000ooooooooool0A_ooool00ooo003oooooooooo`0C
ooooo`03o`000?oooooooooo0:oooooo000?ooooo`;o0000B?ooool00ooo003oooooooooo`0Coooo
o`03o`000?oooooooooo0:kooooo000?ooooo`03o`000?oooooooooo04Sooooo0_oo000Cooooo`03
o`000?oooooooooo0:kooooo000?ooooo`03o`000?oooooooooo04[ooooo00?oo`00ooooooooool0
4Oooool00ol0003oooooooooo`2]ooooo`003oooool00ol0003oooooooooo`1;ooooo`03ool00?oo
oooooooo017ooooo00?o0000ooooooooool0[?ooool000oooooo00?o0000ooooooooool0C?ooool0
0ooo003oooooooooo`0Aooooo`03o`000?oooooooooo0:_ooooo000?ooooo`03o`000?oooooooooo
04gooooo00?oo`00ooooooooool04Oooool00ol0003oooooooooo`2Zooooo`003oooool00ol0003o
ooooooooo`1>ooooo`03ool00?oooooooooo013ooooo00?o0000ooooooooool0Z_ooool000oooooo
00?o0000ooooooooool0Coooool00ooo003oooooooooo`0@ooooo`03o`000?oooooooooo0:Wooooo
000?ooooo`03o`000?oooooooooo053ooooo00?oo`00ooooooooool04?ooool00ol0003ooooooooo
o`2Xooooo`003oooool2o`0005;ooooo00?oo`00ooooooooool04?ooool00ol0003oooooooooo`2W
ooooo`003oooool00ol0003oooooooooo`1Booooo`03ool00?oooooooooo013ooooo00?o0000oooo
ooooool0Y_ooool000oooooo00?o0000ooooooooool0D_ooool00ooo003oooooooooo`0@ooooo`03
o`000?oooooooooo0:Kooooo000?ooooo`03o`000?oooooooooo05?ooooo00?oo`00ooooooooool0
4?ooool00ol0003oooooooooo`2Uooooo`003oooool00ol0003oooooooooo`1Dooooo`03ool00?oo
oooooooo013ooooo00?o0000ooooooooool0Y?ooool000oooooo00?o0000ooooooooool0EOooool0
0ooo003oooooooooo`0@ooooo`03o`000?oooooooooo0:?ooooo000?ooooo`03o`000?oooooooooo
05Kooooo00?oo`00ooooooooool04?ooool00ol0003oooooooooo`2Rooooo`003oooool00ol0003o
ooooooooo`1Gooooo`03ool00?oooooooooo00oooooo00?o0000ooooooooool0X_ooool000oooooo
0_l0001Hooooo`03ool00?oooooooooo013ooooo00?o0000ooooooooool0XOooool000oooooo00?o
0000ooooooooool0F?ooool00ooo003oooooooooo`0@ooooo`03o`000?oooooooooo0:3ooooo000?
ooooo`03o`000?oooooooooo05Wooooo00?oo`00ooooooooool04?ooool00ol0003oooooooooo`2O
ooooo`003oooool00ol0003oooooooooo`1Jooooo`03ool00?oooooooooo013ooooo00?o0000oooo
ooooool0W_ooool000oooooo00?o0000ooooooooool0Foooool00ooo003oooooooooo`0?ooooo`03
o`000?oooooooooo09kooooo000?ooooo`03o`000?oooooooooo05cooooo00?oo`00ooooooooool0
3oooool00ol0003oooooooooo`2Mooooo`003oooool00ol0003oooooooooo`1Looooo`03ool00?oo
oooooooo013ooooo00?o0000ooooooooool0W?ooool000oooooo00?o0000ooooooooool0GOooool0
0ooo003oooooooooo`0@ooooo`03o`000?oooooooooo09_ooooo000?ooooo`03o`000?oooooooooo
05kooooo00?oo`00ooooooooool04?ooool00ol0003oooooooooo`2Jooooo`003oooool2o`00063o
oooo00?oo`00ooooooooool03oooool00ol0003oooooooooo`2Jooooo`003oooool00ol0003ooooo
ooooo`1Pooooo`03ool00?oooooooooo00oooooo00?o0000ooooooooool0VOooool000oooooo00?o
0000ooooooooool0HOooool00ooo003oooooooooo`0?ooooo`03o`000?oooooooooo09Sooooo000?
ooooo`03o`000?oooooooooo067ooooo00?oo`00ooooooooool04?ooool00ol0003oooooooooo`2G
ooooo`003oooool00ol0003oooooooooo`1Rooooo`03ool00?oooooooooo013ooooo1Ol0002Doooo
o`003oooool00ol0003oooooooooo`1Sooooo`03ool00?oooooooooo01Cooooo2?l0002<ooooo`00
1_ooool3o`0000Kooooo00?o0000ooooooooool0I?ooool00ooo003oooooooooo`0Kooooo`So0000
Q?ooool000Gooooo00Go0000ooooooooooooooooo`000005ooooo`03o`000?oooooooooo06Cooooo
00?oo`00ooooooooool08oooool8o`0007cooooo0009ooooo`03o`000?oooooooooo00?ooooo0_l0
001Vooooo`03ool00?oooooooooo02[ooooo2?l0001dooooo`001oooool2o`0000Kooooo00?o0000
ooooooooool0I_ooool00ooo003oooooooooo`0aooooo`So0000K?ooool000Wooooo00?o0000oooo
ooooool00oooool00ol0003oooooooooo`1Vooooo`03ool00?oooooooooo03Wooooo2?l0001Toooo
o`001Oooool01Ol0003ooooooooooooooooo000000Gooooo00?o0000ooooooooool0Ioooool00ooo
003oooooooooo`10ooooo`Wo0000Foooool000Kooooo0ol00006ooooo`03o`000?oooooooooo06So
oooo00?oo`00ooooooooool0B?ooool8o`0005?ooooo000?ooooo`03o`000?oooooooooo06Sooooo
00?oo`00ooooooooool0D?ooool8o`0004_ooooo000?ooooo`03o`000?oooooooooo06Wooooo00?o
o`00ooooooooool0Eoooool8o`0004?ooooo000?ooooo`03o`000?oooooooooo06Wooooo00?oo`00
ooooooooool0Goooool8o`0003_ooooo000?ooooo`03o`000?oooooooooo06[ooooo00?oo`00oooo
ooooool0I_ooool8o`0003?ooooo000?ooooo`;o0000K?ooool00ooo003oooooooooo`1]ooooo`So
0000:oooool000oooooo00?o0000ooooooooool0Joooool00ooo003oooooooooo`1eooooo`So0000
8oooool000oooooo00?o0000ooooooooool0K?ooool00ooo003oooooooooo`1looooo`Go00007_oo
ool000oooooo00?o0000ooooooooool0KOooool00ooo003oooooooooo`20ooooo`;o00007?ooool0
00oooooo00?o0000ooooooooool0K_ooool00ooo003oooooooooo`21ooooo`;o00006_ooool000oo
oooo00?o0000ooooooooool0K_ooool00ooo003oooooooooo`23ooooo`;o00006?ooool000oooooo
00?o0000ooooooooool0Koooool00ooo003oooooooooo`24ooooo`;o00005_ooool000oooooo00?o
0000ooooooooool0L?ooool00ooo003oooooooooo`25ooooo`;o00005?ooool000oooooo0_l0001b
ooooo`03ool00?oooooooooo08Kooooo0ol0000Aooooo`003oooool00ol0003oooooooooo`1aoooo
o`03ool00?oooooooooo08Wooooo0_l0000?ooooo`003oooool00ol0003oooooooooo`1booooo`03
ool00?oooooooooo08[ooooo0_l0000=ooooo`003oooool00ol0003oooooooooo`1booooo`03ool0
0?oooooooooo08cooooo0_l0000;ooooo`003oooool00ol0003oooooooooo`1cooooo`03ool00?oo
oooooooo08gooooo0_l00009ooooo`003oooool00ol0003oooooooooo`1cooooo`03ool00?oooooo
oooo08oooooo0_l00007ooooo`003oooool00ol0003oooooooooo`1dooooo`03ool00?oooooooooo
093ooooo00?o0000ooooooooool01?ooool000oooooo00?o0000ooooooooool0M?ooool00ooo003o
ooooooooo`2Gooooo`003oooool2o`0007Kooooo00?oo`00ooooooooool0U_ooool000oooooo00?o
0000ooooooooool0ooooool?ooooo`003oooool00ol0003oooooooooo`3oooooo`oooooo000?oooo
o`03o`000?oooooooooo0?oooooo3oooool000oooooo00?o0000ooooooooool0ooooool?ooooo`00
3oooool00ol0003oooooooooo`3oooooo`oooooo000?ooooo`03o`000?oooooooooo0?oooooo3ooo
ool000oooooo00?o0000ooooooooool0ooooool?ooooo`003oooool00ol0003oooooooooo`3ooooo
o`oooooo000?ooooo`;o0000ooooool@ooooo`003oooool00ol0003oooooooooo`3oooooo`oooooo
000?ooooo`03o`000?oooooooooo0?oooooo3oooool000oooooo00?o0000ooooooooool0ooooool?
ooooo`003oooool00ol0003oooooooooo`3oooooo`oooooo000?ooooo`03o`000?oooooooooo0?oo
oooo3oooool000Oooooo0ol00005ooooo`03o`000?oooooooooo0?oooooo3oooool000Sooooo00?o
0000ooooooooool01?ooool00ol0003oooooooooo`3oooooo`oooooo0005ooooo`Go00001Oooool2
o`000?oooooo4?ooool000Gooooo00Co0000oooooooooooo00001_ooool00ol0003oooooooooo`3o
ooooo`oooooo0006ooooo`03o`000?oooooo000000Kooooo00?o0000ooooooooool0ooooool?oooo
o`001oooool2o`0000Kooooo00?o0000ooooooooool0ooooool?ooooo`002?ooool00ol0003ooooo
ooooo`04ooooo`03o`000?oooooooooo0?oooooo3oooool000oooooo00?o0000ooooooooool0oooo
ool?ooooo`003oooool00ol0003oooooooooo`3oooooo`oooooo000?ooooo`03o`000?oooooooooo
0?oooooo3oooool000oooooo00?o0000ooooooooool0ooooool?ooooo`003oooool2o`000?oooooo
4?ooool000oooooo00?o0000ooooooooool0ooooool?ooooo`003oooool00ol0003oooooooooo`3o
ooooo`oooooo000?ooooo`03o`000?oooooooooo0?oooooo3oooool000oooooo00?o0000oooooooo
ool0ooooool?ooooo`003oooool00ol0003oooooooooo`3oooooo`oooooo000?ooooo`03o`000?oo
oooooooo0?oooooo3oooool000oooooo00?o0000ooooooooool0ooooool?ooooo`003oooool2o`00
0?oooooo4?ooool000oooooo00?o0000ooooooooool0ooooool?ooooo`003oooool00ol0003ooooo
ooooo`3oooooo`oooooo000?ooooo`03o`000?oooooooooo0?oooooo3oooool000oooooo00?o0000
ooooooooool0ooooool?ooooo`003oooool00ol0003oooooooooo`3oooooo`oooooo000?ooooo`03
o`000?oooooooooo0?oooooo3oooool000oooooo00?o0000ooooooooool0ooooool?ooooo`003ooo
ool2o`000?oooooo4?ooool000oooooo00?o0000ooooooooool0ooooool?ooooo`003oooool00ol0
003oooooooooo`3oooooo`oooooo000?ooooo`03o`000?oooooooooo0?oooooo3oooool000oooooo
00?o0000ooooooooool0ooooool?ooooo`003oooool00ol0003oooooooooo`3oooooo`oooooo000?
ooooo`03o`000?oooooooooo0?oooooo3oooool000oooooo00?o0000ooooooooool0ooooool?oooo
o`003oooool00ol0003oooooooooo`3oooooo`oooooo000?ooooo`;o0000ooooool@ooooo`003ooo
ool00ol0003oooooooooo`3oooooo`oooooo000?ooooo`03o`000?oooooooooo0?oooooo3oooool0
00oooooo00?o0000ooooooooool0ooooool?ooooo`003oooool00ol0003oooooooooo`3oooooo`oo
oooo0000\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.250203, 0.705105, \
0.0165728, 0.0237659}}],

Cell[BoxData[
    TagBox[GridBox[{
          {"0.25`", "1.1481481481481481`"},
          {"0.5`", "1.1728395061728396`"},
          {"1", "1.1111111111111112`"},
          {"2", "2.9012345679012346`"},
          {"4", "3.259259259259259`"},
          {"6", "4.604938271604938`"},
          {"8", "4.814814814814815`"}
          },
        RowSpacings->1,
        ColumnSpacings->3,
        RowAlignments->Baseline,
        ColumnAlignments->{Left}],
      Function[ BoxForm`e$, 
        TableForm[ BoxForm`e$]]]], "Output",
  CellLabel->"Out[246]//TableForm="]
}, Open  ]],

Cell[TextData[{
  "To get a more accurate picture for small ",
  Cell[BoxData[
      \(TraditionalForm\`R\)]],
  ", run the graph back for a much longer time (T=100 instead of T=10).  This \
fits better, but it is still clear that the DJM prediction only holds for \
small R:"
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(tblNonNull2 = \({#, 
              Mean[Table[
                    Length[LineagesPresent[DeleteNullLineages[aa[#, 100]], 
                        t]], {t, 10, 100, 0.5}]] // N} &\) /@ {0.25, 0.5, 1, 
            1.5, 2};\)\), "\n", 
    \(\(DisplayTogether[
        Plot[1 + R - R\^2\/3 + \(13\/54\) R\^3, {R, 0, 2}, 
          PlotStyle \[Rule] Red], 
        ListPlot[tblNonNull2, PlotJoined \[Rule] True]];\)\), "\n", 
    \(tblNonNull2 // TableForm\)}], "Input",
  CellLabel->"In[247]:="],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.47619 -0.212318 0.227033 [
[.2619 .00222 -9 -9 ]
[.2619 .00222 9 0 ]
[.5 .00222 -3 -9 ]
[.5 .00222 3 0 ]
[.7381 .00222 -9 -9 ]
[.7381 .00222 9 0 ]
[.97619 .00222 -3 -9 ]
[.97619 .00222 3 0 ]
[.01131 .12823 -18 -4.5 ]
[.01131 .12823 0 4.5 ]
[.01131 .24175 -6 -4.5 ]
[.01131 .24175 0 4.5 ]
[.01131 .35526 -18 -4.5 ]
[.01131 .35526 0 4.5 ]
[.01131 .46878 -6 -4.5 ]
[.01131 .46878 0 4.5 ]
[.01131 .5823 -18 -4.5 ]
[.01131 .5823 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2619 .01472 m
.2619 .02097 L
s
[(0.5)] .2619 .00222 0 1 Mshowa
.5 .01472 m
.5 .02097 L
s
[(1)] .5 .00222 0 1 Mshowa
.7381 .01472 m
.7381 .02097 L
s
[(1.5)] .7381 .00222 0 1 Mshowa
.97619 .01472 m
.97619 .02097 L
s
[(2)] .97619 .00222 0 1 Mshowa
.125 Mabswid
.07143 .01472 m
.07143 .01847 L
s
.11905 .01472 m
.11905 .01847 L
s
.16667 .01472 m
.16667 .01847 L
s
.21429 .01472 m
.21429 .01847 L
s
.30952 .01472 m
.30952 .01847 L
s
.35714 .01472 m
.35714 .01847 L
s
.40476 .01472 m
.40476 .01847 L
s
.45238 .01472 m
.45238 .01847 L
s
.54762 .01472 m
.54762 .01847 L
s
.59524 .01472 m
.59524 .01847 L
s
.64286 .01472 m
.64286 .01847 L
s
.69048 .01472 m
.69048 .01847 L
s
.78571 .01472 m
.78571 .01847 L
s
.83333 .01472 m
.83333 .01847 L
s
.88095 .01472 m
.88095 .01847 L
s
.92857 .01472 m
.92857 .01847 L
s
.25 Mabswid
0 .01472 m
1 .01472 L
s
.02381 .12823 m
.03006 .12823 L
s
[(1.5)] .01131 .12823 1 0 Mshowa
.02381 .24175 m
.03006 .24175 L
s
[(2)] .01131 .24175 1 0 Mshowa
.02381 .35526 m
.03006 .35526 L
s
[(2.5)] .01131 .35526 1 0 Mshowa
.02381 .46878 m
.03006 .46878 L
s
[(3)] .01131 .46878 1 0 Mshowa
.02381 .5823 m
.03006 .5823 L
s
[(3.5)] .01131 .5823 1 0 Mshowa
.125 Mabswid
.02381 .03742 m
.02756 .03742 L
s
.02381 .06012 m
.02756 .06012 L
s
.02381 .08282 m
.02756 .08282 L
s
.02381 .10553 m
.02756 .10553 L
s
.02381 .15093 m
.02756 .15093 L
s
.02381 .17364 m
.02756 .17364 L
s
.02381 .19634 m
.02756 .19634 L
s
.02381 .21904 m
.02756 .21904 L
s
.02381 .26445 m
.02756 .26445 L
s
.02381 .28715 m
.02756 .28715 L
s
.02381 .30986 m
.02756 .30986 L
s
.02381 .33256 m
.02756 .33256 L
s
.02381 .37797 m
.02756 .37797 L
s
.02381 .40067 m
.02756 .40067 L
s
.02381 .42337 m
.02756 .42337 L
s
.02381 .44608 m
.02756 .44608 L
s
.02381 .49148 m
.02756 .49148 L
s
.02381 .51419 m
.02756 .51419 L
s
.02381 .53689 m
.02756 .53689 L
s
.02381 .55959 m
.02756 .55959 L
s
.02381 .605 m
.02756 .605 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
1 0 0 r
.5 Mabswid
.02381 .01472 m
.06244 .03267 L
.10458 .05131 L
.14415 .06814 L
.18221 .08387 L
.22272 .10033 L
.26171 .11607 L
.30316 .13289 L
.34309 .14939 L
.3815 .16572 L
.42237 .18377 L
.46172 .202 L
.49955 .2205 L
.53984 .24143 L
.57861 .26294 L
.61984 .2875 L
.65954 .31298 L
.69774 .33938 L
.73838 .36968 L
.77751 .40119 L
.81909 .4374 L
.85916 .47515 L
.89771 .51431 L
.93871 .55919 L
.97619 .60332 L
s
0 g
.14286 .05987 m
.2619 .1251 L
.5 .16398 L
.7381 .27436 L
.97619 .36969 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[250]:=",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/B000`400?l00000o`00003ooooooolQ
ooooo`00Coooool2o`0000Cooooo00?o0000ooooooooool00_ooool3o`0003Oooooo0ol0000hoooo
o`?o00001?ooool00ol0003oooooooooo`02ooooo`?o0000=oooool5o`0000Kooooo001>ooooo`04
o`000?ooooooooooo`0000Oooooo00Go0000ooooooooooooooooo`00000gooooo`03o`000?oooooo
oooo03Sooooo00?o0000ooooooooool01oooool01Ol0003ooooooooooooooooo000003Oooooo00Co
0000oooooooooooo00001_ooool004kooooo00Co0000oooooooooooo00002oooool00ol0003ooooo
ooooo`0eooooo`03o`000?oooooooooo03Sooooo00?o0000ooooooooool02oooool00ol0003ooooo
ooooo`0fooooo`03o`000?oooooooooo00Kooooo001>ooooo`04o`000?ooooooooooo`0000_ooooo
00?o0000ooooooooool0=Oooool00ol0003oooooooooo`0hooooo`03o`000?oooooooooo00_ooooo
00?o0000ooooooooool0=oooool00ol0003oooooooooo`05ooooo`00C_ooool01?l0003ooooooooo
ool00007ooooo`Co0000>?ooool00ol0003oooooooooo`0hooooo`03o`000?oooooooooo00Oooooo
1?l0000gooooo`05o`000?ooooooooooooooool000001_ooool004kooooo00Co0000oooooooooooo
00001oooool00ol0003oooooooooo`0hooooo`;o0000>Oooool2o`0000Wooooo00?o0000oooooooo
ool0>?ooool01Ol0003ooooooooooooooooo000000Kooooo001?ooooo`;o00002?ooool5o`0003Oo
oooo00?o0000ooooooooool0>?ooool00ol0003oooooooooo`07ooooo`Go0000=oooool3o`0000Oo
oooo000Eooooo`03o`000?oooooooooo0?oooooo2Oooool001Gooooo00?o0000ooooooooool0oooo
ool9ooooo`005Oooool00ol0003oooooooooo`3oooooo`Wooooo000Eooooo`03o`000?oooooooooo
0?oooooo2Oooool000kooooo1ol00002ool00?oo00002_l0000001Gooooo00Co0000oooooooo003o
o`002Oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00[ooooo00?o0000oooooooo
ool02_ooool00ol0003oooooooooo`0:ooooo`0300000?oooooooooo00[ooooo00?o0000oooooooo
ool02_ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00[ooooo00?o0000oooooooo
ool02Oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00[ooooo00?o0000oooooooo
ool02_ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00[ooooo00?o0000oooooooo
ool02_ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00[ooooo00?o0000oooooooo
ool02_ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00Gooooo000Eooooo`04o`00
0?ooooooooooooooo`;oo`00>oooool00`00003oooooooooo`0mooooo`03o`000?oooooooooo03ko
oooo00?o0000ooooooooool0?_ooool00ol0003oooooooooo`05ooooo`005Oooool00ol0003ooooo
ooooo`03ooooo`;oo`00ooooool4ooooo`005Oooool00ol0003oooooooooo`05ooooo`;oo`00oooo
ool2ooooo`005Oooool00ol0003oooooooooo`07ooooo`;oo`00ooooool001Gooooo0_l0000:oooo
o`?oo`00o?ooool001Gooooo00?o0000ooooooooool03?ooool2ool00?[ooooo000Eooooo`03o`00
0?oooooooooo00kooooo0_oo003hooooo`005Oooool00ol0003oooooooooo`0@ooooo`?oo`00mOoo
ool001Gooooo00?o0000ooooooooool04oooool2ool00??ooooo000Eooooo`03o`000?oooooooooo
01Gooooo0_oo003aooooo`005Oooool00ol0003oooooooooo`0Gooooo`?oo`000oooool2o`000>Wo
oooo000Eooooo`;o00006oooool2ool000?ooooo0_l0003Wooooo`005Oooool00ol0003ooooooooo
o`0Looooo`;oo`000oooool2o`000>Gooooo000Eooooo`03o`000?oooooooooo01kooooo0_oo0003
ooooo`03o`000?oooooooooo0>;ooooo000Eooooo`03o`000?oooooooooo023ooooo0ooo00000ooo
oooo0000o`00003Rooooo`005Oooool00ol0003oooooooooo`0Sooooo`;oo`0000?oooooo`000?l0
0000h?ooool001Gooooo00?o0000ooooooooool09Oooool3ool000;o0000g_ooool001Gooooo0_l0
000Yooooo`;oo`000_l0003Looooo`005Oooool00ol0003oooooooooo`0Zooooo`;oo`000_l0003J
ooooo`005Oooool00ol0003oooooooooo`0]ooooo`03ool00?l0003oo`000=Sooooo000Eooooo`03
o`000?oooooooooo02oooooo0_l00002ool00=Gooooo000Eooooo`03o`000?oooooooooo037ooooo
0_l00002ool00=?ooooo000Eooooo`03o`000?oooooooooo03?ooooo0_l00002ool00=7ooooo000E
ooooo`;o0000=_ooool2o`0000?oo`00c_ooool001Gooooo00?o0000ooooooooool0=oooool2o`00
0003oooooooo003oo`000<cooooo000Eooooo`03o`000?oooooooooo03Wooooo00?o0000oooooooo
ool00_oo003:ooooo`005Oooool00ol0003oooooooooo`0jooooo`;o00000_ooool2ool00<Sooooo
00001?oooooo0000o`000?l00004ooooo`03o`000?oooooooooo00;ooooo0ol00005ooooo`03o`00
0?oooooooooo03cooooo0_l00002ooooo`?oo`00aOooool000;ooooo00?o0000ooooooooool01ooo
ool01Ol0003ooooooooooooooooo000000Cooooo00?o0000ooooooooool0?_ooool4o`000004oooo
oooo003oo`00ool00<;ooooo0002ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool0
0_ooool3o`0004;ooooo1_l000000ooo003oooooooooo`2mooooo`000_ooool00ol0003ooooooooo
o`0;ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0B?ooool6o`000;[ooooo0002
ooooo`03o`000?oooooooooo00Oooooo1?l00005ooooo`03o`000?oooooooooo04_ooooo0_oo0000
0ooooooo0000o`000003o`000;Gooooo00000ooooooo0000o`000009ooooo`03o`000?oooooooooo
00Kooooo00?o0000ooooooooool0COooool3ool000?ooooo1_l0002_ooooo`000_ooool00ol0003o
ooooooooo`07ooooo`Go00001?ooool00ol0003oooooooooo`1@ooooo`;oo`001oooool6o`000:Wo
oooo000Eooooo`03o`000?oooooooooo05;ooooo0_oo000;ooooo`Ko0000Xoooool001Gooooo0_l0
001Eooooo`;oo`003oooool6o`0009gooooo000Eooooo`03o`000?oooooooooo05Kooooo0ooo000B
ooooo`Go0000V?ooool001Gooooo00?o0000ooooooooool0FOooool2ool001Gooooo1_l0002Boooo
o`005Oooool00ol0003oooooooooo`1Kooooo`?oo`006?ooool6o`0008cooooo000Eooooo`03o`00
0?oooooooooo05kooooo0_oo000Looooo`Co0000R?ooool001Gooooo00?o0000ooooooooool0H?oo
ool2ool001kooooo0_l00026ooooo`005Oooool2o`0006?ooooo0ooo000Mooooo`;o0000Q?ooool0
01Gooooo00?o0000ooooooooool0IOooool2ool001gooooo0ol00021ooooo`005Oooool00ol0003o
ooooooooo`1Wooooo`;oo`007_ooool2o`0007oooooo000Eooooo`03o`000?oooooooooo06Wooooo
0_oo000Nooooo`;o0000OOooool001Gooooo00?o0000ooooooooool0Joooool2ool001kooooo0_l0
001kooooo`005Oooool00ol0003oooooooooo`1]ooooo`?oo`007Oooool2o`0007Wooooo000Eoooo
o`03o`000?oooooooooo073ooooo0_oo000Mooooo`;o0000Moooool001Gooooo0_l0001cooooo`;o
o`007Oooool3o`0007Cooooo000Eooooo`03o`000?oooooooooo07Cooooo0_oo000Nooooo`;o0000
L_ooool001Gooooo00?o0000ooooooooool0M_ooool2ool001kooooo0_l0001`ooooo`005Oooool0
0ol0003oooooooooo`1hooooo`;oo`007_ooool2o`0006kooooo000Eooooo`03o`000?oooooooooo
07[ooooo0_oo000Nooooo`;o0000K?ooool001Gooooo00?o0000ooooooooool0O?ooool2ool001ko
oooo0_l0001Zooooo`005Oooool2o`0007oooooo0_oo000Nooooo`?o0000Ioooool001Gooooo00?o
0000ooooooooool0P?ooool2ool001oooooo0_l0001Uooooo`005Oooool00ol0003oooooooooo`22
ooooo`;oo`007oooool2o`0006?ooooo000<ooooo`Go00001?ooool00ol0003oooooooooo`24oooo
o`03ool00?oooooooooo01kooooo0_l0001Qooooo`003Oooool01?l0003oooooooooool00004oooo
o`03o`000?oooooooooo08Gooooo0_oo000Pooooo`;o0000Goooool000kooooo00?o0000oooooooo
ool01?ooool00ol0003oooooooooo`27ooooo`;oo`008?ooool2o`0005gooooo000?ooooo`03o`00
0?oooooooooo00?ooooo0ol00029ooooo`;oo`008?ooool3o`0005[ooooo000<ooooo`05o`000?oo
ooooooooooooool000001?ooool00ol0003oooooooooo`2;ooooo`;oo`008Oooool2o`0005Sooooo
000<ooooo`05o`000?ooooooooooooooool000001?ooool00ol0003oooooooooo`2=ooooo`;oo`00
8Oooool2o`0005Kooooo000=ooooo`?o00001Oooool00ol0003oooooooooo`2?ooooo`03ool00?oo
oooooooo023ooooo0_l0001Dooooo`005Oooool00ol0003oooooooooo`2@ooooo`;oo`008_ooool2
o`0005;ooooo000Eooooo`03o`000?oooooooooo09;ooooo0_oo000Rooooo`;o0000D?ooool001Go
oooo0_l0002Eooooo`;oo`008_ooool3o`0004gooooo000Eooooo`03o`000?oooooooooo09Kooooo
0_oo000Sooooo`;o0000Boooool001Gooooo00?o0000ooooooooool0V?ooool2ool002?ooooo0_l0
0019ooooo`005Oooool00ol0003oooooooooo`2Jooooo`03ool00?oooooooooo02;ooooo0_l00017
ooooo`005Oooool00ol0003oooooooooo`2Kooooo`;oo`009?ooool3o`0004Cooooo000Eooooo`03
o`000?oooooooooo09gooooo0_oo000Uooooo`;o0000@_ooool001Gooooo0_l0002Pooooo`;oo`00
9Oooool3o`0003oooooo000Eooooo`03o`000?oooooooooo0:7ooooo00?oo`00ooooooooool09Ooo
ool2o`0003gooooo000Eooooo`03o`000?oooooooooo0:;ooooo0_oo000Wooooo`?o0000>_ooool0
01Gooooo00?o0000ooooooooool0Y?ooool2ool002Sooooo0_l0000hooooo`005Oooool00ol0003o
ooooooooo`2Vooooo`03ool00?oooooooooo02Oooooo0ol0000eooooo`005Oooool00ol0003ooooo
ooooo`2Wooooo`;oo`00:_ooool2o`0003?ooooo000Eooooo`;o0000Z_ooool00ooo003ooooooooo
o`0Yooooo`?o0000<?ooool001Gooooo00?o0000ooooooooool0Z_ooool2ool002cooooo0_l0000^
ooooo`005Oooool00ol0003oooooooooo`2/ooooo`03ool00?oooooooooo02_ooooo0ol0000[oooo
o`005Oooool00ol0003oooooooooo`2]ooooo`;oo`00;_ooool2o`0002Wooooo000Eooooo`03o`00
0?oooooooooo0:oooooo00?oo`00ooooooooool0;Oooool3o`0002Kooooo000Eooooo`03o`000?oo
oooooooo0;3ooooo00?oo`00ooooooooool0;oooool2o`0002Cooooo000Eooooo`03o`000?oooooo
oooo0;7ooooo0_oo000aooooo`?o00008Oooool001Gooooo0_l0002dooooo`03ool00?oooooooooo
037ooooo0_l0000Oooooo`005Oooool00ol0003oooooooooo`2dooooo`;oo`00<oooool3o`0001co
oooo000Eooooo`03o`000?oooooooooo0;Kooooo00?oo`00ooooooooool0<oooool2o`0001[ooooo
0005o`0000?ooooo00?o0000ooooooooool00_ooool3o`0000Gooooo00?o0000ooooooooool0]ooo
ool00ooo003oooooooooo`0dooooo`?o00005oooool00005ooooool0003oooooooooool000001ooo
ool01Ol0003ooooooooooooooooo000000Cooooo00?o0000ooooooooool0^?ooool00ooo003ooooo
ooooo`0fooooo`;o00005Oooool000;ooooo00?o0000ooooooooool02oooool00ol0003ooooooooo
o`02ooooo`03o`000?oooooooooo0;Wooooo0_oo000hooooo`?o00004_ooool000?ooooo00?o0000
ooooooooool02_ooool00ol0003oooooooooo`02ooooo`?o0000^oooool00ooo003oooooooooo`0h
ooooo`;o00004?ooool00005o`000?ooooooooooooooool000001oooool4o`0000Gooooo00?o0000
ooooooooool0_?ooool00ooo003oooooooooo`0iooooo`?o00003Oooool00005o`000?oooooooooo
ooooool000001oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo0;gooooo00?oo`00
ooooooooool0>oooool2o`0000_ooooo00001?oooooo0000o`000?l00008ooooo`Go00001?ooool0
0ol0003oooooooooo`2nooooo`03ool00?oooooooooo03cooooo0ol00008ooooo`005Oooool00ol0
003oooooooooo`2oooooo`;oo`00?oooool00ol0003oooooooooo`05ooooo`005Oooool00ol0003o
ooooooooo`31ooooo`03ool00?oooooooooo04Cooooo000Eooooo`;o0000`oooool00ooo003ooooo
ooooo`13ooooo`005Oooool00ol0003oooooooooo`33ooooo`;oo`00@oooool001Gooooo00?o0000
ooooooooool0aOooool00ooo003oooooooooo`10ooooo`005Oooool00ol0003oooooooooo`36oooo
o`;oo`00@?ooool001Gooooo00?o0000ooooooooool0b?ooool00ooo003oooooooooo`0mooooo`00
5Oooool00ol0003oooooooooo`39ooooo`03ool00?oooooooooo03cooooo000Eooooo`;o0000booo
ool2ool003cooooo000Eooooo`03o`000?oooooooooo0<cooooo00?oo`00ooooooooool0>Oooool0
01Gooooo00?o0000ooooooooool0cOooool00ooo003oooooooooo`0hooooo`005Oooool00ol0003o
ooooooooo`3>ooooo`03ool00?oooooooooo03Oooooo000Eooooo`03o`000?oooooooooo0<oooooo
00?oo`00ooooooooool0=_ooool001Gooooo00?o0000ooooooooool0d?ooool00ooo003ooooooooo
o`0eooooo`005Oooool2o`000=;ooooo00?oo`00ooooooooool0=?ooool001Gooooo00?o0000oooo
ooooool0d_ooool00ooo003oooooooooo`0cooooo`005Oooool00ol0003oooooooooo`3Cooooo`03
ool00?oooooooooo03;ooooo000Eooooo`03o`000?oooooooooo0=Cooooo00?oo`00ooooooooool0
<Oooool001Gooooo00?o0000ooooooooool0eOooool2ool0037ooooo000Eooooo`03o`000?oooooo
oooo0=Oooooo00?oo`00ooooooooool0;_ooool001Gooooo00?o0000ooooooooool0f?ooool00ooo
003oooooooooo`0]ooooo`005Oooool2o`000=[ooooo00?oo`00ooooooooool0;?ooool001Gooooo
00?o0000ooooooooool0f_ooool00ooo003oooooooooo`0[ooooo`005Oooool00ol0003ooooooooo
o`3Kooooo`03ool00?oooooooooo02[ooooo000=ooooo`?o00001Oooool00ol0003oooooooooo`3L
ooooo`03ool00?oooooooooo02Wooooo000<ooooo`05o`000?ooooooooooooooool000001?ooool0
0ol0003oooooooooo`3Mooooo`03ool00?oooooooooo02Sooooo000@ooooo`03o`000?oooooooooo
00;ooooo00?o0000ooooooooool0g_ooool00ooo003oooooooooo`0Wooooo`003_ooool2o`0000Go
oooo0ol0003Oooooo`03ool00?oooooooooo02Kooooo000@ooooo`03o`000?oooooooooo00;ooooo
00?o0000ooooooooool0h?ooool00ooo003oooooooooo`0Uooooo`003?ooool01Ol0003ooooooooo
oooooooo000000Cooooo00?o0000ooooooooool0hOooool00ooo003oooooooooo`0Tooooo`003Ooo
ool3o`0000Gooooo00?o0000ooooooooool0h_ooool00ooo003oooooooooo`0Sooooo`005Oooool0
0ol0003oooooooooo`3Sooooo`03ool00?oooooooooo02;ooooo000Eooooo`03o`000?oooooooooo
0>Cooooo00?oo`00ooooooooool08Oooool001Gooooo0_l0003Vooooo`03ool00?oooooooooo023o
oooo000Eooooo`03o`000?oooooooooo0>Kooooo00?oo`00ooooooooool07oooool001Gooooo00?o
0000ooooooooool0ioooool00ooo003oooooooooo`0Nooooo`005Oooool00ol0003oooooooooo`3X
ooooo`03ool00?oooooooooo01gooooo000Eooooo`03o`000?oooooooooo0>Wooooo00?oo`00oooo
ooooool07?ooool001Gooooo00?o0000ooooooooool0j_ooool00ooo003oooooooooo`0Kooooo`00
5Oooool2o`000>cooooo00?oo`00ooooooooool06_ooool001Gooooo00?o0000ooooooooool0jooo
ool00ooo003oooooooooo`0Jooooo`005Oooool00ol0003oooooooooo`3/ooooo`03ool00?oooooo
oooo01Wooooo000Eooooo`03o`000?oooooooooo0>gooooo00?oo`00ooooooooool06?ooool001Go
oooo00?o0000ooooooooool0k_ooool00ooo003oooooooooo`0Gooooo`005Oooool00ol0003ooooo
ooooo`3_ooooo`03ool00?oooooooooo01Kooooo000Eooooo`;o0000lOooool00ooo003ooooooooo
o`0Eooooo`005Oooool00ol0003oooooooooo`3aooooo`03ool00?oooooooooo01Cooooo000Eoooo
o`03o`000?oooooooooo0?;ooooo00?oo`00ooooooooool04oooool001Gooooo00?o0000oooooooo
ool0loooool00ooo003oooooooooo`0Booooo`005Oooool00ol0003oooooooooo`3dooooo`03ool0
0?oooooooooo017ooooo000Eooooo`03o`000?oooooooooo0?Gooooo00?oo`00ooooooooool04?oo
ool001Gooooo0_l0003gooooo`03ool00?oooooooooo00oooooo000Eooooo`03o`000?oooooooooo
0?Kooooo00?oo`00ooooooooool03oooool001Gooooo00?o0000ooooooooool0moooool00ooo003o
ooooooooo`0>ooooo`005Oooool00ol0003oooooooooo`3hooooo`03ool00?oooooooooo00gooooo
00001?oooooo0000o`000?l00004ooooo`03o`000?oooooooooo00;ooooo0ol00005ooooo`03o`00
0?oooooooooo0?Wooooo00?oo`00ooooooooool03?ooool00005o`000?ooooooooooooooool00000
1oooool01Ol0003ooooooooooooooooo000000Cooooo00?o0000ooooooooool0n_ooool00ooo003o
ooooooooo`0;ooooo`001?ooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00;ooooo
00?o0000ooooooooool0noooool00ooo003oooooooooo`0:ooooo`000_ooool2o`0000cooooo00?o
0000ooooooooool00_ooool3o`000?_ooooo00?oo`00ooooooooool02_ooool000Cooooo00?o0000
ooooooooool01Oooool4o`0000Gooooo00?o0000ooooooooool0o?ooool00ooo003oooooooooo`09
ooooo`0000Go0000ooooooooooooooooo`000007ooooo`03o`000?oooooooooo00Kooooo00?o0000
ooooooooool0oOooool00ooo003oooooooooo`08ooooo`0000Coooooo`000?l0003o00002?ooool5
o`0000Cooooo00?o0000ooooooooool0o_ooool00ooo003oooooooooo`07ooooo`005Oooool00ol0
003oooooooooo`3oooooo`03ool00?oooooooooo00Kooooo000Eooooo`03o`000?oooooooooo0?oo
oooo0Oooool00ooo003oooooooooo`05ooooo`005Oooool2o`000?oooooo2_ooool001Gooooo00?o
0000ooooooooool0ooooool9ooooo`005Oooool00ol0003oooooooooo`3oooooo`Wooooo000Eoooo
o`03o`000?oooooooooo0?oooooo2Oooool00001\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.165192, 0.796094, \
0.00771848, 0.0161891}}],

Cell[BoxData[
    TagBox[GridBox[{
          {"0.25`", "1.1988950276243093`"},
          {"0.5`", "1.4861878453038675`"},
          {"1", "1.6574585635359116`"},
          {"1.5`", "2.143646408839779`"},
          {"2", "2.56353591160221`"}
          },
        RowSpacings->1,
        ColumnSpacings->3,
        RowAlignments->Baseline,
        ColumnAlignments->{Left}],
      Function[ BoxForm`e$, 
        TableForm[ BoxForm`e$]]]], "Output",
  CellLabel->"Out[251]//TableForm="]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData[{
  StyleBox["Q8: ",
    FontColor->RGBColor[0, 0, 1]],
  "What is expected in theory?  Recall that the rate of coalescence of ",
  Cell[BoxData[
      \(TraditionalForm\`k\)]],
  " lineages is ~ ",
  Cell[BoxData[
      \(TraditionalForm\`\(k(k - 1)\)\/2, \ \(\(and\)\(\ \)\(the\)\(\ \
\)\(rate\)\(\ \)\)\)]],
  "of recombination is ~ ",
  Cell[BoxData[
      \(TraditionalForm\`k\[VeryThinSpace]R\)]],
  " (scaling time to ",
  Cell[BoxData[
      \(TraditionalForm\`\(\(2  N\_e\)\()\)\)\)]]
}], "SubsubsectionIcon"],

Cell[TextData[{
  "A rough answer is that on average, the rate of decrease in ",
  Cell[BoxData[
      \(TraditionalForm\`k\)]],
  " through coalescence must equal the rate of increase through \
recombination.  Thus, ",
  Cell[BoxData[
      \(TraditionalForm\`\(k(k - 1)\)\/2 = k\[VeryThinSpace]R\)]],
  ", and so ",
  Cell[BoxData[
      \(TraditionalForm\`k = 1 + 2  R\)]],
  " on average.  "
}], "Text"],

Cell[TextData[{
  "To get a better answer, suppose that the distribution of number of \
lineages is ",
  Cell[BoxData[
      \(TraditionalForm\`f\_k\)]],
  ".  The ndistribution now must be made up of the number of lineages :"
}], "Text"],

Cell[BoxData[
    \(f\_k = \((1 - \((\(k \((k - 1)\)\)\/2 + 
                    k\[VeryThinSpace]R)\) \[Delta]t)\) 
          f\_k + \(\(k \((k + 1)\)\)\/2\) \[Delta]t\ f\_\(k + 1\) + \((k - 
              1)\) R\ \[Delta]t\ \[VeryThinSpace]f\_\(k - 1\)\)], \
"DisplayMath"],

Cell["Hence:", "Text"],

Cell[BoxData[
    \(\(\(\ \)\(f\_\(k + 1\)\  = \ \((\(2  k\[VeryThinSpace]R + k - 1\)\/\(k \
+ 1\))\) f\_k - \(2 \((k - 1)\) R\)\/\(k \((k + 1)\)\)\ \ \[VeryThinSpace]f\_\
\(k - 1\)\)\)\)], "DisplayMath"],

Cell["Calculating the first few values gives:", "Text"],

Cell[BoxData[
    \(\(f\_1\) {\ 1, R, \(2\ R\^2\)\/3, 
        R\^3\/3, \(2\ R\^4\)\/15, \(2\ R\^5\)\/45, \(4\ R\^6\)\/315, \
\(R\^7\/315\) \[Ellipsis]}\)], "DisplayMath"],

Cell[TextData[{
  "This is a Poisson distribution for ",
  Cell[BoxData[
      \(TraditionalForm\`\(\(k\)\(,\)\(\ \)\)\)]],
  "truncated at ",
  Cell[BoxData[
      \(TraditionalForm\`k = 1\)]],
  ".  The mean is ",
  Cell[BoxData[
      \(TraditionalForm\`E[
          k] = \(2  R\)\/\(1 - \[ExponentialE]\^\(\(-2\) R\)\)\)]],
  ", which fits well with the simulations (see red line above):"
}], "Text"],

Cell[BoxData[
    \(\(\(\ \)\(f\_k\  = \ \(\(\(\((2  
                      R)\)\^k\) \[ExponentialE]\^\(\(-2\) R\)\)\/\(k!\)\) 
        1\/\(1 - \[ExponentialE]\^\(\(-2\) R\)\)\)\)\)], "DisplayMath"],

Cell[TextData[{
  "This result is not very helpful, because the number of lineages that are \
",
  StyleBox["actually",
    FontSlant->"Italic"],
  " ancestral is much smaller than this for large ",
  Cell[BoxData[
      \(TraditionalForm\`R\)]],
  ".  As we saw above, the Derrida & Jung-Muller result does not predict this \
actual # very well: this is a hard problem.  At best, we can say that the \
distribution ",
  Cell[BoxData[
      \(TraditionalForm\`f\_k\)]],
  " is an upper bound."
}], "Text"]
}, Closed]]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Number & sizes of blocks",
  FontColor->RGBColor[0, 0, 1]]], "SubsectionIcon"],

Cell[CellGroupData[{

Cell[TextData[{
  StyleBox["Q9: ",
    FontColor->RGBColor[0, 0, 1]],
  "How does the mean block size depend on the map length, R?  What is the \
distribution of block sizes?"
}], "SubsubsectionIcon"],

Cell["\<\
This gives the mean block size for a genome of length R.  (Uses the \
results from aa[R,10] above, which simulated up to T=10).  Averaging starts \
at T=2 to avoid initial increase from 1 lineage to several\
\>", "Text"],

Cell[BoxData[
    \(\(mjt[R_] := 
        Mean[Table[\[IndentingNewLine]N[
              Mean[Mean /@ \((BlockSizes /@ 
                      DeleteNullLineages[\(ExtractLineage[
                              aa[R, 10], #] &\) \
/@ \[IndentingNewLine]LineagesPresent[aa[R, 10], t]])\)]], {t, 2, 10, 
              0.1}]];\)\)], "Input",
  CellLabel->"In[276]:="],

Cell["This is the mean block size plotted against map length:", "Text"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(tbl = \({#, mjt[#]} &\) /@ {0.25, 0.5, 1, 2, 4, 6, 8};\)\), "\n", 
    \(\(ListPlot[tbl, PlotJoined \[Rule] True, 
        PlotRange \[Rule] {{0, 10}, {0, 3}}];\)\), "\n", 
    \(tbl // TableForm\)}], "Input",
  CellLabel->"In[278]:="],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 0.1 0 0.206011 [
[.2 -0.0125 -3 -9 ]
[.2 -0.0125 3 0 ]
[.4 -0.0125 -3 -9 ]
[.4 -0.0125 3 0 ]
[.6 -0.0125 -3 -9 ]
[.6 -0.0125 3 0 ]
[.8 -0.0125 -3 -9 ]
[.8 -0.0125 3 0 ]
[1 -0.0125 -6 -9 ]
[1 -0.0125 6 0 ]
[-0.0125 .10301 -18 -4.5 ]
[-0.0125 .10301 0 4.5 ]
[-0.0125 .20601 -6 -4.5 ]
[-0.0125 .20601 0 4.5 ]
[-0.0125 .30902 -18 -4.5 ]
[-0.0125 .30902 0 4.5 ]
[-0.0125 .41202 -6 -4.5 ]
[-0.0125 .41202 0 4.5 ]
[-0.0125 .51503 -18 -4.5 ]
[-0.0125 .51503 0 4.5 ]
[-0.0125 .61803 -6 -4.5 ]
[-0.0125 .61803 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 0 m
.2 .00625 L
s
[(2)] .2 -0.0125 0 1 Mshowa
.4 0 m
.4 .00625 L
s
[(4)] .4 -0.0125 0 1 Mshowa
.6 0 m
.6 .00625 L
s
[(6)] .6 -0.0125 0 1 Mshowa
.8 0 m
.8 .00625 L
s
[(8)] .8 -0.0125 0 1 Mshowa
1 0 m
1 .00625 L
s
[(10)] 1 -0.0125 0 1 Mshowa
.125 Mabswid
.05 0 m
.05 .00375 L
s
.1 0 m
.1 .00375 L
s
.15 0 m
.15 .00375 L
s
.25 0 m
.25 .00375 L
s
.3 0 m
.3 .00375 L
s
.35 0 m
.35 .00375 L
s
.45 0 m
.45 .00375 L
s
.5 0 m
.5 .00375 L
s
.55 0 m
.55 .00375 L
s
.65 0 m
.65 .00375 L
s
.7 0 m
.7 .00375 L
s
.75 0 m
.75 .00375 L
s
.85 0 m
.85 .00375 L
s
.9 0 m
.9 .00375 L
s
.95 0 m
.95 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .10301 m
.00625 .10301 L
s
[(0.5)] -0.0125 .10301 1 0 Mshowa
0 .20601 m
.00625 .20601 L
s
[(1)] -0.0125 .20601 1 0 Mshowa
0 .30902 m
.00625 .30902 L
s
[(1.5)] -0.0125 .30902 1 0 Mshowa
0 .41202 m
.00625 .41202 L
s
[(2)] -0.0125 .41202 1 0 Mshowa
0 .51503 m
.00625 .51503 L
s
[(2.5)] -0.0125 .51503 1 0 Mshowa
0 .61803 m
.00625 .61803 L
s
[(3)] -0.0125 .61803 1 0 Mshowa
.125 Mabswid
0 .0206 m
.00375 .0206 L
s
0 .0412 m
.00375 .0412 L
s
0 .0618 m
.00375 .0618 L
s
0 .0824 m
.00375 .0824 L
s
0 .12361 m
.00375 .12361 L
s
0 .14421 m
.00375 .14421 L
s
0 .16481 m
.00375 .16481 L
s
0 .18541 m
.00375 .18541 L
s
0 .22661 m
.00375 .22661 L
s
0 .24721 m
.00375 .24721 L
s
0 .26781 m
.00375 .26781 L
s
0 .28842 m
.00375 .28842 L
s
0 .32962 m
.00375 .32962 L
s
0 .35022 m
.00375 .35022 L
s
0 .37082 m
.00375 .37082 L
s
0 .39142 m
.00375 .39142 L
s
0 .43262 m
.00375 .43262 L
s
0 .45322 m
.00375 .45322 L
s
0 .47383 m
.00375 .47383 L
s
0 .49443 m
.00375 .49443 L
s
0 .53563 m
.00375 .53563 L
s
0 .55623 m
.00375 .55623 L
s
0 .57683 m
.00375 .57683 L
s
0 .59743 m
.00375 .59743 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.025 .04769 m
.05 .0941 L
.1 .19457 L
.2 .16682 L
.4 .3167 L
.6 .40244 L
.8 .53055 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[282]:=",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/B000`400?l00000o`00003ooooooolQ
ooooo`00A_ooool5o`00037ooooo0ol0000`ooooo`?o0000<?ooool3o`0002kooooo0ol00004oooo
o`;o00001?ooool004Oooooo00Co0000oooooooooooo0000<_ooool00ol0003oooooooooo`0^oooo
o`05o`000?ooooooooooooooool00000;_ooool01Ol0003ooooooooooooooooo000002kooooo00?o
0000ooooooooool00_ooool01?l0003oooooooooool00003ooooo`00B?ooool00ol0003ooooooooo
o`0_ooooo`Go0000;oooool01Ol0003ooooooooooooooooo000002kooooo00Go0000oooooooooooo
ooooo`00000^ooooo`03o`000?oooooooooo00;ooooo00Co0000oooooooooooo00000oooool004Wo
oooo00?o0000ooooooooool0;_ooool01?l0003oooooooooool0000`ooooo`Co0000<?ooool3o`00
02oooooo00?o0000ooooooooool00_ooool01?l0003oooooooooool00003ooooo`00A_ooool01Ol0
003ooooooooooooooooo0000033ooooo00?o0000ooooool00000<?ooool00ol0003oooooooooo`0`
ooooo`05o`000?ooooooooooooooool00000;_ooool00ol0003oooooooooo`02ooooo`04o`000?oo
ooooooooo`0000?ooooo0016ooooo`05o`000?ooooooooooooooool00000<Oooool2o`00037ooooo
00?o0000ooooooooool0;oooool01Ol0003ooooooooooooooooo000002gooooo0_l00004ooooo`04
o`000?ooooooooooo`0000?ooooo0017ooooo`?o0000<oooool00ol0003oooooooooo`0`ooooo`;o
0000<?ooool3o`0002oooooo00?o0000ooooooooool00oooool2o`0000Cooooo003oooooob7ooooo
003oooooob7ooooo003oooooob7ooooo003oooooob7ooooo000Eoooooooo00001Ol00007ooooo`00
5Oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool0
2_ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool0
2_ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool0
2_ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool0
2_ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool0
2_ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool0
2_ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool0
1Oooool001Gooooo00?o0000ooooooooool0ooooool9ooooo`005Oooool00ol0003oooooooooo`3o
ooooo`Wooooo000Eooooo`03o`000?oooooooooo0?oooooo2Oooool001Gooooo0_l0003oooooo`[o
oooo000Eooooo`03o`000?oooooooooo0?oooooo2Oooool001Gooooo00?o0000ooooooooool0oooo
ool9ooooo`005Oooool00ol0003oooooooooo`3oooooo`Wooooo000Eooooo`03o`000?oooooooooo
0?oooooo2Oooool001Gooooo0_l0003oooooo`[ooooo000Eooooo`03o`000?oooooooooo0?oooooo
2Oooool001Gooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`3oooooo`;ooooo000E
ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0ooooool2ooooo`005Oooool00ol0
003oooooooooo`05ooooo`03o`000?oooooooooo0?oooooo0Oooool001Gooooo00?o0000oooooooo
ool01Oooool00ol0003oooooooooo`3oooooo`7ooooo000Eooooo`;o00001oooool00ol0003ooooo
ooooo`3oooooo`005Oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo0?oooooo000E
ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0o_ooool001Gooooo00?o0000oooo
ooooool01oooool00ol0003oooooooooo`3nooooo`005Oooool00ol0003oooooooooo`08ooooo`03
o`000?oooooooooo0?gooooo000Eooooo`;o00002Oooool00ol0003oooooooooo`3mooooo`005Ooo
ool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo0?cooooo000Eooooo`03o`000?oooooo
oooo00Wooooo00?o0000ooooooooool0o?ooool000;ooooo0_l00004ooooo`03o`000?oooooooooo
00;ooooo0ol00005ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool0noooool00005
ooooool0003oooooooooool000001oooool01Ol0003ooooooooooooooooo000000Cooooo00?o0000
ooooooooool02_ooool00ol0003oooooooooo`3kooooo`0000Goooooo`000?ooooooooooo`00000;
ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`3j
ooooo`0000Goooooo`000?ooooooooooo`00000;ooooo`03o`000?oooooooooo00;ooooo0ol0000;
ooooo`03o`000?oooooooooo0?[ooooo00001Ooooooo0000oooooooooooo000000Oooooo1?l00005
ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool0nOooool00005ooooool0003ooooo
ooooool000001oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00cooooo00?o0000
ooooooooool0nOooool000;ooooo0_l00008ooooo`Go00001?ooool00ol0003oooooooooo`0=oooo
o`03o`000?oooooooooo0?Sooooo000Eooooo`03o`000?oooooooooo00gooooo00?o0000oooooooo
ool0n?ooool001Gooooo0_l0000?ooooo`03o`000?oooooooooo0?Oooooo000Eooooo`03o`000?oo
oooooooo00kooooo00?o0000ooooooooool0moooool001Gooooo00?o0000ooooooooool03oooool0
0ol0003oooooooooo`3fooooo`005Oooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo
0?Kooooo000Eooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool0mOooool001Gooooo
0_l0000Aooooo`03o`000?oooooooooo0?Gooooo000Eooooo`03o`000?oooooooooo017ooooo00?o
0000ooooooooool0m?ooool001Gooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`3d
ooooo`005Oooool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo0??ooooo000Eooooo`03
o`000?oooooooooo01;ooooo00?o0000ooooooooool0loooool001Gooooo00?o0000ooooooooool0
4oooool00ol0003oooooooooo`3booooo`005Oooool2o`0001Cooooo00?o0000ooooooooool06Ooo
ool4o`000=Gooooo000Eooooo`03o`000?oooooooooo01Cooooo00?o0000ooooooooool05?ooool4
o`0000Cooooo00?o0000ooooooooool0d_ooool001Gooooo00?o0000ooooooooool05?ooool00ol0
003oooooooooo`0Aooooo`?o00002Oooool00ol0003oooooooooo`3Aooooo`005Oooool00ol0003o
ooooooooo`0Eooooo`03o`000?oooooooooo00cooooo1?l0000=ooooo`;o0000dOooool001Gooooo
00?o0000ooooooooool05Oooool00ol0003oooooooooo`08ooooo`Co00004oooool00ol0003ooooo
ooooo`3>ooooo`005Oooool2o`0001Oooooo00?o0000ooooooooool01?ooool3o`0001Sooooo00?o
0000ooooooooool0cOooool001Gooooo00?o0000ooooooooool05_ooool00ol0003oooooooooo`04
o`0001cooooo0_l0003=ooooo`005Oooool00ol0003oooooooooo`0Gooooo`;o00008_ooool00ol0
003oooooooooo`3:ooooo`003Oooool3o`0000Gooooo00?o0000ooooooooool0??ooool00ol0003o
ooooooooo`39ooooo`003_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo03gooooo
0_l00039ooooo`003_ooool00ol0003oooooooooo`04ooooo`?o0000?oooool00ol0003ooooooooo
o`36ooooo`003_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo043ooooo00?o0000
ooooooooool0aOooool000kooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`11oooo
o`;o0000aOooool000gooooo0_l00006ooooo`03o`000?oooooooooo04?ooooo00?o0000oooooooo
ool0`_ooool000kooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`14ooooo`03o`00
0?oooooooooo0<7ooooo000Eooooo`03o`000?oooooooooo04Gooooo0_l00031ooooo`005Oooool2
o`0004Sooooo00?o0000ooooooooool0__ooool001Gooooo00?o0000ooooooooool0B?ooool00ol0
003oooooooooo`2mooooo`005Oooool00ol0003oooooooooo`19ooooo`;o0000_Oooool001Gooooo
00?o0000ooooooooool0Boooool00ol0003oooooooooo`2jooooo`005Oooool00ol0003ooooooooo
o`1<ooooo`03o`000?oooooooooo0;Wooooo000Eooooo`;o0000C_ooool2o`000;Wooooo000Eoooo
o`03o`000?oooooooooo04oooooo00?o0000ooooooooool0]_ooool001Gooooo00?o0000oooooooo
ool0D?ooool00ol0003oooooooooo`2eooooo`005Oooool00ol0003oooooooooo`1Aooooo`;o0000
]Oooool001Gooooo00?o0000ooooooooool0Doooool00ol0003oooooooooo`2booooo`005Oooool2
o`0005Gooooo00?o0000ooooooooool0/Oooool001Gooooo00?o0000ooooooooool0EOooool2o`00
0;7ooooo000Eooooo`03o`000?oooooooooo05Oooooo00?o0000ooooooooool0[_ooool001Gooooo
00?o0000ooooooooool0F?ooool00ol0003oooooooooo`2]ooooo`005Oooool00ol0003ooooooooo
o`1Iooooo`;o0000[Oooool001Gooooo00?o0000ooooooooool0Foooool00ol0003oooooooooo`2Z
ooooo`005Oooool2o`0005gooooo00?o0000ooooooooool0ZOooool001Gooooo00?o0000oooooooo
ool0GOooool2o`000:Wooooo00001?oooooo0000o`000?l00004ooooo`03o`000?oooooooooo00;o
oooo0ol00005ooooo`03o`000?oooooooooo05oooooo00?o0000ooooooooool0Y_ooool000;ooooo
00?o0000ooooooooool01oooool01Ol0003ooooooooooooooooo000000Cooooo00?o0000oooooooo
ool0H?ooool00ol0003oooooooooo`2Uooooo`000_ooool00ol0003oooooooooo`0;ooooo`03o`00
0?oooooooooo00;ooooo00?o0000ooooooooool0HOooool2o`000:Gooooo0002ooooo`03o`000?oo
oooooooo00_ooooo00?o0000ooooooooool00_ooool3o`0006?ooooo00?o0000ooooooooool0X_oo
ool000;ooooo00?o0000ooooooooool01oooool4o`0000Gooooo00?o0000ooooooooool0I?ooool0
0ol0003oooooooooo`2Qooooo`0000?oooooo`000?l000002Oooool00ol0003oooooooooo`06oooo
o`03o`000?oooooooooo06Gooooo0_l0002Qooooo`000_ooool00ol0003oooooooooo`07ooooo`Go
00001?ooool00ol0003oooooooooo`1Wooooo`?o0000W_ooool001Gooooo00?o0000ooooooooool0
J_ooool2o`0009cooooo000Eooooo`;o0000KOooool2o`0009[ooooo000Eooooo`03o`000?oooooo
oooo06kooooo0ol0002Gooooo`005Oooool00ol0003oooooooooo`1aooooo`;o0000UOooool001Go
oooo00?o0000ooooooooool0Loooool2o`0009?ooooo000Eooooo`03o`000?oooooooooo07Gooooo
0ol0002@ooooo`005Oooool00ol0003oooooooooo`1hooooo`;o0000S_ooool001Gooooo0_l0001k
ooooo`;o0000S?ooool001Gooooo00?o0000ooooooooool0O?ooool3o`0008Wooooo000Eooooo`03
o`000?oooooooooo07oooooo0_l00027ooooo`005Oooool00ol0003oooooooooo`21ooooo`?o0000
Q?ooool001Gooooo00?o0000ooooooooool0Q?ooool2o`0008;ooooo000Eooooo`;o0000Qoooool2
o`00083ooooo000Eooooo`03o`000?oooooooooo08Sooooo0ol0001mooooo`005Oooool00ol0003o
ooooooooo`2;ooooo`;o0000Noooool001Gooooo00?o0000ooooooooool0SOooool2o`0007Wooooo
000Eooooo`03o`000?oooooooooo08oooooo0ol0001fooooo`005Oooool2o`0009?ooooo0_l0001d
ooooo`005Oooool00ol0003oooooooooo`2Dooooo`;o0000L_ooool001Gooooo00?o0000oooooooo
ool0U_ooool3o`0006oooooo000<ooooo`Go00001?ooool00ol0003oooooooooo`2Iooooo`;o0000
KOooool000gooooo00Co0000oooooooooooo00001?ooool00ol0003oooooooooo`2Kooooo`03o`00
0?oooooooooo06[ooooo000>ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0W?oo
ool2o`0006[ooooo000?ooooo`03o`000?oooooooooo00?ooooo0ol0002Nooooo`03o`000?oooooo
oooo06Oooooo000<ooooo`05o`000?ooooooooooooooool000001?ooool00ol0003oooooooooo`2O
ooooo`;o0000Ioooool000cooooo00Go0000ooooooooooooooooo`000004ooooo`03o`000?oooooo
oooo0:7ooooo0_l0001Uooooo`003Oooool3o`0000Gooooo00?o0000ooooooooool0Xoooool00ol0
003oooooooooo`1Rooooo`005Oooool00ol0003oooooooooo`2Tooooo`;o0000H_ooool001Gooooo
0_l0002Wooooo`03o`000?oooooooooo05oooooo000Eooooo`03o`000?oooooooooo0:Oooooo0_l0
001Oooooo`005Oooool00ol0003oooooooooo`2Yooooo`03o`000?oooooooooo05cooooo000Eoooo
o`03o`000?oooooooooo0:[ooooo0_l0001Looooo`005Oooool00ol0003oooooooooo`2/ooooo`03
o`000?oooooooooo05Wooooo000Eooooo`;o0000[_ooool2o`0005Wooooo000Eooooo`03o`000?oo
oooooooo0:oooooo00?o0000ooooooooool0E_ooool001Gooooo00?o0000ooooooooool0/?ooool2
o`0005Kooooo000Eooooo`03o`000?oooooooooo0;;ooooo0_l0001Dooooo`005Oooool00ol0003o
ooooooooo`2dooooo`03o`000?oooooooooo057ooooo000Eooooo`03o`000?oooooooooo0;Gooooo
0_l0001Aooooo`005Oooool2o`000;Sooooo00?o0000ooooooooool0C_ooool001Gooooo00?o0000
ooooooooool0^?ooool2o`0004kooooo000Eooooo`03o`000?oooooooooo0;[ooooo00?o0000oooo
ooooool0Boooool001Gooooo00?o0000ooooooooool0^oooool2o`0004_ooooo000Eooooo`03o`00
0?oooooooooo0;gooooo00?o0000ooooooooool0B?ooool001Gooooo0_l0002oooooo`;o0000B?oo
ool001Gooooo00?o0000ooooooooool0`?ooool00ol0003oooooooooo`15ooooo`005Oooool00ol0
003oooooooooo`31ooooo`;o0000AOooool000Go00000oooool00ol0003oooooooooo`02ooooo`?o
00001Oooool00ol0003oooooooooo`33ooooo`;o0000@oooool00005ooooool0003oooooooooool0
00001oooool01Ol0003ooooooooooooooooo000000Cooooo00?o0000ooooooooool0aOooool00ol0
003oooooooooo`10ooooo`000_ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00;o
oooo0ol00036ooooo`;o0000@?ooool000?ooooo00?o0000ooooooooool02_ooool00ol0003ooooo
ooooo`02ooooo`03o`000?oooooooooo0<Sooooo00?o0000ooooooooool0?Oooool00005o`000?oo
ooooooooooooool000001oooool4o`0000Gooooo00?o0000ooooooooool0bOooool2o`0003gooooo
00001Ol0003ooooooooooooooooo000000Oooooo00?o0000ooooooooool01_ooool00ol0003ooooo
ooooo`3;ooooo`03o`000?oooooooooo03[ooooo00001?oooooo0000o`000?l00008ooooo`Go0000
1?ooool00ol0003oooooooooo`3<ooooo`03o`000?oooooooooo03Wooooo000Eooooo`03o`000?oo
oooooooo0?oooooo2Oooool001Gooooo0_l0003oooooo`[ooooo000Eooooo`03o`000?oooooooooo
0?oooooo2Oooool001Gooooo00?o0000ooooooooool0ooooool9ooooo`005Oooool00ol0003ooooo
ooooo`3oooooo`Wooooo000Eooooo`03o`000?oooooooooo0?oooooo2Oooool001Gooooo0_l0003o
ooooo`[ooooo000Eooooo`03o`000?oooooooooo0?oooooo2Oooool001Gooooo00?o0000oooooooo
ool0ooooool9ooooo`005Oooool00ol0003oooooooooo`3oooooo`Wooooo000Eooooo`03o`000?oo
oooooooo0?oooooo2Oooool001Gooooo0_l0003oooooo`[ooooo000Eooooo`03o`000?oooooooooo
0?oooooo2Oooool001Gooooo00?o0000ooooooooool0ooooool9ooooo`005Oooool00ol0003ooooo
ooooo`3oooooo`Wooooo000Eooooo`03o`000?oooooooooo0?oooooo2Oooool001Gooooo00?o0000
ooooooooool0ooooool9ooooo`005Oooool2o`000?oooooo2_ooool001Gooooo00?o0000oooooooo
ool0ooooool9ooooo`003Oooool3o`0000Gooooo00?o0000ooooooooool0ooooool9ooooo`003?oo
ool01Ol0003ooooooooooooooooo000000Cooooo00?o0000ooooooooool0ooooool9ooooo`004?oo
ool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo0?oooooo2Oooool000kooooo0_l00005
ooooo`?o0000ooooool9ooooo`004?ooool00ol0003oooooooooo`3oooooo`kooooo000<ooooo`05
o`000?ooooooooooooooool00000ooooool@ooooo`003Oooool3o`000?oooooo4Oooool00?oooooo
8Oooool00001\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.830159, -0.229235, \
0.0385797, 0.018727}}],

Cell[BoxData[
    TagBox[GridBox[{
          {"0.25`", "0.23148148148148148`"},
          {"0.5`", "0.4567901234567901`"},
          {"1", "0.9444444444444444`"},
          {"2", "0.80977366255144`"},
          {"4", "1.5372976680384087`"},
          {"6", "1.9534978469502273`"},
          {"8", "2.5753293580806806`"}
          },
        RowSpacings->1,
        ColumnSpacings->3,
        RowAlignments->Baseline,
        ColumnAlignments->{Left}],
      Function[ BoxForm`e$, 
        TableForm[ BoxForm`e$]]]], "Output",
  CellLabel->"Out[283]//TableForm="]
}, Open  ]],

Cell["\<\
This increase is surprising: for large R, we would expect block \
size to be independent of map length, because ancestral lineages will have \
several blocks of 'average' size.  In fact, there is an appreciable chance of \
getting very long blocks when R is large, so that the mean block size does \
increase with map length. However, there is a problem in that the initial \
state of 1 long block may still be causing a bias: runs are needed over a \
longer time to rule this out.  After all, the Poisson distribution derived \
above as an upper bound should imply that large blocks are unlikely for large \
R, because it is unlikely that there will be one or a few ancestral lineages.\
\
\>", "Text"],

Cell["This generates the distribution of block sizes:", "Text"],

Cell[BoxData[
    \(\(bsd[R_] := \(bsd[R] = 
          Flatten[Table[
              BlockSizes /@ 
                DeleteNullLineages[\(ExtractLineage[
                        aa[R, 10], #] &\) \
/@ \[IndentingNewLine]LineagesPresent[aa[R, 10], t]], {t, 2, 10, 
                0.1}]]\);\)\)], "Input",
  CellLabel->"In[289]:="],

Cell["There is a tail of large blocks, of size ~ R:", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(DisplayTogether[\[IndentingNewLine]ListPlot[
          Transpose[{Range[0.05, 7.95, 0.1], 
              BinCounts[bsd[1], {0, 8, 0.1}]}], PlotJoined \[Rule] True], 
        ListPlot[
          Transpose[{Range[0.05, 7.95, 0.1], 
              BinCounts[bsd[2], {0, 8, 0.1}]}], PlotJoined \[Rule] True, 
          PlotStyle \[Rule] Red], 
        ListPlot[
          Transpose[{Range[0.05, 7.95, 0.1], 
              BinCounts[bsd[4], {0, 8, 0.1}]}], PlotJoined \[Rule] True, 
          PlotStyle \[Rule] Blue], 
        ListPlot[
          Transpose[{Range[0.05, 7.95, 0.1], 
              BinCounts[bsd[8], {0, 8, 0.1}]}], PlotJoined \[Rule] True, 
          PlotStyle \[Rule] 
            Green], \[IndentingNewLine]PlotRange \[Rule] {{0, 8}, {0, 
              150}}];\)\)], "Input",
  CellLabel->"In[301]:="],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 0.125 0 0.00412023 [
[.125 -0.0125 -3 -9 ]
[.125 -0.0125 3 0 ]
[.25 -0.0125 -3 -9 ]
[.25 -0.0125 3 0 ]
[.375 -0.0125 -3 -9 ]
[.375 -0.0125 3 0 ]
[.5 -0.0125 -3 -9 ]
[.5 -0.0125 3 0 ]
[.625 -0.0125 -3 -9 ]
[.625 -0.0125 3 0 ]
[.75 -0.0125 -3 -9 ]
[.75 -0.0125 3 0 ]
[.875 -0.0125 -3 -9 ]
[.875 -0.0125 3 0 ]
[1 -0.0125 -3 -9 ]
[1 -0.0125 3 0 ]
[-0.0125 .0824 -12 -4.5 ]
[-0.0125 .0824 0 4.5 ]
[-0.0125 .16481 -12 -4.5 ]
[-0.0125 .16481 0 4.5 ]
[-0.0125 .24721 -12 -4.5 ]
[-0.0125 .24721 0 4.5 ]
[-0.0125 .32962 -12 -4.5 ]
[-0.0125 .32962 0 4.5 ]
[-0.0125 .41202 -18 -4.5 ]
[-0.0125 .41202 0 4.5 ]
[-0.0125 .49443 -18 -4.5 ]
[-0.0125 .49443 0 4.5 ]
[-0.0125 .57683 -18 -4.5 ]
[-0.0125 .57683 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.125 0 m
.125 .00625 L
s
[(1)] .125 -0.0125 0 1 Mshowa
.25 0 m
.25 .00625 L
s
[(2)] .25 -0.0125 0 1 Mshowa
.375 0 m
.375 .00625 L
s
[(3)] .375 -0.0125 0 1 Mshowa
.5 0 m
.5 .00625 L
s
[(4)] .5 -0.0125 0 1 Mshowa
.625 0 m
.625 .00625 L
s
[(5)] .625 -0.0125 0 1 Mshowa
.75 0 m
.75 .00625 L
s
[(6)] .75 -0.0125 0 1 Mshowa
.875 0 m
.875 .00625 L
s
[(7)] .875 -0.0125 0 1 Mshowa
1 0 m
1 .00625 L
s
[(8)] 1 -0.0125 0 1 Mshowa
.125 Mabswid
.025 0 m
.025 .00375 L
s
.05 0 m
.05 .00375 L
s
.075 0 m
.075 .00375 L
s
.1 0 m
.1 .00375 L
s
.15 0 m
.15 .00375 L
s
.175 0 m
.175 .00375 L
s
.2 0 m
.2 .00375 L
s
.225 0 m
.225 .00375 L
s
.275 0 m
.275 .00375 L
s
.3 0 m
.3 .00375 L
s
.325 0 m
.325 .00375 L
s
.35 0 m
.35 .00375 L
s
.4 0 m
.4 .00375 L
s
.425 0 m
.425 .00375 L
s
.45 0 m
.45 .00375 L
s
.475 0 m
.475 .00375 L
s
.525 0 m
.525 .00375 L
s
.55 0 m
.55 .00375 L
s
.575 0 m
.575 .00375 L
s
.6 0 m
.6 .00375 L
s
.65 0 m
.65 .00375 L
s
.675 0 m
.675 .00375 L
s
.7 0 m
.7 .00375 L
s
.725 0 m
.725 .00375 L
s
.775 0 m
.775 .00375 L
s
.8 0 m
.8 .00375 L
s
.825 0 m
.825 .00375 L
s
.85 0 m
.85 .00375 L
s
.9 0 m
.9 .00375 L
s
.925 0 m
.925 .00375 L
s
.95 0 m
.95 .00375 L
s
.975 0 m
.975 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .0824 m
.00625 .0824 L
s
[(20)] -0.0125 .0824 1 0 Mshowa
0 .16481 m
.00625 .16481 L
s
[(40)] -0.0125 .16481 1 0 Mshowa
0 .24721 m
.00625 .24721 L
s
[(60)] -0.0125 .24721 1 0 Mshowa
0 .32962 m
.00625 .32962 L
s
[(80)] -0.0125 .32962 1 0 Mshowa
0 .41202 m
.00625 .41202 L
s
[(100)] -0.0125 .41202 1 0 Mshowa
0 .49443 m
.00625 .49443 L
s
[(120)] -0.0125 .49443 1 0 Mshowa
0 .57683 m
.00625 .57683 L
s
[(140)] -0.0125 .57683 1 0 Mshowa
.125 Mabswid
0 .0206 m
.00375 .0206 L
s
0 .0412 m
.00375 .0412 L
s
0 .0618 m
.00375 .0618 L
s
0 .10301 m
.00375 .10301 L
s
0 .12361 m
.00375 .12361 L
s
0 .14421 m
.00375 .14421 L
s
0 .18541 m
.00375 .18541 L
s
0 .20601 m
.00375 .20601 L
s
0 .22661 m
.00375 .22661 L
s
0 .26781 m
.00375 .26781 L
s
0 .28842 m
.00375 .28842 L
s
0 .30902 m
.00375 .30902 L
s
0 .35022 m
.00375 .35022 L
s
0 .37082 m
.00375 .37082 L
s
0 .39142 m
.00375 .39142 L
s
0 .43262 m
.00375 .43262 L
s
0 .45322 m
.00375 .45322 L
s
0 .47383 m
.00375 .47383 L
s
0 .51503 m
.00375 .51503 L
s
0 .53563 m
.00375 .53563 L
s
0 .55623 m
.00375 .55623 L
s
0 .59743 m
.00375 .59743 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.00625 0 m
.01875 .01648 L
.03125 .0412 L
.04375 0 L
.05625 .01648 L
.06875 .01648 L
.08125 0 L
.09375 .0412 L
.10625 .01648 L
.11875 .29666 L
.13125 0 L
.14375 0 L
.15625 0 L
.16875 0 L
.18125 0 L
.19375 0 L
.20625 0 L
.21875 0 L
.23125 0 L
.24375 0 L
.25625 0 L
.26875 0 L
.28125 0 L
.29375 0 L
.30625 0 L
.31875 0 L
.33125 0 L
.34375 0 L
.35625 0 L
.36875 0 L
.38125 0 L
.39375 0 L
.40625 0 L
.41875 0 L
.43125 0 L
.44375 0 L
.45625 0 L
.46875 0 L
.48125 0 L
.49375 0 L
.50625 0 L
.51875 0 L
.53125 0 L
.54375 0 L
.55625 0 L
.56875 0 L
.58125 0 L
.59375 0 L
.60625 0 L
.61875 0 L
Mistroke
.63125 0 L
.64375 0 L
.65625 0 L
.66875 0 L
.68125 0 L
.69375 0 L
.70625 0 L
.71875 0 L
.73125 0 L
.74375 0 L
.75625 0 L
.76875 0 L
.78125 0 L
.79375 0 L
.80625 0 L
.81875 0 L
.83125 0 L
.84375 0 L
.85625 0 L
.86875 0 L
.88125 0 L
.89375 0 L
.90625 0 L
.91875 0 L
.93125 0 L
.94375 0 L
.95625 0 L
.96875 0 L
.98125 0 L
.99375 0 L
Mfstroke
1 0 0 r
.00625 .24721 m
.01875 .0824 L
.03125 .14009 L
.04375 .21837 L
.05625 .54799 L
.06875 .05356 L
.08125 .21425 L
.09375 .07416 L
.10625 .14421 L
.11875 .21013 L
.13125 .0618 L
.14375 .09477 L
.15625 .04532 L
.16875 .04944 L
.18125 .07828 L
.19375 .29666 L
.20625 .03296 L
.21875 .02884 L
.23125 0 L
.24375 .01236 L
.25625 0 L
.26875 0 L
.28125 0 L
.29375 0 L
.30625 0 L
.31875 0 L
.33125 0 L
.34375 0 L
.35625 0 L
.36875 0 L
.38125 0 L
.39375 0 L
.40625 0 L
.41875 0 L
.43125 0 L
.44375 0 L
.45625 0 L
.46875 0 L
.48125 0 L
.49375 0 L
.50625 0 L
.51875 0 L
.53125 0 L
.54375 0 L
.55625 0 L
.56875 0 L
.58125 0 L
.59375 0 L
.60625 0 L
.61875 0 L
Mistroke
.63125 0 L
.64375 0 L
.65625 0 L
.66875 0 L
.68125 0 L
.69375 0 L
.70625 0 L
.71875 0 L
.73125 0 L
.74375 0 L
.75625 0 L
.76875 0 L
.78125 0 L
.79375 0 L
.80625 0 L
.81875 0 L
.83125 0 L
.84375 0 L
.85625 0 L
.86875 0 L
.88125 0 L
.89375 0 L
.90625 0 L
.91875 0 L
.93125 0 L
.94375 0 L
.95625 0 L
.96875 0 L
.98125 0 L
.99375 0 L
Mfstroke
0 0 1 r
.00625 .20189 m
.01875 .14833 L
.03125 .0618 L
.04375 .0618 L
.05625 .04532 L
.06875 .3667 L
.08125 .12361 L
.09375 .20601 L
.10625 .16481 L
.11875 .03296 L
.13125 .14009 L
.14375 .00412 L
.15625 .14421 L
.16875 .05356 L
.18125 .03296 L
.19375 .04944 L
.20625 .05768 L
.21875 .17305 L
.23125 .10713 L
.24375 .05356 L
.25625 .14009 L
.26875 .15657 L
.28125 .05356 L
.29375 .06592 L
.30625 .03296 L
.31875 .0206 L
.33125 .04944 L
.34375 .00824 L
.35625 0 L
.36875 .05768 L
.38125 .00412 L
.39375 .05356 L
.40625 .0618 L
.41875 .0206 L
.43125 .10301 L
.44375 0 L
.45625 .01648 L
.46875 .01236 L
.48125 .03296 L
.49375 .00412 L
.50625 0 L
.51875 0 L
.53125 0 L
.54375 0 L
.55625 0 L
.56875 0 L
.58125 0 L
.59375 0 L
.60625 0 L
.61875 0 L
Mistroke
.63125 0 L
.64375 0 L
.65625 0 L
.66875 0 L
.68125 0 L
.69375 0 L
.70625 0 L
.71875 0 L
.73125 0 L
.74375 0 L
.75625 0 L
.76875 0 L
.78125 0 L
.79375 0 L
.80625 0 L
.81875 0 L
.83125 0 L
.84375 0 L
.85625 0 L
.86875 0 L
.88125 0 L
.89375 0 L
.90625 0 L
.91875 0 L
.93125 0 L
.94375 0 L
.95625 0 L
.96875 0 L
.98125 0 L
.99375 0 L
Mfstroke
0 1 0 r
.00625 .52327 m
.01875 .18541 L
.03125 .10301 L
.04375 .13597 L
.05625 .15245 L
.06875 .23897 L
.08125 .11949 L
.09375 .29254 L
.10625 .10301 L
.11875 .01236 L
.13125 .07416 L
.14375 .33786 L
.15625 .47795 L
.16875 .18129 L
.18125 .17717 L
.19375 .02884 L
.20625 .0618 L
.21875 .11125 L
.23125 .03296 L
.24375 .01236 L
.25625 .09477 L
.26875 .08652 L
.28125 .0824 L
.29375 .0618 L
.30625 .10713 L
.31875 .0412 L
.33125 .03708 L
.34375 .00824 L
.35625 .03296 L
.36875 .03296 L
.38125 .02472 L
.39375 .10301 L
.40625 .00412 L
.41875 .01648 L
.43125 .01648 L
.44375 .14009 L
.45625 .08652 L
.46875 .10713 L
.48125 .04944 L
.49375 .03708 L
.50625 .02884 L
.51875 .05356 L
.53125 .07416 L
.54375 .11125 L
.55625 .06592 L
.56875 .00824 L
.58125 0 L
.59375 0 L
.60625 .03708 L
.61875 .00412 L
Mistroke
.63125 .00412 L
.64375 .00412 L
.65625 0 L
.66875 .06592 L
.68125 .04944 L
.69375 .01648 L
.70625 0 L
.71875 .00824 L
.73125 .00412 L
.74375 .0412 L
.75625 .00412 L
.76875 .02472 L
.78125 .05356 L
.79375 .0206 L
.80625 .0206 L
.81875 .05356 L
.83125 .04532 L
.84375 .01236 L
.85625 .07416 L
.86875 .00412 L
.88125 0 L
.89375 .02884 L
.90625 .08652 L
.91875 .0206 L
.93125 .00824 L
.94375 .00412 L
.95625 .00824 L
.96875 0 L
.98125 0 L
.99375 .09064 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[301]:=",
  ImageSize->{464.75, 287.25},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40007@00017b000`400?l00000o`00003ooooooooA
ooooo`00oooooooAooooo`00C?ooool3o`0003;ooooo1Ol0000cooooo`?o0000=Oooool3o`0003;o
oooo0ol0000dooooo`?o0000=Oooool00ol0003oooooooooo`0booooo`?o00000oooool004gooooo
00?o0000ooooooooool0<_ooool01?l0003oooooooooool0000booooo`05o`000?oooooooooooooo
ool00000=Oooool00ol0003oooooooooo`0`ooooo`05o`000?ooooooooooooooool00000<_ooool0
1Ol0003ooooooooooooooooo000003Cooooo00?o0000ooooooooool0<Oooool01Ol0003ooooooooo
oooooooo000000;ooooo001=ooooo`03o`000?oooooooooo03?ooooo00?o0000ooooooooool0=_oo
ool00ol0003oooooooooo`0`ooooo`Go0000=Oooool00ol0003oooooooooo`0`ooooo`05o`000?oo
ooooooooooooool00000=Oooool00ol0003oooooooooo`0`ooooo`05o`000?ooooooooooooooool0
00000_ooool004gooooo00?o0000ooooooooool0=?ooool00ol0003oooooooooo`0cooooo`;o0000
<oooool01?l0003oooooooooool0000fooooo`03o`000?oooooooooo033ooooo1?l0000fooooo`03
o`000?oooooooooo037ooooo0ol00003ooooo`00COooool00ol0003oooooooooo`0aooooo`05o`00
0?ooooooooooooooool00000=_ooool00ol0003oooooooooo`0aooooo`03o`000?oooooo000003;o
oooo1?l0000cooooo`03o`000?oooooooooo03Sooooo00?o0000ooooooooool0;oooool01Ol0003o
oooooooooooooooo000000;ooooo001<ooooo`;o0000<oooool01Ol0003ooooooooooooooooo0000
03;ooooo00Go0000ooooooooooooooooo`00000dooooo`;o0000<_ooool00ol0003oooooooooo`0e
ooooo`03o`000?oooooooooo03?ooooo00Go0000ooooooooooooooooo`00000aooooo`05o`000?oo
ooooooooooooool000000_ooool004gooooo00?o0000ooooooooool0<_ooool3o`0003Cooooo0ol0
000fooooo`03o`000?oooooooooo033ooooo1Ol0000dooooo`;o0000<oooool5o`0003;ooooo0ol0
0003ooooo`00oooooooAooooo`00oooooooAooooo`00oooooooAooooo`00oooooooAooooo`00oooo
oooAooooo`00oooooooAooooo`005ooooomUo`0000030?l00?l0003o000000So0000:`3o00020000
obD0o`0000<0003o0?l0003o00005`3o000Q0000o`So0?l06@000?l2003o01D0003o0P00o`190000
o`800?l09@000?l7003o00H0003o0_l00003ooooo`005oooool01?l0003oooooooooool00007oooo
o`03o`000?oooooooooo00Gooooo00Co0000oooooooooooo00002_ooool00ol0003oooooo`000008
ooooo`03o`000?oooooooooo00Sooooo00<00000ooooool000002?ooool00ol0003oooooooooo`07
ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`02
0?l000Kooooo00Co0000ooooooooool0o`001oooool00ol0003oooooooooo`08ooooo`03o`000?oo
oooooooo00Sooooo00?o0000ooooooooool02?ooool01?l00000003oooooo`000?l7ooooo`03o`00
0?oooooooooo00Sooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`05ooooo`040000
ooooooooooooo`0000[ooooo00?o0000ooooooooool01_ooool30000o`[ooooo00?o0000oooooooo
ool01oooool00ol0003oooooooooo`08ooooo`03o`000?l0o`3ooooo00Kooooo00?o0?l0ooooool0
00002_ooool00ol0003oooooooooo`07ooooo`<00?l000?ooooo003o0?ooool01_ooool00ol0003o
ooooooooo`08ooooo`06o`000?oooooooooo003o0?ooool00?l01Oooool00ol0003oooooooooo`08
ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`08
ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool01_ooool3003o0003ooooo`00o`3o
oooo00Oooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`08ooooo`03o`000?oooooo
oooo00Cooooo00D00?l0ooooooooooooooooo`000002ooooo`03003o0?oooooooooo00Gooooo00?o
0000ooooooooool00Oooool001Oooooo00Go0000ooooooooooooooooo`000006ooooo`03o`000?oo
oooooooo00Gooooo0_l000000ooooooo0000ooooo`09ooooo`;o000000?oooooo`000?ooool01_oo
ool00ol0003oooooooooo`08ooooo`0300000?oooooo000000Gooooo00@0003ooooooooooooo0000
2Oooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooo`3o0000
0_ooool00`3o003oooooooooo`03ooooo`03o`000?ooool0o`0000Sooooo00?o0000ooooooooool0
2?ooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00Oooooo0P000?l2ooooo`030000
oooooooooooo00Gooooo00Co0000ooooooooool0003o1oooool01?l0003oooooooooool0o`07oooo
o`03o`000?oooooooooo00Gooooo0P000?l00ooooooo0000ooooo`09ooooo`03o`000?oooooooooo
00Gooooo00@0003ooooooooooooo00002_ooool00ol0003oooooooooo`07ooooo`03o`000?oooooo
oooo00Sooooo00?o0?l0ooooooooool01_ooool00ol0o`3oooooo`000008ooooo``00?l000Gooooo
o`000?oooooooooo003o0007ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooo`00o`000ooo
ool00`00o`3oooooooooo`02ooooo`04o`000?ooool00?l0003o00Oooooo00Co0000ooooooooool0
0?l01oooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00Sooooo00?o0000oooooooo
ool02?ooool00ol0003oooooooooo`05ooooo`04003o0?ooooooooooo`0000;ooooo00<00?l0oooo
ooooool01Oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Gooooo0`00o`000ol0
003oooooooooo`02ooooo`800?l01?ooool01?l0003oooooooooo`00o`07ooooo`03o`000?oooooo
oooo007ooooo000Gooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool02_ooool01?l0
003oooooooooool0000;ooooo`04o`000?ooooooooooo`0001;ooooo00<00000ooooool000001Ooo
ool00`000?ooooooooooo`0Rooooo`050?l00?ooooooooooooooo`3o00001?ooool00ol00000o`00
ooooo`0Wooooo`030000oooooooooooo00;ooooo00<0003oooooooooool01Oooool01?l0003ooooo
ooooo`000?l:ooooo`03o`3o0?oooooooooo00gooooo00<0003oooooo`000?l04oooool010000?oo
ooooooooool0000Nooooo`03o`3o0?oooooooooo00Sooooo00?o0?l0ooooooooool01oooool00ol0
o`3oooooo`00000=ooooo`03003o0?oooooooooo017ooooo00<00?l0ooooooooool00oooool00`00
o`3oooooooooo`03003o0003ooooo`00o`3ooooo00Kooooo00Co0000ooooooooool00?l0<?ooool0
1000o`3oooooooooool00002ooooo`03003o0?oooooooooo01Cooooo0`00o`03ooooo`<00?l000?o
oooo003o0?ooool02?ooool00`00o`3oooooooooo`05ooooo`03o`000?oooooooooo007ooooo000G
ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool02_ooool01Ol0003ooooooooooooo
oooo000000[ooooo00Co0000oooooooooooo00005?ooool00ol0003oooooooooo`03ooooo`030000
oooooooooooo02;ooooo00<0o`00ooooooooool00_ooool01@3o003oooooooooooooool0o`0002So
oooo00?o0?l0ooooooooool01?ooool00`000?ooooooooooo`07ooooo`030000oooooooooooo00So
oooo0_l0o`0>ooooo`030000ooooool0003o01;ooooo00<0003oooooooooool07oooool00ol0o`3o
ooooooooo`09ooooo`03o`3o0?oooooooooo00Kooooo00?o0?l0ooooooooool03oooool00`00o`3o
ooooooooo`0?ooooo`03003o0?oooooooooo00Gooooo0P00o`04ooooo`03003o0?oooooooooo00Oo
oooo00<00?l0ooooo`00o`00;oooool00`00o`3oooooooooo`04ooooo`03003o0?oooooooooo017o
oooo0P00o`09ooooo`03003o0?oooooooooo00Wooooo00<00?l0ooooooooool02?ooool001Oooooo
00?o0000ooooooooool00oooool00ol0003oooooooooo`09ooooo`05o`000?ooooooooooooooool0
00002Oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo017ooooo00?o0000oooooooo
ool00oooool00`000?ooooooooooo`0Qooooo`030?l00?oooooooooo00Cooooo00<0o`00ooooo`3o
0000:Oooool00ol0o`3oooooooooo`04ooooo`030000oooooooooooo00Kooooo00<0003oooooo`00
0?l02Oooool00ol0o`3oooooo`3o000=ooooo`040000oooooooooooo0000oa7ooooo00<0003ooooo
ooooool07oooool00ol0o`3oooooooooo`09ooooo`03o`3o0?oooooooooo00Kooooo00?o0?l0oooo
ooooool03oooool00`00o`3oooooooooo`0?ooooo`03003o0?oooooooooo00cooooo00<00?l0oooo
ooooool01_ooool00`00o`3ooooo003o000_ooooo`03003o0?oooooooooo00Cooooo00<00?l0oooo
ooooool04?ooool00`00o`3oooooooooo`0Eooooo`03003o0?oooooooooo00Sooooo000Gooooo`03
o`000?oooooooooo00?ooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`03ooooo`03
o`000?oooooooooo00Kooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`0<ooooo`03
o`3o0?oooooooooo00;ooooo00?o0000ooooooooool00oooool00`000?ooooooooooo`0Qooooo`03
0?l00?oooooooooo00Gooooo00?o0?l0ooooooooool09oooool00ol0o`00003oo`3o0005ooooo`03
0000oooooooooooo00Kooooo00<0003oooooo`000?l02Oooool01?l0o`3oooooooooool0o`0;oooo
o`050000ooooooooooooooooo`000?l01_ooool20000o`Sooooo00<0003oooooooooool08?ooool0
0ol0o`3oooooooooo`0:ooooo`03o`3o0?oooooooooo00Gooooo00?o0?l0ooooooooool03oooool0
0`00o`3oooooooooo`0>ooooo`03003o0?oooooooooo00gooooo00<00?l0ooooooooool01_ooool0
1000o`3oooooooooo`00o`0Sooooo`03003o0?oooooooooo00Oooooo00<00?l0ooooooooool01_oo
ool00`00o`3oooooooooo`0>ooooo`03003o0?oooooooooo01Kooooo00<00?l0ooooooooool02?oo
ool001Oooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooo
oooo00Cooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooo
oooo00cooooo00?o0?l0ooooooooool00_ooool00ol0003oooooooooo`03ooooo`030000oooooooo
oooo023ooooo00<0o`00ooooooooool01_ooool00ol0o`3oooooooooo`0Wooooo`03o`3o0?oooooo
0?l000Gooooo00<0003oooooooooool01_ooool00`000?oooooo0000o`08ooooo`03o`3o0?oooooo
oooo00;ooooo00?o0?l0ooooooooool02?ooool00`000?ooooooooooo`02ooooo`030000oooooooo
oooo00<0003o00?ooooo0000ooooool01oooool00`000?ooooooooooo`0Oooooo`03o`3o0?oooooo
oooo00_ooooo00?o0?l0ooooooooool01?ooool00ol0o`3oooooooooo`0@ooooo`03003o0?oooooo
oooo00gooooo00<00?l0ooooooooool03_ooool00`00o`3oooooooooo`05ooooo`03003o0?oooooo
oooo00;ooooo00<00?l0ooooooooool08?ooool00`00o`3oooooooooo`07ooooo`03003o0?oooooo
oooo00Kooooo00<00?l0ooooooooool03Oooool00`00o`3oooooooooo`0Gooooo`03003o0?oooooo
oooo00Sooooo000Gooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01_ooool00ol0
003oooooooooo`05ooooo`Ko00001oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo
00?ooooo00?o0?l0ooooooooool00_ooool00ol0003oooooooooo`02ooooo`80003o8_ooool00`3o
003oooooooooo`05ooooo`;o0?l0:Oooool01?l0o`3oooooooooool0o`04ooooo`030000oooooooo
oooo00Kooooo00<0003oooooo`000?l02?ooool00ol0o`3oooooooooo`03ooooo`Oo0?l00oooool0
0`000?ooooooooooo`03ooooo`80003o1Oooool00`000?ooooooooooo`04ooooo`030000oooooooo
oooo023ooooo00?o0?l0ooooooooool02oooool00ol0o`3oooooooooo`04ooooo`03o`3o0?oooooo
oooo013ooooo00<00?l0ooooooooool03?ooool00`00o`3oooooooooo`0@ooooo`03003o0?oooooo
oooo00Cooooo00<00?l0ooooooooool00_ooool00`00o`3oooooooooo`0Oooooo`800?l02Oooool0
0`00o`3oooooooooo`06ooooo`03003o0?oooooooooo00cooooo00<00?l0ooooooooool06?ooool0
0`00o`3oooooooooo`08ooooo`005oooool3o`0000Gooooo00?o0000ooooooooool01_ooool00ol0
003oooooooooo`0Booooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool00oooool00ol0
o`3oooooooooo`02ooooo`03o`000?oooooooooo00;ooooo00<0003oooooo`000?l08Oooool00`3o
003oooooooooo`04ooooo`03o`3o0?oooooo0?l001oooooo00<0003oooooooooool01_ooool01Ol0
o`00003ooooooooooooo0?l000Gooooo00<0003oooooooooool01?ooool010000?ooooooooooo`00
0?l8ooooo`03o`3o0?oooooooooo00?ooooo00<0003oooooooooool00oooool01Ol0o`3ooooooooo
ooooool0003o00cooooo00<0003oooooooooool01?ooool00`000?ooooooooooo`0Pooooo`03o`3o
0?oooooooooo00cooooo00?o0?l0ooooooooool00_ooool00ol0o`3oooooooooo`0Aooooo`03003o
0?oooooooooo00cooooo00<00?l0ooooooooool04?ooool00`00o`3oooooooooo`04ooooo`03003o
0?oooooooooo00?ooooo00<00?l0ooooooooool02Oooool7003o00kooooo0P00o`09ooooo`03003o
0?oooooooooo00Oooooo00<00?l0ooooooooool02_ooool00`00o`3oooooooooo`0Iooooo`03003o
0?oooooooooo00Sooooo000Gooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01?oo
ool00ol0003oooooooooo`0Cooooo`03o`000?oooooooooo00Cooooo0_l00004ooooo`03o`3o0?oo
oooo0?l000?ooooo00?o0000ooooooooool00_ooool00`000?oooooo0000o`0Pooooo`030?l00?oo
oooooooo00Gooooo00?o0?l0ooooool0o`007oooool00`000?ooooooooooo`06ooooo`03o`3o0?oo
oooooooo00;ooooo00?o0?l0ooooooooool00_ooool00`000?ooooooooooo`04ooooo`050000oooo
ooooooooooooo`000?l01oooool00ol0o`3oooooooooo`03ooooo`030000oooooooooooo00?ooooo
00Go0?l0oooooooooooooooo0000o`0=ooooo`030000oooooooooooo00?ooooo00<0003ooooooooo
ool08?ooool00ol0o`3oooooooooo`0<ooooo`03o`3o0?oooooooooo00;ooooo00?o0?l0oooooooo
ool04_ooool00`00o`3oooooooooo`0:ooooo`03003o0?oooooooooo017ooooo00<00?l0oooooooo
ool00oooool00`00o`3oooooooooo`04ooooo`03003o0?oooooooooo00Wooooo00<00?l0oooooooo
ool00oooool00`00o`3oooooooooo`0;ooooo`04003o0?oooooooooo003o00Sooooo00<00?l0oooo
ooooool01oooool00`00o`3oooooooooo`0:ooooo`03003o0?oooooooooo01Wooooo00<00?l0oooo
ooooool02?ooool001Oooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`03ooooo`03
o`000?oooooooooo01Cooooo00?o0000ooooooooool00oooool2o`0000Cooooo00?o0?l0ooooool0
o`000oooool00ol0003oooooooooo`02ooooo`030000ooooool0003o023ooooo00<0o`00oooooooo
ool01?ooool01Ol0o`3ooooooooooooooooo0?l001gooooo00<0003oooooo`000?l01_ooool00ol0
o`00003oooooo`04ooooo`05o`3o0?ooooooooooooooo`000?l01_ooool01@000?oo0?l0o`3o0?oo
ool0003o00Oooooo00?o0?l0ooooooooool00oooool00`000?ooooooooooo`03ooooo`05o`3o0?oo
ooooooooooooo`000?l03_ooool01@000?ooooooooooooooool0003o02;ooooo00?o0?l0oooooooo
ool03Oooool00ol0o`3oooooooooo`02ooooo`03o`3o0?oooooooooo01;ooooo00<00?l0oooooooo
ool02_ooool00`00o`3oooooooooo`0Booooo`03003o0?oooooooooo00;ooooo00<00?l0oooooooo
ool01Oooool00`00o`3oooooooooo`07ooooo`03003o0?oooooooooo00Gooooo00<00?l0oooooooo
ool02_ooool01000o`3oooooooooo`00o`07ooooo`03003o0?oooooooooo00Wooooo00<00?l0oooo
ooooool02Oooool00`00o`3oooooooooo`0Jooooo`03003o0?oooooooooo00Oooooo000Gooooo`03
o`000?oooooooooo00Oooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`0Dooooo`03
o`000?oooooooooo00;ooooo00?o0000ooooool000001?ooool00ol0o`3oooooo`3o0003ooooo`03
o`000?oooooooooo00;ooooo00<0003oooooo`000?l08?ooool00`3o003oooooooooo`03ooooo`03
o`3o0?oooooooooo00;ooooo00?o0?l0ooooooooool06_ooool010000?ooooooooooo`000?l6oooo
o`03o`3o00000?oooooo00Cooooo00Go0?l0oooooooooooooooo0000o`06ooooo`05o`3o0?oooooo
0?l0ooooo`000?l01oooool00ol0o`3oooooooooo`02ooooo`80003o1Oooool01Ol0o`3ooooooooo
ooooool0003o00kooooo00D0003ooooooooooooooooo0000o`0Rooooo`03o`3o0?oooooooooo00go
oooo00Go0?l0ooooooooooooooooo`3o000Eooooo`03003o0?oooooooooo00[ooooo00<00?l0oooo
ooooool04_ooool01@00o`3oooooooooooooool00?l000Sooooo00<00?l0ooooooooool01oooool0
0`00o`3oooooooooo`05ooooo`03003o0?oooooooooo00[ooooo00@00?l0ooooooooool00?l01ooo
ool00`00o`3oooooooooo`09ooooo`03003o0?oooooooooo00Sooooo00<00?l0ooooooooool06ooo
ool00`00o`3oooooooooo`07ooooo`005oooool00ol0003oooooooooo`08ooooo`03o`000?oooooo
oooo00;ooooo00?o0000ooooooooool05?ooool00ol0003oooooooooo`02ooooo`03o`000?oooooo
000000Cooooo00?o0?l0ooooool0o`000oooool00ol0003oooooooooo`02ooooo`030000ooooool0
003o01Cooooo00?o0?l0ooooooooool01oooool20?l000Kooooo00?o0?l0ooooooooool00_ooool0
0ol0o`3oooooooooo`0Iooooo`030000oooooooooooo00;ooooo00<0003oooooooooool00oooool0
0ol0o`00003oooooo`05ooooo`04o`3o0?oooooooooo0000o`Cooooo0_l0o`02ooooo`03o`3o0?oo
ool0003o00Oooooo00?o0?l0ooooooooool00_ooool00`000?oooooo0000o`04ooooo`05o`3o0?oo
ooooooooooooo`000?l03oooool00`000?oooooo0000o`08ooooo`;o0?l06Oooool00ol0o`3ooooo
ooooo`0>ooooo`04o`3o0?ooooooooooo`3o01Gooooo00<00?l0ooooooooool02Oooool00`00o`3o
ooooooooo`0Cooooo`05003o0?ooooooooooooooo`00o`002Oooool00`00o`3oooooooooo`06oooo
o`03003o0?oooooooooo00Gooooo00<00?l0ooooooooool02Oooool01@00o`3oooooooooooooool0
0?l000Oooooo00<00?l0ooooooooool02_ooool00`00o`3oooooooooo`07ooooo`03003o0?oooooo
oooo01_ooooo00<00?l0ooooooooool01oooool001Oooooo00?o0000ooooooooool02?ooool01Ol0
003ooooooooooooooooo000001Sooooo00Co0000oooooooooooo00000_ooool00ol0003ooooooooo
o`02ooooo`03o`3o0?oooooo0?l000;ooooo00?o0000ooooooooool00oooool00`000?oooooo0000
o`0Dooooo`03o`3o0?oooooooooo00Cooooo0`3o0007ooooo`03o`3o0?oooooooooo00?ooooo00?o
0?l0ooooooooool06?ooool00`000?ooooooooooo`03ooooo`030000oooooooooooo00;ooooo00?o
0?l00000ooooool01_ooool01Ol0o`3oooooooooooooool0003o00;ooooo00?o0?l0ooooo`000?l0
0_ooool01?l0o`3oooooooooo`000?l5ooooo`03o`3o0?oooooooooo00?ooooo00<0003oooooo`00
0?l01Oooool01?l0o`3oooooooooo`000?l?ooooo`030000ooooool0003o00Oooooo00?o0?l0oooo
ool0o`006Oooool00ol0o`3oooooooooo`0>ooooo`03o`3o0?oooooo0?l001Kooooo00<00?l0oooo
ooooool02Oooool00`00o`3oooooooooo`0Dooooo`04003o0?oooooooooo003o00Wooooo00<00?l0
ooooooooool01Oooool00`00o`3oooooooooo`07ooooo`03003o0?oooooooooo00Sooooo00D00?l0
oooooooooooooooo003o0007ooooo`03003o0?oooooooooo00[ooooo00<00?l0ooooooooool01ooo
ool00`00o`3oooooooooo`0Kooooo`03003o0?oooooooooo00Oooooo000Gooooo`03o`000?oooooo
oooo00Wooooo00Co0000oooooooooooo00006?ooool01?l0003oooooooooool00002ooooo`03o`00
0?oooooooooo00;ooooo00Ko0?l00000oooooooo0?l0ooooool00005ooooo`030000ooooool0003o
00kooooo00<0003oooooooooool00oooool2o`3o00?ooooo0P3o0009ooooo`03o`3o0?oooooooooo
00Cooooo00?o0?l0ooooooooool05oooool00`000?ooooooooooo`05ooooo`060000oooooooooooo
ooooool0o`00003o2?ooool6o`3o00;ooooo00L0003oooooooooooooooooo`3o0?ooool0003o00Go
oooo00?o0?l0ooooooooool00oooool00`000?oooooo0000o`05ooooo`03o`3o0?ooool0003o017o
oooo00<0003oooooooooool01Oooool01Ol0o`3ooooooooooooooooo0?l001Oooooo00?o0?l0oooo
ooooool03oooool00ol0o`3oooooo`3o000Gooooo`03003o0?oooooooooo00Sooooo00<00?l0oooo
ooooool05?ooool00`00o`3ooooo003o000;ooooo`03003o0?oooooooooo00Cooooo00<00?l0oooo
ooooool01oooool00`00o`3oooooooooo`07ooooo`03003o0?oooooooooo00?ooooo00<00?l0oooo
ooooool01?ooool00`00o`3oooooooooo`0:ooooo`03003o0?oooooooooo00Oooooo00<00?l0oooo
ooooool06oooool00`00o`3oooooooooo`07ooooo`005oooool00ol0003oooooooooo`0:ooooo`03
o`000?oooooo000001Sooooo00?o0000ooooool000000oooool00ol0003oooooooooo`02ooooo`06
o`3o00000?ooooooo`3o0?oooooo00001Oooool00`000?oooooo0000o`0>ooooo`030000oooooooo
oooo00?ooooo0_l0o`03ooooo`030?l00?oooooooooo00Sooooo00?o0?l0ooooooooool01?ooool0
0ol0o`3oooooooooo`0Gooooo`030000oooooooooooo00Gooooo00H0003oooooooooooooooooo`3o
00000?l;ooooo`030000oooooooooooo00;ooooo00L0003oooooooooooooooooo`3o0?ooool0003o
00Gooooo00?o0?l0ooooooooool00_ooool010000?ooooooooooo`000?l5ooooo`03o`3o0?ooool0
003o01Sooooo00?o0?l0ooooooooool00_ooool00ol0o`3oooooooooo`0Eooooo`03o`3o0?oooooo
oooo013ooooo0_l0o`0Gooooo`03003o0?oooooooooo00Oooooo00<00?l0ooooooooool05Oooool0
0`00o`3ooooo003o000;ooooo`03003o0?oooooooooo00Cooooo00<00?l0ooooooooool01oooool0
0`00o`3oooooooooo`07ooooo`03003o0?oooooooooo00?ooooo00<00?l0ooooooooool00oooool0
0`00o`3oooooooooo`0<ooooo`03003o0?oooooooooo00Kooooo00<00?l0ooooooooool06oooool0
0`00o`3oooooooooo`07ooooo`005oooool00ol0003oooooooooo`0:ooooo`;o00006_ooool2o`00
00?ooooo00_o0000ooooooooooooooooo`3o0?ooool0003oooooool0o`3oooooo`000005ooooo`03
0000ooooool0003o00gooooo00<0003oooooo`000?l01?ooool2o`3o00?ooooo00<0o`00oooooooo
ool02?ooool00ol0o`3oooooooooo`04ooooo`03o`3o0?oooooooooo01Kooooo00<0003ooooooooo
ool01_ooool4o`3o0003ooooo`000?oooooo00[ooooo00D0003ooooooooooooooooo0000o`04oooo
o`03o`3o0?ooool0003o00Gooooo00?o0?l0ooooooooool00_ooool010000?ooooooooooo`000?l5
ooooo`03o`3o0?ooool0003o01Kooooo0_l0o`06ooooo`03o`3o0?oooooooooo01Cooooo00?o0?l0
ooooooooool04?ooool00ol0o`3oooooooooo`0Fooooo`03003o0?oooooooooo00Oooooo00<00?l0
ooooooooool05_ooool2003o00cooooo00<00?l0ooooooooool00_ooool00`00o`3oooooooooo`09
ooooo`03003o0?oooooooooo00Gooooo00<00?l0ooooooooool01?ooool00`00o`3oooooooooo`03
ooooo`03003o0?oooooooooo00cooooo00<00?l0ooooooooool01Oooool00`00o`3oooooooooo`0L
ooooo`03003o0?oooooooooo00Oooooo000Gooooo`?o00002oooool00ol0003oooooooooo`0Hoooo
o`03o`000?oooooooooo00;ooooo00_o0000ooooooooooooooooo`3o0?ooool0003oooooool0o`3o
ooooo`000004ooooo`040000oooooooooooo0000o`gooooo00@0003oooooooooool0003o0oooool0
0ol0o`3oooooo`3o0002ooooo`030?l00?oooooooooo00Sooooo00?o0?l0ooooooooool01Oooool0
0ol0o`3oooooooooo`0Eooooo`030000oooooooooooo00?ooooo0ol0o`001Oooool0003ooooooooo
ool0003o00cooooo00D0003ooooooooooooooooo0000o`04ooooo`04o`3o0?oooooooooo0000o`Co
oooo00?o0?l0ooooooooool00_ooool010000?ooooooooooo`000?l5ooooo`03o`3o0?ooool0003o
01Gooooo00?o0?l0ooooooooool01_ooool00ol0o`3oooooooooo`0Dooooo`03o`3o0?oooooooooo
02Wooooo00<00?l0ooooooooool01oooool00`00o`3oooooooooo`0Fooooo`03003o0?oooooooooo
00_ooooo00<00?l0ooooooooool00_ooool00`00o`3oooooooooo`09ooooo`03003o0?oooooooooo
00Gooooo00<00?l0ooooooooool01?ooool00`00o`3oooooooooo`03ooooo`03003o0?oooooooooo
00cooooo00<00?l0ooooooooool01Oooool00`00o`3oooooooooo`0Mooooo`03003o0?oooooooooo
00Kooooo000Gooooo`03o`000?oooooooooo02cooooo00[o0000oooooooooooo0?l0ooooo`000?oo
ooooo`3o0?oooooo00001?ooool010000?ooooooooooo`000?l<ooooo`030000oooooooooooo00;o
oooo00<0003oooooool0o`000_ooool01?l0o`3oooooooooo`3o0009ooooo`03o`3o0?oooooooooo
00Kooooo00?o0?l0ooooooooool05?ooool00`000?ooooooooooo`04ooooo`05o`3o0?oooooooooo
ooooo`000?l00_ooool00`000?ooooooooooo`0;ooooo`040000oooooooooooo0000o`Cooooo00Co
0?l0ooooooooool0003o1?ooool01Ol0o`3oooooooooooooool0003o00Cooooo00<0003ooooooooo
ool00_ooool00ol0o`3ooooo0000o`0Dooooo`03o`3o0?oooooooooo00Sooooo00?o0?l0oooooooo
ool04oooool00ol0o`3oooooooooo`0Yooooo`03003o0?oooooooooo00Kooooo00<00?l0oooooooo
ool09Oooool00`00o`3oooooooooo`02ooooo`03003o0?oooooooooo00Wooooo00<00?l0oooooooo
ool01Oooool00`00o`3oooooooooo`04ooooo`03003o0?oooooooooo00?ooooo00<00?l0oooooooo
ool03?ooool00`00o`3oooooooooo`05ooooo`03003o0?oooooooooo01gooooo00<00?l0oooooooo
ool01_ooool001Oooooo00?o0000ooooooooool05_ooool00`000?ooooooooooo`0Cooooo`06o`00
0?ooooooooooo`3o0?ooool0003o0_ooool00ol0o`3o0000ooooo`03ooooo`040000oooooooooooo
0000o`?ooooo0`3o0005ooooo`030000oooooooooooo00Cooooo00D0003oo`3o0?ooooooooooo`3o
0002ooooo`030?l00?oooooooooo00Oooooo00?o0?l0ooooooooool01_ooool00ol0o`3ooooooooo
o`0Dooooo`030000oooooooooooo00Cooooo00?o0?l0ooooooooool00_ooool00`000?oooooo0000
o`0=ooooo`040000oooooooooooo0000o`Cooooo00Co0?l0ooooooooool0003o1?ooool01Ol0o`3o
ooooooooooooool0003o00Cooooo00<0003oooooooooool00_ooool00ol0o`3ooooo0000o`0Coooo
o`03o`3o0?oooooooooo00[ooooo00?o0?l0ooooooooool04Oooool00ol0o`3oooooooooo`0Zoooo
o`03003o0?oooooooooo00Kooooo00<00?l0ooooooooool09_ooool01000o`3oooooooooo`00o`0=
ooooo`03003o0?oooooooooo00;ooooo0P00o`08ooooo`03003o0?oooooooooo00;ooooo00<00?l0
ooooooooool03?ooool00`00o`3oooooooooo`05ooooo`03003o0?oooooooooo01gooooo00<00?l0
ooooooooool01_ooool001Oooooo00?o0000ooooooooool05_ooool00`000?ooooooooooo`0Coooo
o`0:o`000?ooooooooooo`3o00000?oooooo0000oooooooo0?l0o`0000Cooooo00@0003ooooooooo
ool0003o0oooool00`3o003oooooooooo`030?l000;ooooo00<0003oooooooooool01Oooool01ol0
o`3ooooooooooooooooo0?l0ooooo`3o00002Oooool00ol0o`3oooooooooo`06ooooo`03o`3o0?oo
oooooooo01Cooooo00<0003oooooooooool01?ooool00ol0o`3oooooooooo`02ooooo`80003o3_oo
ool00`000?oooooo0000o`05ooooo`04o`3o0?oooooooooo0000o`?ooooo00?o0?l0ooooooooool0
0_ooool00`000?ooooooooooo`02ooooo`030000oooooooooooo00;ooooo00?o0?l0ooooo`000?l0
4_ooool00ol0o`3oooooooooo`0;ooooo`03o`3o0?oooooooooo017ooooo00?o0?l0ooooooooool0
:oooool00`00o`3oooooooooo`05ooooo`03003o0?oooooooooo02Kooooo00@00?l0ooooooooool0
0?l03Oooool01@00o`3oooooooooooooool00?l000[ooooo00D00?l0oooooooooooooooo003o000@
ooooo`03003o0?oooooooooo00Cooooo00<00?l0ooooooooool07Oooool00`00o`3oooooooooo`06
ooooo`005oooool00ol0003oooooooooo`0Eooooo`80003o5Oooool02_l0003oooooooooool0o`00
003oooooo`000?ooooooo`3o0?l00004ooooo`050000ooooooooooooooooo`000?l00_ooool00`3o
003oooooooooo`03ooooo`030?l000000?oooooo00Oooooo00Oo0?l00000o`000?ooooooo`3o0?oo
ool0o`0000Wooooo00?o0?l0ooooooooool01_ooool00ol0o`3oooooooooo`0Cooooo`030000oooo
oooooooo00Cooooo00?o0?l0ooooooooool01?ooool00`000?ooooooooooo`0<ooooo`030000oooo
ool0003o00Kooooo00?o0?l0ooooo`000?l00oooool00ol0o`3oooooooooo`02ooooo`030000oooo
oooooooo00;ooooo00<0003oooooooooool00_ooool00ol0o`3ooooo0000o`0Aooooo`03o`3o0?oo
oooooooo00gooooo00?o0?l0ooooooooool04?ooool00ol0o`3oooooooooo`0[ooooo`03003o0?oo
oooooooo00Cooooo00<00?l0ooooooooool0:?ooool00`00o`3ooooo003o000=ooooo`04003o0?oo
oooooooo003o00_ooooo00D00?l0oooooooooooooooo003o000@ooooo`03003o0?oooooooooo00?o
oooo00<00?l0ooooooooool07_ooool00`00o`3oooooooooo`06ooooo`005oooool00ol0003ooooo
ooooo`0Dooooo`030000ooooool0003o01Gooooo00[o0000oooooooooooo0?l00000ooooool0003o
ooooool0o`3o00001?ooool01`000?ooooooooooooooool0003oooooo`3o00001_ooool00`3o0000
003oooooo`07ooooo`07o`3o0?oooooooooo0000ool0o`3ooooo0?l00009ooooo`03o`3o0?oooooo
oooo00Kooooo00?o0?l0ooooooooool04oooool00`000?ooooooooooo`04ooooo`03o`3o0?oooooo
oooo01?ooooo00<0003oooooo`000?l01_ooool01?l0o`3oooooooooo`000?l2ooooo`05o`3o0?oo
ooooooooooooo`000?l01Oooool00`000?ooooooooooo`02ooooo`03o`3o0?ooool0003o017ooooo
00?o0?l0ooooooooool03Oooool00ol0o`3oooooooooo`0@ooooo`03o`3o0?oooooooooo02_ooooo
00<00?l0ooooooooool01?ooool00`00o`3oooooooooo`0Xooooo`800?l03oooool2003o00cooooo
00D00?l0oooooooooooooooo003o000@ooooo`03003o0?oooooooooo00?ooooo00<00?l0oooooooo
ool07_ooool00`00o`3oooooooooo`06ooooo`005oooool00ol0003oooooooooo`0Cooooo`040000
oooooooooooo0000o`Cooooo00<0o`00ooooooooool03_ooool02_l0003oooooo`3o0?ooool0003o
ooooo`000?ooooooo`3o0?l00004ooooo`070000ooooooooooooooooo`000?oooooo0?l00006oooo
o`030000o`3o003ooooo00Oooooo00Oo0?l0oooooooooooooooo0000ool0o`00o`0000Wooooo00?o
0?l0ooooooooool01?ooool00`000?ooooooo`3o000=ooooo`030000oooooooooooo00Cooooo00<0
003oooooooooool01Oooool00ol0o`3oooooooooo`0Dooooo`80003o1_ooool00ol0o`3ooooooooo
o`020000o`03ooooool0o`3ooooo00;ooooo00<0003oooooooooool00oooool00`000?oooooooooo
o`02ooooo`03o`3o00000?oooooo017ooooo00?o0?l0ooooooooool03_ooool00ol0o`3ooooooooo
o`0>ooooo`03o`3o0?oooooooooo02cooooo00<00?l0ooooooooool00oooool00`00o`3ooooooooo
o`0Zooooo`03003o0?oooooooooo00gooooo00<00?l0ooooooooool02oooool01@00o`3ooooooooo
ooooool00?l0013ooooo00<00?l0ooooooooool00oooool00`00o`3oooooooooo`0Oooooo`03003o
0?oooooooooo00Gooooo000Gooooo`03o`000?oooooooooo01?ooooo00@0003oooooooooool0003o
1?ooool00`3o003oooooooooo`0>ooooo`0:o`000?oooooo0?l0ooooo`000?oooooo0000oooooooo
0?l0o`0000Cooooo00L0003ooooooooooooooooo0000ooooool0o`0000Kooooo00<0003o0?l00?oo
ool01oooool00ol0o`3oooooooooo`02ooooo`03o`3o003o003ooooo00Sooooo00?o0?l0oooooooo
ool01?ooool010000?ooooooooooool0o`0<ooooo`80003o1Oooool00`000?ooooooooooo`05oooo
o`03o`3o0?oooooooooo01Cooooo00<0003oooooooooool01Oooool00ol0o`3oooooooooo`02oooo
o`030000ool0o`3ooooo00;ooooo00<0003oooooooooool01?ooool00`000?ooooooooooo`02oooo
o`03o`3o0?oooooooooo00oooooo00?o0?l0ooooooooool03oooool00ol0o`3oooooooooo`0>oooo
o`03o`3o0?oooooooooo02cooooo00<00?l0ooooooooool00_ooool00`00o`3oooooooooo`19oooo
o`05003o0?ooooooooooooooo`00o`004?ooool00`00o`3oooooooooo`03ooooo`03003o0?oooooo
oooo01oooooo00<00?l0ooooooooool01Oooool001Oooooo00?o0000ooooooooool04_ooool01@00
0?ooooooooooooooool0003o00Cooooo00<0o`00ooooooooool03_ooool01ol0003oooooo`3o0?oo
ool0003oooooo`000?l00_ooool00ol0o`3oooooooooo`02ooooo`070000ooooooooooooooooo`00
0?oooooo0?l00006ooooo`030000o`3o003ooooo00Oooooo00?o0?l0ooooooooool00_ooool00ol0
o`00003oooooo`07ooooo`03o`3o0?oooooooooo00Gooooo00@0003ooooooooooooo0?l03?ooool0
0`000?oooooo0000o`03ooooo`030000oooooooooooo00Kooooo00?o0?l0ooooooooool05?ooool0
0`000?ooooooooooo`05ooooo`03o`3o0?oooooooooo00?ooooo00Go0?l00000oooooooooooo0000
o`06ooooo`030000oooooooooooo00;ooooo00?o0?l0ooooooooool03oooool00ol0o`3ooooooooo
o`0@ooooo`03o`3o0?oooooooooo00gooooo00?o0?l0ooooooooool0;?ooool01@00o`3ooooooooo
ooooool00?l004gooooo00<00?l0ooooo`00o`004_ooool00`00o`3oooooooooo`02ooooo`03003o
0?oooooooooo01oooooo00<00?l0ooooooooool01Oooool001Oooooo00?o0000ooooooooool04Ooo
ool00`000?ooooooooooo`02ooooo`030000oooooooooooo00;ooooo00<0o`00ooooooooool03_oo
ool01ol0003oooooo`3o0?ooool0003oooooo`000?l00_ooool00ol0o`3oooooooooo`02ooooo`07
0000ooooooooooooooooo`000?oooooo0?l00006ooooo`030000ooooool0o`0000Oooooo00?o0?l0
ooooooooool00_ooool00`3o003o0?l0ooooo`07ooooo`03o`3o0?oooooooooo00Cooooo0P000?l2
ooooo`03o`3o0?oooooooooo00[ooooo00@0003oooooooooool0003o0_ooool00`000?oooooooooo
o`06ooooo`03o`3o0?oooooooooo01cooooo00?o0?l0ooooooooool00oooool01?l0o`3ooooo0000
o`000?l7ooooo`030000oooooooooooo00;ooooo00?o0?l0ooooooooool03oooool00ol0o`3ooooo
ooooo`0@ooooo`03o`3o0?oooooooooo00gooooo00?o0?l0ooooooooool0;Oooool00`00o`3ooooo
003o001>ooooo`03003o0?ooool00?l001;ooooo00D00?l0oooooooooooooooo003o000Rooooo`03
003o0?oooooooooo00Gooooo000Gooooo`?o00002oooool60000o`Gooooo00<0003oooooooooool0
0_ooool00`3o003oooooooooo`0>ooooo`07o`000?oooooo0?l0ooooo`000?oooooo0000o`02oooo
o`05o`3o003o003oooooooooo`000?l01?ooool00`000?l0o`00ooooo`05ooooo`040000oooooooo
oooo0?l000Oooooo00?o0?l0ooooooooool00_ooool00`3o003o0?l0ooooo`07ooooo`03o`3o0?oo
oooooooo00Cooooo0P000?l2ooooo`03o`3o0?oooooooooo00[ooooo00L0003ooooooooooooooooo
0000ool0o`00003o00Oooooo00?o0?l0ooooooooool07Oooool00ol0o`3oooooooooo`03ooooo`04
o`3o0?oooooooooo0000o`Oooooo00<0003oooooooooool00_ooool00ol0o`3oooooooooo`0?oooo
o`03o`3o0?oooooooooo017ooooo00?o0?l0ooooooooool02oooool00ol0o`3oooooooooo`0^oooo
o`800?l0Coooool00`00o`3ooooo003o000Booooo`05003o0?ooooooooooooooo`00o`008_ooool0
0`00o`3oooooooooo`05ooooo`005oooool00ol0003oooooooooo`0;ooooo`030000oooooooooooo
00Sooooo00<0003oooooooooool00_ooool00`3o003oooooooooo`0>ooooo`07o`000?oooooo0?l0
ooooo`000?oooooo0000o`02ooooo`05o`3o003o003oooooooooo`000?l01?ooool00`000?l0o`00
ooooo`05ooooo`050000ooooooooooooooooo`3o00001_ooool00ol0o`3oooooooooo`02ooooo`03
0?l00?l0o`3ooooo00Oooooo00?o0?l0ooooooooool01?ooool01@000?oooooo0000oooooooo0?l0
00_ooooo00<0003oooooooooool00oooool00ol0o`3oooooooooo`06ooooo`03o`3o0?oooooooooo
01kooooo00Go0?l0ooooooooooooooooo`3o000;ooooo`030000oooooooooooo00;ooooo00?o0?l0
ooooooooool03oooool00ol0o`3oooooooooo`0Booooo`03o`3o0?oooooooooo00[ooooo00?o0?l0
ooooooooool0;_ooool00`00o`3oooooooooo`1>ooooo`03003o0?ooool00?l001;ooooo00D00?l0
oooooooooooooooo003o000Rooooo`03003o0?oooooooooo00Gooooo000Gooooo`03o`000?oooooo
oooo00_ooooo00<0003oooooooooool02?ooool00`000?ooooooooooo`02ooooo`030?l00?oooooo
oooo00kooooo00Co0000o`3o0?ooool0003o0oooool00`000?ooooooo`3o00020?l00003ooooo`00
0?oooooo00?ooooo00<0003o0?l00?ooool01Oooool01@000?ooooooooooooooool0o`0000Gooooo
00?o0?l0ooooooooool00oooool00`3o003o0?l0ooooo`07ooooo`03o`3o0?oooooooooo00Cooooo
00D0003oooooo`000?ooooooo`3o000;ooooo`030000oooooooooooo00;ooooo0_l0o`08ooooo`03
o`3o0?oooooooooo01kooooo00Go0?l0ooooooooooooooooo`3o000;ooooo`030000oooooooooooo
00;ooooo00?o0?l0ooooooooool03_ooool00ol0o`3oooooooooo`0Cooooo`03o`3o0?oooooooooo
00[ooooo00?o0?l0ooooooooool0Ooooool00`00o`3ooooo003o000Booooo`05003o0?oooooooooo
ooooo`00o`008_ooool00`00o`3oooooooooo`05ooooo`005oooool00ol0003oooooooooo`0;oooo
o`030000oooooooooooo00Sooooo00<0003oooooooooool00_ooool00`3o003oooooooooo`0>oooo
o`04o`000?l0o`3ooooo0000o`?ooooo00L0003oooooool0003o0?l00?l00?ooool0003o00Cooooo
00<0003o0?l00?ooool01Oooool01@000?ooooooooooooooool0o`0000Gooooo00?o0?l0oooooooo
ool00oooool00`3o003oooooo`3o0007ooooo`03o`3o0?oooooooooo00?ooooo00H0003ooooooooo
ool0003oooooool0o`0;ooooo`030000oooooooooooo00;ooooo00?o0?l0ooooool0o`001oooool0
0ol0o`3oooooooooo`0Nooooo`05o`3o0?ooooooooooooooool0o`002oooool00`000?oooooooooo
o`02ooooo`03o`3o0?oooooooooo00kooooo00?o0?l0ooooooooool05?ooool00ol0o`3ooooooooo
o`09ooooo`03o`3o0?oooooooooo083ooooo00<00?l0ooooooooool04_ooool01000o`3ooooooooo
o`00o`0Sooooo`03003o0?oooooooooo00Cooooo000Gooooo`03o`000?oooooooooo00[ooooo00<0
003oooooooooool02Oooool00`000?ooooooooooo`02ooooo`80o`003oooool01?l0003o0?l0oooo
o`000?l3ooooo`070000oooooooo0000o`3o0?ooool0o`000000o`04ooooo`030000oooooooooooo
00Gooooo00<0003oooooooooool00_ooool00`3o003oooooooooo`02ooooo`03o`3o0?oooooooooo
00?ooooo00<0o`00ooooool0o`001oooool00ol0o`3oooooooooo`03ooooo`040000oooooooooooo
0000o`;ooooo00?o0?l0ooooooooool02?ooool01@000?oooooooooooooooooo0?l000;ooooo00?o
0?l0ooooooooool01Oooool00ol0o`3oooooooooo`0Nooooo`05o`3o0?ooooooooooooooool0o`00
3?ooool01@000?oooooooooooooooooo0?l0013ooooo00?o0?l0ooooooooool05?ooool00ol0o`3o
ooooooooo`08ooooo`03o`3o0?oooooooooo087ooooo00<00?l0ooooooooool04_ooool00`00o`3o
oooo003o000Tooooo`03003o0?oooooooooo00Cooooo000Gooooo`03o`000?oooooooooo00[ooooo
00<0003oooooooooool02Oooool00`000?ooooooooooo`02ooooo`80o`002Oooool00`3o003ooooo
ooooo`03ooooo`04o`000?l0o`3ooooo0000o`?ooooo00L0003oooooool0003o0?l0ooooo`3o0000
003o00Cooooo00<0003oooooooooool01Oooool00`000?ooooooooooo`02ooooo`030?l00?oooooo
oooo00;ooooo00?o0?l0ooooooooool00oooool00`3o003oooooo`3o0006ooooo`03o`3o0?oooooo
oooo00Cooooo00@0003oooooooooool0003o0_ooool00ol0o`3oooooooooo`08ooooo`040000oooo
ooooooooo`3o00?ooooo00?o0?l0ooooooooool01?ooool00ol0o`3oooooooooo`0Oooooo`05o`3o
0?ooooooooooooooool0o`003?ooool01@000?ooooooooooo`000?oo0?l0013ooooo00?o0?l0oooo
ooooool05Oooool00ol0o`3oooooooooo`07ooooo`03o`3o0?oooooooooo087ooooo00<00?l0oooo
ooooool04_ooool00`00o`3ooooo003o000Tooooo`03003o0?oooooooooo00Cooooo0006ooooo`Go
00000oooool2o`0000Oooooo00?o0000ooooooooool02_ooool00`000?ooooooooooo`09ooooo`03
0000oooooooooooo00;ooooo0P3o0009ooooo`030?l00?oooooooooo00?ooooo00Co0000o`3o0?oo
ool0003o0oooool01`000?ooooooo`000?l0o`3ooooo0?l000000?l01?ooool00`3o0000003ooooo
o`05ooooo`030000oooooooooooo00;ooooo00<0o`00ooooooooool00_ooool00ol0o`3ooooooooo
o`03ooooo`040?l00?ooool0003oo`3o00Gooooo00?o0?l0ooooooooool01?ooool010000?oooooo
ooooo`000?l2ooooo`03o`3o0?oooooooooo00Sooooo00@0003ooooooooooooo0?l01?ooool00ol0
o`3oooooooooo`03ooooo`03o`3o0?oooooooooo01oooooo00Go0?l0ooooooooooooooooo`3o000<
ooooo`050000oooooooooooo0000ool0o`004?ooool00ol0o`3oooooooooo`0Eooooo`03o`3o0?oo
oooooooo00Oooooo00?o0?l0ooooooooool0U_ooool00`00o`3ooooo003o000Tooooo`03003o0?oo
oooooooo00Cooooo0007ooooo`04o`000?ooooooooooo`0000;ooooo00Co0000oooooooooooo0000
1_ooool00ol0003oooooooooo`0:ooooo`030000oooooooooooo00[ooooo00@0003ooooooooooooo
oooo0P3o0009ooooo`030?l00?oooooooooo00?ooooo00Co0000o`3o0?ooool0003o0oooool01000
0?oooooo0?l00?l0o`02ooooo`030000oooooooooooo00;ooooo00<0o`000000ooooool01?ooool0
0`000?ooooooooooo`04ooooo`050?l00?ooooooooooooooool0o`001Oooool0103o003ooooo0000
ool0o`05ooooo`03o`3o0?oooooooooo00?ooooo00D0003ooooooooooooooooo0000o`02ooooo`03
o`3o0?oooooooooo00Sooooo00<0003oooooool0o`001Oooool00ol0o`3oooooooooo`03ooooo`03
o`3o0?oooooooooo01oooooo00Go0?l0ooooooooooooooooo`3o000<ooooo`050000oooooooooooo
0000ool0o`003oooool00ol0o`3oooooooooo`0Gooooo`03o`3o0?oooooooooo00Kooooo00?o0?l0
ooooooooool0U_ooool00`00o`3ooooo003o000Tooooo`03003o0?oooooooooo00Cooooo0008oooo
o`03o`000?oooooooooo00;ooooo00Co0000oooooooooooo00001_ooool00ol0003oooooooooo`0:
ooooo`030000oooooooooooo00[ooooo00@0003ooooooooooooooooo0P3o0009ooooo`030?l00?oo
oooooooo00?ooooo00Co0000o`3o0?ooool0003o0oooool010000?oooooo0?l00?l0o`02ooooo`07
0000ooooooooooooooooo`3o003ooooo0000o`05ooooo`030000oooooooooooo00Cooooo00D0o`00
ooooooooooooooooo`3o0005ooooo`040?l00?ooool0003oo`3o00Gooooo00?o0?l0ooooooooool0
0oooool00`000?ooooooooooo`02ooooo`030000oooooooo0?l000Wooooo00@0003ooooooooooooo
0?l01Oooool00ol0o`3oooooooooo`03ooooo`03o`3o0?oooooooooo023ooooo00?o0?l0ooooool0
o`003Oooool01P000?ooooooooooo`000?ooooooo`3o00kooooo00?o0?l0ooooooooool05oooool0
0ol0o`3oooooooooo`05ooooo`03o`3o0?oooooooooo09Sooooo0P00o`0Tooooo`03003o0?oooooo
oooo00Cooooo0009ooooo`05o`000?ooooooooooooooool000000_ooool00ol0003oooooooooo`04
ooooo`Co00001?ooool00`3o003oooooooooo`02ooooo`030000oooooooooooo00[ooooo00@0003o
oooooooooooooooo0P3o0009ooooo`80o`001?ooool01?l0o`3oooooooooo`000?l3ooooo`040000
ooooool0o`00o`3o00;ooooo00L0003o0?l00?oooooooooo0?l00?ooool0003o00Gooooo00<0003o
ooooooooool01?ooool01@3o003ooooooooooooooooo0?l000Gooooo00@0o`00ooooo`000?oo0?l0
1Oooool00ol0o`3oooooooooo`03ooooo`030000oooooooooooo00;ooooo00<0003oooooool0o`00
2?ooool4o`3o00Oooooo00?o0?l0ooooooooool00_ooool00ol0o`3oooooooooo`0Pooooo`03o`3o
0?oooooo0?l000gooooo00H0003oooooooooool0003oooooool0o`0>ooooo`03o`3o0?oooooooooo
01Oooooo00?o0?l0ooooooooool01Oooool00ol0o`3oooooooooo`2Hooooo`03003o0?oooooooooo
02?ooooo00<00?l0ooooooooool01?ooool000Kooooo00Go0000ooooooooooooooooo`000002oooo
o`04o`000?ooooooooooo`0000Kooooo00?o0000ooooooooool01Oooool01@3o003ooooooooooooo
ool0003o00gooooo00@0003ooooooooooooooooo0P3o0009ooooo`80o`001?ooool01?l0o`3ooooo
ooooo`000?l3ooooo`080000ooooool0o`00o`3o0?ooool0003oooooo`3o0002ooooo`030?l00?oo
ool0003o00Gooooo00<0003oooooooooool01?ooool01@3o003ooooooooooooooooo0?l000Gooooo
00D0o`00ooooo`000?ooooooo`3o0004ooooo`03o`3o0?oooooooooo00;ooooo00<0003ooooooooo
ool00oooool00`000?ooooooo`3o0004ooooo`Co0?l000?ooooo0000ooooool02?ooool00ol0o`3o
ooooooooo`02ooooo`03o`3o0?oooooooooo023ooooo00?o0?l0ooooool0o`003_ooool01@000?oo
oooo0000oooooooo0?l000Kooooo00?o0?l0ooooooooool01Oooool00ol0o`3oooooooooo`0Hoooo
o`03o`3o0?oooooooooo00Cooooo00?o0?l0ooooooooool0V?ooool00`00o`3oooooooooo`0Toooo
o`03003o0?oooooooooo00?ooooo0006ooooo`05o`000?ooooooooooooooool000000_ooool01?l0
003oooooooooool00006ooooo`03o`000?oooooooooo00Gooooo00D0o`00oooooooooooooooo0000
o`0=ooooo`040000ooooooooooooooooo`80o`002?ooool00`3o003ooooo0?l00004ooooo`04o`3o
0?l0003ooooo0000o`Cooooo00D0003o0?l00?l0o`3ooooo0000o`02ooooo`050?l00?ooool0o`00
ooooo`000?l01Oooool00`000?ooooooooooo`04ooooo`050?l00?ooooooooooooooool0o`001Ooo
ool01@3o003oooooooooo`000?oo0?l000Cooooo00?o0?l0ooooooooool00_ooool00`000?oooooo
ooooo`03ooooo`040000ooooooooooooo`3o00;ooooo00?o0?l0ooooooooool00oooool00`000?oo
ooooooooo`07ooooo`05o`3o0?ooooooooooooooool0o`008oooool00ol0o`3oooooo`3o000>oooo
o`050000ooooool0003oooooool0o`001_ooool00ol0o`3oooooooooo`05ooooo`03o`3o0?oooooo
oooo01Sooooo00?o0?l0ooooooooool01?ooool00ol0o`3oooooooooo`2oooooo`03003o0?oooooo
oooo00?ooooo0007ooooo`?o00001?ooool2o`0000Oooooo00?o0000ooooooooool01Oooool20?l0
00;ooooo00<0003oooooooooool02oooool010000?ooooooooooooooool20?l000Sooooo00<0o`00
ooooo`3o00001?ooool00ol0o`3o00000000o`05ooooo`050000o`3o003o0?l0ooooo`000?l00_oo
ool01@3o003ooooo0?l00?ooool0003o00Gooooo00<0003oooooooooool01?ooool01@3o003ooooo
oooooooooooo0?l000Gooooo00D0o`00ooooooooool0003oo`3o0003ooooo`03o`3o0?oooooooooo
00?ooooo00<0003oooooooooool00oooool01P000?ooooooooooool0o`3oooooo`3o00Kooooo00<0
003oooooooooool02?ooool01?l0o`3oooooooooool0o`0Sooooo`03o`3o0?oooooo0?l000kooooo
00D0003oooooo`000?ooooooo`3o0006ooooo`;o0?l01Oooool00ol0o`3oooooooooo`0Iooooo`03
o`3o0?oooooooooo00?ooooo00?o0?l0ooooooooool0`?ooool00`00o`3oooooooooo`03ooooo`00
5oooool00ol0003oooooooooo`05ooooo`80o`000_ooool00`000?ooooooooooo`0;ooooo`040000
ooooooooooooooooo`80o`002?ooool00`3o003ooooo0?l00004ooooo`03o`3o0?l00000003o00Go
oooo00D0003o0?l00?l0o`3ooooo0000o`02ooooo`80o`000_ooool00`000?ooooooooooo`03oooo
o`030000oooooooooooo00Cooooo00@0o`00oooooooooooo0?l01_ooool01P3o003oooooooooo`00
0?ooooooo`3o00;ooooo00?o0?l0ooooooooool00oooool00`000?ooooooooooo`03ooooo`030000
oooooooooooo00;o0?l01oooool00`000?ooooooooooo`08ooooo`04o`3o0?ooooooooooo`3o02?o
oooo00?o0?l0ooooool0o`003_ooool01@000?oooooo0000oooooooo0?l000Gooooo00Co0?l0oooo
oooooooo0?l01?ooool00ol0o`3oooooooooo`0Jooooo`03o`3o0?oooooooooo00;ooooo00?o0?l0
ooooooooool0a_ooool001Oooooo00?o0000ooooooooool01Oooool20?l000;ooooo00<0003ooooo
ooooool02oooool010000?ooooooooooooooool20?l000Sooooo00<0o`00ooooo`3o00001?ooool0
0ol0o`3o00000000o`05ooooo`050000o`3o003o0?l0ooooo`000?l00oooool0103o003ooooooooo
o`000?l4ooooo`030000oooooooooooo00Gooooo00@0o`00oooooooooooo0?l01_ooool01P3o003o
ooooooooo`000?ooooooo`3o00;ooooo00?o0?l0ooooooooool00_ooool00`000?ooooooooooo`04
ooooo`040000ooooooooooooo`3o00Sooooo00<0003oooooooooool02?ooool01?l0o`3ooooooooo
ool0o`0Sooooo`03o`3o0?oooooo0?l000kooooo0P000?l2ooooo`03o`3o0?oooooooooo00?ooooo
00Co0?l0oooooooooooo0?l01?ooool00ol0o`3oooooooooo`0Jooooo`03o`3o0?oooooooooo00;o
oooo00?o0?l0ooooooooool0a_ooool001Oooooo00?o0000ooooooooool01Oooool20?l000;ooooo
00<0003oooooooooool02oooool010000?ooooooooooooooool20?l000Sooooo00@0o`00oooooooo
ool0o`000oooool00ol0o`3o00000000o`05ooooo`050000o`3o003o0?l0ooooo`000?l01_ooool0
0`000?ooooooooooo`02ooooo`030000oooooooooooo00Gooooo00@0o`00oooooooooooo0?l01_oo
ool01P3o003oooooooooo`000?ooooooo`3o00;ooooo00?o0?l0ooooooooool00_ooool00`000?oo
ooooooooo`04ooooo`030000oooooooooooo00Wooooo00<0003oooooooooool02Oooool00ol0o`3o
ooooo`3o000Tooooo`03o`3o0?oooooooooo00gooooo0P000?l2ooooo`03o`3o0?oooooooooo00?o
oooo00Go0?l0ooooooooooooooooo`3o0003ooooo`03o`3o0?oooooooooo01_ooooo00Go0?l0oooo
ooooooooooooo`3o0038ooooo`005oooool00ol0003oooooooooo`05ooooo`040?l00?ooool0o`00
0000o`kooooo00@0003ooooooooooooooooo0P3o0008ooooo`040?l00?oooooooooo0?l000;ooooo
00Co0?l0ooooool00000003o1Oooool01@000?l0o`00ooooool0o`00003o00Kooooo00<0003ooooo
ooooool00_ooool00`000?ooooooooooo`06ooooo`030?l00?oooooo0?l000Kooooo00H0o`00oooo
ooooool0003oooooool0o`02ooooo`03o`3o0?oooooooooo00;ooooo00<0003oooooooooool01Ooo
ool00`000?ooooooooooo`07ooooo`030000oooooooooooo00[ooooo00?o0?l0ooooool0o`009?oo
ool00ol0o`3oooooooooo`0>ooooo`040000ooooooooooooo`3o00Gooooo00?o0?l0ooooooooool0
0_ooool01?l0o`3oooooooooool0o`0Mooooo`04o`3o0?ooooooooooo`3o0<Wooooo000Gooooo`03
o`000?oooooooooo00Cooooo00D0o`00ooooooooool0o`000000o`0>ooooo`040000oooooooooooo
ooooo`80o`002?ooool0103o003oooooooooo`3o0002ooooo`04o`3o0?oooooo00000000o`Gooooo
00D0003o0?l00?oooooo0?l00000o`06ooooo`030000oooooooooooo00;ooooo00<0003ooooooooo
ool01_ooool00`3o003oooooo`3o0006ooooo`040?l00?oooooooooo0000o`;ooooo00?o0?l0oooo
ool0o`001?ooool00`000?ooooooooooo`05ooooo`030000oooooooooooo00Oooooo00<0003ooooo
ooooool02_ooool2o`3o02Gooooo00?o0?l0ooooooooool03_ooool010000?ooooooooooool0o`05
ooooo`03o`3o0?oooooooooo00;ooooo00?o0?l0ooooool0o`007_ooool01?l0o`3oooooooooool0
o`39ooooo`005oooool3o`0000Cooooo00D0o`00ooooooooool0o`000000o`02ooooo`03o`3o0?oo
oooooooo00Wooooo00L0003ooooooooooooooooo0?l00?ooool0o`0000Oooooo00@0o`00oooooooo
ool0o`000_ooool01?l0o`3oooooo`0000000?l5ooooo`050000o`3o003oooooo`3o00000?l01ooo
ool01@000?ooooooooooooooool0003o00Sooooo00<0o`00ooooool0o`001_ooool0103o003ooooo
ooooo`000?l2ooooo`03o`3o0?oooooo0?l000?ooooo00<0003oooooooooool01_ooool00`000?oo
ooooooooo`07ooooo`030000oooooooooooo00_ooooo00?o0?l0ooooooooool08oooool00ol0o`3o
ooooooooo`0>ooooo`040000ooooooooooooo`3o00Cooooo00?o0?l0ooooooooool01?ooool2o`3o
01oooooo00?o0?l0ooooool0o`00bOooool001Oooooo00?o0000ooooooooool01?ooool01@3o003o
ooooooooo`3o0000003o00;ooooo00?o0?l0ooooooooool02Oooool010000?ooooooooooo`3o0002
ooooo`030?l00?oooooooooo00Gooooo00@0o`00ooooooooool0o`000_ooool01?l0o`3oooooo`00
00000?l5ooooo`050000o`3o003oooooo`3o00000?l01oooool01@000?ooooooooooooooool0003o
00Sooooo00<0o`00ooooool0o`001_ooool0103o003oooooooooo`000?l2ooooo`;o0?l01?ooool0
0`000?ooooooooooo`06ooooo`030000oooooooooooo00Oooooo00<0003oooooooooool02oooool0
0ol0o`3oooooooooo`0hooooo`05o`3o0?ooooooooooooooool0o`001oooool00ol0o`3ooooooooo
o`0Mooooo`03o`3o0?oooooo0?l00<Wooooo000Gooooo`03o`000?oooooooooo00Cooooo00D0o`00
oooooooooooooooo0000o`02ooooo`;o0?l02_ooool010000?ooooooooooo`3o0002ooooo`030?l0
0?oooooooooo00Gooooo00@0o`00ooooooooool0o`000_ooool01?l0o`3oooooo`0000000?l5oooo
o`040000ooooooooooooo`3o00Sooooo00@0003oooooooooool0003o2Oooool00`3o003oooooo`3o
0006ooooo`050?l00?ooooooooooooooo`000?l00_ooool00ol0o`3oooooooooo`02ooooo`030000
oooooooooooo00Kooooo00<0003oooooooooool01oooool00`000?ooooooooooo`16ooooo`05o`3o
0?ooooooooooooooool0o`009oooool2o`3o0<[ooooo000Gooooo`03o`000?oooooooooo00Cooooo
00D0o`00oooooooooooooooo0000o`02ooooo`;o0?l02_ooool010000?ooooooooooo`3o0002oooo
o`030?l00?oooooooooo00Cooooo00<0o`00ooooooooool00_ooool01P3o003oooooo`3o0?oooooo
00000000o`Gooooo00@0o`000000oooooooo0?l02?ooool010000?ooooooooooo`000?l9ooooo`03
0?l00?oooooo0?l000Kooooo00D0o`00oooooooooooooooo0000o`02ooooo`03o`3o0?oooooooooo
00;ooooo00<0003oooooooooool01_ooool00`000?ooooooooooo`07ooooo`030000oooooooooooo
04Kooooo00Go0?l0ooooooooooooooooo`3o000Xooooo`03o`3o0?oooooooooo0<Sooooo000Goooo
o`03o`000?oooooooooo00Cooooo00T0o`00oooooooooooooooo0000oooooooo0?l0ooooool0o`00
2_ooool010000?ooooooooooo`3o0002ooooo`030?l00?oooooooooo00Cooooo00<0o`00oooooooo
ool00_ooool01@3o003oooooo`3o0?ooool0003o00Kooooo00@0o`000000oooooooo0?l02?ooool0
10000?ooooooooooo`000?l9ooooo`030?l00?oooooo0?l000Gooooo00<0o`00ooooooooool00_oo
ool00`000?ooooooooooo`05ooooo`030000oooooooooooo00Kooooo00<0003oooooooooool01ooo
ool00`000?ooooooooooo`16ooooo`05o`3o0?ooooooooooooooool0o`00loooool001Oooooo00?o
0000ooooooooool01?ooool01`3o003oooooooooo`000?l0o`00ooooool0o`000_ooool00ol0o`3o
ooooooooo`07ooooo`040000oooooooooooo0?l000;ooooo00<0o`00ooooooooool01?ooool00`3o
003oooooooooo`02ooooo`050?l00?oooooo0?l0ooooo`000?l01_ooool0103o0000003oooooool0
o`08ooooo`040000oooooooooooo0000o`Wooooo00<0o`00ooooool0o`001Oooool00`3o003ooooo
ooooo`02ooooo`030000oooooooooooo00Cooooo00<0003oooooooooool01oooool00`000?oooooo
ooooo`06ooooo`030000oooooooooooo04Oooooo00Co0?l0oooooooooooo0?l0m?ooool001Oooooo
00?o0000ooooooooool01?ooool01`3o003oooooooooo`000?l0o`00ooooool0o`000_ooool00ol0
o`3oooooooooo`07ooooo`040000oooooooooooo0?l000;ooooo00<0o`00ooooooooool01?ooool0
0`3o003oooooooooo`02ooooo`050?l00?oooooo0?l0ooooo`000?l01_ooool0103o0000003ooooo
ool0o`08ooooo`040000oooooooooooo0000o`Wooooo00<0o`00o`3o0?ooool01Oooool00`3o003o
ooooooooo`02ooooo`030000oooooooooooo00Cooooo00<0003oooooooooool02?ooool00`000?oo
ooooooooo`05ooooo`030000oooooooooooo04Oooooo00Co0?l0oooooooooooo0?l0m?ooool001Oo
oooo00?o0000ooooooooool01?ooool01`3o003oooooooooo`000?oooooo0?l00?l0o`000_ooool0
0ol0o`3oooooooooo`07ooooo`040000oooooooooooo0?l000;ooooo00@0o`00oooooooooooo0?l0
0oooool00`3o003oooooooooo`02ooooo`050?l00?oooooo0?l0ooooo`000?l01_ooool0103o0000
003oooooool0o`08ooooo`040000oooooooooooo0000o`Wooooo00<0o`00o`3o0?ooool01Oooool0
0`3o003oooooooooo`02ooooo`030000oooooooooooo00Cooooo00<0003oooooooooool02?ooool0
0`000?ooooooooooo`05ooooo`030000oooooooooooo04Oooooo00Co0?l0oooooooooooo0?l0m?oo
ool001Oooooo00?o0000ooooooooool01?ooool01`3o003oooooooooo`000?oooooo0?l00?l0o`00
0oooool00ol0o`3oooooooooo`06ooooo`040000oooooooooooo0?l000;ooooo00@0o`00oooooooo
oooo0?l00oooool00`3o003oooooooooo`02ooooo`050?l00?oooooo0?l0ooooo`000?l01_ooool0
103o0000003oooooool0o`08ooooo`040000oooooooooooo0000o`Wooooo00<0o`00o`3o0?ooool0
1Oooool00`3o003oooooooooo`02ooooo`030000oooooooooooo00Cooooo00<0003oooooooooool0
2?ooool00`000?ooooooooooo`05ooooo`030000oooooooooooo04Oooooo00Co0?l0oooooooooooo
0?l0m?ooool001Oooooo0ol00004ooooo`070?l00?oooooooooo0000ooooool0o`00o`3o0003oooo
o`03o`3o0?oooooooooo00Kooooo00@0003oooooooooool0o`000_ooool0103o003oooooooooool0
o`03ooooo`030?l00?oooooooooo00;ooooo00D0o`00o`3o0?oooooooooo0000o`06ooooo`040?l0
00000?ooooooo`3o00Sooooo00<0003oooooo`000?l02_ooool00`3o003o0?l0ooooo`05ooooo`03
0?l00?oooooooooo00;ooooo00<0003oooooooooool01?ooool00`000?ooooooooooo`08ooooo`03
0000oooooooooooo00Gooooo00<0003oooooooooool0Aoooool01?l0o`3oooooooooool0o`3doooo
o`005oooool00ol0003oooooooooo`04ooooo`060?l00?oooooooooo0000oooooooo0?l01?ooool0
0ol0o`3oooooooooo`06ooooo`040000oooooooooooo0?l000;ooooo00@0o`00oooooooooooo0?l0
0oooool00`3o003oooooooooo`03ooooo`04o`3o0?oooooooooo0000o`Kooooo00@0o`000000oooo
oooo0?l02?ooool00`000?oooooo0000o`0:ooooo`030?l00?l0o`3ooooo00Gooooo00<0o`00oooo
ooooool00oooool00`000?ooooooooooo`03ooooo`030000oooooooooooo00Sooooo00<0003ooooo
ooooool01Oooool00`000?ooooooooooo`17ooooo`03o`3o0?oooooo0?l00?Gooooo000Gooooo`03
o`000?oooooooooo00Cooooo00<0o`00ooooo`000?l00_ooool00ol0o`00o`00ooooo`03ooooo`03
o`3o0?oooooooooo00Gooooo00@0003oooooooooool0o`000_ooool0103o003oooooooooool0o`03
ooooo`030?l00?oooooooooo00?ooooo00Co0?l0ooooooooool0003o1_ooool0103o0000003ooooo
ool0o`08ooooo`030000ooooool0003o00[ooooo00<0o`00o`3o0?ooool01Oooool00`3o003ooooo
ooooo`03ooooo`030000oooooooooooo00;ooooo00<0003oooooooooool02Oooool00`000?oooooo
ooooo`05ooooo`030000oooooooooooo04Oooooo00?o0?l0ooooool0o`00mOooool001Oooooo00?o
0000ooooooooool01?ooool00`3o003ooooo0000o`02ooooo`03o`3o003o003ooooo00?ooooo00?o
0?l0ooooooooool01Oooool010000?ooooooooooo`3o0002ooooo`040?l00?ooooooooooo`3o00?o
oooo00<0o`00ooooooooool00oooool01?l0o`3oooooooooo`000?l6ooooo`040?l00?ooool0003o
o`3o00Sooooo00<0003oooooo`000?l02_ooool00`3o003o0?l0ooooo`05ooooo`030?l00?oooooo
oooo00?ooooo00<0003oooooooooool00_ooool00`000?ooooooooooo`09ooooo`030000oooooooo
oooo00Gooooo00<0003oooooooooool0B?ooool2o`3o0?Gooooo000Gooooo`03o`000?oooooooooo
00Cooooo00<0o`00ooooo`000?l00_ooool00ol0o`00o`00ooooo`03ooooo`03o`3o0?oooooooooo
00Gooooo00@0003oooooooooool0o`000_ooool01`3o003oooooo`3o0?l0o`00003oooooo`3o0000
1_ooool01?l0o`3ooooo0000ool00006ooooo`040?l00?ooool0003oo`3o00Wooooo0P000?l:oooo
o`030?l00?l0o`3ooooo00Gooooo00<0o`00ooooooooool00oooool00`000?ooooooooooo`02oooo
o`030000oooooooooooo00[ooooo00<0003oooooooooool00oooool00`000?ooooooooooo`19oooo
o`;o0?l0mOooool001Oooooo00?o0000ooooooooool00oooool0103o003oooooooooo`000?l2oooo
o`03o`3o003o003ooooo00Cooooo00?o0?l0ooooooooool01?ooool010000?ooooooooooo`3o0003
ooooo`060?l00?l0o`00003oo`3o0?ooool0o`001_ooool01Ol0o`3ooooo0000oooooooo000000Go
oooo00@0o`00ooooo`000?oo0?l02Oooool20000o`_ooooo00?o0?l0ooooooooool01?ooool00`3o
003oooooooooo`03ooooo`030000oooooooooooo00;ooooo00<0003oooooooooool02_ooool00`00
0?ooooooooooo`03ooooo`030000oooooooooooo04Wooooo0_l0o`3eooooo`005oooool00ol0003o
ooooooooo`03ooooo`040?l00?oooooooooo0000o`;ooooo00?o0?l0ooooo`3o00001?ooool00ol0
o`3oooooooooo`04ooooo`040000oooooooooooo0?l000?ooooo00H0o`00o`3o00000?oo0?l0oooo
o`3o0006ooooo`05o`3o0?ooool0003oooooool000001?ooool01@3o003o0000ooooo`000?oo0?l0
00Wooooo0P000?l;ooooo`03o`3o0?oooooooooo00Cooooo00<0o`00ooooooooool00oooool00`00
0?ooooooooooo`02ooooo`030000oooooooooooo00[ooooo00<0003oooooooooool00oooool00`00
0?ooooooooooo`19ooooo`03o`3o0?oooooooooo0?Cooooo000Gooooo`03o`000?oooooooooo00?o
oooo00H0o`00ooooooooool0003oooooool0o`02ooooo`030?l00?oooooooooo00?ooooo00?o0?l0
ooooooooool00oooool010000?ooooooooooo`3o0003ooooo`060?l00?l0o`00003oo`3o0?ooool0
o`001_ooool01Ol0o`00o`000000oooooooo000000Cooooo00D0o`00o`000?ooool0003oo`3o0009
ooooo`030000oooooooooooo00[ooooo00?o0?l0ooooooooool01?ooool00`3o003oooooooooo`03
ooooo`050000ooooooooooooooooo`000?l03Oooool00`000?ooooooooooo`03ooooo`030000oooo
oooooooo04Wooooo00?o0?l0ooooooooool0m?ooool001Oooooo00?o0000ooooooooool00oooool0
0`3o003ooooo0000o`02ooooo`04o`3o0?oooooooooo0?l000Kooooo00?o0?l0ooooooooool00ooo
ool00`000?oooooo0?l00003ooooo`060?l00?l0o`00003oo`3o0?ooool0o`001_ooool01Ol0o`00
o`000000oooooooo000000Cooooo00<0o`00o`000?ooool00_ooool00ol0o`3oooooooooo`06oooo
o`030000oooooooooooo00Wooooo00?o0?l00?l00?ooool01Oooool00`3o003oooooooooo`03oooo
o`050000ooooooooooooooooo`000?l03Oooool00`000?ooooooooooo`03ooooo`030000oooooooo
oooo0?oooooo@Oooool001Oooooo0ol00003ooooo`030?l00?ooool0003o00;ooooo00Co0?l0oooo
ooooool0o`001oooool00ol0o`3oooooooooo`02ooooo`030000ooooool0o`0000?ooooo00H0o`00
o`3o00000?oo0?l0ooooo`3o0006ooooo`05o`3o003o0000003oooooool000001?ooool00`3o003o
0000ooooo`02ooooo`03o`3o0?oooooooooo00Kooooo00<0003oooooooooool02Oooool00ol0o`00
o`00ooooo`05ooooo`030?l00?oooooooooo00Cooooo00@0003oooooooooool0003o3_ooool00`00
0?ooooooooooo`02ooooo`030000oooooooooooo0?oooooo@Oooool001Oooooo00?o0000oooooooo
ool00oooool00`3o003ooooo0000o`02ooooo`04o`3o0?oooooooooo0?l000Sooooo00Oo0?l0oooo
oooooooooooo0000ooooool0o`0000?ooooo00H0o`00o`3o00000?oo0?l00000o`3o0006ooooo`05
o`3o003o0000003oooooool000001?ooool00`3o003o0000ooooo`02ooooo`03o`3o0?oooooooooo
01;ooooo00?o0?l00?l00?ooool01Oooool00`3o003oooooooooo`04ooooo`040000oooooooooooo
0000o`oooooo00D0003ooooooooooooooooo0000o`3ooooood?ooooo000Gooooo`03o`000?oooooo
oooo00?ooooo00<0o`00ooooo`000?l00_ooool01Ol0o`3oooooooooooooool0o`0000Sooooo00Ko
0?l0ooooooooool0003oooooo`3o0003ooooo`060?l00?l0o`00003oo`3o00000?l0o`001_ooool0
1Ol0o`00o`000000oooooooo000000Cooooo00<0o`00ooooooooool00_ooool00ol0o`3ooooooooo
o`0Booooo`03o`3o003o003ooooo00Gooooo00<0o`00ooooooooool01?ooool010000?oooooooooo
o`000?l@ooooo`030000ooooool0003o0?ooooooA?ooool001Oooooo00?o0000ooooooooool00ooo
ool00`3o003ooooo0000o`02ooooo`05o`3o0?ooooooooooooooo`3o00002Oooool01Ol0o`3ooooo
0000ooooool0o`0000?ooooo00H0o`00o`3o0?oooooo0?l00000o`3o0006ooooo`05o`3o0?ooool0
003oooooool000001?ooool00`3o003oooooooooo`02ooooo`03o`3o0?oooooooooo01;ooooo00?o
0?l00?l00?ooool01Oooool00`3o003oooooooooo`04ooooo`040000oooooooooooo0000oa3ooooo
00<0003oooooo`000?l0oooooom4ooooo`005oooool00ol0003oooooooooo`03ooooo`050?l00000
0?ooooooooooool0o`001?ooool00`3o003oooooooooo`07ooooo`05o`3o0?ooool0003oooooo`3o
00000oooool01P3o003o0?l0ooooool0o`00003o0?l000Kooooo00Go0?l0ooooo`000?ooooooo`00
0004ooooo`030?l00?oooooooooo00;ooooo00?o0?l0ooooooooool04_ooool00ol0o`00o`00oooo
o`05ooooo`030?l00?oooooooooo00Cooooo00<0003oooooo`000?l04_ooool20000ooooooooA?oo
ool001Oooooo00?o0000ooooooooool00oooool01@3o0000003ooooooooooooo0?l000Cooooo00<0
o`00ooooooooool01oooool01Ol0o`3ooooo0000ooooool0o`0000?ooooo00H0o`00o`3o0?oooooo
0?l00000o`3o0006ooooo`05o`3o00000?l0o`00ooooool000001?ooool00`3o003oooooooooo`02
ooooo`03o`3o0?oooooooooo01;ooooo00?o0?l00?l00?ooool01Oooool00`3o003oooooooooo`04
ooooo`030000ooooool0003o01?ooooo00<0003oooooooooool0oooooom2ooooo`002?ooool3o`00
00?ooooo0_l00007ooooo`03o`000?oooooooooo00?ooooo00D0o`000000ooooooooooooo`3o0004
ooooo`030?l00?oooooooooo00Oooooo00Go0?l0ooooo`000?oooooo0?l00003ooooo`05o`3o0000
0?ooooooo`3o00000?l01oooool01Ol0o`00003o0?l00?oooooo000000Cooooo00<0o`00oooooooo
ool00_ooool00ol0o`3oooooooooo`0Booooo`03o`3o003o003ooooo00Gooooo00<0o`00oooooooo
ool01?ooool00`000?oooooo0000o`3ooooooeSooooo0009ooooo`05o`000?ooooooooooooooool0
00000_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00?ooooo00D0o`000000oooo
ooooooooo`3o0004ooooo`030?l00?oooooooooo00Oooooo00Go0?l0ooooo`000?oooooo0?l00003
ooooo`06o`3o00000?ooooooo`3o003o0000003o1_ooool01Ol0o`00003o0?l00?oooooo000000Co
oooo00<0o`00ooooooooool00_ooool00ol0o`3oooooooooo`0Booooo`03o`3o003o003ooooo00Go
oooo00<0o`00ooooooooool01?ooool00`000?oooooo0000o`3ooooooeSooooo0006ooooo`Go0000
0_ooool01?l0003oooooooooool00006ooooo`03o`000?oooooooooo00?ooooo00D0o`000000oooo
ooooooooo`3o0004ooooo`030?l00?oooooooooo00Sooooo00Co0?l00000ooooool0o`000oooool0
1_l0o`00003oooooool0o`00o`000000o`Gooooo00Ko0?l0ooooo`000?oooooo0?l00?l00004oooo
o`030?l00?oooooooooo00;ooooo00?o0?l0ooooooooool04_ooool00ol0o`00o`00ooooo`05oooo
o`030?l00?oooooooooo00Cooooo00<0003oooooo`000?l0oooooomHooooo`001_ooool01?l0003o
ooooooooool00003ooooo`04o`000?ooooooooooo`0000Kooooo1?l00002ooooo`050000oooooooo
ooooooooool0o`001Oooool00`3o003oooooooooo`07ooooo`04o`3o00000?oooooo0?l000?ooooo
00Ko0?l00000ooooooooooooo`3o00000?l5ooooo`06o`3o0?ooool0003oooooo`3o003o00001?oo
ool00`3o003oooooooooo`02ooooo`03o`3o0?oooooooooo01;ooooo00?o0?l00?l00?ooool01?oo
ool00`3o003oooooooooo`06ooooo`80003ooooooomHooooo`001oooool00ol0003oooooo`000003
ooooo`04o`000?ooooooooooo`0000Kooooo00?o0000ooooooooool00_ooool01@3o0000003ooooo
oooooooo0?l000Kooooo00<0o`00ooooooooool01oooool01?l0o`00003oooooo`3o0003ooooo`06
o`3o00000?ooooooooooool0o`00003o1Oooool01_l0o`3ooooo0000ooooool0o`00o`0000?ooooo
00<0o`00o`000?ooool00oooool00ol0o`3oooooooooo`0Aooooo`03o`3o0?ooool0o`0000Gooooo
00<0o`00ooooooooool01_ooool00`000?ooooooooooo`3ooooooeOooooo0008ooooo`;o00000ooo
ool01?l0003oooooooooool00006ooooo`03o`000?oooooooooo00;ooooo00D0o`000000oooooooo
ooooo`3o0006ooooo`030?l00?oooooooooo00Oooooo00Co0?l00000ooooool0o`000oooool01_l0
o`00003ooooooooooooo0?l00000o`Gooooo00Ko0?l0ooooo`000?oooooo0?l00?l00003ooooo`03
0?l00?l0003ooooo00?ooooo00?o0?l0ooooooooool04Oooool00ol0o`3ooooo0?l00005ooooo`03
0?l00?oooooooooo00Kooooo00<0003oooooooooool0oooooomGooooo`002Oooool00ol0003ooooo
ooooo`02ooooo`;o00001oooool00ol0003oooooooooo`02ooooo`050?l000000?ooooooooooool0
o`001_ooool00`3o003oooooooooo`07ooooo`04o`3o00000?oooooo0?l000?ooooo00Ko0?l00000
ooooooooooooo`3o00000?l5ooooo`06o`3o00000?ooooooooooo`3o003o00000oooool00`3o003o
0000ooooo`03ooooo`03o`3o0?oooooooooo017ooooo00Co0?l0ooooooooool0o`001?ooool00`3o
003oooooooooo`06ooooo`030000oooooooooooo0?ooooooEoooool001Oooooo00?o0000oooooooo
ool00_ooool01@3o0000003ooooooooooooo0?l000Kooooo00<0o`00ooooooooool01oooool01?l0
o`00003oooooo`3o0003ooooo`07o`3o00000?ooooooooooool0o`3ooooo0000o`04ooooo`03o`3o
00000?oooooo00;ooooo00H0o`00oooooooooooooooo0?l00?l00004ooooo`03o`3o0?oooooooooo
017ooooo00Co0?l0ooooooooool0o`001?ooool00`3o003oooooooooo`3oooooof3ooooo000Goooo
o`03o`000?oooooooooo00;ooooo00D0003oooooooooooooooooo`3o0006ooooo`030?l00?oooooo
oooo00Oooooo00Co0?l00000ooooool0o`000oooool01ol0o`00003ooooooooooooo0?l0ooooo`00
0?l01?ooool00ol0o`00003oooooo`02ooooo`060?l00?ooooooooooooooo`3o003o00001?ooool0
0ol0o`3oooooooooo`0@ooooo`;o0?l00_ooool00`3o003oooooooooo`02ooooo`030?l00?oooooo
oooo0?ooooooH?ooool001Oooooo00?o0000ooooooooool00_ooool01@000?oooooooooooooooooo
0?l000Kooooo00<0o`00ooooooooool02?ooool00ol0o`3ooooo0?l00003ooooo`07o`3o00000?oo
ooooooooool0o`3ooooo0000o`04ooooo`03o`3o0?oooooooooo00;ooooo00H0o`00oooooooooooo
oooo0?l00?l00004ooooo`03o`3o0?oooooooooo00gooooo0ol0o`04ooooo`030?l00?oooooooooo
00;ooooo00<0o`00ooooooooool0oooooomPooooo`005oooool00ol0003oooooooooo`02ooooo`04
0000ooooooooooooo`3o00Sooooo00<0o`00ooooooooool01oooool00ol0o`3ooooo0?l00002oooo
o`08o`3o0?ooool0003oooooo`3o003o0?l0ooooo`000?l4ooooo`03o`3o0?oooooooooo00;ooooo
00H0o`00o`000?oooooooooo0?l00?l00004ooooo`03o`3o0?oooooooooo00cooooo00?o0?l0oooo
ooooool01Oooool00`3o003oooooooooo`02ooooo`030?l00?oooooooooo0?ooooooH?ooool001Oo
oooo00?o0000ooooooooool00_ooool010000?ooooooooooool0o`08ooooo`030?l00?oooooooooo
00Oooooo00?o0?l0ooooo`3o00000_ooool02?l0o`3ooooo0000ooooool0o`00o`3o0?ooool0003o
1?ooool00ol0o`3oooooooooo`03ooooo`050?l00?oooooooooo0?l00?l000001?ooool00ol0o`3o
ooooooooo`0<ooooo`03o`3o0?oooooooooo00Gooooo00<0o`00ooooooooool00_ooool00`3o003o
ooooooooo`3oooooof3ooooo000Gooooo`?o00000_ooool010000?ooooooooooool0o`08ooooo`03
0?l00?oooooooooo00Oooooo00?o0?l0ooooo`3o00000_ooool02?l0o`3ooooo0000ooooool0o`00
o`3o0?ooool0003o1?ooool00ol0o`3oooooooooo`03ooooo`050?l00?oooooooooo0?l00?l00000
1Oooool00ol0o`3oooooooooo`0;ooooo`03o`3o0?oooooooooo00Gooooo00<0o`00ooooooooool0
0_ooool00`3o003oooooooooo`3oooooof3ooooo000Gooooo`06o`000?ooooooooooooooo`000?l0
o`000_ooool00ol0o`3oooooooooo`06ooooo`030?l00?oooooooooo00Oooooo00?o0?l0ooooo`3o
00000_ooool01_l0o`3ooooo0000ooooool0o`00o`3o00;ooooo00D0003oooooooooool0003oo`3o
0005ooooo`050?l00?oooooooooo0?l00?l000001Oooool00ol0o`3oooooooooo`0;ooooo`03o`3o
0?oooooooooo00Gooooo00<0o`00ooooooooool00_ooool00`3o003oooooooooo`3oooooof3ooooo
000Gooooo`06o`000?ooooooooooooooo`000?l0o`000_ooool00ol0o`3oooooooooo`06ooooo`03
0?l00?oooooooooo00Oooooo00?o0?l0ooooo`3o00000_ooool01_l0o`3ooooo0000ooooool0o`00
o`3o00;ooooo00D0003oooooooooool0003oo`3o0005ooooo`050?l00?oooooooooo0?l00?l00000
1Oooool00ol0o`3oooooooooo`0;ooooo`03o`3o0?oooooooooo00Gooooo00<0o`00ooooooooool0
0_ooool00`3o003oooooooooo`3oooooof3ooooo000Gooooo`06o`000?ooooooooooooooo`000?l0
o`000_ooool00ol0o`3oooooooooo`06ooooo`030?l00?oooooooooo00Oooooo00?o0?l0ooooo`3o
00000_ooool02Ol0o`3ooooo0000ooooool0o`00ooooool0o`3ooooo0000o`02ooooo`030000ool0
o`3ooooo00Cooooo00D0o`00ooooooooool0o`00o`000005ooooo`03o`3o0?oooooooooo00_ooooo
00?o0?l0ooooooooool01Oooool00`3o003oooooooooo`02ooooo`030?l00?oooooooooo0?oooooo
H?ooool001Oooooo00Ko0000oooooooooooooooo0000o`3o0002ooooo`03o`3o0?oooooooooo00Ko
oooo00<0o`00ooooooooool01oooool00ol0o`3ooooo0?l00002ooooo`09o`3o0?ooool0003ooooo
o`3o003oooooo`3o0?ooool0003o00;ooooo00<0003oo`3o0?ooool01?ooool01Ol00000o`00oooo
o`3o003o000000Gooooo00?o0?l0ooooooooool02oooool00ol0o`3oooooooooo`05ooooo`030?l0
0?oooooooooo00;ooooo00<0o`00ooooooooool0oooooomPooooo`005oooool01_l0003ooooooooo
ooooool0003o0?l000;ooooo00?o0?l0ooooooooool01oooool00`3o003oooooooooo`06ooooo`03
0000ool0o`00o`0000;ooooo00go0?l0ooooo`000?oooooo0?l00?oooooo0?l0ooooo`000?oooooo
0000oooooooo0?l000Gooooo00Go00000?l0003o003oooooo`000005ooooo`03o`3o0?oooooooooo
00_ooooo00?o0?l0ooooooooool01Oooool00`3o003oooooooooo`02ooooo`030?l00?oooooooooo
0?ooooooH?ooool001Oooooo00Go0000ooooooooool0003o0?l00003ooooo`03o`3o0?oooooooooo
00Oooooo00<0o`00ooooooooool01_ooool00`000?oo0?l00?l00002ooooo`03o`3o00000?oooooo
0080o`0000Ooooooo`3o0?ooool0003oooooo`000?oo0?l000Kooooo00Go00000?l0003o003ooooo
o`000005ooooo`03o`3o0?oooooooooo00_ooooo00?o0?l0ooooooooool01Oooool00`3o003ooooo
ooooo`02ooooo`030?l00?oooooooooo0?ooooooH?ooool001Oooooo00Go0000ooooooooool0003o
0?l00003ooooo`03o`3o0?oooooooooo00Oooooo00<0o`00ooooooooool01_ooool00`000?oo0?l0
0?l00002ooooo`03o`3o00000?oooooo0080o`0000Coooooo`3o0?oooooooooo0P000?l00ol0o`3o
ooooooooo`04ooooo`05o`00003o0000o`00ooooool000001Oooool00ol0o`3oooooooooo`0;oooo
o`03o`3o0?oooooooooo00Gooooo00<0o`00ooooooooool00_ooool00`3o003oooooooooo`3ooooo
of3ooooo000Gooooo`05o`000?ooooooooooooooo`3o00000oooool00ol0o`3oooooooooo`07oooo
o`030?l00?oooooooooo00Kooooo00T0003oo`3o0?ooooooooooo`3o0?ooool0003oooooo`3o0000
0_ooool01_l0o`3oooooooooo`000?ooooooo`3o00Kooooo00Go00000?l0003o003oooooo`000005
ooooo`03o`3o0?oooooooooo00_ooooo00?o0?l0ooooooooool01Oooool00`3o003oooooooooo`02
ooooo`030?l00?oooooooooo0?ooooooH?ooool001Oooooo0ol000000oooool0o`00ooooo`02oooo
o`03o`3o0?oooooooooo00Oooooo00<0o`00ooooooooool01oooool02?l0o`3oooooooooool0o`3o
oooo0000ooooool0o`000_ooool01_l0o`3oooooooooo`000?ooooooo`3o00Kooooo00Go0000oooo
o`3o003oooooo`000005ooooo`03o`3o0?oooooooooo00_ooooo00?o0?l0ooooooooool01_ooool0
1@3o003oooooooooooooool0o`000?ooooooH_ooool001Oooooo00Go0000oooooooooooooooo0?l0
0003ooooo`03o`3o0?oooooooooo00Oooooo00<0o`00ooooooooool01oooool02?l0o`3ooooooooo
ool0o`3ooooo0000ooooool0o`000_ooool00ol0o`3oooooooooo`02ooooo`03o`3o0?oooooooooo
00Cooooo00Co0000ooooo`3o003o00001_ooool00ol0o`3oooooooooo`0:ooooo`03o`3o0?oooooo
oooo00Oooooo00D0o`00oooooooooooooooo0?l0003oooooof;ooooo000Gooooo`05o`000?oooooo
ooooooooo`3o00000oooool00ol0o`3oooooooooo`07ooooo`030?l00?oooooooooo00Oooooo00So
0?l0oooooooooooo0?l0ooooo`000?oooooo0?l000;ooooo00?o0?l0ooooooooool00_ooool00ol0
o`3oooooooooo`04ooooo`04o`000?ooooooooooo`0000Kooooo00?o0?l0ooooooooool02_ooool0
0ol0o`3oooooooooo`07ooooo`050?l00?ooooooooooooooo`3o0000oooooomRooooo`005oooool0
1Ol0003oooooooooooooool0o`0000?ooooo00?o0?l0ooooooooool02?ooool00`3o003ooooooooo
o`06ooooo`08o`3o0?ooooooooooo`3o0?ooool0003oooooo`3o0002ooooo`03o`3o0?oooooooooo
00;ooooo00?o0?l0ooooooooool01?ooool01?l0003oooooooooool00006ooooo`03o`3o0?oooooo
oooo00[ooooo00?o0?l0ooooooooool01oooool01@3o003oooooooooooooool0o`000?ooooooH_oo
ool001Oooooo00Go0000oooooooooooooooo0?l00003ooooo`03o`3o0?oooooooooo00Sooooo00<0
o`00ooooooooool01_ooool01P000?oo0?l0ooooool0o`3ooooo0000o`Cooooo00?o0?l0oooooooo
ool00_ooool00ol0o`3oooooooooo`04ooooo`04o`000?ooooooooooo`0000Kooooo00?o0?l0oooo
ooooool02_ooool00ol0o`3oooooooooo`07ooooo`050?l00?ooooooooooooooo`3o0000oooooomR
ooooo`005oooool01Ol0003oooooooooooooool0o`0000?ooooo00?o0?l0ooooooooool02?ooool0
0`3o003oooooooooo`06ooooo`060000ool0o`3oooooo`3o0?ooool0003o1?ooool00ol0o`3ooooo
ooooo`02ooooo`03o`3o0?oooooooooo00Cooooo00Co0000oooooooooooo00001_ooool00ol0o`3o
ooooooooo`0:ooooo`03o`3o0?oooooooooo00Oooooo00@0o`00ooooooooool0o`00oooooomSoooo
o`005oooool01Ol0003oooooooooooooool0o`0000?ooooo00?o0?l0ooooooooool02?ooool00`3o
003oooooooooo`06ooooo`060000ool0o`3oooooo`3o0?ooool0003o1?ooool00ol0o`3ooooooooo
o`02ooooo`03o`3o0?oooooooooo00Cooooo00Co0000oooooooooooo00001_ooool00ol0o`3ooooo
ooooo`0:ooooo`03o`3o0?oooooooooo00Oooooo00@0o`00ooooooooool0o`00oooooomSooooo`00
5oooool01Ol0003oooooooooooooool0o`0000;ooooo00?o0?l0ooooooooool02Oooool00`3o003o
ooooooooo`06ooooo`060000ool0o`3oooooo`3o0?ooool0003o1Oooool01Ol0o`3ooooooooooooo
oooo0?l000Kooooo00Co0000oooooooooooo00001_ooool00ol0o`3oooooooooo`0:ooooo`03o`3o
0?oooooooooo00Oooooo00@0o`00ooooooooool0o`00oooooomSooooo`005oooool01Ol0003ooooo
ooooooooool0o`0000;ooooo00?o0?l0ooooooooool02Oooool00`3o003oooooooooo`06ooooo`06
0000ool0o`3oooooo`3o0?ooool0003o1Oooool01Ol0o`3ooooooooooooooooo0?l000Kooooo00Co
0000oooooooooooo00001_ooool00ol0o`3oooooooooo`0:ooooo`03o`3o0?oooooooooo00Oooooo
00@0o`00ooooooooool0o`00oooooomSooooo`005oooool3o`000005ooooo`3o003oooooooooool0
o`002oooool00`3o003oooooooooo`06ooooo`060000ool0o`3oooooo`3o0?ooool0003o1Oooool0
1Ol0o`3ooooooooooooooooo0?l000Oooooo00?o0000ooooool000001_ooool00ol0o`3ooooooooo
o`0:ooooo`03o`3o0?oooooooooo00Oooooo00@0o`00ooooooooool0o`00oooooomSooooo`005ooo
ool01Ol0003oooooooooooooool0o`0000;ooooo00?o0?l0ooooooooool02Oooool00`3o003ooooo
ooooo`06ooooo`030000ool0o`3o0?l000;ooooo00<0003oooooooooool00oooool01Ol0o`3ooooo
oooooooooooo0?l000Oooooo00?o0000ooooool000001oooool00ol0o`3oooooooooo`09ooooo`03
o`3o0?oooooooooo00Oooooo00@0o`00ooooooooool0o`00oooooomSooooo`005oooool01Ol0003o
ooooooooooooool0o`0000;ooooo00?o0?l0ooooooooool02Oooool00`3o003oooooooooo`06oooo
o`030000oooooooo0?l000;ooooo00<0003oooooooooool00oooool01Ol0o`3ooooooooooooooooo
0?l000Oooooo00?o0000ooooool000001oooool00ol0o`3oooooooooo`09ooooo`03o`3o0?oooooo
oooo00Oooooo00@0o`00ooooooooool0o`00oooooomSooooo`005oooool01?l0003oooooooooo`3o
0003ooooo`03o`3o0?oooooooooo00Wooooo00<0o`00ooooooooool01_ooool00`000?ooooooo`3o
0002ooooo`030000oooooooooooo00?ooooo00Go0?l0ooooooooooooooooo`3o0007ooooo`03o`00
0?oooooo000000Oooooo00?o0?l0ooooooooool02Oooool00ol0o`3oooooooooo`07ooooo`040?l0
0?oooooooooo0?l00?ooooooHoooool001Oooooo00Co0000ooooooooool0o`000oooool00ol0o`3o
ooooooooo`09ooooo`030?l00?oooooooooo00Kooooo00<0003oooooool0o`000_ooool00`000?oo
ooooooooo`03ooooo`04o`3o0?ooooooooooo`3o00Sooooo00?o0000ooooool000001oooool00ol0
o`3oooooooooo`09ooooo`03o`3o0?oooooooooo00Oooooo00@0o`00ooooooooool0o`00oooooomS
ooooo`005oooool01?l0003oooooooooo`3o0003ooooo`03o`3o0?oooooooooo00Wooooo00<0o`00
ooooooooool01_ooool00`000?ooooooo`3o0002ooooo`030000oooooooooooo00?ooooo00Co0?l0
oooooooooooo0?l02?ooool00ol0003oooooo`000007ooooo`03o`3o0?oooooooooo00Wooooo00?o
0?l0ooooooooool01oooool0103o003oooooooooo`3o003oooooof?ooooo0007ooooo`?o00001?oo
ool2o`0000Oooooo00Co0000ooooooooool0o`000oooool00ol0o`3oooooooooo`09ooooo`030?l0
0?oooooooooo00Kooooo00<0003oooooooooool00_ooool00`000?ooooooooooo`03ooooo`04o`3o
0?ooooooooooo`3o00Sooooo00?o0000ooooool000001oooool00ol0o`3oooooooooo`09ooooo`03
o`3o0?oooooooooo00Oooooo00@0o`00ooooooooool0o`00oooooomSooooo`001_ooool01Ol0003o
oooooooooooooooo000000;ooooo00Co0000oooooooooooo00001_ooool01?l0003oooooooooo`3o
0003ooooo`03o`3o0?oooooooooo00Wooooo00<0o`00ooooooooool01_ooool00`000?oooooooooo
o`02ooooo`030000oooooooooooo00?ooooo00Co0?l0oooooooooooo0?l02?ooool00ol0003ooooo
o`000007ooooo`03o`3o0?oooooooooo00Wooooo00?o0?l0ooooooooool02?ooool00`3o003ooooo
0?l0003oooooof?ooooo0006ooooo`05o`000?ooooooooooooooool000000_ooool01?l0003ooooo
ooooool00006ooooo`04o`000?oooooooooo0?l000?ooooo00?o0?l0ooooooooool02Oooool00`3o
003oooooooooo`06ooooo`030000oooooooooooo00;ooooo00<0003oooooooooool00oooool01?l0
o`3oooooooooool0o`08ooooo`03o`000?oooooo000000Oooooo00?o0?l0ooooooooool02Oooool0
0ol0o`3oooooooooo`08ooooo`030?l00?ooool0o`000?ooooooHoooool000Kooooo1?l00003oooo
o`04o`000?ooooooooooo`0000Kooooo0ol000001@3o003ooooooooooooooooo0?l000cooooo00<0
o`00ooooooooool01Oooool01@000?ooooooooooooooool0003o00Kooooo00Co0?l0oooooooooooo
0?l02?ooool00ol0003oooooo`000007ooooo`03o`3o0?oooooooooo00Wooooo00?o0?l0oooooooo
ool02?ooool00`3o003ooooo0?l0003oooooof?ooooo0006ooooo`03o`000?oooooooooo00Cooooo
00Co0000oooooooooooo00001_ooool00ol0003oooooooooo`04ooooo`03o`3o0?oooooooooo00[o
oooo00<0o`00ooooooooool01Oooool01@000?ooooooooooooooool0003o00Oooooo00?o0?l0oooo
ool0o`002?ooool00ol0003oooooo`000007ooooo`03o`3o0?oooooooooo00Wooooo00?o0?l0oooo
ooooool02?ooool00`3o003ooooo0?l0003oooooof?ooooo0007ooooo`03o`000?oooooooooo00?o
oooo00Co0000oooooooooooo00001_ooool00ol0003oooooooooo`04ooooo`03o`3o0?oooooooooo
00[ooooo00<0o`00ooooooooool01Oooool01@000?ooooooooooooooool0003o00Oooooo00?o0?l0
ooooool0o`002?ooool00ol0003oooooo`000007ooooo`03o`3o0?oooooooooo00Wooooo00?o0?l0
ooooooooool02?ooool00`3o003ooooo0?l0003oooooof?ooooo0008ooooo`;o00001?ooool2o`00
00Oooooo00?o0000ooooooooool01?ooool00ol0o`3oooooooooo`0:ooooo`030?l00?oooooooooo
00Gooooo00D0003ooooooooooooooooo0000o`07ooooo`03o`3o0?oooooo0?l000Sooooo00?o0000
ooooool000001oooool00ol0o`3oooooooooo`09ooooo`03o`3o0?oooooooooo00Sooooo00<0o`00
ooooo`3o0000oooooomSooooo`005oooool00ol0003oooooooooo`04ooooo`03o`3o0?oooooooooo
00[ooooo00<0o`00ooooooooool01Oooool01@000?ooooooooooooooool0003o00Oooooo00?o0?l0
ooooool0o`002?ooool00ol0003oooooo`000007ooooo`03o`3o0?oooooooooo00Sooooo00?o0?l0
ooooooooool02Oooool00`3o003ooooo0?l0003oooooof?ooooo000Gooooo`03o`000?oooooooooo
00Cooooo00?o0?l0ooooooooool02_ooool00`3o003oooooooooo`05ooooo`050000oooooooooooo
ooooo`000?l01oooool00ol0o`3oooooo`3o0008ooooo`03o`000?oooooo000000Oooooo00?o0?l0
ooooooooool02?ooool00ol0o`3oooooooooo`09ooooo`030?l00?ooool0o`000?ooooooHoooool0
01Oooooo00?o0000ooooooooool01?ooool00ol0o`3oooooooooo`0:ooooo`030?l00?oooooooooo
00Gooooo00D0003ooooooooooooooooo0000o`07ooooo`03o`3o0?oooooo0?l000Sooooo00?o0000
ooooool000001oooool00ol0o`3oooooooooo`08ooooo`03o`3o0?oooooooooo00Wooooo00<0o`00
ooooo`3o0000oooooomSooooo`005oooool00ol0003oooooooooo`04ooooo`03o`3o0?oooooooooo
00[ooooo00<0o`00ooooooooool01Oooool01@000?ooooooooooooooool0003o00Oooooo00?o0?l0
ooooool0o`002?ooool00ol0003oooooo`000007ooooo`03o`3o0?oooooooooo00Sooooo00?o0?l0
ooooooooool02Oooool00`3o003ooooo0?l0003oooooof?ooooo000Gooooo`03o`000?oooooooooo
00Cooooo00?o0?l0ooooooooool02_ooool00`3o003oooooooooo`05ooooo`050000oooooooooooo
ooooo`000?l01oooool00ol0o`3oooooo`3o0008ooooo`03o`000?oooooo000000Oooooo00?o0?l0
ooooooooool02?ooool00ol0o`3oooooooooo`09ooooo`030?l00?ooool0o`000?ooooooHoooool0
01Oooooo0ol00004ooooo`03o`3o0?oooooooooo00[ooooo00<0o`00ooooooooool01Oooool01@00
0?ooooooooooooooool0003o00Oooooo00?o0?l0ooooool0o`002?ooool2o`0000Sooooo00?o0?l0
ooooooooool02?ooool00ol0o`3oooooooooo`09ooooo`030?l00?ooool0o`000?ooooooHoooool0
01Oooooo00?o0000ooooooooool01?ooool00ol0o`3oooooooooo`0:ooooo`030?l00?oooooooooo
00Gooooo00D0003ooooooooooooooooo0000o`07ooooo`03o`3o0?oooooo0?l000Sooooo0_l00008
ooooo`03o`3o0?oooooooooo00Sooooo00?o0?l0ooooooooool02Oooool20?l00?ooooooI?ooool0
01Oooooo00?o0000ooooooooool01?ooool00ol0o`3oooooooooo`0:ooooo`030?l00?oooooooooo
00Gooooo00D0o`000000oooooooooooo0000o`07ooooo`03o`3o0?oooooo0?l000Sooooo0_l00009
ooooo`03o`3o0?oooooooooo00Oooooo00?o0?l0ooooooooool02Oooool20?l00?ooooooI?ooool0
01Oooooo00?o0000ooooooooool01?ooool00ol0o`3oooooooooo`0:ooooo`030?l00?oooooooooo
00Gooooo00D0o`000000oooooooooooo0000o`07ooooo`;o0?l02_ooool00ol0003oooooooooo`07
ooooo`03o`3o0?oooooooooo00Oooooo00?o0?l0ooooooooool02Oooool20?l00?ooooooI?ooool0
01Oooooo00?o0000ooooooooool01?ooool00ol0o`3oooooooooo`0:ooooo`030?l00?oooooooooo
00Gooooo00D0o`000000oooooooooooo0000o`07ooooo`;o0?l02_ooool00ol0003oooooooooo`07
ooooo`03o`3o0?oooooooooo00Oooooo00?o0?l0ooooooooool02Oooool20?l00?ooooooI?ooool0
01Oooooo00?o0000ooooooooool01?ooool00ol0o`3oooooooooo`0:ooooo`030?l00?oooooooooo
00Gooooo00D0o`000000oooooooooooo0000o`08ooooo`03o`3o0?oooooooooo00Sooooo00?o0000
ooooooooool01oooool00ol0o`3oooooooooo`07ooooo`03o`3o0?oooooooooo00[ooooo00<0o`00
ooooooooool0oooooomRooooo`005oooool00ol0003oooooooooo`04ooooo`03o`3o0?oooooooooo
00[ooooo00<0o`00ooooooooool01Oooool01@3o0000003oooooooooool0003o00Sooooo00?o0?l0
ooooooooool02?ooool00ol0003oooooooooo`07ooooo`03o`3o0?oooooooooo00Oooooo00?o0?l0
ooooooooool02_ooool00`3o003oooooooooo`3oooooof;ooooo000Gooooo`03o`000?oooooooooo
00Cooooo00?o0?l0ooooooooool02_ooool00`3o003oooooooooo`05ooooo`050?l000000?oooooo
ooooo`000?l02?ooool00ol0o`3oooooooooo`08ooooo`03o`000?oooooooooo00Oooooo00?o0?l0
ooooooooool01oooool00ol0o`3oooooooooo`0:ooooo`030?l00?oooooooooo0?ooooooH_ooool0
01Oooooo00?o0000ooooooooool01?ooool00ol0o`3oooooooooo`0:ooooo`030?l00?oooooooooo
00Gooooo00D0o`000000oooooooooooo0000o`08ooooo`03o`3o0?oooooooooo00Sooooo00?o0000
ooooooooool01oooool00ol0o`3oooooooooo`07ooooo`03o`3o0?oooooooooo00[ooooo00<0o`00
ooooooooool0oooooomRooooo`005oooool3o`0000?ooooo00?o0?l0ooooooooool02oooool00`3o
003oooooooooo`05ooooo`050?l000000?ooooooooooo`000?l02?ooool00ol0o`3oooooooooo`08
ooooo`03o`000?oooooooooo00Oooooo00?o0?l0ooooooooool01oooool00ol0o`3oooooooooo`0:
ooooo`030?l00?oooooooooo0?ooooooH_ooool001Oooooo00?o0000ooooooooool00oooool00ol0
o`3oooooooooo`0;ooooo`030?l00?oooooooooo00Gooooo00D0o`000000oooooooooooo0000o`08
ooooo`03o`3o0?oooooooooo00Sooooo00?o0000ooooooooool01oooool00ol0o`3oooooooooo`07
ooooo`03o`3o0?oooooooooo00[ooooo00<0o`00ooooooooool0oooooomRooooo`005oooool00ol0
003oooooooooo`03ooooo`03o`3o0?oooooooooo00_ooooo00<0o`00ooooooooool01Oooool01@3o
0000003oooooooooool0003o01?ooooo00?o0000ooooooooool01oooool00ol0o`3oooooooooo`07
ooooo`03o`3o0?oooooooooo00[ooooo00<0o`00ooooooooool0oooooomRooooo`005oooool00ol0
003oooooooooo`03ooooo`03o`3o0?oooooooooo00_ooooo00<0o`00ooooooooool01Oooool0103o
0000003oooooo`000?lDooooo`03o`000?oooooooooo00Oooooo00?o0?l0ooooooooool01oooool0
0ol0o`3oooooooooo`0:ooooo`030?l00?oooooooooo0?ooooooH_ooool001Oooooo00?o0000oooo
ooooool00oooool00ol0o`3oooooooooo`0;ooooo`030?l00?oooooooooo00Gooooo00@0o`000000
ooooool0003o7_ooool00ol0o`3oooooooooo`07ooooo`03o`3o0?oooooooooo0?ooooooKoooool0
01Oooooo00?o0000ooooooooool00oooool00ol0o`3oooooooooo`0;ooooo`030?l00?oooooooooo
00Gooooo00@0o`000000ooooool0003o7_ooool00ol0o`3oooooooooo`07ooooo`03o`3o0?oooooo
oooo0?ooooooKoooool001Oooooo00?o0000ooooooooool00oooool00ol0o`3oooooooooo`0<oooo
o`030?l00?oooooooooo00?ooooo00D0o`00ooooo`000?oooooo0000o`0Nooooo`03o`3o0?oooooo
oooo00Oooooo00?o0?l0ooooooooool0oooooom_ooooo`005oooool00ol0003oooooooooo`03oooo
o`03o`3o0?oooooooooo00cooooo00<0o`00ooooooooool00oooool01@3o003ooooo0000ooooool0
003o01kooooo00?o0?l0ooooooooool01oooool00ol0o`3oooooooooo`3oooooofoooooo000Goooo
o`03o`000?oooooooooo00?ooooo00?o0?l0ooooooooool03?ooool00`3o003oooooooooo`03oooo
o`050?l00?ooool0003oooooo`000?l07_ooool00ol0o`3oooooooooo`06ooooo`03o`3o0?oooooo
oooo0?ooooooL?ooool001Oooooo0ol00003ooooo`03o`3o0?oooooooooo00cooooo00<0o`00oooo
ooooool00oooool01@3o003ooooo0000ooooool0003o01kooooo00?o0?l0ooooooooool01_ooool0
0ol0o`3oooooooooo`3oooooog3ooooo000Gooooo`03o`000?oooooooooo00?ooooo00?o0?l0oooo
ooooool03?ooool00`3o003oooooooooo`03ooooo`050?l00?ooool0003oooooo`000?l07_ooool0
0ol0o`3oooooooooo`06ooooo`03o`3o0?oooooooooo0?ooooooL?ooool001Oooooo00?o0000oooo
ooooool00oooool00ol0o`3oooooooooo`0<ooooo`030?l00?oooooooooo00?ooooo00D0o`00oooo
o`000?oooooo0000o`0Nooooo`03o`3o0?oooooooooo00Kooooo00?o0?l0ooooooooool0oooooom`
ooooo`005oooool00ol0003oooooooooo`03ooooo`03o`3o0?oooooooooo00cooooo00<0o`00oooo
ooooool00oooool01@3o003ooooo0000ooooool0003o01oooooo00?o0?l0ooooooooool01Oooool0
0ol0o`3oooooooooo`3oooooog3ooooo000Gooooo`03o`000?oooooooooo00?ooooo00?o0?l0oooo
ooooool03?ooool00`3o003oooooooooo`03ooooo`050?l00?ooool0003oooooo`000?l07oooool0
0ol0o`3oooooooooo`05ooooo`03o`3o0?oooooooooo0?ooooooL?ooool001Oooooo00?o0000oooo
ooooool00oooool00ol0o`3oooooooooo`0<ooooo`030?l00?oooooooooo00?ooooo00D0o`00oooo
o`000?oooooo0000o`0Oooooo`03o`3o0?oooooooooo00Gooooo00?o0?l0ooooooooool0oooooom`
ooooo`001oooool3o`0000Cooooo0_l00007ooooo`03o`000?oooooooooo00?ooooo00?o0?l0oooo
ooooool03?ooool00`3o003oooooooooo`03ooooo`050?l00?ooool0003oooooo`000?l07oooool0
0ol0o`3oooooooooo`05ooooo`03o`3o0?oooooooooo0?ooooooL?ooool000Kooooo00Go0000oooo
ooooooooooooo`000002ooooo`04o`000?ooooooooooo`0000Kooooo00?o0000ooooooooool00ooo
ool00ol0o`3oooooooooo`0<ooooo`030?l00?oooooooooo00?ooooo00D0o`00ooooo`000?oooooo
0000o`0Oooooo`03o`3o0?oooooooooo00Gooooo00?o0?l0ooooooooool0oooooom`ooooo`001_oo
ool01Ol0003ooooooooooooooooo000000;ooooo00Co0000oooooooooooo00001_ooool00ol0003o
ooooooooo`03ooooo`03o`3o0?oooooooooo00cooooo00<0o`00ooooooooool00oooool01@3o003o
oooo0000ooooool0003o01oooooo00?o0?l0ooooooooool01Oooool00ol0o`3oooooooooo`3ooooo
og3ooooo0007ooooo`?o00000oooool01?l0003oooooooooool00006ooooo`Co00000_ooool00ol0
o`3oooooooooo`0<ooooo`030?l00?oooooooooo00?ooooo00D0o`00ooooo`000?oooooo0000o`0O
ooooo`03o`3o0?oooooooooo00Gooooo00?o0?l0ooooooooool0oooooom`ooooo`001_ooool01Ol0
003ooooooooooooooooo000000;ooooo00Co0000oooooooooooo00001_ooool00ol0003ooooooooo
o`03ooooo`03o`3o0?oooooooooo00cooooo00<0o`00ooooooooool00oooool01@3o003ooooo0000
ooooool0003o01oooooo00?o0?l0ooooooooool01Oooool00ol0o`3oooooooooo`3oooooog3ooooo
0006ooooo`05o`000?ooooooooooooooool000000_ooool01?l0003oooooooooool00006ooooo`03
o`000?oooooooooo00?ooooo00?o0?l0ooooooooool03?ooool00`3o003oooooooooo`03ooooo`05
0?l00?ooool0003oooooo`000?l07oooool00ol0o`3oooooooooo`05ooooo`03o`3o0?oooooooooo
0?ooooooL?ooool000Oooooo0ol00004ooooo`;o00001oooool00ol0003oooooooooo`03ooooo`03
o`3o0?oooooooooo00cooooo00<0o`00ooooooooool00oooool00`3o003oooooooooo`020000oaoo
oooo00?o0?l0ooooooooool01Oooool00ol0o`3oooooooooo`3oooooog3ooooo000Gooooo`03o`00
0?oooooooooo00?ooooo00?o0?l0ooooooooool03?ooool00`3o003oooooooooo`03ooooo`030?l0
0?oooooooooo0080003o7oooool00ol0o`3oooooooooo`05ooooo`03o`3o0?oooooooooo0?oooooo
L?ooool001Oooooo00?o0000ooooooooool00oooool00ol0o`3oooooooooo`0<ooooo`030?l00?oo
oooooooo00?ooooo00<0o`00ooooooooool00P000?lOooooo`03o`3o0?oooooooooo00Gooooo00?o
0?l0ooooooooool0oooooom`ooooo`005oooool00ol0003oooooooooo`03ooooo`03o`3o0?oooooo
oooo00cooooo00<0o`00ooooooooool00oooool0103o003oooooooooo`000?lPooooo`03o`3o0?oo
oooooooo00Gooooo00?o0?l0ooooooooool0oooooom`ooooo`005oooool00ol0003oooooooooo`03
ooooo`03o`3o0?oooooooooo00cooooo00<0o`00ooooooooool00oooool0103o003oooooooooo`00
0?lPooooo`03o`3o0?oooooooooo00Gooooo00?o0?l0ooooooooool0oooooom`ooooo`005oooool0
0ol0003oooooooooo`03ooooo`03o`3o0?oooooooooo00cooooo00<0o`00ooooooooool00oooool0
103o003oooooooooo`000?lPooooo`03o`3o0?oooooooooo00Gooooo00?o0?l0ooooooooool0oooo
oom`ooooo`005oooool3o`0000?ooooo00?o0?l0ooooooooool03?ooool00`3o003oooooooooo`03
ooooo`040?l00?oooooooooo0000ob3ooooo00?o0?l0ooooooooool01Oooool00ol0o`3ooooooooo
o`3oooooog3ooooo000Gooooo`03o`000?oooooooooo00?ooooo00?o0?l0ooooooooool03?ooool0
0`3o003oooooooooo`03ooooo`040?l00?oooooooooo0000ob7ooooo00?o0?l0ooooooooool01?oo
ool00ol0o`3oooooooooo`3oooooog3ooooo000Gooooo`03o`000?oooooooooo00;ooooo00?o0?l0
ooooooooool03Oooool00`3o003oooooooooo`03ooooo`040?l00?oooooooooo0000ob7ooooo00?o
0?l0ooooooooool00oooool00ol0o`3oooooooooo`3oooooog7ooooo000Gooooo`03o`000?oooooo
oooo00;ooooo00?o0?l0ooooooooool03_ooool00`3o003oooooooooo`02ooooo`040?l00?oooooo
oooo0000ob7ooooo00?o0?l0ooooooooool00oooool00ol0o`3oooooooooo`3oooooog7ooooo000G
ooooo`03o`000?oooooooooo00;ooooo00?o0?l0ooooooooool03_ooool00`3o003oooooooooo`02
ooooo`040?l00?oooooooooo0000ob7ooooo00?o0?l0ooooooooool00oooool00ol0o`3ooooooooo
o`3oooooog7ooooo000Gooooo`03o`000?oooooooooo00;ooooo00?o0?l0ooooooooool03_ooool0
0`3o003oooooooooo`02ooooo`040?l00?oooooooooo0000ob7ooooo00?o0?l0ooooooooool00ooo
ool00ol0o`3oooooooooo`3oooooog7ooooo000Gooooo`03o`000?oooooooooo00;ooooo00?o0?l0
ooooooooool03_ooool00`3o003oooooooooo`02ooooo`040?l00?oooooooooo0000ob7ooooo00?o
0?l0ooooooooool00oooool00ol0o`3oooooooooo`3oooooog7ooooo000Gooooo`03o`000?oooooo
oooo00;ooooo00?o0?l0ooooooooool03_ooool00`3o003oooooooooo`02ooooo`040?l00?oooooo
oooo0000ob7ooooo00?o0?l0ooooooooool00oooool00ol0o`3oooooooooo`3oooooog7ooooo000G
ooooo`03o`000?oooooooooo00;ooooo00?o0?l0ooooooooool03_ooool00`3o003oooooooooo`02
ooooo`030?l00?oooooooooo02;ooooo00?o0?l0ooooooooool00oooool00ol0o`3oooooooooo`3o
ooooog7ooooo000Gooooo`?o00000_ooool00ol0o`3oooooooooo`0>ooooo`030?l00?oooooooooo
00;ooooo00<0o`00ooooooooool08_ooool00ol0o`3oooooooooo`03ooooo`03o`3o0?oooooooooo
0?ooooooLOooool001Oooooo00?o0000ooooooooool00_ooool00ol0o`3oooooooooo`0>ooooo`03
0?l00?oooooooooo00;ooooo00<0o`00ooooooooool08_ooool00ol0o`3oooooooooo`03ooooo`03
o`3o0?oooooooooo0?ooooooLOooool001Oooooo00?o0000ooooooooool00_ooool00ol0o`3ooooo
ooooo`0>ooooo`030?l00?oooooooooo00;ooooo00<0o`00ooooooooool08_ooool00ol0o`3ooooo
ooooo`03ooooo`03o`3o0?oooooooooo0?ooooooLOooool001Oooooo00?o0000ooooooooool00_oo
ool00ol0o`3oooooooooo`0>ooooo`030?l00?oooooooooo00;ooooo00<0o`00ooooooooool08_oo
ool00ol0o`3oooooooooo`03ooooo`03o`3o0?oooooooooo0?ooooooLOooool001Oooooo00?o0000
ooooooooool00_ooool00ol0o`3oooooooooo`0>ooooo`030?l00?oooooooooo00;ooooo00<0o`00
ooooooooool08oooool00ol0o`3oooooooooo`02ooooo`03o`3o0?oooooooooo0?ooooooLOooool0
01Oooooo00?o0000ooooooooool00_ooool00ol0o`3oooooooooo`0>ooooo`030?l00?oooooooooo
00;ooooo00<0o`00ooooooooool08oooool00ol0o`3oooooooooo`02ooooo`03o`3o0?oooooooooo
0?ooooooLOooool001Oooooo00?o0000ooooooooool00_ooool00ol0o`3oooooooooo`0>ooooo`03
0?l00?oooooooooo00;ooooo00<0o`00ooooooooool08oooool00ol0o`3oooooooooo`02ooooo`03
o`3o0?oooooooooo0?ooooooLOooool001Oooooo00?o0000ooooooooool00_ooool00ol0o`3ooooo
ooooo`0>ooooo`030?l00?oooooooooo00;ooooo00<0o`00ooooooooool08oooool00ol0o`3ooooo
ooooo`02ooooo`03o`3o0?oooooooooo0?ooooooLOooool001Oooooo00?o0000ooooooooool00_oo
ool00ol0o`3oooooooooo`0>ooooo`030?l00?oooooooooo00;ooooo00<0o`00ooooooooool08ooo
ool00ol0o`3oooooooooo`02ooooo`03o`3o0?oooooooooo0?ooooooLOooool001Oooooo0ol00002
ooooo`03o`3o0?oooooooooo00kooooo00<0o`00ooooooooool00_ooool00`3o003oooooooooo`0S
ooooo`03o`3o0?oooooooooo00;ooooo00?o0?l0ooooooooool0oooooomaooooo`005oooool00ol0
003oooooooooo`02ooooo`03o`3o0?oooooooooo00kooooo00<0o`00ooooooooool00_ooool00`3o
003oooooooooo`0Sooooo`03o`3o0?oooooooooo00;ooooo00?o0?l0ooooooooool0oooooomaoooo
o`005oooool00ol0003oooooooooo`02ooooo`03o`3o0?oooooooooo00kooooo00<0o`00oooooooo
ool00_ooool00`3o003oooooooooo`0Sooooo`03o`3o0?oooooooooo00;ooooo00?o0?l0oooooooo
ool0oooooomaooooo`005oooool00ol0003oooooooooo`02ooooo`03o`3o0?oooooooooo00kooooo
00<0o`00ooooooooool00_ooool00`3o003oooooooooo`0Sooooo`03o`3o0?oooooooooo00;ooooo
00?o0?l0ooooooooool0oooooomaooooo`005oooool00ol0003oooooooooo`02ooooo`03o`3o0?oo
oooooooo00kooooo00D0o`00oooooooooooooooo0?l0000Vooooo`03o`3o0?oooooooooo00;ooooo
00?o0?l0ooooooooool0oooooomaooooo`005oooool00ol0003oooooooooo`02ooooo`03o`3o0?oo
oooooooo00kooooo00D0o`00oooooooooooooooo0?l0000Vooooo`03o`3o0?oooooooooo00;ooooo
00?o0?l0ooooooooool0oooooomaooooo`0000Coooooo`000?l0003o00001?ooool2o`0000Cooooo
0_l00007ooooo`03o`000?oooooooooo00;ooooo00?o0?l0ooooooooool03_ooool01@3o003ooooo
ooooooooool0o`0002Kooooo00Go0?l0ooooooooooooooooo`3o003oooooogCooooo0002ooooo`03
o`000?oooooooooo00;ooooo00Co0000oooooooooooo00000_ooool01?l0003oooooooooool00006
ooooo`03o`000?oooooooooo00;ooooo00?o0?l0ooooooooool03_ooool01@3o003ooooooooooooo
ool0o`0002Oooooo00Co0?l0oooooooooooo0?l0oooooomdooooo`000_ooool00ol0003ooooooooo
o`02ooooo`04o`000?ooooooooooo`0000;ooooo00Co0000oooooooooooo00001_ooool00ol0003o
ooooooooo`02ooooo`03o`3o0?oooooooooo00kooooo00D0o`00oooooooooooooooo0?l0000Woooo
o`04o`3o0?ooooooooooo`3o0?ooooooM?ooool000;ooooo00?o0000ooooooooool00_ooool01?l0
003oooooooooool00002ooooo`04o`000?ooooooooooo`0000Kooooo1?l000000ooooooo0?l0oooo
o`0@ooooo`040?l00?oooooooooo0?l002Oooooo00Co0?l0oooooooooooo0?l0oooooomdooooo`00
0_ooool00ol0003oooooooooo`02ooooo`04o`000?ooooooooooo`0000;ooooo00Co0000oooooooo
oooo00001_ooool00ol0003oooooooooo`02ooooo`03o`3o0?oooooooooo00oooooo00@0o`00oooo
ooooool0o`009oooool01?l0o`3oooooooooool0o`3oooooogCooooo00000ooooooo0000o`000004
ooooo`04o`000?ooooooooooo`0000;ooooo00Co0000oooooooooooo00001_ooool00ol0003ooooo
ooooo`02ooooo`03o`3o0?oooooooooo00oooooo00@0o`00ooooooooool0o`009oooool01?l0o`3o
ooooooooool0o`3oooooogCooooo0002ooooo`03o`000?oooooooooo00?ooooo0_l00004ooooo`;o
00001oooool00ol0003oooooooooo`02ooooo`03o`3o0?oooooooooo00oooooo00@0o`00oooooooo
ool0o`009oooool01?l0o`3oooooooooool0o`3oooooogCooooo000Gooooo`03o`000?oooooooooo
00;ooooo00?o0?l0ooooooooool03oooool0103o003oooooooooo`3o000Wooooo`04o`3o0?oooooo
ooooo`3o0?ooooooM?ooool001Oooooo00Go0000ooooooooooooooooo`3o000Booooo`040?l00?oo
oooooooo0?l002Oooooo00Co0?l0oooooooooooo0?l0oooooomdooooo`005oooool01Ol0003ooooo
oooooooooooo0?l001;ooooo00@0o`00ooooooooool0o`009oooool01?l0o`3oooooooooool0o`3o
ooooogCooooo000Gooooo`05o`000?ooooooooooooooool0o`004_ooool0103o003oooooooooo`3o
000Wooooo`04o`3o0?ooooooooooo`3o0?ooooooM?ooool001Oooooo00Go0000oooooooooooooooo
o`3o000Booooo`040?l00?oooooooooo0?l002Oooooo00Co0?l0oooooooooooo0?l0oooooomdoooo
o`005oooool3o`000003ooooool0o`3ooooo017ooooo00@0o`00ooooooooool0o`009oooool01?l0
o`3oooooooooool0o`3oooooogCooooo000Gooooo`05o`000?ooooooooooooooool0o`004_ooool0
103o003oooooooooo`3o000Wooooo`04o`3o0?ooooooooooo`3o0?ooooooM?ooool001Oooooo00Go
0000ooooooooooooooooo`3o000Booooo`040?l00?oooooooooo0?l002Sooooo00?o0?l0ooooool0
o`00oooooomdooooo`005oooool01Ol0003ooooooooooooooooo0?l001;ooooo00@0o`00oooooooo
ool0o`00:?ooool00ol0o`3oooooo`3o003oooooogCooooo000Gooooo`05o`000?oooooooooooooo
ool0o`004_ooool0103o003oooooooooo`3o000Xooooo`03o`3o0?oooooo0?l00?ooooooM?ooool0
01Oooooo00Go0000ooooooooooooooooo`3o000Booooo`040?l00?oooooooooo0?l002Sooooo00?o
0?l0ooooool0o`00oooooomdooooo`005oooool01Ol0003ooooooooooooooooo0?l001;ooooo00@0
o`00ooooooooool0o`00:?ooool00ol0o`3oooooo`3o003oooooogCooooo000Gooooo`05o`000?oo
ooooooooooooool0o`004_ooool0103o003oooooooooo`3o000Xooooo`03o`3o0?oooooo0?l00?oo
ooooM?ooool001Oooooo00Go0000ooooooooooooooooo`3o000Booooo`040?l00?oooooooooo0?l0
02Sooooo00?o0?l0ooooool0o`00oooooomdooooo`005oooool3o`000003ooooool0o`3ooooo017o
oooo00@0o`00ooooooooool0o`00:?ooool2o`3o0?ooooooMOooool001Oooooo00Go0000oooooooo
ooooooooo`3o000Booooo`040?l00?oooooooooo0?l002Sooooo0_l0o`3oooooogGooooo000Goooo
o`05o`000?ooooooooooooooool0o`004_ooool0103o003oooooooooo`3o000Xooooo`;o0?l0oooo
oomeooooo`005oooool01Ol0003ooooooooooooooooo0?l001;ooooo00@0o`00ooooooooool0o`00
:?ooool2o`3o0?ooooooMOooool001Oooooo00Go0000ooooooooooooooooo`3o000Booooo`040?l0
0?oooooooooo0?l002Sooooo0_l0o`3oooooogGooooo000Gooooo`05o`000?ooooooooooooooool0
o`004_ooool0103o003oooooooooo`3o000Yooooo`03o`3o0?oooooooooo0?ooooooLoooool001Oo
oooo00Go0000ooooooooooooooooo`3o000Cooooo`030?l00?ooool0o`0002Wooooo00?o0?l0oooo
ooooool0oooooomcooooo`005oooool01Ol0003ooooooooooooooooo0?l001?ooooo00<0o`00oooo
o`3o0000:Oooool00ol0o`3oooooooooo`3oooooog?ooooo000Gooooo`05o`000?oooooooooooooo
ool0o`004oooool00`3o003ooooo0?l0000Yooooo`03o`3o0?oooooooooo0?ooooooLoooool001Oo
oooo0ol000000ooooooo0?l0ooooo`0Booooo`030?l00?ooool0o`0002Wooooo00?o0?l0oooooooo
ool0oooooomcooooo`005oooool01Ol0003ooooooooooooooooo0?l001?ooooo00<0o`00ooooo`3o
0000:Oooool00ol0o`3oooooooooo`3oooooog?ooooo000Gooooo`05o`000?ooooooooooooooool0
o`004oooool00`3o003ooooo0?l0003ooooooioooooo000Gooooo`05o`000?ooooooooooooooool0
o`004oooool00`3o003ooooo0?l0003ooooooioooooo000Gooooo`05o`000?ooooooooooooooool0
o`004oooool00`3o003ooooo0?l0003ooooooioooooo000Gooooo`05o`000?ooooooooooooooool0
o`004oooool00`3o003ooooo0?l0003ooooooioooooo00001?oooooo0000o`000?l00002ooooo`Go
00000oooool2o`0000Oooooo00Go0000ooooooooooooooooo`3o000Cooooo`030?l00?ooool0o`00
0?ooooooWoooool000;ooooo00?o0000ooooooooool00_ooool01?l0003oooooooooool00002oooo
o`04o`000?ooooooooooo`0000Kooooo00Co0000oooooooooooo0?l05?ooool00`3o003ooooo0?l0
003ooooooioooooo0002ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00_ooool0
1?l0003oooooooooool00006ooooo`04o`000?ooooooooooo`3o01Cooooo00<0o`00ooooo`3o0000
oooooonOooooo`000_ooool00ol0003oooooooooo`04ooooo`05o`000?ooooooooooooooool00000
0_ooool00ol0003oooooooooo`04ooooo`?o000000?o0?l0ooooooooool04_ooool00`3o003ooooo
0?l0003ooooooioooooo0002ooooo`05o`000?ooooooooooooooool000000oooool01?l0003ooooo
ooooool00002ooooo`03o`000?oooooooooo00Cooooo00Co0000oooooooooooo0?l05?ooool00`3o
003ooooo0?l0003ooooooioooooo00000ooooooo0000o`000003ooooo`05o`000?oooooooooooooo
ool000000_ooool01?l0003oooooooooool00006ooooo`04o`000?ooooooooooo`3o01Cooooo0P3o
003ooooooj3ooooo0002ooooo`03o`000?oooooooooo00;ooooo0ol00004ooooo`;o00001oooool0
1?l0003oooooooooool0o`0Dooooo`80o`00oooooonPooooo`005oooool01?l0003oooooooooool0
o`0Dooooo`80o`00oooooonPooooo`005oooool01?l0003oooooooooool0o`0Dooooo`80o`00oooo
oonPooooo`005oooool01?l0003oooooooooool0o`0Dooooo`80o`00oooooonPooooo`005oooool0
1?l0003oooooooooool0o`0Dooooo`80o`00oooooonPooooo`005oooool01?l0003oooooooooool0
o`0Dooooo`80o`00oooooonPooooo`005oooool3o`000003o`3o0?oooooooooo01;ooooo0P3o003o
oooooj3ooooo000Gooooo`04o`000?ooooooooooo`3o01Cooooo0P3o003ooooooj3ooooo000Goooo
o`04o`000?ooooooooooo`3o01Cooooo0P3o003ooooooj3ooooo000Gooooo`04o`000?oooooooooo
o`3o01Gooooo00<0o`00ooooooooool0oooooonNooooo`005oooool00ol0003oooooooooo`0Foooo
o`030?l00?oooooooooo0?ooooooW_ooool001Oooooo00?o0000ooooooooool05_ooool00`3o003o
ooooooooo`3ooooooikooooo000Gooooo`03o`000?oooooooooo01Kooooo00<0o`00ooooooooool0
oooooonNooooo`005oooool00ol0003oooooooooo`0Fooooo`030?l00?oooooooooo0?ooooooW_oo
ool001Oooooo00?o0000ooooooooool05_ooool00`3o003oooooooooo`3ooooooikooooo000Goooo
o`?o00005_ooool00`3o003oooooooooo`3ooooooikooooo000Gooooo`03o`000?oooooooooo01Ko
oooo00<0o`00ooooooooool0oooooonNooooo`005oooool00ol0003oooooooooo`0Fooooo`030?l0
0?oooooooooo0?ooooooW_ooool001Oooooo00?o0000ooooooooool05_ooool00`3o003ooooooooo
o`3ooooooikooooo000Gooooo`03o`000?oooooooooo01Kooooo00<0o`00ooooooooool0oooooonN
ooooo`005oooool00ol0003oooooooooo`0Fooooo`030?l00?oooooooooo0?ooooooW_ooool001Oo
oooo00?o0000ooooooooool0oooooongooooo`005oooool00ol0003oooooooooo`3ooooookOooooo
000Gooooo`03o`000?oooooooooo0?oooooo]oooool001Oooooo0ol0003ooooookOooooo000Goooo
o`03o`000?oooooooooo0?oooooo]oooool001Oooooo00?o0000ooooooooool0oooooongooooo`00
5oooool00ol0003oooooooooo`3ooooookOooooo000Gooooo`03o`000?oooooooooo0?oooooo]ooo
ool001Oooooo00?o0000ooooooooool0oooooongooooo`0000Coooooo`000?l0003o00001?ooool3
o`0000?ooooo0_l00007ooooo`03o`000?oooooooooo0?oooooo]oooool000;ooooo00?o0000oooo
ooooool01?ooool01Ol0003ooooooooooooooooo000000;ooooo00?o0000ooooooooool01?ooool0
0ol0003oooooooooo`3ooooookOooooo0002ooooo`04o`000?ooooooooooooooo`Go00000_ooool0
1?l0003oooooooooool00006ooooo`03o`000?oooooooooo0?oooooo]oooool000;ooooo00Go0000
ooooooooooooooooo`000002ooooo`05o`000?ooooooooooooooool000000_ooool00ol0003ooooo
ooooo`04ooooo`Co0000oooooonfooooo`000_ooool00ol0003oooooooooo`02ooooo`03o`000?oo
oooo000000?ooooo00Co0000oooooooooooo00001_ooool00ol0003oooooooooo`3ooooookOooooo
00000ooooooo0000o`000005ooooo`;o00000oooool01?l0003oooooooooool00006ooooo`03o`00
0?oooooooooo0?oooooo]oooool000;ooooo00?o0000ooooooooool01?ooool00ol0003ooooooooo
o`02ooooo`;o00001oooool00ol0003oooooooooo`3ooooookOooooo000Gooooo`03o`000?oooooo
oooo0?oooooo]oooool001Oooooo00?o0000ooooooooool0oooooongooooo`005oooool00ol0003o
ooooooooo`3ooooookOooooo000Gooooo`03o`000?oooooooooo0?oooooo]oooool001Oooooo00?o
0000ooooooooool0oooooongooooo`005oooool3o`000?oooooo]oooool001Oooooo00?o0000oooo
ooooool0oooooongooooo`005oooool00ol0003oooooooooo`3ooooookOooooo000Gooooo`03o`00
0?oooooooooo0?oooooo]oooool001Oooooo00?o0000ooooooooool0oooooongooooo`005oooool0
0ol0003oooooooooo`3ooooookOooooo000Gooooo`03o`000?oooooooooo0?oooooo]oooool001Oo
oooo00?o0000ooooooooool0oooooongooooo`005oooool00ol0003oooooooooo`3ooooookOooooo
000Gooooo`03o`000?oooooooooo0?oooooo]oooool00001\
\>"],
  ImageRangeCache->{{{0, 463.75}, {286.25, 0}} -> {-0.429349, -8.4543, \
0.0182949, 0.555034}}]
}, Open  ]],

Cell[TextData[{
  "The mean block size should be independent of genome length for large R.  \
Imagine a very long genome: its ancestry will trace back to some very large \
number of lineages, each carrying a small block R~1 in length.  For the human \
genome, total map length is ~ 36 Morgans.  Taking ",
  Cell[BoxData[
      \(TraditionalForm\`\(\(N\_e\)\(=\)\(10\^6\)\(\ \)\)\)]],
  "we have R ~ ",
  Cell[BoxData[
      \(TraditionalForm\`7.2\[Times]10\^7\)]],
  ".  The number of ancestral lineages will be of this order, which is ",
  StyleBox["larger",
    FontSlant->"Italic"],
  " than ",
  Cell[BoxData[
      \(TraditionalForm\`N\_e\)]],
  ".  For very long maps, with several crossovers per generation, the \
coalescent approximation breaks down because the # of ancestrla lineages \
approaches total population size.  Nevertheless, it will be valid for shorter \
chunks of genome"
}], "Text"]
}, Closed]]
}, Open  ]]
},
FrontEndVersion->"4.2 for Macintosh",
ScreenRectangle->{{0, 1276}, {0, 832}},
WindowSize->{1083, 786},
WindowMargins->{{Automatic, 26}, {Automatic, 1}},
StyleDefinitions -> "HelpBrowser.nb"
]

(*******************************************************************
Cached data follows.  If you edit this Notebook file directly, not
using Mathematica, you must remove the line containing CacheID at
the top of  the file.  The cache data will then be recreated when
you save this file from within Mathematica.
*******************************************************************)

(*CellTagsOutline
CellTagsIndex->{}
*)

(*CellTagsIndex
CellTagsIndex->{}
*)

(*NotebookFileOutline
Notebook[{
Cell[1754, 51, 210, 6, 24, "Text"],

Cell[CellGroupData[{
Cell[1989, 61, 113, 1, 36, "SubsectionIcon"],

Cell[CellGroupData[{
Cell[2127, 66, 189, 5, 24, "SubsubsectionIcon"],
Cell[2319, 73, 784, 24, 51, "Text"],
Cell[3106, 99, 245, 4, 55, "DisplayMath"],
Cell[3354, 105, 100, 3, 24, "Text"],

Cell[CellGroupData[{
Cell[3479, 112, 96, 2, 41, "Input"],
Cell[3578, 116, 85, 2, 21, "Output"]
}, Open  ]],
Cell[3678, 121, 62, 0, 24, "Text"],

Cell[CellGroupData[{
Cell[3765, 125, 145, 3, 41, "Input"],
Cell[3913, 130, 78, 2, 21, "Output"]
}, Open  ]],
Cell[4006, 135, 94, 3, 24, "Text"],
Cell[4103, 140, 250, 4, 55, "DisplayMath"],
Cell[4356, 146, 127, 3, 24, "Text"],

Cell[CellGroupData[{
Cell[4508, 153, 250, 5, 52, "Input"],
Cell[4761, 160, 126, 3, 21, "Output"]
}, Open  ]],
Cell[4902, 166, 94, 3, 24, "Text"],
Cell[4999, 171, 250, 4, 55, "DisplayMath"],
Cell[5252, 177, 265, 8, 24, "Text"],

Cell[CellGroupData[{
Cell[5542, 189, 142, 4, 26, "Input"],
Cell[5687, 195, 105, 2, 21, "Output"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{
Cell[5841, 203, 218, 5, 20, "SubsubsectionIcon"],
Cell[6062, 210, 102, 3, 24, "Text"],

Cell[CellGroupData[{
Cell[6189, 217, 253, 6, 42, "Input"],
Cell[6445, 225, 26272, 549, 184, 3860, 267, "GraphicsData", "PostScript", \
"Graphics"],
Cell[32720, 776, 78, 2, 21, "Output"]
}, Open  ]],
Cell[32813, 781, 643, 18, 47, "Text"],

Cell[CellGroupData[{
Cell[33481, 803, 175, 3, 41, "Input"],
Cell[33659, 808, 128, 3, 38, "Output"]
}, Open  ]],
Cell[33802, 814, 158, 3, 24, "Text"],

Cell[CellGroupData[{
Cell[33985, 821, 292, 6, 52, "Input"],
Cell[34280, 829, 129, 3, 21, "Output"]
}, Open  ]],
Cell[34424, 835, 574, 15, 40, "Text"],

Cell[CellGroupData[{
Cell[35023, 854, 121, 3, 50, "Input"],
Cell[35147, 859, 88, 2, 36, "Output"]
}, Open  ]],
Cell[35250, 864, 89, 3, 24, "Text"],

Cell[CellGroupData[{
Cell[35364, 871, 276, 6, 42, "Input"],
Cell[35643, 879, 35844, 723, 184, 4887, 336, "GraphicsData", "PostScript", \
"Graphics"],
Cell[71490, 1604, 99, 2, 21, "Output"]
}, Open  ]],
Cell[71604, 1609, 153, 4, 26, "Text"],

Cell[CellGroupData[{
Cell[71782, 1617, 350, 8, 52, "Input"],
Cell[72135, 1627, 128, 3, 21, "Output"]
}, Open  ]],
Cell[72278, 1633, 314, 6, 40, "Text"],
Cell[72595, 1641, 531, 13, 40, "Text"],

Cell[CellGroupData[{
Cell[73151, 1658, 138, 3, 50, "Input"],
Cell[73292, 1663, 78, 2, 39, "Output"]
}, Open  ]],
Cell[73385, 1668, 138, 3, 24, "Text"],

Cell[CellGroupData[{
Cell[73548, 1675, 263, 5, 42, "Input"],
Cell[73814, 1682, 43179, 861, 184, 5600, 392, "GraphicsData", "PostScript", \
"Graphics"]
}, Open  ]],
Cell[117008, 2546, 330, 7, 40, "Text"],

Cell[CellGroupData[{
Cell[117363, 2557, 49, 1, 26, "Input"],
Cell[117415, 2560, 79, 2, 21, "Output"]
}, Open  ]],
Cell[117509, 2565, 647, 17, 44, "Text"],
Cell[118159, 2584, 202, 8, 24, "Text"],
Cell[118364, 2594, 136, 3, 26, "Input"],
Cell[118503, 2599, 121, 3, 24, "Text"],

Cell[CellGroupData[{
Cell[118649, 2606, 184, 4, 26, "Input"],
Cell[118836, 2612, 662, 15, 111, "Output"]
}, Open  ]],
Cell[119513, 2630, 159, 5, 24, "Text"],
Cell[119675, 2637, 158, 4, 24, "Text"]
}, Closed]]
}, Open  ]],

Cell[CellGroupData[{
Cell[119882, 2647, 112, 1, 36, "SubsectionIcon"],

Cell[CellGroupData[{
Cell[120019, 2652, 249, 5, 24, "SubsubsectionIcon"],
Cell[120271, 2659, 373, 8, 44, "Text"],
Cell[120647, 2669, 141, 3, 24, "Text"],

Cell[CellGroupData[{
Cell[120813, 2676, 172, 3, 55, "Input"],
Cell[120988, 2681, 4780, 68, 257, "Output"]
}, Open  ]],
Cell[125783, 2752, 358, 10, 28, "Text"],

Cell[CellGroupData[{
Cell[126166, 2766, 126, 2, 38, "Input"],
Cell[126295, 2770, 142, 3, 33, "Output"]
}, Open  ]],
Cell[126452, 2776, 232, 5, 24, "Text"],
Cell[126687, 2783, 249, 7, 24, "Text"],

Cell[CellGroupData[{
Cell[126961, 2794, 186, 4, 43, "Input"],
Cell[127150, 2800, 4858, 68, 245, "Output"]
}, Open  ]],
Cell[132023, 2871, 340, 6, 40, "Text"],

Cell[CellGroupData[{
Cell[132388, 2881, 145, 3, 26, "Input"],
Cell[132536, 2886, 134, 3, 21, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[132707, 2894, 350, 7, 58, "Input"],
Cell[133060, 2903, 46437, 1113, 170, 9249, 649, "GraphicsData", "PostScript", \
"Graphics"]
}, Open  ]],
Cell[179512, 4019, 135, 3, 24, "Text"]
}, Closed]]
}, Open  ]],

Cell[CellGroupData[{
Cell[179696, 4028, 104, 1, 36, "SubsectionIcon"],

Cell[CellGroupData[{
Cell[179825, 4033, 260, 6, 24, "SubsubsectionIcon"],
Cell[180088, 4041, 119, 3, 24, "Text"],

Cell[CellGroupData[{
Cell[180232, 4048, 132, 3, 26, "Input"],
Cell[180367, 4053, 2356, 36, 175, "Output"]
}, Open  ]],
Cell[182738, 4092, 511, 11, 40, "Text"],
Cell[183252, 4105, 231, 6, 24, "Text"],

Cell[CellGroupData[{
Cell[183508, 4115, 236, 5, 58, "Input"],
Cell[183747, 4122, 57408, 1347, 162, 21317, 896, "GraphicsData", \
"PostScript", "Graphics"],
Cell[241158, 5471, 1262, 22, 133, "Output"]
}, Open  ]],
Cell[242435, 5496, 168, 6, 24, "Text"],
Cell[242606, 5504, 208, 4, 24, "Text"],

Cell[CellGroupData[{
Cell[242839, 5512, 61, 2, 26, "Input"],
Cell[242903, 5516, 2003, 34, 149, "Output"]
}, Open  ]]
}, Closed]]
}, Open  ]],

Cell[CellGroupData[{
Cell[244967, 5557, 93, 1, 36, "SubsectionIcon"],

Cell[CellGroupData[{
Cell[245085, 5562, 294, 6, 40, "SubsubsectionIcon"],
Cell[245382, 5570, 481, 16, 31, "Text"],

Cell[CellGroupData[{
Cell[245888, 5590, 299, 6, 52, "Input"],
Cell[246190, 5598, 143, 3, 21, "Output"]
}, Open  ]],
Cell[246348, 5604, 223, 4, 24, "Text"]
}, Closed]],

Cell[CellGroupData[{
Cell[246608, 5613, 295, 6, 36, "SubsubsectionIcon"],
Cell[246906, 5621, 135, 3, 24, "Text"],

Cell[CellGroupData[{
Cell[247066, 5628, 140, 3, 43, "Input"],
Cell[247209, 5633, 112, 2, 21, "Output"]
}, Open  ]],
Cell[247336, 5638, 375, 8, 29, "Text"],

Cell[CellGroupData[{
Cell[247736, 5650, 145, 3, 43, "Input"],
Cell[247884, 5655, 102, 2, 21, "Output"]
}, Open  ]],
Cell[248001, 5660, 409, 8, 40, "Text"]
}, Closed]],
Cell[248425, 5671, 38, 0, 34, "Subsubsection"],

Cell[CellGroupData[{
Cell[248488, 5675, 265, 6, 24, "SubsubsectionIcon"],
Cell[248756, 5683, 410, 10, 40, "Text"],
Cell[249169, 5695, 176, 4, 30, "Input"],
Cell[249348, 5701, 185, 5, 24, "Text"],
Cell[249536, 5708, 52, 0, 24, "Text"],

Cell[CellGroupData[{
Cell[249613, 5712, 518, 11, 99, "Input"],
Cell[250134, 5725, 17172, 409, 184, 3311, 233, "GraphicsData", "PostScript", \
"Graphics"],
Cell[267309, 6136, 559, 16, 127, "Output"]
}, Open  ]],
Cell[267883, 6155, 131, 3, 24, "Text"],
Cell[268017, 6160, 183, 4, 24, "Text"],

Cell[CellGroupData[{
Cell[268225, 6168, 514, 11, 96, "Input"],
Cell[268742, 6181, 16818, 405, 184, 3172, 231, "GraphicsData", "PostScript", \
"Graphics"],
Cell[285563, 6588, 560, 16, 127, "Output"]
}, Open  ]],
Cell[286138, 6607, 288, 7, 24, "Text"],

Cell[CellGroupData[{
Cell[286451, 6618, 516, 11, 96, "Input"],
Cell[286970, 6631, 17298, 425, 184, 3457, 249, "GraphicsData", "PostScript", \
"Graphics"],
Cell[304271, 7058, 483, 14, 95, "Output"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{
Cell[304803, 7078, 532, 16, 26, "SubsubsectionIcon"],
Cell[305338, 7096, 407, 12, 28, "Text"],
Cell[305748, 7110, 238, 6, 24, "Text"],
Cell[305989, 7118, 275, 5, 44, "DisplayMath"],
Cell[306267, 7125, 22, 0, 24, "Text"],
Cell[306292, 7127, 204, 3, 46, "DisplayMath"],
Cell[306499, 7132, 55, 0, 24, "Text"],
Cell[306557, 7134, 171, 3, 47, "DisplayMath"],
Cell[306731, 7139, 404, 12, 28, "Text"],
Cell[307138, 7153, 200, 3, 47, "DisplayMath"],
Cell[307341, 7158, 505, 14, 40, "Text"]
}, Closed]]
}, Open  ]],

Cell[CellGroupData[{
Cell[307895, 7178, 102, 1, 36, "SubsectionIcon"],

Cell[CellGroupData[{
Cell[308022, 7183, 200, 5, 24, "SubsubsectionIcon"],
Cell[308225, 7190, 230, 4, 24, "Text"],
Cell[308458, 7196, 362, 8, 58, "Input"],
Cell[308823, 7206, 71, 0, 24, "Text"],

Cell[CellGroupData[{
Cell[308919, 7210, 258, 5, 58, "Input"],
Cell[309180, 7217, 15352, 400, 184, 2917, 241, "GraphicsData", "PostScript", \
"Graphics"],
Cell[324535, 7619, 562, 16, 127, "Output"]
}, Open  ]],
Cell[325112, 7638, 712, 11, 56, "Text"],
Cell[325827, 7651, 63, 0, 24, "Text"],
Cell[325893, 7653, 328, 8, 42, "Input"],
Cell[326224, 7663, 61, 0, 24, "Text"],

Cell[CellGroupData[{
Cell[326310, 7667, 835, 18, 106, "Input"],
Cell[327148, 7687, 95705, 1722, 294, 7902, 633, "GraphicsData", "PostScript", \
"Graphics"]
}, Open  ]],
Cell[422868, 9412, 905, 20, 56, "Text"]
}, Closed]]
}, Open  ]]
}
]
*)



(*******************************************************************
End of Mathematica Notebook file.
*******************************************************************)

