(***********************************************************************

                    Mathematica-Compatible Notebook

This notebook can be used on any computer system with Mathematica 4.0,
MathReader 4.0, or any compatible application. The data for the notebook 
starts with the line containing stars above.

To get the notebook into a Mathematica-compatible application, do one of 
the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing the 
word CacheID, otherwise Mathematica-compatible applications may try to 
use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
***********************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[      3307,         94]*)
(*NotebookOutlinePosition[      4363,        128]*)
(*  CellTagsIndexPosition[      4274,        122]*)
(*WindowFrame->Normal*)



Notebook[{

Cell[CellGroupData[{
Cell["Calculating the moment generating function", "SubsubsectionIcon"],

Cell[TextData[Cell[BoxData[
    FormBox[GridBox[{
          {\(MomentGeneratingFunction[
              g, \[Omega], \[Theta]]\), \(gives\ the\ generating\ function\ \
for\ the\ number\ of\ mutations\ along\ each\ branch\ of\ the\ genealogy, \ 
            under\ the\ infinite\ sites\ \(\(model\)\(.\)\)\)}
          }], TraditionalForm]]]], "DefinitionBox",
  CellTags->"MomentGeneratingFunction"],

Cell[TextData[{
  "\tMomentGeneratingFunction[] constructs the generating function using a \
recursive algorithm, which gives a sum of terms, each corresponding to \
different orders on which coalescence might occur.  The generating function \
is defined as ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          FormBox[\(P\&~[\[Omega]\+_]\),
            "TraditionalForm"], 
          "=", \(\[Sum]\+\(j = 0\)\%\[Infinity]\[Product]\+k\( \[Omega]\_k\%j\
\_k\) P[j\+_]\)}], TraditionalForm]]],
  "; the variables are denoted ",
  Cell[BoxData[
      \(TraditionalForm\`\[Omega][k]\)]],
  " , where ",
  Cell[BoxData[
      \(TraditionalForm\`k\)]],
  " labels the nodes of the genealogy.  The probability ",
  Cell[BoxData[
      \(TraditionalForm\`P[j\+_]\)]],
  " is the probability that a tree with a particular ordered topology would \
be produced by the coalescent process, and that ",
  Cell[BoxData[
      \(TraditionalForm\`j\_k\)]],
  "mutations would arise on the branch leading down to node ",
  Cell[BoxData[
      \(TraditionalForm\`k\)]],
  "."
}], "Text"]
}, Open  ]]
},
FrontEndVersion->"4.0 for Macintosh",
ScreenRectangle->{{0, 1152}, {0, 748}},
WindowSize->{520, 626},
WindowMargins->{{Automatic, 86}, {42, Automatic}},
StyleDefinitions -> "HelpBrowser.nb",
MacintoshSystemPageSetup->"\<\
00<0001804P000000`d26_oQon@3:`8g0dL5N`?P0080001804P000000]P2:001
0000I00000400`<30?l00BL?00400@0000000000000006P801T1T00000000000
00000000004000000000000000000000\>"
]


(***********************************************************************
Cached data follows.  If you edit this Notebook file directly, not using
Mathematica, you must remove the line containing CacheID at the top of 
the file.  The cache data will then be recreated when you save this file 
from within Mathematica.
***********************************************************************)

(*CellTagsOutline
CellTagsIndex->{
  "MomentGeneratingFunction"->{
    Cell[1813, 53, 398, 7, 68, "DefinitionBox",
      CellTags->"MomentGeneratingFunction"]}
  }
*)

(*CellTagsIndex
CellTagsIndex->{
  {"MomentGeneratingFunction", 4155, 115}
  }
*)

(*NotebookFileOutline
Notebook[{

Cell[CellGroupData[{
Cell[1739, 51, 71, 0, 24, "SubsubsectionIcon"],
Cell[1813, 53, 398, 7, 68, "DefinitionBox",
  CellTags->"MomentGeneratingFunction"],
Cell[2214, 62, 1077, 29, 104, "Text"]
}, Open  ]]
}
]
*)




(***********************************************************************
End of Mathematica Notebook file.
***********************************************************************)

