(***********************************************************************

                    Mathematica-Compatible Notebook

This notebook can be used on any computer system with Mathematica 4.0,
MathReader 4.0, or any compatible application. The data for the notebook 
starts with the line containing stars above.

To get the notebook into a Mathematica-compatible application, do one of 
the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing the 
word CacheID, otherwise Mathematica-compatible applications may try to 
use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
***********************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[      4426,        122]*)
(*NotebookOutlinePosition[      5308,        150]*)
(*  CellTagsIndexPosition[      5264,        146]*)
(*WindowFrame->Normal*)



Notebook[{

Cell[CellGroupData[{
Cell["Implementation", "SubsectionIcon"],

Cell["\<\
\tThe whole population, living and dead, is recorded in a set of \
function definitions; individuals are referred to by an integer.  This scheme \
makes it easy to trace genealogies.  It does use a great deal of memory, with \
definitions of length equal to the number of all individuals that have ever \
existed.  However, time is more likely to be limiting than memory; and it \
would always be possible to prune the lists by removing ancestors who left no \
descendants, or all ancestors who lived before a certain time.\
\>", "Text"],

Cell[TextData[{
  "Using function definitions is much faster than maintaining lists in ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  "."
}], "Text"],

Cell[TextData[{
  "Compiling the whole algorithm would not be feasible, because Compile[] \
only allows rectangular arrays.  The time-consuming step is the calculation \
of distances and densities, and then of mortalities and fecundities; this \
does not seem to be speeded up by compiling.  A simulation in a compiled \
language would be much faster; the aim of this package is to provide a simple \
way of exploring the properties of the model, rather than large-scale \
simulation.  It would be possible to transfer output from a compiled \
simulation into files for manipulation by ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  "."
}], "Text"],

Cell[TextData[{
  "The locations of all individuals are recorded in ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          RowBox[{"Locations", "[", 
            RowBox[{
              StyleBox["popln",
                FontSlant->"Italic"], ",", "i"}], "]"}], "=", \(x\_i\)}], 
        TraditionalForm]]],
  ".  These are locations in a one- or two-dimensional habitat, wrapped on a \
torus of size R.  Also recorded are Density, BirthTime, DeathTime, Parent, \
Offspring, Fecundity, Mortality, and Genotype."
}], "Text"],

Cell[TextData[{
  "Global variables that are tracked are the NumberOfIndividuals, ",
  Cell[BoxData[
      \(TraditionalForm\`\(n\ \)\)]],
  "; NetMortality and NetFecundity; and the current time, ",
  Cell[BoxData[
      \(TraditionalForm\`T\)]],
  ". ExtantIndividuals[",
  StyleBox["popln",
    FontSlant->"Italic"],
  "] is a list of all living individuals."
}], "Text"],

Cell[TextData[{
  "The location of neighbouring individuals is found using Individuals[], \
which is a function that gives a list of the extant individuals in each box; \
Neighbours[x, \[CapitalDelta]] gives the codes of all individuals near to ",
  Cell[BoxData[
      \(TraditionalForm\`x\)]],
  "; boxes are of size \[CapitalDelta]."
}], "Text"]
}, Open  ]]
},
FrontEndVersion->"4.0 for Macintosh",
ScreenRectangle->{{0, 1152}, {0, 748}},
WindowSize->{489, 651},
WindowMargins->{{Automatic, -1}, {Automatic, 1}},
StyleDefinitions -> "HelpBrowser.nb",
MacintoshSystemPageSetup->"\<\
00`0001804P000000_02@?o/onh3109BI085:0?l0@00005X0FP000003[0;@001
0000I00100000@0000000BL?0040000000000000000000000000000000000?nL
ojH?50^J00P100000000000000000000\>"
]


(***********************************************************************
Cached data follows.  If you edit this Notebook file directly, not using
Mathematica, you must remove the line containing CacheID at the top of 
the file.  The cache data will then be recreated when you save this file 
from within Mathematica.
***********************************************************************)

(*CellTagsOutline
CellTagsIndex->{}
*)

(*CellTagsIndex
CellTagsIndex->{}
*)

(*NotebookFileOutline
Notebook[{

Cell[CellGroupData[{
Cell[1739, 51, 40, 0, 36, "SubsectionIcon"],
Cell[1782, 53, 547, 8, 92, "Text"],
Cell[2332, 63, 159, 5, 24, "Text"],
Cell[2494, 70, 658, 12, 94, "Text"],
Cell[3155, 84, 527, 13, 50, "Text"],
Cell[3685, 99, 374, 11, 38, "Text"],
Cell[4062, 112, 348, 7, 50, "Text"]
}, Open  ]]
}
]
*)




(***********************************************************************
End of Mathematica Notebook file.
***********************************************************************)

