(***********************************************************************

                    Mathematica-Compatible Notebook

This notebook can be used on any computer system with Mathematica 4.0,
MathReader 4.0, or any compatible application. The data for the notebook 
starts with the line containing stars above.

To get the notebook into a Mathematica-compatible application, do one of 
the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing the 
word CacheID, otherwise Mathematica-compatible applications may try to 
use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
***********************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[      5431,        177]*)
(*NotebookOutlinePosition[      6776,        219]*)
(*  CellTagsIndexPosition[      6647,        211]*)
(*WindowFrame->Normal*)



Notebook[{

Cell[CellGroupData[{
Cell["Iterating", "SubsectionIcon"],

Cell[TextData[Cell[BoxData[
    FormBox[GridBox[{
          {
            RowBox[{
              RowBox[{"IterateContinuum", "[", 
                RowBox[{
                  StyleBox["popln",
                    FontSlant->"Italic"], ",", "R", ",", "\[CapitalDelta]", 
                  ",", "U", ",", "M", ",", "F", ",", "D"}], "]"}], 
              " "}], \(iterates\ a\ population\ on\ a\ range\ R . \ 
                Dispersal\ is\ specified\ by\ D[\[Rho], x, g]\)},
          {
            RowBox[{
              RowBox[{
                RowBox[{"Birth", "[", 
                  RowBox[{
                    StyleBox["popln",
                      FontSlant->"Italic"], ",", "U", ",", "M", ",", "F", ",",
                     "D"}], "]"}], "[", \(R, \[CapitalDelta]\), "]"}], 
              " "}], \(adds\ a\ random\ newborn\ individual . \ 
                Returns\ the\ number\ of\ the\ newborn\ \(\(individual\)\(.\)\
\)\)},
          {
            RowBox[{
              RowBox[{
                RowBox[{"Death", "[", 
                  RowBox[{
                    StyleBox["popln",
                      FontSlant->"Italic"], ",", "U", ",", "M", ",", "F"}], 
                  "]"}], "[", \(R, \[CapitalDelta]\), "]"}], 
              " "}], \(deletes\ a\ random\ individual . \ 
                Returns\ minus\ the\ number\ of\ the\ dead\ \
\(\(individual\)\(.\)\)\)}
          }], TraditionalForm]]]], "DefinitionBox",
  CellTags->{"IterateContinuum", "Birth", "Death"}],

Cell["The dispersal distribution must be specified:", "MathCaption"],

Cell[BoxData[
    \(\(Disp[\[Sigma]_] := 
        RandomArray[NormalDistribution[0, \[Sigma]], {2}] &;\)\)], "Input",
  CellLabel->"In[12]:="],

Cell[TextData[{
  "This generates a random Gaussian, with standard deviation \[Sigma].  In \
general, a function D[",
  StyleBox["pars",
    FontSlant->"Italic"],
  "][\[Rho],x,g] of density, position, and genotype can be specified; it \
generates a random displacement vector."
}], "Text"],

Cell["An individual has died:", "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[
    \(IterateContinuum[p1, R, \[CapitalDelta], U[1], M[5], F[2], 
      Disp[1]]\)], "Input",
  CellLabel->"In[247]:="],

Cell[BoxData[
    \(\(\(-\)\(66\)\(\ \)\)\)], "Output",
  CellLabel->"Out[26]="]
}, Open  ]],

Cell["Minus the number of the dead individual is returned.", "Text"],

Cell["One has been born:", "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[
    \(IterateContinuum[p1, R, \[CapitalDelta], U[1], M[5], F[2], 
      Disp[1]]\)], "Input",
  CellLabel->"In[246]:="],

Cell[BoxData[
    \(100\)], "Output",
  CellLabel->"Out[27]="]
}, Open  ]],

Cell["\<\
The number of the newborn individual is returned; this is just the \
current total number.\
\>", "Text"],

Cell["\<\
The new individual is labelled 101, and came from parent individual \
63:\
\>", "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[
    \(Ancestry[p1, 101]\)], "Input",
  CellLabel->"In[33]:="],

Cell[BoxData[
    \({63}\)], "Output",
  CellLabel->"Out[33]="]
}, Open  ]],

Cell["\<\
These are their locations, and the distance between them (remember, \
distances are wrapped around a torus with R=30):\
\>", "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(parent = Location[p1, 63]; 
    offspring = Location[p1, 101];\), "\[IndentingNewLine]", 
    \({parent, 
      offspring, \@DistanceSquared[parent, offspring, R]}\)}], "Input",
  CellLabel->"In[35]:="],

Cell[BoxData[
    \({{2.3972487082061664`, 27.548273952463454`}, {29.736453921514073`, 
        2.1198015079647687`}, 5.289488924990362`}\)], "Output",
  CellLabel->"Out[36]="]
}, Open  ]]
}, Open  ]]
},
FrontEndVersion->"4.0 for Macintosh",
ScreenRectangle->{{0, 1152}, {0, 748}},
WindowSize->{1021, 625},
WindowMargins->{{27, Automatic}, {Automatic, 24}},
StyleDefinitions -> "HelpBrowser.nb",
MacintoshSystemPageSetup->"\<\
00`0001804P000000_02@?o/onh3109BI085:0?l0@00005X0FP000003[0;@001
0000I00100000@0000000BL?0040000000000000000000000000000000000?nL
ojH?50^J00P100000000000000000000\>"
]


(***********************************************************************
Cached data follows.  If you edit this Notebook file directly, not using
Mathematica, you must remove the line containing CacheID at the top of 
the file.  The cache data will then be recreated when you save this file 
from within Mathematica.
***********************************************************************)

(*CellTagsOutline
CellTagsIndex->{
  "IterateContinuum"->{
    Cell[1777, 53, 1484, 34, 76, "DefinitionBox",
      CellTags->{"IterateContinuum", "Birth", "Death"}]},
  "Birth"->{
    Cell[1777, 53, 1484, 34, 76, "DefinitionBox",
      CellTags->{"IterateContinuum", "Birth", "Death"}]},
  "Death"->{
    Cell[1777, 53, 1484, 34, 76, "DefinitionBox",
      CellTags->{"IterateContinuum", "Birth", "Death"}]}
  }
*)

(*CellTagsIndex
CellTagsIndex->{
  {"IterateContinuum", 6272, 198},
  {"Birth", 6393, 201},
  {"Death", 6514, 204}
  }
*)

(*NotebookFileOutline
Notebook[{

Cell[CellGroupData[{
Cell[1739, 51, 35, 0, 36, "SubsectionIcon"],
Cell[1777, 53, 1484, 34, 76, "DefinitionBox",
  CellTags->{"IterateContinuum", "Birth", "Death"}],
Cell[3264, 89, 68, 0, 28, "MathCaption"],
Cell[3335, 91, 142, 3, 26, "Input"],
Cell[3480, 96, 290, 7, 24, "Text"],
Cell[3773, 105, 46, 0, 28, "MathCaption"],

Cell[CellGroupData[{
Cell[3844, 109, 133, 3, 26, "Input"],
Cell[3980, 114, 80, 2, 20, "Output"]
}, Open  ]],
Cell[4075, 119, 68, 0, 22, "Text"],
Cell[4146, 121, 41, 0, 28, "MathCaption"],

Cell[CellGroupData[{
Cell[4212, 125, 133, 3, 26, "Input"],
Cell[4348, 130, 62, 2, 20, "Output"]
}, Open  ]],
Cell[4425, 135, 114, 3, 22, "Text"],
Cell[4542, 140, 104, 3, 28, "MathCaption"],

Cell[CellGroupData[{
Cell[4671, 147, 75, 2, 26, "Input"],
Cell[4749, 151, 63, 2, 20, "Output"]
}, Open  ]],
Cell[4827, 156, 149, 3, 28, "MathCaption"],

Cell[CellGroupData[{
Cell[5001, 163, 223, 5, 48, "Input"],
Cell[5227, 170, 176, 3, 20, "Output"]
}, Open  ]]
}, Open  ]]
}
]
*)




(***********************************************************************
End of Mathematica Notebook file.
***********************************************************************)

