(***********************************************************************

                    Mathematica-Compatible Notebook

This notebook can be used on any computer system with Mathematica 4.0,
MathReader 4.0, or any compatible application. The data for the notebook 
starts with the line containing stars above.

To get the notebook into a Mathematica-compatible application, do one of 
the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing the 
word CacheID, otherwise Mathematica-compatible applications may try to 
use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
***********************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[     30458,        684]*)
(*NotebookOutlinePosition[     31483,        718]*)
(*  CellTagsIndexPosition[     31404,        712]*)
(*WindowFrame->Normal*)



Notebook[{

Cell[CellGroupData[{
Cell["Making a genealogy", "SubsectionIcon"],

Cell[TextData[Cell[BoxData[
    FormBox[GridBox[{
          {
            FormBox[
              RowBox[{"MakeGenealogy", "[", 
                RowBox[{
                  StyleBox["popln",
                    FontSlant->"Italic"], 
                  ",", \({i\_1, i\_2, \[Ellipsis]}\)}], "]"}],
              
              "TextForm"], \(constructs\ the\ genealogy\ which\ relates\ \
individuals\ \(\({i\_1, i\_2, \[Ellipsis]}\)\(.\)\)\)},
          {
            FormBox[
              RowBox[{"MakeGenealogy", "[", 
                RowBox[{
                  StyleBox["popln",
                    FontSlant->"Italic"], ",", \({i\_1, i\_2, \[Ellipsis]}\), 
                  ",", " ", \(NodeFunction \[Rule] f\)}], "]"}],
              "TextForm"], \(inserts\ information\ f[j]\ at\ each\ node, \ 
            j; \ this\ must\ return\ a\ \(\(list\)\(.\)\)\)}
          }], TraditionalForm]]]], "DefinitionBox",
  CellTags->"MakeGenealogy"],

Cell["\<\
This is the genealogy which connects all the living \
individuals:\
\>", "MathCaption"],

Cell[BoxData[
    \(ei = ExtantIndividuals[p1]; \ntrAll = MakeGenealogy[p1, ei]; \)], 
  "Input",
  CellLabel->"In[60]:="],

Cell["\<\
Because there are three ancestors to the set of living individuals, \
the genealogy consists of three parts, joined at the dummy node 0:\
\>", \
"MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[
    \(trAll // Shallow\)], "Input",
  CellLabel->"In[61]:="],

Cell[BoxData[
    \(Node[
      0, {}, {Node[\[LeftSkeleton]3\[RightSkeleton]], 
        Node[\[LeftSkeleton]3\[RightSkeleton]], 
        Node[\[LeftSkeleton]3\[RightSkeleton]]}]\)], "Output",
  CellLabel->"Out[61]//Shallow="]
}, Closed]],

Cell["\<\
There may be multifurcations, because several siblings may survive. \
 This plot suppresses leaf and node labels:\
\>", "MathCaption"],

Cell[BoxData[
    \(\(Show[
      PlotGenealogy[trAll, LeafLabels \[Rule] None, 
        NodeLabels \[Rule] None]]; \)\)], "Input",
  CellLabel->"In[62]:="],

Cell["\<\
This gives a genealogy connecting 10 individuals, which includes \
the birth time of each individual:\
\>", "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[
    \(tr = 
      MakeGenealogy[p1, Take[ei, 10], 
        NodeFunction \[Rule] \(({BirthTime[p1, #]}&)\)]\)], "Input",
  CellLabel->"In[51]:="],

Cell[BoxData[
    \(Node[
      0, {0}, {Node[
          24027, {77.6429067882569778`}, {
            Node[27570, {90.4274344506116278`}, {
                Node[28669, {93.8262515328053936`}, {}], 
                Node[29422, {95.7326756885663243`}, {}]}], 
            Node[29214, {95.2218054194343821`}, {}]}], 
        Node[5365, {15.9768041555189066`}, {
            Node[24624, {79.8373784941055486`}, {
                Node[28770, {94.1118445035857931`}, {}], 
                Node[25318, {82.0033561741303529`}, {
                    Node[29115, {94.9518667132191751`}, {}], 
                    Node[29407, {95.6949811040170139`}, {}]}]}], 
            Node[18139, {55.5437844758781373`}, {
                Node[29107, {94.9240191285745638`}, {}], 
                Node[22141, {70.0216253497730711`}, {
                    Node[29209, {95.2175628376747695`}, {}], 
                    Node[26751, {87.630718620488075`}, {
                        Node[29244, {95.2984378793575537`}, {}], 
                        Node[29387, {95.6431937501871942`}, {}]}]}]}]}]}]\)], 
  "Output",
  CellLabel->"Out[51]="]
}, Closed]],

Cell[TextData[{
  "Note that the brackets around the function ({BirthTime[p1,#]}&) are \
essential for ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " to interpret the input correctly."
}], "Text"],

Cell[TextData[{
  "In general, the NodeFunction is ",
  Cell[BoxData[
      \(TraditionalForm\`f[j, x, g]\)]],
  " where ",
  Cell[BoxData[
      \(TraditionalForm\`x\)]],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`g\)]],
  " are the genotypes of ancestor ",
  Cell[BoxData[
      \(TraditionalForm\`\(\(j\)\(.\)\)\)]],
  "  "
}], "Text"],

Cell["\<\
This plots the genealogy connecting the 10 individuals; the \
vertical axis is arbitrary:\
\>", "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(Show[
      PlotGenealogy[tr, LeafLabels \[Rule] None, NodeLabels \[Rule] None]]; 
    \)\)], "Input",
  CellLabel->"In[52]:="],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0909091 0.0909091 0.0882906 0.0882906 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
0 g
.5 Mabswid
[ ] 0 setdash
.5 .52974 m
.18182 .26487 L
s
.5 .52974 m
.63636 .44145 L
s
.63636 .44145 m
.45455 .26487 L
s
.63636 .44145 m
.77273 .35316 L
s
.77273 .35316 m
.63636 .08829 L
s
.77273 .35316 m
.81818 .26487 L
s
.81818 .26487 m
.72727 .08829 L
s
.81818 .26487 m
.86364 .17658 L
s
.18182 .26487 m
.13636 .17658 L
s
.18182 .26487 m
.27273 .08829 L
s
.45455 .26487 m
.36364 .08829 L
s
.45455 .26487 m
.5 .17658 L
s
.5 .17658 m
.45455 .08829 L
s
.5 .17658 m
.54545 .08829 L
s
.86364 .17658 m
.81818 .08829 L
s
.86364 .17658 m
.90909 .08829 L
s
.13636 .17658 m
.09091 .08829 L
s
.13636 .17658 m
.18182 .08829 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[52]:=",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/A000`40O003h00Oogoo8Goo003oOolQ
Ool00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00
ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQ
Ool00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00
ogoo8Goo000JOol00`00Oomoo`0GOol00`00Oomoo`0GOol00`00Oomoo`0GOol00`00Oomoo`0GOol0
0`00Oomoo`0GOol00`00Oomoo`0GOol00`00Oomoo`0GOol00`00Oomoo`0GOol00`00Oomoo`0GOol0
0`00Oomoo`0IOol001Yoo`03001oogoo01Moo`03001oogoo01Moo`03001oogoo01Moo`03001oogoo
01Moo`03001oogoo01Moo`03001oogoo01Moo`03001oogoo01Moo`03001oogoo01Moo`03001oogoo
01Moo`03001oogoo01Uoo`006goo00<007ooOol05Goo00<007ooOol05goo00<007ooOol06Goo00<0
07ooOol05goo00<007ooOol05Goo00<007ooOol06Goo00<007ooOol05goo00<007ooOol05goo00<0
07ooOol05Goo00<007ooOol06Woo000KOol00`00Oomoo`0EOol00`00Oomoo`0GOol00`00Oomoo`0I
Ool00`00Oomoo`0GOol00`00Oomoo`0EOol00`00Oomoo`0IOol00`00Oomoo`0GOol00`00Oomoo`0G
Ool00`00Oomoo`0EOol00`00Oomoo`0JOol001aoo`03001oogoo01=oo`03001oogoo01Moo`03001o
ogoo01]oo`03001oogoo01Moo`03001oogoo01=oo`03001oogoo01]oo`03001oogoo01Moo`03001o
ogoo01Moo`03001oogoo01=oo`03001oogoo01]oo`0077oo00<007ooOol04goo00<007ooOol05goo
00<007ooOol06goo00<007ooOol05goo00<007ooOol04goo00<007ooOol06goo00<007ooOol05goo
00<007ooOol05goo00<007ooOol04goo00<007ooOol06goo000MOol00`00Oomoo`0AOol00`00Oomo
o`0GOol00`00Oomoo`0MOol00`00Oomoo`0GOol00`00Oomoo`0AOol00`00Oomoo`0MOol00`00Oomo
o`0GOol00`00Oomoo`0GOol00`00Oomoo`0AOol00`00Oomoo`0LOol001eoo`03001oogoo015oo`03
001oogoo01Moo`03001oogoo01eoo`03001oogoo01Moo`03001oogoo015oo`03001oogoo01eoo`03
001oogoo01Moo`03001oogoo01Moo`03001oogoo015oo`03001oogoo01aoo`007Woo00<007ooOol0
3goo00<007ooOol05goo00<007ooOol07goo00<007ooOol05goo00<007ooOol03goo00<007ooOol0
7goo00<007ooOol05goo00<007ooOol05goo00<007ooOol03goo00<007ooOol07Goo000NOol00`00
Oomoo`0?Ool00`00Oomoo`0GOol00`00Oomoo`0OOol00`00Oomoo`0GOol00`00Oomoo`0?Ool00`00
Oomoo`0OOol00`00Oomoo`0GOol00`00Oomoo`0GOol00`00Oomoo`0?Ool00`00Oomoo`0MOol001mo
o`03001oogoo00eoo`03001oogoo01Moo`03001oogoo025oo`03001oogoo01Moo`03001oogoo00eo
o`03001oogoo025oo`03001oogoo01Moo`03001oogoo01Moo`03001oogoo00eoo`03001oogoo01io
o`007goo00<007ooOol03Goo00<007ooOol05goo00<007ooOol08Goo00<007ooOol05goo00<007oo
Ool03Goo00<007ooOol08Goo00<007ooOol05goo00<007ooOol05goo00<007ooOol03Goo00<007oo
Ool07Woo000POol00`00Oomoo`0;Ool00`00Oomoo`0GOol00`00Oomoo`0SOol00`00Oomoo`0GOol0
0`00Oomoo`0;Ool00`00Oomoo`0SOol00`00Oomoo`0GOol00`00Oomoo`0GOol00`00Oomoo`0;Ool0
0`00Oomoo`0OOol0025oo`03001oogoo00Uoo`03001oogoo01Moo`03001oogoo02Eoo`03001oogoo
01Moo`03001oogoo00Uoo`03001oogoo02Aoo`03001oogoo01Qoo`03001oogoo01Moo`03001oogoo
00Uoo`03001oogoo021oo`008Goo00<007ooOol02Goo00<007ooOol05goo00<007ooOol09Goo00<0
07ooOol05goo00<007ooOol02Goo00<007ooOol09Goo00<007ooOol05goo00<007ooOol05goo00<0
07ooOol02Goo00<007ooOol087oo000ROol00`00Oomoo`07Ool00`00Oomoo`0GOol00`00Oomoo`0W
Ool00`00Oomoo`0GOol00`00Oomoo`07Ool00`00Oomoo`0VOol00`00Oomoo`0HOol00`00Oomoo`0G
Ool00`00Oomoo`07Ool00`00Oomoo`0QOol0029oo`03001oogoo00Moo`03001oogoo01Moo`03001o
ogoo02Moo`03001oogoo01Moo`03001oogoo00Moo`03001oogoo02Moo`03001oogoo01Moo`03001o
ogoo01Moo`03001oogoo00Moo`03001oogoo025oo`008goo00<007ooOol01Goo00<007ooOol05goo
00<007ooOol0:Goo00<007ooOol05goo00<007ooOol01Goo00<007ooOol0:7oo00<007ooOol067oo
00<007ooOol05goo00<007ooOol01Goo00<007ooOol08Woo000SOol00`00Oomoo`05Ool00`00Oomo
o`0GOol00`00Oomoo`0YOol00`00Oomoo`0GOol00`00Oomoo`05Ool00`00Oomoo`0YOol00`00Oomo
o`0GOol00`00Oomoo`0GOol00`00Oomoo`05Ool00`00Oomoo`0ROol002Aoo`03001oogoo00=oo`03
001oogoo01Moo`03001oogoo02]oo`03001oogoo01Moo`03001oogoo00=oo`03001oogoo02Yoo`03
001oogoo01Qoo`03001oogoo01Moo`03001oogoo00=oo`03001oogoo02=oo`0097oo00<007ooOol0
0goo00<007ooOol05goo00<007ooOol0:goo00<007ooOol05goo00<007ooOol00goo00<007ooOol0
:goo00<007ooOol05goo00<007ooOol05goo00<007ooOol00goo00<007ooOol08goo000UOol01@00
Oomoogoo00006Goo00<007ooOol0;Goo00<007ooOol05goo00D007ooOomoo`0002moo`03001oogoo
01Moo`03001oogoo01Moo`05001oogooOol0000VOol002Eoo`05001oogooOol0000IOol00`00Oomo
o`0]Ool00`00Oomoo`0GOol01@00Oomoogoo0000;goo00<007ooOol05goo00<007ooOol05goo00D0
07ooOomoo`0002Ioo`009Woo00<007oo00006Goo00<007ooOol0;goo00<007ooOol05goo00<007oo
0000<Goo00<007ooOol05goo00<007ooOol05goo00<007oo00009goo000VOol00`00Ool0000IOol0
0`00Oomoo`0_Ool00`00Oomoo`0GOol00`00Ool0000aOol00`00Oomoo`0GOol00`00Oomoo`0GOol0
0`00Ool0000WOol002Moo`03001oogoo01Moo`03001oogoo035oo`03001oogoo01Moo`03001oogoo
035oo`03001oogoo01Moo`03001oogoo01Moo`03001oogoo02Ioo`009goo00<007ooOol05goo00<0
07ooOol0<Goo00<007ooOol05goo00<007ooOol0<Goo00<007ooOol05goo00<007ooOol05goo00<0
07ooOol09Woo000XOol00`00Oomoo`0EOol00`00Oomoo`0cOol00`00Oomoo`0EOol00`00Oomoo`0c
Ool00`00Oomoo`0GOol00`00Oomoo`0EOol00`00Oomoo`0WOol002Qoo`03001oogoo01Eoo`03001o
ogoo03=oo`03001oogoo01Eoo`03001oogoo03=oo`03001oogoo01Moo`03001oogoo01Eoo`03001o
ogoo02Moo`00:Goo00<007ooOol04goo00<007ooOol0=Goo00<007ooOol04goo00<007ooOol0=Goo
00<007ooOol05goo00<007ooOol04goo00<007ooOol0:7oo000YOol00`00Oomoo`0COol00`00Oomo
o`0eOol00`00Oomoo`0COol00`00Oomoo`0eOol00`00Oomoo`0GOol00`00Oomoo`0COol00`00Oomo
o`0XOol002Yoo`03001oogoo015oo`03001oogoo03Moo`03001oogoo015oo`03001oogoo03Moo`03
001oogoo01Moo`03001oogoo015oo`03001oogoo02Uoo`00:Woo00<007ooOol04Goo00<007ooOol0
=goo00<007ooOol04Goo00<007ooOol0=goo00<007ooOol05goo00<007ooOol04Goo00<007ooOol0
:Goo000[Ool00`00Oomoo`0?Ool00`00Oomoo`0iOol00`00Oomoo`0?Ool00`00Oomoo`0iOol00`00
Oomoo`0GOol00`00Oomoo`0?Ool00`00Oomoo`0ZOol002]oo`03001oogoo00moo`03001oogoo03Uo
o`03001oogoo00moo`03001oogoo03Uoo`03001oogoo01Moo`03001oogoo00moo`03001oogoo02Yo
o`00;7oo00<007ooOol03Goo00<007ooOol0>goo00<007ooOol03Goo00<007ooOol0>goo00<007oo
Ool05goo00<007ooOol03Goo00<007ooOol0:goo000/Ool00`00Oomoo`0=Ool00`00Oomoo`0kOol0
0`00Oomoo`0=Ool00`00Oomoo`0kOol00`00Oomoo`0GOol00`00Oomoo`0=Ool00`00Oomoo`0[Ool0
02eoo`03001oogoo00]oo`03001oogoo03eoo`03001oogoo00]oo`03001oogoo03eoo`03001oogoo
01Moo`03001oogoo00]oo`03001oogoo02aoo`00;Woo00<007ooOol02Goo00<007ooOol0?goo00<0
07ooOol02Goo00<007ooOol0?Woo00<007ooOol067oo00<007ooOol02Goo00<007ooOol0;Goo000^
Ool00`00Oomoo`09Ool00`00Oomoo`0oOol00`00Oomoo`09Ool00`00Oomoo`0oOol00`00Oomoo`0G
Ool00`00Oomoo`09Ool00`00Oomoo`0]Ool002moo`03001oogoo00Moo`03001oogoo045oo`03001o
ogoo00Moo`03001oogoo041oo`03001oogoo01Qoo`03001oogoo00Moo`03001oogoo02ioo`00;goo
00<007ooOol01goo00<007ooOol0@Goo00<007ooOol01goo00<007ooOol0@Goo00<007ooOol05goo
00<007ooOol01goo00<007ooOol0;Woo000`Ool00`00Oomoo`05Ool00`00Oomoo`13Ool00`00Oomo
o`05Ool00`00Oomoo`12Ool00`00Oomoo`0HOol00`00Oomoo`05Ool00`00Oomoo`0_Ool0031oo`03
001oogoo00Eoo`03001oogoo04=oo`03001oogoo00Eoo`03001oogoo04=oo`03001oogoo01Moo`03
001oogoo00Eoo`03001oogoo02moo`00<Goo00<007ooOol00goo00<007ooOol0AGoo00<007ooOol0
0goo00<007ooOol0A7oo00<007ooOol067oo00<007ooOol00goo00<007ooOol0<7oo000aOol00`00
Oomoo`03Ool00`00Oomoo`15Ool00`00Oomoo`03Ool00`00Oomoo`15Ool00`00Oomoo`0GOol00`00
Oomoo`03Ool00`00Oomoo`0`Ool0039oo`05001oogooOol00019Ool01@00Oomoogoo0000B7oo00<0
07ooOol067oo00D007ooOomoo`0003=oo`00<Woo00D007ooOomoo`0004Uoo`05001oogooOol00019
Ool00`00Oomoo`0GOol01@00Oomoogoo0000<goo000cOol00`00Ool0001;Ool00`00Ool0001:Ool0
0`00Oomoo`0HOol00`00Ool0000dOol003=oo`03001oo`0004]oo`03001oo`0004]oo`03001oogoo
01Moo`03001oo`0003Aoo`00=7oo0P00C7oo0P00Bgoo00<007ooOol067oo00<007ooOol0<goo000f
Ool00`00Oomoo`1;Ool00`00Oomoo`19Ool00`00Oomoo`0GOol00`00Oomoo`0cOol003Moo`03001o
ogoo04]oo`03001oogoo04Qoo`03001oogoo01Ioo`03001oogoo03Aoo`00>7oo00<007ooOol0Bgoo
00<007ooOol0B7oo00<007ooOol05Goo00<007ooOol0=7oo000iOol00`00Oomoo`1;Ool00`00Oomo
o`17Ool00`00Oomoo`0DOol00`00Oomoo`0eOol003Yoo`8004aoo`03001oogoo04Moo`03001oogoo
01=oo`03001oogoo03Eoo`00?7oo00<007ooOol0BWoo00<007ooOol0AWoo00<007ooOol04Woo00<0
07ooOol0=Woo000mOol00`00Oomoo`1:Ool00`00Oomoo`16Ool00`00Oomoo`0AOol00`00Oomoo`0f
Ool003ioo`03001oogoo04Yoo`03001oogoo04Ioo`03001oogoo00moo`03001oogoo03Moo`00?goo
00<007ooOol0BWoo00<007ooOol0AGoo00<007ooOol03goo00<007ooOol0=goo0010Ool2001;Ool0
0`00Oomoo`15Ool00`00Oomoo`0=Ool00`00Oomoo`0hOol0049oo`03001oogoo04Uoo`03001oogoo
04Aoo`03001oogoo00eoo`03001oogoo03Qoo`00@goo00<007ooOol0BGoo00<007ooOol0A7oo00<0
07ooOol02goo00<007ooOol0>Goo0014Ool00`00Oomoo`19Ool00`00Oomoo`13Ool00`00Oomoo`0;
Ool00`00Oomoo`0iOol004Eoo`03001oogoo04Uoo`03001oogoo04=oo`03001oogoo00Uoo`03001o
ogoo03Yoo`00AWoo0P00BWoo00<007ooOol0@Woo00<007ooOol02Goo00<007ooOol0>Woo0018Ool0
0`00Oomoo`18Ool00`00Oomoo`12Ool00`00Oomoo`07Ool00`00Oomoo`0kOol004Uoo`03001oogoo
04Qoo`03001oogoo045oo`03001oogoo00Moo`03001oogoo03]oo`00BWoo00<007ooOol0B7oo00<0
07ooOol0@Goo00<007ooOol01Goo00<007ooOol0?7oo001;Ool00`00Oomoo`18Ool00`00Oomoo`10
Ool00`00Oomoo`05Ool00`00Oomoo`0lOol004aoo`8004Uoo`03001oogoo041oo`03001oogoo00=o
o`03001oogoo03eoo`00CWoo00<007ooOol0Agoo00<007ooOol0?goo00<007ooOol00goo00<007oo
Ool0?Goo001?Ool00`00Oomoo`17Ool00`00Oomoo`0oOol01@00Oomoogoo0000@7oo001@Ool00`00
Oomoo`17Ool00`00Oomoo`0nOol01@00Oomoogoo0000@7oo001AOol00`00Oomoo`17Ool00`00Oomo
o`0nOol00`00Ool00011Ool0059oo`8004Qoo`03001oogoo03eoo`03001oo`00045oo`00E7oo00<0
07ooOol0AWoo00<007ooOol0?7oo0P00@Woo001EOol00`00Oomoo`16Ool00`00Oomoo`0jOol00`00
Oomoo`12Ool005Ioo`03001oogoo04Ioo`03001oogoo03Moo`8004Eoo`00Egoo00<007ooOol0AWoo
00<007ooOol0=Goo00<007ooOol0AGoo001HOol20017Ool00`00Oomoo`0bOol20018Ool005Yoo`03
001oogoo04Eoo`03001oogoo02moo`8004Yoo`00Fgoo00<007ooOol0AGoo00<007ooOol0;Goo00<0
07ooOol0BWoo001LOol00`00Oomoo`15Ool00`00Oomoo`0ZOol2001=Ool005eoo`03001oogoo04Eo
o`03001oogoo02Qoo`03001oogoo04eoo`00GWoo0P00AWoo00<007ooOol09Goo0P00D7oo001POol0
0`00Oomoo`14Ool00`00Oomoo`0SOol00`00Oomoo`1@Ool0065oo`03001oogoo04Aoo`03001oogoo
021oo`8005=oo`00HWoo00<007ooOol0A7oo00<007ooOol07Goo0P00EGoo001SOol00`00Oomoo`14
Ool00`00Oomoo`0KOol00`00Oomoo`1EOol006Aoo`03001oogoo04Aoo`03001oogoo01Qoo`8005Qo
o`00IGoo0P00AGoo00<007ooOol05Woo00<007ooOol0F7oo001WOol00`00Oomoo`13Ool00`00Oomo
o`0COol2001KOol006Qoo`03001oogoo04=oo`03001oogoo015oo`03001oogoo05]oo`00JGoo00<0
07ooOol0@goo00<007ooOol03Woo0P00GWoo001ZOol00`00Oomoo`13Ool00`00Oomoo`0<Ool00`00
Oomoo`1NOol006]oo`8004Aoo`03001oogoo00Uoo`80065oo`00KGoo00<007ooOol0@Woo00<007oo
Ool01Woo0P00Hgoo001^Ool00`00Oomoo`12Ool00`00Oomoo`04Ool00`00Oomoo`1SOol006moo`03
001oogoo049oo`04001oogooOol2001VOol0071oo`03001oogoo049oo`03001oo`0006Qoo`00LGoo
0P00@Woo0P00JGoo001cOol00`00Oomoo`0nOol00`00Oomoo`1YOol007Aoo`03001oogoo03]oo`80
06aoo`00MGoo00<007ooOol0>Goo00<007ooOol0K7oo001fOol00`00Oomoo`0fOol2001_Ool007Mo
o`8003Aoo`80075oo`00NGoo00<007ooOol0<7oo00<007ooOol0LGoo001jOol00`00Oomoo`0]Ool2
001dOol007]oo`03001oogoo02]oo`03001oogoo07Aoo`00O7oo00<007ooOol0:7oo0P00Mgoo001m
Ool2000WOol00`00Oomoo`1gOol007moo`03001oogoo029oo`8007Yoo`00P7oo00<007ooOol07goo
0P00O7oo0021Ool00`00Oomoo`0MOol00`00Oomoo`1lOol0089oo`03001oogoo01Yoo`8007moo`00
Pgoo0P006Goo00<007ooOol0Ogoo0025Ool00`00Oomoo`0DOol20022Ool008Ioo`03001oogoo019o
o`03001oogoo089oo`00Qgoo00<007ooOol03goo0P00QGoo0028Ool00`00Oomoo`0=Ool00`00Oomo
o`25Ool008Uoo`8000]oo`8008Qoo`00Rgoo00<007ooOol01Woo0P00RWoo002<Ool00`00Oomoo`04
Ool00`00Oomoo`2:Ool008eoo`04001oogooOol2002=Ool008ioo`03001oo`0008moo`00Sgoo00<0
07ooOol0SWoo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003o
OolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5o
o`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003o
OolQOol00?moob5oo`00ogoo8Goo003oOolQOol00001\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-1.01364, -1.00004, 
  0.0384226, 0.0395621}}]
}, Closed]],

Cell[TextData[{
  "This plots the same genealogy, but with the vertical axis proportional to \
the birth time.  NodeFunction\[Rule]({#2\[LeftDoubleBracket]-1,1\
\[RightDoubleBracket],5-#2\[LeftDoubleBracket]1\[RightDoubleBracket]/20}&) \
takes the ",
  Cell[BoxData[
      \(TraditionalForm\`x\)]],
  " coordinate from the last element of the information list (which is \
internally generated by PlotGenealogy[]), and the ",
  Cell[BoxData[
      \(TraditionalForm\`y\)]],
  " coordinate from the first element, which is the birth time.  A linear \
transformation (5-t/20) is chosen to give an appropriate vertical scale:"
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(Show[
      PlotGenealogy[tr, LeafLabels \[Rule] None, NodeLabels \[Rule] None, 
        NodeFunction \[Rule] 
          \(({#2\[LeftDoubleBracket]\(-1\), 1\[RightDoubleBracket], 
                5 - #2\[LeftDoubleBracket]1\[RightDoubleBracket]/20}&)\)]]; 
    \)\)], "Input",
  CellLabel->"In[59]:="],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0909091 0.0909091 0.0882906 0.0882906 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
0 g
.5 Mabswid
[ ] 0 setdash
.5 .52974 m
.18182 .18699 L
s
.5 .52974 m
.63636 .45921 L
s
.63636 .45921 m
.45455 .1773 L
s
.63636 .45921 m
.77273 .28454 L
s
.77273 .28454 m
.63636 .1107 L
s
.77273 .28454 m
.81818 .22063 L
s
.81818 .22063 m
.72727 .1094 L
s
.81818 .22063 m
.86364 .1429 L
s
.18182 .18699 m
.13636 .13055 L
s
.18182 .18699 m
.27273 .10938 L
s
.45455 .1773 m
.36364 .11428 L
s
.45455 .1773 m
.5 .16774 L
s
.5 .16774 m
.45455 .11058 L
s
.5 .16774 m
.54545 .1073 L
s
.86364 .1429 m
.81818 .10905 L
s
.86364 .1429 m
.90909 .10752 L
s
.13636 .13055 m
.09091 .11554 L
s
.13636 .13055 m
.18182 .10713 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[59]:=",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/A000`40O003h00Oogoo8Goo003oOolQ
Ool00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00
ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQ
Ool00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00
ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00<goo0P00Igoo00<0
07ooOol0I7oo0P006goo000aOol2000JOol2000cOol00`00Oomoo`0GOol00`00Oomoo`0GOol00`00
Oomoo`0GOol00`00Oomoo`0GOol2000FOol00`00Oomoo`0KOol002moo`8001]oo`03001oogoo01Uo
o`8001Qoo`03001oogoo01Ioo`03001oogoo01Qoo`03001oogoo01Moo`03001oogoo01Uoo`03001o
ogoo019oo`03001oogoo01aoo`006Woo0`0047oo0P0077oo00<007ooOol077oo00<007ooOol05Woo
00<007ooOol057oo00<007ooOol06Woo00<007ooOol05goo00<007ooOol06Goo0P0047oo0P007goo
000MOol3000<Ool00`00Oomoo`0KOol00`00Oomoo`0NOol2000GOol00`00Oomoo`0BOol00`00Oomo
o`0LOol00`00Oomoo`0GOol00`00Oomoo`0JOol00`00Oomoo`0<Ool00`00Oomoo`0OOol0021oo`<0
00Moo`8001eoo`03001oogoo025oo`03001oogoo01Eoo`03001oogoo015oo`03001oogoo01eoo`03
001oogoo01Moo`03001oogoo01Yoo`8000]oo`03001oogoo021oo`008goo0`000Woo0P007Goo0P00
9Goo0P005Goo00<007ooOol047oo00<007ooOol07goo00<007ooOol05goo00<007ooOol06goo00<0
07ooOol01goo00<007ooOol08Goo000VOol2000NOol00`00Oomoo`0WOol00`00Oomoo`0COol00`00
Oomoo`0>Ool00`00Oomoo`0POol00`00Oomoo`0GOol00`00Oomoo`0LOol00`00Oomoo`04Ool2000T
Ool002Moo`03001oogoo01]oo`03001oogoo02Uoo`03001oogoo01=oo`03001oogoo00eoo`03001o
ogoo025oo`03001oogoo01Moo`03001oogoo01aoo`8000=oo`03001oogoo02Aoo`00:7oo00<007oo
Ool06Goo00<007ooOol0:goo0P0057oo00<007ooOol02goo00<007ooOol08goo00<007ooOol05goo
00<007ooOol07Goo00<007oo00009goo000YOol00`00Oomoo`0GOol00`00Oomoo`0^Ool00`00Oomo
o`0BOol00`00Oomoo`09Ool00`00Oomoo`0UOol00`00Oomoo`0GOol00`00Oomoo`0MOol00`00Oomo
o`0VOol002Yoo`03001oogoo01Eoo`03001oogoo031oo`80019oo`03001oogoo00Qoo`03001oogoo
02Ioo`03001oogoo01Qoo`03001oogoo01aoo`03001oogoo02Ioo`00:goo00<007ooOol04Woo0P00
=Goo00<007ooOol047oo00<007ooOol01goo00<007ooOol09goo00<007ooOol067oo00<007ooOol0
6Woo00<007ooOol09goo000[Ool00`00Oomoo`0AOol00`00Oomoo`0fOol2000AOol00`00Oomoo`05
Ool00`00Oomoo`0YOol00`00Oomoo`0GOol00`00Oomoo`0JOol00`00Oomoo`0WOol002aoo`03001o
ogoo00moo`03001oogoo03Uoo`03001oogoo00moo`03001oogoo00=oo`03001oogoo02]oo`03001o
ogoo01Moo`03001oogoo01Qoo`03001oogoo02Qoo`00;Goo00<007ooOol03Goo00<007ooOol0>goo
0P003goo00<007ooOol00goo00<007ooOol0;7oo00<007ooOol05goo00<007ooOol05Woo00<007oo
Ool0:Goo000^Ool00`00Oomoo`0;Ool00`00Oomoo`0nOol00`00Oomoo`0=Ool01@00Oomoogoo0000
;goo00<007ooOol067oo00<007ooOol05Goo00<007ooOol0:Goo000_Ool00`00Oomoo`08Ool20012
Ool00`00Oomoo`0=Ool00`00Ool0000aOol00`00Oomoo`0HOol00`00Oomoo`0COol00`00Oomoo`0Z
Ool0031oo`03001oogoo00Ioo`03001oogoo04=oo`8000]oo`@003=oo`03001oogoo01Moo`03001o
ogoo01=oo`03001oogoo02Yoo`00<7oo00<007ooOol01Goo00<007ooOol0AWoo00@007ooOomoo`L0
03Qoo`03001oogoo01Moo`03001oogoo015oo`03001oogoo02]oo`00<Goo00<007ooOol00goo00<0
07ooOol0B7oo0`00?goo00<007ooOol067oo00<007ooOol047oo00<007ooOol0:goo000bOol01@00
Oomoogoo0000Bgoo00<007ooOol0@7oo00<007ooOol067oo00<007ooOol03Woo00<007ooOol0;7oo
000cOol00`00Ool0001=Ool00`00Oomoo`10Ool00`00Oomoo`0HOol00`00Oomoo`0<Ool00`00Oomo
o`0]Ool003Aoo`03001oogoo04eoo`03001oogoo041oo`03001oogoo01Moo`03001oogoo00aoo`03
001oogoo02eoo`00=7oo00<007ooOol0CGoo00<007ooOol0@Goo00<007ooOol05goo00<007ooOol0
2Woo00<007ooOol0;Woo000eOol00`00Oomoo`1=Ool00`00Oomoo`10Ool00`00Oomoo`0HOol00`00
Oomoo`09Ool00`00Oomoo`0^Ool003Ioo`03001oogoo04eoo`03001oogoo041oo`03001oogoo01Qo
o`03001oogoo00Moo`03001oogoo02moo`00=goo00<007ooOol0C7oo00<007ooOol0@Goo00<007oo
Ool067oo00<007ooOol01Woo00<007ooOol0;goo000hOol00`00Oomoo`1<Ool00`00Oomoo`11Ool0
0`00Oomoo`0HOol00`00Oomoo`04Ool00`00Oomoo`0`Ool003Uoo`03001oogoo04]oo`03001oogoo
045oo`03001oogoo01Qoo`03001oogoo00Aoo`03001oogoo031oo`00>Woo00<007ooOol0Bgoo00<0
07ooOol0@Goo00<007ooOol067oo00<007ooOol00Woo00<007ooOol0<Goo000kOol00`00Oomoo`1;
Ool00`00Oomoo`11Ool00`00Oomoo`0HOol01000Oomoo`00=7oo000lOol00`00Oomoo`1:Ool00`00
Oomoo`12Ool00`00Oomoo`0HOol00`00Ool0000dOol003eoo`03001oogoo04Yoo`03001oogoo049o
o`03001oogoo01Qoo`03001oogoo03=oo`00?Woo00<007ooOol0BWoo00<007ooOol0@Goo00<007oo
Ool067oo00<007ooOol0<goo000oOol00`00Oomoo`19Ool00`00Oomoo`12Ool00`00Oomoo`0FOol0
0`00Oomoo`0dOol0041oo`03001oogoo04Uoo`03001oogoo049oo`03001oogoo01Aoo`03001oogoo
03Eoo`00@Goo00<007ooOol0BGoo00<007ooOol0@Woo00<007ooOol04Woo00<007ooOol0=Woo0011
Ool00`00Oomoo`19Ool00`00Oomoo`12Ool00`00Oomoo`0BOol00`00Oomoo`0fOol0049oo`03001o
ogoo04Uoo`03001oogoo049oo`03001oogoo011oo`03001oogoo03Moo`00@goo00<007ooOol0BGoo
00<007ooOol0@Woo00<007ooOol03Woo00<007ooOol0>7oo0014Ool00`00Oomoo`18Ool00`00Oomo
o`13Ool00`00Oomoo`0=Ool00`00Oomoo`0hOol004Eoo`03001oogoo04Qoo`03001oogoo04=oo`03
001oogoo00]oo`03001oogoo03Uoo`00AWoo00<007ooOol0Agoo00<007ooOol0@goo00<007ooOol0
2Woo00<007ooOol0>Woo0017Ool00`00Oomoo`17Ool00`00Oomoo`13Ool00`00Oomoo`08Ool00`00
Oomoo`0kOol004Qoo`03001oogoo04Moo`03001oogoo04=oo`03001oogoo00Moo`03001oogoo03]o
o`00BGoo00<007ooOol0AWoo00<007ooOol0A7oo00<007ooOol01Goo00<007ooOol0?7oo001:Ool0
0`00Oomoo`16Ool00`00Oomoo`13Ool00`00Oomoo`04Ool00`00Oomoo`0mOol004]oo`03001oogoo
04Ioo`03001oogoo04=oo`03001oogoo00=oo`03001oogoo03eoo`00C7oo00<007ooOol0AGoo00<0
07ooOol0A7oo00D007ooOomoo`00041oo`00CGoo00<007ooOol0AGoo00<007ooOol0A7oo00<007oo
0000@Goo001>Ool00`00Oomoo`15Ool00`00Oomoo`14Ool00`00Oomoo`10Ool004ioo`03001oogoo
04Eoo`03001oogoo04Aoo`03001oogoo041oo`00Cgoo00<007ooOol0AGoo00<007ooOol0@Woo00<0
07ooOol0@Goo001@Ool00`00Oomoo`15Ool00`00Oomoo`10Ool00`00Oomoo`12Ool0055oo`03001o
ogoo04Aoo`03001oogoo03moo`03001oogoo04=oo`00DWoo00<007ooOol0A7oo00<007ooOol0?Goo
00<007ooOol0A7oo001COol00`00Oomoo`13Ool00`00Oomoo`0mOol00`00Oomoo`14Ool005Aoo`03
001oogoo04=oo`03001oogoo03]oo`03001oogoo04Eoo`00EGoo00<007ooOol0@goo00<007ooOol0
>Goo00<007ooOol0AWoo001FOol00`00Oomoo`12Ool00`00Oomoo`0hOol00`00Oomoo`17Ool005Mo
o`03001oogoo049oo`03001oogoo03Moo`03001oogoo04Moo`00F7oo00<007ooOol0@Woo00<007oo
Ool0=Goo00<007ooOol0B7oo001IOol00`00Oomoo`11Ool00`00Oomoo`0dOol00`00Oomoo`19Ool0
05Yoo`03001oogoo045oo`03001oogoo039oo`03001oogoo04Yoo`00Fgoo00<007ooOol0@Goo00<0
07ooOol0<7oo00<007ooOol0Bgoo001KOol00`00Oomoo`11Ool00`00Oomoo`0`Ool00`00Oomoo`1;
Ool005aoo`03001oogoo045oo`03001oogoo02ioo`03001oogoo04aoo`00GGoo00<007ooOol0@7oo
00<007ooOol0;Goo00<007ooOol0CGoo001NOol00`00Oomoo`10Ool00`00Oomoo`0[Ool00`00Oomo
o`1>Ool005moo`03001oogoo041oo`03001oogoo02Yoo`03001oogoo04ioo`00H7oo00<007ooOol0
?goo00<007ooOol0:Goo00<007ooOol0Cgoo001QOol00`00Oomoo`0oOol00`00Oomoo`0WOol00`00
Oomoo`1@Ool0069oo`03001oogoo03moo`03001oogoo02Eoo`03001oogoo055oo`00Hgoo00<007oo
Ool0?Woo00<007ooOol097oo00<007ooOol0DWoo001TOol00`00Oomoo`0nOol00`00Oomoo`0SOol0
0`00Oomoo`1BOol006Eoo`03001oogoo03ioo`03001oogoo025oo`03001oogoo05=oo`00IWoo00<0
07ooOol0?Goo00<007ooOol087oo00<007ooOol0E7oo001WOol00`00Oomoo`0mOol00`00Oomoo`0N
Ool00`00Oomoo`1EOol006Qoo`03001oogoo03eoo`03001oogoo01eoo`03001oogoo05Eoo`00J7oo
00<007ooOol0?Goo00<007ooOol077oo00<007ooOol0EWoo001YOol00`00Oomoo`0mOol00`00Oomo
o`0JOol00`00Oomoo`1GOol006Yoo`03001oogoo03aoo`03001oogoo01Uoo`03001oogoo05Qoo`00
Jgoo00<007ooOol0?7oo00<007ooOol05goo00<007ooOol0FGoo001/Ool00`00Oomoo`0lOol00`00
Oomoo`0FOol00`00Oomoo`1IOol006eoo`03001oogoo03]oo`03001oogoo01Eoo`03001oogoo05Yo
o`00KWoo00<007ooOol0>goo00<007ooOol04goo00<007ooOol0Fgoo001_Ool00`00Oomoo`0kOol0
0`00Oomoo`0AOol00`00Oomoo`1LOol0071oo`03001oogoo03Yoo`03001oogoo015oo`03001oogoo
05aoo`00LGoo00<007ooOol0>Woo00<007ooOol03goo00<007ooOol0GGoo001bOol00`00Oomoo`0j
Ool00`00Oomoo`0=Ool00`00Oomoo`1NOol007=oo`03001oogoo03Uoo`03001oogoo00aoo`03001o
ogoo05moo`00M7oo00<007ooOol0>Goo00<007ooOol02Woo00<007ooOol0H7oo001eOol00`00Oomo
o`0iOol00`00Oomoo`09Ool00`00Oomoo`1POol007Eoo`03001oogoo03Uoo`03001oogoo00Qoo`03
001oogoo065oo`00MWoo00<007ooOol0>Goo00<007ooOol01Woo00<007ooOol0HWoo001gOol00`00
Oomoo`0hOol00`00Oomoo`05Ool00`00Oomoo`1SOol007Qoo`03001oogoo03Qoo`03001oogoo00Ao
o`03001oogoo06=oo`00NGoo00<007ooOol0>7oo00<007ooOol00Woo00<007ooOol0I7oo001jOol0
0`00Oomoo`0gOol01@00Oomoogoo0000Igoo001kOol00`00Oomoo`0gOol00`00Ool0001XOol007ao
o`03001oogoo03Ioo`8006Uoo`00OGoo00<007ooOol0<goo0P00Jgoo001nOol00`00Oomoo`0`Ool2
001]Ool007moo`03001oogoo02eoo`8006moo`00P7oo00<007ooOol0:Woo0P00LGoo0021Ool00`00
Oomoo`0WOol2001cOol0089oo`03001oogoo02Aoo`8007Eoo`00PWoo00<007ooOol08Woo0P00Mgoo
0023Ool00`00Oomoo`0OOol2001iOol008Aoo`03001oogoo01aoo`8007]oo`00QGoo00<007ooOol0
6Woo00<007ooOol0Ngoo0026Ool00`00Oomoo`0GOol2001nOol008Moo`03001oogoo01Aoo`80081o
o`00R7oo00<007ooOol04Goo0P00PWoo0029Ool00`00Oomoo`0>Ool20024Ool008Yoo`03001oogoo
00]oo`8008Ioo`00Rgoo00<007ooOol027oo0P00R7oo002<Ool00`00Oomoo`05Ool2002:Ool008eo
o`03001oogoo009oo`8008aoo`00SWoo00@007oo000008ioo`00Sgoo00<007ooOol0SWoo003oOolQ
Ool00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00
ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQ
Ool00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00
ogoo8Goo003oOolQOol00001\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-1.01364, -1.00004, 
  0.0384226, 0.0395621}}]
}, Closed]],

Cell["\<\
Note that NodeFunction is used in a different sense within \
PlotGenealogy as compared with MakeGenealogy (above).\
\>", "Text"]
}, Open  ]]
},
FrontEndVersion->"4.0 for Macintosh",
ScreenRectangle->{{0, 1152}, {0, 748}},
WindowSize->{1084, 721},
WindowMargins->{{-2, Automatic}, {Automatic, 1}},
StyleDefinitions -> "HelpBrowser.nb",
MacintoshSystemPageSetup->"\<\
00`0001804P000000_02@?o/onh3109BI085:0?l0@00005X0FP000003[0;@001
0000I00100000@0000000BL?0040000000000000000000000000000000000?nL
ojH?50^J00P100000000000000000000\>"
]


(***********************************************************************
Cached data follows.  If you edit this Notebook file directly, not using
Mathematica, you must remove the line containing CacheID at the top of 
the file.  The cache data will then be recreated when you save this file 
from within Mathematica.
***********************************************************************)

(*CellTagsOutline
CellTagsIndex->{
  "MakeGenealogy"->{
    Cell[1786, 53, 941, 22, 56, "DefinitionBox",
      CellTags->"MakeGenealogy"]}
  }
*)

(*CellTagsIndex
CellTagsIndex->{
  {"MakeGenealogy", 31295, 705}
  }
*)

(*NotebookFileOutline
Notebook[{

Cell[CellGroupData[{
Cell[1739, 51, 44, 0, 36, "SubsectionIcon"],
Cell[1786, 53, 941, 22, 56, "DefinitionBox",
  CellTags->"MakeGenealogy"],
Cell[2730, 77, 97, 3, 28, "MathCaption"],
Cell[2830, 82, 122, 3, 42, "Input"],
Cell[2955, 87, 169, 4, 28, "MathCaption"],

Cell[CellGroupData[{
Cell[3149, 95, 74, 2, 26, "Input"],
Cell[3226, 99, 226, 5, 32, "Output"]
}, Closed]],
Cell[3467, 107, 144, 3, 18, "MathCaption"],
Cell[3614, 112, 156, 4, 26, "Input"],
Cell[3773, 118, 132, 3, 28, "MathCaption"],

Cell[CellGroupData[{
Cell[3930, 125, 158, 4, 26, "Input"],
Cell[4091, 131, 1111, 22, 95, "Output"]
}, Closed]],
Cell[5217, 156, 208, 6, 20, "Text"],
Cell[5428, 164, 347, 14, 22, "Text"],
Cell[5778, 180, 120, 3, 28, "MathCaption"],

Cell[CellGroupData[{
Cell[5923, 187, 149, 4, 26, "Input"],
Cell[6075, 193, 12796, 241, 184, 1221, 93, "GraphicsData", "PostScript", \
"Graphics"]
}, Closed]],
Cell[18886, 437, 634, 13, 32, "Text"],

Cell[CellGroupData[{
Cell[19545, 454, 323, 7, 26, "Input"],
Cell[19871, 463, 10418, 212, 184, 1212, 93, "GraphicsData", "PostScript", \
"Graphics"]
}, Closed]],
Cell[30304, 678, 138, 3, 18, "Text"]
}, Open  ]]
}
]
*)




(***********************************************************************
End of Mathematica Notebook file.
***********************************************************************)

