(***********************************************************************

                    Mathematica-Compatible Notebook

This notebook can be used on any computer system with Mathematica 4.0,
MathReader 4.0, or any compatible application. The data for the notebook 
starts with the line containing stars above.

To get the notebook into a Mathematica-compatible application, do one of 
the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing the 
word CacheID, otherwise Mathematica-compatible applications may try to 
use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
***********************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[     86752,       2426]*)
(*NotebookOutlinePosition[     87634,       2454]*)
(*  CellTagsIndexPosition[     87590,       2450]*)
(*WindowFrame->Normal*)



Notebook[{

Cell[CellGroupData[{
Cell["Sampling genealogies", "SubsectionIcon"],

Cell[TextData[{
  "As an example, sample genealogies from  a population which occupies a \
range ",
  Cell[BoxData[
      \(TraditionalForm\`R = 60\)]],
  ", with a Gaussian crowding function ",
  Cell[BoxData[
      \(TraditionalForm
      \`\(U[] = \[ExponentialE]\^\(\(-d\^2\)/2\)/\((2  \[Pi])\)\ \)\)]],
  ".  Mortality is \[Mu]=1+5\[Rho], and fecundity is 2; hence, the carrying \
capacity  with no clumping is 0.2., and so we expect 720 individuals in \
total.  Clumping reduces the actual density substantially.    Dispersal is \
\[Sigma]=1.  The simulation is run for 30,000 births, which takes T=60 time \
units."
}], "Text"],

Cell[BoxData[
    \(R = 60; \[CapitalDelta] = 3; \[Sigma] = 1. ; \ndt = 1000; dm = 10; 
    \[Delta]d = 0.1; tw = 5000; tm = 30000; \n
    tz = CovarianceMidPoints[{dm, \[Delta]d}]; \)], "Input",
  CellLabel->"In[185]:="],

Cell[BoxData[
    \(U[\[Gamma]_] := 
      \(1\/\(2  \[Pi]\ \[Gamma]\ \)\) Exp[\(-\(1\/\(2  \[Gamma]\)\)\) #]&; 
    M[\[Mu]_, \[Alpha]_] := \((\[Mu] + \[Alpha]*#)\)&\ ; F[f_] := f&; \)], 
  "Input",
  CellLabel->"In[186]:="],

Cell[CellGroupData[{

Cell[BoxData[
    \(InitialiseContinuum[p1, 100, R, \[CapitalDelta], 2, U[1], M[1, 5], 
      F[2]]; bc = InitialiseCovariance[{dm, \[Delta]d}]; ns = 0; \n
    nl = {{T[p1], NumberOfIndividuals[p1]}}; 
    dl = {{T[p1], Mean[\(Density[p1, #]&\)/@ExtantIndividuals[p1]]}}; \n
    Timing[While[
        \((NumberOfIndividuals[p1] > 0)\) && \((TotalNumber[p1] < tm)\), \n\t
        Do[IterateContinuum[p1, R, \[CapitalDelta], U[1], M[1, 5], F[2], 
            \[Sigma]], {dt}]; \n\t
        If[TotalNumber[p1] > tw, \n\t\t\tns += 1; 
          bc += SampleCovariance[p1, R, {dm, \[Delta]d}]]; \n\ \ 
        Print["\<T=\>", T[p1], Tab, "\<n=\>", NumberOfIndividuals[p1]]; \n\t\t
        AppendTo[nl, {T[p1], NumberOfIndividuals[p1]}]; \n\t
        AppendTo[
          dl, {T[p1], Mean[\(Density[p1, #]&\)/@ExtantIndividuals[p1]]}]; ]]
      \)], "Input",
  CellLabel->"In[187]:="],

Cell[BoxData[
    InterpretationBox[
      \("T="\[InvisibleSpace]1.65439116515050788`
        \[InvisibleSpace]"\t"\[InvisibleSpace]"n="\[InvisibleSpace]218\),
      SequenceForm[ "T=", 1.6543911651505079, "\t", "n=", 218],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("T="\[InvisibleSpace]2.66736496761264074`
        \[InvisibleSpace]"\t"\[InvisibleSpace]"n="\[InvisibleSpace]256\),
      SequenceForm[ "T=", 2.6673649676126407, "\t", "n=", 256],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("T="\[InvisibleSpace]3.60103326447420712`
        \[InvisibleSpace]"\t"\[InvisibleSpace]"n="\[InvisibleSpace]282\),
      SequenceForm[ "T=", 3.6010332644742071, "\t", "n=", 282],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("T="\[InvisibleSpace]4.52262885715204276`
        \[InvisibleSpace]"\t"\[InvisibleSpace]"n="\[InvisibleSpace]278\),
      SequenceForm[ "T=", 4.5226288571520428, "\t", "n=", 278],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("T="\[InvisibleSpace]5.46281363702012168`
        \[InvisibleSpace]"\t"\[InvisibleSpace]"n="\[InvisibleSpace]272\),
      SequenceForm[ "T=", 5.4628136370201217, "\t", "n=", 272],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("T="\[InvisibleSpace]6.3229084686633028`
        \[InvisibleSpace]"\t"\[InvisibleSpace]"n="\[InvisibleSpace]300\),
      SequenceForm[ "T=", 6.3229084686633028, "\t", "n=", 300],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("T="\[InvisibleSpace]7.16818928492718665`
        \[InvisibleSpace]"\t"\[InvisibleSpace]"n="\[InvisibleSpace]298\),
      SequenceForm[ "T=", 7.1681892849271867, "\t", "n=", 298],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("T="\[InvisibleSpace]7.99431436879287815`
        \[InvisibleSpace]"\t"\[InvisibleSpace]"n="\[InvisibleSpace]284\),
      SequenceForm[ "T=", 7.9943143687928782, "\t", "n=", 284],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("T="\[InvisibleSpace]8.88490105218534687`
        \[InvisibleSpace]"\t"\[InvisibleSpace]"n="\[InvisibleSpace]276\),
      SequenceForm[ "T=", 8.8849010521853469, "\t", "n=", 276],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("T="\[InvisibleSpace]9.77618593474914376`
        \[InvisibleSpace]"\t"\[InvisibleSpace]"n="\[InvisibleSpace]258\),
      SequenceForm[ "T=", 9.7761859347491438, "\t", "n=", 258],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("T="\[InvisibleSpace]10.6655385223319099`
        \[InvisibleSpace]"\t"\[InvisibleSpace]"n="\[InvisibleSpace]252\),
      SequenceForm[ "T=", 10.665538522331911, "\t", "n=", 252],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("T="\[InvisibleSpace]11.6848749164979137`
        \[InvisibleSpace]"\t"\[InvisibleSpace]"n="\[InvisibleSpace]256\),
      SequenceForm[ "T=", 11.684874916497915, "\t", "n=", 256],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("T="\[InvisibleSpace]12.6972740046182908`
        \[InvisibleSpace]"\t"\[InvisibleSpace]"n="\[InvisibleSpace]250\),
      SequenceForm[ "T=", 12.697274004618292, "\t", "n=", 250],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("T="\[InvisibleSpace]13.6793950738884961`
        \[InvisibleSpace]"\t"\[InvisibleSpace]"n="\[InvisibleSpace]274\),
      SequenceForm[ "T=", 13.679395073888497, "\t", "n=", 274],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("T="\[InvisibleSpace]14.6252529710207346`
        \[InvisibleSpace]"\t"\[InvisibleSpace]"n="\[InvisibleSpace]268\),
      SequenceForm[ "T=", 14.625252971020734, "\t", "n=", 268],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("T="\[InvisibleSpace]15.6586589887673728`
        \[InvisibleSpace]"\t"\[InvisibleSpace]"n="\[InvisibleSpace]220\),
      SequenceForm[ "T=", 15.658658988767373, "\t", "n=", 220],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("T="\[InvisibleSpace]16.8959637472903478`
        \[InvisibleSpace]"\t"\[InvisibleSpace]"n="\[InvisibleSpace]200\),
      SequenceForm[ "T=", 16.895963747290349, "\t", "n=", 200],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("T="\[InvisibleSpace]18.158454232937423`
        \[InvisibleSpace]"\t"\[InvisibleSpace]"n="\[InvisibleSpace]190\),
      SequenceForm[ "T=", 18.158454232937423, "\t", "n=", 190],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("T="\[InvisibleSpace]19.5575659179876524`
        \[InvisibleSpace]"\t"\[InvisibleSpace]"n="\[InvisibleSpace]192\),
      SequenceForm[ "T=", 19.557565917987652, "\t", "n=", 192],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("T="\[InvisibleSpace]20.9179142744980817`
        \[InvisibleSpace]"\t"\[InvisibleSpace]"n="\[InvisibleSpace]188\),
      SequenceForm[ "T=", 20.917914274498081, "\t", "n=", 188],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("T="\[InvisibleSpace]22.061905138942599`
        \[InvisibleSpace]"\t"\[InvisibleSpace]"n="\[InvisibleSpace]228\),
      SequenceForm[ "T=", 22.061905138942599, "\t", "n=", 228],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("T="\[InvisibleSpace]23.1717501825021798`
        \[InvisibleSpace]"\t"\[InvisibleSpace]"n="\[InvisibleSpace]194\),
      SequenceForm[ "T=", 23.17175018250218, "\t", "n=", 194],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("T="\[InvisibleSpace]24.3427166728988364`
        \[InvisibleSpace]"\t"\[InvisibleSpace]"n="\[InvisibleSpace]206\),
      SequenceForm[ "T=", 24.342716672898838, "\t", "n=", 206],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("T="\[InvisibleSpace]25.5025680874742288`
        \[InvisibleSpace]"\t"\[InvisibleSpace]"n="\[InvisibleSpace]222\),
      SequenceForm[ "T=", 25.502568087474227, "\t", "n=", 222],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("T="\[InvisibleSpace]26.642878057167616`
        \[InvisibleSpace]"\t"\[InvisibleSpace]"n="\[InvisibleSpace]218\),
      SequenceForm[ "T=", 26.642878057167614, "\t", "n=", 218],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("T="\[InvisibleSpace]27.7143814757189099`
        \[InvisibleSpace]"\t"\[InvisibleSpace]"n="\[InvisibleSpace]246\),
      SequenceForm[ "T=", 27.714381475718909, "\t", "n=", 246],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("T="\[InvisibleSpace]28.7272437106965696`
        \[InvisibleSpace]"\t"\[InvisibleSpace]"n="\[InvisibleSpace]262\),
      SequenceForm[ "T=", 28.72724371069657, "\t", "n=", 262],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("T="\[InvisibleSpace]29.6549164515060237`
        \[InvisibleSpace]"\t"\[InvisibleSpace]"n="\[InvisibleSpace]234\),
      SequenceForm[ "T=", 29.654916451506026, "\t", "n=", 234],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("T="\[InvisibleSpace]30.6100697699283097`
        \[InvisibleSpace]"\t"\[InvisibleSpace]"n="\[InvisibleSpace]236\),
      SequenceForm[ "T=", 30.610069769928309, "\t", "n=", 236],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("T="\[InvisibleSpace]31.7931728704596761`
        \[InvisibleSpace]"\t"\[InvisibleSpace]"n="\[InvisibleSpace]212\),
      SequenceForm[ "T=", 31.793172870459674, "\t", "n=", 212],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("T="\[InvisibleSpace]32.8255291387508751`
        \[InvisibleSpace]"\t"\[InvisibleSpace]"n="\[InvisibleSpace]254\),
      SequenceForm[ "T=", 32.825529138750873, "\t", "n=", 254],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("T="\[InvisibleSpace]33.8975817693149483`
        \[InvisibleSpace]"\t"\[InvisibleSpace]"n="\[InvisibleSpace]252\),
      SequenceForm[ "T=", 33.897581769314947, "\t", "n=", 252],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("T="\[InvisibleSpace]35.0130442203318859`
        \[InvisibleSpace]"\t"\[InvisibleSpace]"n="\[InvisibleSpace]216\),
      SequenceForm[ "T=", 35.013044220331885, "\t", "n=", 216],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("T="\[InvisibleSpace]36.0455719830456544`
        \[InvisibleSpace]"\t"\[InvisibleSpace]"n="\[InvisibleSpace]246\),
      SequenceForm[ "T=", 36.045571983045654, "\t", "n=", 246],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("T="\[InvisibleSpace]37.0873743271450706`
        \[InvisibleSpace]"\t"\[InvisibleSpace]"n="\[InvisibleSpace]240\),
      SequenceForm[ "T=", 37.087374327145071, "\t", "n=", 240],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("T="\[InvisibleSpace]38.1445852673622951`
        \[InvisibleSpace]"\t"\[InvisibleSpace]"n="\[InvisibleSpace]262\),
      SequenceForm[ "T=", 38.144585267362295, "\t", "n=", 262],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("T="\[InvisibleSpace]39.1833823250381954`
        \[InvisibleSpace]"\t"\[InvisibleSpace]"n="\[InvisibleSpace]234\),
      SequenceForm[ "T=", 39.183382325038195, "\t", "n=", 234],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("T="\[InvisibleSpace]40.1651640438663104`
        \[InvisibleSpace]"\t"\[InvisibleSpace]"n="\[InvisibleSpace]240\),
      SequenceForm[ "T=", 40.165164043866312, "\t", "n=", 240],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("T="\[InvisibleSpace]41.0850163447540595`
        \[InvisibleSpace]"\t"\[InvisibleSpace]"n="\[InvisibleSpace]280\),
      SequenceForm[ "T=", 41.08501634475406, "\t", "n=", 280],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("T="\[InvisibleSpace]41.9885452917565071`
        \[InvisibleSpace]"\t"\[InvisibleSpace]"n="\[InvisibleSpace]286\),
      SequenceForm[ "T=", 41.988545291756509, "\t", "n=", 286],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("T="\[InvisibleSpace]42.8685042568543206`
        \[InvisibleSpace]"\t"\[InvisibleSpace]"n="\[InvisibleSpace]316\),
      SequenceForm[ "T=", 42.868504256854322, "\t", "n=", 316],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("T="\[InvisibleSpace]43.7005027933231993`
        \[InvisibleSpace]"\t"\[InvisibleSpace]"n="\[InvisibleSpace]288\),
      SequenceForm[ "T=", 43.700502793323196, "\t", "n=", 288],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("T="\[InvisibleSpace]44.6299527834984566`
        \[InvisibleSpace]"\t"\[InvisibleSpace]"n="\[InvisibleSpace]280\),
      SequenceForm[ "T=", 44.62995278349846, "\t", "n=", 280],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("T="\[InvisibleSpace]45.4992815871491984`
        \[InvisibleSpace]"\t"\[InvisibleSpace]"n="\[InvisibleSpace]296\),
      SequenceForm[ "T=", 45.499281587149198, "\t", "n=", 296],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("T="\[InvisibleSpace]46.3715272964808722`
        \[InvisibleSpace]"\t"\[InvisibleSpace]"n="\[InvisibleSpace]280\),
      SequenceForm[ "T=", 46.37152729648087, "\t", "n=", 280],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("T="\[InvisibleSpace]47.2570797777864104`
        \[InvisibleSpace]"\t"\[InvisibleSpace]"n="\[InvisibleSpace]270\),
      SequenceForm[ "T=", 47.257079777786409, "\t", "n=", 270],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("T="\[InvisibleSpace]48.2445215217035716`
        \[InvisibleSpace]"\t"\[InvisibleSpace]"n="\[InvisibleSpace]244\),
      SequenceForm[ "T=", 48.244521521703568, "\t", "n=", 244],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("T="\[InvisibleSpace]49.2883455947392601`
        \[InvisibleSpace]"\t"\[InvisibleSpace]"n="\[InvisibleSpace]268\),
      SequenceForm[ "T=", 49.288345594739262, "\t", "n=", 268],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("T="\[InvisibleSpace]50.1731046158101268`
        \[InvisibleSpace]"\t"\[InvisibleSpace]"n="\[InvisibleSpace]256\),
      SequenceForm[ "T=", 50.173104615810125, "\t", "n=", 256],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("T="\[InvisibleSpace]51.1244931650112022`
        \[InvisibleSpace]"\t"\[InvisibleSpace]"n="\[InvisibleSpace]292\),
      SequenceForm[ "T=", 51.124493165011202, "\t", "n=", 292],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("T="\[InvisibleSpace]51.9129173441301894`
        \[InvisibleSpace]"\t"\[InvisibleSpace]"n="\[InvisibleSpace]300\),
      SequenceForm[ "T=", 51.912917344130186, "\t", "n=", 300],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("T="\[InvisibleSpace]52.7275404865292607`
        \[InvisibleSpace]"\t"\[InvisibleSpace]"n="\[InvisibleSpace]286\),
      SequenceForm[ "T=", 52.727540486529257, "\t", "n=", 286],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("T="\[InvisibleSpace]53.64615664849536`
        \[InvisibleSpace]"\t"\[InvisibleSpace]"n="\[InvisibleSpace]242\),
      SequenceForm[ "T=", 53.646156648495356, "\t", "n=", 242],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("T="\[InvisibleSpace]54.6736199261752098`
        \[InvisibleSpace]"\t"\[InvisibleSpace]"n="\[InvisibleSpace]244\),
      SequenceForm[ "T=", 54.673619926175213, "\t", "n=", 244],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("T="\[InvisibleSpace]55.7347233325626234`
        \[InvisibleSpace]"\t"\[InvisibleSpace]"n="\[InvisibleSpace]234\),
      SequenceForm[ "T=", 55.734723332562623, "\t", "n=", 234],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("T="\[InvisibleSpace]56.7917022936885551`
        \[InvisibleSpace]"\t"\[InvisibleSpace]"n="\[InvisibleSpace]256\),
      SequenceForm[ "T=", 56.791702293688552, "\t", "n=", 256],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("T="\[InvisibleSpace]57.8794074307096284`
        \[InvisibleSpace]"\t"\[InvisibleSpace]"n="\[InvisibleSpace]246\),
      SequenceForm[ "T=", 57.879407430709627, "\t", "n=", 246],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("T="\[InvisibleSpace]58.9441681850917298`
        \[InvisibleSpace]"\t"\[InvisibleSpace]"n="\[InvisibleSpace]226\),
      SequenceForm[ "T=", 58.944168185091726, "\t", "n=", 226],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("T="\[InvisibleSpace]59.9642834911622024`
        \[InvisibleSpace]"\t"\[InvisibleSpace]"n="\[InvisibleSpace]268\),
      SequenceForm[ "T=", 59.964283491162206, "\t", "n=", 268],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("T="\[InvisibleSpace]60.8987964806309456`
        \[InvisibleSpace]"\t"\[InvisibleSpace]"n="\[InvisibleSpace]240\),
      SequenceForm[ "T=", 60.898796480630949, "\t", "n=", 240],
      Editable->False]], "Print"],

Cell[BoxData[
    \({2000.71666666666692`\ Second, Null}\)], "Output",
  CellLabel->"Out[187]="]
}, Closed]],

Cell[TextData[{
  "The population at time ",
  Cell[BoxData[
      \(TraditionalForm\`T[p1] = 60.90\)]],
  " traces back to 6 ancestors at time 0.  Their number of offspring varies \
from 5 to 83:"
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(ei = ExtantIndividuals[p1]; anc = Ancestors[p1, ei]; \n
    desc = \(Descendants[p1, #, ei]&\)/@Ancestors[p1, ei]; 
    \n{anc, Length/@desc} // TableForm\)], "Input",
  CellLabel->"In[274]:="],

Cell[BoxData[
    TagBox[GridBox[{
          {"8", "19", "25", "43", "86", "89"},
          {"23", "29", "64", "83", "36", "5"}
          },
        RowSpacings->1,
        ColumnSpacings->3,
        RowAlignments->Baseline,
        ColumnAlignments->{Left}],
      (TableForm[ #]&)]], "Output",
  CellLabel->"Out[274]//TableForm="]
}, Open  ]],

Cell["\<\
One might do better to run on a smaller range (say, 40*40) for this \
example: the above took 2000s, and did not give coalescence back to one \
ancestor.  It might also be useful to store simulation results using Save[] \
on ALL the relevant variables- although this can eat up too much memory.  \
\
\>", "Text",
  FontSlant->"Italic"],

Cell["There is very strong spatial clustering:", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(DisplayTogether[\n\ \ 
      ListPlot[\(Location[p1, #]&\)/@desc[\([1]\)], PlotStyle \[Rule] Red], \n
      \tListPlot[\(Location[p1, #]&\)/@desc[\([2]\)], 
        PlotStyle \[Rule] Blue], \n\t
      ListPlot[\(Location[p1, #]&\)/@desc[\([3]\)], PlotStyle \[Rule] Green], 
      ListPlot[\(Location[p1, #]&\)/@desc[\([4]\)], 
        PlotStyle \[Rule] Yellow], \n\t
      ListPlot[\(Location[p1, #]&\)/@desc[\([5]\)], PlotStyle \[Rule] Black], 
      \n\tListPlot[\(Location[p1, #]&\)/@desc[\([6]\)], 
        PlotStyle \[Rule] Purple], \n\tPlotRange \[Rule] {{0, R}, {0, R}}, 
      AspectRatio \[Rule] 1]; \)\)], "Input",
  CellLabel->"In[275]:="],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 0.0166667 0 0.0166667 [
[.16667 -0.0125 -6 -9 ]
[.16667 -0.0125 6 0 ]
[.33333 -0.0125 -6 -9 ]
[.33333 -0.0125 6 0 ]
[.5 -0.0125 -6 -9 ]
[.5 -0.0125 6 0 ]
[.66667 -0.0125 -6 -9 ]
[.66667 -0.0125 6 0 ]
[.83333 -0.0125 -6 -9 ]
[.83333 -0.0125 6 0 ]
[1 -0.0125 -6 -9 ]
[1 -0.0125 6 0 ]
[-0.0125 .16667 -12 -4.5 ]
[-0.0125 .16667 0 4.5 ]
[-0.0125 .33333 -12 -4.5 ]
[-0.0125 .33333 0 4.5 ]
[-0.0125 .5 -12 -4.5 ]
[-0.0125 .5 0 4.5 ]
[-0.0125 .66667 -12 -4.5 ]
[-0.0125 .66667 0 4.5 ]
[-0.0125 .83333 -12 -4.5 ]
[-0.0125 .83333 0 4.5 ]
[-0.0125 1 -12 -4.5 ]
[-0.0125 1 0 4.5 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.16667 0 m
.16667 .00625 L
s
[(10)] .16667 -0.0125 0 1 Mshowa
.33333 0 m
.33333 .00625 L
s
[(20)] .33333 -0.0125 0 1 Mshowa
.5 0 m
.5 .00625 L
s
[(30)] .5 -0.0125 0 1 Mshowa
.66667 0 m
.66667 .00625 L
s
[(40)] .66667 -0.0125 0 1 Mshowa
.83333 0 m
.83333 .00625 L
s
[(50)] .83333 -0.0125 0 1 Mshowa
1 0 m
1 .00625 L
s
[(60)] 1 -0.0125 0 1 Mshowa
.125 Mabswid
.03333 0 m
.03333 .00375 L
s
.06667 0 m
.06667 .00375 L
s
.1 0 m
.1 .00375 L
s
.13333 0 m
.13333 .00375 L
s
.2 0 m
.2 .00375 L
s
.23333 0 m
.23333 .00375 L
s
.26667 0 m
.26667 .00375 L
s
.3 0 m
.3 .00375 L
s
.36667 0 m
.36667 .00375 L
s
.4 0 m
.4 .00375 L
s
.43333 0 m
.43333 .00375 L
s
.46667 0 m
.46667 .00375 L
s
.53333 0 m
.53333 .00375 L
s
.56667 0 m
.56667 .00375 L
s
.6 0 m
.6 .00375 L
s
.63333 0 m
.63333 .00375 L
s
.7 0 m
.7 .00375 L
s
.73333 0 m
.73333 .00375 L
s
.76667 0 m
.76667 .00375 L
s
.8 0 m
.8 .00375 L
s
.86667 0 m
.86667 .00375 L
s
.9 0 m
.9 .00375 L
s
.93333 0 m
.93333 .00375 L
s
.96667 0 m
.96667 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .16667 m
.00625 .16667 L
s
[(10)] -0.0125 .16667 1 0 Mshowa
0 .33333 m
.00625 .33333 L
s
[(20)] -0.0125 .33333 1 0 Mshowa
0 .5 m
.00625 .5 L
s
[(30)] -0.0125 .5 1 0 Mshowa
0 .66667 m
.00625 .66667 L
s
[(40)] -0.0125 .66667 1 0 Mshowa
0 .83333 m
.00625 .83333 L
s
[(50)] -0.0125 .83333 1 0 Mshowa
0 1 m
.00625 1 L
s
[(60)] -0.0125 1 1 0 Mshowa
.125 Mabswid
0 .03333 m
.00375 .03333 L
s
0 .06667 m
.00375 .06667 L
s
0 .1 m
.00375 .1 L
s
0 .13333 m
.00375 .13333 L
s
0 .2 m
.00375 .2 L
s
0 .23333 m
.00375 .23333 L
s
0 .26667 m
.00375 .26667 L
s
0 .3 m
.00375 .3 L
s
0 .36667 m
.00375 .36667 L
s
0 .4 m
.00375 .4 L
s
0 .43333 m
.00375 .43333 L
s
0 .46667 m
.00375 .46667 L
s
0 .53333 m
.00375 .53333 L
s
0 .56667 m
.00375 .56667 L
s
0 .6 m
.00375 .6 L
s
0 .63333 m
.00375 .63333 L
s
0 .7 m
.00375 .7 L
s
0 .73333 m
.00375 .73333 L
s
0 .76667 m
.00375 .76667 L
s
0 .8 m
.00375 .8 L
s
0 .86667 m
.00375 .86667 L
s
0 .9 m
.00375 .9 L
s
0 .93333 m
.00375 .93333 L
s
0 .96667 m
.00375 .96667 L
s
.25 Mabswid
0 0 m
0 1 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
1 0 0 r
.008 w
.91083 .37101 Mdot
.13188 .08206 Mdot
.05077 .10055 Mdot
.04237 .55341 Mdot
.13823 .17802 Mdot
.83892 .35577 Mdot
.08331 .09216 Mdot
.01063 .11544 Mdot
.01191 .48648 Mdot
.9619 .5225 Mdot
.93082 .39452 Mdot
.82839 .35541 Mdot
.94502 .39613 Mdot
.0541 .11202 Mdot
.78436 .37069 Mdot
.06136 .17416 Mdot
.95016 .52132 Mdot
.0351 .1498 Mdot
.06127 .19281 Mdot
.01948 .11505 Mdot
.06244 .19189 Mdot
.06301 .08025 Mdot
.06549 .15182 Mdot
0 0 1 r
.30233 .30832 Mdot
.1876 .06146 Mdot
.31505 .33513 Mdot
.29803 .33561 Mdot
.23429 .86993 Mdot
.19322 .10976 Mdot
.24761 .14656 Mdot
.21882 .14131 Mdot
.19813 .10237 Mdot
.1728 .06626 Mdot
.3064 .08268 Mdot
.18478 .10108 Mdot
.17748 .08658 Mdot
.39769 .27221 Mdot
.30815 .30645 Mdot
.22595 .12546 Mdot
.18829 .14906 Mdot
.32687 .29562 Mdot
.29469 .31193 Mdot
.31848 .24946 Mdot
.23191 .22827 Mdot
.32162 .24897 Mdot
.19913 .13303 Mdot
.16073 .07059 Mdot
.19617 .13275 Mdot
.216 .21574 Mdot
.22892 .14455 Mdot
.29978 .34148 Mdot
.31664 .28928 Mdot
0 1 0 r
.03428 .7347 Mdot
.1072 .61661 Mdot
.32444 .82453 Mdot
.23169 .74715 Mdot
.3124 .84501 Mdot
.21786 .69961 Mdot
.24744 .66077 Mdot
.23719 .72222 Mdot
.31365 .82619 Mdot
.27817 .6092 Mdot
.304 .66039 Mdot
.20551 .83962 Mdot
.03252 .57361 Mdot
.98035 .63826 Mdot
.2841 .61677 Mdot
.14764 .5533 Mdot
.30262 .52775 Mdot
.00301 .57763 Mdot
.1956 .69291 Mdot
.13339 .80564 Mdot
.30931 .8314 Mdot
.99266 .56297 Mdot
.27644 .50852 Mdot
.36056 .49733 Mdot
.04274 .7608 Mdot
.27684 .6405 Mdot
.21532 .75729 Mdot
.3642 .48011 Mdot
.41694 .6342 Mdot
.98583 .58684 Mdot
.35547 .48702 Mdot
.20209 .74638 Mdot
.15252 .74208 Mdot
.13771 .51761 Mdot
.97386 .62507 Mdot
.18218 .8387 Mdot
.27735 .53485 Mdot
.21074 .75895 Mdot
.21345 .69794 Mdot
.31898 .4401 Mdot
.33179 .82356 Mdot
.34034 .84894 Mdot
.33659 .80673 Mdot
.31395 .50411 Mdot
.04421 .70214 Mdot
.35091 .47669 Mdot
.30528 .80072 Mdot
.03539 .60192 Mdot
.24089 .68409 Mdot
.26614 .5307 Mdot
.12633 .51909 Mdot
.28724 .61589 Mdot
.32347 .79392 Mdot
.29561 .85093 Mdot
.95933 .59191 Mdot
.31877 .83649 Mdot
.12926 .59468 Mdot
.19863 .84696 Mdot
.21316 .81805 Mdot
.98711 .58667 Mdot
.3041 .51467 Mdot
.0585 .71058 Mdot
.02669 .52934 Mdot
.06947 .6872 Mdot
1 1 0 r
.78364 .15992 Mdot
.93036 .91649 Mdot
.07441 .4604 Mdot
.78262 .00523 Mdot
.82119 .19386 Mdot
.79412 .09634 Mdot
.03948 .39637 Mdot
.07922 .39863 Mdot
.81329 .21571 Mdot
.03627 .05422 Mdot
.64252 .04792 Mdot
.75878 .13818 Mdot
.8571 .87123 Mdot
.36819 .31892 Mdot
.06286 .41225 Mdot
.84427 .9016 Mdot
.53176 .97205 Mdot
.76085 .22424 Mdot
.74124 .07228 Mdot
.61363 .04744 Mdot
.00022 .01317 Mdot
.77911 .97702 Mdot
.56344 .96879 Mdot
.0087 .99812 Mdot
.52816 .23963 Mdot
.85519 .0528 Mdot
.81618 .89841 Mdot
.72044 .03104 Mdot
.08097 .46202 Mdot
.84565 .20413 Mdot
.85781 .05698 Mdot
.57506 .04405 Mdot
.59757 .04311 Mdot
.86636 .22787 Mdot
.04479 .36768 Mdot
.89278 .22314 Mdot
.78728 .93911 Mdot
.7873 .91984 Mdot
.73867 .08828 Mdot
.52569 .01952 Mdot
.87839 .2545 Mdot
.02483 .39166 Mdot
.03431 .06808 Mdot
.9005 .88105 Mdot
.11243 .44955 Mdot
.79581 .10339 Mdot
.74992 .95152 Mdot
.09891 .37446 Mdot
.7222 .12189 Mdot
.89482 .25424 Mdot
.9321 .8857 Mdot
.68783 .11559 Mdot
.80847 .16505 Mdot
.80137 .97689 Mdot
.51435 .98659 Mdot
.02345 .0536 Mdot
.81025 .17586 Mdot
.73316 .13374 Mdot
.75345 .97319 Mdot
.69747 .11455 Mdot
.87358 .09178 Mdot
.59448 .10489 Mdot
.03214 .39392 Mdot
.58309 .05911 Mdot
.85666 .18146 Mdot
.73315 .08083 Mdot
.52559 .27989 Mdot
.88596 .90923 Mdot
.10379 .40791 Mdot
.82457 .07045 Mdot
.0288 .40403 Mdot
.82798 .18991 Mdot
.54365 .23647 Mdot
.55287 .03363 Mdot
.80018 .08982 Mdot
.52524 .28046 Mdot
.08026 .40546 Mdot
.71794 .14005 Mdot
.81898 .15719 Mdot
.5823 .05768 Mdot
.51611 .99015 Mdot
.75198 .94559 Mdot
.86325 .19946 Mdot
0 0 0 r
.40121 .47874 Mdot
.31545 .64081 Mdot
.24196 .47656 Mdot
.36605 .56589 Mdot
.1904 .41725 Mdot
.23367 .46892 Mdot
.24572 .52858 Mdot
.45842 .42611 Mdot
.53359 .40334 Mdot
.19045 .43234 Mdot
.35686 .63852 Mdot
.24594 .45584 Mdot
.40756 .38158 Mdot
.45017 .42564 Mdot
.34364 .52825 Mdot
.47621 .42246 Mdot
.144 .48225 Mdot
.29714 .72163 Mdot
.31423 .7185 Mdot
.35813 .5737 Mdot
.31955 .69922 Mdot
.39075 .58423 Mdot
.50766 .39185 Mdot
.50288 .41383 Mdot
.36507 .55054 Mdot
.36702 .59514 Mdot
.39753 .47251 Mdot
.4103 .48876 Mdot
.19118 .43932 Mdot
.40428 .40252 Mdot
.33615 .59084 Mdot
.43045 .42954 Mdot
.27945 .73212 Mdot
.16453 .46845 Mdot
.31535 .65727 Mdot
.36817 .59656 Mdot
.628 .126 .941 r
.40165 .66665 Mdot
.66441 .81813 Mdot
.61404 .75544 Mdot
.61674 .73685 Mdot
.67316 .84241 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[275]:=",
  ImageSize->{429, 429},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40006]0001[A000`40O003h00Oogoo[Woo003oOon^
Ool00?moojioo`00ogoo[Woo003oOon^Ool004moo`<000Aoo`8003]oo`@000=oo`8003Yoo`<000Ao
o`8003aoo`<000=oo`8003Yoo`<000Aoo`8003]oo`8000Aoo`8000Aoo`00D7oo00<007ooOol00Woo
00@007ooOol003]oo`03001oogoo009oo`04001oogoo000lOol01000Oomoo`000Woo00<007ooOol0
>Woo00D007ooOomoo`00009oo`03001oogoo03Yoo`04001oogoo0002Ool00`00Oomoo`0gOol01000
Oomoo`000Woo00@007ooOol000=oo`00D7oo00<007ooOol00Woo00@007ooOol003aoo`05001oogoo
Ool00002Ool00`00Oomoo`0jOol01000Oomoo`000Woo00<007ooOol0>7oo10000Woo00@007ooOol0
03aoo`04001oogoo0002Ool00`00Oomoo`0gOol01000Oomoo`000Woo00@007ooOol000=oo`00D7oo
00<007ooOol00Woo00@007ooOol003eoo`04001oogoo0002Ool00`00Oomoo`0hOol20003Ool01000
Oomoo`00>Woo00<007oo00000goo00@007ooOol003Uoo`<000=oo`04001oogoo000iOol30003Ool0
1000Oomoo`000goo001@Ool00`00Oomoo`02Ool01000Oomoo`00>Woo00@007ooOol0009oo`04001o
ogoo000lOol01000Oomoo`000Woo00<007ooOol0>7oo00<007oo00000goo00@007ooOol003Uoo`03
001oogoo00=oo`04001oogoo000iOol00`00Oomoo`03Ool01000Oomoo`000goo001?Ool20005Ool2
000lOol20004Ool2000jOol30004Ool2000lOol20004Ool2000jOol40003Ool2000kOol30003Ool2
0004Ool00?moojioo`00ogoo[Woo003oOon^Ool00?moojioo`00ogoo[Woo003oOon^Ool0015oool0
09H000Moo`004Goo00<007ooOol02Woo00<007ooOol02goo00<007ooOol02Woo00<007ooOol02goo
00<007ooOol02Woo00<007ooOol02goo00<007ooOol02Woo00<007ooOol02goo00<007ooOol02Woo
00<007ooOol02goo00<007ooOol02Woo00<007ooOol02goo00<007ooOol02Woo00<007ooOol02goo
00<007ooOol02Woo00<007ooOol02goo00<007ooOol02Woo00<007ooOol02goo00<007ooOol02Woo
00<007ooOol02goo00<007ooOol02Woo00<007ooOol02goo00<007ooOol02Woo00<007ooOol00Woo
0goP1Woo00<007ooOol02Woo00<007ooOol02goo00<007ooOol02Woo00<007ooOol02goo00<007oo
Ool02Woo00<007ooOol02Woo00<007ooOol01Goo000AOol00`00Oomoo`10Ool00`00Oomoo`11Ool0
0`00Oomoo`10Ool00`00Oomoo`11Ool00`00Oomoo`0ZOol3On0COol00`00Oomoo`10Ool00`00Oomo
o`05Ool0015oo`03001oogoo0?moocUoo`=oh5ioo`0047oo0goPogooVgoo000@Ool3On3oOonKOol0
011oo`=oh?mooi]oo`004Goo00<007ooOol0d7oo0goPaWoo000AOol00`00Oomoo`3@Ool3On36Ool0
015oo`03001oogoo0=1oo`=oh<Ioo`004Goo00<007ooOol0ogooVWoo000AOol00`00Oomoo`3oOolP
Ool3On1gOol0015oo`03001oogoo0=]oo`=oh45oo`=oh7Moo`004Goo0P00g7oo0goP@Goo0goPMgoo
000AOol00`00Oomoo`3KOol3On2kOol0015oo`03001oogoo0?mooiYoo`004Goo00<007ooOol0kGoo
0goPZGoo000AOol00`00Oomoo`3TOol3On06Ool3On2YOol0015oo`03001oogoo0>Aoo`=oh0Ioo`=o
h0Aoo`=oh0Uoo`=oh9Ioo`004Goo00<007ooOol0i7oo0goP3Goo0goP2Goo0goPUWoo000AOol00`00
Oomoo`3dOol3On09Ool3On1COol3On10Ool0015oo`03001oogoo00Eoo`=oh09oo`=oh?moodYoo`=o
h41oo`004Goo00<007ooOol01Goo0goP0Woo0goPfWoo0goPK7oo17oP?goo000AOol00`00Oomoo`05
Ool3On02Ool3On3JOol4On1/Ool3On0oOol0015oo`03001oogoo04Moo`<07ieoo`Aoh6aoo`=oh3mo
o`004Goo00<007ooOol0Agoo0`0OWWoo0goP[Woo000AOol00`00Oomoo`09Ool3On0eOol301l3Ool3
01ooOom@Ool0015oo`8000Yoo`=oh35oo`<07`04Ool07`0O01ooOol6Ool3On1=Ool0015oo`03001o
ogoo00Uoo`=oh35oo`<07`04Ool07`0O01oTOol3On0NOol3On1=Ool0015oo`03001oogoo03eoo`<0
7nQoo`=oh1ioo`=oh4eoo`004Goo00<007ooOol0ogoo:Goo0goPKWoo000AOol00`00Oomoo`0EOol3
O03oOon2Ool0015oo`03001oogoo01Eoo`=l01Uoo`=l04Aoo`<07jUoo`=oh79oo`004Goo00<007oo
Ool05Goo0g`06Goo0g`0A7oo0`0OZGoo0goPLWoo000AOol00`00Oomoo`0aOol3O00?Ool301lbOol3
01nYOol3On1bOol0015oo`03001oogoo04=oo`<07n5oo`=oh1Ioo`=oh5Ioo`004Goo00<007ooOol0
7Goo0g`08goo0`0OhGoo0goP5Woo0goP6Woo0goP>Goo000AOol00`00Oomoo`0MOol3O03oOol8Ool3
On0FOol3On0JOol3On0iOol0015oo`03001oogoo01eoo`=l0?mooaioo`=oh1eoo`=oh3Uoo`004Goo
00<007ooOol0ogoo?Woo0goPFGoo000AOol2000AOol3O00cOol301l3Ool301o^Ool3On1IOol0015o
o`03001oogoo011oo`=l03=oo`<07`=oo`<07ieoo`=oh4moo`=oh5Qoo`004Goo00<007ooOol047oo
0g`0<goo0`0O0goo0`0OWGoo0goPCgoo0goPF7oo000AOol00`00Oomoo`1:Ool301nOOol3On1?Ool3
On1HOol0015oo`03001oogoo015oo`=l03Ioo`<07omoodeoo`004Goo00<007ooOol00goo0g`02goo
0g`0=Woo0`0ObGoo0goPP7oo000AOol00`00Oomoo`06O00;Ool3O03nOol3On0017ooOn1oh7oPP7oo
000AOol00`00Oomoo`06O03oOol=Ool3On0017ooOn1oh7oPP7oo000AOol00`00Oomoo`03O03oOol@
Ool3On0;Ool3On1fOol0015oo`03001oogoo0?moob5oo`=oh7Ioo`004Goo00<007ooOol0Egoo0`0O
aWoo0goPMWoo000AOol00`00Oomoo`1GOol301ooOom0Ool0015oo`03001oogoo05Moo`<07omood1o
o`004Goo00<007ooOol0Bgoo100OeGoo0goPLWoo000AOol2001<Ool401oEOol3On1bOol0015oo`03
001oogoo04]oo`@07mEoo`=oh0Qoo`=oh6Moo`004Goo00<007ooOol0E7oo0`0Oagoo0goP3Woo0goP
Igoo000AOol00`00Oomoo`1DOol301l017oo01l07`0O`goo0goP3Woo0goPIgoo000AOol00`00Oomo
o`1DOol301l017oo01l07`0O1Goo0`0O^goo0goPN7oo000AOol00`00Oomoo`18Ool301l=Ool301l5
Ool301ooOolgOol0015oo`03001oogoo00Yoo`=l00Uoo`=l02moo`<07aEoo`<07omoocMoo`004Goo
00<007ooOol02Woo0g`02Goo0g`0;goo0`0OogooCgoo000AOol00`00Oomoo`0:Ool3O009Ool3O03o
Oon1Ool0015oo`03001oogoo0?moodQoo`=oh4moo`004Goo00<007ooOol0ogoo>Woo0goP2goo0goP
Cgoo000017oo0000000017oo0P001goo00<007ooOol0ogoo>Woo0goP2goo0goPCgoo0002Ool00`00
Oomoo`02Ool01000Oomoo`001Woo00<007ooOol0ogoo>Woo0goP1goo0goPDgoo0002Ool00`00Oomo
o`02Ool01000Oomoo`001Woo0`00ogooA7oo0goPDgoo0002Ool00`00Oomoo`02Ool01000Oomoo`00
1Woo00<007ooOol0ogooA7oo0goPDgoo0002Ool00`00Oomoo`02Ool01000Oomoo`001Woo00<007oo
Ool057oo0g`0ogooPgoo00000goo00000005Ool20007Ool00`00Oomoo`0DOol3O03oOol^Ool3On1B
Ool0015oo`03001oogoo01Aoo`=l01aoo`=l0?moo`moo`=oh59oo`004Goo00<007ooOol0<goo0g`0
ogoo3goo0goP3goo0goP@7oo000AOol00`00Oomoo`0cOol3O03oOolQOol3On10Ool0015oo`03001o
ogoo0?mooeMoo`=oh41oo`004Goo00<007ooOol0ogooVWoo000AOol00`00Oomoo`3oOom<Ool3On1;
Ool0015oo`03001oogoo01Aoo`Al0?mooc5oo`Ioh4]oo`004Goo00<007ooOol057oo17`0ogoo<Goo
1WoPBgoo000AOol00`00Oomoo`0DOol4O03oOolaOol3On1>Ool0015oo`03001oogoo0?mooeYoo`=o
h3eoo`004Goo0P00ogooFgoo0goP?Goo000AOol00`00Oomoo`3oOomCOol3On04Ool3On0mOol0015o
o`03001oogoo0?mooe=oo`=oh4Aoo`004Goo00<007ooOol0ogooDgoo0goPA7oo000AOol00`00Oomo
o`3oOonJOol0015oo`03001oogoo05=oo`<07nmoo`=oh55oo`004Goo00<007ooOol0Dgoo0`0Okgoo
0goPDGoo000AOol00`00Oomoo`1COol301o_Ool3On1AOol0015oo`03001oogoo0?moofIoo`=oh35o
o`004Goo00<007ooOol0ogoo<Goo0goP<Woo0goP<Goo000AOol00`00Oomoo`1IOol301oDOol3On0W
Ool3On08Ool3On0aOol0015oo`03001oogoo05Uoo`<07mAoo`=oh2Moo`=oh3aoo`004Goo00<007oo
Ool0FGoo0`0OoWoo0goP?7oo000AOol2003oOonKOol0015oo`03001oogoo0=Qoo`=oh;ioo`004Goo
00<007ooOol0dGoo0goP17oo0goP_Woo000AOol00`00Oomoo`3AOol3On04Ool3On2nOol0015oo`03
001oogoo0=5oo`=oh<Eoo`004Goo00<007ooOol0ogooVWoo000AOol00`00Oomoo`1lOol501ooOolI
Ool0015oo`03001oogoo07aoo`D07omooaUoo`004Goo00<007ooOol0O7oo1@0OgWoo0goP17oo0goP
<7oo000AOol00`00Oomoo`3oOomPOol3On04Ool3On0`Ool0015oo`03001oogoo0?moof1oo`=oh0Ao
o`=oh31oo`004Goo00<007ooOol0ogooVWoo000AOol00`00Oomoo`3oOonJOol0015oo`03001oogoo
0?mooiYoo`004Goo0P00ogooVgoo000AOol00`00Oomoo`2MOol301oiOol0015oo`03001oogoo09eo
o`<07oUoo`004Goo00<007ooOol0WGoo0`0OnGoo000AOol00`00Oomoo`3@Ool3On36Ool0015oo`03
001oogoo0=1oo`=oh<Ioo`004Goo00<007ooOol0d7oo0goPaWoo000AOol00`00Oomoo`3oOonJOol0
015oo`03001oogoo07aoo`<07omooa]oo`004Goo00<007ooOol0O7oo0`0Oogoo6goo000AOol00`00
Oomoo`1lOol301ooOolKOol0015oo`03001oogoo081oo`<07omooaMoo`004Goo00<007ooOol0P7oo
0`0Oogoo5goo000AOol20021Ool301ooOolGOol0015oo`03001oogoo0?mooiYoo`004Goo00<007oo
Ool0N7oo0`0Oogoo7goo000AOol00`00Oomoo`1fOol501ooOolOOol0015oo`03001oogoo07=oo`P0
7omooamoo`004Goo00<007ooOol0Lgoo1P0Oogoo8Goo000AOol00`00Oomoo`1cOol301ooOolTOol0
015oo`03001oogoo095oo`=oh?moo`Ioo`004Goo00<007ooOol0TGoo0goPogoo1Woo000AOol00`00
Oomoo`2AOol3On3oOol6Ool0015oo`03001oogoo0?mooiYoo`004Goo00<007ooOol0ogooVWoo0000
0goo000000020003Ool20007Ool00`00Oomoo`3oOonJOol0009oo`03001oogoo009oo`04001oogoo
0006Ool00`00Oomoo`3oOonJOol000=oo`05001oogooOol00002Ool00`00Oomoo`04Ool3001dOol3
01l4Ool301ooOolLOol000Aoo`04001oogoo0002Ool00`00Oomoo`04Ool00`00Oomoo`1dOol301l4
Ool301ooOolLOol00005Ool007ooOol00002Ool01000Oomoo`001Woo00<007ooOol0M7oo100O0goo
0`0Oogoo77oo0002Ool20004Ool20007Ool00`00Oomoo`1eOol301ooOolROol0015oo`03001oogoo
07Eoo`<07omoob9oo`004Goo00<007ooOol0ogooVWoo000AOol00`00Oomoo`3oOonJOol0015oo`03
001oogoo0?mooiYoo`004Goo00<007ooOol0ogooC7oo0g`000Aoog`0O01l04Moo`004Goo00<007oo
Ool0ogooC7oo0g`000Aoog`0O01l04Moo`004Goo00<007ooOol0ogooC7oo0g`000Aoog`0O01l04Mo
o`004Goo00<007ooOol0ogooVWoo000AOol00`00Oomoo`3oOonJOol0015oo`8000moo`=oh?moohUo
o`004Goo00<007ooOol03Woo0goPogoo:Goo0g`0<7oo0g`0:Woo000AOol00`00Oomoo`0>Ool3On3o
OolYOol3O00`Ool3O00ZOol0015oo`03001oogoo02Aoo`=oh?mooa=oo`=l031oo`=l02Yoo`004Goo
00<007ooOol097oo0goPogooLgoo000AOol00`00Oomoo`0TOol3On1jOol3003eOol0015oo`03001o
ogoo0:5oo`<00?Eoo`004Goo00<007ooOol0XGoo0`00mGoo000AOol00`00Oomoo`3oOonJOol0015o
o`03001oogoo00Ioo`=oh?mooi5oo`004Goo00<007ooOol01Woo1WoP_Goo0`00cGoo000AOol00`00
Oomoo`06Ool8On2kOol3002XOol3O003Ool3O00LOol0015oo`03001oogoo00Uoo`Eoh0ioo`=oh:Yo
o`<00:Qoo`=l00=oo`=l01aoo`004Goo00<007ooOol02goo0goP3Woo0goPogooEWoo0g`00goo0g`0
77oo000AOol20008Ool3On0BOol3On20Ool3000bOol30032Ool0015oo`03001oogoo00Moo`=oh19o
o`=oh81oo`<0039oo`<00<9oo`004Goo00<007ooOol01goo0goP4Woo0goP1goo0goPMWoo0`00<Woo
0`00`Woo000AOol00`00Oomoo`0LOol3On07Ool3On3oOomaOol0015oo`03001oogoo01Eoo`=oh0io
o`=oh9ioo`<00<moo`004Goo00<007ooOol05Goo0goP[goo0`00cgoo000AOol00`00Oomoo`0EOol3
On0aOol3001kOol3003?Ool0015oo`03001oogoo04Uoo`<00?moodioo`004Goo00<007ooOol0BGoo
0`00L7oo0`00fWoo000AOol00`00Oomoo`2bOol60004Ool3003JOol0015oo`03001oogoo0;9oo`H0
00Aoo`<00=Yoo`004Goo00<007ooOol0ZWoo0`001Goo1P00hGoo000AOol00`00Oomoo`19Ool3001N
Ool3003/Ool0015oo`8004Yoo`<005ioo`<00>aoo`004Goo00<007ooOol0BGoo0`00ogooCWoo000A
Ool00`00Oomoo`19Ool3000aOol30n3oOolJOol0015oo`03001oogoo04Uoo`<0035oo`<3h?mooaYo
o`004Goo00<007ooOol0BGoo0`00<Goo0`?Pogoo6Woo000AOol00`00Oomoo`3oOonJOol0015oo`03
001oogoo02Uoo`=oh?moofioo`004Goo00<007ooOol0:Goo0goPogooKWoo000AOol00`00Oomoo`0Y
Ool3On0cOol3003oOolhOol0015oo`03001oogoo05moo`<00?moocQoo`004Goo00<007ooOol06Woo
0goP@Woo0`00ogoo>7oo000AOol00`00Oomoo`0JOol5On3oOomkOol0015oo`03001oogoo01Yoo`Eo
h?moog]oo`004Goo00<007ooOol077oo0goPogooNgoo000AOol2000oOol3000IOol3003oOolmOol0
015oo`03001oogoo03ioo`<001Uoo`<003moo`<00?Yoo`004Goo00<007ooOol0?Woo0`006Goo0`00
?goo0`00nWoo000AOol00`00Oomoo`1MOol3000ZOol30n0?Ool3003jOol0015oo`03001oogoo05eo
o`<002Yoo`<3h09oo`<3h0aoo`<00?Qoo`004Goo00<007ooOol0=Woo0`0097oo0`00:Woo0`?P0Woo
0`?P37oo0`00n7oo000AOol00`00Oomoo`0fOol3001FOol30n0<Ool3003hOol0015oo`03001oogoo
00=l03=oo`<0059oo`<3h?moo`aoo`004Goo00<007ooOol00g`0R7oo0`?P57oo0`00m7oo000AOol0
0`00Oomoo`03O028Ool30n0DOol3003dOol0015oo`03001oogoo0:9oo`<00?Aoo`0000Aoo`000000
00Aoo`8000Moo`03001oogoo08ioo`<3h?moo`Uoo`0017oo00@007ooOol0009oo`03001oogoo00Ao
o`03001oogoo08ioo`<3h?moo`Uoo`0017oo00@007ooOol0009oo`03001oogoo00Aoo`<008ioo`<3
h?moo`Uoo`000Woo0P000goo00@007ooOol000Ioo`03001oogoo07]oo`<3h?mooaaoo`0017oo00@0
07ooOol0009oo`03001oogoo00Aoo`03001oogoo07]oo`<3h?mooaaoo`0000Aoo`00000000Aoo`80
00Moo`03001oogoo06]oo`<3h0eoo`<3h?mooaaoo`004Goo00<007ooOol0Jgoo0`?Pogoo;7oo000A
Ool00`00Oomoo`1[Ool30n09Ool30n3oOolPOol0015oo`03001oogoo03=oo`<3h45oo`<3h?moob1o
o`004Goo00<007ooOol0;goo0`?P00Aoo`?P0n03h45oo`<3h?moob1oo`004Goo00<007ooOol0;goo
0`?P00Aoo`?P0n03h?moodMoo`=l009oo`=l01Eoo`004Goo00<007ooOol0;goo0`?PogooBgoo0g`0
0Woo0g`05Goo000AOol00`00Oomoo`3oOommOol3O002Ool3O00EOol0015oo`03001oogoo00Ioo`<3
h5Ioo`<001Aoo`<3h0ioo`<00?mooa1oo`004Goo00<007ooOol01Woo0`?PEWoo0`001Goo0`?P37oo
0`?P3Woo0`00ogoo47oo000AOol00`00Oomoo`06Ool30n1FOol30005Ool30n02Ool30n07Ool30n0>
Ool3003oOol@Ool0015oo`8006Qoo`<3h09oo`<3h?moob]oo`004Goo00<007ooOol0K7oo0`?Pogoo
:goo000AOol00`00Oomoo`3oOonJOol0015oo`03001oogoo0?mooiYoo`004Goo00<007ooOol0ogoo
VWoo000AOol00`00Oomoo`3oOonJOol0015oo`03001oogoo08moo`<00?moo`Qoo`004Goo00<007oo
Ool03Goo0g`09goo0`?PEGoo0`00ogoo27oo000AOol00`00Oomoo`0=Ool3O00WOol30n1EOol3003o
Ool8Ool0015oo`03001oogoo00eoo`=l02Moo`<3h?moof1oo`004Goo00<007ooOol0ogooVWoo000A
Ool00`00Oomoo`3oOon>Ool30n09Ool0015oo`03001oogoo091oo`<00?Yoo`<3h0Uoo`004Goo0P00
TGoo0`00nWoo0`?P2Goo000AOol00`00Oomoo`2@Ool3003oOol7Ool0015oo`03001oogoo00Uoo`<3
h85oo`<00?moo`Yoo`004Goo00<007ooOol02Goo0`?PPGoo0`00ogoo2Woo000AOol30n09Ool30n21
Ool3003oOol:Ool0015oo`<3h?mooiYoo`004Goo0`?PVWoo0`00o7oo000AOol00`00Oomoo`2JOol3
003^Ool30n0;Ool0015oo`03001oogoo09Yoo`<00>ioo`<3h0]oo`004Goo00<007ooOol0Q7oo0`00
ogoo1Goo0`?P2goo000AOol00`00Oomoo`24Ool3003iOol30n08Ool30n0;Ool0015oo`03001oogoo
031oo`<3h55oo`<000Uoo`@00>aoo`<3h1Ioo`004Goo00<007ooOol0<7oo0`?PGGoo1000k7oo0`?P
5Woo000AOol00`00Oomoo`0`Ool30n1MOol4003oOol6Ool0015oo`8000]oo`<3h?mooheoo`004Goo
00<007ooOol02Woo0`?PogooSGoo000AOol00`00Oomoo`0:Ool30n3oOon=Ool0015oo`03001oogoo
06aoo`<3h?moob]oo`004Goo00<007ooOol0K7oo0`?Pogoo:goo000AOol00`00Oomoo`1/Ool30n00
17oo0n03h0?Pogoo9goo000AOol00`00Oomoo`0WOol30n15Ool40n3oOolWOol0015oo`03001oogoo
02Moo`<3h4Eoo`@3h?moobMoo`004Goo00<007ooOol09goo0`?PAGoo0`?Pogoo:7oo000AOol00`00
Oomoo`3oOon7Ool30n0@Ool0015oo`03001oogoo0?moohMoo`<3h11oo`004Goo00<007ooOol0ogoo
Qgoo0`?P47oo000AOol00`00Oomoo`3oOonJOol0015oo`800:Eoo`<3h?9oo`004Goo00<007ooOol0
S7oo0`005Goo0`?PhGoo0`?P3Woo000AOol00`00Oomoo`1/Ool30n0<Ool3000>Ool3000EOol30n3Q
Ool30n0>Ool0015oo`03001oogoo06aoo`<3h0aoo`<000ioo`<00?Uoo`<3h0ioo`004Goo00<007oo
Ool0K7oo0`?P37oo0`00ogoo77oo000AOol00`00Oomoo`3oOonJOol0015oo`03001oogoo0?mooiYo
o`004Goo00<007ooOol0ogooVWoo000AOol00`00Oomoo`3oOonJOol0015oo`03001oogoo07]oo`<0
0?mooaaoo`004Goo00<007ooOol0H7oo0`?P57oo0`?P00Aoo`0000000?mooaaoo`004Goo00<007oo
Ool0H7oo0`?P57oo0`?P00Aoo`0000000?mooaaoo`000Woo0`000goo0P001goo00<007ooOol0H7oo
0`?P57oo0`?Pogoo87oo0003Ool01@00Oomoogoo00000Woo00<007ooOol017oo00<007ooOol0WWoo
0e2Nn7oo00000goo000000020002Ool01000Oomoo`001Woo0`00WWoo0e2Nn7oo000017oo001oo`00
0goo00@007ooOol000Ioo`03001oogoo09ioo`=@W_Qoo`0000Aoo`00Ool000=oo`04001oogoo0006
Ool00`00Oomoo`3oOonJOol0009oo`8000Aoo`8000Moo`03001oogoo0?mooiYoo`004Goo00<007oo
Ool0ogooVWoo000AOol00`00Oomoo`3oOonJOol0015oo`03001oogoo05eoo`<3h?moocYoo`004Goo
00<007ooOol067oo0`?P@Woo0`?Pogoo>Woo000AOol00`00Oomoo`0HOol30n12Ool30n3oOoljOol0
015oo`03001oogoo01Qoo`<3h31oo`<3h?moodaoo`004Goo00<007ooOol0Bgoo0`?PogooC7oo000A
Ool00`00Oomoo`1;Ool30n04Ool30n3oOom5Ool0015oo`03001oogoo059oo`D3h2Ioo`<00?mooaYo
o`004Goo0P003Woo0`?P@Woo1@?P9Woo0`00ogoo6Woo000AOol00`00Oomoo`0=Ool30n14Ool30n0V
Ool3003oOolJOol0015oo`03001oogoo00eoo`<3h?moohYoo`004Goo00<007ooOol0ogooVWoo000A
Ool00`00Oomoo`0COol30n3oOon4Ool0015oo`03001oogoo01=oo`<3h?moohAoo`004Goo00<007oo
Ool04goo0`?PogooQ7oo000AOol00`00Oomoo`1kOol3003oOolLOol0015oo`03001oogoo05aoo`<3
h1Eoo`<000Aoo`<00?mooaaoo`004Goo00<007ooOol0G7oo0`?P5Goo0`0017oo0`00ogoo77oo000A
Ool00`00Oomoo`1LOol30n0EOol3003oOolSOol0015oo`03001oogoo0?mooiYoo`004Goo00<007oo
Ool0KGoo0`00ogoo:Woo000AOol00`00Oomoo`09Ool30n1QOol3003oOolZOol0015oo`8000Yoo`<3
h65oo`<008Eoo`=@WZ5oo`004Goo00<007ooOol02Goo0`?PjGoo0e2NXGoo000AOol00`00Oomoo`0i
Ool30n2iOol3D9jQOol0015oo`03001oogoo03Uoo`<3h?mooeioo`004Goo00<007ooOol0>Goo0`?P
4Goo0`?P2Goo0`?Pogoo?Woo000AOol00`00Oomoo`1=Ool30n09Ool30n3oOolnOol0015oo`03001o
ogoo04eoo`<3h0Uoo`<3h?moocioo`004Goo00<007ooOol0ogooVWoo000AOol00`00Oomoo`3dOol3
D9jROol0015oo`03001oogoo055oo`D3h9ioo`=@WZ9oo`004Goo00<007ooOol03Goo0`?P@Goo1@?P
WWoo0e2NXWoo000AOol00`00Oomoo`0=Ool30n11Ool50n3oOom4Ool0015oo`03001oogoo00eoo`<3
h?moohYoo`004Goo0P00ogooVgoo000AOol00`00Oomoo`3oOonJOol0015oo`03001oogoo0?mooiYo
o`004Goo00<007ooOol0ogooVWoo000AOol00`00Oomoo`3oOonJOol0015oo`03001oogoo0?mooiYo
o`004Goo00<007ooOol0ogooVWoo000AOol00`00Oomoo`3oOonJOol0015oo`03001oogoo0?mooiYo
o`004Goo00<007ooOol0ogooVWoo000AOol00`00Oomoo`1nOol30n3oOolIOol0015oo`03001oogoo
07ioo`<3h?mooaUoo`004Goo00<007ooOol0OWoo0`?Pogoo6Goo000AOol00`00Oomoo`1gOol30n3o
OolPOol0015oo`8007Qoo`<3h?moob1oo`004Goo00<007ooOol0<Woo0`?P@Woo0`?Pogoo87oo000A
Ool00`00Oomoo`0bOol30n1?Ool30n3oOolCOol0015oo`03001oogoo039oo`<3h4moo`<3h?mooa=o
o`004Goo00<007ooOol0Q7oo0`?Pogoo4goo000AOol00`00Oomoo`3oOonJOol0015oo`03001oogoo
059oo`<3h;Aoo`=@WXeoo`004Goo00<007ooOol0DWoo0`?P]7oo0e2NSGoo000AOol00`00Oomoo`1B
Ool30n0]Ool30n24Ool3D9j=Ool0015oo`03001oogoo07]oo`<3h003Ool3h0?P00@3h?mooaEoo`00
4Goo00<007ooOol0Ngoo0`?P00=oo`?P0n0010?Pogoo5Goo000017oo0000000017oo0P001goo00<0
07ooOol0Ngoo0`?P00Aoo`?P0n03h?mooaQoo`0017oo00@007ooOol0009oo`03001oogoo00Aoo`03
001oogoo07Uoo`<3h?mooaioo`0017oo00@007ooOol0009oo`03001oogoo00Aoo`<007Uoo`<3h?mo
oaioo`0000Aoo`00000000=oo`04001oogoo0006Ool00`00Oomoo`15Ool30n0aOol30n0017oo0n03
h0?Pogoo6Woo00000goo001oo`04Ool01000Oomoo`001Woo00<007ooOol0AGoo0`?P1goo0`?P:goo
0`?Pogoo6Woo00000goo000000020003Ool20007Ool00`00Oomoo`15Ool30n07Ool30n0[Ool30n2<
Ool3D9j:Ool0015oo`03001oogoo04moo`<3h2Qoo`<3h8moo`=@WXYoo`004Goo00<007ooOol0C7oo
0`?P:goo0`?PSgoo0e2NRWoo000AOol00`00Oomoo`1<Ool30n0TOol30n04Ool30n08Ool30n3oOolB
Ool0015oo`03001oogoo04aoo`<3h2Aoo`<3h0moo`<3h?mooa9oo`004Goo00<007ooOol0Lgoo0`?P
3goo0`?Pogoo4Woo000AOol00`00Oomoo`3oOonJOol0015oo`03001oogoo0?mooiYoo`004Goo00<0
07ooOol0ogooVWoo000AOol00`00Oomoo`3oOonJOol0015oo`03001oogoo0?mooiYoo`004Goo0P00
Fgoo0`0Oogoo?Goo000AOol00`00Oomoo`1JOol301ojOol3On0oOol0015oo`03001oogoo05Yoo`<0
7oYoo`=oh3moo`004Goo00<007ooOol0ogooF7oo0goP?goo000AOol00`00Oomoo`3oOonJOol0015o
o`03001oogoo0?moofUoo`=oh2ioo`004Goo00<007ooOol0ogooJGoo0goP;Woo000AOol00`00Oomo
o`3oOomYOol3On0:Ool3On0QOol0015oo`03001oogoo0?moogIoo`=oh25oo`004Goo00<007ooOol0
ogooMWoo0goP8Goo000AOol00`00Oomoo`3oOonJOol0015oo`03001oogoo0?mooiYoo`004Goo00<0
07ooOol0ogooAgoo0goPD7oo000AOol2003oOom8Ool3On08Ool3On15Ool0015oo`03001oogoo0?mo
odMoo`=oh0Qoo`=oh4Eoo`004Goo00<007ooOol0ogooDWoo0goPAGoo000AOol00`00Oomoo`3oOomS
Ool3On0dOol0015oo`03001oogoo0?moof=oo`=oh3Aoo`004Goo00<007ooOol0ogooHgoo0goP=7oo
000AOol00`00Oomoo`3oOomeOol3On0ROol0015oo`03001oogoo0?mooc]oo`=oh3Moo`=oh29oo`00
4Goo00<007ooOol0ogoo>goo0goP=goo0goP8Woo000AOol00`00Oomoo`3oOolkOol3On1LOol0015o
o`03001oogoo0?mooiYoo`004Goo00<007ooOol0ogooVWoo000AOol00`00Oomoo`3oOonJOol0015o
o`03001oogoo0?mooiYoo`004Goo0P00ogooVgoo000AOol00`00Oomoo`3oOolkOol3On1LOol0015o
o`03001oogoo0?mooc]oo`=oh5aoo`004Goo00<007ooOol0ogoo>goo0goPG7oo000AOol00`00Oomo
o`3oOol]Ool3On1ZOol0015oo`03001oogoo0?moobeoo`=oh6Yoo`004Goo00<007ooOol0ogoo;7oo
17oPJWoo000AOol00`00Oomoo`3oOol/Ool3On1[Ool0015oo`03001oogoo0?moobaoo`=oh6]oo`00
4Goo00<007ooOol0ogooVWoo000AOol00`00Oomoo`3oOonJOol0015oo`03001oogoo0?mooiYoo`00
4Goo00<007ooOol0ogooVWoo000AOol2003QOol3On2fOol0015oo`03001oogoo0==oo`=oh0Yoo`=o
h;Ioo`004Goo00<007ooOol0dgoo0goP2Woo0goPBWoo0goPJGoo000AOol00`00Oomoo`3COol3On1G
Ool3On0@Ool3On1FOol0015oo`03001oogoo0?moobioo`=oh0Moo`=oh0Ioo`=oh5Ioo`004Goo00<0
07ooOol0ogoo>7oo0goP1Woo0goPEWoo000AOol00`00Oomoo`3oOolhOol3On1OOol0015oo`03001o
ogoo0<aoo`=oh<Yoo`004Goo00<007ooOol0c7oo0goPbWoo000AOol00`00Oomoo`3<Ool3On3:Ool0
015oo`03001oogoo0<aoo`=oh<Yoo`004Goo00<007ooOol0c7oo0goPbWoo0002Ool20004Ool20007
Ool00`00Oomoh002On3oOonHOol00005Ool007ooOol00002Ool01000Oomoo`001Woo00<007ooOn00
0WoPogooV7oo00001Goo001oogoo00000Woo00@007ooOol000Ioo`8000=oh?mooiQoo`0000Aoo`00
000000=oo`04001oogoo003oOonSOol00003Ool007oo00Aoo`04001oogoo003oOonSOol0009oo`<0
00=oo`800?moojAoo`00ogoo[Woo003oOon^Ool00?moojioo`00\
\>"],
  ImageRangeCache->{{{0, 428}, {428, 0}} -> {-2.52837, -2.41724, 0.148172, 
  0.148172}}]
}, Open  ]],

Cell[TextData[{
  "We sample 10 individuals from each of three sites.  These are on the \
y-axis, and separated by ",
  Cell[BoxData[
      \(TraditionalForm\`10 \@ 2\)]],
  ":"
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(ss = 
      SampleIndividuals[p1, {{10, 10}, {10, 30}, {10, 50}}, 10, 4, R, 6]; 
    ss // TableForm\)], "Input",
  CellLabel->"In[276]:="],

Cell[BoxData[
    TagBox[GridBox[{
          {"30154", "29731", "30123", "29977", "30143", "29817", "30080", 
            "29863", "29960", "29845"},
          {"29925", "29930", "30148", "29783", "30119", "30101", "29712", 
            "30059", "29970", "29862"},
          {"29974", "30138", "30074", "29898", "30008", "30139", "29684", 
            "29506", "30049", "30055"}
          },
        RowSpacings->1,
        ColumnSpacings->3,
        RowAlignments->Baseline,
        ColumnAlignments->{Left}],
      (TableForm[ #]&)]], "Output",
  CellLabel->"Out[276]//TableForm="]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(DisplayTogether[
      ListPlot[\(Location[p1, #]&\)/@ei, PlotStyle -> PointSize[0.002]], \n\t
      Graphics[Circle[{10, 10}, 4]], Graphics[Circle[{10, 30}, 4]], 
      Graphics[Circle[{10, 50}, 4]], \n\t
      ListPlot[\(Location[p1, #]&\)/@ss[\([1]\)], PlotStyle \[Rule] Red], \n\t
      ListPlot[\(Location[p1, #]&\)/@ss[\([2]\)], PlotStyle \[Rule] Blue], \n
      \tListPlot[\(Location[p1, #]&\)/@ss[\([3]\)], PlotStyle \[Rule] Green], 
      \n\tPlotRange \[Rule] {{0, R}, {0, R}}, AspectRatio \[Rule] 1]; \)\)], 
  "Input",
  CellLabel->"In[277]:="],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 0.0166667 0 0.0166667 [
[.16667 -0.0125 -6 -9 ]
[.16667 -0.0125 6 0 ]
[.33333 -0.0125 -6 -9 ]
[.33333 -0.0125 6 0 ]
[.5 -0.0125 -6 -9 ]
[.5 -0.0125 6 0 ]
[.66667 -0.0125 -6 -9 ]
[.66667 -0.0125 6 0 ]
[.83333 -0.0125 -6 -9 ]
[.83333 -0.0125 6 0 ]
[1 -0.0125 -6 -9 ]
[1 -0.0125 6 0 ]
[-0.0125 .16667 -12 -4.5 ]
[-0.0125 .16667 0 4.5 ]
[-0.0125 .33333 -12 -4.5 ]
[-0.0125 .33333 0 4.5 ]
[-0.0125 .5 -12 -4.5 ]
[-0.0125 .5 0 4.5 ]
[-0.0125 .66667 -12 -4.5 ]
[-0.0125 .66667 0 4.5 ]
[-0.0125 .83333 -12 -4.5 ]
[-0.0125 .83333 0 4.5 ]
[-0.0125 1 -12 -4.5 ]
[-0.0125 1 0 4.5 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.16667 0 m
.16667 .00625 L
s
[(10)] .16667 -0.0125 0 1 Mshowa
.33333 0 m
.33333 .00625 L
s
[(20)] .33333 -0.0125 0 1 Mshowa
.5 0 m
.5 .00625 L
s
[(30)] .5 -0.0125 0 1 Mshowa
.66667 0 m
.66667 .00625 L
s
[(40)] .66667 -0.0125 0 1 Mshowa
.83333 0 m
.83333 .00625 L
s
[(50)] .83333 -0.0125 0 1 Mshowa
1 0 m
1 .00625 L
s
[(60)] 1 -0.0125 0 1 Mshowa
.125 Mabswid
.03333 0 m
.03333 .00375 L
s
.06667 0 m
.06667 .00375 L
s
.1 0 m
.1 .00375 L
s
.13333 0 m
.13333 .00375 L
s
.2 0 m
.2 .00375 L
s
.23333 0 m
.23333 .00375 L
s
.26667 0 m
.26667 .00375 L
s
.3 0 m
.3 .00375 L
s
.36667 0 m
.36667 .00375 L
s
.4 0 m
.4 .00375 L
s
.43333 0 m
.43333 .00375 L
s
.46667 0 m
.46667 .00375 L
s
.53333 0 m
.53333 .00375 L
s
.56667 0 m
.56667 .00375 L
s
.6 0 m
.6 .00375 L
s
.63333 0 m
.63333 .00375 L
s
.7 0 m
.7 .00375 L
s
.73333 0 m
.73333 .00375 L
s
.76667 0 m
.76667 .00375 L
s
.8 0 m
.8 .00375 L
s
.86667 0 m
.86667 .00375 L
s
.9 0 m
.9 .00375 L
s
.93333 0 m
.93333 .00375 L
s
.96667 0 m
.96667 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .16667 m
.00625 .16667 L
s
[(10)] -0.0125 .16667 1 0 Mshowa
0 .33333 m
.00625 .33333 L
s
[(20)] -0.0125 .33333 1 0 Mshowa
0 .5 m
.00625 .5 L
s
[(30)] -0.0125 .5 1 0 Mshowa
0 .66667 m
.00625 .66667 L
s
[(40)] -0.0125 .66667 1 0 Mshowa
0 .83333 m
.00625 .83333 L
s
[(50)] -0.0125 .83333 1 0 Mshowa
0 1 m
.00625 1 L
s
[(60)] -0.0125 1 1 0 Mshowa
.125 Mabswid
0 .03333 m
.00375 .03333 L
s
0 .06667 m
.00375 .06667 L
s
0 .1 m
.00375 .1 L
s
0 .13333 m
.00375 .13333 L
s
0 .2 m
.00375 .2 L
s
0 .23333 m
.00375 .23333 L
s
0 .26667 m
.00375 .26667 L
s
0 .3 m
.00375 .3 L
s
0 .36667 m
.00375 .36667 L
s
0 .4 m
.00375 .4 L
s
0 .43333 m
.00375 .43333 L
s
0 .46667 m
.00375 .46667 L
s
0 .53333 m
.00375 .53333 L
s
0 .56667 m
.00375 .56667 L
s
0 .6 m
.00375 .6 L
s
0 .63333 m
.00375 .63333 L
s
0 .7 m
.00375 .7 L
s
0 .73333 m
.00375 .73333 L
s
0 .76667 m
.00375 .76667 L
s
0 .8 m
.00375 .8 L
s
0 .86667 m
.00375 .86667 L
s
0 .9 m
.00375 .9 L
s
0 .93333 m
.00375 .93333 L
s
0 .96667 m
.00375 .96667 L
s
.25 Mabswid
0 0 m
0 1 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
.002 w
.40165 .66665 Mdot
.40121 .47874 Mdot
.03428 .7347 Mdot
.91083 .37101 Mdot
.78364 .15992 Mdot
.1072 .61661 Mdot
.93036 .91649 Mdot
.30233 .30832 Mdot
.07441 .4604 Mdot
.31545 .64081 Mdot
.32444 .82453 Mdot
.1876 .06146 Mdot
.24196 .47656 Mdot
.78262 .00523 Mdot
.82119 .19386 Mdot
.13188 .08206 Mdot
.79412 .09634 Mdot
.03948 .39637 Mdot
.07922 .39863 Mdot
.23169 .74715 Mdot
.81329 .21571 Mdot
.03627 .05422 Mdot
.64252 .04792 Mdot
.36605 .56589 Mdot
.75878 .13818 Mdot
.8571 .87123 Mdot
.36819 .31892 Mdot
.31505 .33513 Mdot
.06286 .41225 Mdot
.29803 .33561 Mdot
.3124 .84501 Mdot
.21786 .69961 Mdot
.84427 .9016 Mdot
.1904 .41725 Mdot
.53176 .97205 Mdot
.76085 .22424 Mdot
.05077 .10055 Mdot
.74124 .07228 Mdot
.23429 .86993 Mdot
.61363 .04744 Mdot
.23367 .46892 Mdot
.24744 .66077 Mdot
.24572 .52858 Mdot
.04237 .55341 Mdot
.13823 .17802 Mdot
.00022 .01317 Mdot
.77911 .97702 Mdot
.45842 .42611 Mdot
.56344 .96879 Mdot
.0087 .99812 Mdot
.83892 .35577 Mdot
.66441 .81813 Mdot
.53359 .40334 Mdot
.19045 .43234 Mdot
.52816 .23963 Mdot
.08331 .09216 Mdot
.19322 .10976 Mdot
.23719 .72222 Mdot
.35686 .63852 Mdot
.85519 .0528 Mdot
.61404 .75544 Mdot
.81618 .89841 Mdot
.24761 .14656 Mdot
.72044 .03104 Mdot
.08097 .46202 Mdot
.84565 .20413 Mdot
.85781 .05698 Mdot
.57506 .04405 Mdot
.24594 .45584 Mdot
.21882 .14131 Mdot
.59757 .04311 Mdot
.40756 .38158 Mdot
.19813 .10237 Mdot
.31365 .82619 Mdot
.86636 .22787 Mdot
.27817 .6092 Mdot
.04479 .36768 Mdot
.45017 .42564 Mdot
.89278 .22314 Mdot
.78728 .93911 Mdot
.304 .66039 Mdot
.20551 .83962 Mdot
.03252 .57361 Mdot
.1728 .06626 Mdot
.98035 .63826 Mdot
.34364 .52825 Mdot
.7873 .91984 Mdot
.2841 .61677 Mdot
.47621 .42246 Mdot
.01063 .11544 Mdot
.01191 .48648 Mdot
.73867 .08828 Mdot
.144 .48225 Mdot
.52569 .01952 Mdot
.3064 .08268 Mdot
.14764 .5533 Mdot
.87839 .2545 Mdot
.02483 .39166 Mdot
.9619 .5225 Mdot
.03431 .06808 Mdot
.29714 .72163 Mdot
.9005 .88105 Mdot
.30262 .52775 Mdot
.93082 .39452 Mdot
.00301 .57763 Mdot
.18478 .10108 Mdot
.31423 .7185 Mdot
.1956 .69291 Mdot
.35813 .5737 Mdot
.11243 .44955 Mdot
.82839 .35541 Mdot
.13339 .80564 Mdot
.31955 .69922 Mdot
.30931 .8314 Mdot
.17748 .08658 Mdot
.94502 .39613 Mdot
.99266 .56297 Mdot
.39075 .58423 Mdot
.79581 .10339 Mdot
.27644 .50852 Mdot
.50766 .39185 Mdot
.74992 .95152 Mdot
.36056 .49733 Mdot
.04274 .7608 Mdot
.27684 .6405 Mdot
.50288 .41383 Mdot
.36507 .55054 Mdot
.09891 .37446 Mdot
.21532 .75729 Mdot
.7222 .12189 Mdot
.0541 .11202 Mdot
.3642 .48011 Mdot
.78436 .37069 Mdot
.39769 .27221 Mdot
.36702 .59514 Mdot
.30815 .30645 Mdot
.89482 .25424 Mdot
.9321 .8857 Mdot
.41694 .6342 Mdot
.98583 .58684 Mdot
.68783 .11559 Mdot
.35547 .48702 Mdot
.06136 .17416 Mdot
.80847 .16505 Mdot
.20209 .74638 Mdot
.80137 .97689 Mdot
.51435 .98659 Mdot
.15252 .74208 Mdot
.02345 .0536 Mdot
.13771 .51761 Mdot
.61674 .73685 Mdot
.95016 .52132 Mdot
.81025 .17586 Mdot
.73316 .13374 Mdot
.39753 .47251 Mdot
.97386 .62507 Mdot
.0351 .1498 Mdot
.75345 .97319 Mdot
.18218 .8387 Mdot
.69747 .11455 Mdot
.27735 .53485 Mdot
.22595 .12546 Mdot
.18829 .14906 Mdot
.21074 .75895 Mdot
.87358 .09178 Mdot
.21345 .69794 Mdot
.31898 .4401 Mdot
.32687 .29562 Mdot
.4103 .48876 Mdot
.33179 .82356 Mdot
.59448 .10489 Mdot
.03214 .39392 Mdot
.29469 .31193 Mdot
.34034 .84894 Mdot
.58309 .05911 Mdot
.85666 .18146 Mdot
.73315 .08083 Mdot
.33659 .80673 Mdot
.19118 .43932 Mdot
.31395 .50411 Mdot
.06127 .19281 Mdot
.31848 .24946 Mdot
.04421 .70214 Mdot
.35091 .47669 Mdot
.30528 .80072 Mdot
.03539 .60192 Mdot
.24089 .68409 Mdot
.52559 .27989 Mdot
.88596 .90923 Mdot
.10379 .40791 Mdot
.82457 .07045 Mdot
.23191 .22827 Mdot
.26614 .5307 Mdot
.32162 .24897 Mdot
.0288 .40403 Mdot
.12633 .51909 Mdot
.28724 .61589 Mdot
.82798 .18991 Mdot
.32347 .79392 Mdot
.19913 .13303 Mdot
.40428 .40252 Mdot
.29561 .85093 Mdot
.54365 .23647 Mdot
.55287 .03363 Mdot
.95933 .59191 Mdot
.31877 .83649 Mdot
.16073 .07059 Mdot
.12926 .59468 Mdot
.01948 .11505 Mdot
.33615 .59084 Mdot
.43045 .42954 Mdot
.19863 .84696 Mdot
.21316 .81805 Mdot
.27945 .73212 Mdot
.19617 .13275 Mdot
.80018 .08982 Mdot
.98711 .58667 Mdot
.3041 .51467 Mdot
.16453 .46845 Mdot
.216 .21574 Mdot
.06244 .19189 Mdot
.52524 .28046 Mdot
.08026 .40546 Mdot
.31535 .65727 Mdot
.22892 .14455 Mdot
.29978 .34148 Mdot
.06301 .08025 Mdot
.71794 .14005 Mdot
.31664 .28928 Mdot
.81898 .15719 Mdot
.5823 .05768 Mdot
.0585 .71058 Mdot
.51611 .99015 Mdot
.36817 .59656 Mdot
.02669 .52934 Mdot
.06549 .15182 Mdot
.75198 .94559 Mdot
.06947 .6872 Mdot
.86325 .19946 Mdot
.67316 .84241 Mdot
.5 Mabswid
newpath
.16667 .16667 .06667 0 365.73 arc
s
newpath
.16667 .5 .06667 0 365.73 arc
s
newpath
.16667 .83333 .06667 0 365.73 arc
s
1 0 0 r
.008 w
.22892 .14455 Mdot
.13823 .17802 Mdot
.19913 .13303 Mdot
.17748 .08658 Mdot
.19617 .13275 Mdot
.19322 .10976 Mdot
.18829 .14906 Mdot
.21882 .14131 Mdot
.18478 .10108 Mdot
.24761 .14656 Mdot
0 0 1 r
.144 .48225 Mdot
.14764 .5533 Mdot
.16453 .46845 Mdot
.19045 .43234 Mdot
.12633 .51909 Mdot
.19118 .43932 Mdot
.24572 .52858 Mdot
.13771 .51761 Mdot
.11243 .44955 Mdot
.24594 .45584 Mdot
0 1 0 r
.13339 .80564 Mdot
.19863 .84696 Mdot
.18218 .8387 Mdot
.20551 .83962 Mdot
.21532 .75729 Mdot
.21316 .81805 Mdot
.23429 .86993 Mdot
.23169 .74715 Mdot
.20209 .74638 Mdot
.15252 .74208 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[277]:=",
  ImageSize->{288, 288},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P000181000`40O003h00Oogoo8Goo003oOolQ
Ool00?moob5oo`00ogoo8Goo003oOolQOol003Ioo`<000Aoo`8002=oo`@000=oo`8002Aoo`<000Ao
o`8002Aoo`<000=oo`8002=oo`<000Aoo`8002Eoo`8000Aoo`8000=oo`00=goo00<007ooOol00Woo
00@007ooOol002=oo`03001oogoo009oo`04001oogoo000VOol01000Oomoo`000Woo00<007ooOol0
8Woo00D007ooOomoo`00009oo`03001oogoo02=oo`04001oogoo0002Ool00`00Oomoo`0QOol01000
Oomoo`000Woo00@007ooOol0009oo`00=goo00<007ooOol00Woo00@007ooOol002Aoo`05001oogoo
Ool00002Ool00`00Oomoo`0TOol01000Oomoo`000Woo00<007ooOol087oo10000Woo00@007ooOol0
02Eoo`04001oogoo0002Ool00`00Oomoo`0QOol01000Oomoo`000Woo00@007ooOol0009oo`00=goo
00<007ooOol00Woo00@007ooOol002Eoo`04001oogoo0002Ool00`00Oomoo`0ROol20003Ool01000
Oomoo`008Woo00<007oo00000goo00@007ooOol0029oo`<000=oo`04001oogoo000SOol30003Ool0
1000Oomoo`000Woo000gOol00`00Oomoo`02Ool01000Oomoo`008Woo00@007ooOol0009oo`04001o
ogoo000VOol01000Oomoo`000Woo00<007ooOol087oo00<007oo00000goo00@007ooOol0029oo`03
001oogoo00=oo`04001oogoo000SOol00`00Oomoo`03Ool01000Oomoo`000Woo000fOol20005Ool2
000TOol20004Ool2000TOol30004Ool2000TOol20004Ool2000SOol40003Ool2000UOol30003Ool2
0003Ool00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`003gooo`0030001Woo000?Ool00`00
Oomoo`06Ool00`00Oomoo`06Ool00`00Oomoo`05Ool00`00Oomoo`06Ool00`00Oomoo`06Ool00`00
Oomoo`06Ool00`00Oomoo`06Ool00`00Oomoo`06Ool00`00Oomoo`06Ool00`00Oomoo`05Ool00`00
Oomoo`06Ool00`00Oomoo`06Ool00`00Oomoo`06Ool00`00Oomoo`06Ool00`00Oomoo`06Ool00`00
Oomoo`06Ool00`00Oomoo`05Ool00`00Oomoo`06Ool00`00Oomoo`06Ool00`00Oomoo`06Ool00`00
Oomoo`06Ool00`00Oomoo`06Ool00`00Oomoo`06Ool01@00Oomoogoo00000goo00<007ooOol01Woo
00<007ooOol01Woo00<007ooOol01Woo00<007ooOol01Woo00<007ooOol01Woo00<007ooOol01Woo
00<007ooOol017oo000?Ool00`00Oomoo`0YOol00`00Oomoo`0YOol00`00Oomoo`0ZOol00`00Oomo
o`0YOol00`00Oomoo`0YOol00`00Oomoo`0ZOol00`00Oomoo`04Ool000moo`03001oogoo0?moo`mo
o`003goo00<007ooOol0ogoo3goo000?Ool00`00Oomoo`29Ool00`00Oomoo`22Ool000moo`03001o
ogoo0?moo`moo`003goo00<007ooOol0ogoo3goo000?Ool00`00Oomoo`2lOol00`00Oomoo`1?Ool0
00moo`80095oo`03001oogoo07]oo`003goo00<007ooOol0ogoo3goo000?Ool00`00Oomoo`2LOol0
0`00Oomoo`1_Ool000moo`03001oogoo09Ioo`03001oogoo00Moo`03001oogoo06]oo`003goo00<0
07ooOol0Z7oo00<007ooOol0Hgoo000?Ool00`00Oomoo`03Ool01@00Oomoogoo0000f7oo00<007oo
Ool0:goo000?Ool00`00Oomoo`2HOol00`00Oomoo`16Ool00`00Oomoo`0ZOol000moo`03001oogoo
02moo`03001oogoo06Ioo`03001oogoo07=oo`003goo00<007ooOol0:goo00<007ooOol0h7oo000?
Ool20007Ool00`00Oomoo`3oOol6Ool000moo`03001oogoo02Qoo`03001oogoo09Moo`03001oogoo
01=oo`03001oogoo03=oo`003goo00<007ooOol0ogoo3goo000?Ool00`00Oomoo`0>Ool00`00Oomo
o`2_Ool00`00Oomoo`1;Ool000moo`03001oogoo021oo`03001oogoo02]oo`03001oogoo0;eoo`00
3goo00<007ooOol0:goo0W`0U7oo00<007ooOol0BWoo000?Ool00`00Oomoo`0COol00`00Oomoo`0E
Ool2O02UOol00`00Oomoo`0@Ool00`00Oomoo`0VOol000moo`03001oogoo0=1oo`03001oogoo03]o
o`003goo00<007ooOol0;Goo0W`0ggoo000?Ool2000<Ool00`00Oomoo`0FOol90002O0001000Oomo
o`00WWoo00<007ooOol0>Woo000?Ool00`00Oomoo`0QOol3000<Ool00`00Oomoo`1XOol00`00Oomo
o`1`Ool000moo`03001oogoo01moo`8000moo`9l0003001oogoo0=Uoo`003goo00H007ooOol007oo
0008Ool00`00Oomoo`0@Ool00`00Oomoo`0?Ool2O0000goo001oo`21Ool00`00Oomoo`1EOol000mo
o`03001oogoo01eoo`03001oogoo01Aoo`8007ioo`03001oogoo05Moo`003goo00<007ooOol07Goo
00<007ooOol05Woo00<007ooOol0Q7oo00<007ooOol0CWoo000?Ool00`00Oomoo`0LOol00`00Oomo
o`0HOol00`00Ool0003DOol000moo`03001oogoo01]oo`03001oogoo01Uoo`03001oogoo0=Aoo`00
3goo0P006goo00<007ooOol04goo0g`01Goo00<007ooOol0QGoo00<007ooOol0Bgoo000?Ool00`00
Oomoo`0JOol00`00Oomoo`0COol3O006Ool00`00Oomoo`3BOol000moo`03001oogoo01Uoo`03001o
ogoo01Yoo`9l0003Ool007oo085oo`03001oogoo00Qoo`03001oogoo04Aoo`003goo00<007ooOol0
67oo00<007ooOol06goo0W`000=oog`0O000dgoo000?Ool00`00Oomoo`0HOol00`00Oomoo`0COol2
O009Ool2O003Ool2O03>Ool000moo`03001oogoo00Ioo`03001oogoo00Eoo`03001oogoo00Moo`03
001oogoo01=oo`9l00Yoo`04001oogooOol2O03>Ool000moo`03001oogoo01Qoo`03001oogoo01mo
o`03001oogoo0=5oo`0000Aoo`00000000Aoo`8000Eoo`03001oogoo01Qoo`03001oogoo01moo`03
001oogoo091oo`03001oogoo00Moo`03001oogoo03Aoo`000Woo00<007ooOol00Woo00@007ooOol0
00Aoo`03001oogoo01Moo`03001oogoo025oo`03001oogoo0=1oo`000Woo00<007ooOol00Woo00@0
07ooOol000Aoo`8001Qoo`03001oogoo025oo`03001oogoo09Ioo`03001oogoo03Moo`000Woo00<0
07ooOol00Woo00@007ooOol000Aoo`03001oogoo01Moo`03001oogoo025oo`03001oogoo0=1oo`00
0Woo00<007ooOol00Woo00@007ooOol000Aoo`03001oogoo00eoo`03001oogoo00Moo`03001oogoo
025oo`03001oogoo0=1oo`0000=oo`0000001Goo0P001Goo00<007ooOol067oo00<007ooOol01Woo
0W`067oo00<007ooOol0UWoo00<007ooOol0=goo000?Ool00`00Oomoo`0HOol00`00Oomoo`06Ool2
O00GOol00`00Oomoo`2TOol00`00Oomoo`0ZOol000moo`03001oogoo01Qoo`03001oogoo01moo`03
001oogoo0=5oo`003goo00<007ooOol067oo00<007ooOol07goo00<007ooOol0W7oo00<007ooOol0
<Woo000?Ool00`00Oomoo`0=Ool20009Ool00`00Oomoo`0NOol00`00Oomoo`2KOol00`00Oomoo`0d
Ool000moo`03001oogoo01Uoo`03001oogoo01eoo`03001oogoo0=9oo`003goo0P006Woo00<007oo
Ool07Goo00<007ooOol0YWoo00<007ooOol0:Goo000?Ool00`00Oomoo`0JOol00`00Oomoo`0KOol0
0`00Oomoo`2SOol00`00Oomoo`0]Ool000moo`03001oogoo01]oo`03001oogoo01Uoo`03001oogoo
0=Aoo`003goo00<007ooOol077oo00<007ooOol05goo00<007ooOol0eGoo000?Ool00`00Oomoo`0M
Ool00`00Oomoo`0EOol2002NOol00`00Oomoo`0fOol000moo`03001oogoo01ioo`03001oogoo01=o
o`03001oogoo0=Moo`003goo00<007ooOol07goo00<007ooOol047oo0P00Tgoo00<007ooOol087oo
00<007ooOol08Goo000?Ool00`00Oomoo`0POol3000>Ool00`00Oomoo`07Ool00`00Oomoo`2UOol0
0`00Oomoo`0XOol000moo`03001oogoo02=oo`8000Qoo`@00=eoo`003goo0P009Woo2000hGoo000?
Ool00`00Oomoo`29Ool00`00Oomoo`02Ool00`00Oomoo`1mOol000moo`03001oogoo0?moo`moo`00
3goo00<007ooOol0ogoo3goo000?Ool00`00Oomoo`1BOol2002jOol000moo`03001oogoo0>Ioo`03
001oogoo009oo`03001oogoo021oo`003goo00<007ooOol0ogoo3goo000?Ool00`00Oomoo`3oOol?
Ool000moo`03001oogoo0?moo`moo`003goo0P00ogoo47oo000?Ool00`00Oomoo`1WOol00`00Oomo
o`2TOol000moo`03001oogoo0?moo`moo`003goo00<007ooOol0RGoo00<007ooOol0PWoo000?Ool0
0`00Oomoo`3oOol?Ool000moo`03001oogoo0?moo`moo`003goo00<007ooOol0DGoo00<007ooOol0
^Woo000?Ool00`00Oomoo`1DOol00`00Oomoo`2gOol000moo`03001oogoo0?moo`moo`003goo0P00
ogoo47oo000?Ool00`00Oomoo`1?Ool00`00Oomoo`2lOol000moo`03001oogoo04eoo`03001oogoo
0;ioo`003goo00<007ooOol0Bgoo00<007ooOol0`7oo000?Ool00`00Oomoo`3oOol?Ool000moo`03
001oogoo05moo`03001oogoo0:aoo`003goo00<007ooOol0ogoo3goo00000goo000000020003Ool2
0005Ool00`00Oomoo`3oOol?Ool0009oo`03001oogoo009oo`04001oogoo0004Ool00`00Oomoo`3o
Ool?Ool000=oo`05001oogooOol00002Ool00`00Oomoo`02Ool2001=Ool00`00Oomoo`02Ool00`00
Oomoo`2jOol000Aoo`04001oogoo0002Ool00`00Oomoo`02Ool00`00Oomoo`3oOol?Ool00005Ool0
07ooOol00002Ool01000Oomoo`0017oo00<007ooOol0CGoo00<007ooOol0_Woo0002Ool20004Ool2
0005Ool00`00Oomoo`3oOol?Ool000moo`03001oogoo0?moo`moo`003goo00<007ooOol0fGoo00@0
07ooOol0035oo`003goo00<007ooOol0ogoo3goo000?Ool00`00Oomoo`3oOol?Ool000moo`800?mo
oa1oo`003goo00<007ooOol02Goo00<007ooOol0`Goo00<007ooOol07goo00<007ooOol077oo000?
Ool00`00Oomoo`0GOol00`00Oomoo`3dOol000moo`03001oogoo0?moo`moo`003goo00<007ooOol0
JGoo00<007ooOol0XWoo000?Ool00`00Oomoo`3oOol?Ool000moo`03001oogoo0?moo`moo`003goo
00<007ooOol017oo00<007oo0000OGoo00<007ooOol0Qgoo000?Ool00`00Oomoo`08Ool00`00Oomo
o`3YOol01@00Oomoogoo00005Goo000?Ool2000COol00`00Oomoo`3iOol000moo`03001oogoo00Eo
o`03001oogoo061oo`03001oogoo021oo`03001oogoo081oo`003goo00<007ooOol04Woo00<007oo
Ool017oo00<007ooOol0lWoo000?Ool00`00Oomoo`0>Ool00`00Oomoo`3mOol000moo`03001oogoo
08=oo`03001oogoo08Qoo`003goo00<007ooOol0<7oo00<007ooOol0fgoo000?Ool00`00Oomoo`1l
Ool00`00Oomoo`2?Ool000moo`03001oogoo07Eoo`03001oo`0009Ioo`003goo00<007ooOol0;goo
0P0O?Woo00<007ooOol0W7oo000?Ool2000WOol800000goo01l07`3MOol000moo`03001oogoo02=o
o`<000Qoo`0300007`0O0=eoo`003goo00<007ooOol08Goo0P0037oo0P0O0P007goo00<007ooOol0
^Goo000?Ool00`00Oomoo`0OOol2000BOol00`00Oomoo`3HOol000moo`03001oogoo01Yoo`807`9o
o`03001oogoo01=oo`03001oogoo0=Moo`003goo00<007ooOol06Woo0P0O00=oo`00Ool05Woo00<0
07ooOol0eWoo000?Ool00`00Oomoo`0LOol00`00Oomoo`0GOol00`00Oomoo`05Ool201o>Ool000mo
o`03001oogoo015oo`03001oogoo00Moo`03001oogoo01Uoo`03001oogoo00Aoo`807lioo`003goo
00<007ooOol04goo00<007ooOol01Goo00<007ooOol06Woo00<007ooOol0dgoo000?Ool2000KOol0
0`00Oomoo`0;Ool201l?Ool00`00Ool0003BOol000moo`03001oogoo01Uoo`03001oogoo00aoo`80
7`moo`03001oogoo02]oo`03001oogoo0:Aoo`003goo00<007ooOol06Goo00<007ooOol07Goo00D0
07ooOomoo`0001aoo`03001oogoo0;5oo`003goo00<007ooOol067oo00<007ooOol07Woo00<007oo
Ool08Woo00<007ooOol01goo00<007ooOol0Xgoo000?Ool00`00Oomoo`0HOol00`00Oomoo`08Ool2
01lEOol00`00Oomoo`3AOol000moo`04001oogoo000GOol00`00Oomoo`08Ool201lEOol00`00Oomo
o`0OOol00`00Oomoo`2_Ool000moo`03001oogoo01Qoo`03001oogoo01moo`03001oogoo02eoo`03
001oogoo0:5oo`0000Aoo`00000000Aoo`8000Eoo`03001oogoo01Qoo`03001oogoo021oo`03001o
ogoo0=1oo`0017oo00@007ooOol0009oo`03001oogoo009oo`03001oogoo01Moo`03001oogoo025o
o`03001oogoo01moo`03001oogoo0:ioo`0017oo00@007ooOol0009oo`03001oogoo009oo`8001Qo
o`03001oogoo025oo`03001oogoo0=1oo`000Woo0P000goo00@007ooOol000Aoo`03001oogoo01Mo
o`03001oogoo025oo`03001oogoo019oo`03001oogoo0;]oo`0017oo00@007ooOol0009oo`03001o
ogoo009oo`03001oogoo01Moo`03001oogoo025oo`03001oogoo00Uoo`03001oogoo0<Aoo`0000Ao
o`00000000Aoo`8000Eoo`03001oogoo01Qoo`03001oogoo01moo`03001oogoo0=5oo`003goo00<0
07ooOol067oo00<007ooOol01Woo0P0O5goo00<007ooOol04Goo00<007ooOol0_Goo000?Ool00`00
Oomoo`0HOol00`00Oomoo`03Ool201l00goo01l07`0GOol00`00Oomoo`2mOol00`00Oomoo`0AOol0
00moo`03001oogoo01Qoo`03001oogoo00=oo`807aYoo`03001oogoo0<1oo`03001oogoo00ioo`00
3goo00<007ooOol017oo00<007ooOol04Goo00<007ooOol07Woo00<007ooOol00Woo0P0O3Goo00<0
07ooOol027oo00<007ooOol0/goo000?Ool00`00Oomoo`0IOol00`00Oomoo`0MOol00`00Oomoo`02
Ool201l4Ool00`00Oomoo`37Ool000moo`8001]oo`03001oogoo01aoo`03001oogoo00]oo`03001o
ogoo0<Aoo`003goo00<007ooOol06Woo00<007ooOol06goo00<007ooOol0dgoo000?Ool00`00Oomo
o`0KOol00`00Oomoo`0IOol00`00Oomoo`3DOol000moo`03001oogoo01aoo`8001Qoo`03001oogoo
0=Eoo`003goo00<007ooOol07Woo00<007ooOol057oo00<007ooOol09Woo00<007ooOol0[Goo000?
Ool00`00Oomoo`08Ool00`00Oomoo`0DOol01000Oomoogoo0P0O3goo00<007ooOol0egoo000?Ool0
0`00Oomoo`0POol200000goo01l07`0=Ool2003JOol000moo`03001oogoo029oo`03001oogoo00Yo
o`<00==oo`03001oogoo00Ioo`003goo00<007ooOol08goo1P000Woo1000;goo00<007ooOol0[Goo
000?Ool2000ZOol2003SOol000moo`03001oogoo00Ioo`03001oogoo05=oo`03001oogoo0:moo`00
3goo0P00ogoo47oo000?Ool00`00Oomoo`3oOol?Ool000moo`03001oogoo06Eoo`03001oogoo0:Io
o`003goo00<007ooOol0ogoo17oo00<007ooOol027oo000?Ool00`00Oomoo`1FOol00`00Oomoo`2S
Ool00`00Oomoo`0?Ool000moo`03001oogoo01moo`03001oogoo03eoo`03001oogoo0:aoo`003goo
0P00ogoo47oo000?Ool00`00Oomoo`06Ool00`00Oomoo`3oOol6Ool000moo`03001oogoo0?moo`mo
o`003goo00<007ooOol0Agoo00<007ooOol0a7oo000?Ool00`00Oomoo`19Ool00`00Oomoo`32Ool0
00moo`03001oogoo01Yoo`03001oogoo02aoo`03001oogoo0<9oo`003goo00<007ooOol0ogoo3goo
000?Ool00`00Oomoo`3oOol1Ool00`00Oomoo`0;Ool000moo`03001oogoo0?moo`moo`003goo0P00
KGoo00<007ooOol0Wgoo000?Ool00`00Oomoo`1LOol00`00Oomoo`2SOol00`00Oomoo`09Ool000mo
o`03001oogoo04Moo`03001oogoo00Moo`03001oogoo0;Yoo`003goo00<007ooOol0ogoo3goo000?
Ool00`00Oomoo`3oOol?Ool000moo`03001oogoo0?moo`moo`003goo00<007ooOol0DGoo00<007oo
Ool0^Woo0002Ool30003Ool20005Ool00`00Oomoo`0oOol00`00Oomoo`0<Ool00`00Oomoo`2mOol0
00=oo`05001oogooOol00002Ool00`00Oomoo`02Ool00`00Oomoo`3oOol?Ool00003Ool000000080
009oo`04001oogoo0004Ool2001YOol00`00Oomoo`2SOol00004Ool007oo0003Ool01000Oomoo`00
17oo00<007ooOol0ogoo3goo000017oo001oo`000goo00@007ooOol000Aoo`03001oogoo0?moo`mo
o`000Woo0P0017oo0P001Goo00<007ooOol0ogoo3goo000?Ool00`00Oomoo`3oOol?Ool000moo`03
001oogoo011oo`03001oogoo02Yoo`03001oogoo0<ioo`003goo00<007ooOol0ogoo3goo000?Ool0
0`00Oomoo`0aOol00`00Oomoo`3JOol000moo`03001oogoo03Ioo`03001oogoo0=Eoo`003goo0P00
2Woo00<007ooOol0:goo00<007ooOol067oo00<007ooOol0^Goo000?Ool00`00Oomoo`3oOol?Ool0
00moo`03001oogoo0?moo`moo`003goo00<007ooOol03Goo00<007ooOol0oWoo000?Ool00`00Oomo
o`3oOol?Ool000moo`03001oogoo055oo`03001oogoo0;Yoo`003goo00<007ooOol0?7oo00<007oo
Ool03Goo00<007ooOol0_goo000?Ool00`00Oomoo`3oOol?Ool000moo`03001oogoo04Moo`03001o
ogoo0<Aoo`003goo0P001goo00<007ooOol0ogoo1Woo000?Ool00`00Oomoo`2QOol00`00Oomoo`1Z
Ool000moo`03001oogoo02Eoo`83h>Moo`003goo00<007ooOol09Goo0P?P2goo0P?P1Woo0P?PdWoo
000?Ool00`00Oomoo`0bOol20n06Ool20n3BOol000moo`03001oogoo0?moo`moo`003goo00<007oo
Ool0=Goo0P?PJGoo00<007ooOol0Jgoo000?Ool00`00Oomoo`08Ool00`00Oomoo`0ZOol20n3GOol0
00moo`03001oogoo0?moo`moo`003goo0P009Goo3000gWoo000?Ool00`00Oomoo`0QOol3000<Ool0
0`00Oomoo`3KOol000moo`03001oogoo01moo`80011oo`800=]oo`003goo00<007ooOol07Woo00<0
07ooOol04Woo00<007ooOol0f7oo000?Ool00`00Oomoo`0MOol00`00Oomoo`0DOol2003HOol000mo
o`03001oogoo01eoo`03001oogoo01Ioo`03001oogoo0=Eoo`003goo00<007ooOol077oo00<007oo
Ool067oo00<007ooOol0e7oo000?Ool00`00Oomoo`0KOol00`00Oomoo`0IOol00`00Oomoo`0IOol0
0`00Oomoo`2hOol000moo`03001oogoo01Yoo`03001oogoo01]oo`03001oogoo0==oo`003goo0P00
6goo00<007ooOol077oo00<007ooOol04Woo00<007ooOol0_Goo000?Ool00`00Oomoo`0IOol00`00
Oomoo`04Ool20n0GOol00`00Oomoo`0JOol00`00Oomoo`2eOol000moo`03001oogoo01Qoo`03001o
ogoo00Eoo`83h1Moo`03001oogoo0=9oo`003goo00<007ooOol067oo00<007ooOol07goo00<007oo
Ool0dGoo000?Ool00`00Oomoo`0HOol00`00Oomoo`0JOol20n03Ool00`00Oomoo`1aOol00`00Oomo
o`1MOol000moo`03001oogoo01Qoo`03001oogoo01Yoo`83h0=oo`03001oogoo0=5oo`0000Aoo`00
000000Aoo`8000Eoo`03001oogoo01Qoo`03001oogoo01moo`03001oogoo01=oo`06001oogoo001o
o`00^7oo0004Ool01000Oomoo`000Woo00<007ooOol00Woo00<007ooOol067oo00<007ooOol087oo
00<007ooOol0d7oo0004Ool01000Oomoo`000Woo00<007ooOol00Woo0P0067oo00<007ooOol08Goo
00<007ooOol04Goo00<007ooOol0_7oo000017oo000000000goo00@007ooOol000Aoo`03001oogoo
01Moo`03001oogoo01=oo`83h0aoo`03001oogoo01Aoo`03001oogoo0;Uoo`0000=oo`00Ool017oo
00@007ooOol000Aoo`03001oogoo01Moo`03001oogoo01=oo`83h0Aoo`83h0Ioo`03001oogoo0=1o
o`0000=oo`0000000P000goo0P001Goo00<007ooOol067oo00<007ooOol067oo0P?P1Woo00<007oo
Ool04Woo00<007ooOol0GGoo00<007ooOol0Fgoo000?Ool00`00Oomoo`0HOol00`00Oomoo`0FOol2
0n07Ool00`00Oomoo`0JOol00`00Oomoo`2dOol000moo`03001oogoo01Qoo`03001oogoo01Ioo`83
h0Moo`03001oogoo00moo`03001oogoo0;moo`003goo00<007ooOol067oo00<007ooOol07goo00<0
07ooOol0dGoo000?Ool00`00Oomoo`0HOol00`00Oomoo`0NOol00`00Oomoo`3BOol000moo`03001o
ogoo01Uoo`03001oogoo01eoo`03001oogoo0=9oo`003goo0P006Woo00<007ooOol07Goo00<007oo
Ool0dWoo000?Ool00`00Oomoo`0JOol00`00Oomoo`0KOol00`00Oomoo`020n2TOol00`00Oomoo`0Z
Ool000moo`03001oogoo01Yoo`03001oogoo01Yoo`04001oogooOol20n3AOol000moo`03001oogoo
01]oo`03001oogoo01Qoo`03001oogoo0=Eoo`003goo00<007ooOol077oo0P005goo00<007ooOol0
]7oo00<007ooOol07goo000?Ool00`00Oomoo`0NOol00`00Oomoo`0COol00`00Oomoo`2nOol00`00
Oomoo`0FOol000moo`03001oogoo01moo`03001oogoo011oo`800=Yoo`003goo00<007ooOol087oo
0P003goo00<007ooOol0fWoo000?Ool00`00Oomoo`0ROol3000:Ool2003MOol000moo`8002Ioo`X0
0:Moo`03001oogoo00Aoo`03001oogoo02ioo`003goo00<007ooOol0ogoo3goo000?Ool00`00Oomo
o`3XOol00`00Oomoo`0SOol000moo`03001oogoo0?moo`moo`003goo00<007ooOol0m7oo00<007oo
Ool05goo000?Ool00`00Oomoo`3>Ool00`00Oomoo`0mOol000moo`03001oogoo0?moo`moo`003goo
00<007ooOol0ogoo3goo000?Ool00`00Oomoo`3oOol?Ool000moo`800?mooa1oo`003goo00<007oo
Ool0cWoo00<007ooOol0?Goo000?Ool00`00Oomoo`3oOol?Ool000moo`03001oogoo0<Eoo`03001o
ogoo04Ioo`003goo00<007ooOol0ogoo3goo000?Ool00`00Oomoo`34Ool00`00Oomoo`17Ool000mo
o`03001oogoo0?moo`moo`003goo00<007ooOol0ogoo3goo000?Ool00`00Oomoo`3oOol?Ool000mo
o`8009Aoo`03001oogoo07Qoo`003goo00<007ooOol0RWoo00<007ooOol0>7oo00<007ooOol0AWoo
000?Ool00`00Oomoo`3<Ool00`00Oomoo`03Ool00`00Oomoo`0iOol000moo`03001oogoo0?moo`mo
o`003goo00<007ooOol0ogoo3goo000?Ool00`00Oomoo`26Ool00`00Oomoo`25Ool000moo`03001o
ogoo08Ioo`03001oogoo08Eoo`000Woo0P0017oo0P001Goo00<007ooOol0ogoo3goo00001Goo001o
ogoo00000Woo00@007ooOol000Aoo`03001oo`000?moo`moo`0000Eoo`00Oomoo`00009oo`04001o
ogoo0004Ool2003oOol@Ool00004Ool000000003Ool01000Oomoo`00ogoo5Woo00000goo001oo`04
Ool01000Oomoo`00ogoo5Woo0002Ool30003Ool2003oOolGOol00?moob5oo`00ogoo8Goo003oOolQ
Ool00001\
\>"],
  ImageRangeCache->{{{0, 287}, {287, 0}} -> {-3.46036, -3.29098, 0.225838, 
  0.225838}}]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    \(bt = 
      Table[Sum[
            \((mrca = 
                MostRecentCommonAncestor[p1, 
                  ss\[LeftDoubleBracket]k, i\[RightDoubleBracket], 
                  ss\[LeftDoubleBracket]l, j\[RightDoubleBracket]]; 
              If[mrca == 0, 0, BirthTime[p1, mrca]])\), {j, 2, 10}, {i, 
              j - 1}]/\((10*9/2)\), {l, 1, 3}, {k, l}]; bt // TableForm\)], 
  "Input",
  CellLabel->"In[270]:="],

Cell[BoxData[
    InterpretationBox[GridBox[{
          {"35.7055407233387223`", "\<\"\"\>", "\<\"\"\>"},
          {"0", "44.226559274271997`", "\<\"\"\>"},
          {"0", "0", "56.4066022783731391`"}
          },
        RowSpacings->1,
        ColumnSpacings->3,
        RowAlignments->Baseline,
        ColumnAlignments->{Left}],
      TableForm[ {{35.705540723338721}, {0, 44.226559274271999}, {0, 0, 
        56.406602278373136}}]]], "Output",
  CellLabel->"Out[270]//TableForm="]
}, Open  ]],

Cell["\<\
This is the genealogy connecting all the sampled individuals:\
\>", 
  "Text"],

Cell[BoxData[
    \(tr = 
      MakeGenealogy[p1, ss // Flatten, 
        NodeFunction \[Rule] \(({BirthTime[p1, #]}&)\)]\)], "Input",
  CellLabel->"In[219]:="],

Cell[TextData[{
  "Note that the brackets around the function ({BirthTime[p1,#]}&) are \
essential for ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " to interpret the input correctly."
}], "Text"],

Cell[TextData[{
  "This plots the genealogy, with the vertical axis proportional to the birth \
time.  NodeFunction\[Rule]({#2\[LeftDoubleBracket]-1,1\[RightDoubleBracket],5-\
#2\[LeftDoubleBracket]1\[RightDoubleBracket]/20}&) takes the ",
  Cell[BoxData[
      \(TraditionalForm\`x\)]],
  " coordinate from the last element of the information list (which is \
internally generated by PlotGenealogy[]), and the ",
  Cell[BoxData[
      \(TraditionalForm\`y\)]],
  " coordinate from the first element, which is the birth time.  A linear \
transformation (5-t/20) is chosen to give an appropriate vertical scale:"
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(Show[
      PlotGenealogy[tr, LeafLabels \[Rule] None, NodeLabels \[Rule] None, 
        NodeFunction \[Rule] 
          \(({#2\[LeftDoubleBracket]\(-1\), 1\[RightDoubleBracket], 
                5 - #2\[LeftDoubleBracket]1\[RightDoubleBracket]/20}&)\)]]; 
    \)\)], "Input",
  CellLabel->"In[59]:="],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0909091 0.0909091 0.0882906 0.0882906 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
0 g
.5 Mabswid
[ ] 0 setdash
.5 .52974 m
.18182 .18699 L
s
.5 .52974 m
.63636 .45921 L
s
.63636 .45921 m
.45455 .1773 L
s
.63636 .45921 m
.77273 .28454 L
s
.77273 .28454 m
.63636 .1107 L
s
.77273 .28454 m
.81818 .22063 L
s
.81818 .22063 m
.72727 .1094 L
s
.81818 .22063 m
.86364 .1429 L
s
.18182 .18699 m
.13636 .13055 L
s
.18182 .18699 m
.27273 .10938 L
s
.45455 .1773 m
.36364 .11428 L
s
.45455 .1773 m
.5 .16774 L
s
.5 .16774 m
.45455 .11058 L
s
.5 .16774 m
.54545 .1073 L
s
.86364 .1429 m
.81818 .10905 L
s
.86364 .1429 m
.90909 .10752 L
s
.13636 .13055 m
.09091 .11554 L
s
.13636 .13055 m
.18182 .10713 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[59]:=",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/A000`40O003h00Oogoo8Goo003oOolQ
Ool00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00
ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQ
Ool00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00
ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00<goo0P00Igoo00<0
07ooOol0I7oo0P006goo000aOol2000JOol2000cOol00`00Oomoo`0GOol00`00Oomoo`0GOol00`00
Oomoo`0GOol00`00Oomoo`0GOol2000FOol00`00Oomoo`0KOol002moo`8001]oo`03001oogoo01Uo
o`8001Qoo`03001oogoo01Ioo`03001oogoo01Qoo`03001oogoo01Moo`03001oogoo01Uoo`03001o
ogoo019oo`03001oogoo01aoo`006Woo0`0047oo0P0077oo00<007ooOol077oo00<007ooOol05Woo
00<007ooOol057oo00<007ooOol06Woo00<007ooOol05goo00<007ooOol06Goo0P0047oo0P007goo
000MOol3000<Ool00`00Oomoo`0KOol00`00Oomoo`0NOol2000GOol00`00Oomoo`0BOol00`00Oomo
o`0LOol00`00Oomoo`0GOol00`00Oomoo`0JOol00`00Oomoo`0<Ool00`00Oomoo`0OOol0021oo`<0
00Moo`8001eoo`03001oogoo025oo`03001oogoo01Eoo`03001oogoo015oo`03001oogoo01eoo`03
001oogoo01Moo`03001oogoo01Yoo`8000]oo`03001oogoo021oo`008goo0`000Woo0P007Goo0P00
9Goo0P005Goo00<007ooOol047oo00<007ooOol07goo00<007ooOol05goo00<007ooOol06goo00<0
07ooOol01goo00<007ooOol08Goo000VOol2000NOol00`00Oomoo`0WOol00`00Oomoo`0COol00`00
Oomoo`0>Ool00`00Oomoo`0POol00`00Oomoo`0GOol00`00Oomoo`0LOol00`00Oomoo`04Ool2000T
Ool002Moo`03001oogoo01]oo`03001oogoo02Uoo`03001oogoo01=oo`03001oogoo00eoo`03001o
ogoo025oo`03001oogoo01Moo`03001oogoo01aoo`8000=oo`03001oogoo02Aoo`00:7oo00<007oo
Ool06Goo00<007ooOol0:goo0P0057oo00<007ooOol02goo00<007ooOol08goo00<007ooOol05goo
00<007ooOol07Goo00<007oo00009goo000YOol00`00Oomoo`0GOol00`00Oomoo`0^Ool00`00Oomo
o`0BOol00`00Oomoo`09Ool00`00Oomoo`0UOol00`00Oomoo`0GOol00`00Oomoo`0MOol00`00Oomo
o`0VOol002Yoo`03001oogoo01Eoo`03001oogoo031oo`80019oo`03001oogoo00Qoo`03001oogoo
02Ioo`03001oogoo01Qoo`03001oogoo01aoo`03001oogoo02Ioo`00:goo00<007ooOol04Woo0P00
=Goo00<007ooOol047oo00<007ooOol01goo00<007ooOol09goo00<007ooOol067oo00<007ooOol0
6Woo00<007ooOol09goo000[Ool00`00Oomoo`0AOol00`00Oomoo`0fOol2000AOol00`00Oomoo`05
Ool00`00Oomoo`0YOol00`00Oomoo`0GOol00`00Oomoo`0JOol00`00Oomoo`0WOol002aoo`03001o
ogoo00moo`03001oogoo03Uoo`03001oogoo00moo`03001oogoo00=oo`03001oogoo02]oo`03001o
ogoo01Moo`03001oogoo01Qoo`03001oogoo02Qoo`00;Goo00<007ooOol03Goo00<007ooOol0>goo
0P003goo00<007ooOol00goo00<007ooOol0;7oo00<007ooOol05goo00<007ooOol05Woo00<007oo
Ool0:Goo000^Ool00`00Oomoo`0;Ool00`00Oomoo`0nOol00`00Oomoo`0=Ool01@00Oomoogoo0000
;goo00<007ooOol067oo00<007ooOol05Goo00<007ooOol0:Goo000_Ool00`00Oomoo`08Ool20012
Ool00`00Oomoo`0=Ool00`00Ool0000aOol00`00Oomoo`0HOol00`00Oomoo`0COol00`00Oomoo`0Z
Ool0031oo`03001oogoo00Ioo`03001oogoo04=oo`8000]oo`@003=oo`03001oogoo01Moo`03001o
ogoo01=oo`03001oogoo02Yoo`00<7oo00<007ooOol01Goo00<007ooOol0AWoo00@007ooOomoo`L0
03Qoo`03001oogoo01Moo`03001oogoo015oo`03001oogoo02]oo`00<Goo00<007ooOol00goo00<0
07ooOol0B7oo0`00?goo00<007ooOol067oo00<007ooOol047oo00<007ooOol0:goo000bOol01@00
Oomoogoo0000Bgoo00<007ooOol0@7oo00<007ooOol067oo00<007ooOol03Woo00<007ooOol0;7oo
000cOol00`00Ool0001=Ool00`00Oomoo`10Ool00`00Oomoo`0HOol00`00Oomoo`0<Ool00`00Oomo
o`0]Ool003Aoo`03001oogoo04eoo`03001oogoo041oo`03001oogoo01Moo`03001oogoo00aoo`03
001oogoo02eoo`00=7oo00<007ooOol0CGoo00<007ooOol0@Goo00<007ooOol05goo00<007ooOol0
2Woo00<007ooOol0;Woo000eOol00`00Oomoo`1=Ool00`00Oomoo`10Ool00`00Oomoo`0HOol00`00
Oomoo`09Ool00`00Oomoo`0^Ool003Ioo`03001oogoo04eoo`03001oogoo041oo`03001oogoo01Qo
o`03001oogoo00Moo`03001oogoo02moo`00=goo00<007ooOol0C7oo00<007ooOol0@Goo00<007oo
Ool067oo00<007ooOol01Woo00<007ooOol0;goo000hOol00`00Oomoo`1<Ool00`00Oomoo`11Ool0
0`00Oomoo`0HOol00`00Oomoo`04Ool00`00Oomoo`0`Ool003Uoo`03001oogoo04]oo`03001oogoo
045oo`03001oogoo01Qoo`03001oogoo00Aoo`03001oogoo031oo`00>Woo00<007ooOol0Bgoo00<0
07ooOol0@Goo00<007ooOol067oo00<007ooOol00Woo00<007ooOol0<Goo000kOol00`00Oomoo`1;
Ool00`00Oomoo`11Ool00`00Oomoo`0HOol01000Oomoo`00=7oo000lOol00`00Oomoo`1:Ool00`00
Oomoo`12Ool00`00Oomoo`0HOol00`00Ool0000dOol003eoo`03001oogoo04Yoo`03001oogoo049o
o`03001oogoo01Qoo`03001oogoo03=oo`00?Woo00<007ooOol0BWoo00<007ooOol0@Goo00<007oo
Ool067oo00<007ooOol0<goo000oOol00`00Oomoo`19Ool00`00Oomoo`12Ool00`00Oomoo`0FOol0
0`00Oomoo`0dOol0041oo`03001oogoo04Uoo`03001oogoo049oo`03001oogoo01Aoo`03001oogoo
03Eoo`00@Goo00<007ooOol0BGoo00<007ooOol0@Woo00<007ooOol04Woo00<007ooOol0=Woo0011
Ool00`00Oomoo`19Ool00`00Oomoo`12Ool00`00Oomoo`0BOol00`00Oomoo`0fOol0049oo`03001o
ogoo04Uoo`03001oogoo049oo`03001oogoo011oo`03001oogoo03Moo`00@goo00<007ooOol0BGoo
00<007ooOol0@Woo00<007ooOol03Woo00<007ooOol0>7oo0014Ool00`00Oomoo`18Ool00`00Oomo
o`13Ool00`00Oomoo`0=Ool00`00Oomoo`0hOol004Eoo`03001oogoo04Qoo`03001oogoo04=oo`03
001oogoo00]oo`03001oogoo03Uoo`00AWoo00<007ooOol0Agoo00<007ooOol0@goo00<007ooOol0
2Woo00<007ooOol0>Woo0017Ool00`00Oomoo`17Ool00`00Oomoo`13Ool00`00Oomoo`08Ool00`00
Oomoo`0kOol004Qoo`03001oogoo04Moo`03001oogoo04=oo`03001oogoo00Moo`03001oogoo03]o
o`00BGoo00<007ooOol0AWoo00<007ooOol0A7oo00<007ooOol01Goo00<007ooOol0?7oo001:Ool0
0`00Oomoo`16Ool00`00Oomoo`13Ool00`00Oomoo`04Ool00`00Oomoo`0mOol004]oo`03001oogoo
04Ioo`03001oogoo04=oo`03001oogoo00=oo`03001oogoo03eoo`00C7oo00<007ooOol0AGoo00<0
07ooOol0A7oo00D007ooOomoo`00041oo`00CGoo00<007ooOol0AGoo00<007ooOol0A7oo00<007oo
0000@Goo001>Ool00`00Oomoo`15Ool00`00Oomoo`14Ool00`00Oomoo`10Ool004ioo`03001oogoo
04Eoo`03001oogoo04Aoo`03001oogoo041oo`00Cgoo00<007ooOol0AGoo00<007ooOol0@Woo00<0
07ooOol0@Goo001@Ool00`00Oomoo`15Ool00`00Oomoo`10Ool00`00Oomoo`12Ool0055oo`03001o
ogoo04Aoo`03001oogoo03moo`03001oogoo04=oo`00DWoo00<007ooOol0A7oo00<007ooOol0?Goo
00<007ooOol0A7oo001COol00`00Oomoo`13Ool00`00Oomoo`0mOol00`00Oomoo`14Ool005Aoo`03
001oogoo04=oo`03001oogoo03]oo`03001oogoo04Eoo`00EGoo00<007ooOol0@goo00<007ooOol0
>Goo00<007ooOol0AWoo001FOol00`00Oomoo`12Ool00`00Oomoo`0hOol00`00Oomoo`17Ool005Mo
o`03001oogoo049oo`03001oogoo03Moo`03001oogoo04Moo`00F7oo00<007ooOol0@Woo00<007oo
Ool0=Goo00<007ooOol0B7oo001IOol00`00Oomoo`11Ool00`00Oomoo`0dOol00`00Oomoo`19Ool0
05Yoo`03001oogoo045oo`03001oogoo039oo`03001oogoo04Yoo`00Fgoo00<007ooOol0@Goo00<0
07ooOol0<7oo00<007ooOol0Bgoo001KOol00`00Oomoo`11Ool00`00Oomoo`0`Ool00`00Oomoo`1;
Ool005aoo`03001oogoo045oo`03001oogoo02ioo`03001oogoo04aoo`00GGoo00<007ooOol0@7oo
00<007ooOol0;Goo00<007ooOol0CGoo001NOol00`00Oomoo`10Ool00`00Oomoo`0[Ool00`00Oomo
o`1>Ool005moo`03001oogoo041oo`03001oogoo02Yoo`03001oogoo04ioo`00H7oo00<007ooOol0
?goo00<007ooOol0:Goo00<007ooOol0Cgoo001QOol00`00Oomoo`0oOol00`00Oomoo`0WOol00`00
Oomoo`1@Ool0069oo`03001oogoo03moo`03001oogoo02Eoo`03001oogoo055oo`00Hgoo00<007oo
Ool0?Woo00<007ooOol097oo00<007ooOol0DWoo001TOol00`00Oomoo`0nOol00`00Oomoo`0SOol0
0`00Oomoo`1BOol006Eoo`03001oogoo03ioo`03001oogoo025oo`03001oogoo05=oo`00IWoo00<0
07ooOol0?Goo00<007ooOol087oo00<007ooOol0E7oo001WOol00`00Oomoo`0mOol00`00Oomoo`0N
Ool00`00Oomoo`1EOol006Qoo`03001oogoo03eoo`03001oogoo01eoo`03001oogoo05Eoo`00J7oo
00<007ooOol0?Goo00<007ooOol077oo00<007ooOol0EWoo001YOol00`00Oomoo`0mOol00`00Oomo
o`0JOol00`00Oomoo`1GOol006Yoo`03001oogoo03aoo`03001oogoo01Uoo`03001oogoo05Qoo`00
Jgoo00<007ooOol0?7oo00<007ooOol05goo00<007ooOol0FGoo001/Ool00`00Oomoo`0lOol00`00
Oomoo`0FOol00`00Oomoo`1IOol006eoo`03001oogoo03]oo`03001oogoo01Eoo`03001oogoo05Yo
o`00KWoo00<007ooOol0>goo00<007ooOol04goo00<007ooOol0Fgoo001_Ool00`00Oomoo`0kOol0
0`00Oomoo`0AOol00`00Oomoo`1LOol0071oo`03001oogoo03Yoo`03001oogoo015oo`03001oogoo
05aoo`00LGoo00<007ooOol0>Woo00<007ooOol03goo00<007ooOol0GGoo001bOol00`00Oomoo`0j
Ool00`00Oomoo`0=Ool00`00Oomoo`1NOol007=oo`03001oogoo03Uoo`03001oogoo00aoo`03001o
ogoo05moo`00M7oo00<007ooOol0>Goo00<007ooOol02Woo00<007ooOol0H7oo001eOol00`00Oomo
o`0iOol00`00Oomoo`09Ool00`00Oomoo`1POol007Eoo`03001oogoo03Uoo`03001oogoo00Qoo`03
001oogoo065oo`00MWoo00<007ooOol0>Goo00<007ooOol01Woo00<007ooOol0HWoo001gOol00`00
Oomoo`0hOol00`00Oomoo`05Ool00`00Oomoo`1SOol007Qoo`03001oogoo03Qoo`03001oogoo00Ao
o`03001oogoo06=oo`00NGoo00<007ooOol0>7oo00<007ooOol00Woo00<007ooOol0I7oo001jOol0
0`00Oomoo`0gOol01@00Oomoogoo0000Igoo001kOol00`00Oomoo`0gOol00`00Ool0001XOol007ao
o`03001oogoo03Ioo`8006Uoo`00OGoo00<007ooOol0<goo0P00Jgoo001nOol00`00Oomoo`0`Ool2
001]Ool007moo`03001oogoo02eoo`8006moo`00P7oo00<007ooOol0:Woo0P00LGoo0021Ool00`00
Oomoo`0WOol2001cOol0089oo`03001oogoo02Aoo`8007Eoo`00PWoo00<007ooOol08Woo0P00Mgoo
0023Ool00`00Oomoo`0OOol2001iOol008Aoo`03001oogoo01aoo`8007]oo`00QGoo00<007ooOol0
6Woo00<007ooOol0Ngoo0026Ool00`00Oomoo`0GOol2001nOol008Moo`03001oogoo01Aoo`80081o
o`00R7oo00<007ooOol04Goo0P00PWoo0029Ool00`00Oomoo`0>Ool20024Ool008Yoo`03001oogoo
00]oo`8008Ioo`00Rgoo00<007ooOol027oo0P00R7oo002<Ool00`00Oomoo`05Ool2002:Ool008eo
o`03001oogoo009oo`8008aoo`00SWoo00@007oo000008ioo`00Sgoo00<007ooOol0SWoo003oOolQ
Ool00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00
ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQ
Ool00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00
ogoo8Goo003oOolQOol00001\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-1.01364, -1.00004, 
  0.0384226, 0.0395621}}]
}, Closed]]
}, Open  ]]
},
FrontEndVersion->"4.0 for Macintosh",
ScreenRectangle->{{0, 1024}, {0, 748}},
WindowSize->{515, 626},
WindowMargins->{{Automatic, 6}, {Automatic, -7}},
StyleDefinitions -> "HelpBrowser.nb",
MacintoshSystemPageSetup->"\<\
00`0001804P000000_02@?o/onh3109BI085:0?l0@00005X0FP000003[0;@001
0000I00100000@0000000BL?0040000000000000000000000000000000000?nL
ojH?50^J00P100000000000000000000\>"
]


(***********************************************************************
Cached data follows.  If you edit this Notebook file directly, not using
Mathematica, you must remove the line containing CacheID at the top of 
the file.  The cache data will then be recreated when you save this file 
from within Mathematica.
***********************************************************************)

(*CellTagsOutline
CellTagsIndex->{}
*)

(*CellTagsIndex
CellTagsIndex->{}
*)

(*NotebookFileOutline
Notebook[{

Cell[CellGroupData[{
Cell[1739, 51, 46, 0, 36, "SubsectionIcon"],
Cell[1788, 53, 634, 14, 83, "Text"],
Cell[2425, 69, 221, 4, 57, "Input"],
Cell[2649, 75, 225, 5, 45, "Input"],

Cell[CellGroupData[{
Cell[2899, 84, 877, 16, 207, "Input"],
Cell[3779, 102, 258, 5, 20, "Print"],
Cell[4040, 109, 258, 5, 20, "Print"],
Cell[4301, 116, 258, 5, 20, "Print"],
Cell[4562, 123, 258, 5, 20, "Print"],
Cell[4823, 130, 258, 5, 20, "Print"],
Cell[5084, 137, 257, 5, 20, "Print"],
Cell[5344, 144, 258, 5, 20, "Print"],
Cell[5605, 151, 258, 5, 20, "Print"],
Cell[5866, 158, 258, 5, 20, "Print"],
Cell[6127, 165, 258, 5, 20, "Print"],
Cell[6388, 172, 258, 5, 20, "Print"],
Cell[6649, 179, 258, 5, 20, "Print"],
Cell[6910, 186, 258, 5, 20, "Print"],
Cell[7171, 193, 258, 5, 20, "Print"],
Cell[7432, 200, 258, 5, 20, "Print"],
Cell[7693, 207, 258, 5, 20, "Print"],
Cell[7954, 214, 258, 5, 20, "Print"],
Cell[8215, 221, 257, 5, 20, "Print"],
Cell[8475, 228, 258, 5, 20, "Print"],
Cell[8736, 235, 258, 5, 20, "Print"],
Cell[8997, 242, 257, 5, 20, "Print"],
Cell[9257, 249, 257, 5, 20, "Print"],
Cell[9517, 256, 258, 5, 20, "Print"],
Cell[9778, 263, 258, 5, 20, "Print"],
Cell[10039, 270, 257, 5, 20, "Print"],
Cell[10299, 277, 258, 5, 20, "Print"],
Cell[10560, 284, 257, 5, 20, "Print"],
Cell[10820, 291, 258, 5, 20, "Print"],
Cell[11081, 298, 258, 5, 20, "Print"],
Cell[11342, 305, 258, 5, 20, "Print"],
Cell[11603, 312, 258, 5, 20, "Print"],
Cell[11864, 319, 258, 5, 20, "Print"],
Cell[12125, 326, 258, 5, 20, "Print"],
Cell[12386, 333, 258, 5, 20, "Print"],
Cell[12647, 340, 258, 5, 20, "Print"],
Cell[12908, 347, 258, 5, 20, "Print"],
Cell[13169, 354, 258, 5, 20, "Print"],
Cell[13430, 361, 258, 5, 20, "Print"],
Cell[13691, 368, 257, 5, 20, "Print"],
Cell[13951, 375, 258, 5, 20, "Print"],
Cell[14212, 382, 258, 5, 20, "Print"],
Cell[14473, 389, 258, 5, 20, "Print"],
Cell[14734, 396, 257, 5, 20, "Print"],
Cell[14994, 403, 258, 5, 20, "Print"],
Cell[15255, 410, 257, 5, 20, "Print"],
Cell[15515, 417, 258, 5, 20, "Print"],
Cell[15776, 424, 258, 5, 20, "Print"],
Cell[16037, 431, 258, 5, 20, "Print"],
Cell[16298, 438, 258, 5, 20, "Print"],
Cell[16559, 445, 258, 5, 20, "Print"],
Cell[16820, 452, 258, 5, 20, "Print"],
Cell[17081, 459, 258, 5, 20, "Print"],
Cell[17342, 466, 256, 5, 20, "Print"],
Cell[17601, 473, 258, 5, 20, "Print"],
Cell[17862, 480, 258, 5, 20, "Print"],
Cell[18123, 487, 258, 5, 20, "Print"],
Cell[18384, 494, 258, 5, 20, "Print"],
Cell[18645, 501, 258, 5, 20, "Print"],
Cell[18906, 508, 258, 5, 20, "Print"],
Cell[19167, 515, 258, 5, 20, "Print"],
Cell[19428, 522, 96, 2, 20, "Output"]
}, Closed]],
Cell[19539, 527, 209, 6, 32, "Text"],

Cell[CellGroupData[{
Cell[19773, 537, 213, 4, 57, "Input"],
Cell[19989, 543, 332, 10, 35, "Output"]
}, Open  ]],
Cell[20336, 556, 345, 7, 56, "Text"],
Cell[20684, 565, 56, 0, 22, "Text"],

Cell[CellGroupData[{
Cell[20765, 569, 672, 12, 132, "Input"],
Cell[21440, 583, 26529, 749, 435, 7746, 512, "GraphicsData", "PostScript", \
"Graphics"]
}, Open  ]],
Cell[47984, 1335, 189, 6, 26, "Text"],

Cell[CellGroupData[{
Cell[48198, 1345, 159, 4, 42, "Input"],
Cell[48360, 1351, 583, 14, 62, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[48980, 1370, 578, 10, 128, "Input"],
Cell[49561, 1382, 24329, 752, 70, 8425, 550, "GraphicsData", "PostScript", \
"Graphics"]
}, Closed]],

Cell[CellGroupData[{
Cell[73927, 2139, 435, 10, 53, "Input"],
Cell[74365, 2151, 487, 12, 51, "Output"]
}, Open  ]],
Cell[74867, 2166, 88, 3, 22, "Text"],
Cell[74958, 2171, 160, 4, 27, "Input"],
Cell[75121, 2177, 208, 6, 38, "Text"],
Cell[75332, 2185, 623, 12, 64, "Text"],

Cell[CellGroupData[{
Cell[75980, 2201, 323, 7, 42, "Input"],
Cell[76306, 2210, 10418, 212, 184, 1212, 93, "GraphicsData", "PostScript", \
"Graphics"]
}, Closed]]
}, Open  ]]
}
]
*)




(***********************************************************************
End of Mathematica Notebook file.
***********************************************************************)

