(***********************************************************************

                    Mathematica-Compatible Notebook

This notebook can be used on any computer system with Mathematica 4.0,
MathReader 4.0, or any compatible application. The data for the notebook 
starts with the line containing stars above.

To get the notebook into a Mathematica-compatible application, do one of 
the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing the 
word CacheID, otherwise Mathematica-compatible applications may try to 
use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
***********************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[    125314,       3773]*)
(*NotebookOutlinePosition[    126354,       3807]*)
(*  CellTagsIndexPosition[    126269,       3801]*)
(*WindowFrame->Normal*)



Notebook[{

Cell[CellGroupData[{
Cell["Sampling individuals", "SubsectionIcon"],

Cell[TextData[Cell[BoxData[
    FormBox[GridBox[{
          {
            FormBox[
              RowBox[{"SampleIndividuals", "[", 
                RowBox[{
                  StyleBox["popln",
                    FontSlant->"Italic"], ",", \({x\_1, \[Ellipsis]}\), ",", 
                  " ", "n", ",", " ", \(\[Sigma]\^2\), ",", " ", "R", ",", 
                  " ", "\[CapitalDelta]"}], "]"}],
              "TraditionalForm"], \(samples\ n\ individuals, \ 
            without\ replacement, \ 
            from\ around\ each\ of\ the\ locations\ x\_i . \ \ The\ \
probability\ of\ sampling\ falls\ as\ a\ Gaussian\ around\ x, \ \(\(with\)\(\ \
\)\(variance\)\(\ \)\(\(\[Sigma]\^2\)\(.\)\)\(\ \)\)\)},
          {
            RowBox[{"SampleIndividuals", "[", 
              RowBox[{
                StyleBox["popln",
                  FontSlant->"Italic"], ",", \({x\_1, \[Ellipsis]}\), ",", 
                " ", "n", ",", " ", "0", ",", " ", "R", ",", " ", 
                "\[CapitalDelta]"}], 
              "]"}], \(samples\ the\ nearest\ n\ individuals\ to\ each\ of\ \
the\ \(\(x\_i\)\(.\)\)\)}
          }], TraditionalForm]]]], "DefinitionBox",
  CellTags->"SampleIndividuals"],

Cell[TextData[{
  "Here is a population of 100 individuals on a range ",
  Cell[BoxData[
      \(TraditionalForm\`R = 60\)]],
  ", initally with uniform density ",
  Cell[BoxData[
      \(TraditionalForm\`\[Rho] = 1000\/60\^2\)]],
  "=0.28."
}], "MathCaption"],

Cell[BoxData[
    \(R = 60; \[CapitalDelta] = 3; \[Sigma] = 1. ; \n
    U[\[Gamma]_] := 
      \(1\/\(2  \[Pi]\ \[Gamma]\ \)\) Exp[\(-\(1\/\(2  \[Gamma]\)\)\) #]&; 
    M[\[Mu]_, \[Alpha]_] := \((\[Mu] + \[Alpha]*#)\)&\ ; F[f_] := f&; \n
    InitialiseContinuum[p1, 1000, R, \[CapitalDelta], 2, U[1], M[1, 5], 
      F[2]]; \)], "Input",
  CellLabel->"In[75]:="],

Cell["\<\
Here is a sample of 10 individuals, from around each of 3 points.  \
The sampling probability falls as a Gaussian with variance 4:\
\>", \
"MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[
    \(ss = 
      SampleIndividuals[p1, {{20, 20}, {30, 30}, {40, 40}}, 10, 4, R, 6]; 
    ss // TableForm\)], "Input",
  CellLabel->"In[169]:="],

Cell[BoxData[
    TagBox[GridBox[{
          {"238", "266", "142", "17", "325", "491", "119", "413", "688", 
            "531"},
          {"498", "924", "450", "617", "2", "56", "717", "914", "499", 
            "661"},
          {"243", "910", "724", "737", "817", "172", "973", "578", "252", 
            "787"}
          },
        RowSpacings->1,
        ColumnSpacings->3,
        RowAlignments->Baseline,
        ColumnAlignments->{Left}],
      (TableForm[ #]&)]], "Output",
  CellLabel->"Out[169]//TableForm="]
}, Closed]],

Cell[BoxData[
    \(<< Graphics`Colors`; << Graphics`Graphics`; \)], "Input",
  CellLabel->"In[103]:="],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(DisplayTogether[ListPlot[locs, PlotStyle -> PointSize[0.002]], \n\t
      Graphics[Circle[{20, 20}, 4]], Graphics[Circle[{30, 30}, 4]], 
      Graphics[Circle[{40, 40}, 4]], \n\t
      ListPlot[\(Location[p1, #]&\)/@ss[\([1]\)], PlotStyle \[Rule] Red], \n\t
      ListPlot[\(Location[p1, #]&\)/@ss[\([2]\)], PlotStyle \[Rule] Blue], \n
      \tListPlot[\(Location[p1, #]&\)/@ss[\([3]\)], PlotStyle \[Rule] Green], 
      \n\tPlotRange \[Rule] {{0, R}, {0, R}}, AspectRatio \[Rule] 1]; \)\)], 
  "Input",
  CellLabel->"In[176]:="],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 0.0166667 0 0.0166667 [
[.16667 -0.0125 -6 -9 ]
[.16667 -0.0125 6 0 ]
[.33333 -0.0125 -6 -9 ]
[.33333 -0.0125 6 0 ]
[.5 -0.0125 -6 -9 ]
[.5 -0.0125 6 0 ]
[.66667 -0.0125 -6 -9 ]
[.66667 -0.0125 6 0 ]
[.83333 -0.0125 -6 -9 ]
[.83333 -0.0125 6 0 ]
[1 -0.0125 -6 -9 ]
[1 -0.0125 6 0 ]
[-0.0125 .16667 -12 -4.5 ]
[-0.0125 .16667 0 4.5 ]
[-0.0125 .33333 -12 -4.5 ]
[-0.0125 .33333 0 4.5 ]
[-0.0125 .5 -12 -4.5 ]
[-0.0125 .5 0 4.5 ]
[-0.0125 .66667 -12 -4.5 ]
[-0.0125 .66667 0 4.5 ]
[-0.0125 .83333 -12 -4.5 ]
[-0.0125 .83333 0 4.5 ]
[-0.0125 1 -12 -4.5 ]
[-0.0125 1 0 4.5 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.16667 0 m
.16667 .00625 L
s
[(10)] .16667 -0.0125 0 1 Mshowa
.33333 0 m
.33333 .00625 L
s
[(20)] .33333 -0.0125 0 1 Mshowa
.5 0 m
.5 .00625 L
s
[(30)] .5 -0.0125 0 1 Mshowa
.66667 0 m
.66667 .00625 L
s
[(40)] .66667 -0.0125 0 1 Mshowa
.83333 0 m
.83333 .00625 L
s
[(50)] .83333 -0.0125 0 1 Mshowa
1 0 m
1 .00625 L
s
[(60)] 1 -0.0125 0 1 Mshowa
.125 Mabswid
.03333 0 m
.03333 .00375 L
s
.06667 0 m
.06667 .00375 L
s
.1 0 m
.1 .00375 L
s
.13333 0 m
.13333 .00375 L
s
.2 0 m
.2 .00375 L
s
.23333 0 m
.23333 .00375 L
s
.26667 0 m
.26667 .00375 L
s
.3 0 m
.3 .00375 L
s
.36667 0 m
.36667 .00375 L
s
.4 0 m
.4 .00375 L
s
.43333 0 m
.43333 .00375 L
s
.46667 0 m
.46667 .00375 L
s
.53333 0 m
.53333 .00375 L
s
.56667 0 m
.56667 .00375 L
s
.6 0 m
.6 .00375 L
s
.63333 0 m
.63333 .00375 L
s
.7 0 m
.7 .00375 L
s
.73333 0 m
.73333 .00375 L
s
.76667 0 m
.76667 .00375 L
s
.8 0 m
.8 .00375 L
s
.86667 0 m
.86667 .00375 L
s
.9 0 m
.9 .00375 L
s
.93333 0 m
.93333 .00375 L
s
.96667 0 m
.96667 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .16667 m
.00625 .16667 L
s
[(10)] -0.0125 .16667 1 0 Mshowa
0 .33333 m
.00625 .33333 L
s
[(20)] -0.0125 .33333 1 0 Mshowa
0 .5 m
.00625 .5 L
s
[(30)] -0.0125 .5 1 0 Mshowa
0 .66667 m
.00625 .66667 L
s
[(40)] -0.0125 .66667 1 0 Mshowa
0 .83333 m
.00625 .83333 L
s
[(50)] -0.0125 .83333 1 0 Mshowa
0 1 m
.00625 1 L
s
[(60)] -0.0125 1 1 0 Mshowa
.125 Mabswid
0 .03333 m
.00375 .03333 L
s
0 .06667 m
.00375 .06667 L
s
0 .1 m
.00375 .1 L
s
0 .13333 m
.00375 .13333 L
s
0 .2 m
.00375 .2 L
s
0 .23333 m
.00375 .23333 L
s
0 .26667 m
.00375 .26667 L
s
0 .3 m
.00375 .3 L
s
0 .36667 m
.00375 .36667 L
s
0 .4 m
.00375 .4 L
s
0 .43333 m
.00375 .43333 L
s
0 .46667 m
.00375 .46667 L
s
0 .53333 m
.00375 .53333 L
s
0 .56667 m
.00375 .56667 L
s
0 .6 m
.00375 .6 L
s
0 .63333 m
.00375 .63333 L
s
0 .7 m
.00375 .7 L
s
0 .73333 m
.00375 .73333 L
s
0 .76667 m
.00375 .76667 L
s
0 .8 m
.00375 .8 L
s
0 .86667 m
.00375 .86667 L
s
0 .9 m
.00375 .9 L
s
0 .93333 m
.00375 .93333 L
s
0 .96667 m
.00375 .96667 L
s
.25 Mabswid
0 0 m
0 1 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
.002 w
.93914 .98334 Mdot
.45036 .56924 Mdot
.45771 .51409 Mdot
.17466 .13715 Mdot
.58562 .15974 Mdot
.21024 .51471 Mdot
.49717 .21941 Mdot
.78261 .57513 Mdot
.46846 .0751 Mdot
.50129 .7704 Mdot
.29026 .97505 Mdot
.52589 .65784 Mdot
.35111 .99171 Mdot
.07553 .0886 Mdot
.8934 .47763 Mdot
.90087 .95144 Mdot
.30778 .31789 Mdot
.69063 .43673 Mdot
.81061 .09848 Mdot
.90802 .8616 Mdot
.34215 .02338 Mdot
.40674 .0912 Mdot
.05189 .04833 Mdot
.88085 .43336 Mdot
.70078 .05662 Mdot
.80532 .34476 Mdot
.80738 .57899 Mdot
.90445 .39332 Mdot
.4996 .2611 Mdot
.21382 .95659 Mdot
.68899 .16262 Mdot
.3058 .09499 Mdot
.34684 .13924 Mdot
.89906 .00379 Mdot
.29495 .09091 Mdot
.01821 .57043 Mdot
.59417 .03429 Mdot
.21288 .22567 Mdot
.78679 .4553 Mdot
.30843 .83235 Mdot
.28719 .1942 Mdot
.09461 .87576 Mdot
.5982 .03158 Mdot
.78882 .78078 Mdot
.25135 .89234 Mdot
.88976 .77699 Mdot
.9564 .80143 Mdot
.87155 .20656 Mdot
.36223 .76714 Mdot
.65867 .98089 Mdot
.57544 .31184 Mdot
.35023 .14854 Mdot
.28825 .11764 Mdot
.25562 .27278 Mdot
.69006 .08606 Mdot
.4668 .492 Mdot
.4387 .19372 Mdot
.57705 .71501 Mdot
.4823 .39229 Mdot
.7055 .50845 Mdot
.12007 .62515 Mdot
.04683 .52756 Mdot
.54463 .31331 Mdot
.6966 .37902 Mdot
.25638 .19567 Mdot
.44098 .10624 Mdot
.56632 .10961 Mdot
.97417 .61424 Mdot
.12762 .91589 Mdot
.39713 .89922 Mdot
.64531 .5236 Mdot
.69163 .39077 Mdot
.52524 .89845 Mdot
.6448 .86321 Mdot
.98061 .58513 Mdot
.9482 .4842 Mdot
.72423 .38946 Mdot
.50722 .37796 Mdot
.15791 .27985 Mdot
.53304 .76372 Mdot
.0303 .36396 Mdot
.13592 .8645 Mdot
.38499 .84036 Mdot
.44429 .47373 Mdot
.85975 .94191 Mdot
.79949 .61051 Mdot
.87913 .35678 Mdot
.8513 .12632 Mdot
.1549 .96732 Mdot
.34408 .74836 Mdot
.99699 .68747 Mdot
.81104 .98464 Mdot
.96669 .32352 Mdot
.67512 .12014 Mdot
.58171 .48316 Mdot
.23083 .64641 Mdot
.72196 .54125 Mdot
.43134 .0359 Mdot
.84283 .18447 Mdot
.58004 .90958 Mdot
.68792 .21715 Mdot
.23596 .16123 Mdot
.69094 .52967 Mdot
.42492 .17659 Mdot
.72425 .20616 Mdot
.7498 .05645 Mdot
.14254 .723 Mdot
.51897 .41004 Mdot
.42058 .18175 Mdot
.08764 .37414 Mdot
.57775 .99728 Mdot
.5076 .46456 Mdot
.88983 .78013 Mdot
.27164 .30333 Mdot
.19889 .25046 Mdot
.84672 .12674 Mdot
.47465 .0443 Mdot
.09692 .07028 Mdot
.33211 .32131 Mdot
.57794 .66024 Mdot
.91153 .13956 Mdot
.49031 .2861 Mdot
.33377 .14228 Mdot
.98271 .82154 Mdot
.44394 .36215 Mdot
.71107 .51821 Mdot
.24505 .11169 Mdot
.86435 .39147 Mdot
.7704 .06739 Mdot
.76743 .32119 Mdot
.43829 .74609 Mdot
.18948 .66095 Mdot
.52676 .60653 Mdot
.69918 .37486 Mdot
.19299 .46425 Mdot
.71647 .55331 Mdot
.74904 .10209 Mdot
.0054 .0351 Mdot
.50399 .9904 Mdot
.14106 .64363 Mdot
.7336 .92301 Mdot
.37363 .32244 Mdot
.29531 .17692 Mdot
.18414 .66148 Mdot
.76854 .57039 Mdot
.48497 .28663 Mdot
.57556 .10615 Mdot
.7685 .73331 Mdot
.82651 .00405 Mdot
.7631 .69821 Mdot
.32252 .01365 Mdot
.62204 .05458 Mdot
.58892 .09065 Mdot
.24841 .73215 Mdot
.29362 .91372 Mdot
.06427 .07066 Mdot
.52507 .34333 Mdot
.5793 .78403 Mdot
.94952 .23718 Mdot
.8108 .05072 Mdot
.123 .23313 Mdot
.04771 .35251 Mdot
.80049 .21947 Mdot
.42567 .29793 Mdot
.21156 .12882 Mdot
.17726 .56578 Mdot
.91794 .2151 Mdot
.11299 .49512 Mdot
.39287 .87177 Mdot
.53369 .71108 Mdot
.44335 .63459 Mdot
.72289 .66036 Mdot
.32035 .40146 Mdot
.67518 .30785 Mdot
.51986 .18199 Mdot
.24952 .00992 Mdot
.3083 .05317 Mdot
.07226 .44414 Mdot
.39036 .83807 Mdot
.95927 .94902 Mdot
.99749 .9663 Mdot
.42558 .23794 Mdot
.55414 .33171 Mdot
.70269 .57758 Mdot
.23379 .93024 Mdot
.02751 .26972 Mdot
.71392 .74825 Mdot
.77799 .2598 Mdot
.40562 .69508 Mdot
.70573 .81566 Mdot
.01526 .85701 Mdot
.74645 .86664 Mdot
.01777 .89071 Mdot
.32087 .6287 Mdot
.46364 .55901 Mdot
.61818 .05112 Mdot
.22985 .62876 Mdot
.59067 .78139 Mdot
.51593 .88051 Mdot
.81268 .52159 Mdot
.11031 .18543 Mdot
.10696 .70593 Mdot
.09505 .32842 Mdot
.36051 .8393 Mdot
.07727 .4377 Mdot
.03963 .2106 Mdot
.61364 .8787 Mdot
.42146 .15948 Mdot
.38379 .24994 Mdot
.83078 .37809 Mdot
.86786 .36942 Mdot
.0181 .8565 Mdot
.75755 .18399 Mdot
.91114 .15056 Mdot
.66251 .85557 Mdot
.55063 .31127 Mdot
.58523 .41787 Mdot
.511 .10066 Mdot
.9716 .53917 Mdot
.08954 .94118 Mdot
.58781 .28924 Mdot
.25876 .56309 Mdot
.71995 .91981 Mdot
.24066 .70659 Mdot
.9624 .73582 Mdot
.32952 .55602 Mdot
.2999 .88025 Mdot
.77889 .24476 Mdot
.71467 .46238 Mdot
.26789 .1441 Mdot
.74307 .92321 Mdot
.17834 .20292 Mdot
.15526 .63397 Mdot
.91958 .63983 Mdot
.4353 .71416 Mdot
.67892 .93324 Mdot
.4729 .97834 Mdot
.3494 .37722 Mdot
.173 .09809 Mdot
.57051 .13246 Mdot
.45834 .63571 Mdot
.30262 .98836 Mdot
.71527 .71251 Mdot
.12428 .78545 Mdot
.56001 .07853 Mdot
.20469 .14562 Mdot
.12471 .36437 Mdot
.52577 .21237 Mdot
.65181 .38603 Mdot
.17637 .83516 Mdot
.47881 .28794 Mdot
.60587 .7027 Mdot
.02047 .65222 Mdot
.30325 .71433 Mdot
.3052 .93972 Mdot
.17897 .92889 Mdot
.74519 .86118 Mdot
.97428 .78327 Mdot
.62048 .49681 Mdot
.44851 .5709 Mdot
.96867 .11078 Mdot
.27213 .73574 Mdot
.48986 .82284 Mdot
.66627 .03305 Mdot
.46939 .17062 Mdot
.36302 .31871 Mdot
.1642 .2309 Mdot
.18405 .38983 Mdot
.41901 .36972 Mdot
.20977 .60656 Mdot
.79853 .8729 Mdot
.76126 .03566 Mdot
.82987 .76212 Mdot
.48913 .29992 Mdot
.34001 .93928 Mdot
.82287 .26687 Mdot
.87061 .76866 Mdot
.45984 .94816 Mdot
.70642 .53776 Mdot
.27579 .55833 Mdot
.28741 .16805 Mdot
.06602 .95177 Mdot
.48887 .29514 Mdot
.30476 .91611 Mdot
.65901 .53302 Mdot
.81563 .61619 Mdot
.319 .59374 Mdot
.99276 .34932 Mdot
.44839 .82507 Mdot
.53292 .40117 Mdot
.74197 .28731 Mdot
.25712 .84284 Mdot
.45457 .11926 Mdot
.1911 .89107 Mdot
.9657 .82412 Mdot
.88634 .97496 Mdot
.30669 .2911 Mdot
.07071 .35877 Mdot
.98769 .69736 Mdot
.07795 .00945 Mdot
.5393 .87229 Mdot
.54504 .60828 Mdot
.79733 .58498 Mdot
.28792 .76544 Mdot
.34276 .46572 Mdot
.09682 .87437 Mdot
.37707 .6416 Mdot
.21048 .89941 Mdot
.07038 .35051 Mdot
.13976 .54064 Mdot
.08269 .65315 Mdot
.06181 .53119 Mdot
.54338 .78086 Mdot
.51677 .92292 Mdot
.74606 .19588 Mdot
.22886 .15748 Mdot
.4033 .73015 Mdot
.13204 .28311 Mdot
.02623 .08855 Mdot
.92156 .3837 Mdot
.95585 .73804 Mdot
.78179 .84306 Mdot
.87317 .0849 Mdot
.71998 .31187 Mdot
.32979 .30404 Mdot
.20321 .38896 Mdot
.58373 .10816 Mdot
.97435 .23148 Mdot
.18043 .37801 Mdot
.84232 .94837 Mdot
.1542 .28946 Mdot
.92076 .56467 Mdot
.19835 .55142 Mdot
.13897 .7216 Mdot
.32518 .46652 Mdot
.41899 .40973 Mdot
.9954 .16249 Mdot
.21578 .02077 Mdot
.41167 .05432 Mdot
.24142 .78929 Mdot
.23123 .67631 Mdot
.3991 .84092 Mdot
.07703 .38685 Mdot
.47834 .27626 Mdot
.87868 .83543 Mdot
.33937 .55466 Mdot
.5535 .36891 Mdot
.92039 .14493 Mdot
.5581 .20642 Mdot
.70461 .12415 Mdot
.14643 .1521 Mdot
.46319 .33486 Mdot
.9152 .47579 Mdot
.06408 .49394 Mdot
.83818 .08894 Mdot
.58574 .21768 Mdot
.9595 .2535 Mdot
.24637 .66302 Mdot
.406 .88459 Mdot
.32598 .5181 Mdot
.8479 .67817 Mdot
.62137 .39394 Mdot
.70147 .52607 Mdot
.15818 .05908 Mdot
.78626 .05028 Mdot
.0941 .56515 Mdot
.94809 .96135 Mdot
.50836 .34747 Mdot
.98859 .70784 Mdot
.26199 .68444 Mdot
.58259 .82325 Mdot
.93601 .16635 Mdot
.73468 .14508 Mdot
.31464 .7724 Mdot
.03321 .61901 Mdot
.15646 .71332 Mdot
.24695 .56872 Mdot
.06236 .14818 Mdot
.29886 .60738 Mdot
.554 .80071 Mdot
.31027 .89954 Mdot
.29202 .11627 Mdot
.72769 .07629 Mdot
.35601 .94992 Mdot
.99301 .93121 Mdot
.04137 .17752 Mdot
.95979 .3122 Mdot
.88491 .4642 Mdot
.71284 .74348 Mdot
.82255 .31602 Mdot
.41398 .1361 Mdot
.26855 .51531 Mdot
.10371 .23656 Mdot
.97653 .39904 Mdot
.37602 .16028 Mdot
.62052 .44912 Mdot
.38301 .22907 Mdot
.57915 .2716 Mdot
.42322 .91686 Mdot
.69424 .8074 Mdot
.71038 .17338 Mdot
.87169 .49138 Mdot
.2964 .03728 Mdot
.60315 .97608 Mdot
.19269 .80072 Mdot
.62662 .57704 Mdot
.81668 .64044 Mdot
.0061 .12792 Mdot
.43366 .41137 Mdot
.42694 .85632 Mdot
.01044 .49451 Mdot
.7327 .04892 Mdot
.30006 .32113 Mdot
.861 .55753 Mdot
.00366 .28385 Mdot
.25786 .58146 Mdot
.81096 .48313 Mdot
.63124 .00442 Mdot
.99429 .84269 Mdot
.62514 .8765 Mdot
.56063 .43132 Mdot
.1982 .02018 Mdot
.55019 .93681 Mdot
.4655 .97127 Mdot
.25013 .61567 Mdot
.6045 .41373 Mdot
.24647 .33182 Mdot
.34664 .83227 Mdot
.4355 .84869 Mdot
.7154 .82785 Mdot
.44121 .00599 Mdot
.09026 .95135 Mdot
.88059 .57467 Mdot
.89206 .93116 Mdot
.3304 .63787 Mdot
.42656 .9599 Mdot
.08027 .02219 Mdot
.82206 .54616 Mdot
.83381 .69037 Mdot
.47542 .71389 Mdot
.3983 .84168 Mdot
.76001 .88604 Mdot
.95709 .83568 Mdot
.66975 .93469 Mdot
.0765 .26101 Mdot
.77769 .00353 Mdot
.7461 .62314 Mdot
.35113 .04363 Mdot
.66583 .60095 Mdot
.52907 .49747 Mdot
.83202 .91058 Mdot
.05365 .78358 Mdot
.43372 .0689 Mdot
.29363 .89754 Mdot
.47663 .23322 Mdot
.62388 .96285 Mdot
.40012 .9722 Mdot
.84619 .95933 Mdot
.65402 .34906 Mdot
.49507 .9157 Mdot
.9882 .74811 Mdot
.966 .41823 Mdot
.15618 .83753 Mdot
.91235 .63465 Mdot
.72246 .76863 Mdot
.61872 .73711 Mdot
.24584 .53542 Mdot
.99483 .77425 Mdot
.84571 .56321 Mdot
.14864 .81493 Mdot
.19169 .21415 Mdot
.65357 .89923 Mdot
.20349 .46604 Mdot
.68757 .481 Mdot
.04732 .6285 Mdot
.77522 .84635 Mdot
.32486 .85987 Mdot
.15651 .10925 Mdot
.07902 .32445 Mdot
.16168 .33499 Mdot
.23331 .76124 Mdot
.01304 .52007 Mdot
.04161 .54709 Mdot
.35947 .62084 Mdot
.83812 .08105 Mdot
.67189 .13983 Mdot
.7908 .45254 Mdot
.89667 .29348 Mdot
.46595 .59268 Mdot
.74016 .18423 Mdot
.38693 .26822 Mdot
.57849 .84924 Mdot
.15362 .50699 Mdot
.56545 .32917 Mdot
.11201 .9599 Mdot
.20598 .70834 Mdot
.27389 .87885 Mdot
.53409 .5685 Mdot
.48308 .42631 Mdot
.63742 .27502 Mdot
.01714 .83363 Mdot
.89726 .09079 Mdot
.63021 .56541 Mdot
.31877 .24155 Mdot
.47659 .05842 Mdot
.75332 .91237 Mdot
.36458 .09852 Mdot
.54734 .20404 Mdot
.0907 .21967 Mdot
.01324 .63554 Mdot
.60761 .79336 Mdot
.37582 .36051 Mdot
.59047 .95972 Mdot
.47856 .26973 Mdot
.96026 .39431 Mdot
.15979 .02818 Mdot
.48367 .33589 Mdot
.40647 .11581 Mdot
.11909 .23737 Mdot
.85914 .91177 Mdot
.02839 .01771 Mdot
.8459 .27623 Mdot
.42078 .22435 Mdot
.47007 .91572 Mdot
.83031 .26462 Mdot
.99151 .64599 Mdot
.87005 .87031 Mdot
.83171 .61781 Mdot
.38638 .53442 Mdot
.42524 .502 Mdot
.26729 .29704 Mdot
.5661 .59023 Mdot
.2389 .27934 Mdot
.72021 .314 Mdot
.81811 .05499 Mdot
.25013 .39828 Mdot
.98781 .79037 Mdot
.25862 .75229 Mdot
.11776 .92006 Mdot
.42691 .13448 Mdot
.73138 .38564 Mdot
.00167 .63248 Mdot
.46409 .0886 Mdot
.43557 .04224 Mdot
.2252 .80926 Mdot
.71536 .72824 Mdot
.40709 .75427 Mdot
.46523 .32996 Mdot
.41928 .9639 Mdot
.20661 .57767 Mdot
.30152 .04384 Mdot
.7797 .44319 Mdot
.57014 .6582 Mdot
.77803 .81071 Mdot
.10604 .5696 Mdot
.34246 .76847 Mdot
.88085 .76035 Mdot
.6271 .04023 Mdot
.47376 .00608 Mdot
.16187 .71027 Mdot
.05448 .04218 Mdot
.95526 .13261 Mdot
.75296 .99833 Mdot
.17556 .68942 Mdot
.18282 .34013 Mdot
.39753 .87871 Mdot
.07677 .77053 Mdot
.05507 .11024 Mdot
.19593 .01018 Mdot
.42797 .07001 Mdot
.72217 .00411 Mdot
.2661 .35974 Mdot
.66769 .96193 Mdot
.31083 .22713 Mdot
.91473 .9636 Mdot
.13527 .53771 Mdot
.73192 .62346 Mdot
.73774 .659 Mdot
.65514 .85294 Mdot
.68267 .54876 Mdot
.45922 .84275 Mdot
.2547 .47875 Mdot
.73705 .83865 Mdot
.9886 .11901 Mdot
.06936 .87672 Mdot
.67777 .89188 Mdot
.15463 .91312 Mdot
.5425 .35417 Mdot
.42271 .28965 Mdot
.80476 .69517 Mdot
.76757 .43672 Mdot
.12209 .14641 Mdot
.30835 .59397 Mdot
.86739 .66766 Mdot
.5713 .75532 Mdot
.87879 .54865 Mdot
.50194 .87861 Mdot
.20102 .65677 Mdot
.34731 .96549 Mdot
.65852 .30259 Mdot
.92459 .67583 Mdot
.85376 .60742 Mdot
.15703 .23911 Mdot
.73167 .461 Mdot
.84867 .64514 Mdot
.86428 .79334 Mdot
.27737 .88982 Mdot
.98549 .24469 Mdot
.77543 .01122 Mdot
.78447 .58793 Mdot
.42813 .04573 Mdot
.12594 .28533 Mdot
.50353 .3699 Mdot
.27218 .67792 Mdot
.3465 .13079 Mdot
.54051 .21691 Mdot
.49783 .48565 Mdot
.67623 .42357 Mdot
.22046 .59582 Mdot
.69075 .17888 Mdot
.44502 .5846 Mdot
.90628 .59095 Mdot
.0169 .53887 Mdot
.78033 .30562 Mdot
.51337 .16897 Mdot
.50815 .6277 Mdot
.16686 .03818 Mdot
.96764 .41079 Mdot
.66903 .55253 Mdot
.2914 .98722 Mdot
.44857 .95671 Mdot
.60066 .80835 Mdot
.00355 .37211 Mdot
.69438 .21739 Mdot
.98665 .83324 Mdot
.91405 .91178 Mdot
.47328 .66427 Mdot
.40589 .28407 Mdot
.30642 .62609 Mdot
.43826 .87328 Mdot
.63739 .07356 Mdot
.14685 .88606 Mdot
.18881 .11685 Mdot
.54619 .07771 Mdot
.18526 .74474 Mdot
.85181 .86032 Mdot
.19861 .9115 Mdot
.93777 .94854 Mdot
.72533 .24723 Mdot
.53187 .66447 Mdot
.41891 .62114 Mdot
.09362 .79119 Mdot
.78152 .54757 Mdot
.94677 .90513 Mdot
.59271 .43072 Mdot
.40057 .82742 Mdot
.40745 .68598 Mdot
.54876 .9671 Mdot
.20884 .77448 Mdot
.61099 .01856 Mdot
.48351 .52726 Mdot
.07912 .35409 Mdot
.0646 .90612 Mdot
.9855 .56291 Mdot
.28308 .35855 Mdot
.03874 .65778 Mdot
.69038 .92782 Mdot
.63817 .83036 Mdot
.28293 .24184 Mdot
.08941 .86325 Mdot
.07409 .46735 Mdot
.47842 .84469 Mdot
.59059 .9401 Mdot
.3993 .4906 Mdot
.52598 .03398 Mdot
.41379 .92769 Mdot
.2429 .67543 Mdot
.37506 .26991 Mdot
.55252 .74761 Mdot
.73689 .43956 Mdot
.26959 .50577 Mdot
.64748 .5763 Mdot
.1955 .03842 Mdot
.16907 .73161 Mdot
.60491 .09832 Mdot
.76977 .24102 Mdot
.07893 .06435 Mdot
.35598 .31333 Mdot
.83603 .38892 Mdot
.98092 .04342 Mdot
.28351 .64131 Mdot
.24403 .60386 Mdot
.01392 .13554 Mdot
.59655 .02756 Mdot
.81842 .09712 Mdot
.42748 .29594 Mdot
.21351 .99879 Mdot
.6577 .05493 Mdot
.13458 .93444 Mdot
.30173 .7416 Mdot
.29855 .54553 Mdot
.3208 .69818 Mdot
.01504 .90422 Mdot
.07677 .09432 Mdot
.00112 .76868 Mdot
.48023 .06677 Mdot
.1827 .67157 Mdot
.05275 .77082 Mdot
.96919 .67277 Mdot
.39505 .7159 Mdot
.83461 .73833 Mdot
.09332 .9743 Mdot
.53606 .1928 Mdot
.77252 .27611 Mdot
.52101 .28858 Mdot
.69575 .18179 Mdot
.51989 .5199 Mdot
.21552 .11502 Mdot
.33719 .84833 Mdot
.16276 .3442 Mdot
.368 .17556 Mdot
.76771 .6283 Mdot
.53339 .43723 Mdot
.67439 .654 Mdot
.99733 .24443 Mdot
.90187 .37789 Mdot
.47632 .95585 Mdot
.20612 .1961 Mdot
.95643 .43595 Mdot
.99061 .08108 Mdot
.61924 .58761 Mdot
.82784 .73688 Mdot
.25125 .41205 Mdot
.06013 .10858 Mdot
.71786 .97482 Mdot
.38574 .45458 Mdot
.72052 .73039 Mdot
.48387 .07669 Mdot
.2442 .77454 Mdot
.27775 .88059 Mdot
.28778 .33859 Mdot
.28714 .7995 Mdot
.66853 .75098 Mdot
.4593 .06262 Mdot
.41729 .33892 Mdot
.39917 .95404 Mdot
.69943 .3641 Mdot
.01343 .49946 Mdot
.97891 .63371 Mdot
.52957 .42277 Mdot
.7347 .85917 Mdot
.25182 .54219 Mdot
.44693 .52058 Mdot
.96468 .74268 Mdot
.7784 .7696 Mdot
.50538 .68006 Mdot
.36111 .43068 Mdot
.10621 .72602 Mdot
.66168 .06657 Mdot
.09278 .22656 Mdot
.68277 .43286 Mdot
.56321 .80379 Mdot
.94806 .57369 Mdot
.31139 .2616 Mdot
.50113 .05311 Mdot
.34671 .51891 Mdot
.72274 .28351 Mdot
.84133 .83885 Mdot
.36163 .85283 Mdot
.73512 .11283 Mdot
.69996 .78626 Mdot
.64234 .88627 Mdot
.01719 .35339 Mdot
.07913 .08248 Mdot
.06913 .7797 Mdot
.76774 .82088 Mdot
.56799 .72659 Mdot
.42103 .30197 Mdot
.84526 .44309 Mdot
.5797 .46312 Mdot
.48362 .59026 Mdot
.84459 .35029 Mdot
.78367 .804 Mdot
.20224 .46402 Mdot
.76648 .45061 Mdot
.12311 .38154 Mdot
.69735 .6709 Mdot
.35537 .56065 Mdot
.12936 .94431 Mdot
.93433 .25868 Mdot
.28411 .50122 Mdot
.35463 .79557 Mdot
.80048 .91097 Mdot
.51004 .44528 Mdot
.01681 .10697 Mdot
.3078 .98126 Mdot
.25033 .65636 Mdot
.18469 .59972 Mdot
.55298 .98545 Mdot
.82932 .03907 Mdot
.42362 .04114 Mdot
.89499 .78038 Mdot
.13951 .53992 Mdot
.54036 .98482 Mdot
.33903 .62895 Mdot
.03032 .53954 Mdot
.32222 .52199 Mdot
.72251 .55828 Mdot
.07189 .86563 Mdot
.53782 .95855 Mdot
.51891 .88018 Mdot
.7085 .91948 Mdot
.09529 .83903 Mdot
.81351 .1391 Mdot
.95578 .29912 Mdot
.27315 .15428 Mdot
.61675 .67016 Mdot
.24284 .61475 Mdot
.29452 .14818 Mdot
.52032 .05647 Mdot
.22264 .28254 Mdot
.9825 .09792 Mdot
.70372 .40237 Mdot
.274 .17843 Mdot
.60843 .56333 Mdot
.46049 .03934 Mdot
.65265 .26422 Mdot
.18734 .88505 Mdot
.03591 .59406 Mdot
.9445 .27031 Mdot
.74138 .44588 Mdot
.42418 .21384 Mdot
.51875 .16334 Mdot
.44168 .11592 Mdot
.81502 .76097 Mdot
.16768 .93748 Mdot
.20659 .19763 Mdot
.70719 .89815 Mdot
.55394 .93342 Mdot
.51985 .01309 Mdot
.51803 .33936 Mdot
.57535 .74279 Mdot
.77664 .89348 Mdot
.15118 .52895 Mdot
.25789 .73014 Mdot
.7095 .41303 Mdot
.44287 .96918 Mdot
.54183 .47555 Mdot
.23628 .77154 Mdot
.83464 .5774 Mdot
.68234 .83813 Mdot
.31478 .56431 Mdot
.16431 .49876 Mdot
.73943 .82152 Mdot
.38767 .60528 Mdot
.58825 .29257 Mdot
.12978 .87514 Mdot
.87875 .87953 Mdot
.68691 .90596 Mdot
.33692 .40398 Mdot
.45063 .13442 Mdot
.50228 .82658 Mdot
.76829 .29629 Mdot
.1875 .26227 Mdot
.60397 .79753 Mdot
.44807 .44076 Mdot
.2163 .19224 Mdot
.85982 .14819 Mdot
.08653 .31711 Mdot
.98107 .26865 Mdot
.39962 .41114 Mdot
.64415 .86467 Mdot
.949 .27672 Mdot
.14186 .03809 Mdot
.18071 .98043 Mdot
.95437 .77581 Mdot
.57674 .1829 Mdot
.5063 .33506 Mdot
.36043 .99066 Mdot
.64648 .18687 Mdot
.2739 .67355 Mdot
.66541 .91822 Mdot
.87428 .26241 Mdot
.02127 .05355 Mdot
.92529 .98568 Mdot
.8794 .01546 Mdot
.74458 .00526 Mdot
.92503 .23964 Mdot
.16784 .82236 Mdot
.41874 .90458 Mdot
.80741 .8317 Mdot
.77225 .71771 Mdot
.53351 .15815 Mdot
.10684 .7995 Mdot
.65922 .89574 Mdot
.08557 .74595 Mdot
.73394 .91006 Mdot
.20617 .73049 Mdot
.98936 .9048 Mdot
.28114 .49085 Mdot
.82152 .08245 Mdot
.8624 .58627 Mdot
.01411 .25075 Mdot
.09015 .86855 Mdot
.48061 .09259 Mdot
.98331 .06905 Mdot
.82138 .19685 Mdot
.89774 .3231 Mdot
.08744 .28679 Mdot
.69157 .59261 Mdot
.09808 .38199 Mdot
.41043 .10176 Mdot
.27656 .29954 Mdot
.54803 .51549 Mdot
.26245 .0488 Mdot
.45789 .64694 Mdot
.78184 .9562 Mdot
.47458 .57788 Mdot
.96046 .75935 Mdot
.57684 .25478 Mdot
.87302 .47256 Mdot
.88527 .66217 Mdot
.77494 .09057 Mdot
.47483 .56041 Mdot
.49837 .79103 Mdot
.9268 .04492 Mdot
.23592 .74223 Mdot
.46891 .39798 Mdot
.45408 .78603 Mdot
.99434 .8201 Mdot
.49362 .02668 Mdot
.4175 .56532 Mdot
.6206 .55412 Mdot
.53223 .90315 Mdot
.84566 .46354 Mdot
.0574 .34273 Mdot
.34729 .67251 Mdot
.1306 .29781 Mdot
.11136 .93028 Mdot
.66169 .89983 Mdot
.65728 .14425 Mdot
.66735 .07973 Mdot
.16367 .11757 Mdot
.24985 .51441 Mdot
.54307 .56345 Mdot
.71761 .61126 Mdot
.69741 .09991 Mdot
.66021 .26853 Mdot
.35013 .4274 Mdot
.52961 .97072 Mdot
.23877 .49712 Mdot
.86792 .07089 Mdot
.58148 .35287 Mdot
.20057 .99116 Mdot
.41781 .23529 Mdot
.95072 .47675 Mdot
.87474 .67184 Mdot
.23311 .86549 Mdot
.17732 .57193 Mdot
.57289 .59696 Mdot
.8272 .14454 Mdot
.04328 .62625 Mdot
.58843 .64742 Mdot
.17536 .55536 Mdot
.00695 .29456 Mdot
.9748 .56419 Mdot
.58914 .05926 Mdot
.02408 .08744 Mdot
.7144 .38742 Mdot
.79097 .22195 Mdot
.53708 .81549 Mdot
.21808 .62498 Mdot
.70988 .67095 Mdot
.17479 .99874 Mdot
.12145 .02353 Mdot
.99943 .44338 Mdot
.1145 .72898 Mdot
.02463 .87918 Mdot
.52536 .66972 Mdot
.00056 .79174 Mdot
.81096 .2823 Mdot
.20959 .56979 Mdot
.27388 .46681 Mdot
.99151 .94481 Mdot
.564 .79585 Mdot
.81672 .94607 Mdot
.44255 .77232 Mdot
.81729 .5027 Mdot
.32806 .04335 Mdot
.79266 .62351 Mdot
.8027 .37363 Mdot
.7921 .83177 Mdot
.99174 .09134 Mdot
.58252 .26198 Mdot
.71786 .62453 Mdot
.591 .31716 Mdot
.15385 .82868 Mdot
.77428 .37109 Mdot
.7113 .05635 Mdot
.95699 .86839 Mdot
.5 Mabswid
newpath
.33333 .33333 .06667 0 365.73 arc
s
newpath
.5 .5 .06667 0 365.73 arc
s
newpath
.66667 .66667 .06667 0 365.73 arc
s
1 0 0 r
.008 w
.3494 .37722 Mdot
.36302 .31871 Mdot
.37363 .32244 Mdot
.30778 .31789 Mdot
.32979 .30404 Mdot
.38693 .26822 Mdot
.33211 .32131 Mdot
.30006 .32113 Mdot
.35598 .31333 Mdot
.26729 .29704 Mdot
0 0 1 r
.53409 .5685 Mdot
.47483 .56041 Mdot
.52907 .49747 Mdot
.49783 .48565 Mdot
.45036 .56924 Mdot
.4668 .492 Mdot
.51989 .5199 Mdot
.54803 .51549 Mdot
.48308 .42631 Mdot
.48351 .52726 Mdot
0 1 0 r
.71527 .71251 Mdot
.69157 .59261 Mdot
.67439 .654 Mdot
.72052 .73039 Mdot
.61675 .67016 Mdot
.72289 .66036 Mdot
.70988 .67095 Mdot
.73774 .659 Mdot
.60587 .7027 Mdot
.69735 .6709 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[176]:=",
  ImageSize->{481.375, 481.375},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40007Q0001hA000`40O003h00OogoohWoo003oOooR
Ool00?moon9oo`00ogoohWoo001HOol30004Ool20013Ool40003Ool20014Ool30004Ool20014Ool3
0003Ool20013Ool30004Ool20014Ool20004Ool20003Ool005Uoo`03001oogoo009oo`04001oogoo
0013Ool00`00Oomoo`02Ool01000Oomoo`00AWoo00@007ooOol0009oo`03001oogoo049oo`05001o
ogooOol00002Ool00`00Oomoo`13Ool01000Oomoo`000Woo00<007ooOol0@7oo00@007ooOol0009o
o`04001oogoo0002Ool005Uoo`03001oogoo009oo`04001oogoo0014Ool01@00Oomoogoo00000Woo
00<007ooOol0A7oo00@007ooOol0009oo`03001oogoo041oo`@0009oo`04001oogoo0015Ool01000
Oomoo`000Woo00<007ooOol0@7oo00@007ooOol0009oo`04001oogoo0002Ool005Uoo`03001oogoo
009oo`04001oogoo0015Ool01000Oomoo`000Woo00<007ooOol0@Woo0P000goo00@007ooOol0049o
o`03001oo`0000=oo`04001oogoo0012Ool30003Ool01000Oomoo`00@Woo0`000goo00@007ooOol0
009oo`00FGoo00<007ooOol00Woo00@007ooOol0049oo`04001oogoo0002Ool01000Oomoo`00AWoo
00@007ooOol0009oo`03001oogoo041oo`03001oo`0000=oo`04001oogoo0012Ool00`00Oomoo`03
Ool01000Oomoo`00@Woo00<007ooOol00goo00@007ooOol0009oo`00F7oo0P001Goo0P00A7oo0P00
17oo0P00A7oo0`0017oo0P00A7oo0P0017oo0P00@goo10000goo0P00A7oo0`000goo0P000goo003o
OooROol00?moon9oo`00ogoohWoo003oOooROol00?moon9oo`00ogoohWoo003oOooROol0015oool0
0</000Ioo`004Goo00<007ooOol037oo00<007ooOol03Goo00<007ooOol037oo00<007ooOol037oo
00<007ooOol037oo00<007ooOol03Goo00<007ooOol037oo00<007ooOol037oo00<007ooOol037oo
00<007ooOol037oo00<007ooOol03Goo00<007ooOol037oo00<007ooOol037oo00<007ooOol037oo
00<007ooOol03Goo00<007ooOol037oo00<007ooOol037oo00<007ooOol037oo00<007ooOol037oo
00<007ooOol03Goo00<007ooOol037oo00<007ooOol037oo00<007ooOol037oo00<007ooOol03Goo
00<007ooOol037oo00<007ooOol037oo00<007ooOol037oo00<007ooOol037oo00<007ooOol03Goo
00<007ooOol037oo00<007ooOol017oo000AOol00`00Oomoo`0<Ool00`00Oomoo`0=Ool00`00Oomo
o`0<Ool00`00Oomoo`0<Ool00`00Oomoo`0<Ool00`00Oomoo`0=Ool00`00Oomoo`0<Ool00`00Oomo
o`0<Ool00`00Oomoo`0<Ool00`00Oomoo`0<Ool00`00Oomoo`0=Ool00`00Oomoo`0<Ool00`00Oomo
o`0<Ool00`00Oomoo`0<Ool00`00Oomoo`0=Ool00`00Oomoo`0<Ool00`00Oomoo`0<Ool00`00Oomo
o`0<Ool00`00Oomoo`0<Ool00`00Oomoo`0=Ool00`00Oomoo`0<Ool00`00Oomoo`07Ool00`00Oomo
o`02Ool00`00Oomoo`02Ool00`00Oomoo`07Ool00`00Oomoo`02Ool00`00Oomoo`08Ool00`00Oomo
o`09Ool01000Oomoo`003Woo00<007ooOol037oo00<007ooOol037oo00<007ooOol03Goo00<007oo
Ool037oo00<007ooOol017oo000AOol00`00Oomoo`19Ool00`00Oomoo`19Ool00`00Oomoo`0_Ool0
0`00Oomoo`0<Ool00`00Oomoo`09Ool00`00Oomoo`19Ool00`00Oomoo`19Ool00`00Oomoo`19Ool0
0`00Oomoo`04Ool0015oo`03001oogoo025oo`03001oogoo0?moojYoo`004Goo00<007ooOol0Egoo
00<007ooOol05Goo00<007ooOol0kGoo00<007ooOol0Jgoo000AOol00`00Oomoo`2AOol00`00Oomo
o`1GOol00`00Oomoo`3OOol0015oo`03001oogoo0?mooi1oo`03001oogoo03]oo`004Goo00<007oo
Ool02Woo00<007ooOol0ogoo27oo00<007ooOol0]Woo000AOol00`00Oomoo`1HOol00`00Oomoo`3o
OomcOol0015oo`03001oogoo029oo`03001oogoo03]oo`03001oogoo0?moof]oo`004Goo00<007oo
Ool0=Goo00<007ooOol0HWoo00<007ooOol0ogoo<Goo000AOol00`00Oomoo`3OOol00`00Oomoo`3[
Ool0015oo`03001oogoo04Ioo`03001oogoo0<Eoo`03001oogoo0;aoo`004Goo00<007ooOol0ogoo
3goo00<007ooOol0_7oo000AOol3003oOol_Ool00`00Oomoo`2LOol0015oo`04001oogoo0031Ool0
0`00Oomoo`0XOol00`00Oomoo`0MOol00`00Oomoo`19Ool00`00Oomoo`1aOol0015oo`03001oogoo
03ioo`03001oogoo00Qoo`03001oogoo03Uoo`03001oogoo0?moodIoo`004Goo00<007ooOol0Egoo
00<007ooOol0MWoo00<007ooOol0BGoo00<007ooOol0FGoo00<007ooOol0DWoo000AOol00`00Oomo
o`0FOol00`00Oomoo`2VOol00`00Oomoo`02Ool00`00Oomoo`3oOol7Ool0015oo`03001oogoo08Mo
o`03001oogoo00Uoo`03001oogoo00Qoo`03001oogoo03Eoo`03001oogoo0>Aoo`03001oogoo00eo
o`004Goo00<007ooOol0`Goo00<007ooOol0hGoo00<007ooOol09Goo000AOol00`00Oomoo`0EOol0
0`00Oomoo`1MOol00`00Oomoo`3DOol00`00Oomoo`1nOol0015oo`03001oogoo0?mooaUoo`03001o
ogoo04Uoo`03001oogoo00Uoo`03001oogoo05Yoo`004Goo00<007ooOol01goo00<007ooOol0P7oo
00<007ooOol0EGoo00<007ooOol0j7oo000AOol00`00Oomoo`2iOol00`00Oomoo`1MOol00`00Oomo
o`0>Ool00`00Oomoo`16Ool00`00Oomoo`1GOol0015oo`03001oogoo0>]oo`03001oogoo04moo`03
001oogoo009oo`03001oogoo00moo`03001oogoo07Ioo`004Goo00<007ooOol0AWoo00<007ooOol0
SWoo00<007ooOol0<7oo00<007ooOol0`7oo000AOol00`00Oomoo`3oOoo>Ool0015oo`03001oogoo
025oo`03001oogoo0:]oo`03001oogoo0?]oo`004Goo00<007ooOol0ogoo;7oo00<007ooOol0Wgoo
000AOol30033Ool00`00Oomoo`0COol00`00Oomoo`21Ool00`00Oomoo`1]Ool0015oo`03001oogoo
01]oo`03001oogoo00aoo`03001oogoo09Aoo`03001oogoo0<Ioo`03001oogoo035oo`03001oogoo
00aoo`004Goo00<007ooOol0ogoocWoo000AOol00`00Oomoo`3COol00`00Oomoo`1:Ool00`00Oomo
o`2ZOol0015oo`03001oogoo0=Yoo`03001oogoo06eoo`03001oogoo081oo`004Goo00<007ooOol0
mgoo00<007ooOol00goo00<007ooOol0;Woo00<007ooOol0W7oo000AOol00`00Oomoo`3oOommOol0
0`00Oomoo`13Ool00`00Oomoo`08Ool0015oo`03001oogoo025oo`03001oogoo0?mooe5oo`03001o
ogoo05Ioo`004Goo00<007ooOol0ogoo>Goo00<007ooOol0DGoo00<007ooOol0?Woo000AOol00`00
Oomoo`08Ool2000FOol00`00Oomoo`2^Ool00`00Oomoo`3iOol0015oo`03001oogoo0?moo`]oo`03
001oogoo059oo`03001oogoo01Yoo`03001oogoo01Qoo`03001oogoo03=oo`004Goo00<007ooOol0
Q7oo00<007ooOol0<7oo00<007ooOol07goo00<007ooOol0iWoo00<007ooOol027oo000AOol00`00
Oomoo`0POol00`00Oomoo`1VOol00`00Oomoo`3oOom2Ool0015oo`03001oogoo0?moogAoo`03001o
ogoo05Moo`004Goo00<007ooOol0C7oo00<007ooOol0EGoo00<007ooOol0Jgoo00<007ooOol0FWoo
00<007ooOol0C7oo00<007ooOol037oo000AOol3002iOol00`00Oomoo`0[Ool00`00Oomoo`1BOol0
0`00Oomoo`2>Ool0015oo`03001oogoo0?mooeAoo`03001oogoo07Moo`004Goo00<007ooOol0ogoo
1Goo00<007ooOol0aWoo000AOol00`00Oomoo`05Ool00`00Oomoo`2oOol00`00Oomoo`0nOol00`00
Oomoo`32Ool0015oo`03001oogoo01Ioo`04001oogoo000[Ool00`00Oomoo`2hOol00`00Oomoo`3:
Ool0015oo`03001oogoo06eoo`03001oogoo0?moodUoo`03001oogoo019oo`004Goo00<007ooOol0
ogooCWoo00<007ooOol0OGoo000AOol00`00Oomoo`1COol00`00Oomoo`0:Ool00`00Oomoo`0POol0
0`00Oomoo`0aOol00`00Oomoo`0=Ool00`00Oomoo`3oOol4Ool0015oo`03001oogoo04Qoo`03001o
ogoo03Ioo`03001oogoo04Uoo`03001oogoo0?5oo`03001oogoo00Uoo`004Goo00<007ooOol0ogoo
<goo00<007ooOol0V7oo000AOol00`00Oomoo`3oOoo>Ool0015oo`03001oogoo0?mood1oo`03001o
ogoo08]oo`004Goo00@007ooOol00?mooh1oo`03001oo`0004Yoo`004Goo00<007ooOol0GWoo00<0
07ooOol0ogooKGoo000AOol00`00Oomoo`2LOol00`00Oomoo`3oOol_Ool0015oo`<00<1oo`03001o
ogoo00Qoo`03001oogoo03Aoo`03001oogoo0:eoo`03001oogoo01Qoo`004Goo00<007ooOol017oo
00<007ooOol0/goo00<007ooOol0ogoo4Goo000AOol00`00Oomoo`1=Ool00`00Oomoo`3oOomnOol0
015oo`03001oogoo09aoo`03001oogoo095oo`03001oogoo03ioo`03001oogoo02Yoo`03001oogoo
02aoo`004Goo00<007ooOol0UWoo00<007ooOol0ogoo=Goo000AOol00`00Oomoo`1hOol00`00Oomo
o`2^Ool00`00Oomoo`0QOol00`00Oomoo`0WOol00`00Oomoo`0XOol00`00Oomoo`0XOol0015oo`03
001oogoo03Eoo`03001oogoo02=oo`03001oogoo0?moog1oo`004Goo00<007ooOol06Woo00<007oo
Ool0Igoo00<007ooOol05Woo00<007ooOol0iWoo00<007ooOol0A7oo000AOol00`00Oomoo`10Ool0
0`00Oomoo`3oOomKOol00`00Oomoo`0]Ool0015oo`03001oogoo07Yoo`03001oogoo0?mooe5oo`00
4Goo00<007ooOol0ogoocWoo000AOol00`00Oomoo`1VOol00`00Oomoo`28Ool00`00Oomoo`3IOol0
015oo`03001oogoo0:Uoo`03001oogoo019oo`03001oogoo04Qoo`03001oogoo0<5oo`0000Aoo`00
000000Aoo`8000Moo`03001oogoo06Uoo`03001oogoo0<aoo`03001oogoo08Uoo`03001oogoo00Io
o`000Woo00<007ooOol00Woo00@007ooOol000Ioo`03001oogoo0>Yoo`03001oogoo0>1oo`000Woo
00<007ooOol00Woo00@007ooOol000Ioo`@00?moojUoo`03001oogoo025oo`000Woo00<007ooOol0
0Woo00@007ooOol000Ioo`03001oogoo085oo`03001oogoo06Aoo`03001oogoo0>9oo`000Woo00<0
07ooOol00Woo00@007ooOol000Ioo`03001oogoo0=Aoo`03001oogoo0?Ioo`0000=oo`0000001Goo
0P001goo00<007ooOol0ogoo@goo00<007ooOol0R7oo000AOol00`00Oomoo`2UOol00`00Oomoo`3o
OolVOol0015oo`03001oogoo011oo`03001oogoo075oo`03001oogoo03Qoo`03001oogoo0?moo`ao
o`004Goo00<007ooOol0NWoo00<007ooOol0_7oo00<007ooOol0TGoo000AOol00`00Oomoo`2mOol0
0`00Oomoo`0[Ool00`00Oomoo`1=Ool00`00Oomoo`2?Ool0015oo`03001oogoo0?moo`Ioo`03001o
ogoo04Moo`03001oogoo00Eoo`03001oogoo02Aoo`03001oogoo04aoo`004Goo00<007ooOol0<7oo
00<007ooOol0lGoo00<007ooOol0YWoo000AOol00`00Oomoo`3oOoo>Ool0015oo`03001oogoo0?mo
olioo`004Goo00<007ooOol0H7oo00<007ooOol0Hgoo00<007ooOol0:Goo00<007ooOol0f7oo000A
Ool00`00Oomoo`1bOol00`00Oomoo`0;Ool00`00Oomoo`3?Ool00`00Oomoo`1hOol0015oo`03001o
ogoo05]oo`800?mooaQoo`03001oogoo05Ioo`004Goo0`00ogoocWoo000AOol00`00Oomoo`3oOoo>
Ool0015oo`03001oogoo04moo`03001oogoo0:Eoo`03001oogoo0==oo`004Goo00<007ooOol0o7oo
00<007ooOol0BGoo00<007ooOol0@7oo00<007ooOol0?goo000AOol00`00Oomoo`3oOoo>Ool0015o
o`03001oogoo00moo`03001oogoo0?mookaoo`004Goo00<007ooOol0kGoo00<007ooOol0gGoo000A
Ool00`00Oomoo`1EOol00`00Oomoo`1WOol00`00Oomoo`3NOol00`00Oomoo`0ZOol0015oo`03001o
ogoo0?Aoo`03001oogoo019oo`03001oogoo02]oo`04001oogoo002BOol0015oo`03001oogoo02Mo
o`03001oogoo0;Ioo`03001oogoo08Qoo`03001oogoo05moo`004Goo00<007ooOol0ogooIgoo00<0
07ooOol0I7oo000AOol00`00Oomoo`2mOol00`00Oomoo`3oOol>Ool0015oo`03001oogoo02Qoo`03
001oogoo03=oo`03001oogoo0?moofeoo`004Goo00<007ooOol0Rgoo00<007ooOol0ogoo@7oo000A
Ool00`00Oomoo`18Ool00`00Oomoo`1QOol00`00Oomoo`3oOolOOol0015oo`03001oogoo03Eoo`03
001oogoo0?mooh=oo`03001oogoo011oo`004Goo0`00_7oo00<007ooOol067oo00<007ooOol0lgoo
000AOol00`00Oomoo`0]Ool00`00Oomoo`04Ool00`00Oomoo`3oOomiOol00`00Oomoo`0KOol0015o
o`03001oogoo04Eoo`03001oogoo07Qoo`03001oogoo0>5oo`03001oogoo02Ioo`004Goo00<007oo
Ool0OWoo00<007ooOol03Woo00<007ooOol0bgoo00<007ooOol0KGoo000AOol00`00Oomoo`3oOoo>
Ool0015oo`03001oogoo0?moof9oo`03001oogoo05]oo`03001oogoo00=oo`03001oogoo00Eoo`00
4Goo00<007ooOol0ogooBWoo00<007ooOol0PGoo000AOol00`00Oomoo`1HOol00`00Oomoo`1BOol0
0`00Oomoo`3oOolNOol0015oo`03001oogoo00Aoo`03001oogoo0?moolMoo`004Goo00<007ooOol0
ogoo1Woo00<007ooOol0Zgoo00<007ooOol05goo000AOol00`00Oomoo`3oOoo>Ool0015oo`03001o
ogoo0?moojUoo`03001oogoo029oo`004Goo00<007ooOol087oo00<007ooOol0J7oo00<007ooOol0
Dgoo00<007ooOol0OGoo00<007ooOol0JGoo000AOol00`00Oomoo`1COol00`00Oomoo`2aOol00`00
Oomoo`23Ool00`00Oomoo`0mOol0015oo`03001oogoo0?moobQoo`03001oogoo04ioo`03001oogoo
059oo`004Goo0`00TGoo3@003goo0g`0aGoo00<007ooOol0EGoo000AOol00`00Oomoo`0:Ool00`00
Oomoo`1nOol6000=Ool30008Ool01000Oomoogoo0g`0:7oo00<007ooOol0D7oo00<007ooOol0Ogoo
00<007ooOol03Goo00<007ooOol03Goo000AOol00`00Oomoo`2:Ool00`00Oomoo`0DOol2000:Ool3
O01FOol00`00Oomoo`34Ool0015oo`03001oogoo079oo`03001oogoo01=oo`8001Uoo`800?moobUo
o`004Goo00<007ooOol0QWoo0P007Goo00<007ooOol0<7oo00<007ooOol0AGoo00<007ooOol0>goo
00<007ooOol07goo00<007ooOol0;7oo00<007ooOol06goo000AOol00`00Oomoo`25Ool00`00Oomo
o`0NOol00`00Oomoo`3oOolUOol0015oo`03001oogoo04Eoo`03001oogoo029oo`03001oogoo01Io
o`80029oo`03001oogoo0?moobAoo`004Goo00<007ooOol0>Woo00<007ooOol09Woo00<007ooOol0
6goo0P009Goo0P00WGoo00<007ooOol09Woo00<007ooOol0FWoo000AOol00`00Ool0000gOol00`00
Oomoo`17Ool00`00Oomoo`0VOol00`00Oomoo`0:Ool00`00Oomoo`3oOolDOol0015oo`03001oogoo
02Eoo`03001oogoo05Qoo`03001oogoo02Qoo`03001oogoo02eoo`03001oo`00079oo`03001oogoo
07Yoo`004Goo00<007ooOol0A7oo00<007ooOol0>7oo00<007ooOol0:Woo00<007ooOol03goo00<0
07ooOol05goo00<007ooOol047oo00<007ooOol077oo00<007ooOol0`7oo000AOol00`00Oomoo`1n
Ool00`00Oomoo`08Ool00`00Oomoo`0QOol00`00Oomoo`3oOolNOol0015oo`03001oogoo07eoo`03
001oogoo02ioo`03001oogoo05Uoo`03001oogoo08Yoo`03001oogoo03=oo`004Goo00@007ooOol0
07Eoo`=l00=oo`03001oogoo031oo`03001oogoo00ioo`03001oogoo01Yoo`03001oogoo07aoo`03
001oogoo06ioo`004Goo00<007ooOol0>Goo00<007ooOol0>Woo0g`00Woo00<007ooOol0<Goo00<0
07ooOol03Woo00<007ooOol0ogoo2goo000AOol3001fOol3O002Ool2000cOol00`00Oomoo`0ZOol0
0`00Oomoo`3BOol00`00Oomoo`0HOol0015oo`03001oogoo07Yoo`03001oogoo01Ioo`=l01Yoo`03
001oogoo00]oo`03001oogoo06Uoo`03001oogoo0:1oo`004Goo00<007ooOol0NGoo0P0067oo0g`0
6Woo00<007ooOol0ogoo6goo000AOol00`00Oomoo`1jOol00`00Oomoo`0FOol3O00KOol00`00Oomo
o`2^Ool00`00Oomoo`1XOol0015oo`03001oogoo07Uoo`03001oogoo03Eoo`03001oogoo07ioo`03
001oogoo09Qoo`004Goo00<007ooOol0NGoo00<007ooOol08Woo0g`04Goo00<007ooOol0A7oo00<0
07ooOol027oo00<007ooOol0?goo00<007ooOol0Q7oo000AOol00`00Oomoo`1iOol00`00Oomoo`0R
Ool3O00BOol00`00Oomoo`10Ool00`00Oomoo`1=Ool00`00Oomoo`1[Ool00`00Oomoo`0FOol0015o
o`03001oogoo07Qoo`03001oogoo02=oo`=l019oo`03001oogoo0;moo`03001oogoo05Eoo`004Goo
00<007ooOol09Goo00<007ooOol0D7oo00<007ooOol03Goo0g`05goo0g`03Woo00<007ooOol0EGoo
00<007ooOol0_goo000AOol00`00Oomoo`1hOol00`00Oomoo`0:Ool6O009Ool3O00;Ool3O00>Ool0
0`00Oomoo`3oOolHOol0015oo`03001oogoo07Moo`03001oogoo00]oo`Il00Uoo`=l00]oo`=l009o
o`=l00Uoo`03001oogoo0:Ioo`03001oogoo06ioo`004Goo00<007ooOol08Goo00<007ooOol0Dgoo
00<007ooOol02goo0g`037oo0g`047oo0g`02Woo00<007ooOol0h7oo00<007ooOol07Goo00<007oo
Ool04goo000AOol00`00Oomoo`1gOol00`00Oomoo`0]Ool3O00:Ool00`00Oomoo`3oOolGOol00003
Ool00000008000=oo`8000Moo`03001oogoo02Uoo`03001oogoo04]oo`03001oogoo03Yoo`03001o
ogoo04Qoo`03001oogoo0<]oo`000Woo00<007ooOol00Woo00@007ooOol000Ioo`03001oogoo07Mo
o`03001oogoo03Yoo`03001oogoo01]oo`03001oogoo0?Qoo`000goo00D007ooOomoo`00009oo`03
001oogoo00Aoo`@006eoo`03001oogoo00Ioo`03001oogoo03Yoo`03001oogoo04=oo`03001oogoo
0=1oo`0017oo00@007ooOol0009oo`03001oogoo00Aoo`03001oogoo04Moo`03001oogoo02eoo`03
001oogoo03Yoo`03001oogoo01Yoo`03001oogoo00Ioo`03001oogoo00Moo`03001oogoo0>Ioo`00
00Eoo`00Oomoo`00009oo`04001oogoo0006Ool00`00Oomoo`1gOol00`00Oomoo`0jOol00`00Oomo
o`3oOolGOol0009oo`8000Aoo`8000Moo`03001oogoo055oo`03001oogoo02=oo`03001oogoo00Mo
o`03001oogoo031oo`03001oogoo00Eoo`03001oogoo02]oo`03001oogoo0>1oo`004Goo00<007oo
Ool0Mgoo00<007ooOol0>Woo00<007ooOol0ogoo5goo000AOol00`00Oomoo`0GOol00`00Oomoo`0^
Ool00`00Oomoo`0/Ool00`00Oomoo`0iOol00`00Oomoo`0gOol00`00Oomoo`1mOol00`00Oomoo`1M
Ool0015oo`03001oogoo07Moo`03001oogoo03Uoo`03001oogoo0?mooaQoo`004Goo00<007ooOol0
N7oo00<007ooOol0>7oo00<007ooOol0;goo00<007ooOol0@7oo00<007ooOol0XWoo000AOol00`00
Oomoo`0MOol00`00Oomoo`1HOol00`00Oomoo`0hOol00`00Oomoo`39Ool00`00Oomoo`11Ool00`00
Oomoo`07Ool0015oo`03001oogoo00Eoo`03001oogoo00]oo`03001oogoo069oo`03001oogoo03Qo
o`03001oogoo055oo`03001oogoo0<=oo`004Goo00<007ooOol08Goo00<007ooOol0EGoo00<007oo
Ool0=goo00<007ooOol0?goo00<007ooOol0eGoo000AOol00`00Oomoo`1iOol00`00Oomoo`0fOol0
0`00Oomoo`3JOol00`00Oomoo`0kOol0015oo`03001oogoo01ioo`03001oogoo05Ioo`03001oo`00
00Eoo`03001oogoo02moo`03001oogoo0?mooaYoo`004Goo00<007ooOol0NWoo00<007ooOol0;7oo
00<007ooOol01Goo00<007ooOol057oo00<007ooOol0ogoo0goo000AOol00`00Oomoo`0;Ool00`00
Oomoo`0XOol00`00Oomoo`11Ool00`00Oomoo`0cOol00`00Oomoo`2:Ool00`00Oomoo`2=Ool0015o
o`03001oogoo07Yoo`03001oogoo03=oo`03001oogoo0?mooa]oo`004Goo0`00Ngoo00<007ooOol0
<Woo00<007ooOol0Agoo00<007ooOol0d7oo000AOol00`00Oomoo`1kOol00`00Oomoo`0aOol00`00
Oomoo`0;Ool00`00Oomoo`0SOol00`00Oomoo`1iOol00`00Oomoo`0XOol00`00Oomoo`10Ool0015o
o`03001oo`0007aoo`03001oogoo031oo`03001oogoo0?mooaaoo`004Goo00<007ooOol09Goo00<0
07ooOol0EGoo00<007ooOol0;Woo00<007ooOol0S7oo00<007ooOol0;7oo00<007ooOol0GWoo000A
Ool00`00Oomoo`1nOol00`00Oomoo`0JOol3O00?Ool00`00Oomoo`3oOolNOol0015oo`03001oogoo
051oo`03001oogoo02aoo`03001oogoo01Uoo`=l00ioo`03001oogoo03Ioo`03001oogoo05=oo`03
001oogoo03]oo`03001oogoo01eoo`03001oogoo035oo`004Goo00<007ooOol0:Woo00<007ooOol0
27oo00<007ooOol0B7oo00<007ooOol067oo0g`037oo0P00ogoo8Woo000AOol00`00Oomoo`21Ool2
000VOol00`00Oomoo`3fOol00`00Oomoo`0XOol0015oo`03001oogoo08=oo`03001oogoo029oo`03
001oogoo07aoo`03001oogoo025oo`03001oogoo07moo`004Goo00<007ooOol087oo00<007ooOol0
HGoo00<007ooOol087oo00<007ooOol0VWoo00<007ooOol0QWoo000AOol00`00Oomoo`1AOol00`00
Oomoo`06Ool00`00Oomoo`0XOol00`00Oomoo`0MOol2002BOol00`00Oomoo`0<Ool00`00Oomoo`0`
Ool00`00Oomoo`1?Ool0015oo`03001oogoo08Ioo`<001Yoo`8003Eoo`03001oogoo0:]oo`03001o
ogoo049oo`004Goo00<007ooOol0RGoo0`005Woo00<007ooOol0M7oo00<007ooOol0OWoo00<007oo
Ool05goo00<007ooOol05Woo000AOol00`00Oomoo`2<Ool3000AOol2003oOol/Ool0015oo`03001o
ogoo06moo`03001oogoo01eoo`<000Qoo`H003=oo`03001oogoo0>Eoo`03001oogoo00moo`004Goo
0`00T7oo00<007oo00001`00Egoo00<007ooOol0fGoo000AOol00`00Oomoo`3oOom0Ool00`00Oomo
o`2;Ool0015oo`03001oogoo09Moo`03001oogoo0?moocAoo`004Goo00<007ooOol0ogoocWoo000A
Ool00`00Oomoo`2mOol00`00Oomoo`0ZOol00`00Oomoo`3POol0015oo`03001oogoo071oo`03001o
ogoo045oo`03001oogoo00aoo`03001oogoo0?5oo`03001oogoo01=oo`004Goo00<007ooOol0ogoo
4Woo00<007ooOol0;Goo00<007ooOol0RGoo000AOol00`00Oomoo`3oOoo>Ool0015oo`03001oogoo
0?moo`Yoo`03001oogoo0:Yoo`03001oogoo01Aoo`004Goo00<007ooOol0ogoocWoo000AOol00`00
Oomoo`3_Ool00`00Oomoo`10Ool00`00Oomoo`2HOol0015oo`03001oogoo0=Uoo`<07o5oo`004Goo
00<007ooOol0WGoo00<007ooOol0>Goo0`0OlGoo000AOol00`00Oomoo`3IOol301oaOol0015oo`03
001oogoo0:9oo`03001oogoo05Qoo`03001oogoo00aoo`03001oogoo0;ioo`004Goo0`00gGoo3@00
Bgoo00<007ooOol0F7oo00<007ooOol0>Woo000AOol00`00Oomoo`3JOol3000=Ool3001<Ool00`00
Oomoo`0POol00`00Oomoo`1COol00`00Oomoo`0HOol0015oo`03001oogoo025oo`03001oogoo0;=o
o`<001=oo`80009oo`03001oogoo0=Uoo`004Goo00<007ooOol0bWoo00<007ooOol01goo0`0067oo
0P00GGoo00<007ooOol0O7oo000AOol00`00Oomoo`3BOol2000MOol00`00Oomoo`1]Ool00`00Oomo
o`0KOol00`00Oomoo`14Ool00`00Oomoo`04Ool0015oo`03001oogoo01ioo`03001oogoo0;1oo`03
001oogoo019oo`03001oogoo00Uoo`800=Uoo`004Goo00<007ooOol0cgoo0P008goo00<007ooOol0
FGoo00<007ooOol0NWoo000AOol00`00Oomoo`3>Ool00`00Oomoo`0TOol00`00Oomoo`0QOol00`00
Oomoo`2aOol0015oo`03001oogoo0<eoo`03001oogoo02Ioo`03001oogoo069oo`03001oogoo06mo
o`004Goo00<007ooOol0c7oo00<007ooOol0:7oo00<007ooOol0K7oo00<007ooOol0I7oo000AOol0
0`00Oomoo`2]Ool00`00Oomoo`0KOol00`00Oomoo`0ZOol00`00Oomoo`1ZOol00`00Oomoo`1UOol0
015oo`03001oogoo0<Yoo`03001oogoo02aoo`03001oogoo0=5oo`004Goo00<007ooOol0bGoo00<0
07ooOol0;Woo00<007ooOol0d7oo000AOol00`00Oomoo`39Ool00`00Oomoo`0_Ool00`00Oomoo`16
Ool00`00Oomoo`04Ool00`00Oomoo`1oOol0015oo`03001oogoo05Eoo`03001oogoo009oo`03001o
ogoo06]oo`03001oogoo01Yoo`03001oogoo01=oo`03001oogoo00Qoo`03001oogoo07Ioo`03001o
ogoo00moo`03001oogoo03Uoo`004Goo0`007goo00<007ooOol0>7oo00<007ooOol07Goo00<007oo
Ool05Goo00<007ooOol01Goo00<007ooOol0:goo00<007ooOol0<Goo00<007ooOol0cWoo000AOol0
0`00Oomoo`37Ool00`00Oomoo`0bOol00`00Oomoo`3>Ool0015oo`03001oogoo0<Ioo`03001oogoo
03=oo`03001oogoo0<ioo`004Goo00<007ooOol0aWoo00<007oo0000=7oo00<007ooOol0S7oo00<0
07ooOol0?Woo000AOol00`00Oomoo`35Ool00`00Oomoo`0]Ool00`00Oomoo`06Ool00`00Oomoo`2N
Ool00`00Oomoo`0[Ool0015oo`03001oogoo0<Eoo`03001oogoo03Ioo`03001oogoo09Aoo`03001o
ogoo01Moo`03001oogoo01]oo`004Goo00<007ooOol0LWoo00<007ooOol0D7oo00<007ooOol0=goo
00<007ooOol0bgoo000AOol00`00Oomoo`34Ool00`00Oomoo`0hOol00`00Oomoo`0eOol00`00Oomo
o`2COol0015oo`03001oogoo0<Aoo`03001oogoo01Qoo`<07aeoo`03001oogoo00Eoo`03001oogoo
06Ioo`03001oogoo03]oo`03001oogoo01aoo`004Goo00<007ooOol0a7oo00<007ooOol067oo0`0O
7Goo00<007ooOol0bgoo000AOol00`00Oomoo`33Ool00`00Oomoo`0IOol301lMOol00`00Oomoo`3;
Ool0015oo`03001oogoo07ioo`03001oogoo03=oo`03001oogoo00aoo`03001oogoo00]oo`<07bao
o`03001oogoo08Qoo`03001oogoo03moo`004Goo00<007ooOol0`goo00<007ooOol02goo0`0O;7oo
00<007ooOol0bWoo000017oo0000000017oo0P001goo00<007ooOol00Woo00<007ooOol05Woo00<0
07ooOol04goo00<007ooOol0Sgoo00<007ooOol02goo0`0O;7oo00<007ooOol0bWoo0004Ool01000
Oomoo`000Woo00<007ooOol017oo00<007ooOol0JWoo00<007ooOol0EWoo00<007ooOol0:7oo0`0O
3goo00<007ooOol05Woo00<007ooOol0/Goo0004Ool01000Oomoo`000Woo00<007ooOol017oo1000
0Woo00<007ooOol0@Woo00<007ooOol0N7oo00<007ooOol0:7oo0`0O3goo00<007ooOol0bWoo0002
Ool20003Ool01000Oomoo`001Woo00<007ooOol0Ogoo00<007ooOol0?Goo00D007ooOomoo`0002Yo
o`<07`moo`03001oogoo0<Yoo`0017oo00@007ooOol0009oo`03001oogoo00Aoo`03001oogoo0<=o
o`03001oogoo03Yoo`03001oogoo071oo`03001oogoo05Moo`0000Aoo`00000000Aoo`8000Moo`03
001oogoo07Qoo`03001oogoo04Qoo`03001oogoo03Yoo`03001oogoo0<Yoo`004Goo00<007ooOol0
@goo00<007ooOol0OGoo00<007ooOol0>Woo00<007ooOol0?7oo00<007ooOol0Rgoo000AOol00`00
Oomoo`33Ool00`00Oomoo`0iOol00`00Oomoo`3;Ool0015oo`03001oogoo0<=oo`03001oogoo03Uo
o`03001oogoo0<]oo`004Goo00<007ooOol0GGoo00<007ooOol03goo00<007ooOol01Woo00<007oo
Ool0BGoo00<007ooOol01goo00<007ooOol09Goo0`0O1Woo00<007ooOol0bgoo000AOol00`00Oomo
o`34Ool00`00Oomoo`0_Ool301l6Ool00`00Oomoo`3;Ool0015oo`03001oogoo099oo`03001oogoo
00Moo`03001oogoo02Eoo`03001oogoo029oo`<07`Yoo`<07`Ioo`03001oogoo041oo`03001oogoo
08Qoo`004Goo00<007ooOol00goo00<007ooOol0RWoo00<007ooOol0<Woo00D007ooOomoo`0001mo
o`<07a=oo`03001oogoo06ioo`03001oogoo05Yoo`004Goo00<007ooOol0aGoo00<007ooOol08Goo
0`0O4Woo00<007ooOol08goo00<007ooOol0YWoo000AOol00`00Oomoo`35Ool00`00Oomoo`0AOol3
01lROol00`00Oomoo`0mOol00`00Oomoo`2<Ool0015oo`03001oogoo01=oo`03001oogoo0;1oo`03
001oogoo011oo`<07b9oo`03001oogoo0<aoo`004Goo00<007ooOol0@Woo00<007ooOol0PGoo00<0
07ooOol047oo0`0O8Goo00<007ooOol0>Goo00<007ooOol0TGoo000AOol00`00Oomoo`0JOol00`00
Oomoo`2ZOol00`00Oomoo`0bOol00`00Oomoo`0[Ool00`00Oomoo`2POol0015oo`<00:ioo`03001o
ogoo01Moo`03001oogoo035oo`03001oogoo0<ioo`004Goo00<007ooOol0KWoo00<007ooOol0Egoo
00<007ooOol0<7oo00<007ooOol0cgoo000AOol00`00Oomoo`05Ool00`00Oomoo`03Ool00`00Oomo
o`0]Ool00`00Oomoo`2;Ool00`00Oomoo`0_Ool00`00Oomoo`12Ool00`00Oomoo`1fOol00`00Oomo
o`0AOol0015oo`03001oogoo03eoo`03001oogoo08Uoo`03001oogoo02ioo`03001oogoo04Yoo`03
001oogoo08=oo`004Goo00<007ooOol0L7oo00<007ooOol0Egoo00<007ooOol0;7oo00<007ooOol0
dGoo000AOol00`00Oomoo`26Ool00`00Oomoo`12Ool00`00Oomoo`0ZOol00`00Oomoo`1jOol00`00
Oomoo`1EOol0015oo`03001oogoo011oo`03001oogoo0;Uoo`03001oogoo02Qoo`03001oogoo06Qo
o`03001oogoo06Qoo`004Goo00<007ooOol0cGoo0P009goo00<007ooOol0?7oo00<007ooOol0Egoo
00<007ooOol0>goo000AOol00`00Oomoo`1HOol00`00Oomoo`1dOol00`00Oomoo`0ROol2000iOol0
0`00Oomoo`2KOol0015oo`03001oogoo09Qoo`03001oogoo03Eoo`03001oogoo021oo`03001oogoo
02=oo`03001oogoo02Qoo`03001oogoo08Ioo`004Goo00<007ooOol0CGoo00<007ooOol0A7oo00<0
07ooOol0>Woo00<007ooOol07Goo0P00fWoo000AOol00`00Oomoo`1kOol00`00Oomoo`1COol40003
01lHOol00`00Oomoo`1DOol00`00Oomoo`0lOol00`00Oomoo`14Ool0015oo`03001oogoo0:1oo`03
001oogoo039oo`<07aIoo`800=eoo`004Goo00<007ooOol0Lgoo00<007ooOol0Ggoo0`0O0`004Goo
0P001goo00<007ooOol06goo00<007ooOol0JGoo00<007ooOol0?Goo00<007ooOol02goo000AOol0
0`00Oomoo`0XOol00`00Oomoo`0SOol00`00Oomoo`0lOol00`00Oomoo`0/Ool00`00Oomoo`0LOol3
0008Ool6000aOol00`00Oomoo`22Ool00`00Oomoo`0EOol00`00Oomoo`0@Ool0015oo`<00<Yoo`<0
7a5oo`P000Yoo`<07mYoo`004Goo00<007ooOol0;Woo00<007ooOol0;7oo00<007ooOol03Woo00<0
07ooOol0FGoo0`0O8goo0`0OJGoo00<007ooOol0KWoo000AOol00`00Oomoo`06Ool00`00Oomoo`15
Ool00`00Oomoo`1iOol301lSOol301oJOol0015oo`03001oogoo0?mooi1oo`03001oogoo01aoo`03
001oogoo01aoo`004Goo00<007ooOol0ogoo9Woo00<007ooOol0>goo00<007ooOol0Igoo000AOol0
0`00Oomoo`1LOol00`00Oomoo`1gOol00`00Oomoo`12Ool00`00Oomoo`0POol00`00Oomoo`0]Ool0
0`00Oomoo`09Ool00`00Oomoo`1@Ool0015oo`03001oogoo0?moolioo`004Goo00<007ooOol0Lgoo
00<007ooOol0ogooF7oo000AOol00`00Oomoo`38Ool00`00Oomoo`2NOol00`00Oomoo`1AOol00`00
Oomoo`0=Ool0015oo`03001oogoo0?mooaUoo`03001oogoo06aoo`03001oogoo04=oo`004Goo00<0
07ooOol0ogooIGoo00<007ooOol0IWoo000AOol00`00Oomoo`3JOol00`00Oomoo`0SOol00`00Oomo
o`0eOol30n1POol00`00Oomoo`0_Ool0015oo`03001oogoo00ioo`03001oogoo07Uoo`03001oogoo
009oo`03001oogoo041oo`03001oogoo06=oo`<3h99oo`004Goo00<007ooOol0HWoo00<007ooOol0
dgoo0`?PTWoo000AOol00`00Oomoo`3oOol4Ool00`00Oomoo`37Ool0015oo`<0059oo`03001oogoo
0=Aoo`X009Yoo`004Goo00<007ooOol0ogoo9goo0`002Woo1P00U7oo000AOol00`00Oomoo`1]Ool0
0`00Oomoo`0nOol00`00Oomoo`1bOol3000COol3002AOol0015oo`03001oogoo05eoo`03001oogoo
02Ioo`03001oogoo06Eoo`03001oogoo02moo`<001Uoo`03001oogoo04Aoo`03001oogoo04Moo`00
4Goo00<007ooOol0mWoo00<007ooOol09Goo0P007Goo00<007ooOol0SGoo000AOol00`00Oomoo`3o
OolNOol00`00Oomoo`0NOol20005Ool00`00Oomoo`0ROol00`00Oomoo`1POol0015oo`03001oogoo
0?mooaeoo`03001oogoo025oo`03001oogoo08Yoo`004Goo00<007ooOol0K7oo00@007ooOol00:]o
o`03001oogoo02=oo`03001oogoo02ioo`03001oogoo04Eoo`03001oogoo011oo`004Goo00<007oo
Ool0ogoo6Woo0P009goo00<007ooOol0=7oo00<007ooOol0DGoo000AOol00`00Oomoo`0<Ool00`00
Oomoo`3oOol:Ool00`00Oomoo`0XOol00`00Oomoo`27Ool0015oo`03001oogoo0:5oo`03001oogoo
01Uoo`03001oogoo05Moo`03001oogoo02Yoo`03001oogoo08Ioo`004Goo00<007ooOol0HGoo00<0
07ooOol0/Woo00<007ooOol0;7oo00<007ooOol017oo00<007ooOol00goo00<007ooOol04Woo00<0
07ooOol0Hgoo000AOol00`00Oomoo`0AOol00`00Oomoo`0POol00`00Oomoo`1BOol00`00Oomoo`29
Ool00`00Oomoo`0^Ool00`00Oomoo`24Ool0015oo`03001oogoo01=oo`03001oogoo051oo`03001o
ogoo02Moo`03001oogoo00Eoo`03001oogoo04Yoo`03001oogoo02eoo`03001oogoo02moo`03001o
ogoo019oo`03001oogoo06ioo`004Goo00<007ooOol0ogoo5Goo00<007ooOol0<7oo00<007ooOol0
Pgoo000AOol3003oOolEOol00`00Oomoo`0aOol00`00Oomoo`1aOol00`00Oomoo`0>Ool0015oo`03
001oogoo00=oo`03001oogoo03ioo`03001oogoo085oo`03001oogoo00Aoo`03001oogoo045oo`03
001oogoo039oo`03001oogoo05=oo`03001oogoo02aoo`004Goo00<007ooOol0U7oo00<007ooOol0
Ngoo00<007ooOol0<goo00<007ooOol0PWoo000AOol00`00Oomoo`3oOolCOol00`00Oomoo`0dOol0
0`00Oomoo`0VOol00`00Oomoo`0/Ool00`00Oomoo`0YOol0015oo`03001oogoo07moo`03001oogoo
02Moo`03001oogoo06Eoo`03001oogoo03Ioo`03001oogoo081oo`004Goo00<007ooOol0?Woo00<0
07ooOol0d7oo00<007ooOol0=Woo00<007ooOol0P7oo000AOol00`00Oomoo`1WOol00`00Oomoo`1T
Ool00`00Oomoo`10Ool00`00Oomoo`0gOol00`00Oomoo`0cOol00`00Oomoo`0nOol00`00Oomoo`08
Ool0015oo`03001oogoo0?moo`]oo`03001oogoo00=oo`03001oogoo03Qoo`03001oogoo07moo`00
4Goo00<007ooOol0ogoo4Goo00<007ooOol0>7oo00<007ooOol0Ogoo000AOol00`00Oomoo`07Ool0
0`00Oomoo`0IOol00`00Oomoo`3ZOol00`00Oomoo`0MOol30n0HOol00`00Oomoo`1oOol0015oo`03
001oogoo0?mooa5oo`03001oogoo01eoo`<3h1Qoo`03001oogoo07moo`004Goo00<007ooOol03goo
00<007ooOol0Agoo00<007ooOol057oo00<007ooOol0NWoo00<007ooOol087oo00<007ooOol07Goo
0`?P67oo00<007oo0n000P?POGoo000AOol00`00Oomoo`3oOol3Ool00`00Oomoo`0;Ool00`00Oomo
o`0cOol30n03Ool010000n03h0?POGoo000AOol00`00Oomoo`1AOol01000Oomoo`00/7oo00<007oo
Ool01goo00<007ooOol0=7oo0`?P0goo00@000?P0n03h49oo`03001oogoo03Qoo`000Woo0`000goo
0P001goo00<007ooOol0KWoo00<007ooOol0I7oo00<007ooOol067oo00<007ooOol077oo00<007oo
Ool0=7oo0`?P0goo00<007ooOol0OWoo0003Ool01@00Oomoogoo00000Woo00<007ooOol017oo00<0
07ooOol0ogoo47oo00<007ooOol0>Woo00<007ooOol0OWoo00000goo000000020002Ool01000Oomo
o`001Woo1000ogoo3goo00<007ooOol017oo0`?P<goo00<007ooOol0>Woo00<007ooOol0@Goo0000
17oo001oo`000goo00@007ooOol000Ioo`03001oogoo0>eoo`03001oogoo01moo`03001oogoo00Ao
o`<3h25oo`<3h0=oo`<3h0Uoo`03001oogoo07ioo`0000Aoo`00Ool000=oo`04001oogoo0006Ool0
0`00Oomoo`1AOol00`00Oomoo`18Ool00`00Oomoo`1`Ool00`00Oomoo`04Ool30n0QOol30n03Ool3
0n09Ool00`00Oomoo`0nOol00`00Oomoo`0XOol00`00Oomoo`0BOol0009oo`8000Aoo`8000Moo`03
001oogoo06aoo`03001oogoo00]oo`03001oogoo09=oo`03001oogoo02Moo`<3h0=oo`<3h0Uoo`03
001oogoo07ioo`004Goo00<007ooOol0Igoo00<007ooOol0YWoo00<007ooOol0>Goo00<007ooOol0
EGoo00<007ooOol09Woo000AOol00`00Oomoo`1jOol00`00Oomoo`2COol00`00Oomoo`0hOol00`00
Oomoo`0bOol00`00Oomoo`1:Ool0015oo`03001oogoo0>Aoo`03001oogoo02Uoo`03001oogoo03Qo
o`03001oogoo07moo`004Goo00<007ooOol0ogoo4Goo00<007ooOol0>7oo00<007ooOol0Ogoo000A
Ool00`00Oomoo`1eOol00`00Oomoo`0oOol00`00Oomoo`1FOol00`00Oomoo`0hOol00`00Oomoo`1o
Ool0015oo`03001oogoo0?mooa9oo`03001oogoo03Moo`03001oogoo07Moo`03001oogoo00Eoo`00
4Goo00<007ooOol0CGoo00<007ooOol0`Goo00<007ooOol0=goo00<007ooOol0;7oo00<007ooOol0
D7oo000AOol00`00Oomoo`3oOolBOol00`00Oomoo`0fOol00`00Oomoo`20Ool0015oo`03001oogoo
0;Moo`03001oogoo05Qoo`03001oogoo03Eoo`03001oogoo021oo`03001oogoo05eoo`004Goo00<0
07ooOol0ogoo4goo00<007ooOol0=7oo00<007ooOol0M7oo00<007ooOol02Woo000AOol00`00Oomo
o`2@Ool00`00Oomoo`20Ool00`00Oomoo`0bOol00`00Oomoo`0?Ool00`00Oomoo`1`Ool0015oo`<0
0?mooa9oo`<3h003001oogoo035oo`03001oogoo089oo`004Goo00<007ooOol0ogoo4Woo0`?P00<0
07ooOol0<7oo00<007ooOol0Pgoo000AOol00`00Oomoo`0^Ool00`00Oomoo`3POol30n000goo001o
o`0`Ool00`00Oomoo`23Ool0015oo`03001oogoo05]oo`03001oogoo00eoo`03001oogoo0:Moo`03
001oogoo02ioo`03001oogoo07Qoo`03001oogoo00Uoo`004Goo00<007ooOol0Agoo00<007ooOol0
c7oo00<007ooOol0;7oo00<007ooOol0QGoo000AOol00`00Oomoo`3aOol00`00Oomoo`0SOol2000Z
Ool30n27Ool0015oo`03001oogoo04Eoo`03001oogoo041oo`03001oogoo03Uoo`03001oogoo00mo
o`03001oogoo041oo`03001oogoo02Moo`<3h8Moo`004Goo00<007ooOol0/Woo00<007ooOol0D7oo
00<007ooOol04Woo00<007ooOol09Goo00@000?P0n03h8Moo`004Goo00<007ooOol0ogoo77oo00<0
07ooOol08Woo0P0077oo00<007ooOol0K7oo000AOol00`00Oomoo`3oOolMOol00`00Oomoo`0POol0
0`00Oomoo`2;Ool0015oo`03001oogoo03eoo`800=ioo`03001oogoo01ioo`03001oogoo08aoo`00
4Goo00<007ooOol0ogoo7goo0`0077oo00<007ooOol0SGoo000AOol00`00Oomoo`0^Ool00`00Oomo
o`3@Ool00`00Oomoo`0MOol3000GOol2002@Ool0015oo`03001oogoo039oo`03001oogoo03ioo`03
001oogoo03moo`03001oogoo06aoo`<0015oo`<000Uoo`040003h0?P0n25Ool0015oo`03001oogoo
04Yoo`03001oogoo00ioo`03001oogoo015oo`03001oogoo0;Eoo`<000]oo`<000eoo`<3h8Eoo`00
4Goo0`00ogoo:goo2`0047oo0`?P57oo00<007ooOol0KWoo000AOol00`00Oomoo`1jOol00`00Oomo
o`3oOoliOol00`00Oomoo`0EOol0015oo`03001oogoo0?mooaUoo`03001oogoo05aoo`04001oogoo
000gOol00`00Oomoo`0HOol0015oo`03001oogoo0?moolioo`004Goo00<007ooOol0JGoo00<007oo
Ool06goo00<007ooOol0NWoo00<007ooOol0[goo00<007ooOol057oo000AOol00`00Oomoo`1BOol0
0`00Oomoo`3^Ool00`00Oomoo`27Ool0015oo`03001oogoo02Aoo`03001oogoo09ioo`03001oogoo
039oo`03001oogoo0=1oo`004Goo00<007ooOol0VWoo00<007ooOol0YWoo00<007ooOol0Ngoo00<0
07ooOol02Goo000AOol00`00Oomoo`3oOol`Ool00`00Oomoo`2KOol0015oo`03001oogoo07=oo`03
001oogoo045oo`03001oogoo0?mooaAoo`004Goo00<007ooOol0ogoo0goo00<007ooOol0b7oo000A
Ool00`00Oomoo`3oOoo>Ool0015oo`03001oogoo0?mooi5oo`03001oogoo025oo`03001oogoo01Io
o`004Goo00<007ooOol0J7oo00<007ooOol0ogoo1goo00<007ooOol017oo00<007ooOol0DWoo000A
Ool00`00Oomoo`3aOol00`00Oomoo`3IOol0015oo`<0085oo`03001oogoo01moo`03001oogoo0?mo
obQoo`004Goo0P00Vgoo00<007ooOol0ZWoo00<007ooOol05goo00<007ooOol09goo00<007ooOol0
?goo000AOol00`00Oomoo`0EOol00`00Oomoo`08Ool00`00Oomoo`16Ool00`00Oomoo`1fOol00`00
Oomoo`3XOol0015oo`03001oogoo08eoo`03001oogoo03Moo`03001oogoo0?moo`Aoo`004Goo00<0
07ooOol0GGoo00<007ooOol03Goo00<007ooOol0ogoo@Woo00<007ooOol047oo00<007ooOol01Woo
000AOol00`00Oomoo`3oOonEOol00`00Oomoo`0fOol0015oo`03001oogoo01eoo`03001oogoo0?mo
ogEoo`03001oo`0003Ioo`004Goo00<007ooOol0mGoo00<007ooOol04goo00<007ooOol0Egoo00<0
07ooOol0IGoo000AOol00`00Oomoo`0FOol00`00Oomoo`3]Ool00`00Oomoo`2aOol00`00Oomoo`0@
Ool0015oo`03001oogoo03Ioo`03001oogoo09Aoo`03001oogoo06eoo`03001oogoo08eoo`004Goo
00<007ooOol0K7oo00<007ooOol0ogooGgoo000AOol00`00Oomoo`0XOol00`00Oomoo`2fOol00`00
Oomoo`3LOol00`00Oomoo`0:Ool0015oo`800?mooaEoo`03001oogoo079oo`03001oogoo049oo`00
4Goo00<007ooOol0Wgoo00<007ooOol0GGoo00<007ooOol0bgoo000AOol00`00Oomoo`3oOolBOol0
0`00Oomoo`2iOol0015oo`<002ioo`03001oogoo04moo`03001oogoo0?mood]oo`004Goo00<007oo
Ool0EGoo00<007ooOol0XWoo00<007ooOol0]Goo00<007ooOol067oo000AOol00`00Oomoo`3nOol0
0`00Oomoo`1ROol00`00Oomoo`1WOol0015oo`03001oogoo0?moolioo`004Goo00<007ooOol0ogoo
4Goo00<007ooOol09goo00<007ooOol0T7oo000AOol00`00Oomoo`1TOol00`00Oomoo`3jOol00`00
Oomoo`1YOol0015oo`03001oogoo0?moolioo`004Goo00<007ooOol0@Goo00<007ooOol0[goo00<0
07ooOol0egoo000AOol00`00Oomoo`3oOom1Ool00`00Oomoo`2:Ool0015oo`03001oogoo0?moolio
o`004Goo00<007ooOol0ogooD7oo00<007ooOol02Woo00<007ooOol0Ggoo00<007ooOol00Woo00<0
07ooOol01goo000AOol00`00Oomoo`1:Ool00`00Oomoo`2@Ool00`00Oomoo`0WOol00`00Oomoo`2/
Ool00`00Oomoo`0DOol0015oo`03001oogoo0<Yoo`03001oogoo01Ioo`03001oogoo0>Moo`004Goo
00<007ooOol0A7oo00<007ooOol0KGoo00<007ooOol0SGoo00<007ooOol0QWoo000017oo00000000
17oo0P001goo00<007ooOol0ogoo8Woo00<007ooOol0ZGoo0004Ool01000Oomoo`000Woo00<007oo
Ool017oo00<007ooOol0RWoo00<007ooOol03goo00<007ooOol0b7oo00<007ooOol017oo00<007oo
Ool0G7oo0004Ool01000Oomoo`000Woo00<007ooOol017oo100017oo00<007ooOol0AWoo00<007oo
Ool0ogooL7oo00<007ooOol02Woo000017oo000000000goo00@007ooOol000Ioo`03001oogoo04Eo
o`03001oogoo0?moodQoo`03001oogoo021oo`03001oogoo01Qoo`0000=oo`00Ool017oo00@007oo
Ool000Ioo`03001oogoo02Uoo`03001oogoo07Ioo`03001oogoo00]oo`03001oogoo089oo`03001o
ogoo01Ioo`03001oogoo02aoo`03001oogoo04eoo`0000=oo`0000000P000goo0P001goo00<007oo
Ool0[Goo00<007ooOol00goo0P00ogoo6Goo000AOol00`00Oomoo`1cOol00`00Oomoo`1IOol00`00
Oomoo`2@Ool00`00Oomoo`1NOol00`00Oomoo`07Ool0015oo`03001oogoo0=Qoo`03001oogoo0?9o
o`004Goo00<007ooOol0Ugoo00<007ooOol0aGoo00<007ooOol0Jgoo000AOol00`00Oomoo`34Ool0
0`00Oomoo`0nOol00`00Oomoo`35Ool0015oo`03001oogoo0:9oo`03001oogoo0?moobUoo`004Goo
00<007ooOol0ogoo:Goo00<007ooOol0XWoo000AOol00`00Oomoo`04Ool00`00Ool0002iOol00`00
Oomoo`1YOol00`00Oomoo`2NOol0015oo`03001oogoo0?moodioo`03001oogoo07eoo`004Goo00<0
07ooOol0TWoo00<007ooOol0_Goo00<007ooOol0;Goo00<007ooOol05goo00<007ooOol0;Woo000A
Ool00`00Oomoo`0VOol00`00Oomoo`3kOol00`00Oomoo`2VOol0015oo`03001oogoo01ioo`03001o
ogoo01Yoo`03001oogoo02Yoo`03001oogoo0;Qoo`03001oogoo0:Moo`004Goo0`00ogooDgoo00<0
07ooOol0N7oo000AOol00`00Oomoo`0VOol00`00Oomoo`3oOomSOol00`00Oomoo`0TOol00`00Oomo
o`0HOol0015oo`03001oogoo0;5oo`03001oogoo041oo`03001oogoo0=Ioo`004Goo00<007ooOol0
:Goo00<007ooOol0VGoo00<007ooOol0XWoo00<007ooOol0H7oo000AOol00`00Oomoo`0MOol00`00
Oomoo`08Ool00`00Oomoo`0>Ool00`00Oomoo`3OOol00`00Oomoo`2_Ool0015oo`03001oogoo07Yo
o`03001oogoo03Ioo`03001oogoo02aoo`03001oogoo035oo`03001oogoo0;Aoo`004Goo00<007oo
Ool02Goo00<007ooOol0L7oo00<007ooOol01goo00<007ooOol0H7oo0P00Y7oo00<007ooOol0>goo
000AOol00`00Oomoo`3oOoo>Ool0015oo`03001oogoo05=oo`03001oogoo065oo`03001oogoo0?mo
oaAoo`004Goo00<007ooOol0@7oo00<007ooOol0h7oo00<007ooOol0<Woo00<007ooOol0LWoo000A
Ool00`00Oomoo`1lOol00`00Oomoo`3oOom?Ool0015oo`03001oogoo00Eoo`03001oogoo04eoo`03
001oogoo0=]oo`03001oogoo09Moo`004Goo00<007ooOol0L7oo00<007ooOol0kGoo00<007ooOol0
JWoo000AOol00`00Oomoo`3oOol[Ool00`00Oomoo`2POol0015oo`03001oogoo08=oo`03001oogoo
06Moo`03001oogoo051oo`03001oogoo08Yoo`004Goo0`00GGoo00<007ooOol0:goo00<007ooOol0
9Goo00<007ooOol0LWoo00@007ooOol00:5oo`004Goo00<007ooOol0l7oo00<007ooOol0fWoo000A
Ool00`00Oomoo`04Ool00`00Oomoo`2eOol00`00Oomoo`3_Ool00`00Oomoo`0@Ool00`00Oomoo`09
Ool0015oo`03001oogoo01]oo`03001oogoo0?mooaYoo`03001oogoo09=oo`004Goo00<007ooOol0
ogoo1goo00<007ooOol0a7oo000AOol00`00Oomoo`1HOol00`00Oomoo`3aOol00`00Oomoo`0LOol0
0`00Oomoo`0;Ool00`00Oomoo`0:Ool00`00Oomoo`0FOol00`00Oomoo`0[Ool0015oo`03001oogoo
04Aoo`03001oogoo03aoo`03001oogoo0<moo`03001oogoo07Eoo`004Goo00<007ooOol0>7oo00<0
07ooOol0CGoo00<007ooOol0BGoo00<007ooOol027oo00<007ooOol0jgoo000AOol00`00Oomoo`2o
Ool00`00Oomoo`1[Ool00`00Oomoo`2MOol0015oo`03001oogoo03=oo`03001oogoo0?moo`aoo`03
001oogoo009oo`03001oogoo08Aoo`004Goo00<007ooOol0jGoo00<007ooOol0hGoo000AOol00`00
Oomoo`3oOom=Ool00`00Oomoo`02Ool00`00Oomoo`1iOol0015oo`03001oogoo0?moolioo`004Goo
00<007ooOol0Cgoo00<007ooOol0J7oo00<007ooOol0O7oo00<007ooOol0TGoo000AOol00`00Oomo
o`0`Ool00`00Oomoo`0eOol00`00Oomoo`3oOol[Ool00`00Oomoo`0[Ool00`00Oomoo`07Ool0015o
o`<00?Yoo`03001oogoo03Ioo`03001oogoo09Moo`004Goo00<007ooOol0>goo00<007ooOol0lGoo
00<007ooOol0Vgoo000AOol00`00Oomoo`1:Ool00`00Oomoo`2/Ool00`00Oomoo`3AOol0015oo`03
001oogoo08Uoo`03001oogoo00eoo`03001oogoo06moo`03001oogoo0;moo`004Goo00<007ooOol0
9Woo00<007ooOol0ogooGWoo00<007ooOol0A7oo000AOol00`00Oomoo`0hOol00`00Oomoo`3oOon8
Ool00`00Oomoo`08Ool0015oo`03001oogoo0?moog=oo`03001oogoo05Qoo`004Goo00<007ooOol0
cgoo00<007ooOol0[7oo00<007ooOol0:Goo00<007ooOol01Woo00<007ooOol05goo000AOol00`00
Oomoo`0VOol00`00Oomoo`1gOol00`00Oomoo`3oOol[Ool0015oo`03001oogoo01]oo`03001oogoo
0?moogaoo`03001oogoo035oo`004Goo00<007ooOol0]7oo00<007ooOol0ogoo5goo000AOol00`00
Oomoo`1OOol00`00Oomoo`1XOol00`00Oomoo`0:Ool00`00Oomoo`28Ool00`00Oomoo`1XOol0015o
o`03001oogoo031oo`03001oogoo08eoo`03001oogoo031oo`03001oogoo01Eoo`03001oogoo079o
o`03001oogoo04Yoo`004Goo00<007ooOol0ogoo;goo00<007ooOol0OGoo00<007ooOol077oo000A
Ool00`00Oomoo`2mOol00`00Oomoo`1JOol00`00Oomoo`22Ool00`00Oomoo`0[Ool0015oo`03001o
ogoo09aoo`03001oogoo0?moobMoo`03001oogoo00Eoo`004Goo0`00A7oo00<007ooOol0/Goo00<0
07ooOol0dWoo000AOol00`00Oomoo`38Ool00`00Oomoo`0TOol00`00Oomoo`3KOol0015oo`03001o
ogoo0;Aoo`03001oogoo01]oo`03001oogoo0?Qoo`004Goo00<007ooOol0:7oo00<007ooOol0Egoo
00<007ooOol0`7oo00<007ooOol0BWoo00<007ooOol0>7oo000AOol00`00Oomoo`3oOolBOol00`00
Oomoo`2iOol0015oo`03001oogoo0=Eoo`03001oogoo0?Eoo`004Goo00<007ooOol0D7oo00<007oo
Ool0=goo00<007ooOol0WGoo00<007ooOol0X7oo000AOol00`00Oomoo`3oOon[Ool00`00Oomoo`0P
Ool0015oo`03001oogoo0?Aoo`03001oogoo00=oo`03001oogoo07=oo`03001oogoo035oo`03001o
ogoo02Ioo`004Goo00<007ooOol0PWoo00<007ooOol00Woo00<007ooOol0ogooA7oo000AOol00`00
Oomoo`2ROol00`00Oomoo`0nOol00`00Oomoo`3WOol0015oo`03001oogoo05Uoo`03001oogoo049o
o`03001oogoo0?moobeoo`004Goo00<007ooOol0ogoocWoo0002Ool20004Ool20007Ool00`00Oomo
o`3oOol6Ool00`00Oomoo`35Ool00005Ool007ooOol00002Ool01000Oomoo`001Woo00<007ooOol0
CGoo00<007ooOol03goo00<007ooOol0lgoo00<007ooOol0MGoo00001Goo001oogoo00000Woo00@0
07ooOol000Ioo`@00?mooleoo`0000Aoo`00000000=oo`04001oogoo003oOooGOol00003Ool007oo
00Aoo`04001oogoo003oOooGOol0009oo`<000=oo`800?moomQoo`00ogoohWoo003oOooROol00?mo
on9oo`00\
\>"],
  ImageRangeCache->{{{0, 480.375}, {480.375, 0}} -> {-2.32696, -2.22842, 
  0.131388, 0.131388}}]
}, Closed]],

Cell["\<\
Here is a sample of 10 individuals; by setting the variance of the \
Gaussian to zero, the nearest individuals are chosen (in order):\
\>", \
"MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[
    \(ss = 
      SampleIndividuals[p1, {{20, 20}, {30, 30}, {40, 40}}, 10, 0, R, 6]; 
    ss // TableForm\)], "Input",
  CellLabel->"In[179]:="],

Cell[BoxData[
    TagBox[GridBox[{
          {"119", "325", "17", "688", "266", "413", "142", "741", "238", 
            "297"},
          {"617", "717", "450", "661", "56", "112", "3", "848", "914", 
            "794"},
          {"724", "787", "973", "817", "172", "449", "995", "243", "252", 
            "578"}
          },
        RowSpacings->1,
        ColumnSpacings->3,
        RowAlignments->Baseline,
        ColumnAlignments->{Left}],
      (TableForm[ #]&)]], "Output",
  CellLabel->"Out[179]//TableForm="]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(DisplayTogether[ListPlot[locs, PlotStyle -> PointSize[0.002]], \n\t
      Graphics[Circle[{20, 20}, 4]], Graphics[Circle[{30, 30}, 4]], 
      Graphics[Circle[{40, 40}, 4]], \n\t
      ListPlot[\(Location[p1, #]&\)/@ss[\([1]\)], PlotStyle \[Rule] Red], \n\t
      ListPlot[\(Location[p1, #]&\)/@ss[\([2]\)], PlotStyle \[Rule] Blue], \n
      \tListPlot[\(Location[p1, #]&\)/@ss[\([3]\)], PlotStyle \[Rule] Green], 
      \n\tPlotRange \[Rule] {{0, R}, {0, R}}, AspectRatio \[Rule] 1]; \)\)], 
  "Input",
  CellLabel->"In[180]:="],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 0.0166667 0 0.0166667 [
[.16667 -0.0125 -6 -9 ]
[.16667 -0.0125 6 0 ]
[.33333 -0.0125 -6 -9 ]
[.33333 -0.0125 6 0 ]
[.5 -0.0125 -6 -9 ]
[.5 -0.0125 6 0 ]
[.66667 -0.0125 -6 -9 ]
[.66667 -0.0125 6 0 ]
[.83333 -0.0125 -6 -9 ]
[.83333 -0.0125 6 0 ]
[1 -0.0125 -6 -9 ]
[1 -0.0125 6 0 ]
[-0.0125 .16667 -12 -4.5 ]
[-0.0125 .16667 0 4.5 ]
[-0.0125 .33333 -12 -4.5 ]
[-0.0125 .33333 0 4.5 ]
[-0.0125 .5 -12 -4.5 ]
[-0.0125 .5 0 4.5 ]
[-0.0125 .66667 -12 -4.5 ]
[-0.0125 .66667 0 4.5 ]
[-0.0125 .83333 -12 -4.5 ]
[-0.0125 .83333 0 4.5 ]
[-0.0125 1 -12 -4.5 ]
[-0.0125 1 0 4.5 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.16667 0 m
.16667 .00625 L
s
[(10)] .16667 -0.0125 0 1 Mshowa
.33333 0 m
.33333 .00625 L
s
[(20)] .33333 -0.0125 0 1 Mshowa
.5 0 m
.5 .00625 L
s
[(30)] .5 -0.0125 0 1 Mshowa
.66667 0 m
.66667 .00625 L
s
[(40)] .66667 -0.0125 0 1 Mshowa
.83333 0 m
.83333 .00625 L
s
[(50)] .83333 -0.0125 0 1 Mshowa
1 0 m
1 .00625 L
s
[(60)] 1 -0.0125 0 1 Mshowa
.125 Mabswid
.03333 0 m
.03333 .00375 L
s
.06667 0 m
.06667 .00375 L
s
.1 0 m
.1 .00375 L
s
.13333 0 m
.13333 .00375 L
s
.2 0 m
.2 .00375 L
s
.23333 0 m
.23333 .00375 L
s
.26667 0 m
.26667 .00375 L
s
.3 0 m
.3 .00375 L
s
.36667 0 m
.36667 .00375 L
s
.4 0 m
.4 .00375 L
s
.43333 0 m
.43333 .00375 L
s
.46667 0 m
.46667 .00375 L
s
.53333 0 m
.53333 .00375 L
s
.56667 0 m
.56667 .00375 L
s
.6 0 m
.6 .00375 L
s
.63333 0 m
.63333 .00375 L
s
.7 0 m
.7 .00375 L
s
.73333 0 m
.73333 .00375 L
s
.76667 0 m
.76667 .00375 L
s
.8 0 m
.8 .00375 L
s
.86667 0 m
.86667 .00375 L
s
.9 0 m
.9 .00375 L
s
.93333 0 m
.93333 .00375 L
s
.96667 0 m
.96667 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .16667 m
.00625 .16667 L
s
[(10)] -0.0125 .16667 1 0 Mshowa
0 .33333 m
.00625 .33333 L
s
[(20)] -0.0125 .33333 1 0 Mshowa
0 .5 m
.00625 .5 L
s
[(30)] -0.0125 .5 1 0 Mshowa
0 .66667 m
.00625 .66667 L
s
[(40)] -0.0125 .66667 1 0 Mshowa
0 .83333 m
.00625 .83333 L
s
[(50)] -0.0125 .83333 1 0 Mshowa
0 1 m
.00625 1 L
s
[(60)] -0.0125 1 1 0 Mshowa
.125 Mabswid
0 .03333 m
.00375 .03333 L
s
0 .06667 m
.00375 .06667 L
s
0 .1 m
.00375 .1 L
s
0 .13333 m
.00375 .13333 L
s
0 .2 m
.00375 .2 L
s
0 .23333 m
.00375 .23333 L
s
0 .26667 m
.00375 .26667 L
s
0 .3 m
.00375 .3 L
s
0 .36667 m
.00375 .36667 L
s
0 .4 m
.00375 .4 L
s
0 .43333 m
.00375 .43333 L
s
0 .46667 m
.00375 .46667 L
s
0 .53333 m
.00375 .53333 L
s
0 .56667 m
.00375 .56667 L
s
0 .6 m
.00375 .6 L
s
0 .63333 m
.00375 .63333 L
s
0 .7 m
.00375 .7 L
s
0 .73333 m
.00375 .73333 L
s
0 .76667 m
.00375 .76667 L
s
0 .8 m
.00375 .8 L
s
0 .86667 m
.00375 .86667 L
s
0 .9 m
.00375 .9 L
s
0 .93333 m
.00375 .93333 L
s
0 .96667 m
.00375 .96667 L
s
.25 Mabswid
0 0 m
0 1 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
.002 w
.93914 .98334 Mdot
.45036 .56924 Mdot
.45771 .51409 Mdot
.17466 .13715 Mdot
.58562 .15974 Mdot
.21024 .51471 Mdot
.49717 .21941 Mdot
.78261 .57513 Mdot
.46846 .0751 Mdot
.50129 .7704 Mdot
.29026 .97505 Mdot
.52589 .65784 Mdot
.35111 .99171 Mdot
.07553 .0886 Mdot
.8934 .47763 Mdot
.90087 .95144 Mdot
.30778 .31789 Mdot
.69063 .43673 Mdot
.81061 .09848 Mdot
.90802 .8616 Mdot
.34215 .02338 Mdot
.40674 .0912 Mdot
.05189 .04833 Mdot
.88085 .43336 Mdot
.70078 .05662 Mdot
.80532 .34476 Mdot
.80738 .57899 Mdot
.90445 .39332 Mdot
.4996 .2611 Mdot
.21382 .95659 Mdot
.68899 .16262 Mdot
.3058 .09499 Mdot
.34684 .13924 Mdot
.89906 .00379 Mdot
.29495 .09091 Mdot
.01821 .57043 Mdot
.59417 .03429 Mdot
.21288 .22567 Mdot
.78679 .4553 Mdot
.30843 .83235 Mdot
.28719 .1942 Mdot
.09461 .87576 Mdot
.5982 .03158 Mdot
.78882 .78078 Mdot
.25135 .89234 Mdot
.88976 .77699 Mdot
.9564 .80143 Mdot
.87155 .20656 Mdot
.36223 .76714 Mdot
.65867 .98089 Mdot
.57544 .31184 Mdot
.35023 .14854 Mdot
.28825 .11764 Mdot
.25562 .27278 Mdot
.69006 .08606 Mdot
.4668 .492 Mdot
.4387 .19372 Mdot
.57705 .71501 Mdot
.4823 .39229 Mdot
.7055 .50845 Mdot
.12007 .62515 Mdot
.04683 .52756 Mdot
.54463 .31331 Mdot
.6966 .37902 Mdot
.25638 .19567 Mdot
.44098 .10624 Mdot
.56632 .10961 Mdot
.97417 .61424 Mdot
.12762 .91589 Mdot
.39713 .89922 Mdot
.64531 .5236 Mdot
.69163 .39077 Mdot
.52524 .89845 Mdot
.6448 .86321 Mdot
.98061 .58513 Mdot
.9482 .4842 Mdot
.72423 .38946 Mdot
.50722 .37796 Mdot
.15791 .27985 Mdot
.53304 .76372 Mdot
.0303 .36396 Mdot
.13592 .8645 Mdot
.38499 .84036 Mdot
.44429 .47373 Mdot
.85975 .94191 Mdot
.79949 .61051 Mdot
.87913 .35678 Mdot
.8513 .12632 Mdot
.1549 .96732 Mdot
.34408 .74836 Mdot
.99699 .68747 Mdot
.81104 .98464 Mdot
.96669 .32352 Mdot
.67512 .12014 Mdot
.58171 .48316 Mdot
.23083 .64641 Mdot
.72196 .54125 Mdot
.43134 .0359 Mdot
.84283 .18447 Mdot
.58004 .90958 Mdot
.68792 .21715 Mdot
.23596 .16123 Mdot
.69094 .52967 Mdot
.42492 .17659 Mdot
.72425 .20616 Mdot
.7498 .05645 Mdot
.14254 .723 Mdot
.51897 .41004 Mdot
.42058 .18175 Mdot
.08764 .37414 Mdot
.57775 .99728 Mdot
.5076 .46456 Mdot
.88983 .78013 Mdot
.27164 .30333 Mdot
.19889 .25046 Mdot
.84672 .12674 Mdot
.47465 .0443 Mdot
.09692 .07028 Mdot
.33211 .32131 Mdot
.57794 .66024 Mdot
.91153 .13956 Mdot
.49031 .2861 Mdot
.33377 .14228 Mdot
.98271 .82154 Mdot
.44394 .36215 Mdot
.71107 .51821 Mdot
.24505 .11169 Mdot
.86435 .39147 Mdot
.7704 .06739 Mdot
.76743 .32119 Mdot
.43829 .74609 Mdot
.18948 .66095 Mdot
.52676 .60653 Mdot
.69918 .37486 Mdot
.19299 .46425 Mdot
.71647 .55331 Mdot
.74904 .10209 Mdot
.0054 .0351 Mdot
.50399 .9904 Mdot
.14106 .64363 Mdot
.7336 .92301 Mdot
.37363 .32244 Mdot
.29531 .17692 Mdot
.18414 .66148 Mdot
.76854 .57039 Mdot
.48497 .28663 Mdot
.57556 .10615 Mdot
.7685 .73331 Mdot
.82651 .00405 Mdot
.7631 .69821 Mdot
.32252 .01365 Mdot
.62204 .05458 Mdot
.58892 .09065 Mdot
.24841 .73215 Mdot
.29362 .91372 Mdot
.06427 .07066 Mdot
.52507 .34333 Mdot
.5793 .78403 Mdot
.94952 .23718 Mdot
.8108 .05072 Mdot
.123 .23313 Mdot
.04771 .35251 Mdot
.80049 .21947 Mdot
.42567 .29793 Mdot
.21156 .12882 Mdot
.17726 .56578 Mdot
.91794 .2151 Mdot
.11299 .49512 Mdot
.39287 .87177 Mdot
.53369 .71108 Mdot
.44335 .63459 Mdot
.72289 .66036 Mdot
.32035 .40146 Mdot
.67518 .30785 Mdot
.51986 .18199 Mdot
.24952 .00992 Mdot
.3083 .05317 Mdot
.07226 .44414 Mdot
.39036 .83807 Mdot
.95927 .94902 Mdot
.99749 .9663 Mdot
.42558 .23794 Mdot
.55414 .33171 Mdot
.70269 .57758 Mdot
.23379 .93024 Mdot
.02751 .26972 Mdot
.71392 .74825 Mdot
.77799 .2598 Mdot
.40562 .69508 Mdot
.70573 .81566 Mdot
.01526 .85701 Mdot
.74645 .86664 Mdot
.01777 .89071 Mdot
.32087 .6287 Mdot
.46364 .55901 Mdot
.61818 .05112 Mdot
.22985 .62876 Mdot
.59067 .78139 Mdot
.51593 .88051 Mdot
.81268 .52159 Mdot
.11031 .18543 Mdot
.10696 .70593 Mdot
.09505 .32842 Mdot
.36051 .8393 Mdot
.07727 .4377 Mdot
.03963 .2106 Mdot
.61364 .8787 Mdot
.42146 .15948 Mdot
.38379 .24994 Mdot
.83078 .37809 Mdot
.86786 .36942 Mdot
.0181 .8565 Mdot
.75755 .18399 Mdot
.91114 .15056 Mdot
.66251 .85557 Mdot
.55063 .31127 Mdot
.58523 .41787 Mdot
.511 .10066 Mdot
.9716 .53917 Mdot
.08954 .94118 Mdot
.58781 .28924 Mdot
.25876 .56309 Mdot
.71995 .91981 Mdot
.24066 .70659 Mdot
.9624 .73582 Mdot
.32952 .55602 Mdot
.2999 .88025 Mdot
.77889 .24476 Mdot
.71467 .46238 Mdot
.26789 .1441 Mdot
.74307 .92321 Mdot
.17834 .20292 Mdot
.15526 .63397 Mdot
.91958 .63983 Mdot
.4353 .71416 Mdot
.67892 .93324 Mdot
.4729 .97834 Mdot
.3494 .37722 Mdot
.173 .09809 Mdot
.57051 .13246 Mdot
.45834 .63571 Mdot
.30262 .98836 Mdot
.71527 .71251 Mdot
.12428 .78545 Mdot
.56001 .07853 Mdot
.20469 .14562 Mdot
.12471 .36437 Mdot
.52577 .21237 Mdot
.65181 .38603 Mdot
.17637 .83516 Mdot
.47881 .28794 Mdot
.60587 .7027 Mdot
.02047 .65222 Mdot
.30325 .71433 Mdot
.3052 .93972 Mdot
.17897 .92889 Mdot
.74519 .86118 Mdot
.97428 .78327 Mdot
.62048 .49681 Mdot
.44851 .5709 Mdot
.96867 .11078 Mdot
.27213 .73574 Mdot
.48986 .82284 Mdot
.66627 .03305 Mdot
.46939 .17062 Mdot
.36302 .31871 Mdot
.1642 .2309 Mdot
.18405 .38983 Mdot
.41901 .36972 Mdot
.20977 .60656 Mdot
.79853 .8729 Mdot
.76126 .03566 Mdot
.82987 .76212 Mdot
.48913 .29992 Mdot
.34001 .93928 Mdot
.82287 .26687 Mdot
.87061 .76866 Mdot
.45984 .94816 Mdot
.70642 .53776 Mdot
.27579 .55833 Mdot
.28741 .16805 Mdot
.06602 .95177 Mdot
.48887 .29514 Mdot
.30476 .91611 Mdot
.65901 .53302 Mdot
.81563 .61619 Mdot
.319 .59374 Mdot
.99276 .34932 Mdot
.44839 .82507 Mdot
.53292 .40117 Mdot
.74197 .28731 Mdot
.25712 .84284 Mdot
.45457 .11926 Mdot
.1911 .89107 Mdot
.9657 .82412 Mdot
.88634 .97496 Mdot
.30669 .2911 Mdot
.07071 .35877 Mdot
.98769 .69736 Mdot
.07795 .00945 Mdot
.5393 .87229 Mdot
.54504 .60828 Mdot
.79733 .58498 Mdot
.28792 .76544 Mdot
.34276 .46572 Mdot
.09682 .87437 Mdot
.37707 .6416 Mdot
.21048 .89941 Mdot
.07038 .35051 Mdot
.13976 .54064 Mdot
.08269 .65315 Mdot
.06181 .53119 Mdot
.54338 .78086 Mdot
.51677 .92292 Mdot
.74606 .19588 Mdot
.22886 .15748 Mdot
.4033 .73015 Mdot
.13204 .28311 Mdot
.02623 .08855 Mdot
.92156 .3837 Mdot
.95585 .73804 Mdot
.78179 .84306 Mdot
.87317 .0849 Mdot
.71998 .31187 Mdot
.32979 .30404 Mdot
.20321 .38896 Mdot
.58373 .10816 Mdot
.97435 .23148 Mdot
.18043 .37801 Mdot
.84232 .94837 Mdot
.1542 .28946 Mdot
.92076 .56467 Mdot
.19835 .55142 Mdot
.13897 .7216 Mdot
.32518 .46652 Mdot
.41899 .40973 Mdot
.9954 .16249 Mdot
.21578 .02077 Mdot
.41167 .05432 Mdot
.24142 .78929 Mdot
.23123 .67631 Mdot
.3991 .84092 Mdot
.07703 .38685 Mdot
.47834 .27626 Mdot
.87868 .83543 Mdot
.33937 .55466 Mdot
.5535 .36891 Mdot
.92039 .14493 Mdot
.5581 .20642 Mdot
.70461 .12415 Mdot
.14643 .1521 Mdot
.46319 .33486 Mdot
.9152 .47579 Mdot
.06408 .49394 Mdot
.83818 .08894 Mdot
.58574 .21768 Mdot
.9595 .2535 Mdot
.24637 .66302 Mdot
.406 .88459 Mdot
.32598 .5181 Mdot
.8479 .67817 Mdot
.62137 .39394 Mdot
.70147 .52607 Mdot
.15818 .05908 Mdot
.78626 .05028 Mdot
.0941 .56515 Mdot
.94809 .96135 Mdot
.50836 .34747 Mdot
.98859 .70784 Mdot
.26199 .68444 Mdot
.58259 .82325 Mdot
.93601 .16635 Mdot
.73468 .14508 Mdot
.31464 .7724 Mdot
.03321 .61901 Mdot
.15646 .71332 Mdot
.24695 .56872 Mdot
.06236 .14818 Mdot
.29886 .60738 Mdot
.554 .80071 Mdot
.31027 .89954 Mdot
.29202 .11627 Mdot
.72769 .07629 Mdot
.35601 .94992 Mdot
.99301 .93121 Mdot
.04137 .17752 Mdot
.95979 .3122 Mdot
.88491 .4642 Mdot
.71284 .74348 Mdot
.82255 .31602 Mdot
.41398 .1361 Mdot
.26855 .51531 Mdot
.10371 .23656 Mdot
.97653 .39904 Mdot
.37602 .16028 Mdot
.62052 .44912 Mdot
.38301 .22907 Mdot
.57915 .2716 Mdot
.42322 .91686 Mdot
.69424 .8074 Mdot
.71038 .17338 Mdot
.87169 .49138 Mdot
.2964 .03728 Mdot
.60315 .97608 Mdot
.19269 .80072 Mdot
.62662 .57704 Mdot
.81668 .64044 Mdot
.0061 .12792 Mdot
.43366 .41137 Mdot
.42694 .85632 Mdot
.01044 .49451 Mdot
.7327 .04892 Mdot
.30006 .32113 Mdot
.861 .55753 Mdot
.00366 .28385 Mdot
.25786 .58146 Mdot
.81096 .48313 Mdot
.63124 .00442 Mdot
.99429 .84269 Mdot
.62514 .8765 Mdot
.56063 .43132 Mdot
.1982 .02018 Mdot
.55019 .93681 Mdot
.4655 .97127 Mdot
.25013 .61567 Mdot
.6045 .41373 Mdot
.24647 .33182 Mdot
.34664 .83227 Mdot
.4355 .84869 Mdot
.7154 .82785 Mdot
.44121 .00599 Mdot
.09026 .95135 Mdot
.88059 .57467 Mdot
.89206 .93116 Mdot
.3304 .63787 Mdot
.42656 .9599 Mdot
.08027 .02219 Mdot
.82206 .54616 Mdot
.83381 .69037 Mdot
.47542 .71389 Mdot
.3983 .84168 Mdot
.76001 .88604 Mdot
.95709 .83568 Mdot
.66975 .93469 Mdot
.0765 .26101 Mdot
.77769 .00353 Mdot
.7461 .62314 Mdot
.35113 .04363 Mdot
.66583 .60095 Mdot
.52907 .49747 Mdot
.83202 .91058 Mdot
.05365 .78358 Mdot
.43372 .0689 Mdot
.29363 .89754 Mdot
.47663 .23322 Mdot
.62388 .96285 Mdot
.40012 .9722 Mdot
.84619 .95933 Mdot
.65402 .34906 Mdot
.49507 .9157 Mdot
.9882 .74811 Mdot
.966 .41823 Mdot
.15618 .83753 Mdot
.91235 .63465 Mdot
.72246 .76863 Mdot
.61872 .73711 Mdot
.24584 .53542 Mdot
.99483 .77425 Mdot
.84571 .56321 Mdot
.14864 .81493 Mdot
.19169 .21415 Mdot
.65357 .89923 Mdot
.20349 .46604 Mdot
.68757 .481 Mdot
.04732 .6285 Mdot
.77522 .84635 Mdot
.32486 .85987 Mdot
.15651 .10925 Mdot
.07902 .32445 Mdot
.16168 .33499 Mdot
.23331 .76124 Mdot
.01304 .52007 Mdot
.04161 .54709 Mdot
.35947 .62084 Mdot
.83812 .08105 Mdot
.67189 .13983 Mdot
.7908 .45254 Mdot
.89667 .29348 Mdot
.46595 .59268 Mdot
.74016 .18423 Mdot
.38693 .26822 Mdot
.57849 .84924 Mdot
.15362 .50699 Mdot
.56545 .32917 Mdot
.11201 .9599 Mdot
.20598 .70834 Mdot
.27389 .87885 Mdot
.53409 .5685 Mdot
.48308 .42631 Mdot
.63742 .27502 Mdot
.01714 .83363 Mdot
.89726 .09079 Mdot
.63021 .56541 Mdot
.31877 .24155 Mdot
.47659 .05842 Mdot
.75332 .91237 Mdot
.36458 .09852 Mdot
.54734 .20404 Mdot
.0907 .21967 Mdot
.01324 .63554 Mdot
.60761 .79336 Mdot
.37582 .36051 Mdot
.59047 .95972 Mdot
.47856 .26973 Mdot
.96026 .39431 Mdot
.15979 .02818 Mdot
.48367 .33589 Mdot
.40647 .11581 Mdot
.11909 .23737 Mdot
.85914 .91177 Mdot
.02839 .01771 Mdot
.8459 .27623 Mdot
.42078 .22435 Mdot
.47007 .91572 Mdot
.83031 .26462 Mdot
.99151 .64599 Mdot
.87005 .87031 Mdot
.83171 .61781 Mdot
.38638 .53442 Mdot
.42524 .502 Mdot
.26729 .29704 Mdot
.5661 .59023 Mdot
.2389 .27934 Mdot
.72021 .314 Mdot
.81811 .05499 Mdot
.25013 .39828 Mdot
.98781 .79037 Mdot
.25862 .75229 Mdot
.11776 .92006 Mdot
.42691 .13448 Mdot
.73138 .38564 Mdot
.00167 .63248 Mdot
.46409 .0886 Mdot
.43557 .04224 Mdot
.2252 .80926 Mdot
.71536 .72824 Mdot
.40709 .75427 Mdot
.46523 .32996 Mdot
.41928 .9639 Mdot
.20661 .57767 Mdot
.30152 .04384 Mdot
.7797 .44319 Mdot
.57014 .6582 Mdot
.77803 .81071 Mdot
.10604 .5696 Mdot
.34246 .76847 Mdot
.88085 .76035 Mdot
.6271 .04023 Mdot
.47376 .00608 Mdot
.16187 .71027 Mdot
.05448 .04218 Mdot
.95526 .13261 Mdot
.75296 .99833 Mdot
.17556 .68942 Mdot
.18282 .34013 Mdot
.39753 .87871 Mdot
.07677 .77053 Mdot
.05507 .11024 Mdot
.19593 .01018 Mdot
.42797 .07001 Mdot
.72217 .00411 Mdot
.2661 .35974 Mdot
.66769 .96193 Mdot
.31083 .22713 Mdot
.91473 .9636 Mdot
.13527 .53771 Mdot
.73192 .62346 Mdot
.73774 .659 Mdot
.65514 .85294 Mdot
.68267 .54876 Mdot
.45922 .84275 Mdot
.2547 .47875 Mdot
.73705 .83865 Mdot
.9886 .11901 Mdot
.06936 .87672 Mdot
.67777 .89188 Mdot
.15463 .91312 Mdot
.5425 .35417 Mdot
.42271 .28965 Mdot
.80476 .69517 Mdot
.76757 .43672 Mdot
.12209 .14641 Mdot
.30835 .59397 Mdot
.86739 .66766 Mdot
.5713 .75532 Mdot
.87879 .54865 Mdot
.50194 .87861 Mdot
.20102 .65677 Mdot
.34731 .96549 Mdot
.65852 .30259 Mdot
.92459 .67583 Mdot
.85376 .60742 Mdot
.15703 .23911 Mdot
.73167 .461 Mdot
.84867 .64514 Mdot
.86428 .79334 Mdot
.27737 .88982 Mdot
.98549 .24469 Mdot
.77543 .01122 Mdot
.78447 .58793 Mdot
.42813 .04573 Mdot
.12594 .28533 Mdot
.50353 .3699 Mdot
.27218 .67792 Mdot
.3465 .13079 Mdot
.54051 .21691 Mdot
.49783 .48565 Mdot
.67623 .42357 Mdot
.22046 .59582 Mdot
.69075 .17888 Mdot
.44502 .5846 Mdot
.90628 .59095 Mdot
.0169 .53887 Mdot
.78033 .30562 Mdot
.51337 .16897 Mdot
.50815 .6277 Mdot
.16686 .03818 Mdot
.96764 .41079 Mdot
.66903 .55253 Mdot
.2914 .98722 Mdot
.44857 .95671 Mdot
.60066 .80835 Mdot
.00355 .37211 Mdot
.69438 .21739 Mdot
.98665 .83324 Mdot
.91405 .91178 Mdot
.47328 .66427 Mdot
.40589 .28407 Mdot
.30642 .62609 Mdot
.43826 .87328 Mdot
.63739 .07356 Mdot
.14685 .88606 Mdot
.18881 .11685 Mdot
.54619 .07771 Mdot
.18526 .74474 Mdot
.85181 .86032 Mdot
.19861 .9115 Mdot
.93777 .94854 Mdot
.72533 .24723 Mdot
.53187 .66447 Mdot
.41891 .62114 Mdot
.09362 .79119 Mdot
.78152 .54757 Mdot
.94677 .90513 Mdot
.59271 .43072 Mdot
.40057 .82742 Mdot
.40745 .68598 Mdot
.54876 .9671 Mdot
.20884 .77448 Mdot
.61099 .01856 Mdot
.48351 .52726 Mdot
.07912 .35409 Mdot
.0646 .90612 Mdot
.9855 .56291 Mdot
.28308 .35855 Mdot
.03874 .65778 Mdot
.69038 .92782 Mdot
.63817 .83036 Mdot
.28293 .24184 Mdot
.08941 .86325 Mdot
.07409 .46735 Mdot
.47842 .84469 Mdot
.59059 .9401 Mdot
.3993 .4906 Mdot
.52598 .03398 Mdot
.41379 .92769 Mdot
.2429 .67543 Mdot
.37506 .26991 Mdot
.55252 .74761 Mdot
.73689 .43956 Mdot
.26959 .50577 Mdot
.64748 .5763 Mdot
.1955 .03842 Mdot
.16907 .73161 Mdot
.60491 .09832 Mdot
.76977 .24102 Mdot
.07893 .06435 Mdot
.35598 .31333 Mdot
.83603 .38892 Mdot
.98092 .04342 Mdot
.28351 .64131 Mdot
.24403 .60386 Mdot
.01392 .13554 Mdot
.59655 .02756 Mdot
.81842 .09712 Mdot
.42748 .29594 Mdot
.21351 .99879 Mdot
.6577 .05493 Mdot
.13458 .93444 Mdot
.30173 .7416 Mdot
.29855 .54553 Mdot
.3208 .69818 Mdot
.01504 .90422 Mdot
.07677 .09432 Mdot
.00112 .76868 Mdot
.48023 .06677 Mdot
.1827 .67157 Mdot
.05275 .77082 Mdot
.96919 .67277 Mdot
.39505 .7159 Mdot
.83461 .73833 Mdot
.09332 .9743 Mdot
.53606 .1928 Mdot
.77252 .27611 Mdot
.52101 .28858 Mdot
.69575 .18179 Mdot
.51989 .5199 Mdot
.21552 .11502 Mdot
.33719 .84833 Mdot
.16276 .3442 Mdot
.368 .17556 Mdot
.76771 .6283 Mdot
.53339 .43723 Mdot
.67439 .654 Mdot
.99733 .24443 Mdot
.90187 .37789 Mdot
.47632 .95585 Mdot
.20612 .1961 Mdot
.95643 .43595 Mdot
.99061 .08108 Mdot
.61924 .58761 Mdot
.82784 .73688 Mdot
.25125 .41205 Mdot
.06013 .10858 Mdot
.71786 .97482 Mdot
.38574 .45458 Mdot
.72052 .73039 Mdot
.48387 .07669 Mdot
.2442 .77454 Mdot
.27775 .88059 Mdot
.28778 .33859 Mdot
.28714 .7995 Mdot
.66853 .75098 Mdot
.4593 .06262 Mdot
.41729 .33892 Mdot
.39917 .95404 Mdot
.69943 .3641 Mdot
.01343 .49946 Mdot
.97891 .63371 Mdot
.52957 .42277 Mdot
.7347 .85917 Mdot
.25182 .54219 Mdot
.44693 .52058 Mdot
.96468 .74268 Mdot
.7784 .7696 Mdot
.50538 .68006 Mdot
.36111 .43068 Mdot
.10621 .72602 Mdot
.66168 .06657 Mdot
.09278 .22656 Mdot
.68277 .43286 Mdot
.56321 .80379 Mdot
.94806 .57369 Mdot
.31139 .2616 Mdot
.50113 .05311 Mdot
.34671 .51891 Mdot
.72274 .28351 Mdot
.84133 .83885 Mdot
.36163 .85283 Mdot
.73512 .11283 Mdot
.69996 .78626 Mdot
.64234 .88627 Mdot
.01719 .35339 Mdot
.07913 .08248 Mdot
.06913 .7797 Mdot
.76774 .82088 Mdot
.56799 .72659 Mdot
.42103 .30197 Mdot
.84526 .44309 Mdot
.5797 .46312 Mdot
.48362 .59026 Mdot
.84459 .35029 Mdot
.78367 .804 Mdot
.20224 .46402 Mdot
.76648 .45061 Mdot
.12311 .38154 Mdot
.69735 .6709 Mdot
.35537 .56065 Mdot
.12936 .94431 Mdot
.93433 .25868 Mdot
.28411 .50122 Mdot
.35463 .79557 Mdot
.80048 .91097 Mdot
.51004 .44528 Mdot
.01681 .10697 Mdot
.3078 .98126 Mdot
.25033 .65636 Mdot
.18469 .59972 Mdot
.55298 .98545 Mdot
.82932 .03907 Mdot
.42362 .04114 Mdot
.89499 .78038 Mdot
.13951 .53992 Mdot
.54036 .98482 Mdot
.33903 .62895 Mdot
.03032 .53954 Mdot
.32222 .52199 Mdot
.72251 .55828 Mdot
.07189 .86563 Mdot
.53782 .95855 Mdot
.51891 .88018 Mdot
.7085 .91948 Mdot
.09529 .83903 Mdot
.81351 .1391 Mdot
.95578 .29912 Mdot
.27315 .15428 Mdot
.61675 .67016 Mdot
.24284 .61475 Mdot
.29452 .14818 Mdot
.52032 .05647 Mdot
.22264 .28254 Mdot
.9825 .09792 Mdot
.70372 .40237 Mdot
.274 .17843 Mdot
.60843 .56333 Mdot
.46049 .03934 Mdot
.65265 .26422 Mdot
.18734 .88505 Mdot
.03591 .59406 Mdot
.9445 .27031 Mdot
.74138 .44588 Mdot
.42418 .21384 Mdot
.51875 .16334 Mdot
.44168 .11592 Mdot
.81502 .76097 Mdot
.16768 .93748 Mdot
.20659 .19763 Mdot
.70719 .89815 Mdot
.55394 .93342 Mdot
.51985 .01309 Mdot
.51803 .33936 Mdot
.57535 .74279 Mdot
.77664 .89348 Mdot
.15118 .52895 Mdot
.25789 .73014 Mdot
.7095 .41303 Mdot
.44287 .96918 Mdot
.54183 .47555 Mdot
.23628 .77154 Mdot
.83464 .5774 Mdot
.68234 .83813 Mdot
.31478 .56431 Mdot
.16431 .49876 Mdot
.73943 .82152 Mdot
.38767 .60528 Mdot
.58825 .29257 Mdot
.12978 .87514 Mdot
.87875 .87953 Mdot
.68691 .90596 Mdot
.33692 .40398 Mdot
.45063 .13442 Mdot
.50228 .82658 Mdot
.76829 .29629 Mdot
.1875 .26227 Mdot
.60397 .79753 Mdot
.44807 .44076 Mdot
.2163 .19224 Mdot
.85982 .14819 Mdot
.08653 .31711 Mdot
.98107 .26865 Mdot
.39962 .41114 Mdot
.64415 .86467 Mdot
.949 .27672 Mdot
.14186 .03809 Mdot
.18071 .98043 Mdot
.95437 .77581 Mdot
.57674 .1829 Mdot
.5063 .33506 Mdot
.36043 .99066 Mdot
.64648 .18687 Mdot
.2739 .67355 Mdot
.66541 .91822 Mdot
.87428 .26241 Mdot
.02127 .05355 Mdot
.92529 .98568 Mdot
.8794 .01546 Mdot
.74458 .00526 Mdot
.92503 .23964 Mdot
.16784 .82236 Mdot
.41874 .90458 Mdot
.80741 .8317 Mdot
.77225 .71771 Mdot
.53351 .15815 Mdot
.10684 .7995 Mdot
.65922 .89574 Mdot
.08557 .74595 Mdot
.73394 .91006 Mdot
.20617 .73049 Mdot
.98936 .9048 Mdot
.28114 .49085 Mdot
.82152 .08245 Mdot
.8624 .58627 Mdot
.01411 .25075 Mdot
.09015 .86855 Mdot
.48061 .09259 Mdot
.98331 .06905 Mdot
.82138 .19685 Mdot
.89774 .3231 Mdot
.08744 .28679 Mdot
.69157 .59261 Mdot
.09808 .38199 Mdot
.41043 .10176 Mdot
.27656 .29954 Mdot
.54803 .51549 Mdot
.26245 .0488 Mdot
.45789 .64694 Mdot
.78184 .9562 Mdot
.47458 .57788 Mdot
.96046 .75935 Mdot
.57684 .25478 Mdot
.87302 .47256 Mdot
.88527 .66217 Mdot
.77494 .09057 Mdot
.47483 .56041 Mdot
.49837 .79103 Mdot
.9268 .04492 Mdot
.23592 .74223 Mdot
.46891 .39798 Mdot
.45408 .78603 Mdot
.99434 .8201 Mdot
.49362 .02668 Mdot
.4175 .56532 Mdot
.6206 .55412 Mdot
.53223 .90315 Mdot
.84566 .46354 Mdot
.0574 .34273 Mdot
.34729 .67251 Mdot
.1306 .29781 Mdot
.11136 .93028 Mdot
.66169 .89983 Mdot
.65728 .14425 Mdot
.66735 .07973 Mdot
.16367 .11757 Mdot
.24985 .51441 Mdot
.54307 .56345 Mdot
.71761 .61126 Mdot
.69741 .09991 Mdot
.66021 .26853 Mdot
.35013 .4274 Mdot
.52961 .97072 Mdot
.23877 .49712 Mdot
.86792 .07089 Mdot
.58148 .35287 Mdot
.20057 .99116 Mdot
.41781 .23529 Mdot
.95072 .47675 Mdot
.87474 .67184 Mdot
.23311 .86549 Mdot
.17732 .57193 Mdot
.57289 .59696 Mdot
.8272 .14454 Mdot
.04328 .62625 Mdot
.58843 .64742 Mdot
.17536 .55536 Mdot
.00695 .29456 Mdot
.9748 .56419 Mdot
.58914 .05926 Mdot
.02408 .08744 Mdot
.7144 .38742 Mdot
.79097 .22195 Mdot
.53708 .81549 Mdot
.21808 .62498 Mdot
.70988 .67095 Mdot
.17479 .99874 Mdot
.12145 .02353 Mdot
.99943 .44338 Mdot
.1145 .72898 Mdot
.02463 .87918 Mdot
.52536 .66972 Mdot
.00056 .79174 Mdot
.81096 .2823 Mdot
.20959 .56979 Mdot
.27388 .46681 Mdot
.99151 .94481 Mdot
.564 .79585 Mdot
.81672 .94607 Mdot
.44255 .77232 Mdot
.81729 .5027 Mdot
.32806 .04335 Mdot
.79266 .62351 Mdot
.8027 .37363 Mdot
.7921 .83177 Mdot
.99174 .09134 Mdot
.58252 .26198 Mdot
.71786 .62453 Mdot
.591 .31716 Mdot
.15385 .82868 Mdot
.77428 .37109 Mdot
.7113 .05635 Mdot
.95699 .86839 Mdot
.5 Mabswid
newpath
.33333 .33333 .06667 0 365.73 arc
s
newpath
.5 .5 .06667 0 365.73 arc
s
newpath
.66667 .66667 .06667 0 365.73 arc
s
1 0 0 r
.008 w
.33211 .32131 Mdot
.32979 .30404 Mdot
.30778 .31789 Mdot
.35598 .31333 Mdot
.36302 .31871 Mdot
.30006 .32113 Mdot
.37363 .32244 Mdot
.28778 .33859 Mdot
.3494 .37722 Mdot
.30669 .2911 Mdot
0 0 1 r
.49783 .48565 Mdot
.51989 .5199 Mdot
.52907 .49747 Mdot
.48351 .52726 Mdot
.4668 .492 Mdot
.5076 .46456 Mdot
.45771 .51409 Mdot
.54183 .47555 Mdot
.54803 .51549 Mdot
.51004 .44528 Mdot
0 1 0 r
.67439 .654 Mdot
.69735 .6709 Mdot
.70988 .67095 Mdot
.61675 .67016 Mdot
.72289 .66036 Mdot
.66583 .60095 Mdot
.71786 .62453 Mdot
.71527 .71251 Mdot
.60587 .7027 Mdot
.73774 .659 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[180]:=",
  ImageSize->{472.375, 472.375},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40007H0001f1000`40O003h00OogoofGoo003oOooI
Ool00?moomUoo`00ogoofGoo001GOol30004Ool20011Ool40003Ool20012Ool30004Ool20013Ool3
0003Ool20011Ool30004Ool20013Ool20004Ool20003Ool005Qoo`03001oogoo009oo`04001oogoo
0011Ool00`00Oomoo`02Ool01000Oomoo`00A7oo00@007ooOol0009oo`03001oogoo045oo`05001o
ogooOol00002Ool00`00Oomoo`11Ool01000Oomoo`000Woo00<007ooOol0?goo00@007ooOol0009o
o`04001oogoo0002Ool005Qoo`03001oogoo009oo`04001oogoo0012Ool01@00Oomoogoo00000Woo
00<007ooOol0@Woo00@007ooOol0009oo`03001oogoo03moo`@0009oo`04001oogoo0013Ool01000
Oomoo`000Woo00<007ooOol0?goo00@007ooOol0009oo`04001oogoo0002Ool005Qoo`03001oogoo
009oo`04001oogoo0013Ool01000Oomoo`000Woo00<007ooOol0@7oo0P000goo00@007ooOol0045o
o`03001oo`0000=oo`04001oogoo0010Ool30003Ool01000Oomoo`00@Goo0`000goo00@007ooOol0
009oo`00F7oo00<007ooOol00Woo00@007ooOol0041oo`04001oogoo0002Ool01000Oomoo`00A7oo
00@007ooOol0009oo`03001oogoo03moo`03001oo`0000=oo`04001oogoo0010Ool00`00Oomoo`03
Ool01000Oomoo`00@Goo00<007ooOol00goo00@007ooOol0009oo`00Egoo0P001Goo0P00@Woo0P00
17oo0P00@Woo0`0017oo0P00@goo0P0017oo0P00@Goo10000goo0P00@goo0`000goo0P000goo003o
OooIOol00?moomUoo`00ogoofGoo003oOooIOol00?moomUoo`00ogoofGoo003oOooIOol0015oool0
0<8000Ioo`004Goo00<007ooOol037oo00<007ooOol037oo00<007ooOol037oo00<007ooOol037oo
00<007ooOol037oo00<007ooOol037oo00<007ooOol037oo00<007ooOol037oo00<007ooOol02goo
00<007ooOol037oo00<007ooOol037oo00<007ooOol037oo00<007ooOol037oo00<007ooOol037oo
00<007ooOol037oo00<007ooOol037oo00<007ooOol037oo00<007ooOol037oo00<007ooOol037oo
00<007ooOol037oo00<007ooOol037oo00<007ooOol02goo00<007ooOol037oo00<007ooOol00Woo
00<007ooOol01goo00<007ooOol037oo00<007ooOol037oo00<007ooOol037oo00<007ooOol037oo
00<007ooOol037oo00<007ooOol037oo00<007ooOol017oo000AOol00`00Oomoo`0<Ool00`00Oomo
o`0<Ool00`00Oomoo`0<Ool00`00Oomoo`0<Ool00`00Oomoo`0<Ool00`00Oomoo`0<Ool00`00Oomo
o`0<Ool00`00Oomoo`0<Ool00`00Oomoo`0;Ool00`00Oomoo`0<Ool00`00Oomoo`0<Ool00`00Oomo
o`0<Ool00`00Oomoo`0<Ool00`00Oomoo`0<Ool00`00Oomoo`0<Ool00`00Oomoo`0<Ool00`00Oomo
o`0<Ool00`00Oomoo`0<Ool00`00Oomoo`0;Ool2000>Ool00`00Oomoo`0<Ool00`00Oomoo`07Ool0
1@00Oomoogoo00001Goo00<007ooOol01Woo00<007ooOol037oo00<007ooOol02Goo00@007ooOol0
00ioo`03001oogoo00aoo`03001oogoo00aoo`03001oogoo00aoo`03001oogoo00aoo`03001oogoo
00Aoo`004Goo00<007ooOol0B7oo00<007ooOol0Agoo00<007ooOol0;Woo00<007ooOol02goo00<0
07ooOol02Goo00<007ooOol0B7oo00<007ooOol0Agoo00<007ooOol0B7oo00<007ooOol017oo000A
Ool00`00Oomoo`0POol00`00Oomoo`0bOol00`00Oomoo`0EOol00`00Oomoo`3oOomEOol0015oo`03
001oogoo0?mooeUoo`03001oogoo06Uoo`004Goo00<007ooOol0SWoo00<007ooOol0EGoo00<007oo
Ool0fgoo000AOol00`00Oomoo`3oOon8Ool00`00Oomoo`0jOol0015oo`03001oogoo00Yoo`03001o
ogoo0?moo`=oo`03001oogoo0;9oo`004Goo00<007ooOol0EWoo00<007ooOol01Goo00<007ooOol0
ogooI7oo000AOol00`00Oomoo`0QOol00`00Oomoo`0@Ool00`00Oomoo`1OOol00`00Oomoo`3oOol/
Ool0015oo`03001oogoo0?moolEoo`004Goo00<007ooOol0fWoo00<007ooOol0:goo00<007ooOol0
^Goo000AOol00`00Oomoo`15Ool00`00Oomoo`3oOommOol0015oo`03001oogoo0?moo`Yoo`03001o
ogoo0;Qoo`004Goo0`00jGoo00<007ooOol06goo00<007ooOol07Woo00<007ooOol0VGoo000AOol0
1000Oomoo`00_Goo00<007ooOol0TGoo00<007ooOol0Kgoo000AOol00`00Oomoo`0mOol00`00Oomo
o`08Ool00`00Oomoo`0:Ool00`00Oomoo`0ZOol00`00Oomoo`3/Ool00`00Oomoo`1@Ool0015oo`03
001oogoo0;]oo`03001oogoo00eoo`03001oogoo04Qoo`03001oogoo0:]oo`004Goo00<007ooOol0
5Woo00<007ooOol0Mgoo00<007ooOol01goo00<007ooOol08goo00<007ooOol0lGoo00<007ooOol0
3Goo000AOol00`00Oomoo`24Ool00`00Oomoo`0fOol00`00Oomoo`0BOol00`00Oomoo`37Ool00`00
Oomoo`0UOol0015oo`03001oogoo0?moolEoo`004Goo00<007ooOol057oo00<007ooOol0G7oo00<0
07ooOol0cgoo00<007ooOol05Goo00<007ooOol0I7oo000AOol00`00Oomoo`3oOolCOol00`00Oomo
o`1COol00`00Oomoo`1IOol0015oo`03001oogoo00Moo`03001oogoo07eoo`03001oogoo02]oo`03
001oogoo02Ioo`03001oogoo03=oo`03001oogoo0:eoo`004Goo00<007ooOol0iWoo00<007ooOol0
>goo00<007ooOol047oo00<007ooOol00Woo00<007ooOol03Woo00<007ooOol06goo00<007ooOol0
EWoo000AOol00`00Oomoo`14Ool00`00Oomoo`2<Ool00`00Oomoo`0_Ool00`00Oomoo`2lOol0015o
o`03001oogoo0?moolEoo`004Goo00<007ooOol0bgoo00<007ooOol0mWoo000AOol00`00Oomoo`0Q
Ool00`00Oomoo`3oOonQOol0015oo`<00=Aoo`03001oogoo04ioo`03001oogoo02ioo`03001oogoo
06]oo`004Goo00<007ooOol0:Goo00<007ooOol0TGoo00<007oo0000mGoo00<007ooOol037oo000A
Ool00`00Oomoo`0JOol00`00Oomoo`3oOomVOol00`00Oomoo`0oOol0015oo`03001oogoo0?mooaao
o`03001oogoo0:Ioo`004Goo00<007ooOol0cgoo00<007ooOol017oo00<007ooOol0JWoo00<007oo
Ool0OWoo000AOol00`00Oomoo`3bOol00`00Oomoo`03Ool00`00Oomoo`39Ool0015oo`03001oogoo
0?moobUoo`03001oogoo04Uoo`03001oogoo049oo`03001oogoo00Qoo`004Goo00<007ooOol08Goo
00<007ooOol0ogooBWoo00<007ooOol0E7oo000AOol00`00Oomoo`3oOolcOol00`00Oomoo`1?Ool0
0`00Oomoo`0mOol0015oo`03001oogoo00Qoo`03001oogoo0?mookYoo`004Goo00<007ooOol02Goo
00<007ooOol04goo00<007ooOol0Zgoo00<007ooOol0R7oo00<007ooOol06Goo00<007ooOol0CGoo
000AOol00`00Oomoo`21Ool00`00Oomoo`0_Ool00`00Oomoo`0NOol00`00Oomoo`0^Ool00`00Oomo
o`27Ool00`00Oomoo`0WOol00`00Oomoo`08Ool0015oo`03001oogoo021oo`03001oogoo06=oo`03
001oogoo0?moocaoo`004Goo00<007ooOol0ogooKGoo00<007ooOol0EGoo000AOol00`00Oomoo`1;
Ool00`00Oomoo`1BOol00`00Oomoo`1YOol00`00Oomoo`1IOol00`00Oomoo`1:Ool00`00Oomoo`0<
Ool0015oo`<00;Eoo`03001oogoo02Yoo`03001oogoo051oo`03001oogoo08aoo`004Goo00<007oo
Ool0ogooCWoo00<007ooOol0M7oo000AOol00`00Oomoo`33Ool00`00Oomoo`0iOol00`00Oomoo`32
Ool0015oo`03001oogoo00Eoo`03001oogoo0?]oo`03001oogoo0;ioo`004Goo00<007ooOol05Woo
00<007oo0000:Woo00<007ooOol0]Goo00<007ooOol0aWoo000AOol00`00Oomoo`1[Ool00`00Oomo
o`3HOol00`00Oomoo`1VOol00`00Oomoo`0BOol0015oo`03001oogoo05ioo`03001oogoo0?moofAo
o`004Goo00<007ooOol0DWoo00<007ooOol0:goo00<007ooOol0<7oo00<007ooOol03Goo00<007oo
Ool0oWoo000AOol00`00Oomoo`16Ool00`00Oomoo`0eOol00`00Oomoo`18Ool00`00Oomoo`3/Ool0
0`00Oomoo`09Ool0015oo`03001oogoo0?moobaoo`03001oogoo09Ioo`004Goo00<007ooOol0ogoo
aGoo000AOol00`00Oomoo`3oOoljOol00`00Oomoo`0nOol00`00Oomoo`17Ool0015oo`04001oogoo
003oOomhOol00`00Oomoo`19Ool0015oo`03001oogoo05aoo`03001oogoo03Uoo`03001oogoo0?mo
obYoo`004Goo00<007ooOol0oGoo00<007ooOol0ZGoo00<007ooOol067oo000AOol3002lOol00`00
Oomoo`08Ool00`00Oomoo`3jOol0015oo`03001oogoo00=oo`03001oogoo04Eoo`03001oogoo06Uo
o`03001oogoo0?moo`]oo`004Goo00<007ooOol0V7oo00<007ooOol0cWoo00<007ooOol0:Goo00<0
07ooOol0;7oo000AOol00`00Oomoo`3oOol[Ool00`00Oomoo`2GOol0015oo`03001oogoo07Eoo`03
001oogoo01]oo`03001oogoo0?moobmoo`004Goo00<007ooOol0=7oo00<007ooOol08Woo00<007oo
Ool0agoo00<007ooOol087oo00<007ooOol09goo00<007ooOol09Woo00<007ooOol0:7oo000AOol0
0`00Oomoo`0IOol00`00Oomoo`1UOol00`00Oomoo`0FOol00`00Oomoo`3QOol00`00Oomoo`13Ool0
015oo`03001oogoo0?mooiIoo`03001oogoo02aoo`004Goo00<007ooOol0?goo00<007ooOol0ogoo
Pgoo000AOol00`00Oomoo`1gOol00`00Oomoo`3oOom;Ool0015oo`03001oogoo06Aoo`03001oogoo
0?mooeioo`004Goo00<007ooOol0^Woo00<007ooOol0;goo00<007ooOol057oo00<007ooOol0_Woo
000AOol00`00Oomoo`1WOol00`00Oomoo`0lOol00`00Oomoo`3oOolLOol00004Ool000000004Ool2
0007Ool00`00Oomoo`3UOol00`00Oomoo`1:Ool00`00Oomoo`26Ool00`00Oomoo`06Ool0009oo`03
001oogoo009oo`04001oogoo0006Ool00`00Oomoo`3oOonQOol00`00Oomoo`0QOol0009oo`03001o
ogoo009oo`04001oogoo0006Ool4001mOol00`00Oomoo`3oOom4Ool0009oo`03001oogoo009oo`04
001oogoo0006Ool00`00Oomoo`3?Ool00`00Oomoo`0AOol00`00Oomoo`3NOol0009oo`03001oogoo
009oo`04001oogoo0006Ool00`00Oomoo`3oOoo5Ool00003Ool0000000Eoo`8000Moo`03001oogoo
0?moocaoo`03001oogoo08Ioo`004Goo00<007ooOol047oo00<007ooOol0KWoo00<007ooOol07Woo
00<007ooOol05Woo00<007ooOol0ogoo1goo000AOol00`00Oomoo`1hOol00`00Oomoo`2gOol00`00
Oomoo`2?Ool0015oo`03001oogoo0;Uoo`03001oogoo02Yoo`03001oogoo04aoo`03001oogoo08ao
o`004Goo00<007ooOol0ogoo00<007ooOol0Agoo00<007ooOol017oo00<007ooOol0LGoo000AOol0
0`00Oomoo`0_Ool00`00Oomoo`3oOom6Ool00`00Oomoo`1:Ool0015oo`03001oogoo0?moob1oo`03
001oogoo0:9oo`004Goo00<007ooOol0ogooaGoo000AOol00`00Oomoo`1NOol00`00Oomoo`2<Ool0
0`00Oomoo`3DOol0015oo`03001oogoo07ioo`03001oogoo045oo`03001oogoo0?moo`004Goo00<0
07ooOol0FGoo0P005Goo00<007ooOol0f7oo00<007ooOol07goo00<007ooOol0E7oo000AOol00`00
Oomoo`3oOoo5Ool0015oo`<00?moolEoo`004Goo00<007ooOol0CGoo00<007ooOol0XWoo00<007oo
Ool0cgoo000AOol00`00Oomoo`3gOol00`00Oomoo`17Ool00`00Oomoo`0oOol00`00Oomoo`0nOol0
015oo`03001oogoo0?moolEoo`004Goo00<007ooOol03goo00<007ooOol0ogoo/goo000AOol00`00
Oomoo`3YOol00`00Oomoo`3HOol0015oo`03001oogoo05=oo`03001oogoo06Eoo`03001oogoo0=Yo
o`03001oogoo02Uoo`004Goo00<007ooOol0kgoo00<007ooOol04Goo00<007ooOol0:goo00@007oo
Ool008moo`004Goo00<007ooOol09Woo00<007ooOol0/goo00<007ooOol0QGoo00<007ooOol0GGoo
000AOol00`00Oomoo`3oOomPOol00`00Oomoo`1ROol0015oo`03001oogoo0;Yoo`03001oogoo0?mo
o`Qoo`004Goo00<007ooOol09goo00<007ooOol0<Woo00<007ooOol0ogooIWoo000AOol00`00Oomo
o`28Ool00`00Oomoo`0NOol00`00Oomoo`3oOolIOol0015oo`03001oogoo04Moo`03001oogoo0?mo
og]oo`004Goo0`00=7oo00<007ooOol0W7oo00<007ooOol0fgoo00<007ooOol047oo000AOol00`00
Oomoo`2hOol00`00Oomoo`3oOol:Ool0015oo`03001oogoo02aoo`03001oogoo00=oo`03001oogoo
08Moo`03001oogoo0>Moo`03001oogoo01]oo`004Goo00<007ooOol0@goo00<007ooOol0ogooEWoo
00<007ooOol09Woo000AOol00`00Oomoo`1lOol00`00Oomoo`0=Ool00`00Oomoo`37Ool00`00Oomo
o`1[Ool0015oo`03001oogoo0?mookMoo`03001oogoo00=oo`03001oogoo00Eoo`004Goo00<007oo
Ool0ogooFgoo00<007ooOol0Igoo000AOol00`00Oomoo`3oOom3Ool00`00Oomoo`1oOol0015oo`03
001oogoo00=oo`03001oogoo051oo`03001oogoo051oo`03001oogoo0?mooaUoo`004Goo00<007oo
Ool0ogoo[7oo00<007ooOol05Woo000AOol00`00Oomoo`3oOol00`00Oomoo`32Ool0015oo`03001o
ogoo0?moolEoo`004Goo00<007ooOol0ogooFgoo00<007ooOol0@goo00<007ooOol08Goo000AOol0
0`00Oomoo`0OOol00`00Oomoo`0_Ool00`00Oomoo`0eOol00`00Oomoo`1AOol00`00Oomoo`0ROol0
0`00Oomoo`20Ool00`00Oomoo`0lOol0015oo`03001oogoo0?moob9oo`03001oogoo04eoo`03001o
ogoo051oo`004Goo0`00TGoo1`00eWoo00<007ooOol0Dgoo000AOol00`00Oomoo`2;Ool60007Ool5
000=Ool00`00Oomoo`1hOol00`00Oomoo`2<Ool00`00Oomoo`0=Ool0015oo`03001oogoo00Uoo`03
001oogoo07aoo`<0019oo`8000Ioo`03001oogoo02]oo`03001oogoo0<ioo`03001oogoo01eoo`00
4Goo00<007ooOol0L7oo00<007ooOol04Woo0`005goo00<007ooOol0GWoo00<007ooOol0`Goo000A
Ool00`00Oomoo`23Ool2000KOol3001hOol00`00Oomoo`2VOol0015oo`03001oogoo089oo`03001o
ogoo01ioo`03001oogoo02eoo`03001oogoo085oo`03001oogoo01ioo`03001oogoo02]oo`03001o
ogoo01]oo`004Goo00<007ooOol0A7oo00<007ooOol08Goo00<007ooOol05Woo00<007ooOol087oo
00<007ooOol0ogoo7Woo000AOol00`00Oomoo`1QOol00`00Oomoo`0LOol00`00Oomoo`0ROol00`00
Oomoo`30Ool00`00Oomoo`1IOol0015oo`03001oo`0003Qoo`03001oogoo04=oo`8002Ioo`03001o
ogoo00Yoo`03001oogoo08]oo`03001oogoo081oo`004Goo00<007ooOol097oo00<007ooOol03goo
00<007ooOol0A7oo00<007ooOol09goo00<007ooOol0;7oo00@007ooOol00>Yoo`004Goo00<007oo
Ool0O7oo00<007ooOol0:Goo00<007ooOol0:Goo00<007ooOol03goo00<007ooOol06goo00<007oo
Ool0@Woo00<007ooOol0N7oo000AOol00`00Oomoo`12Ool00`00Oomoo`0gOol00`00Oomoo`06Ool3
O00QOol00`00Oomoo`0>Ool00`00Oomoo`3oOol8Ool0015oo`03001oogoo07]oo`03001oogoo00Mo
o`=l029oo`03001oogoo05Qoo`03001oogoo08Moo`03001oogoo039oo`004Goo00@007ooOol007Yo
o`03001oogoo00Moo`=l02=oo`03001oogoo00moo`03001oogoo01Qoo`03001oogoo0>Uoo`004Goo
00<007ooOol0>7oo00<007ooOol0>Woo00<007ooOol00Woo00<007ooOol0;Woo00<007ooOol03Woo
00<007ooOol0UWoo00<007ooOol0K7oo000AOol3001iOol00`00Oomoo`0`Ool00`00Oomoo`0YOol0
0`00Oomoo`3>Ool00`00Oomoo`0HOol0015oo`03001oogoo07Qoo`03001oogoo01Eoo`=l01Yoo`03
001oogoo00Yoo`03001oogoo06Moo`03001oogoo09eoo`004Goo00<007ooOol0Mgoo00<007ooOol0
5Woo0g`06Woo00<007ooOol0ogoo5Goo000AOol00`00Oomoo`1gOol00`00Oomoo`0FOol3O00KOol0
0`00Oomoo`2ZOol00`00Oomoo`1VOol0015oo`03001oogoo07Ioo`03001oogoo03Eoo`03001oogoo
07Yoo`03001oogoo09Ioo`004Goo00<007ooOol0MWoo00<007ooOol0=Goo00<007ooOol0@goo00<0
07ooOol0cGoo000AOol00`00Oomoo`1fOol00`00Oomoo`0ROol3O00AOol00`00Oomoo`0oOol00`00
Oomoo`0;Ool00`00Oomoo`0nOol00`00Oomoo`1XOol00`00Oomoo`0FOol0015oo`03001oogoo07Eo
o`03001oogoo02=oo`=l015oo`03001oogoo08ioo`03001oogoo02Yoo`03001oogoo05Aoo`004Goo
00<007ooOol097oo00<007ooOol0CWoo00<007ooOol03Woo0g`04Woo1W`03goo00<007ooOol0Dgoo
00<007ooOol0^goo000AOol00`00Oomoo`1eOol00`00Oomoo`0:Ool3O00017ooO01l07`027oo0g`0
2Woo0g`03goo00<007ooOol0ogoo4Woo000AOol00`00Oomoo`1eOol00`00Oomoo`0:Ool3O00017oo
O01l07`027oo0g`02Woo0g`00Woo0g`02Woo00<007ooOol0XWoo00<007ooOol0K7oo000AOol00`00
Oomoo`0QOol00`00Oomoo`1AOol00`00Oomoo`0:Ool3O00<Ool3O00?Ool3O00:Ool00`00Oomoo`3L
Ool00`00Oomoo`0LOol00`00Oomoo`0COol0015oo`03001oogoo07Eoo`03001oogoo02]oo`=l00Yo
o`03001oogoo0?mooa9oo`0000=oo`0000000P000goo0P001goo00<007ooOol0:7oo00<007ooOol0
BWoo00<007ooOol0>7oo00<007ooOol0Agoo00<007ooOol0agoo0002Ool00`00Oomoo`02Ool01000
Oomoo`001Woo00<007ooOol0K7oo00<007ooOol01Woo00<007ooOol0>7oo00<007ooOol06Woo00<0
07ooOol09Goo00<007ooOol0c7oo0003Ool01@00Oomoogoo00000Woo00<007ooOol017oo1000M7oo
00<007ooOol0>7oo00<007ooOol0ogoo4Woo0004Ool01000Oomoo`000Woo00<007ooOol017oo00<0
07ooOol0AWoo00<007ooOol0;7oo00<007ooOol0>7oo00<007ooOol06Woo00<007ooOol01Woo00<0
07ooOol01goo00<007ooOol0hGoo00001Goo001oogoo00000Woo00@007ooOol000Ioo`03001oogoo
07Eoo`03001oogoo00Eoo`=l031oo`03001oogoo0?mooa9oo`000Woo0P0017oo0P001goo00<007oo
Ool0Cgoo00<007ooOol08goo00<007ooOol01Goo0g`0<7oo00<007ooOol01Goo00<007ooOol0:Woo
00<007ooOol0g7oo000AOol00`00Oomoo`0GOol00`00Oomoo`1KOol00`00Oomoo`05Ool3O00`Ool0
0`00Oomoo`3oOolBOol0015oo`03001oogoo04Ioo`03001oogoo02aoo`03001oogoo03Qoo`03001o
ogoo03Eoo`03001oogoo07]oo`03001oogoo05]oo`004Goo00<007ooOol0MGoo00<007ooOol0>7oo
00<007ooOol0;Woo00<007ooOol0h7oo000AOol00`00Oomoo`1eOol00`00Oomoo`0hOol00`00Oomo
o`1_Ool00`00Oomoo`2EOol00`00Oomoo`07Ool0015oo`03001oogoo01eoo`03001oogoo05Eoo`03
001oogoo03Moo`03001oogoo0<Eoo`03001oogoo04Yoo`004Goo00<007ooOol01Goo00<007ooOol0
2goo00<007ooOol02goo00<007ooOol0DGoo00<007ooOol0=goo00<007ooOol0?Woo00<007ooOol0
3goo00<007ooOol0_goo000AOol00`00Oomoo`1fOol00`00Oomoo`0fOol00`00Oomoo`3oOolCOol0
015oo`03001oogoo07Ioo`03001oogoo00=oo`03001oogoo02moo`03001oogoo0=Ioo`03001oogoo
03Yoo`004Goo00<007ooOol07Goo00<007ooOol0E7oo00@007ooOol002eoo`03001oogoo00Ioo`03
001oogoo0?mooaAoo`004Goo00<007ooOol0Mgoo00<007ooOol0=7oo00<007ooOol04goo00<007oo
Ool0oGoo000AOol00`00Oomoo`0;Ool00`00Oomoo`0WOol00`00Oomoo`0oOol00`00Oomoo`0cOol0
0`00Oomoo`26Ool00`00Oomoo`2;Ool0015oo`<007Qoo`03001oogoo039oo`03001oogoo0?mooaEo
o`004Goo00<007ooOol0NGoo00<007ooOol0<7oo00<007ooOol02Woo00<007ooOol0>Goo00<007oo
Ool0RWoo00<007ooOol0?goo000AOol00`00Oomoo`1jOol00`00Oomoo`0^Ool00`00Oomoo`0aOol0
0`00Oomoo`1fOol00`00Oomoo`1YOol0015oo`03001oo`0002Aoo`03001oogoo05Aoo`03001oogoo
02aoo`03001oogoo0;Qoo`03001oogoo05aoo`004Goo00<007ooOol0Ngoo00<007ooOol06Woo0g`0
3Woo00<007ooOol0RWoo00<007ooOol0Rgoo000AOol00`00Oomoo`1>Ool00`00Oomoo`0[Ool00`00
Oomoo`0IOol3O00>Ool00`00Oomoo`0dOol00`00Oomoo`2>Ool00`00Oomoo`0MOol00`00Oomoo`0`
Ool0015oo`03001oogoo07aoo`8001Yoo`=l00eoo`03001oogoo08Yoo`03001oogoo08aoo`004Goo
00<007ooOol0:Goo00<007ooOol027oo00<007ooOol0Agoo00<007ooOol09Woo00<007ooOol0ogoo
6goo000AOol00`00Oomoo`1oOol2000UOol00`00Oomoo`3aOol00`00Oomoo`0WOol0015oo`03001o
ogoo021oo`03001oogoo05ioo`03001oogoo021oo`8007]oo`03001oogoo01Uoo`03001oogoo00Eo
o`03001oogoo07aoo`004Goo00<007ooOol0D7oo00<007ooOol01Goo00<007ooOol09goo00<007oo
Ool07Goo0P00WGoo00<007ooOol0<7oo00<007ooOol0CGoo000AOol00`00Oomoo`23Ool3000KOol0
0`00Oomoo`2?Ool00`00Oomoo`1:Ool00`00Oomoo`11Ool0015oo`03001oogoo08Ioo`8001Moo`80
03Aoo`03001oogoo03]oo`03001oogoo07aoo`03001oogoo01Ioo`03001oogoo01Ioo`004Goo00<0
07ooOol0R7oo00<007ooOol04Goo0`00ogoo9Woo000AOol00`00Oomoo`1]Ool00`00Oomoo`0IOol6
000:Ool3000cOol00`00Oomoo`3bOol0015oo`<008moo`X00?mooaYoo`03001oogoo00moo`004Goo
00<007ooOol0SGoo00<007ooOol0G7oo00<007ooOol0BGoo00<007ooOol0RGoo000AOol00`00Oomo
o`2DOol00`00Oomoo`3oOol^Ool0015oo`03001oogoo0?moolEoo`004Goo00<007ooOol0^Goo00<0
07ooOol0ogoo2Goo000AOol00`00Oomoo`1^Ool00`00Oomoo`0oOol00`00Oomoo`0<Ool00`00Oomo
o`0TOol00`00Oomoo`35Ool00`00Oomoo`0COol0015oo`03001oogoo0?moo`eoo`03001oogoo02ao
o`03001oogoo08Ioo`004Goo00<007ooOol0ogooaGoo000AOol00`00Oomoo`3oOol4Ool00`00Oomo
o`2XOol00`00Oomoo`0COol0015oo`03001oogoo0?moolEoo`004Goo00<007ooOol0jWoo00<007oo
Ool0egoo000AOol00`00Oomoo`3oOol]Ool00`00Oomoo`2EOol0015oo`03001oogoo09Yoo`03001o
ogoo03Qoo`03001oogoo0>aoo`004Goo00<007ooOol0ogooaGoo000AOol00`00Oomoo`2OOol00`00
Oomoo`1FOol00`00Oomoo`0<Ool00`00Oomoo`2jOol0015oo`<00=Qoo`d004Yoo`03001oogoo05Io
o`03001oogoo03Uoo`004Goo00<007ooOol0eGoo0`003Goo0`00BWoo00<007ooOol087oo00<007oo
Ool0DGoo00<007ooOol067oo000AOol00`00Oomoo`0POol00`00Oomoo`2_Ool3000COol300000goo
001oo`3FOol0015oo`03001oogoo0<Ioo`03001oogoo00Moo`8001Uoo`03001oogoo05Uoo`03001o
ogoo07Yoo`004Goo00<007ooOol0cWoo0P0077oo00<007ooOol0Jgoo00<007ooOol06goo00<007oo
Ool0@Woo00<007ooOol017oo000AOol00`00Oomoo`0NOol00`00Oomoo`2/Ool00`00Oomoo`0@Ool3
01l:Ool2003EOol0015oo`03001oogoo0<]oo`8001=oo`<07`aoo`03001oogoo05Moo`03001oogoo
07Qoo`004Goo00<007ooOol0bGoo0P005Goo0`0O3Goo0P008Goo00<007ooOol0[Woo000AOol00`00
Oomoo`39Ool00`00Oomoo`0VOol00`00Oomoo`1OOol00`00Oomoo`1]Ool0015oo`03001oogoo0:Yo
o`03001oogoo01]oo`03001oogoo02Moo`03001oogoo06Yoo`03001oogoo069oo`004Goo00<007oo
Ool0agoo00<007ooOol0:Goo00<007ooOol0Igoo00<007ooOol0I7oo000AOol00`00Oomoo`36Ool0
0`00Oomoo`0[Ool00`00Oomoo`3=Ool0015oo`03001oogoo0<Eoo`03001oogoo02eoo`03001oogoo
04eoo`03001oogoo07aoo`004Goo00<007ooOol0aGoo00<007ooOol05goo0`0O57oo00<007ooOol0
27oo00<007ooOol0>Goo00<007ooOol0>7oo00<007ooOol0BGoo000AOol00`00Oomoo`1DOol01@00
Oomoogoo0000?Woo00<007ooOol0:Woo00<007ooOol067oo0`0O57oo00<007ooOol0T7oo00<007oo
Ool0>7oo000AOol3000NOol00`00Oomoo`0gOol00`00Oomoo`0MOol00`00Oomoo`0DOol00`00Oomo
o`0bOol00`00Oomoo`0HOol301lEOol00`00Oomoo`3:Ool0015oo`03001oogoo0<=oo`03001oogoo
035oo`03001oogoo0<Yoo`004Goo00<007ooOol0`Woo00<007ooOol0<Woo00<007ooOol0bWoo000A
Ool00`00Oomoo`32Ool00`00Ool0000YOol301l7Ool00`00Oomoo`29Ool00`00Oomoo`0mOol0015o
o`03001oogoo0<5oo`03001oogoo02Yoo`<07`Moo`03001oogoo09aoo`03001oogoo00eoo`03001o
ogoo01Yoo`004Goo00<007ooOol0Kgoo00<007ooOol0Cgoo00<007ooOol0:Woo0`0O27oo00<007oo
Ool0TGoo00<007ooOol0=7oo000AOol00`00Oomoo`31Ool00`00Oomoo`0fOol00`00Oomoo`0dOol0
0`00Oomoo`2@Ool0015oo`03001oogoo0<1oo`03001oogoo03Moo`03001oogoo00Eoo`03001oogoo
06=oo`03001oogoo05Uoo`004Goo00<007ooOol0`7oo00<007ooOol067oo0`0O77oo00<007ooOol0
ZGoo00<007ooOol06goo000AOol00`00Oomoo`2oOol00`00Oomoo`0IOol301lLOol00`00Oomoo`37
Ool0015oo`03001oogoo0;moo`03001oogoo01Uoo`<07aaoo`03001oogoo0<Moo`004Goo00<007oo
Ool0Ngoo00<007ooOol0<Woo00<007ooOol037oo00<007ooOol02goo0`0O:goo00<007ooOol0QGoo
00<007ooOol0?Woo000AOol00`00Oomoo`02Ool00`00Oomoo`0EOol00`00Oomoo`2ROol00`00Oomo
o`0;Ool301l[Ool00`00Oomoo`36Ool00004Ool000000004Ool20007Ool00`00Oomoo`0`Ool00`00
Oomoo`2<Ool00`00Oomoo`0;Ool301lIOol301l?Ool00`00Oomoo`0EOol00`00Oomoo`2^Ool000Ao
o`04001oogoo0002Ool00`00Oomoo`04Ool00`00Oomoo`17Ool00`00Oomoo`0NOol00`00Oomoo`1D
Ool00`00Oomoo`0WOol301l?Ool00`00Oomoo`36Ool000Aoo`04001oogoo0002Ool00`00Oomoo`04
Ool40002Ool00`00Oomoo`1fOol00`00Oomoo`10Ool00`00Oomoo`0WOol301l?Ool00`00Oomoo`36
Ool0009oo`8000=oo`04001oogoo0006Ool00`00Oomoo`2lOol01000Oomoo`00>goo00<007ooOol0
KGoo00<007ooOol0EWoo0004Ool01000Oomoo`000Woo00<007ooOol017oo00<007ooOol0MWoo00<0
07ooOol0AWoo00<007ooOol0>Goo00<007ooOol0aWoo000017oo0000000017oo0P001goo00<007oo
Ool0@Woo00<007ooOol0NWoo00<007ooOol0>Goo00<007ooOol0aWoo000AOol00`00Oomoo`2oOol0
0`00Oomoo`0iOol00`00Oomoo`0kOol00`00Oomoo`28Ool0015oo`03001oogoo0;moo`03001oogoo
00Moo`<07bioo`03001oogoo0<Moo`004Goo00<007ooOol0Fgoo00<007ooOol03goo00<007ooOol0
D7oo00<007ooOol01Woo0`0O9Goo0`0O1Woo00<007ooOol0agoo000AOol00`00Oomoo`1eOol00`00
Oomoo`18Ool00`00Oomoo`06Ool301lUOol301l6Ool00`00Oomoo`37Ool0015oo`03001oogoo08mo
o`03001oogoo00Ioo`03001oogoo02Eoo`03001oogoo029oo`<07`Uoo`<07`Ioo`03001oogoo03mo
o`03001oogoo08Eoo`004Goo00<007ooOol00goo00<007ooOol0^goo00D007ooOomoo`0001moo`<0
7a9oo`03001oogoo06aoo`03001oogoo05Qoo`004Goo00<007ooOol0SGoo00<007ooOol0<Goo00<0
07ooOol08Goo0`0O4Goo00<007ooOol08Woo00<007ooOol0Xgoo000AOol00`00Oomoo`31Ool00`00
Oomoo`0@Ool301lQOol00`00Oomoo`0lOol00`00Oomoo`2:Ool0015oo`03001oogoo019oo`03001o
ogoo0:eoo`03001oogoo00moo`<07b5oo`03001oogoo0<Uoo`004Goo00<007ooOol0@Goo00<007oo
Ool0OWoo00<007ooOol03goo0`0O87oo00<007ooOol0>Goo00<007ooOol0SWoo000AOol00`00Oomo
o`0IOol00`00Oomoo`2WOol00`00Oomoo`0aOol00`00Oomoo`3:Ool0015oo`<00:Yoo`03001oogoo
01Moo`03001oogoo031oo`03001oogoo02Yoo`03001oogoo09eoo`004Goo00<007ooOol0Jgoo00<0
07ooOol0EWoo00<007ooOol0;goo00<007ooOol0bgoo000AOol00`00Oomoo`05Ool00`00Oomoo`0b
Ool00`00Oomoo`28Ool00`00Oomoo`0^Ool00`00Oomoo`10Ool00`00Oomoo`1dOol00`00Oomoo`0A
Ool0015oo`03001oogoo00]oo`03001oogoo02ioo`03001oogoo08Ioo`03001oogoo02eoo`03001o
ogoo04Qoo`03001oogoo085oo`004Goo00<007ooOol0KWoo00<007ooOol0EGoo00<007ooOol0:goo
00<007ooOol0cGoo000AOol00`00Oomoo`23Ool00`00Oomoo`11Ool00`00Oomoo`0YOol00`00Oomo
o`1gOol00`00Oomoo`1DOol0015oo`03001oogoo011oo`03001oogoo0;Eoo`03001oogoo02Moo`03
001oogoo06Ioo`03001oogoo06Ioo`004Goo00<007ooOol0bGoo0P009Woo00<007ooOol0>goo00<0
07ooOol0EGoo00<007ooOol0>Woo000AOol00`00Oomoo`1FOol00`00Oomoo`1bOol00`00Oomoo`0Q
Ool2000hOol00`00Oomoo`2HOol0015oo`03001oogoo09Eoo`03001oogoo03Aoo`03001oogoo01mo
o`03001oogoo029oo`03001oogoo02Qoo`03001oogoo08=oo`004Goo00<007ooOol0C7oo00<007oo
Ool0@Woo00<007ooOol0>Goo00<007ooOol077oo0P00eWoo000AOol00`00Oomoo`1iOol00`00Oomo
o`1AOol4000IOol2001EOol00`00Oomoo`0kOol00`00Oomoo`12Ool0015oo`03001oogoo09aoo`03
001oogoo039oo`8001Ioo`03001oogoo0=Qoo`004Goo00<007ooOol0LGoo00<007ooOol0Ggoo0`00
4Goo0P001goo00<007ooOol06goo00<007ooOol0Igoo00<007ooOol0>goo00<007ooOol02goo000A
Ool00`00Oomoo`0WOol00`00Oomoo`0SOol00`00Oomoo`0jOol00`00Oomoo`0[Ool00`00Oomoo`0K
Ool60005Ool6000`Ool00`00Oomoo`1oOol00`00Oomoo`0FOol00`00Oomoo`0?Ool0015oo`<00=ao
o`D000]oo`03001oogoo0=Eoo`004Goo00<007ooOol01Goo00<007ooOol09Goo00<007ooOol0:goo
00<007ooOol03Woo00<007ooOol0F7oo00<007ooOol0Rgoo00<007ooOol0K7oo000AOol00`00Oomo
o`1=Ool00`00Oomoo`1fOol00`00Oomoo`3kOol0015oo`03001oogoo0?mooeeoo`03001oogoo02Qo
o`03001oogoo01aoo`03001oogoo01]oo`004Goo00<007ooOol0ogoo5goo00<007ooOol01Woo00<0
07ooOol0DGoo00<007ooOol0CWoo000AOol00`00Oomoo`1JOol00`00Oomoo`1eOol00`00Oomoo`1S
Ool00`00Oomoo`0/Ool00`00Oomoo`1JOol0015oo`03001oogoo075oo`03001oogoo0?mooe5oo`00
4Goo00<007ooOol0ogooaGoo000AOol00`00Oomoo`34Ool00`00Oomoo`2KOol00`00Oomoo`0JOol0
0`00Oomoo`0bOol00`00Oomoo`0=Ool0015oo`03001oogoo0?mooa=oo`03001oogoo04Moo`03001o
ogoo06Eoo`004Goo00<007ooOol0eWoo00<007ooOol08Woo00<007ooOol0aWoo000AOol00`00Oomo
o`3>Ool00`00Oomoo`1ROol00`00Oomoo`1MOol00`00Oomoo`0^Ool0015oo`03001oogoo00eoo`03
001oogoo07Moo`03001oogoo009oo`03001oogoo0?moocIoo`004Goo00<007ooOol0H7oo00<007oo
Ool0Vgoo00<007ooOol0`goo000AOol00`00Oomoo`1@Ool00`00Oomoo`3COol30n2KOol0015oo`<0
0?moob5oo`H000<3h0L009Aoo`004Goo00<007ooOol0JWoo00<007ooOol0/7oo0`001Woo0`?P1goo
0`00TGoo000AOol00`00Oomoo`2[Ool00`00Oomoo`0kOol00`00Oomoo`0_Ool2000FOol2002?Ool0
015oo`03001oogoo05]oo`03001oogoo02Eoo`03001oogoo06]oo`03001oogoo02Ioo`03001oogoo
01Qoo`<004=oo`03001oogoo04Ioo`004Goo00<007ooOol0ogoo6Goo0P007Woo00<007ooOol0:7oo
00<007ooOol0GWoo000AOol00`00Oomoo`3oOolGOol2000QOol00`00Oomoo`02Ool00`00Oomoo`23
Ool0015oo`03001oogoo06Yoo`03001oogoo0:Qoo`03001oogoo029oo`03001oogoo07Aoo`03001o
ogoo011oo`004Goo00<007ooOol0KGoo00<007ooOol0Y7oo00<007ooOol097oo00<007ooOol0;7oo
00<007ooOol0Egoo000AOol00`00Oomoo`0<Ool00`00Oomoo`3oOol5Ool00`00Oomoo`0VOol00`00
Oomoo`0cOol00`00Oomoo`1?Ool0015oo`03001oogoo09ioo`03001oogoo01Qoo`03001oogoo05Io
o`03001oogoo02Qoo`03001oogoo08Aoo`004Goo00<007ooOol0ogoo4Woo00<007ooOol0:Goo0`?P
1Goo00<007ooOol00goo00<007ooOol04Woo00<007ooOol0HGoo000AOol00`00Oomoo`0AOol00`00
Oomoo`0OOol00`00Oomoo`0YOol00`00Oomoo`0TOol00`00Oomoo`27Ool00`00Oomoo`0ZOol30n24
Ool0015oo`03001oogoo019oo`03001oogoo04moo`03001oogoo02Ioo`03001oogoo055oo`03001o
ogoo02aoo`03001oogoo02Yoo`<3h1Eoo`03001oogoo06aoo`004Goo00<007ooOol0UGoo00<007oo
Ool0Mgoo00<007ooOol0;Woo00<007ooOol0PGoo000AOol2003oOol@Ool00`00Oomoo`0`Ool00`00
Oomoo`20Ool0015oo`<000=oo`03001oogoo03eoo`03001oogoo07ioo`03001oogoo04Moo`03001o
ogoo035oo`03001oogoo055oo`03001oogoo01Yoo`03001oogoo00ioo`004Goo00<007ooOol0bWoo
00<007ooOol0@7oo00<007ooOol0<Woo00<007ooOol0Ogoo000AOol00`00Oomoo`2AOol00`00Oomo
o`1iOol00`00Oomoo`0cOol00`00Oomoo`1COol00`00Oomoo`0XOol0015oo`03001oogoo07aoo`03
001oogoo02Moo`03001oogoo06Aoo`03001oogoo03=oo`03001oogoo02Eoo`03001oogoo05Ioo`00
4Goo00<007ooOol0?7oo00<007ooOol0cGoo00<007ooOol0=7oo00<007ooOol0OWoo000AOol00`00
Oomoo`1UOol00`00Oomoo`2TOol00`00Oomoo`0eOol00`00Oomoo`0bOol00`00Oomoo`0mOol00`00
Oomoo`08Ool0015oo`03001oogoo0<Yoo`03001oogoo03Qoo`03001oogoo00=oo`03001oogoo03Io
o`03001oogoo07eoo`004Goo00<007ooOol0ogoo37oo00<007ooOol0=Woo00<007ooOol0OGoo000A
Ool00`00Oomoo`06Ool00`00Oomoo`0IOol00`00Oomoo`3VOol00`00Oomoo`0LOol30n0HOol00`00
Oomoo`1lOol0015oo`03001oogoo0?moo`]oo`03001oogoo01eoo`<3h1Qoo`03001oogoo07aoo`00
4Goo00<007ooOol03goo00<007ooOol0AGoo00<007ooOol04goo00<007ooOol0NGoo00<007ooOol0
7Woo00<007ooOol07Goo0`?P67oo00@000?P0n03h7]oo`004Goo00<007ooOol0o7oo00<007ooOol0
2goo00<007ooOol0<goo0`?P0Woo00@000?P0n03h7]oo`000Woo0`000goo0P001goo00<007ooOol0
D7oo00<007oo0000[Goo00<007ooOol01goo00<007ooOol0<goo0`?P0Woo00@000?P0n03h45oo`03
001oogoo03Moo`000goo00D007ooOomoo`00009oo`03001oogoo00Aoo`03001oogoo06]oo`03001o
ogoo06=oo`03001oogoo01Moo`03001oogoo01aoo`03001oogoo03=oo`<3h09oo`03001oogoo07ao
o`0000=oo`0000000P000Woo00@007ooOol000Ioo`@00?moo`Yoo`03001oogoo03Qoo`03001oogoo
07aoo`0000Aoo`00Ool000=oo`04001oogoo0006Ool00`00Oomoo`3oOol;Ool00`00Oomoo`03Ool3
0n0bOol00`00Oomoo`0jOol00`00Oomoo`0oOol00004Ool007oo0003Ool01000Oomoo`001Woo00<0
07ooOol0j7oo00<007ooOol07goo00<007ooOol00goo0`?P8Goo0`?P0goo0`?P27oo00<007ooOol0
O7oo0002Ool20004Ool20007Ool00`00Oomoo`1?Ool00`00Oomoo`17Ool00`00Oomoo`1^Ool00`00
Oomoo`03Ool30n0QOol30n03Ool30n08Ool00`00Oomoo`0mOol00`00Oomoo`0WOol00`00Oomoo`0B
Ool0015oo`03001oogoo06Yoo`03001oogoo00]oo`03001oogoo08moo`03001oogoo02Moo`<3h0=o
o`<3h0Qoo`03001oogoo07aoo`004Goo00<007ooOol0IGoo00<007ooOol03goo00<007ooOol0T7oo
00<007ooOol0>7oo00<007ooOol0Dgoo00<007ooOol09Woo000AOol00`00Oomoo`3OOol00`00Oomo
o`0XOol00`00Oomoo`0hOol00`00Oomoo`0aOol00`00Oomoo`18Ool0015oo`03001oogoo0?moo`ao
o`03001oogoo03Moo`03001oogoo07aoo`004Goo00<007ooOol0LWoo00<007ooOol0UWoo00<007oo
Ool0=Woo00<007ooOol0OGoo000AOol00`00Oomoo`2dOol00`00Oomoo`1DOol00`00Oomoo`0fOol0
0`00Oomoo`1mOol0015oo`03001oogoo0?moo`eoo`03001oogoo03Eoo`03001oogoo07Eoo`03001o
ogoo00Eoo`004Goo00<007ooOol0C7oo00<007ooOol0_Goo00<007ooOol0=7oo00<007ooOol0;Goo
00<007ooOol0CWoo000AOol00`00Oomoo`3oOol=Ool00`00Oomoo`0dOol00`00Oomoo`1nOol0015o
o`03001oogoo0;=oo`03001oogoo05Moo`03001oogoo03=oo`03001oogoo021oo`03001oogoo05]o
o`004Goo00<007ooOol0ogoo3Woo00<007ooOol0<Woo00<007ooOol0LWoo00<007ooOol02Woo000A
Ool3002=Ool00`00Oomoo`1nOol00`00Oomoo`0aOol00`00Oomoo`0>Ool00`00Oomoo`1^Ool0015o
o`03001oogoo0?moo`aoo`<3h003001oogoo031oo`03001oogoo081oo`004Goo00<007ooOol0ogoo
37oo0`?P00<007ooOol0;goo00<007ooOol0PGoo000AOol00`00Oomoo`0]Ool00`00Oomoo`0iOol0
0`00Oomoo`2OOol30n000goo001oo`0_Ool00`00Oomoo`21Ool0015oo`03001oogoo05Uoo`03001o
ogoo0;Aoo`03001oogoo02aoo`03001oogoo07Ioo`03001oogoo00Uoo`004Goo00<007ooOol0AWoo
00<007ooOol0Xgoo00<007ooOol08Woo00<007ooOol0:7oo0`?PQGoo000AOol00`00Oomoo`13Ool0
0`00Oomoo`3<Ool00`00Oomoo`0WOol30n25Ool0015oo`03001oogoo08Eoo`03001oogoo02Ioo`03
001oogoo00moo`03001oogoo00moo`03001oogoo02]oo`03001oogoo011oo`03001oogoo02Ioo`<3
h8Eoo`004Goo00<007ooOol0ogoo5Goo00<007ooOol097oo00<007ooOol06Goo00<007ooOol0JWoo
000AOol00`00Oomoo`3oOolFOol00`00Oomoo`0ROol00`00Oomoo`27Ool0015oo`03001oogoo03]o
o`03001oogoo0=Qoo`<0021oo`03001oogoo08Qoo`004Goo00<007ooOol0?Goo00<007ooOol0fGoo
00<007ooOol06goo0P00Rgoo000AOol00`00Oomoo`0]Ool00`00Oomoo`3;Ool00`00Oomoo`0LOol0
0`00Oomoo`0GOol3002=Ool0015oo`03001oogoo031oo`03001oogoo0>Qoo`<001Aoo`8000Uoo`03
001oogoo08Aoo`004Goo00<007ooOol0FGoo00<007ooOol05Goo00<007ooOol0?Woo00<007ooOol0
JGoo0`003Woo0`003Woo00<007ooOol0PGoo000AOol30019Ool00`00Oomoo`0POol00`00Oomoo`2b
Ool>000VOol00`00Oomoo`1/Ool0015oo`03001oogoo07Moo`03001oogoo0?mooc=oo`03001oogoo
01Eoo`004Goo00<007ooOol0ogoo4goo00<007ooOol0Fgoo00<007ooOol0=Woo00<007ooOol067oo
000AOol00`00Oomoo`3oOomdOol00`00Oomoo`1>Ool0015oo`03001oogoo06Moo`03001oogoo01Yo
o`03001oogoo0?moobMoo`03001oogoo01Aoo`004Goo00<007ooOol0D7oo00<007ooOol0[7oo00<0
07ooOol0>Woo00<007ooOol0QGoo000AOol00`00Oomoo`0SOol00`00Oomoo`2KOol00`00Oomoo`3o
Ool1Ool0015oo`03001oogoo09Moo`03001oogoo05]oo`03001oogoo04Eoo`03001oogoo07Qoo`03
001oogoo00Uoo`004Goo00<007ooOol0ogoo:Woo00<007ooOol0V7oo000AOol00`00Oomoo`1aOol0
0`00Oomoo`3oOomAOol0015oo`03001oogoo0;=oo`03001oogoo04Moo`03001oogoo0<Aoo`004Goo
00<007ooOol0ogooaGoo000AOol00`00Oomoo`3oOon9Ool00`00Oomoo`0POol00`00Oomoo`0FOol0
015oo`03001oogoo06Ioo`03001oogoo0?moo`9oo`03001oogoo00Aoo`03001oogoo051oo`004Goo
00<007ooOol0k7oo00<007ooOol0eGoo000AOol3001nOol00`00Oomoo`0NOol00`00Oomoo`3oOolS
Ool0015oo`8009Qoo`03001oogoo0:Moo`03001oogoo03moo`03001oogoo03ioo`004Goo00<007oo
Ool05Goo00<007ooOol027oo00<007ooOol0A7oo00<007ooOol0M7oo00<007ooOol0NGoo00<007oo
Ool0Igoo000AOol00`00Oomoo`2:Ool00`00Oomoo`0fOol00`00Oomoo`3nOol0015oo`03001oogoo
05]oo`03001oogoo00eoo`03001oogoo0?moocaoo`03001oogoo00moo`03001oogoo00Ioo`004Goo
00<007ooOol0ogooSGoo00<007ooOol0=Goo000AOol00`00Oomoo`0LOol00`00Oomoo`3oOom^Ool0
0`00Ool0000eOol0015oo`03001oogoo0?1oo`03001oogoo01=oo`03001oogoo05Eoo`03001oogoo
06=oo`004Goo00<007ooOol05Goo00<007ooOol0jGoo00<007ooOol0[Goo00<007ooOol047oo000A
Ool00`00Oomoo`0eOol00`00Oomoo`2@Ool00`00Oomoo`1/Ool00`00Oomoo`2:Ool0015oo`03001o
ogoo06Uoo`03001oogoo0?mooeUoo`004Goo00<007ooOol09goo00<007ooOol0/Woo00<007ooOol0
f7oo00<007ooOol02Woo000AOol00`00Oomoo`3oOol>Ool00`00Oomoo`1`Ool00`00Oomoo`11Ool0
015oo`03001oogoo09aoo`03001oogoo05]oo`03001oogoo0<Moo`004Goo00<007ooOol0ogoo3Goo
00<007ooOol0]Goo000AOol3000]Ool00`00Oomoo`0SOol00`00Oomoo`0XOol00`00Oomoo`1dOol0
0`00Oomoo`3<Ool0015oo`03001oogoo0?moojYoo`03001oogoo01Qoo`004Goo00<007ooOol0nGoo
00<007ooOol0H7oo00<007ooOol0IGoo000AOol00`00Oomoo`3oOoleOol00`00Oomoo`2=Ool0015o
o`03001oogoo069oo`03001oogoo0:Eoo`03001oogoo0;Moo`004Goo00<007ooOol0ogooFgoo00<0
07ooOol0Igoo000AOol00`00Oomoo`3oOoo5Ool0015oo`03001oogoo041oo`03001oogoo0:]oo`03
001oogoo04Qoo`03001oogoo08Qoo`004Goo00<007ooOol0ogooaGoo000AOol00`00Oomoo`3oOomF
Ool00`00Oomoo`1ROol00`00Oomoo`07Ool0015oo`03001oogoo04Qoo`03001oogoo08ioo`03001o
ogoo06aoo`03001oogoo06Yoo`03001oogoo00aoo`004Goo00<007ooOol0aWoo00<007ooOol0>Goo
00<007ooOol0ZGoo00<007ooOol04goo000AOol00`00Oomoo`2aOol00`00Oomoo`0ZOol00`00Oomo
o`3SOol00004Ool000000004Ool20007Ool00`00Oomoo`12Ool00`00Oomoo`3iOol00`00Oomoo`23
Ool000Aoo`04001oogoo0002Ool00`00Oomoo`04Ool00`00Oomoo`3oOolLOol00`00Oomoo`12Ool0
0`00Oomoo`04Ool00`00Oomoo`1JOol000Aoo`04001oogoo0002Ool00`00Oomoo`04Ool40004Ool0
0`00Oomoo`1oOol00`00Oomoo`0>Ool00`00Oomoo`3oOolMOol00`00Oomoo`0:Ool00004Ool00000
0003Ool01000Oomoo`001Woo00<007ooOol0C7oo00<007ooOol0ogoo>Goo00<007ooOol087oo00<0
07ooOol05goo00000goo001oo`04Ool01000Oomoo`001Woo00<007ooOol0@goo00<007ooOol0IWoo
00<007ooOol0P7oo00<007ooOol05Goo00<007ooOol0NWoo00000goo000000020003Ool20007Ool0
0`00Oomoo`0XOol00`00Oomoo`1dOol00`00Oomoo`08Ool00`00Oomoo`03Ool00`00Oomoo`33Ool0
0`00Oomoo`1;Ool0015oo`03001oogoo071oo`03001oogoo03eoo`03001oogoo01Qoo`03001oogoo
08eoo`03001oogoo05aoo`03001oogoo00Moo`004Goo00<007ooOol0dgoo00<007ooOol0kWoo000A
Ool00`00Oomoo`3oOomIOol00`00Oomoo`1YOol0015oo`03001oogoo09Aoo`03001oogoo02Uoo`03
001oogoo03eoo`03001oogoo0<5oo`004Goo00<007ooOol0ogooaGoo000AOol00`00Oomoo`2OOol0
0`00Oomoo`21Ool00`00Oomoo`2NOol0015oo`03001oogoo00Eoo`03001oogoo0;Aoo`03001oogoo
06Moo`03001oogoo09]oo`004Goo00<007ooOol017oo00<007ooOol0ogoo_Woo000AOol00`00Oomo
o`2?Ool00`00Oomoo`2dOol00`00Oomoo`0bOol00`00Oomoo`16Ool0015oo`03001oogoo02Eoo`03
001oogoo0?Ioo`03001oogoo02Yoo`03001oogoo04Ioo`03001oogoo02eoo`004Goo00<007ooOol0
>Woo00<007ooOol0:Goo00<007ooOol0]Goo00<007ooOol0Xgoo000AOol3000MOol00`00Oomoo`3o
Ool/Ool00`00Oomoo`1fOol0015oo`03001oogoo02Ioo`03001oogoo0?mooh9oo`03001oogoo01Mo
o`004Goo00<007ooOol0[Goo00<007ooOol0?goo00<007ooOol0TGoo00<007ooOol0?Woo000AOol0
0`00Oomoo`0YOol00`00Oomoo`2EOol00`00Oomoo`2OOol00`00Oomoo`1NOol0015oo`03001oogoo
01aoo`03001oogoo00Uoo`03001oogoo00aoo`03001oogoo0=]oo`03001oogoo0:aoo`004Goo00<0
07ooOol0N7oo00<007ooOol0=7oo00<007ooOol0;7oo00<007ooOol0;goo00<007ooOol0/Goo000A
Ool00`00Oomoo`08Ool00`00Oomoo`1_Ool00`00Oomoo`06Ool00`00Oomoo`1NOol00`00Ool0002P
Ool00`00Oomoo`0jOol0015oo`03001oogoo0?moolEoo`004Goo00<007ooOol0DGoo00<007ooOol0
Ggoo00<007ooOol0ogoo3goo000AOol00`00Oomoo`0oOol00`00Oomoo`3KOol00`00Oomoo`0aOol0
0`00Oomoo`1`Ool0015oo`03001oogoo07Uoo`03001oogoo0?moodUoo`004Goo00<007ooOol01Goo
00<007ooOol0Bgoo00<007ooOol067oo00<007ooOol0_7oo00<007ooOol0U7oo000AOol00`00Oomo
o`3oOomJOol00`00Oomoo`1XOol0015oo`03001oogoo0?moobEoo`03001oogoo09eoo`004Goo00<0
07ooOol0PGoo00<007ooOol0I7oo00<007ooOol0Cgoo00<007ooOol0Qgoo000AOol3001KOol00`00
Oomoo`0ZOol00`00Oomoo`0TOol00`00Oomoo`1`Ool01000Oomoo`00WWoo000AOol00`00Oomoo`3[
Ool00`00Oomoo`3FOol0015oo`03001oogoo00Aoo`03001oogoo0;9oo`03001oogoo0>Uoo`03001o
ogoo011oo`03001oogoo00Uoo`004Goo00<007ooOol06Woo00<007ooOol0ogoo5Goo00<007ooOol0
T7oo000AOol00`00Oomoo`3oOol2Ool00`00Oomoo`12Ool00`00Oomoo`1kOol0015oo`03001oogoo
05Ioo`03001oogoo0?Eoo`03001oogoo01=oo`03001oogoo00]oo`03001oogoo00Uoo`03001oogoo
01Eoo`03001oogoo02]oo`004Goo00<007ooOol0@Woo00<007ooOol0?7oo00<007ooOol0ogoo@Goo
000AOol00`00Oomoo`0fOol00`00Oomoo`1=Ool00`00Oomoo`0bOol00`00Oomoo`0BOol00`00Oomo
o`08Ool00`00Oomoo`3VOol0015oo`03001oogoo0?moobQoo`03001oogoo09Yoo`004Goo00<007oo
Ool0<Woo00<007ooOol0ogoo1Woo00<007ooOol00goo00<007ooOol0PGoo000AOol00`00Oomoo`3U
Ool00`00Oomoo`1NOol01@00Oomoogoo0000NGoo000AOol00`00Oomoo`3oOoo5Ool0015oo`03001o
ogoo0;Ioo`03001oogoo07Uoo`03001oogoo08moo`004Goo00<007ooOol0;goo00<007ooOol06goo
00<007ooOol05Woo00<007ooOol0ogooG7oo000AOol00`00Oomoo`3oOon>Ool00`00Oomoo`0ZOol0
0`00Oomoo`07Ool0015oo`<003Uoo`03001oogoo0;Uoo`03001oogoo035oo`05001oogooOol0002F
Ool0015oo`03001oogoo0?Aoo`03001oogoo0<eoo`004Goo00<007ooOol0B7oo00<007ooOol0BWoo
00<007ooOol0ogoo;Goo000AOol00`00Oomoo`0UOol00`00Oomoo`1NOol00`00Oomoo`1mOol00`00
Oomoo`2kOol0015oo`03001oogoo0?moogmoo`03001oogoo04=oo`004Goo00<007ooOol0=goo00<0
07ooOol0ogooP7oo00<007ooOol027oo000AOol00`00Oomoo`3;Ool00`00Oomoo`2MOol00`00Oomo
o`1FOol0015oo`03001oogoo09eoo`03001oogoo0=Ioo`03001oogoo02Qoo`03001oogoo00Moo`03
001oogoo01Ioo`004Goo00<007ooOol06goo00<007ooOol027oo00<007ooOol0ogooJGoo00<007oo
Ool0<7oo000AOol00`00Oomoo`2`Ool00`00Oomoo`3oOolBOol0015oo`03001oogoo05eoo`03001o
ogoo06Ioo`03001oogoo00Uoo`03001oogoo08Ioo`03001oogoo06Ioo`004Goo00<007ooOol0kWoo
00<007ooOol0Qgoo00<007ooOol0BGoo000AOol00`00Oomoo`0_Ool00`00Oomoo`2:Ool00`00Oomo
o`17Ool00`00Oomoo`2MOol00`00Oomoo`0KOol0015oo`03001oogoo0?mooaIoo`03001oogoo011o
o`03001oogoo06aoo`03001oogoo02Yoo`004Goo00<007ooOol0VGoo00<007ooOol07Goo00<007oo
Ool0ogoo2Goo000AOol30013Ool00`00Oomoo`2]Ool00`00Oomoo`36Ool00`00Oomoo`05Ool0015o
o`03001oogoo0<=oo`03001oogoo0?ioo`004Goo00<007ooOol0/7oo00<007ooOol06goo00<007oo
Ool06Goo00<007ooOol0egoo000AOol00`00Oomoo`0WOol00`00Oomoo`3oOolFOol00`00Oomoo`18
Ool00`00Oomoo`0gOol0015oo`03001oogoo07moo`03001oogoo08Uoo`03001oogoo0;Ioo`004Goo
00<007ooOol0dGoo00<007ooOol0l7oo000AOol00`00Oomoo`1>Ool00`00Oomoo`0fOol00`00Oomo
o`2JOol00`00Oomoo`2MOol0015oo`03001oogoo0?mooj=oo`03001oogoo01moo`004Goo00<007oo
Ool0kgoo00<007ooOol00goo00<007ooOol0L7oo00<007ooOol0<7oo00<007ooOol09Woo000AOol0
0`00Oomoo`20Ool00`00Oomoo`02Ool00`00Oomoo`3oOolmOol0015oo`03001oogoo0=moo`03001o
ogoo0>9oo`004Goo00<007ooOol0Egoo00<007ooOol0@7oo00<007ooOol00Woo00<007ooOol0ogoo
8goo000AOol00`00Oomoo`3oOoo5Ool0009oo`8000Aoo`8000Moo`03001oogoo0?moo`5oo`03001o
ogoo0<5oo`0000Eoo`00Oomoo`00009oo`04001oogoo0006Ool00`00Oomoo`1;Ool00`00Oomoo`0?
Ool00`00Oomoo`3^Ool00`00Oomoo`1cOol00005Ool007ooOol00002Ool01000Oomoo`001Woo1000
ogooa7oo000017oo000000000goo00@007ooOol00?moolioo`0000=oo`00Ool017oo00@007ooOol0
0?moolioo`000Woo0`000goo0P00ogoocgoo003oOooIOol00?moomUoo`00ogoofGoo0000\
\>"],
  ImageRangeCache->{{{0, 471.375}, {471.375, 0}} -> {-2.35826, -2.25776, 
  0.133996, 0.133996}}]
}, Closed]],

Cell["\<\
If the maximum distance  \[CapitalDelta] is chosen to be too small, \
then there may not be the required number of individuals within each region.  \
A smaller sample is then returned:\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(ss = 
      SampleIndividuals[p1, {{20, 20}, {30, 30}, {40, 40}}, 10, 0, R, 2]; 
    ss // TableForm\)], "Input",
  CellLabel->"In[182]:="],

Cell[BoxData[
    InterpretationBox[GridBox[{
          {"119", "325", "17", "688", "266", "413", "142", "238", "512"},
          {"617", "717", "450", "661", "56", "848", "914", "924", "945"},
          {"724", "787", "973", "172", "243", "546", "737", "\<\"\"\>", 
            "\<\"\"\>"}
          },
        RowSpacings->1,
        ColumnSpacings->3,
        RowAlignments->Baseline,
        ColumnAlignments->{Left}],
      TableForm[ {{119, 325, 17, 688, 266, 413, 142, 238, 512}, {617, 717, 
        450, 661, 56, 848, 914, 924, 945}, {724, 787, 973, 172, 243, 546, 
        737}}]]], "Output",
  CellLabel->"Out[182]//TableForm="]
}, Closed]],

Cell["\<\
It is important  that  \[CapitalDelta] be chosen large enough that  \
the Gaussian sampling function is not truncated: this requires \
\[CapitalDelta]>3\[Sigma], say.\
\>", "Text"],

Cell["Note that the same individual may appear in nearby samples:", \
"MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[
    \(ss = 
      SampleIndividuals[p1, {{20, 20}, {20, 20}, {20, 20}}, 10, 1, R, 6]; 
    Sort/@ss // TableForm\)], "Input",
  CellLabel->"In[184]:="],

Cell[BoxData[
    TagBox[GridBox[{
          {"17", "119", "142", "238", "266", "297", "325", "665", "688", 
            "741"},
          {"17", "119", "142", "238", "266", "297", "325", "413", "688", 
            "741"},
          {"17", "119", "142", "266", "297", "325", "413", "512", "688", 
            "741"}
          },
        RowSpacings->1,
        ColumnSpacings->3,
        RowAlignments->Baseline,
        ColumnAlignments->{Left}],
      (TableForm[ #]&)]], "Output",
  CellLabel->"Out[184]//TableForm="]
}, Closed]]
}, Open  ]]
},
FrontEndVersion->"4.0 for Macintosh",
ScreenRectangle->{{0, 1024}, {0, 748}},
WindowSize->{515, 626},
WindowMargins->{{Automatic, 6}, {Automatic, -7}},
StyleDefinitions -> "HelpBrowser.nb",
MacintoshSystemPageSetup->"\<\
00`0001804P000000_02@?o/onh3109BI085:0?l0@00005X0FP000003[0;@001
0000I00100000@0000000BL?0040000000000000000000000000000000000?nL
ojH?50^J00P100000000000000000000\>"
]


(***********************************************************************
Cached data follows.  If you edit this Notebook file directly, not using
Mathematica, you must remove the line containing CacheID at the top of 
the file.  The cache data will then be recreated when you save this file 
from within Mathematica.
***********************************************************************)

(*CellTagsOutline
CellTagsIndex->{
  "SampleIndividuals"->{
    Cell[1788, 53, 1191, 25, 112, "DefinitionBox",
      CellTags->"SampleIndividuals"]}
  }
*)

(*CellTagsIndex
CellTagsIndex->{
  {"SampleIndividuals", 126154, 3794}
  }
*)

(*NotebookFileOutline
Notebook[{

Cell[CellGroupData[{
Cell[1739, 51, 46, 0, 36, "SubsectionIcon"],
Cell[1788, 53, 1191, 25, 112, "DefinitionBox",
  CellTags->"SampleIndividuals"],
Cell[2982, 80, 260, 8, 70, "MathCaption"],
Cell[3245, 90, 362, 7, 74, "Input"],
Cell[3610, 99, 163, 4, 42, "MathCaption"],

Cell[CellGroupData[{
Cell[3798, 107, 159, 4, 42, "Input"],
Cell[3960, 113, 519, 14, 62, "Output"]
}, Closed]],
Cell[4494, 130, 103, 2, 23, "Input"],

Cell[CellGroupData[{
Cell[4622, 136, 551, 9, 117, "Input"],
Cell[5176, 147, 58420, 1757, 488, 22655, 1310, "GraphicsData", "PostScript", \
"Graphics"]
}, Closed]],
Cell[63611, 1907, 166, 4, 32, "MathCaption"],

Cell[CellGroupData[{
Cell[63802, 1915, 159, 4, 42, "Input"],
Cell[63964, 1921, 519, 14, 62, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[64520, 1940, 551, 9, 113, "Input"],
Cell[65074, 1951, 58159, 1753, 479, 22654, 1310, "GraphicsData", \
"PostScript", "Graphics"]
}, Closed]],
Cell[123248, 3707, 208, 4, 32, "Text"],

Cell[CellGroupData[{
Cell[123481, 3715, 159, 4, 42, "Input"],
Cell[123643, 3721, 638, 14, 62, "Output"]
}, Closed]],
Cell[124296, 3738, 190, 4, 32, "Text"],
Cell[124489, 3744, 84, 1, 28, "MathCaption"],

Cell[CellGroupData[{
Cell[124598, 3749, 165, 4, 42, "Input"],
Cell[124766, 3755, 520, 14, 62, "Output"]
}, Closed]]
}, Open  ]]
}
]
*)




(***********************************************************************
End of Mathematica Notebook file.
***********************************************************************)

