(***********************************************************************

                    Mathematica-Compatible Notebook

This notebook can be used on any computer system with Mathematica 4.0,
MathReader 4.0, or any compatible application. The data for the notebook 
starts with the line containing stars above.

To get the notebook into a Mathematica-compatible application, do one of 
the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing the 
word CacheID, otherwise Mathematica-compatible applications may try to 
use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
***********************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[     28361,        746]*)
(*NotebookOutlinePosition[     29675,        788]*)
(*  CellTagsIndexPosition[     29526,        780]*)
(*WindowFrame->Normal*)



Notebook[{

Cell[CellGroupData[{
Cell["Drawing a random genealogy", "SubsectionIcon"],

Cell[TextData[Cell[BoxData[
    FormBox[GridBox[{
          {\(RandomGenealogy[{leaf\_1, 
                leaf\_2, \[Ellipsis]}]\), \(gives\ a\ random\ realisation\ of\
\ the\ coalescent\ \(\(process\)\(.\)\)\)},
          {\(RandomGenealogy[{leaf\_1, \[Ellipsis]}, 
              NodeLabels \[Rule] {label\_1, \[Ellipsis]}]\), \(labels\ the\ \
internal\ nodes\)}
          }], TraditionalForm]]]], "DefinitionBox",
  CellTags->"RandomGenealogy"],

Cell["This loads the package:", "MathCaption"],

Cell[BoxData[
    \(<< Genealogies`Genealogies`; \)], "Input",
  CellLabel->"In[679]:="],

Cell["This generates a genealogy using the coalescent process: ", \
"MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[
    \(rg = RandomGenealogy[{a, b, c, d, e}]\)], "Input",
  CellLabel->"In[9]:="],

Cell[BoxData[
    \(Node[
      5, {0.6663383874660059`}, {Node[
          4, {0.6663383874660059`}, {Node[e, {0}, {}], 
            Node[3, {0.40113241900608054`}, {Node[
                  1, {0.18761398269484203`}, {Node[a, {0}, {}], 
                    Node[b, {0}, {}]}], 
                Node[2, {0.22142254847352522`}, {Node[c, {0}, {}], 
                    Node[d, {0}, {}]}]}]}]}]\)], "Output",
  CellLabel->"Out[9]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(Show[PlotGenealogy[rg]];\)\)], "Input",
  CellLabel->"In[10]:="],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.166667 0.166667 0.103006 0.103006 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
0 g
.5 Mabswid
[ ] 0 setdash
.41667 .20601 m
.33333 .10301 L
s
.41667 .20601 m
.5 .10301 L
s
.75 .20601 m
.66667 .10301 L
s
.75 .20601 m
.83333 .10301 L
s
.58333 .30902 m
.41667 .20601 L
s
.58333 .30902 m
.75 .20601 L
s
.5 .41202 m
.16667 .10301 L
s
.5 .41202 m
.58333 .30902 L
s
.5 .51503 m
.5 .41202 L
s
[(1)] .38333 .22661 0 0 Mshowa
[(2)] .71667 .22661 0 0 Mshowa
[(3)] .55 .32962 0 0 Mshowa
[(4)] .46667 .43262 0 0 Mshowa
[(5)] .46667 .53563 0 0 Mshowa
gsave
.16667 .0824 -66 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(e) show
1.000 setlinewidth
grestore
gsave
.33333 .0824 -66 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(a) show
1.000 setlinewidth
grestore
gsave
.5 .0824 -66 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(b) show
1.000 setlinewidth
grestore
gsave
.66667 .0824 -66 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(c) show
1.000 setlinewidth
grestore
gsave
.83333 .0824 -66 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(d) show
1.000 setlinewidth
grestore
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[10]:=",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/B000`400?l00000o`00003oo`3ooolQ
0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ
0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ
0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ
0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ
0?ooo`00;P3oool3000002`0oooo1000000[0?ooo`@00000;@3oool3000002`0oooo1000000`0?oo
o`00;@3oool00`000000oooo0?ooo`0/0?ooo`040000003oool0oooo000002d0oooo00@000000?oo
o`3oool00000:`3oool01@000000oooo0?ooo`3oool0000002X0oooo00@000000?ooo`3oool00000
<@3oool002d0oooo1@00000[0?ooo`<00000;@3oool010000000oooo0?ooo`00000[0?ooo`030000
003oool0oooo02`0oooo00@000000?ooo`3oool00000<@3oool002d0oooo00D000000?ooo`3oool0
oooo0000000Z0?ooo`040000003oool0oooo000002d0oooo00@000000?ooo`3oool00000:`3oool0
1@000000oooo0?ooo`3oool0000002X0oooo00@000000?ooo`3oool00000<@3oool002h0oooo0`00
000/0?ooo`800000;P3oool3000002d0oooo0`00000/0?ooo`<00000<@3oool008d0oooo00<00000
0?ooo`3oool0GP3oool00`000000oooo0?ooo`0_0?ooo`00S03oool2000005l0oooo0P00000a0?oo
o`00o`3ooolQ0?ooo`00<03oool2000002d0oooo00<000000?ooo`3oool0;@3oool00`000000oooo
0?ooo`0]0?ooo`030000003oool0oooo02`0oooo00<000000?ooo`3oool0;`3oool00380oooo00<0
00000?ooo`3oool0:P3oool00`000000oooo0?ooo`0]0?ooo`030000003oool0oooo02d0oooo00<0
00000?ooo`3oool0;03oool00`000000oooo0?ooo`0_0?ooo`00<`3oool00`000000oooo0?ooo`0Z
0?ooo`030000003oool0oooo02/0oooo00<000000?ooo`3oool0;`3oool00`000000oooo0?ooo`0Z
0?ooo`030000003oool0oooo0300oooo000d0?ooo`030000003oool0oooo02X0oooo00<000000?oo
o`3oool0:@3oool00`000000oooo0?ooo`0a0?ooo`030000003oool0oooo02P0oooo00<000000?oo
o`3oool0<@3oool003D0oooo00<000000?ooo`3oool0:P3oool00`000000oooo0?ooo`0W0?ooo`03
0000003oool0oooo03<0oooo00<000000?ooo`3oool09P3oool00`000000oooo0?ooo`0b0?ooo`00
=P3oool00`000000oooo0?ooo`0Z0?ooo`030000003oool0oooo02D0oooo00<000000?ooo`3oool0
=@3oool00`000000oooo0?ooo`0U0?ooo`030000003oool0oooo0380oooo000g0?ooo`030000003o
ool0oooo02T0oooo00<000000?ooo`3oool09@3oool00`000000oooo0?ooo`0e0?ooo`030000003o
ool0oooo02@0oooo00<000000?ooo`3oool0<`3oool003P0oooo00<000000?ooo`3oool0:@3oool0
0`000000oooo0?ooo`0S0?ooo`030000003oool0oooo03L0oooo00<000000?ooo`3oool08P3oool0
0`000000oooo0?ooo`0d0?ooo`00>@3oool00`000000oooo0?ooo`0Y0?ooo`030000003oool0oooo
0240oooo00<000000?ooo`3oool0>@3oool00`000000oooo0?ooo`0P0?ooo`030000003oool0oooo
03D0oooo000j0?ooo`030000003oool0oooo02T0oooo00<000000?ooo`3oool07`3oool00`000000
oooo0?ooo`0k0?ooo`030000003oool0oooo01h0oooo00<000000?ooo`3oool0=P3oool003/0oooo
00<000000?ooo`3oool0:@3oool00`000000oooo0?ooo`0M0?ooo`030000003oool0oooo03d0oooo
00<000000?ooo`3oool07@3oool00`000000oooo0?ooo`0f0?ooo`00?03oool00`000000oooo0?oo
o`0X0?ooo`030000003oool0oooo01d0oooo00<000000?ooo`3oool0?@3oool00`000000oooo0?oo
o`0L0?ooo`030000003oool0oooo03L0oooo000m0?ooo`030000003oool0oooo02P0oooo00<00000
0?ooo`3oool06`3oool00`000000oooo0?ooo`0o0?ooo`030000003oool0oooo01X0oooo00<00000
0?ooo`3oool0>03oool003h0oooo00<000000?ooo`3oool0:03oool00`000000oooo0?ooo`0I0?oo
o`030000003oool0oooo0440oooo00<000000?ooo`3oool0603oool00`000000oooo0?ooo`0i0?oo
o`00?`3oool00`000000oooo0?ooo`0X0?ooo`030000003oool0oooo01L0oooo00<000000?ooo`3o
ool0@`3oool00`000000oooo0?ooo`0G0?ooo`030000003oool0oooo03T0oooo00100?ooo`800000
:@3oool00`000000oooo0?ooo`0E0?ooo`030000003oool0oooo04D0oooo00<000000?ooo`3oool0
5@3oool00`000000oooo0?ooo`0j0?ooo`00@P3oool00`000000oooo0?ooo`0V0?ooo`030000003o
ool0oooo01D0oooo00<000000?ooo`3oool0A@3oool00`000000oooo0?ooo`0D0?ooo`030000003o
ool0oooo03/0oooo00130?ooo`030000003oool0oooo02H0oooo00<000000?ooo`3oool04`3oool0
0`000000oooo0?ooo`170?ooo`030000003oool0oooo0180oooo00<000000?ooo`3oool0?03oool0
04@0oooo00<000000?ooo`3oool09P3oool00`000000oooo0?ooo`0A0?ooo`030000003oool0oooo
04T0oooo00<000000?ooo`3oool04@3oool00`000000oooo0?ooo`0l0?ooo`00A@3oool00`000000
oooo0?ooo`0V0?ooo`030000003oool0oooo00l0oooo00<000000?ooo`3oool0B`3oool00`000000
oooo0?ooo`0?0?ooo`030000003oool0oooo03d0oooo00160?ooo`030000003oool0oooo02H0oooo
00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`1=0?ooo`030000003oool0oooo00d0oooo
00<000000?ooo`3oool0?P3oool004L0oooo00<000000?ooo`3oool09@3oool00`000000oooo0?oo
o`0=0?ooo`030000003oool0oooo04d0oooo00<000000?ooo`3oool0303oool00`000000oooo0?oo
o`0o0?ooo`00B03oool00`000000oooo0?ooo`0U0?ooo`030000003oool0oooo00/0oooo00<00000
0?ooo`3oool0C`3oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo03l0oooo00190?oo
o`030000003oool0oooo02D0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`1A0?oo
o`030000003oool0oooo00T0oooo00<000000?ooo`3oool0@03oool004X0oooo00<000000?ooo`3o
ool09@3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo05<0oooo00<000000?ooo`3o
ool01`3oool00`000000oooo0?ooo`110?ooo`00B`3oool00`000000oooo0?ooo`0U0?ooo`030000
003oool0oooo00D0oooo00<000000?ooo`3oool0E@3oool00`000000oooo0?ooo`050?ooo`030000
003oool0oooo0480oooo001<0?ooo`030000003oool0oooo02@0oooo00<000000?ooo`3oool01@3o
ool00`000000oooo0?ooo`1E0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0@`3o
ool004d0oooo00<000000?ooo`3oool0903oool00`000000oooo0?ooo`030?ooo`030000003oool0
oooo05L0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`130?ooo`00CP3oool00`00
0000oooo0?ooo`0T0?ooo`050000003oool0oooo0?ooo`000000F`3oool01@000000oooo0?ooo`3o
ool0000004H0oooo001?0?ooo`030000003oool0oooo02@0oooo00<000000?ooo`000000G@3oool0
0`000000oooo000000170?ooo`00D03oool2000002D0oooo0P00001M0?ooo`800000B03oool00580
oooo00<000000?ooo`3oool0903oool00`000000oooo0?ooo`1I0?ooo`030000003oool0oooo04P0
oooo001C0?ooo`030000003oool0oooo02@0oooo0P00001G0?ooo`800000B`3oool005@0oooo00<0
00000?ooo`3oool05@3oool3000000d0oooo0P00001<0?ooo`D000000P3oool2000004d0oooo001E
0?ooo`030000003oool0oooo01D0oooo00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`1:
0?ooo`060000003oool0oooo0000003oool00000C`3oool005H0oooo00<000000?ooo`3oool0503o
ool00`000000oooo0?ooo`0?0?ooo`800000B`3oool010000000oooo00000000001@0?ooo`00E`3o
ool00`000000oooo0?ooo`0C0?ooo`030000003oool0oooo0140oooo0P0000190?ooo`800000DP3o
ool005P0oooo00<000000?ooo`3oool04P3oool00`000000oooo0?ooo`0C0?ooo`030000003oool0
oooo04@0oooo0P0000020?ooo`030000003oool0oooo04l0oooo001I0?ooo`030000003oool0oooo
0100oooo0P00000F0?ooo`800000@`3oool2000000<0oooo00<000000?ooo`3oool0C`3oool005X0
oooo00<000000?ooo`3oool0403oool00`000000oooo0?ooo`0F0?ooo`800000?`3oool200000080
oooo0`00001B0?ooo`00F`3oool00`000000oooo0?ooo`0Z0?ooo`030000003oool0oooo03/0oooo
00<000000?ooo`3oool0E`3oool005`0oooo00<000000?ooo`3oool0:P3oool2000003T0oooo0P00
001J0?ooo`00G@3oool00`000000oooo0?ooo`0[0?ooo`800000=@3oool2000005`0oooo001N0?oo
o`030000003oool0oooo02`0oooo00<000000?ooo`3oool0<@3oool00`000000oooo0?ooo`1L0?oo
o`00G`3oool2000002d0oooo0P00000_0?ooo`800000G`3oool00640oooo00<000000?ooo`3oool0
;03oool2000002/0oooo0P00001Q0?ooo`00HP3oool00`000000oooo0?ooo`0]0?ooo`030000003o
ool0oooo02L0oooo00<000000?ooo`3oool0H@3oool006<0oooo00<000000?ooo`3oool0;@3oool2
000002D0oooo0P00001T0?ooo`00I03oool00`000000oooo0?ooo`0^0?ooo`8000008@3oool20000
06H0oooo001U0?ooo`030000003oool0oooo02l0oooo00<000000?ooo`3oool07@3oool00`000000
oooo0?ooo`1V0?ooo`00IP3oool00`000000oooo0?ooo`0_0?ooo`8000006`3oool2000006T0oooo
001W0?ooo`030000003oool0oooo0300oooo0P00000G0?ooo`800000J`3oool006P0oooo00<00000
0?ooo`3oool0<@3oool00`000000oooo0?ooo`0C0?ooo`030000003oool0oooo06/0oooo001Y0?oo
o`030000003oool0oooo0340oooo0P00000A0?ooo`800000KP3oool006X0oooo00<000000?ooo`3o
ool0<P3oool2000000d0oooo0P00001`0?ooo`00J`3oool00`000000oooo0?ooo`0c0?ooo`030000
003oool0oooo00T0oooo00<000000?ooo`3oool0L03oool006`0oooo00<000000?ooo`3oool0<`3o
ool2000000L0oooo0P00001c0?ooo`00K@3oool00`000000oooo0?ooo`0d0?ooo`8000000`3oool2
000007D0oooo001^0?ooo`030000003oool0oooo03D0oooo00<000000?ooo`000000M`3oool006l0
oooo0P00000f0?ooo`030000003oool0oooo07H0oooo001a0?ooo`030000003oool0oooo03<0oooo
00<000000?ooo`3oool0MP3oool00780oooo00<000000?ooo`3oool0<@3oool00`000000oooo0?oo
o`1g0?ooo`00L`3oool00`000000oooo0?ooo`0U0?ooo`<000001`3oool00`000000oooo0?ooo`1h
0?ooo`00M03oool00`000000oooo0?ooo`0S0?ooo`050000003oool0oooo0?ooo`0000001@3oool0
0`000000oooo0?ooo`1i0?ooo`00M@3oool00`000000oooo0?ooo`0V0?ooo`030000003oool0oooo
0080oooo00<000000?ooo`3oool0NP3oool007H0oooo00<000000?ooo`3oool08`3oool2000000D0
oooo00<000000?ooo`3oool0NP3oool007L0oooo00<000000?ooo`3oool0903oool01@000000oooo
0?ooo`3oool0000007d0oooo001h0?ooo`030000003oool0oooo01l0oooo00D000000?ooo`3oool0
oooo000000020?ooo`030000003oool0oooo07`0oooo001i0?ooo`030000003oool0oooo01l0oooo
0`0000020?ooo`030000003oool0oooo07d0oooo001j0?ooo`030000003oool0oooo0280oooo00<0
00000?ooo`3oool0OP3oool007/0oooo00<000000?ooo`3oool08@3oool00`000000oooo0?ooo`1n
0?ooo`00O03oool00`000000oooo0?ooo`0O0?ooo`030000003oool0oooo07l0oooo001m0?ooo`03
0000003oool0oooo01d0oooo00<000000?ooo`3oool0P03oool007h0oooo00<000000?ooo`3oool0
6`3oool00`000000oooo0?ooo`210?ooo`00O`3oool2000001X0oooo00<000000?ooo`3oool0PP3o
ool00840oooo00<000000?ooo`3oool05`3oool00`000000oooo0?ooo`220?ooo`00PP3oool00`00
0000oooo0?ooo`0E0?ooo`030000003oool0oooo08<0oooo00230?ooo`030000003oool0oooo01<0
oooo00<000000?ooo`3oool0Q03oool008@0oooo00<000000?ooo`3oool04@3oool00`000000oooo
0?ooo`250?ooo`00Q@3oool00`000000oooo0?ooo`0?0?ooo`030000003oool0oooo08H0oooo0026
0?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3oool0QP3oool008L0oooo00<000000?oo
o`3oool0303oool00`000000oooo0?ooo`270?ooo`00R03oool00`000000oooo0?ooo`0:0?ooo`03
0000003oool0oooo08P0oooo00290?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool0
R@3oool008X0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`2:0?ooo`00R`3oool0
0`000000oooo0?ooo`050?ooo`030000003oool0oooo08X0oooo002<0?ooo`030000003oool0oooo
00<0oooo00<000000?ooo`3oool0R`3oool008d0oooo00D000000?ooo`3oool0oooo0000002>0?oo
o`00SP3oool00`000000oooo0000002?0?ooo`00S`3oool00`000000oooo0?ooo`2>0?ooo`00S`3o
ool00`000000oooo0?ooo`2>0?ooo`00S`3oool00`000000oooo0?ooo`2>0?ooo`00Q03oool30000
00P0oooo00<000000?ooo`3oool0SP3oool008D0oooo00<000000?ooo`3oool01`3oool00`000000
oooo0?ooo`2>0?ooo`00PP3oool5000000P0oooo00<000000?ooo`3oool0SP3oool00880oooo00@0
00000?ooo`3oool000002@3oool00`000000oooo0?ooo`2>0?ooo`00P`3oool00`000000oooo0000
00090?ooo`030000003oool0oooo08h0oooo00240?ooo`8000002@3oool00`000000oooo0?ooo`2>
0?ooo`00Q@3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo08h0oooo002?0?ooo`03
0000003oool0oooo08h0oooo002?0?ooo`030000003oool0oooo08h0oooo002?0?ooo`030000003o
ool0oooo08h0oooo002?0?ooo`030000003oool0oooo08h0oooo002?0?ooo`030000003oool0oooo
08h0oooo002?0?ooo`030000003oool0oooo08h0oooo002?0?ooo`030000003oool0oooo08h0oooo
002?0?ooo`030000003oool0oooo08h0oooo002?0?ooo`030000003oool0oooo08h0oooo002?0?oo
o`030000003oool0oooo08h0oooo002?0?ooo`030000003oool0oooo08h0oooo002?0?ooo`030000
003oool0oooo08h0oooo002?0?ooo`030000003oool0oooo08h0oooo002?0?ooo`030000003oool0
oooo08h0oooo002?0?ooo`030000003oool0oooo08h0oooo002?0?ooo`030000003oool0oooo08h0
oooo002?0?ooo`030000003oool0oooo08h0oooo002?0?ooo`030000003oool0oooo08h0oooo002?
0?ooo`030000003oool0oooo08h0oooo002?0?ooo`030000003oool0oooo08h0oooo003o0?ooob40
oooo003o0?ooob40oooo00230?ooo`<00000VP3oool00880oooo00D000000?ooo`3oool0oooo0000
002I0?ooo`00QP3oool00`000000oooo0?ooo`2G0?ooo`00QP3oool00`000000oooo0?ooo`2G0?oo
o`00PP3oool4000009X0oooo00220?ooo`030000003oool0oooo09/0oooo00220?ooo`D00000V@3o
ool00?l0oooo8@3oool00?l0oooo8@3oool00?l0oooo8@3oool00?l0oooo8@3oool00?l0oooo8@3o
ool00?l0oooo8@3oool00?l0oooo8@3oool00?l0oooo8@3oool00?l0oooo8@3oool00?l0oooo8@3o
ool00?l0oooo8@3oool00?l0oooo8@3oool00?l0oooo8@3oool00?l0oooo8@3oool00?l0oooo8@3o
ool00?l0oooo8@3oool00?l0oooo8@3oool00?l0oooo8@3oool00?l0oooo8@3oool00?l0oooo8@3o
ool00001\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-1.00744, -1.00003, \
0.0209577, 0.0339103}}]
}, Open  ]],

Cell["\<\
 Coalescence times are given as the first element of the list of \
information for each node.  Nodes are labelled by an integer, counting in \
order of coealescence events.\
\>", "Text"],

Cell["\<\
Note that the root node is a dummy, with only one descendant node; \
its coalescence time is set equal to that of its descendant.  It can be \
removed by taking g\[LeftDoubleBracket]3,1\[RightDoubleBracket]; \
CondenseGenealogy[] will not remove the root of a genealogy.\
\>", "Text"],

Cell["\<\
Nodes can be labelled arbitrarily, by supplying a list ordered by \
the coalescence events.  The length of this list must be the same as the \
number of leaves:\
\>", "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[
    \(RandomGenealogy[{a, b, c, d, e}, 
      NodeLabels \[Rule] {n1, n2, n3, n4, n5}]\)], "Input",
  CellLabel->"In[5]:="],

Cell[BoxData[
    \(Node[
      n5, {3.46756277698827863`}, {Node[
          n4, {3.46756277698827863`}, {Node[d, {0}, {}], 
            Node[n3, {1.22255641009027682`}, {Node[e, {0}, {}], 
                Node[n2, {0.523266065394928325`}, {Node[c, {0}, {}], 
                    Node[n1, {0.102993102174985384`}, {Node[a, {0}, {}], 
                        Node[b, {0}, {}]}]}]}]}]}]\)], "Output",
  CellLabel->"Out[5]="]
}, Closed]],

Cell["A more flexible method is to apply a rule:", "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(RandomGenealogy[{a, b, c, d, e}] //. 
        Node[i_, {t_}, {m___}] :> NodeTemp[f[i, t], {t}, {m}]\) /. 
      NodeTemp \[Rule] Node\)], "Input",
  CellLabel->"In[8]:="],

Cell[BoxData[
    \(Node[
      f[5, 4.52508739205570797`], {4.52508739205570797`}, {Node[
          f[4, 4.52508739205570797`], {4.52508739205570797`}, {Node[
              f[2, 0.85134257583064965`], {0.85134257583064965`}, {Node[
                  f[d, 0], {0}, {}], Node[f[e, 0], {0}, {}]}], 
            Node[f[3, 
                1.2856602493515683`], {1.2856602493515683`}, {Node[
                  f[c, 0], {0}, {}], 
                Node[f[1, 
                    0.401287323224818504`], {0.401287323224818504`}, {Node[
                      f[a, 0], {0}, {}], 
                    Node[f[b, 0], {0}, {}]}]}]}]}]\)], "Output",
  CellLabel->"Out[8]="]
}, Closed]],

Cell["\<\
Note that the obvious rule \
//.Node[i_,{t_},{m___}]:>NodeTemp[f[i,t],{t},{m}] leads to an infinite \
recursion: hence the use of the dummy variable NodeTemp[].\
\>", "Text"],

Cell[TextData[{
  " ",
  Cell[BoxData[
      FormBox[GridBox[{
            {
              RowBox[{
                
                FormBox[\(\(RandomGenealogy\)\([\)\({a, b, c, d, e}, 
                    CoalescenceTimes \[Rule] {t\_1, \[Ellipsis]}\)\),
                  "TraditionalForm"], 
                "]"}], \(generates\ a\ genealogy\ with\ \ \ the\ specified\ \
coalescence\ times\)}
            }], TraditionalForm]]]
}], "DefinitionBox",
  CellTags->"CoalescenceTimes"],

Cell["\<\
By default, the coalescence times are generated by \
RandomCoalescenceTimes[k].  These are exponentially distributed intervals, \
under the standard coalescent process.  Arbitrary times can be specified, \
however:\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(rt = RandomCoalescenceTimes[5]\)], "Input",
  CellLabel->"In[12]:="],

Cell[BoxData[
    \({0.05364324807732184`, 0.05674988454998406`, 0.27212323764707924`, 
      0.7751777632379518`}\)], "Output",
  CellLabel->"Out[12]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(RandomGenealogy[{a, b, c, d, e}, 
      CoalescenceTimes \[Rule] rt]\)], "Input",
  CellLabel->"In[13]:="],

Cell[BoxData[
    \(Node[
      5, {0.7751777632379518`}, {Node[
          4, {0.7751777632379518`}, {Node[d, {0}, {}], 
            Node[3, {0.27212323764707924`}, {Node[
                  1, {0.05364324807732184`}, {Node[b, {0}, {}], 
                    Node[e, {0}, {}]}], 
                Node[2, {0.05674988454998406`}, {Node[a, {0}, {}], 
                    Node[c, {0}, {}]}]}]}]}]\)], "Output",
  CellLabel->"Out[13]="]
}, Open  ]],

Cell["\<\
For example, one could generate times appropriate to a growing \
population, or a branching process.\
\>", "Text"],

Cell[TextData[Cell[BoxData[
    FormBox[GridBox[{
          {\(RandomGenealogy[{leaf\_1, \[Ellipsis]}, 
              MutationRate \[Rule] \[Theta]]\), \(simulates\ infinite - 
                sites\ mutation\ at\ a\ scaled\ rate\[Theta] = 
              4  N\[VeryThinSpace]\(\(\[Mu]\)\(.\)\)\)}
          }], TraditionalForm]]]], "DefinitionBox",
  CellTags->"MutationRate"],

Cell["\<\
Infinite-sites mutation can be simulated by setting MutationRate\
\[Rule]\[Theta], where \[Theta]=4N\[VeryThinSpace]\[Mu].  Mutations are \
labelled by a unique integer, and the list of mutations held at each node is \
given as the second element of the list of information.\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(g = 
      RandomGenealogy[{a, b, c, d, e}, MutationRate \[Rule] 10]\)], "Input",
  CellLabel->"In[34]:="],

Cell[BoxData[
    \(Node[
      5, {2.79979239932224643`, {}}, {Node[
          4, {2.79979239932224643`, {}}, {Node[
              b, {0, {1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14}}, {}], 
            Node[3, {0.685984069617417535`, {15, 16, 17, 18, 19, 20, 21, 22, 
                  23, 24, 25, 26}}, {Node[
                  1, {0.101178472468082847`, {15, 16, 17, 18, 19, 20, 21, 22, 
                      23, 24, 25, 26, 27}}, {Node[
                      c, {0, {15, 16, 17, 18, 19, 20, 21, 22, 23, 24, 25, 26, 
                          27}}, {}], 
                    Node[e, {0, {15, 16, 17, 18, 19, 20, 21, 22, 23, 24, 25, 
                          26, 27, 30}}, {}]}], 
                Node[2, {0.410205229285356232`, {15, 16, 17, 18, 19, 20, 21, 
                      22, 23, 24, 25, 26}}, {Node[
                      a, {0, {15, 16, 17, 18, 19, 20, 21, 22, 23, 24, 25, 26, 
                          28, 29}}, {}], 
                    Node[d, {0, {15, 16, 17, 18, 19, 20, 21, 22, 23, 24, 25, 
                          26, 31, 32, 33, 34}}, {}]}]}]}]}]\)], "Output",
  CellLabel->"Out[34]="]
}, Closed]],

Cell["\<\
Note that the root node is a dummy; because its coalescence time is \
set equal to its one descendant node, here can be no mutations on this first \
branch.\
\>", "Text"],

Cell["\<\
The coalescence times can be recovered using CollapseGenealogy[]:\
\
\>", "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[
    \(t = \(CollapseGenealogy[g, 
            NodeFunction \[Rule] \((#2\[LeftDoubleBracket]1\
\[RightDoubleBracket] &)\)] // Flatten\) // Sort\)], "Input",
  CellLabel->"In[35]:="],

Cell[BoxData[
    \({0, 0, 0, 0, 0, 0.101178472468082847`, 0.410205229285356232`, 
      0.685984069617417535`, 2.79979239932224643`, 
      2.79979239932224643`}\)], "Output",
  CellLabel->"Out[35]="]
}, Closed]],

Cell["\<\
A list of the mutations at each leaf can be obtained using \
CollapseGenealogy[]:\
\>", "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[
    \(s = 
      CollapseGenealogy[g, Node \[Rule] False, 
        NodeFunction \[Rule] \(({#1, #2\[LeftDoubleBracket]2\
\[RightDoubleBracket]} &)\)]\)], "Input",
  CellLabel->"In[36]:="],

Cell[BoxData[
    \({{{b, {1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 
            14}}, {{{c, {15, 16, 17, 18, 19, 20, 21, 22, 23, 24, 25, 26, 
                27}}, {e, {15, 16, 17, 18, 19, 20, 21, 22, 23, 24, 25, 26, 
                27, 30}}}, {{a, {15, 16, 17, 18, 19, 20, 21, 22, 23, 24, 25, 
                26, 28, 29}}, {d, {15, 16, 17, 18, 19, 20, 21, 22, 23, 24, 
                25, 26, 31, 32, 33, 34}}}}}}\)], "Output",
  CellLabel->"Out[36]="]
}, Closed]],

Cell["\<\
The nested structure can be removed using Nested\[Rule]False:\
\>", \
"MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[
    \(sf = 
      CollapseGenealogy[g, Node \[Rule] False, 
          NodeFunction \[Rule] \(({#1, #2\[LeftDoubleBracket]2\
\[RightDoubleBracket]} &)\), Nested \[Rule] False] // Sort\)], "Input",
  CellLabel->"In[39]:="],

Cell[BoxData[
    \({{a, {15, 16, 17, 18, 19, 20, 21, 22, 23, 24, 25, 26, 28, 29}}, {b, {1, 
          2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14}}, {c, {15, 16, 17, 18, 
          19, 20, 21, 22, 23, 24, 25, 26, 27}}, {d, {15, 16, 17, 18, 19, 20, 
          21, 22, 23, 24, 25, 26, 31, 32, 33, 34}}, {e, {15, 16, 17, 18, 19, 
          20, 21, 22, 23, 24, 25, 26, 27, 30}}}\)], "Output",
  CellLabel->"Out[39]="]
}, Closed]],

Cell[TextData[{
  ButtonBox["FlattenList[]",
    ButtonData:>{"Flattening lists by pattern", "FlattenList"},
    ButtonStyle->"AddOnsLink",
    ButtonNote->"FlattenList[]"],
  " could  also be used:"
}], "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[
    \(FlattenList[s, {_, {___}}] // Sort\)], "Input",
  CellLabel->"In[38]:="],

Cell[BoxData[
    \({{a, {15, 16, 17, 18, 19, 20, 21, 22, 23, 24, 25, 26, 28, 29}}, {b, {1, 
          2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14}}, {c, {15, 16, 17, 18, 
          19, 20, 21, 22, 23, 24, 25, 26, 27}}, {d, {15, 16, 17, 18, 19, 20, 
          21, 22, 23, 24, 25, 26, 31, 32, 33, 34}}, {e, {15, 16, 17, 18, 19, 
          20, 21, 22, 23, 24, 25, 26, 27, 30}}}\)], "Output",
  CellLabel->"Out[38]="]
}, Closed]],

Cell[TextData[{
  "This picks out those parts of the nested list ",
  Cell[BoxData[
      \(TraditionalForm\`s\)]],
  " that match the pattern ",
  "{_,{___}}",
  "."
}], "Text"]
}, Open  ]]
},
FrontEndVersion->"4.0 for Macintosh",
ScreenRectangle->{{0, 1152}, {0, 748}},
WindowSize->{976, 674},
WindowMargins->{{Automatic, 52}, {Automatic, 3}},
StyleDefinitions -> "HelpBrowser.nb",
MacintoshSystemPageSetup->"\<\
00h0001804P000000b02<?oaonl3>@91H`85N0?N0@00005X0FP000003j0:l001
0@00I00100000@0200000BL?00400000000000000000010000000000000@0?ne
oj/@7@]500P1000000000000000001T1\>"
]


(***********************************************************************
Cached data follows.  If you edit this Notebook file directly, not using
Mathematica, you must remove the line containing CacheID at the top of 
the file.  The cache data will then be recreated when you save this file 
from within Mathematica.
***********************************************************************)

(*CellTagsOutline
CellTagsIndex->{
  "RandomGenealogy"->{
    Cell[1794, 53, 446, 9, 54, "DefinitionBox",
      CellTags->"RandomGenealogy"]},
  "CoalescenceTimes"->{
    Cell[21392, 536, 483, 14, 39, "DefinitionBox",
      CellTags->"CoalescenceTimes"]},
  "MutationRate"->{
    Cell[23122, 595, 376, 7, 37, "DefinitionBox",
      CellTags->"MutationRate"]}
  }
*)

(*CellTagsIndex
CellTagsIndex->{
  {"RandomGenealogy", 29199, 767},
  {"CoalescenceTimes", 29308, 770},
  {"MutationRate", 29417, 773}
  }
*)

(*NotebookFileOutline
Notebook[{

Cell[CellGroupData[{
Cell[1739, 51, 52, 0, 36, "SubsectionIcon"],
Cell[1794, 53, 446, 9, 54, "DefinitionBox",
  CellTags->"RandomGenealogy"],
Cell[2243, 64, 46, 0, 28, "MathCaption"],
Cell[2292, 66, 88, 2, 26, "Input"],
Cell[2383, 70, 82, 1, 28, "MathCaption"],

Cell[CellGroupData[{
Cell[2490, 75, 94, 2, 26, "Input"],
Cell[2587, 79, 428, 9, 35, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[3052, 93, 86, 2, 26, "Input"],
Cell[3141, 97, 15801, 367, 184, 4020, 216, "GraphicsData", "PostScript", \
"Graphics"]
}, Open  ]],
Cell[18957, 467, 196, 4, 22, "Text"],
Cell[19156, 473, 294, 5, 36, "Text"],
Cell[19453, 480, 191, 4, 28, "MathCaption"],

Cell[CellGroupData[{
Cell[19669, 488, 137, 3, 26, "Input"],
Cell[19809, 493, 422, 8, 70, "Output"]
}, Closed]],
Cell[20246, 504, 65, 0, 18, "MathCaption"],

Cell[CellGroupData[{
Cell[20336, 508, 192, 4, 26, "Input"],
Cell[20531, 514, 659, 13, 70, "Output"]
}, Closed]],
Cell[21205, 530, 184, 4, 18, "Text"],
Cell[21392, 536, 483, 14, 39, "DefinitionBox",
  CellTags->"CoalescenceTimes"],
Cell[21878, 552, 238, 5, 36, "Text"],

Cell[CellGroupData[{
Cell[22141, 561, 88, 2, 26, "Input"],
Cell[22232, 565, 153, 3, 20, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[22422, 573, 126, 3, 26, "Input"],
Cell[22551, 578, 429, 9, 35, "Output"]
}, Open  ]],
Cell[22995, 590, 124, 3, 22, "Text"],
Cell[23122, 595, 376, 7, 37, "DefinitionBox",
  CellTags->"MutationRate"],
Cell[23501, 604, 298, 5, 36, "Text"],

Cell[CellGroupData[{
Cell[23824, 613, 126, 3, 26, "Input"],
Cell[23953, 618, 1115, 19, 70, "Output"]
}, Closed]],
Cell[25083, 640, 180, 4, 18, "Text"],
Cell[25266, 646, 98, 3, 28, "MathCaption"],

Cell[CellGroupData[{
Cell[25389, 653, 195, 4, 26, "Input"],
Cell[25587, 659, 201, 4, 70, "Output"]
}, Closed]],
Cell[25803, 666, 112, 3, 18, "MathCaption"],

Cell[CellGroupData[{
Cell[25940, 673, 201, 5, 26, "Input"],
Cell[26144, 680, 458, 7, 70, "Output"]
}, Closed]],
Cell[26617, 690, 94, 3, 18, "MathCaption"],

Cell[CellGroupData[{
Cell[26736, 697, 234, 5, 26, "Input"],
Cell[26973, 704, 413, 6, 70, "Output"]
}, Closed]],
Cell[27401, 713, 218, 6, 19, "MathCaption"],

Cell[CellGroupData[{
Cell[27644, 723, 92, 2, 26, "Input"],
Cell[27739, 727, 413, 6, 70, "Output"]
}, Closed]],
Cell[28167, 736, 178, 7, 18, "Text"]
}, Open  ]]
}
]
*)




(***********************************************************************
End of Mathematica Notebook file.
***********************************************************************)

