(***********************************************************************

                    Mathematica-Compatible Notebook

This notebook can be used on any computer system with Mathematica 4.0,
MathReader 4.0, or any compatible application. The data for the notebook 
starts with the line containing stars above.

To get the notebook into a Mathematica-compatible application, do one of 
the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing the 
word CacheID, otherwise Mathematica-compatible applications may try to 
use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
***********************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[    169229,       3346]*)
(*NotebookOutlinePosition[    170385,       3384]*)
(*  CellTagsIndexPosition[    170273,       3377]*)
(*WindowFrame->Normal*)



Notebook[{

Cell[CellGroupData[{
Cell["The exact Griffiths-Tavare algorithm", "SubsectionIcon"],

Cell[TextData[Cell[BoxData[
    FormBox[GridBox[{
          {\(GriffithsTavare[S, \[Theta]]\), \(uses\ the\ Griffiths - 
              Tavare\ algorithm\ to\ find\ the\ probability\ of\ a\ \
configuration\ of\ mutations\ defined\ by\ the\ matrix\ S\)}
          }], TraditionalForm]]]], "DefinitionBox",
  CellTags->"GriffithsTavare"],

Cell["This loads the package:", "MathCaption"],

Cell[BoxData[
    \(\(<< Genealogies`Genealogies`;\)\)], "Input",
  CellLabel->"In[679]:="],

Cell["\<\
This calculates the probability of finding this configuration of \
mutations:\
\>", "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"Timing", "[", 
      RowBox[{"GriffithsTavare", "[", 
        RowBox[{
          TagBox[
            RowBox[{"(", GridBox[{
                  {"0", "0", "0", "0", "0", "0", "0", "0", "0"},
                  {"1", "1", "1", "0", "0", "1", "0", "0", "0"},
                  {"1", "1", "1", "0", "0", "0", "0", "0", "0"},
                  {"0", "0", "0", "1", "1", "0", "1", "0", "0"},
                  {"0", "0", "0", "1", "1", "0", "0", "1", "1"}
                  }], ")"}],
            (MatrixForm[ #]&)], ",", "\[Theta]"}], "]"}], "]"}]], "Input",
  CellLabel->"In[54]:="],

Cell[BoxData[
    \({0.716666666666696983`\ Second, 
      \((\[Theta]\^9\ 
            \((3141821952 + 13483366272\ \[Theta] + 
                25217739648\ \[Theta]\^2 + 26937488864\ \[Theta]\^3 + 
                18096993360\ \[Theta]\^4 + 7930297836\ \[Theta]\^5 + 
                2268383044\ \[Theta]\^6 + 408842683\ \[Theta]\^7 + 
                42184385\ \[Theta]\^8 + 1900974\ \[Theta]\^9)\))\)/
        \((259200000\ \((1 + \[Theta])\)\^4\ \((2 + \[Theta])\)\^6\ 
            \((3 + \[Theta])\)\^7\ \((4 + \[Theta])\)\^5)\)}\)], "Output",
  CellLabel->"Out[54]="]
}, Closed]],

Cell["\<\
The expression is the same as was derived from the moment \
generating function:\
\>", "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"Timing", "[", 
      RowBox[{"ExactProbability", "[", 
        RowBox[{
          TagBox[
            RowBox[{"(", GridBox[{
                  {"0", "0", "0", "0", "0", "0", "0", "0", "0"},
                  {"1", "1", "1", "0", "0", "1", "0", "0", "0"},
                  {"1", "1", "1", "0", "0", "0", "0", "0", "0"},
                  {"0", "0", "0", "1", "1", "0", "1", "0", "0"},
                  {"0", "0", "0", "1", "1", "0", "0", "1", "1"}
                  }], ")"}],
            (MatrixForm[ #]&)], ",", "\[Theta]"}], "]"}], "]"}]], "Input",
  CellLabel->"In[55]:="],

Cell[BoxData[
    \({1.96666666666669698`\ Second, 
      \((\[Theta]\^9\ 
            \((3141821952 + 13483366272\ \[Theta] + 
                25217739648\ \[Theta]\^2 + 26937488864\ \[Theta]\^3 + 
                18096993360\ \[Theta]\^4 + 7930297836\ \[Theta]\^5 + 
                2268383044\ \[Theta]\^6 + 408842683\ \[Theta]\^7 + 
                42184385\ \[Theta]\^8 + 1900974\ \[Theta]\^9)\))\)/
        \((259200000\ \((1 + \[Theta])\)\^4\ \((2 + \[Theta])\)\^6\ 
            \((3 + \[Theta])\)\^7\ \((4 + \[Theta])\)\^5)\)}\)], "Output",
  CellLabel->"Out[55]="]
}, Closed]],

Cell["\<\
In this example, the Griffiths-Tavare recursion is faster than \
differentiation of the generating function. If an entirely different \
configuration of mutations is given, the generating function does not have to \
be recalculated; thyere is a single m.g.f. for a given number of lineages.  \
However, ExactProbability[] is no faster, because most time is spent \
differentiating:\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"Timing", "[", 
      RowBox[{"ExactProbability", "[", 
        RowBox[{
          TagBox[
            RowBox[{"(", GridBox[{
                  {"0", "1", "1", "1", "0", "0", "0", "0", "0"},
                  {"1", "0", "1", "1", "0", "0", "0", "0", "0"},
                  {"0", "0", "1", "1", "0", "0", "0", "0", "0"},
                  {"0", "0", "0", "0", "1", "0", "1", "1", "0"},
                  {"0", "0", "0", "0", "1", "1", "0", "1", "1"}
                  }], ")"}],
            (MatrixForm[ #]&)], ",", "\[Theta]"}], "]"}], "]"}]], "Input",
  CellLabel->"In[56]:="],

Cell[BoxData[
    \({1.90000000000009094`\ Second, 
      \((\[Theta]\^9\ 
            \((20377564416 + 73047163392\ \[Theta] + 
                115190706528\ \[Theta]\^2 + 104939074448\ \[Theta]\^3 + 
                60906248640\ \[Theta]\^4 + 23372370204\ \[Theta]\^5 + 
                5934375094\ \[Theta]\^6 + 962034174\ \[Theta]\^7 + 
                90416121\ \[Theta]\^8 + 3755966\ \[Theta]\^9)\))\)/
        \((48600000\ \((1 + \[Theta])\)\^5\ \((2 + \[Theta])\)\^6\ 
            \((3 + \[Theta])\)\^5\ \((4 + \[Theta])\)\^6)\)}\)], "Output",
  CellLabel->"Out[56]="]
}, Closed]],

Cell["\<\
The Griffiths-Tavare method could in principle be faster for the \
new configuration, because many simpler configurations are stored. \
\>", \
"Text"],

Cell[" In this example, however, that is not the case:", "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"Timing", "[", 
      RowBox[{"GriffithsTavare", "[", 
        RowBox[{
          TagBox[
            RowBox[{"(", GridBox[{
                  {"0", "1", "1", "1", "0", "0", "0", "0", "0"},
                  {"1", "0", "1", "1", "0", "0", "0", "0", "0"},
                  {"0", "0", "1", "1", "0", "0", "0", "0", "0"},
                  {"0", "0", "0", "0", "1", "0", "1", "1", "0"},
                  {"0", "0", "0", "0", "1", "1", "0", "1", "1"}
                  }], ")"}],
            (MatrixForm[ #]&)], ",", "\[Theta]"}], "]"}], "]"}]], "Input",
  CellLabel->"In[57]:="],

Cell[BoxData[
    \({0.733333333333121117`\ Second, 
      \((\[Theta]\^9\ 
            \((20377564416 + 73047163392\ \[Theta] + 
                115190706528\ \[Theta]\^2 + 104939074448\ \[Theta]\^3 + 
                60906248640\ \[Theta]\^4 + 23372370204\ \[Theta]\^5 + 
                5934375094\ \[Theta]\^6 + 962034174\ \[Theta]\^7 + 
                90416121\ \[Theta]\^8 + 3755966\ \[Theta]\^9)\))\)/
        \((48600000\ \((1 + \[Theta])\)\^5\ \((2 + \[Theta])\)\^6\ 
            \((3 + \[Theta])\)\^5\ \((4 + \[Theta])\)\^6)\)}\)], "Output",
  CellLabel->"Out[57]="]
}, Closed]],

Cell["These two configurations must have the same probability:", "MathCaption"],

Cell[BoxData[
    FormBox[
      RowBox[{
        TagBox[
          RowBox[{"(", GridBox[{
                {" ", "1", "2", "3", "4", "5", "6", "7", "8", "9"},
                {"a", "0", "0", "0", "1", "1", "0", "1", "0", "0"},
                {"b", "0", "0", "0", "1", "1", "0", "0", "1", "1"},
                {"c", "1", "1", "1", "0", "0", "1", "0", "0", "0"},
                {"d", "1", "1", "1", "0", "0", "0", "0", "0", "0"},
                {"e", "0", "0", "0", "0", "0", "0", "0", "0", "0"}
                }], ")"}],
          (MatrixForm[ #]&)], "            ", 
        TagBox[
          RowBox[{"(", GridBox[{
                {" ", "6", "1", "2", "3", "7", "8", "9", "4", "5"},
                {"e", "0", "0", "0", "0", "0", "0", "0", "0", "0"},
                {"b", "0", "0", "0", "0", "0", "1", "1", "1", "1"},
                {"a", "0", "0", "0", "0", "1", "0", "0", "1", "1"},
                {"d", "0", "1", "1", "1", "0", "0", "0", "0", "0"},
                {"c", "1", "1", "1", "1", "0", "0", "0", "0", "0"}
                }], ")"}],
          (MatrixForm[ #]&)]}], TextForm]], "Text"],

Cell[TextData[{
  "Therefore, only the probabilities of each ",
  StyleBox["distinct",
    FontSlant->"Italic"],
  " configuration is stored: the archetypal configuration is sorted along \
both axes.  For the above examples, 109 results were stored:"
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(?? GriffithsTavare\)], "Input",
  CellLabel->"In[59]:="],

Cell[BoxData[
    \("GriffithsTavare[S,\[Theta]] uses the Griffiths-Tavare algorithm to \
find the probability of a configuration of mutations defined by the matrix \
S."\)], "Print"],

Cell[BoxData[
    StyleBox[
      \(GriffithsTavare[{{0}, \ {0}}, \ \[Theta]]\  = \ 
        \(\((1\  + \ \[Theta])\)^\((\(-1\))\)\n\ \n
            GriffithsTavare[{{0}, \ {1}}, \ \[Theta]]\  = \ 
          \(\[Theta]/\((2*\((1\  + \ \[Theta])\)^2)\)\n\ \n
              GriffithsTavare[{{0, \ 0}, \ {1, \ 1}}, \ \[Theta]]\  = \ 
            \(\[Theta]^2/\((4*\((1\  + \ \[Theta])\)^3)\)\n\ \n
                GriffithsTavare[{{0, \ 0, \ 0}, \ {1, \ 1, \ 1}}, \ \[Theta]]
                  \  = \ \(\[Theta]^3/\((8*\((1\  + \ \[Theta])\)^4)\)\n\ \n
                  GriffithsTavare[{{0, \ 0, \ 1}, \ {1, \ 1, \ 0}}, \ 
                    \[Theta]]\  = \ 
                \(\((3*\[Theta]^3)\)/\((8*\((1\  + \ \[Theta])\)^4)\)\n\ \n
                    GriffithsTavare[{{0, \ 1, \ 1}, \ {1, \ 0, \ 0}}, \ 
                      \[Theta]]\  = \ 
                  \(\((3*\[Theta]^3)\)/\((8*\((1\  + \ \[Theta])\)^4)\)\n\ \n
                      GriffithsTavare[{{0, \ 0, \ 1, \ 1}, 
                          \ {1, \ 1, \ 0, \ 0}}, \ \[Theta]]\  = \ 
                    \(\((3*\[Theta]^4)\)/\((8*\((1\  + \ \[Theta])\)^5)\)\n\ 
                        \nGriffithsTavare[{{0}, \ {0}, \ {0}}, \ \[Theta]]
                          \  = \ \(2/
                            \((\((1\  + \ \[Theta])\)*\((2\  + \ \[Theta])\))
                              \)\n\ \n
                          GriffithsTavare[{{0}, \ {0}, \ {1}}, \ \[Theta]]
                            \  = \ \(\((\[Theta]*\((4\  + \ 3*\[Theta])\))\)/
                              \((3*\((1\  + \ \[Theta])\)^2*
                                  \((2\  + \ \[Theta])\)^2)\)\n\ \n
                            GriffithsTavare[{{0, \ 0}, \ {0, \ 0}, 
                                \ {1, \ 1}}, \ \[Theta]]\  = \ 
                          \(\((\[Theta]^2*
                                    \((20\  + \ 26*\[Theta]\  + \ 
                                        9*\[Theta]^2)\))\)/
                                \((18*\((1\  + \ \[Theta])\)^3*
                                    \((2\  + \ \[Theta])\)^3)\)\n\ \n
                              GriffithsTavare[{{0, \ 0}, \ {0, \ 1}, 
                                  \ {1, \ 0}}, \ \[Theta]]\  = \ 
                            \(\((2*\[Theta]^2*\((4\  + \ 3*\[Theta])\))\)/
                                  \((9*\((1\  + \ \[Theta])\)^2*
                                      \((2\  + \ \[Theta])\)^3)\)\n\ \n
                                GriffithsTavare[{{0, \ 0}, \ {1, \ 1}, 
                                    \ {1, \ 1}}, \ \[Theta]]\  = \ 
                              \(\[Theta]^2/
                                    \((6*\((1\  + \ \[Theta])\)^3*
                                        \((2\  + \ \[Theta])\))\)\n\ \n
                                  GriffithsTavare[{{0, \ 0, \ 0}, 
                                      \ {0, \ 0, \ 0}, \ {1, \ 1, \ 1}}, \ 
                                    \[Theta]]\  = \ 
                                \(\((\[Theta]^3*
                                        \((112\  + \ 200*\[Theta]\  + \ 
                                        124*\[Theta]^2\  + \ 27*\[Theta]^3)\))
                                        \)/\((
                                        108*\((1\  + \ \[Theta])\)^4*
                                        \((2\  + \ \[Theta])\)^4)\)\n\ \n
                                    GriffithsTavare[{{0, \ 0, \ 0}, 
                                        \ {0, \ 0, \ 1}, \ {1, \ 1, \ 0}}, \ 
                                      \[Theta]]\  = \ 
                                  \(\((\[Theta]^3*
                                        \((12\  + \ 18*\[Theta]\  + \ 
                                        7*\[Theta]^2)\))\)/
                                        \((18*\((1\  + \ \[Theta])\)^3*
                                        \((2\  + \ \[Theta])\)^4)\)\n\ \n
                                      GriffithsTavare[{{0, \ 0, \ 0}, 
                                        \ {0, \ 1, \ 1}, \ {1, \ 0, \ 0}}, \ 
                                        \[Theta]]\  = \ 
                                    \(\((\[Theta]^3*
                                        \((12\  + \ 18*\[Theta]\  + \ 
                                        7*\[Theta]^2)\))\)/
                                        \((18*\((1\  + \ \[Theta])\)^3*
                                        \((2\  + \ \[Theta])\)^4)\)\n\ \n
                                        GriffithsTavare[{{0, \ 0, \ 0}, 
                                        \ {0, \ 1, \ 1}, \ {1, \ 1, \ 1}}, \ 
                                        \[Theta]]\  = \ 
                                      \(\[Theta]^3/
                                        \((18*\((1\  + \ \[Theta])\)^3*
                                        \((2\  + \ \[Theta])\)^2)\)\n\ \n
                                        GriffithsTavare[{{0, \ 0, \ 0}, 
                                        \ {1, \ 1, \ 1}, \ {1, \ 1, \ 1}}, \ 
                                        \[Theta]]\  = \ 
                                        \(\[Theta]^3/
                                        \((12*\((1\  + \ \[Theta])\)^4*
                                        \((2\  + \ \[Theta])\))\)\n\ \n
                                        GriffithsTavare[{{0, \ 0, \ 1}, 
                                        \ {1, \ 1, \ 0}, \ {1, \ 1, \ 0}}, \ 
                                        \[Theta]]\  = \ 
                                        \(\((\[Theta]^3*
                                        \((20\  + \ 11*\[Theta])\))\)/
                                        \((36*\((1\  + \ \[Theta])\)^4*
                                        \((2\  + \ \[Theta])\)^2)\)\n\ \n
                                        GriffithsTavare[{{0, \ 1, \ 1}, 
                                        \ {0, \ 1, \ 1}, \ {1, \ 0, \ 0}}, \ 
                                        \[Theta]]\  = \ 
                                        \(\((\[Theta]^3*
                                        \((20\  + \ 11*\[Theta])\))\)/
                                        \((36*\((1\  + \ \[Theta])\)^4*
                                        \((2\  + \ \[Theta])\)^2)\)\n\ \n
                                        GriffithsTavare[{{0, \ 0, \ 0, \ 0}, 
                                        \ {0, \ 0, \ 0, \ 1}, 
                                        \ {1, \ 1, \ 1, \ 0}}, \ \[Theta]]
                                        \  = \ \(\((\[Theta]^4*
                                        \((184\  + \ 380*\[Theta]\  + \ 
                                        274*\[Theta]^2\  + \ 69*\[Theta]^3)\))
                                        \)/\((324*\((1\  + \ \[Theta])\)^4*
                                        \((2\  + \ \[Theta])\)^5)\)\n\ \n
                                        GriffithsTavare[{{0, \ 0, \ 0, \ 0}, 
                                        \ {0, \ 0, \ 1, \ 1}, 
                                        \ {1, \ 1, \ 0, \ 0}}, \ \[Theta]]
                                        \  = \ \(\((\[Theta]^4*
                                        \((12\  + \ 18*\[Theta]\  + \ 
                                        7*\[Theta]^2)\))\)/
                                        \((27*\((1\  + \ \[Theta])\)^3*
                                        \((2\  + \ \[Theta])\)^5)\)\n\ \n
                                        GriffithsTavare[{{0, \ 0, \ 0, \ 0}, 
                                        \ {0, \ 0, \ 1, \ 1}, 
                                        \ {1, \ 1, \ 1, \ 1}}, \ \[Theta]]
                                        \  = \ \(\[Theta]^4/
                                        \((54*\((1\  + \ \[Theta])\)^3*
                                        \((2\  + \ \[Theta])\)^3)\)\n\ \n
                                        GriffithsTavare[{{0, \ 0, \ 0, \ 0}, 
                                        \ {0, \ 1, \ 1, \ 1}, 
                                        \ {1, \ 0, \ 1, \ 1}}, \ \[Theta]]
                                        \  = \ \(\[Theta]^4/
                                        \((27*\((1\  + \ \[Theta])\)^3*
                                        \((2\  + \ \[Theta])\)^3)\)\n\ \n
                                        GriffithsTavare[{{0, \ 0, \ 0, \ 0}, 
                                        \ {0, \ 1, \ 1, \ 1}, 
                                        \ {1, \ 1, \ 1, \ 1}}, \ \[Theta]]
                                        \  = \ \(\[Theta]^4/\((
                                        36*\((1\  + \ \[Theta])\)^4*
                                        \((2\  + \ \[Theta])\)^2)\)\n\ \n
                                        GriffithsTavare[{{0, \ 0, \ 0, \ 1}, 
                                        \ {0, \ 1, \ 1, \ 0}, \ {1, \ 1, \ 1, 
                                        \ 0}}, \ \[Theta]]\  = \ 
                                        \(\((\[Theta]^4*\((22\  + \ 
                                        13*\[Theta])\))\)/\((108*\((1\  + \ 
                                        \[Theta])\)^4*\((2\  + \ \[Theta])
                                        \)^3)\)\n\ \nGriffithsTavare[{{0, \ 
                                        0, \ 1, \ 1}, \ {0, \ 0, \ 1, \ 1}, 
                                        \ {1, \ 1, \ 0, \ 0}}, \ \[Theta]]
                                        \  = \ \(\((\[Theta]^4*\((128\  + \ 
                                        139*\[Theta]\  + \ 38*\[Theta]^2)\))
                                        \)/\((108*\((1\  + \ \[Theta])\)^5*
                                        \((2\  + \ \[Theta])\)^3)\)\n\ \n
                                        GriffithsTavare[{{0, \ 0, \ 1, \ 1}, 
                                        \ {0, \ 1, \ 1, \ 1}, \ {1, \ 0, \ 0, 
                                        \ 0}}, \ \[Theta]]\  = \ 
                                        \(\((\[Theta]^4*\((22\  + \ 
                                        13*\[Theta])\))\)/\((108*\((1\  + \ 
                                        \[Theta])\)^4*\((2\  + \ 
                                        \[Theta])\)^3)\)\n\ \n
                                        GriffithsTavare[{{0, \ 0, \ 1, \ 1}, 
                                        \ {1, \ 1, \ 0, \ 0}, \ {1, \ 1, \ 0, 
                                        \ 0}}, \ \[Theta]]\  = \ 
                                        \(\((\[Theta]^4*\((128\  + \ 
                                        139*\[Theta]\  + \ 38*\[Theta]^2)\))
                                        \)/\((108*\((1\  + \ \[Theta])\)^5*
                                        \((2\  + \ \[Theta])\)^3)\)\n\ \n
                                        GriffithsTavare[{{0, \ 0, \ 0, \ 0, \ 
                                        0}, \ {0, \ 0, \ 0, \ 1, \ 1}, 
                                        \ {1, \ 1, \ 1, \ 0, \ 0}}, \ 
                                        \[Theta]]\  = \ 
                                        \(\((\[Theta]^5*\((328\  + \ 
                                        740*\[Theta]\  + \ 574*\[Theta]^2\  + 
                                        \ 153*\[Theta]^3)\))\)/\((972*\((1\ 
                                         + \ \[Theta])\)^4*\((2\  + \ 
                                        \[Theta])\)^6)\)\n\ \n
                                        GriffithsTavare[{{0, \ 0, \ 0, \ 0, \ 
                                        0}, \ {0, \ 0, \ 1, \ 1, \ 1}, \ {1, 
                                        \ 1, \ 0, \ 1, \ 1}}, \ \[Theta]]\  = 
                                        \ \(\[Theta]^5/\((54*\((1\  + \ 
                                        \[Theta])\)^3*\((2\  + \ 
                                        \[Theta])\)^4)\)\n\ \n
                                        GriffithsTavare[{{0, \ 0, \ 0, \ 0, \ 
                                        0}, \ {0, \ 1, \ 1, \ 1, \ 1}, \ {1, 
                                        \ 0, \ 0, \ 1, \ 1}}, \ \[Theta]]\  = 
                                        \ \(\[Theta]^5/\((54*\((1\  + \ 
                                        \[Theta])\)^3*\((2\  + \ 
                                        \[Theta])\)^4)\)\n\ \n
                                        GriffithsTavare[{{0, \ 0, \ 0, \ 1, \ 
                                        1}, \ {0, \ 0, \ 1, \ 1, \ 1}, \ {1, 
                                        \ 1, \ 0, \ 0, \ 0}}, \ \[Theta]]\  = 
                                        \ \(\((\[Theta]^5*\((50\  + \ 
                                        58*\[Theta]\  + \ 17*\[Theta]^2)\))\)/
                                        \((108*\((1\  + \ \[Theta])\)^5*\((2\ 
                                         + \ \[Theta])\)^4)\)\n\ \n
                                        GriffithsTavare[{{0, \ 0, \ 0, \ 1, \ 
                                        1}, \ {0, \ 1, \ 1, \ 0, \ 0}, \ {1, 
                                        \ 1, \ 1, \ 0, \ 0}}, \ \[Theta]]\  = 
                                        \ \(\((\[Theta]^5*\((50\  + \ 
                                        58*\[Theta]\  + \ 
                                        17*\[Theta]^2)\))\)/\((108*\((1\  + \ 
                                        \[Theta])\)^5*\((2\  + \ 
                                        \[Theta])\)^4)\)\n\ \n
                                        GriffithsTavare[{{0, \ 0, \ 0, \ 1, \ 
                                        1}, \ {0, \ 1, \ 1, \ 1, \ 1}, \ {1, 
                                        \ 0, \ 0, \ 0, \ 0}}, \ \[Theta]]\  = 
                                        \ \(\((\[Theta]^5*\((8\  + \ 
                                        5*\[Theta])\))\)/\((108*\((1\  + \ 
                                        \[Theta])\)^4*\((2\  + \ 
                                        \[Theta])\)^4)\)\n\ \n
                                        GriffithsTavare[{{0, \ 0, \ 1, \ 1, \ 
                                        1}, \ {0, \ 1, \ 0, \ 1, \ 1}, \ {1, 
                                        \ 0, \ 0, \ 0, \ 0}}, \ \[Theta]]\  = 
                                        \ \(\((\[Theta]^5*\((8\  + \ 
                                        5*\[Theta])\))\)/\((54*\((1\  + \ 
                                        \[Theta])\)^4*\((2\  + \ 
                                        \[Theta])\)^4)\)\n\ \n
                                        GriffithsTavare[{{0, \ 0, \ 0, \ 0, \ 
                                        1, \ 1}, \ {0, \ 0, \ 1, \ 1, \ 1, \ 
                                        1}, \ {1, \ 1, \ 0, \ 0, \ 0, \ 0}}, 
                                        \ \[Theta]]\  = \ 
                                        \(\((\[Theta]^6*\((58\  + \ 
                                        71*\[Theta]\  + \ 
                                        22*\[Theta]^2)\))\)/\((324*\((1\  + \ 
                                        \[Theta])\)^5*\((2\  + \ 
                                        \[Theta])\)^5)\)\n\ \n
                                        GriffithsTavare[{{0, \ 0, \ 0, \ 1, \ 
                                        1, \ 1}, \ {0, \ 0, \ 1, \ 0, \ 1, \ 
                                        1}, \ {1, \ 1, \ 0, \ 0, \ 0, \ 0}}, 
                                        \ \[Theta]]\  = \ 
                                        \(\((\[Theta]^6*\((58\  + \ 
                                        71*\[Theta]\  + \ 
                                        22*\[Theta]^2)\))\)/\((162*\((1\  + \ 
                                        \[Theta])\)^5*\((2\  + \ 
                                        \[Theta])\)^5)\)\n\ \n
                                        GriffithsTavare[{{0, \ 0, \ 0, \ 1, \ 
                                        1, \ 1}, \ {0, \ 1, \ 1, \ 0, \ 1, \ 
                                        1}, \ {1, \ 0, \ 0, \ 0, \ 0, \ 0}}, 
                                        \ \[Theta]]\  = \ 
                                        \(\((\[Theta]^6*\((26\  + \ 
                                        17*\[Theta])\))\)/\((324*\((1\  + \ 
                                        \[Theta])\)^4*\((2\  + \ 
                                        \[Theta])\)^5)\)\n\ \n
                                        GriffithsTavare[{{0, \ 0, \ 0, \ 0, \ 
                                        1, \ 1, \ 1}, \ {0, \ 0, \ 1, \ 1, \ 
                                        0, \ 1, \ 1}, \ {1, \ 1, \ 0, \ 0, \ 
                                        0, \ 0, \ 0}}, \ \[Theta]]\  = \ 
                                        \(\((\[Theta]^7*\((200\  + \ 
                                        256*\[Theta]\  + \ 
                                        83*\[Theta]^2)\))\)/\((972*\((1\  + \ 
                                        \[Theta])\)^5*\((2\  + \ 
                                        \[Theta])\)^6)\)\n\ \n
                                        GriffithsTavare[{{0, \ 0}, \ {0, \ 
                                        0}, \ {1, \ 1}, \ {1, \ 1}}, \ 
                                        \[Theta]]\  = \ 
                                        \(\((\[Theta]^2*\((16\  + \ 
                                        19*\[Theta]\  + \ 
                                        6*\[Theta]^2)\))\)/\((18*\((1\  + \ 
                                        \[Theta])\)^3*\((2\  + \ 
                                        \[Theta])\)^3*\((3\  + \ 
                                        \[Theta])\))\)\n\ \n
                                        GriffithsTavare[{{0, \ 0}, \ {1, \ 
                                        1}, \ {1, \ 1}, \ {1, \ 1}}, \ 
                                        \[Theta]]\  = \ 
                                        \(\[Theta]^2/\((4*\((1\  + \ 
                                        \[Theta])\)^3*\((2\  + \ 
                                        \[Theta])\)*\((3\  + \ 
                                        \[Theta])\))\)\n\ \n
                                        GriffithsTavare[{{0, \ 0, \ 0}, \ {0, 
                                        \ 0, \ 0}, \ {0, \ 1, \ 1}, \ {1, \ 
                                        1, \ 1}}, \ \[Theta]]\  = \ 
                                        \(\((\[Theta]^3*\((28\  + \ 
                                        29*\[Theta]\  + \ 
                                        8*\[Theta]^2)\))\)/\((72*\((1\  + \ 
                                        \[Theta])\)^3*\((2\  + \ 
                                        \[Theta])\)^3*\((3\  + \ 
                                        \[Theta])\)^2)\)\n\ \n
                                        GriffithsTavare[{{0, \ 0, \ 0}, \ {0, 
                                        \ 0, \ 0}, \ {1, \ 1, \ 1}, \ {1, \ 
                                        1, \ 1}}, \ \[Theta]]\  = \ 
                                        \(\((\[Theta]^3*\((92\  + \ 
                                        154*\[Theta]\  + \ 89*\[Theta]^2\  + 
                                        \ 18*\[Theta]^3)\))\)/\((108*\((1\  + 
                                        \ \[Theta])\)^4*\((2\  + \ 
                                        \[Theta])\)^4*\((3\  + \ 
                                        \[Theta])\))\)\n\ \n
                                        GriffithsTavare[{{0, \ 0, \ 0}, \ {0, 
                                        \ 1, \ 1}, \ {0, \ 1, \ 1}, \ {1, \ 
                                        0, \ 0}}, \ \[Theta]]\  = \ 
                                        \(\((\[Theta]^3*\((104\  + \ 
                                        186*\[Theta]\  + \ 109*\[Theta]^2\  + 
                                        \ 20*\[Theta]^3)\))\)/\((72*\((1\  + 
                                        \ \[Theta])\)^3*\((2\  + \ 
                                        \[Theta])\)^4*\((3\  + \ 
                                        \[Theta])\)^2)\)\n\ \n
                                        GriffithsTavare[{{0, \ 0, \ 0}, \ {0, 
                                        \ 1, \ 1}, \ {0, \ 1, \ 1}, \ {1, \ 
                                        1, \ 1}}, \ \[Theta]]\  = \ 
                                        \(\((\[Theta]^3*\((30\  + \ 
                                        13*\[Theta])\))\)/\((144*\((1\  + \ 
                                        \[Theta])\)^3*\((2\  + \ 
                                        \[Theta])\)^2*\((3\  + \ 
                                        \[Theta])\)^2)\)\n\ \n
                                        GriffithsTavare[{{0, \ 0, \ 1}, \ {1, 
                                        \ 1, \ 0}, \ {1, \ 1, \ 0}, \ {1, \ 
                                        1, \ 0}}, \ \[Theta]]\  = \ 
                                        \(\((\[Theta]^3*\((9\  + \ 
                                        5*\[Theta])\)*\((14\  + \ 
                                        5*\[Theta])\))\)/\((48*\((1\  + \ 
                                        \[Theta])\)^4*\((2\  + \ 
                                        \[Theta])\)^2*\((3\  + \ 
                                        \[Theta])\)^2)\)\n\ \n
                                        GriffithsTavare[{{0, \ 0, \ 0, \ 0}, 
                                        \ {0, \ 0, \ 0, \ 0}, \ {0, \ 0, \ 1, 
                                        \ 1}, \ {1, \ 1, \ 1, \ 1}}, \ 
                                        \[Theta]]\  = \ 
                                        \(\((\[Theta]^4*\((156\  + \ 
                                        135*\[Theta]\  + \ 
                                        32*\[Theta]^2)\))\)/\((864*\((1\  + \ 
                                        \[Theta])\)^3*\((2\  + \ 
                                        \[Theta])\)^3*\((3\  + \ 
                                        \[Theta])\)^3)\)\n\ \n
                                        GriffithsTavare[{{0, \ 0, \ 0, \ 0}, 
                                        \ {0, \ 0, \ 0, \ 0}, \ {0, \ 1, \ 1, 
                                        \ 1}, \ {1, \ 0, \ 1, \ 1}}, \ 
                                        \[Theta]]\  = \ 
                                        \(\((\[Theta]^4*\((156\  + \ 
                                        135*\[Theta]\  + \ 
                                        32*\[Theta]^2)\))\)/\((432*\((1\  + \ 
                                        \[Theta])\)^3*\((2\  + \ 
                                        \[Theta])\)^3*\((3\  + \ 
                                        \[Theta])\)^3)\)\n\ \n
                                        GriffithsTavare[{{0, \ 0, \ 0, \ 0}, 
                                        \ {0, \ 0, \ 0, \ 0}, \ {0, \ 1, \ 1, 
                                        \ 1}, \ {1, \ 1, \ 1, \ 1}}, \ 
                                        \[Theta]]\  = \ 
                                        \(\((\[Theta]^4*\((164\  + \ 
                                        250*\[Theta]\  + \ 131*\[Theta]^2\  + 
                                        \ 24*\[Theta]^3)\))\)/\((432*\((1\  + 
                                        \ \[Theta])\)^4*\((2\  + \ 
                                        \[Theta])\)^4*\((3\  + \ 
                                        \[Theta])\)^2)\)\n\ \n
                                        GriffithsTavare[{{0, \ 0, \ 0, \ 0}, 
                                        \ {0, \ 0, \ 0, \ 1}, \ {1, \ 1, \ 1, 
                                        \ 0}, \ {1, \ 1, \ 1, \ 0}}, \ 
                                        \[Theta]]\  = \ 
                                        \(\((\[Theta]^4*\((1656\  + \ 
                                        3848*\[Theta]\  + \ 3400*\[Theta]^2\ 
                                         + \ 1337*\[Theta]^3\  + \ 
                                        192*\[Theta]^4)\))\)/\((1296*\((1\  + 
                                        \ \[Theta])\)^4*\((2\  + \ 
                                        \[Theta])\)^5*\((3\  + \ 
                                        \[Theta])\)^2)\)\n\ \n
                                        GriffithsTavare[{{0, \ 0, \ 0, \ 0}, 
                                        \ {0, \ 0, \ 1, \ 1}, \ {0, \ 0, \ 1, 
                                        \ 1}, \ {1, \ 1, \ 0, \ 0}}, \ 
                                        \[Theta]]\  = \ 
                                        \(\((\[Theta]^4*\((2352\  + \ 
                                        5172*\[Theta]\  + \ 4140*\[Theta]^2\ 
                                         + \ 1407*\[Theta]^3\  + \ 
                                        172*\[Theta]^4)\))\)/\((864*\((1\  + 
                                        \ \[Theta])\)^3*\((2\  + \ 
                                        \[Theta])\)^5*\((3\  + \ 
                                        \[Theta])\)^3)\)\n\ \n
                                        GriffithsTavare[{{0, \ 0, \ 0, \ 0}, 
                                        \ {0, \ 0, \ 1, \ 1}, \ {0, \ 1, \ 1, 
                                        \ 1}, \ {1, \ 0, \ 0, \ 0}}, \ 
                                        \[Theta]]\  = \ 
                                        \(\((\[Theta]^4*\((80\  + \ 
                                        136*\[Theta]\  + \ 77*\[Theta]^2\  + 
                                        \ 14*\[Theta]^3)\))\)/\((144*\((1\  + 
                                        \ \[Theta])\)^3*\((2\  + \ 
                                        \[Theta])\)^4*\((3\  + \ 
                                        \[Theta])\)^3)\)\n\ \n
                                        GriffithsTavare[{{0, \ 0, \ 0, \ 0}, 
                                        \ {0, \ 0, \ 1, \ 1}, \ {0, \ 1, \ 1, 
                                        \ 1}, \ {1, \ 0, \ 1, \ 1}}, \ 
                                        \[Theta]]\  = \ 
                                        \(\((\[Theta]^4*\((30\  + \ 
                                        13*\[Theta])\))\)/\((288*\((1\  + \ 
                                        \[Theta])\)^3*\((2\  + \ 
                                        \[Theta])\)^2*\((3\  + \ 
                                        \[Theta])\)^3)\)\n\ \n
                                        GriffithsTavare[{{0, \ 0, \ 0, \ 1}, 
                                        \ {0, \ 1, \ 1, \ 0}, \ {0, \ 1, \ 1, 
                                        \ 0}, \ {1, \ 1, \ 1, \ 0}}, \ 
                                        \[Theta]]\  = \ 
                                        \(\((\[Theta]^4*\((1008\  + \ 
                                        1386*\[Theta]\  + \ 623*\[Theta]^2\ 
                                         + \ 92*\[Theta]^3)\))\)/\((432*\((1\ 
                                         + \ \[Theta])\)^4*\((2\  + \ 
                                        \[Theta])\)^3*\((3\  + \ 
                                        \[Theta])\)^3)\)\n\ \n
                                        GriffithsTavare[{{0, \ 0, \ 1, \ 1}, 
                                        \ {0, \ 0, \ 1, \ 1}, \ {1, \ 1, \ 0, 
                                        \ 0}, \ {1, \ 1, \ 0, \ 0}}, \ 
                                        \[Theta]]\  = \ 
                                        \(\((\[Theta]^4*\((128\  + \ 
                                        139*\[Theta]\  + \ 
                                        38*\[Theta]^2)\))\)/\((108*\((1\  + \ 
                                        \[Theta])\)^5*\((2\  + \ 
                                        \[Theta])\)^3*\((3\  + \ 
                                        \[Theta])\))\)\n\ \n
                                        GriffithsTavare[{{0, \ 0, \ 1, \ 1}, 
                                        \ {1, \ 1, \ 0, \ 0}, \ {1, \ 1, \ 0, 
                                        \ 0}, \ {1, \ 1, \ 0, \ 0}}, \ 
                                        \[Theta]]\  = \ 
                                        \(\((\[Theta]^4*\((9972\  + \ 
                                        17976*\[Theta]\  + \ 
                                        11995*\[Theta]^2\  + \ 
                                        3506*\[Theta]^3\  + \ 
                                        379*\[Theta]^4)\))\)/\((576*\((1\  + 
                                        \ \[Theta])\)^5*\((2\  + \ 
                                        \[Theta])\)^3*\((3\  + \ 
                                        \[Theta])\)^3)\)\n\ \n
                                        GriffithsTavare[{{0, \ 0, \ 0, \ 0, \ 
                                        0}, \ {0, \ 0, \ 0, \ 0, \ 0}, \ {0, 
                                        \ 1, \ 1, \ 1, \ 1}, \ {1, \ 0, \ 0, 
                                        \ 1, \ 1}}, \ \[Theta]]\  = \ 
                                        \(\((\[Theta]^5*\((1800\  + \ 
                                        2142*\[Theta]\  + \ 885*\[Theta]^2\ 
                                         + \ 
                                        128*\[Theta]^3)\))\)/\((3456*\((1\  + 
                                        \ \[Theta])\)^3*\((2\  + \ 
                                        \[Theta])\)^4*\((3\  + \ 
                                        \[Theta])\)^4)\)\n\ \n
                                        GriffithsTavare[{{0, \ 0, \ 0, \ 0, \ 
                                        0}, \ {0, \ 0, \ 0, \ 0, \ 1}, \ {0, 
                                        \ 1, \ 1, \ 1, \ 0}, \ {1, \ 1, \ 1, 
                                        \ 1, \ 0}}, \ \[Theta]]\  = \ 
                                        \(\((\[Theta]^5*\((44\  + \ 
                                        46*\[Theta]\  + \ 
                                        11*\[Theta]^2)\)*\((30\  + \ 
                                        35*\[Theta]\  + \ 
                                        12*\[Theta]^2)\))\)/\((2592*\((1\  + 
                                        \ \[Theta])\)^4*\((2\  + \ 
                                        \[Theta])\)^5*\((3\  + \ 
                                        \[Theta])\)^3)\)\n\ \n
                                        GriffithsTavare[{{0, \ 0, \ 0, \ 0, \ 
                                        0}, \ {0, \ 0, \ 0, \ 1, \ 1}, \ {0, 
                                        \ 0, \ 0, \ 1, \ 1}, \ {1, \ 1, \ 1, 
                                        \ 0, \ 0}}, \ \[Theta]]\  = \ 
                                        \(\((\[Theta]^5*\((184032\  + \ 
                                        617976*\[Theta]\  + \ 
                                        850212*\[Theta]^2\  + \ 
                                        609526*\[Theta]^3\  + \ 
                                        238937*\[Theta]^4\  + \ 
                                        48523*\[Theta]^5\  + \ 
                                        3996*\[Theta]^6)\))\)/\((31104*\((1\ 
                                         + \ \[Theta])\)^4*\((2\  + \ 
                                        \[Theta])\)^6*\((3\  + \ 
                                        \[Theta])\)^4)\)\n\ \n
                                        GriffithsTavare[{{0, \ 0, \ 0, \ 0, \ 
                                        0}, \ {0, \ 0, \ 0, \ 1, \ 1}, \ {0, 
                                        \ 0, \ 1, \ 1, \ 1}, \ {1, \ 1, \ 0, 
                                        \ 0, \ 0}}, \ \[Theta]]\  = \ 
                                        \(\((\[Theta]^5*\((3312\  + \ 
                                        7284*\[Theta]\  + \ 5880*\[Theta]^2\ 
                                         + \ 2037*\[Theta]^3\  + \ 
                                        256*\[Theta]^4)\))\)/\((3456*\((1\  + 
                                        \ \[Theta])\)^3*\((2\  + \ 
                                        \[Theta])\)^5*\((3\  + \ 
                                        \[Theta])\)^4)\)\n\ \n
                                        GriffithsTavare[{{0, \ 0, \ 0, \ 0, \ 
                                        0}, \ {0, \ 0, \ 0, \ 1, \ 1}, \ {0, 
                                        \ 1, \ 1, \ 1, \ 1}, \ {1, \ 0, \ 0, 
                                        \ 0, \ 0}}, \ \[Theta]]\  = \ 
                                        \(\((\[Theta]^5*\((792\  + \ 
                                        1242*\[Theta]\  + \ 661*\[Theta]^2\ 
                                         + \ 
                                        116*\[Theta]^3)\))\)/\((3456*\((1\  + 
                                        \ \[Theta])\)^3*\((2\  + \ 
                                        \[Theta])\)^4*\((3\  + \ 
                                        \[Theta])\)^4)\)\n\ \n
                                        GriffithsTavare[{{0, \ 0, \ 0, \ 0, \ 
                                        0}, \ {0, \ 0, \ 0, \ 1, \ 1}, \ {1, 
                                        \ 1, \ 1, \ 0, \ 0}, \ {1, \ 1, \ 1, 
                                        \ 0, \ 0}}, \ \[Theta]]\  = \ 
                                        \(\((\[Theta]^5*\((33552\  + \ 
                                        97080*\[Theta]\  + \ 
                                        111416*\[Theta]^2\  + \ 
                                        62710*\[Theta]^3\  + \ 
                                        17099*\[Theta]^4\  + \ 
                                        1800*\[Theta]^5)\))\)/\((15552*\((1\ 
                                         + \ \[Theta])\)^4*\((2\  + \ 
                                        \[Theta])\)^6*\((3\  + \ 
                                        \[Theta])\)^3)\)\n\ \n
                                        GriffithsTavare[{{0, \ 0, \ 0, \ 0, \ 
                                        0}, \ {0, \ 0, \ 1, \ 1, \ 1}, \ {0, 
                                        \ 1, \ 0, \ 1, \ 1}, \ {1, \ 0, \ 0, 
                                        \ 0, \ 0}}, \ \[Theta]]\  = \ 
                                        \(\((\[Theta]^5*\((792\  + \ 
                                        1242*\[Theta]\  + \ 661*\[Theta]^2\ 
                                         + \ 
                                        116*\[Theta]^3)\))\)/\((1728*\((1\  + 
                                        \ \[Theta])\)^3*\((2\  + \ 
                                        \[Theta])\)^4*\((3\  + \ 
                                        \[Theta])\)^4)\)\n\ \n
                                        GriffithsTavare[{{0, \ 0, \ 0, \ 0, \ 
                                        1}, \ {0, \ 0, \ 1, \ 1, \ 0}, \ {0, 
                                        \ 1, \ 1, \ 1, \ 0}, \ {1, \ 0, \ 1, 
                                        \ 1, \ 0}}, \ \[Theta]]\  = \ 
                                        \(\((\[Theta]^5*\((4212\  + \ 
                                        5892*\[Theta]\  + \ 2699*\[Theta]^2\ 
                                         + \ 
                                        407*\[Theta]^3)\))\)/\((3456*\((1\  + 
                                        \ \[Theta])\)^4*\((2\  + \ 
                                        \[Theta])\)^3*\((3\  + \ 
                                        \[Theta])\)^4)\)\n\ \n
                                        GriffithsTavare[{{0, \ 0, \ 0, \ 1, \ 
                                        1}, \ {0, \ 0, \ 0, \ 1, \ 1}, \ {0, 
                                        \ 1, \ 1, \ 0, \ 0}, \ {1, \ 1, \ 1, 
                                        \ 0, \ 0}}, \ \[Theta]]\  = \ 
                                        \(\((\[Theta]^5*\((556\  + \ 
                                        854*\[Theta]\  + \ 433*\[Theta]^2\  + 
                                        \ 72*\[Theta]^3)\))\)/\((432*\((1\  + 
                                        \ \[Theta])\)^5*\((2\  + \ 
                                        \[Theta])\)^4*\((3\  + \ 
                                        \[Theta])\)^2)\)\n\ \n
                                        GriffithsTavare[{{0, \ 0, \ 0, \ 1, \ 
                                        1}, \ {0, \ 0, \ 1, \ 1, \ 1}, \ {1, 
                                        \ 1, \ 0, \ 0, \ 0}, \ {1, \ 1, \ 0, 
                                        \ 0, \ 0}}, \ \[Theta]]\  = \ 
                                        \(\((\[Theta]^5*\((556\  + \ 
                                        854*\[Theta]\  + \ 433*\[Theta]^2\  + 
                                        \ 72*\[Theta]^3)\))\)/\((432*\((1\  + 
                                        \ \[Theta])\)^5*\((2\  + \ 
                                        \[Theta])\)^4*\((3\  + \ 
                                        \[Theta])\)^2)\)\n\ \n
                                        GriffithsTavare[{{0, \ 0, \ 0, \ 1, \ 
                                        1}, \ {0, \ 1, \ 1, \ 0, \ 0}, \ {0, 
                                        \ 1, \ 1, \ 0, \ 0}, \ {1, \ 1, \ 1, 
                                        \ 0, \ 0}}, \ \[Theta]]\  = \ 
                                        \(\((\[Theta]^5*\((111096\  + \ 
                                        254268*\[Theta]\  + \ 
                                        230746*\[Theta]^2\  + \ 
                                        103769*\[Theta]^3\  + \ 
                                        23140*\[Theta]^4\  + \ 
                                        2049*\[Theta]^5)\))\)/\((6912*\((1\ 
                                         + \ \[Theta])\)^5*\((2\  + \ 
                                        \[Theta])\)^4*\((3\  + \ 
                                        \[Theta])\)^4)\)\n\ \n
                                        GriffithsTavare[{{0, \ 0, \ 0, \ 0, \ 
                                        0, \ 0}, \ {0, \ 0, \ 0, \ 0, \ 1, \ 
                                        1}, \ {0, \ 0, \ 0, \ 1, \ 1, \ 1}, 
                                        \ {1, \ 1, \ 1, \ 0, \ 0, \ 0}}, \ 
                                        \[Theta]]\  = \ 
                                        \(\((\[Theta]^6*\((60912\  + \ 
                                        209628*\[Theta]\  + \ 
                                        295632*\[Theta]^2\  + \ 
                                        217627*\[Theta]^3\  + \ 
                                        87866*\[Theta]^4\  + \ 
                                        18442*\[Theta]^5\  + \ 
                                        1575*\[Theta]^6)\))\)/\((31104*\((1\ 
                                         + \ \[Theta])\)^4*\((2\  + \ 
                                        \[Theta])\)^6*\((3\  + \ 
                                        \[Theta])\)^5)\)\n\ \n
                                        GriffithsTavare[{{0, \ 0, \ 0, \ 0, \ 
                                        0, \ 0}, \ {0, \ 0, \ 0, \ 0, \ 1, \ 
                                        1}, \ {0, \ 0, \ 1, \ 1, \ 1, \ 1}, 
                                        \ {1, \ 1, \ 0, \ 0, \ 0, \ 0}}, \ 
                                        \[Theta]]\  = \ 
                                        \(\((\[Theta]^6*\((2448\  + \ 
                                        5280*\[Theta]\  + \ 4222*\[Theta]^2\ 
                                         + \ 1465*\[Theta]^3\  + \ 
                                        186*\[Theta]^4)\))\)/\((6912*\((1\  + 
                                        \ \[Theta])\)^3*\((2\  + \ 
                                        \[Theta])\)^5*\((3\  + \ 
                                        \[Theta])\)^5)\)\n\ \n
                                        GriffithsTavare[{{0, \ 0, \ 0, \ 0, \ 
                                        0, \ 0}, \ {0, \ 0, \ 0, \ 0, \ 1, \ 
                                        1}, \ {0, \ 1, \ 1, \ 1, \ 0, \ 0}, 
                                        \ {1, \ 1, \ 1, \ 1, \ 0, \ 0}}, \ 
                                        \[Theta]]\  = \ 
                                        \(\((\[Theta]^6*\((49392\  + \ 
                                        140040*\[Theta]\  + \ 
                                        158552*\[Theta]^2\  + \ 
                                        88762*\[Theta]^3\  + \ 
                                        24305*\[Theta]^4\  + \ 
                                        2592*\[Theta]^5)\))\)/\((62208*\((1\ 
                                         + \ \[Theta])\)^4*\((2\  + \ 
                                        \[Theta])\)^6*\((3\  + \ 
                                        \[Theta])\)^4)\)\n\ \n
                                        GriffithsTavare[{{0, \ 0, \ 0, \ 0, \ 
                                        0, \ 0}, \ {0, \ 0, \ 0, \ 1, \ 1, \ 
                                        1}, \ {0, \ 0, \ 1, \ 0, \ 1, \ 1}, 
                                        \ {1, \ 1, \ 0, \ 0, \ 0, \ 0}}, \ 
                                        \[Theta]]\  = \ 
                                        \(\((\[Theta]^6*\((2448\  + \ 
                                        5280*\[Theta]\  + \ 4222*\[Theta]^2\ 
                                         + \ 1465*\[Theta]^3\  + \ 
                                        186*\[Theta]^4)\))\)/\((3456*\((1\  + 
                                        \ \[Theta])\)^3*\((2\  + \ 
                                        \[Theta])\)^5*\((3\  + \ 
                                        \[Theta])\)^5)\)\n\ \n
                                        GriffithsTavare[{{0, \ 0, \ 0, \ 0, \ 
                                        0, \ 0}, \ {0, \ 0, \ 1, \ 1, \ 1, \ 
                                        1}, \ {0, \ 1, \ 0, \ 0, \ 1, \ 1}, 
                                        \ {1, \ 0, \ 0, \ 0, \ 0, \ 0}}, \ 
                                        \[Theta]]\  = \ 
                                        \(\((\[Theta]^6*\((1044\  + \ 
                                        1467*\[Theta]\  + \ 717*\[Theta]^2\ 
                                         + \ 
                                        119*\[Theta]^3)\))\)/\((3456*\((1\  + 
                                        \ \[Theta])\)^3*\((2\  + \ 
                                        \[Theta])\)^4*\((3\  + \ 
                                        \[Theta])\)^5)\)\n\ \n
                                        GriffithsTavare[{{0, \ 0, \ 0, \ 0, \ 
                                        1, \ 1}, \ {0, \ 0, \ 0, \ 1, \ 1, \ 
                                        1}, \ {0, \ 1, \ 1, \ 0, \ 0, \ 0}, 
                                        \ {1, \ 1, \ 1, \ 0, \ 0, \ 0}}, \ 
                                        \[Theta]]\  = \ 
                                        \(\((\[Theta]^6*\((556\  + \ 
                                        854*\[Theta]\  + \ 433*\[Theta]^2\  + 
                                        \ 72*\[Theta]^3)\))\)/\((864*\((1\  + 
                                        \ \[Theta])\)^5*\((2\  + \ 
                                        \[Theta])\)^4*\((3\  + \ 
                                        \[Theta])\)^3)\)\n\ \n
                                        GriffithsTavare[{{0, \ 0, \ 0, \ 0, \ 
                                        1, \ 1}, \ {0, \ 0, \ 1, \ 1, \ 0, \ 
                                        0}, \ {0, \ 1, \ 1, \ 1, \ 0, \ 0}, 
                                        \ {1, \ 0, \ 1, \ 1, \ 0, \ 0}}, \ 
                                        \[Theta]]\  = \ \(\((\[Theta]^6*\((5\ 
                                         + \ 2*\[Theta])\)*\((5976\  + \ 
                                        11544*\[Theta]\  + \ 8284*\[Theta]^2\ 
                                         + \ 2615*\[Theta]^3\  + \ 
                                        307*\[Theta]^4)\))\)/\((3456*\((1\  + 
                                        \ \[Theta])\)^5*\((2\  + \ 
                                        \[Theta])\)^4*\((3\  + \ 
                                        \[Theta])\)^5)\)\n\ \n
                                        GriffithsTavare[{{0, \ 0, \ 0, \ 0, \ 
                                        1, \ 1}, \ {0, \ 0, \ 1, \ 1, \ 1, \ 
                                        1}, \ {1, \ 1, \ 0, \ 0, \ 0, \ 0}, 
                                        \ {1, \ 1, \ 0, \ 0, \ 0, \ 0}}, \ 
                                        \[Theta]]\  = \ 
                                        \(\((\[Theta]^6*\((7512\  + \ 
                                        14688*\[Theta]\  + \ 
                                        10616*\[Theta]^2\  + \ 
                                        3355*\[Theta]^3\  + \ 
                                        392*\[Theta]^4)\))\)/\((5184*\((1\  + 
                                        \ \[Theta])\)^5*\((2\  + \ 
                                        \[Theta])\)^5*\((3\  + \ 
                                        \[Theta])\)^3)\)\n\ \n
                                        GriffithsTavare[{{0, \ 0, \ 0, \ 1, \ 
                                        1, \ 1}, \ {0, \ 0, \ 1, \ 0, \ 1, \ 
                                        1}, \ {1, \ 1, \ 0, \ 0, \ 0, \ 0}, 
                                        \ {1, \ 1, \ 0, \ 0, \ 0, \ 0}}, \ 
                                        \[Theta]]\  = \ 
                                        \(\((\[Theta]^6*\((7512\  + \ 
                                        14688*\[Theta]\  + \ 
                                        10616*\[Theta]^2\  + \ 
                                        3355*\[Theta]^3\  + \ 
                                        392*\[Theta]^4)\))\)/\((2592*\((1\  + 
                                        \ \[Theta])\)^5*\((2\  + \ 
                                        \[Theta])\)^5*\((3\  + \ 
                                        \[Theta])\)^3)\)\n\ \n
                                        GriffithsTavare[{{0, \ 0, \ 0, \ 0, \ 
                                        0, \ 0, \ 0}, \ {0, \ 0, \ 0, \ 0, \ 
                                        0, \ 1, \ 1}, \ {0, \ 0, \ 0, \ 1, \ 
                                        1, \ 1, \ 1}, \ {1, \ 1, \ 1, \ 0, \ 
                                        0, \ 0, \ 0}}, \ \[Theta]]\  = \ 
                                        \(\((\[Theta]^7*\((165888\  + \ 
                                        580392*\[Theta]\  + \ 
                                        831852*\[Theta]^2\  + \ 
                                        623138*\[Theta]^3\  + \ 
                                        256633*\[Theta]^4\  + \ 
                                        55091*\[Theta]^5\  + \ 
                                        4824*\[Theta]^6)\))\)/\((248832*\((1\ 
                                         + \ \[Theta])\)^4*\((2\  + \ 
                                        \[Theta])\)^6*\((3\  + \ 
                                        \[Theta])\)^6)\)\n\ \n
                                        GriffithsTavare[{{0, \ 0, \ 0, \ 0, \ 
                                        0, \ 0, \ 0}, \ {0, \ 0, \ 0, \ 0, \ 
                                        1, \ 1, \ 1}, \ {0, \ 0, \ 0, \ 1, \ 
                                        0, \ 1, \ 1}, \ {1, \ 1, \ 1, \ 0, \ 
                                        0, \ 0, \ 0}}, \ \[Theta]]\  = \ 
                                        \(\((\[Theta]^7*\((165888\  + \ 
                                        580392*\[Theta]\  + \ 
                                        831852*\[Theta]^2\  + \ 
                                        623138*\[Theta]^3\  + \ 
                                        256633*\[Theta]^4\  + \ 
                                        55091*\[Theta]^5\  + \ 
                                        4824*\[Theta]^6)\))\)/\((124416*\((1\ 
                                         + \ \[Theta])\)^4*\((2\  + \ 
                                        \[Theta])\)^6*\((3\  + \ 
                                        \[Theta])\)^6)\)\n\ \n
                                        GriffithsTavare[{{0, \ 0, \ 0, \ 0, \ 
                                        0, \ 0, \ 0}, \ {0, \ 0, \ 0, \ 1, \ 
                                        1, \ 1, \ 1}, \ {0, \ 0, \ 1, \ 0, \ 
                                        0, \ 1, \ 1}, \ {1, \ 1, \ 0, \ 0, \ 
                                        0, \ 0, \ 0}}, \ \[Theta]]\  = \ 
                                        \(\((\[Theta]^7*\((11520\  + \ 
                                        23796*\[Theta]\  + \ 
                                        18468*\[Theta]^2\  + \ 
                                        6305*\[Theta]^3\  + \ 
                                        796*\[Theta]^4)\))\)/\((27648*\((1\ 
                                         + \ \[Theta])\)^3*\((2\  + \ 
                                        \[Theta])\)^5*\((3\  + \ 
                                        \[Theta])\)^6)\)\n\ \n
                                        GriffithsTavare[{{0, \ 0, \ 0, \ 0, \ 
                                        0, \ 1, \ 1}, \ {0, \ 0, \ 0, \ 1, \ 
                                        1, \ 1, \ 1}, \ {0, \ 1, \ 1, \ 0, \ 
                                        0, \ 0, \ 0}, \ {1, \ 1, \ 1, \ 0, \ 
                                        0, \ 0, \ 0}}, \ \[Theta]]\  = \ 
                                        \(\((\[Theta]^7*\((14184\  + \ 
                                        28272*\[Theta]\  + \ 
                                        20936*\[Theta]^2\  + \ 
                                        6817*\[Theta]^3\  + \ 
                                        824*\[Theta]^4)\))\)/\((20736*\((1\ 
                                         + \ \[Theta])\)^5*\((2\  + \ 
                                        \[Theta])\)^5*\((3\  + \ 
                                        \[Theta])\)^4)\)\n\ \n
                                        GriffithsTavare[{{0, \ 0, \ 0, \ 0, \ 
                                        1, \ 1, \ 1}, \ {0, \ 0, \ 0, \ 1, \ 
                                        0, \ 1, \ 1}, \ {0, \ 1, \ 1, \ 0, \ 
                                        0, \ 0, \ 0}, \ {1, \ 1, \ 1, \ 0, \ 
                                        0, \ 0, \ 0}}, \ \[Theta]]\  = \ 
                                        \(\((\[Theta]^7*\((14184\  + \ 
                                        28272*\[Theta]\  + \ 
                                        20936*\[Theta]^2\  + \ 
                                        6817*\[Theta]^3\  + \ 
                                        824*\[Theta]^4)\))\)/\((10368*\((1\ 
                                         + \ \[Theta])\)^5*\((2\  + \ 
                                        \[Theta])\)^5*\((3\  + \ 
                                        \[Theta])\)^4)\)\n\ \n
                                        GriffithsTavare[{{0, \ 0, \ 0, \ 0, \ 
                                        1, \ 1, \ 1}, \ {0, \ 0, \ 1, \ 1, \ 
                                        0, \ 1, \ 1}, \ {1, \ 1, \ 0, \ 0, \ 
                                        0, \ 0, \ 0}, \ {1, \ 1, \ 0, \ 0, \ 
                                        0, \ 0, \ 0}}, \ \[Theta]]\  = \ 
                                        \(\((\[Theta]^7*\((308016\  + \ 
                                        725976*\[Theta]\  + \ 
                                        673776*\[Theta]^2\  + \ 
                                        307774*\[Theta]^3\  + \ 
                                        69347*\[Theta]^4\  + \ 
                                        6184*\[Theta]^5)\))\)/\((62208*\((1\ 
                                         + \ \[Theta])\)^5*\((2\  + \ 
                                        \[Theta])\)^6*\((3\  + \ 
                                        \[Theta])\)^4)\)\n\ \n
                                        GriffithsTavare[{{0, \ 0, \ 0, \ 0, \ 
                                        0, \ 0, \ 0, \ 0}, \ {0, \ 0, \ 0, \ 
                                        0, \ 1, \ 1, \ 1, \ 1}, \ {0, \ 0, \ 
                                        0, \ 1, \ 0, \ 0, \ 1, \ 1}, \ {1, \ 
                                        1, \ 1, \ 0, \ 0, \ 0, \ 0, \ 0}}, \ 
                                        \[Theta]]\  = \ 
                                        \(\((\[Theta]^8*\((117504\  + \ 
                                        413424*\[Theta]\  + \ 
                                        595692*\[Theta]^2\  + \ 
                                        449284*\[Theta]^3\  + \ 
                                        186779*\[Theta]^4\  + \ 
                                        40585*\[Theta]^5\  + \ 
                                        3606*\[Theta]^6)\))\)/\((165888*\((1\ 
                                         + \ \[Theta])\)^4*\((2\  + \ 
                                        \[Theta])\)^6*\((3\  + \ 
                                        \[Theta])\)^7)\)\n\ \n
                                        GriffithsTavare[{{0, \ 0, \ 0, \ 0, \ 
                                        0, \ 1, \ 1, \ 1}, \ {0, \ 0, \ 0, \ 
                                        1, \ 1, \ 0, \ 1, \ 1}, \ {0, \ 1, \ 
                                        1, \ 0, \ 0, \ 0, \ 0, \ 0}, \ {1, \ 
                                        1, \ 1, \ 0, \ 0, \ 0, \ 0, \ 0}}, \ 
                                        \[Theta]]\  = \ 
                                        \(\((\[Theta]^8*\((140832\  + \ 
                                        340632*\[Theta]\  + \ 
                                        326268*\[Theta]^2\  + \ 
                                        154726*\[Theta]^3\  + \ 
                                        36383*\[Theta]^4\  + \ 
                                        3400*\[Theta]^5)\))\)/\((62208*\((1\ 
                                         + \ \[Theta])\)^5*\((2\  + \ 
                                        \[Theta])\)^6*\((3\  + \ 
                                        \[Theta])\)^5)\)\n\ \n
                                        GriffithsTavare[{{0, \ 0, \ 1, \ 1}, 
                                        \ {0, \ 0, \ 1, \ 1}, \ {1, \ 1, \ 0, 
                                        \ 0}, \ {1, \ 1, \ 0, \ 0}, \ {1, \ 
                                        1, \ 0, \ 0}}, \ \[Theta]]\  = \ 
                                        \(\((\[Theta]^4*\((9468\  + \ 
                                        16760*\[Theta]\  + \ 
                                        10953*\[Theta]^2\  + \ 
                                        3126*\[Theta]^3\  + \ 
                                        329*\[Theta]^4)\))\)/\((480*\((1\  + 
                                        \ \[Theta])\)^5*\((2\  + \ 
                                        \[Theta])\)^3*\((3\  + \ 
                                        \[Theta])\)^3*\((4\  + \ 
                                        \[Theta])\))\)\n\ \n
                                        GriffithsTavare[{{0, \ 0, \ 0, \ 0, \ 
                                        0}, \ {0, \ 0, \ 0, \ 1, \ 1}, \ {0, 
                                        \ 0, \ 0, \ 1, \ 1}, \ {1, \ 1, \ 1, 
                                        \ 0, \ 0}, \ {1, \ 1, \ 1, \ 0, \ 
                                        0}}, \ \[Theta]]\  = \ 
                                        \(\((\[Theta]^5*\((385344\  + \ 
                                        1267560*\[Theta]\  + \ 
                                        1712868*\[Theta]^2\  + \ 
                                        1208618*\[Theta]^3\  + \ 
                                        466951*\[Theta]^4\  + \ 
                                        93521*\[Theta]^5\  + \ 
                                        7596*\[Theta]^6)\))\)/\((77760*\((1\ 
                                         + \ \[Theta])\)^4*\((2\  + \ 
                                        \[Theta])\)^6*\((3\  + \ 
                                        \[Theta])\)^4*\((4\  + \ 
                                        \[Theta])\))\)\n\ \n
                                        GriffithsTavare[{{0, \ 0, \ 0, \ 1, \ 
                                        1}, \ {0, \ 0, \ 0, \ 1, \ 1}, \ {0, 
                                        \ 1, \ 1, \ 0, \ 0}, \ {0, \ 1, \ 1, 
                                        \ 0, \ 0}, \ {1, \ 1, \ 1, \ 0, \ 
                                        0}}, \ \[Theta]]\  = \ 
                                        \(\((\[Theta]^5*\((5868288\  + \ 
                                        14892600*\[Theta]\  + \ 
                                        15556156*\[Theta]^2\  + \ 
                                        8557386*\[Theta]^3\  + \ 
                                        2614497*\[Theta]^4\  + \ 
                                        420676*\[Theta]^5\  + \ 
                                        27849*\[Theta]^6)\))\)/\((86400*\((1\ 
                                         + \ \[Theta])\)^5*\((2\  + \ 
                                        \[Theta])\)^4*\((3\  + \ 
                                        \[Theta])\)^4*\((4\  + \ 
                                        \[Theta])\)^2)\)\n\ \n
                                        GriffithsTavare[{{0, \ 0, \ 0, \ 1, \ 
                                        1}, \ {0, \ 0, \ 1, \ 1, \ 1}, \ {1, 
                                        \ 1, \ 0, \ 0, \ 0}, \ {1, \ 1, \ 0, 
                                        \ 0, \ 0}, \ {1, \ 1, \ 0, \ 0, \ 
                                        0}}, \ \[Theta]]\  = \ 
                                        \(\((\[Theta]^5*\((190248\  + \ 
                                        411764*\[Theta]\  + \ 
                                        350598*\[Theta]^2\  + \ 
                                        146595*\[Theta]^3\  + \ 
                                        30092*\[Theta]^4\  + \ 
                                        2427*\[Theta]^5)\))\)/\((7200*\((1\ 
                                         + \ \[Theta])\)^5*\((2\  + \ 
                                        \[Theta])\)^4*\((3\  + \ 
                                        \[Theta])\)^3*\((4\  + \ 
                                        \[Theta])\)^2)\)\n\ \n
                                        GriffithsTavare[{{0, \ 0, \ 0, \ 0, \ 
                                        0, \ 0}, \ {0, \ 0, \ 0, \ 0, \ 1, \ 
                                        1}, \ {0, \ 0, \ 0, \ 0, \ 1, \ 1}, 
                                        \ {0, \ 1, \ 1, \ 1, \ 0, \ 0}, \ {1, 
                                        \ 1, \ 1, \ 1, \ 0, \ 0}}, \ 
                                        \[Theta]]\  = \ 
                                        \(\((\[Theta]^6*\((1758528\  + \ 
                                        5582880*\[Theta]\  + \ 
                                        7296976*\[Theta]^2\  + \ 
                                        4985236*\[Theta]^3\  + \ 
                                        1863812*\[Theta]^4\  + \ 
                                        360407*\[Theta]^5\  + \ 
                                        28152*\[Theta]^6)\))\)/\((777600*\((
                                        1\  + \ \[Theta])\)^4*\((2\  + \ 
                                        \[Theta])\)^6*\((3\  + \ 
                                        \[Theta])\)^4*\((4\  + \ 
                                        \[Theta])\)^2)\)\n\ \n
                                        GriffithsTavare[{{0, \ 0, \ 0, \ 0, \ 
                                        0, \ 0}, \ {0, \ 0, \ 0, \ 0, \ 1, \ 
                                        1}, \ {0, \ 0, \ 0, \ 1, \ 1, \ 1}, 
                                        \ {1, \ 1, \ 1, \ 0, \ 0, \ 0}, \ {1, 
                                        \ 1, \ 1, \ 0, \ 0, \ 0}}, \ 
                                        \[Theta]]\  = \ 
                                        \(\((\[Theta]^6*\((2374272\  + \ 
                                        8685144*\[Theta]\  + \ 
                                        13366944*\[Theta]^2\  + \ 
                                        11169422*\[Theta]^3\  + \ 
                                        5454926*\[Theta]^4\  + \ 
                                        1555684*\[Theta]^5\  + \ 
                                        240019*\[Theta]^6\  + \ 
                                        15471*\[Theta]^7)\))\)/\((388800*\((
                                        1\  + \ \[Theta])\)^4*\((2\  + \ 
                                        \[Theta])\)^6*\((3\  + \ 
                                        \[Theta])\)^5*\((4\  + \ 
                                        \[Theta])\)^2)\)\n\ \n
                                        GriffithsTavare[{{0, \ 0, \ 0, \ 0, \ 
                                        1, \ 1}, \ {0, \ 0, \ 0, \ 0, \ 1, \ 
                                        1}, \ {0, \ 0, \ 1, \ 1, \ 0, \ 0}, 
                                        \ {0, \ 1, \ 1, \ 1, \ 0, \ 0}, \ {1, 
                                        \ 0, \ 1, \ 1, \ 0, \ 0}}, \ 
                                        \[Theta]]\  = \ 
                                        \(\((\[Theta]^6*\((29556864\  + \ 
                                        84390888*\[Theta]\  + \ 
                                        102045668*\[Theta]^2\  + \ 
                                        67728914*\[Theta]^3\  + \ 
                                        26648177*\[Theta]^4\  + \ 
                                        6216200*\[Theta]^5\  + \ 
                                        796148*\[Theta]^6\  + \ 
                                        43199*\[Theta]^7)\))\)/\((216000*\((
                                        1\  + \ \[Theta])\)^5*\((2\  + \ 
                                        \[Theta])\)^4*\((3\  + \ 
                                        \[Theta])\)^5*\((4\  + \ 
                                        \[Theta])\)^3)\)\n\ \n
                                        GriffithsTavare[{{0, \ 0, \ 0, \ 0, \ 
                                        1, \ 1}, \ {0, \ 0, \ 0, \ 1, \ 1, \ 
                                        1}, \ {0, \ 1, \ 1, \ 0, \ 0, \ 0}, 
                                        \ {0, \ 1, \ 1, \ 0, \ 0, \ 0}, \ {1, 
                                        \ 1, \ 1, \ 0, \ 0, \ 0}}, \ 
                                        \[Theta]]\  = \ 
                                        \(\((\[Theta]^6*\((18054816\  + \ 
                                        44645480*\[Theta]\  + \ 
                                        45330852*\[Theta]^2\  + \ 
                                        24187182*\[Theta]^3\  + \ 
                                        7156349*\[Theta]^4\  + \ 
                                        1114152*\[Theta]^5\  + \ 
                                        71373*\[Theta]^6)\))\)/\((432000*\((
                                        1\  + \ \[Theta])\)^5*\((2\  + \ 
                                        \[Theta])\)^4*\((3\  + \ 
                                        \[Theta])\)^4*\((4\  + \ 
                                        \[Theta])\)^3)\)\n\ \n
                                        GriffithsTavare[{{0, \ 0, \ 0, \ 0, \ 
                                        1, \ 1}, \ {0, \ 0, \ 1, \ 1, \ 1, \ 
                                        1}, \ {1, \ 1, \ 0, \ 0, \ 0, \ 0}, 
                                        \ {1, \ 1, \ 0, \ 0, \ 0, \ 0}, \ {1, 
                                        \ 1, \ 0, \ 0, \ 0, \ 0}}, \ 
                                        \[Theta]]\  = \ 
                                        \(\((\[Theta]^6*\((4146288\  + \ 
                                        10418928*\[Theta]\  + \ 
                                        10710680*\[Theta]^2\  + \ 
                                        5763764*\[Theta]^3\  + \ 
                                        1713537*\[Theta]^4\  + \ 
                                        267113*\[Theta]^5\  + \ 
                                        17081*\[Theta]^6)\))\)/\((108000*\((
                                        1\  + \ \[Theta])\)^5*\((2\  + \ 
                                        \[Theta])\)^5*\((3\  + \ 
                                        \[Theta])\)^3*\((4\  + \ 
                                        \[Theta])\)^3)\)\n\ \n
                                        GriffithsTavare[{{0, \ 0, \ 0, \ 1, \ 
                                        1, \ 1}, \ {0, \ 0, \ 1, \ 0, \ 1, \ 
                                        1}, \ {1, \ 1, \ 0, \ 0, \ 0, \ 0}, 
                                        \ {1, \ 1, \ 0, \ 0, \ 0, \ 0}, \ {1, 
                                        \ 1, \ 0, \ 0, \ 0, \ 0}}, \ 
                                        \[Theta]]\  = \ 
                                        \(\((\[Theta]^6*\((4146288\  + \ 
                                        10418928*\[Theta]\  + \ 
                                        10710680*\[Theta]^2\  + \ 
                                        5763764*\[Theta]^3\  + \ 
                                        1713537*\[Theta]^4\  + \ 
                                        267113*\[Theta]^5\  + \ 
                                        17081*\[Theta]^6)\))\)/\((54000*\((1\ 
                                         + \ \[Theta])\)^5*\((2\  + \ 
                                        \[Theta])\)^5*\((3\  + \ 
                                        \[Theta])\)^3*\((4\  + \ 
                                        \[Theta])\)^3)\)\n\ \n
                                        GriffithsTavare[{{0, \ 0, \ 0, \ 0, \ 
                                        0, \ 0, \ 0}, \ {0, \ 0, \ 0, \ 0, \ 
                                        0, \ 1, \ 1}, \ {0, \ 0, \ 0, \ 0, \ 
                                        1, \ 1, \ 1}, \ {0, \ 1, \ 1, \ 1, \ 
                                        0, \ 0, \ 0}, \ {1, \ 1, \ 1, \ 1, \ 
                                        0, \ 0, \ 0}}, \ \[Theta]]\  = \ 
                                        \(\((\[Theta]^7*\((10024128\  + \ 
                                        35877456*\[Theta]\  + \ 
                                        54207696*\[Theta]^2\  + \ 
                                        44591528*\[Theta]^3\  + \ 
                                        21486524*\[Theta]^4\  + \ 
                                        6056401*\[Theta]^5\  + \ 
                                        924901*\[Theta]^6\  + \ 
                                        59094*\[Theta]^7)\))\)/\((3888000*\((
                                        1\  + \ \[Theta])\)^4*\((2\  + \ 
                                        \[Theta])\)^6*\((3\  + \ 
                                        \[Theta])\)^5*\((4\  + \ 
                                        \[Theta])\)^3)\)\n\ \n
                                        GriffithsTavare[{{0, \ 0, \ 0, \ 0, \ 
                                        0, \ 0, \ 0}, \ {0, \ 0, \ 0, \ 0, \ 
                                        0, \ 1, \ 1}, \ {0, \ 0, \ 0, \ 1, \ 
                                        1, \ 1, \ 1}, \ {1, \ 1, \ 1, \ 0, \ 
                                        0, \ 0, \ 0}, \ {1, \ 1, \ 1, \ 0, \ 
                                        0, \ 0, \ 0}}, \ \[Theta]]\  = \ 
                                        \(\((\[Theta]^7*\((123337728\  + \ 
                                        492772032*\[Theta]\  + \ 
                                        843254208*\[Theta]^2\  + \ 
                                        805137080*\[Theta]^3\  + \ 
                                        468350700*\[Theta]^4\  + \ 
                                        169917274*\[Theta]^5\  + \ 
                                        37569553*\[Theta]^6\  + \ 
                                        4633531*\[Theta]^7\  + \ 
                                        244368*\[Theta]^8)\))\)/\((15552000*
                                        \((1\  + \ \[Theta])\)^4*\((2\  + \ 
                                        \[Theta])\)^6*\((3\  + \ 
                                        \[Theta])\)^6*\((4\  + \ 
                                        \[Theta])\)^3)\)\n\ \n
                                        GriffithsTavare[{{0, \ 0, \ 0, \ 0, \ 
                                        0, \ 0, \ 0}, \ {0, \ 0, \ 0, \ 0, \ 
                                        1, \ 1, \ 1}, \ {0, \ 0, \ 0, \ 1, \ 
                                        0, \ 1, \ 1}, \ {1, \ 1, \ 1, \ 0, \ 
                                        0, \ 0, \ 0}, \ {1, \ 1, \ 1, \ 0, \ 
                                        0, \ 0, \ 0}}, \ \[Theta]]\  = \ 
                                        \(\((\[Theta]^7*\((123337728\  + \ 
                                        492772032*\[Theta]\  + \ 
                                        843254208*\[Theta]^2\  + \ 
                                        805137080*\[Theta]^3\  + \ 
                                        468350700*\[Theta]^4\  + \ 
                                        169917274*\[Theta]^5\  + \ 
                                        37569553*\[Theta]^6\  + \ 
                                        4633531*\[Theta]^7\  + \ 
                                        244368*\[Theta]^8)\))\)/\((7776000*\((
                                        1\  + \ \[Theta])\)^4*\((2\  + \ 
                                        \[Theta])\)^6*\((3\  + \ 
                                        \[Theta])\)^6*\((4\  + \ 
                                        \[Theta])\)^3)\)\n\ \n
                                        GriffithsTavare[{{0, \ 0, \ 0, \ 0, \ 
                                        0, \ 1, \ 1}, \ {0, \ 0, \ 0, \ 0, \ 
                                        1, \ 1, \ 1}, \ {0, \ 0, \ 1, \ 1, \ 
                                        0, \ 0, \ 0}, \ {0, \ 1, \ 1, \ 1, \ 
                                        0, \ 0, \ 0}, \ {1, \ 0, \ 1, \ 1, \ 
                                        0, \ 0, \ 0}}, \ \[Theta]]\  = \ 
                                        \(\((\[Theta]^7*\((83721312\  + \ 
                                        236382144*\[Theta]\  + \ 
                                        282683704*\[Theta]^2\  + \ 
                                        185621312*\[Theta]^3\  + \ 
                                        72304406*\[Theta]^4\  + \ 
                                        16715005*\[Theta]^5\  + \ 
                                        2124419*\[Theta]^6\  + \ 
                                        114572*\[Theta]^7)\))\)/\((1080000*\((
                                        1\  + \ \[Theta])\)^5*\((2\  + \ 
                                        \[Theta])\)^4*\((3\  + \ 
                                        \[Theta])\)^5*\((4\  + \ 
                                        \[Theta])\)^4)\)\n\ \n
                                        GriffithsTavare[{{0, \ 0, \ 0, \ 0, \ 
                                        0, \ 1, \ 1}, \ {0, \ 0, \ 0, \ 1, \ 
                                        1, \ 1, \ 1}, \ {0, \ 1, \ 1, \ 0, \ 
                                        0, \ 0, \ 0}, \ {0, \ 1, \ 1, \ 0, \ 
                                        0, \ 0, \ 0}, \ {1, \ 1, \ 1, \ 0, \ 
                                        0, \ 0, \ 0}}, \ \[Theta]]\  = \ 
                                        \(\((\[Theta]^7*\((371067264\  + \ 
                                        1058154192*\[Theta]\  + \ 
                                        1274929168*\[Theta]^2\  + \ 
                                        841472312*\[Theta]^3\  + \ 
                                        328784140*\[Theta]^4\  + \ 
                                        76118971*\[Theta]^5\  + \ 
                                        9679091*\[Theta]^6\  + \ 
                                        522091*\[Theta]^7)\))\)/\((6480000*\((
                                        1\  + \ \[Theta])\)^5*\((2\  + \ 
                                        \[Theta])\)^5*\((3\  + \ 
                                        \[Theta])\)^4*\((4\  + \ 
                                        \[Theta])\)^4)\)\n\ \n
                                        GriffithsTavare[{{0, \ 0, \ 0, \ 0, \ 
                                        1, \ 1, \ 1}, \ {0, \ 0, \ 0, \ 1, \ 
                                        0, \ 1, \ 1}, \ {0, \ 1, \ 1, \ 0, \ 
                                        0, \ 0, \ 0}, \ {0, \ 1, \ 1, \ 0, \ 
                                        0, \ 0, \ 0}, \ {1, \ 1, \ 1, \ 0, \ 
                                        0, \ 0, \ 0}}, \ \[Theta]]\  = \ 
                                        \(\((\[Theta]^7*\((371067264\  + \ 
                                        1058154192*\[Theta]\  + \ 
                                        1274929168*\[Theta]^2\  + \ 
                                        841472312*\[Theta]^3\  + \ 
                                        328784140*\[Theta]^4\  + \ 
                                        76118971*\[Theta]^5\  + \ 
                                        9679091*\[Theta]^6\  + \ 
                                        522091*\[Theta]^7)\))\)/\((3240000*\((
                                        1\  + \ \[Theta])\)^5*\((2\  + \ 
                                        \[Theta])\)^5*\((3\  + \ 
                                        \[Theta])\)^4*\((4\  + \ 
                                        \[Theta])\)^4)\)\n\ \n
                                        GriffithsTavare[{{0, \ 0, \ 0, \ 0, \ 
                                        1, \ 1, \ 1}, \ {0, \ 0, \ 1, \ 1, \ 
                                        0, \ 1, \ 1}, \ {1, \ 1, \ 0, \ 0, \ 
                                        0, \ 0, \ 0}, \ {1, \ 1, \ 0, \ 0, \ 
                                        0, \ 0, \ 0}, \ {1, \ 1, \ 0, \ 0, \ 
                                        0, \ 0, \ 0}}, \ \[Theta]]\  = \ 
                                        \(\((\[Theta]^7*\((3359726208\  + \ 
                                        10652724288*\[Theta]\  + \ 
                                        14546268288*\[Theta]^2\  + \ 
                                        11180290832*\[Theta]^3\  + \ 
                                        5296016992*\[Theta]^4\  + \ 
                                        1585065572*\[Theta]^5\  + \ 
                                        293053418*\[Theta]^6\  + \ 
                                        30635023*\[Theta]^7\  + \ 
                                        1387916*\[Theta]^8)\))\)/\((6480000*
                                        \((1\  + \ \[Theta])\)^5*\((2\  + \ 
                                        \[Theta])\)^6*\((3\  + \ 
                                        \[Theta])\)^4*\((4\  + \ 
                                        \[Theta])\)^4)\)\n\ \n
                                        GriffithsTavare[{{0, \ 0, \ 0, \ 0, \ 
                                        0, \ 0, \ 0, \ 0}, \ {0, \ 0, \ 0, \ 
                                        0, \ 0, \ 0, \ 1, \ 1}, \ {0, \ 0, \ 
                                        0, \ 0, \ 1, \ 1, \ 1, \ 1}, \ {0, \ 
                                        1, \ 1, \ 1, \ 0, \ 0, \ 0, \ 0}, 
                                        \ {1, \ 1, \ 1, \ 1, \ 0, \ 0, \ 0, \ 
                                        0}}, \ \[Theta]]\  = \ 
                                        \(\((\[Theta]^8*\((243627264\  + \ 
                                        963398016*\[Theta]\  + \ 
                                        1637256384*\[Theta]^2\  + \ 
                                        1557066200*\[Theta]^3\  + \ 
                                        904555100*\[Theta]^4\  + \ 
                                        328540182*\[Theta]^5\  + \ 
                                        72893969*\[Theta]^6\  + \ 
                                        9042263*\[Theta]^7\  + \ 
                                        480744*\[Theta]^8)\))\)/\((77760000*
                                        \((1\  + \ \[Theta])\)^4*\((2\  + \ 
                                        \[Theta])\)^6*\((3\  + \ 
                                        \[Theta])\)^6*\((4\  + \ 
                                        \[Theta])\)^4)\)\n\ \n
                                        GriffithsTavare[{{0, \ 0, \ 0, \ 0, \ 
                                        0, \ 0, \ 0, \ 0}, \ {0, \ 0, \ 0, \ 
                                        0, \ 0, \ 1, \ 1, \ 1}, \ {0, \ 0, \ 
                                        0, \ 0, \ 1, \ 0, \ 1, \ 1}, \ {0, \ 
                                        1, \ 1, \ 1, \ 0, \ 0, \ 0, \ 0}, 
                                        \ {1, \ 1, \ 1, \ 1, \ 0, \ 0, \ 0, \ 
                                        0}}, \ \[Theta]]\  = \ 
                                        \(\((\[Theta]^8*\((243627264\  + \ 
                                        963398016*\[Theta]\  + \ 
                                        1637256384*\[Theta]^2\  + \ 
                                        1557066200*\[Theta]^3\  + \ 
                                        904555100*\[Theta]^4\  + \ 
                                        328540182*\[Theta]^5\  + \ 
                                        72893969*\[Theta]^6\  + \ 
                                        9042263*\[Theta]^7\  + \ 
                                        480744*\[Theta]^8)\))\)/\((38880000*
                                        \((1\  + \ \[Theta])\)^4*\((2\  + \ 
                                        \[Theta])\)^6*\((3\  + \ 
                                        \[Theta])\)^6*\((4\  + \ 
                                        \[Theta])\)^4)\)\n\ \n
                                        GriffithsTavare[{{0, \ 0, \ 0, \ 0, \ 
                                        0, \ 0, \ 0, \ 0}, \ {0, \ 0, \ 0, \ 
                                        0, \ 1, \ 1, \ 1, \ 1}, \ {0, \ 0, \ 
                                        0, \ 1, \ 0, \ 0, \ 1, \ 1}, \ {1, \ 
                                        1, \ 1, \ 0, \ 0, \ 0, \ 0, \ 0}, 
                                        \ {1, \ 1, \ 1, \ 0, \ 0, \ 0, \ 0, \ 
                                        0}}, \ \[Theta]]\  = \ 
                                        \(\((\[Theta]^8*\((1680058368\  + \ 
                                        7215723648*\[Theta]\  + \ 
                                        13467405312*\[Theta]^2\  + \ 
                                        14320578896*\[Theta]^3\  + \ 
                                        9555530360*\[Theta]^4\  + \ 
                                        4149946544*\[Theta]^5\  + \ 
                                        1173938866*\[Theta]^6\  + \ 
                                        208801167*\[Theta]^7\  + \ 
                                        21215395*\[Theta]^8\  + \ 
                                        939486*\[Theta]^9)\))\)/\((51840000*
                                        \((1\  + \ \[Theta])\)^4*\((2\  + \ 
                                        \[Theta])\)^6*\((3\  + \ 
                                        \[Theta])\)^7*\((4\  + \ 
                                        \[Theta])\)^4)\)\n\ \n
                                        GriffithsTavare[{{0, \ 0, \ 0, \ 0, \ 
                                        0, \ 0, \ 1, \ 1}, \ {0, \ 0, \ 0, \ 
                                        0, \ 1, \ 1, \ 1, \ 1}, \ {0, \ 0, \ 
                                        1, \ 1, \ 0, \ 0, \ 0, \ 0}, \ {0, \ 
                                        1, \ 1, \ 1, \ 0, \ 0, \ 0, \ 0}, 
                                        \ {1, \ 0, \ 1, \ 1, \ 0, \ 0, \ 0, \ 
                                        0}}, \ \[Theta]]\  = \ 
                                        \(\((\[Theta]^8*\((1615529664\  + \ 
                                        5214986640*\[Theta]\  + \ 
                                        7288190352*\[Theta]^2\  + \ 
                                        5761125088*\[Theta]^3\  + \ 
                                        2818515104*\[Theta]^4\  + \ 
                                        874344301*\[Theta]^5\  + \ 
                                        168047773*\[Theta]^6\  + \ 
                                        18306053*\[Theta]^7\  + \ 
                                        865807*\[Theta]^8)\))\)/\((16200000*
                                        \((1\  + \ \[Theta])\)^5*\((2\  + \ 
                                        \[Theta])\)^5*\((3\  + \ 
                                        \[Theta])\)^5*\((4\  + \ 
                                        \[Theta])\)^5)\)\n\ \n
                                        GriffithsTavare[{{0, \ 0, \ 0, \ 0, \ 
                                        0, \ 1, \ 1, \ 1}, \ {0, \ 0, \ 0, \ 
                                        0, \ 1, \ 0, \ 1, \ 1}, \ {0, \ 0, \ 
                                        1, \ 1, \ 0, \ 0, \ 0, \ 0}, \ {0, \ 
                                        1, \ 1, \ 1, \ 0, \ 0, \ 0, \ 0}, 
                                        \ {1, \ 0, \ 1, \ 1, \ 0, \ 0, \ 0, \ 
                                        0}}, \ \[Theta]]\  = \ 
                                        \(\((\[Theta]^8*\((1615529664\  + \ 
                                        5214986640*\[Theta]\  + \ 
                                        7288190352*\[Theta]^2\  + \ 
                                        5761125088*\[Theta]^3\  + \ 
                                        2818515104*\[Theta]^4\  + \ 
                                        874344301*\[Theta]^5\  + \ 
                                        168047773*\[Theta]^6\  + \ 
                                        18306053*\[Theta]^7\  + \ 
                                        865807*\[Theta]^8)\))\)/\((8100000*\((
                                        1\  + \ \[Theta])\)^5*\((2\  + \ 
                                        \[Theta])\)^5*\((3\  + \ 
                                        \[Theta])\)^5*\((4\  + \ 
                                        \[Theta])\)^5)\)\n\ \n
                                        GriffithsTavare[{{0, \ 0, \ 0, \ 0, \ 
                                        0, \ 1, \ 1, \ 1}, \ {0, \ 0, \ 0, \ 
                                        1, \ 1, \ 0, \ 1, \ 1}, \ {0, \ 1, \ 
                                        1, \ 0, \ 0, \ 0, \ 0, \ 0}, \ {0, \ 
                                        1, \ 1, \ 0, \ 0, \ 0, \ 0, \ 0}, 
                                        \ {1, \ 1, \ 1, \ 0, \ 0, \ 0, \ 0, \ 
                                        0}}, \ \[Theta]]\  = \ 
                                        \(\((\[Theta]^8*\((72808288128\  + \ 
                                        256826290464*\[Theta]\  + \ 
                                        397831226544*\[Theta]^2\  + \ 
                                        355401407488*\[Theta]^3\  + \ 
                                        201947845536*\[Theta]^4\  + \ 
                                        75757017666*\[Theta]^5\  + \ 
                                        18777916847*\[Theta]^6\  + \ 
                                        2968231959*\[Theta]^7\  + \ 
                                        271741602*\[Theta]^8\  + \ 
                                        10987567*\[Theta]^9)\))\)/\((97200000*
                                        \((1\  + \ \[Theta])\)^5*\((2\  + \ 
                                        \[Theta])\)^6*\((3\  + \ 
                                        \[Theta])\)^5*\((4\  + \ 
                                        \[Theta])\)^5)\)\n\ \n
                                        GriffithsTavare[{{0, \ 0, \ 0, \ 0, \ 
                                        0, \ 0, \ 0, \ 0, \ 0}, \ {0, \ 0, \ 
                                        0, \ 0, \ 0, \ 1, \ 1, \ 1, \ 1}, 
                                        \ {0, \ 0, \ 0, \ 0, \ 1, \ 0, \ 0, \ 
                                        1, \ 1}, \ {0, \ 1, \ 1, \ 1, \ 0, \ 
                                        0, \ 0, \ 0, \ 0}, \ {1, \ 1, \ 1, \ 
                                        1, \ 0, \ 0, \ 0, \ 0, \ 0}}, \ 
                                        \[Theta]]\  = \ 
                                        \(\((\[Theta]^9*\((3141821952\  + \ 
                                        13483366272*\[Theta]\  + \ 
                                        25217739648*\[Theta]^2\  + \ 
                                        26937488864*\[Theta]^3\  + \ 
                                        18096993360*\[Theta]^4\  + \ 
                                        7930297836*\[Theta]^5\  + \ 
                                        2268383044*\[Theta]^6\  + \ 
                                        408842683*\[Theta]^7\  + \ 
                                        42184385*\[Theta]^8\  + \ 
                                        1900974*\[Theta]^9)\))\)/\((259200000*
                                        \((1\  + \ \[Theta])\)^4*\((2\  + \ 
                                        \[Theta])\)^6*\((3\  + \ 
                                        \[Theta])\)^7*\((4\  + \ 
                                        \[Theta])\)^5)\)\n\ \n
                                        GriffithsTavare[{{0, \ 0, \ 0, \ 0, \ 
                                        0, \ 0, \ 1, \ 1, \ 1}, \ {0, \ 0, \ 
                                        0, \ 0, \ 1, \ 1, \ 0, \ 1, \ 1}, 
                                        \ {0, \ 0, \ 1, \ 1, \ 0, \ 0, \ 0, \ 
                                        0, \ 0}, \ {0, \ 1, \ 1, \ 1, \ 0, \ 
                                        0, \ 0, \ 0, \ 0}, \ {1, \ 0, \ 1, \ 
                                        1, \ 0, \ 0, \ 0, \ 0, \ 0}}, \ 
                                        \[Theta]]\  = \ 
                                        \((\[Theta]^9*\((20377564416\  + \ 
                                        73047163392*\[Theta]\  + \ 
                                        115190706528*\[Theta]^2\  + \ 
                                        104939074448*\[Theta]^3\  + \ 
                                        60906248640*\[Theta]^4\  + \ 
                                        23372370204*\[Theta]^5\  + \ 
                                        5934375094*\[Theta]^6\  + \ 
                                        962034174*\[Theta]^7\  + \ 
                                        90416121*\[Theta]^8\  + \ 
                                        3755966*\[Theta]^9)\))\)/\((48600000*
                                        \((1\  + \ \[Theta])\)^5*\((2\  + \ 
                                        \[Theta])\)^6*\((3\  + \ 
                                        \[Theta])\)^5*\((4\  + \ 
                                        \[Theta])\)^6)
                                        \)\)\)\)\)\)\)\)\)\)\)\)\)\)\)\)\)\)\)\
\)\)\)\)\)\)\)\)\)\)\)\)\)\)\)\)\)\)\)\)\)\)\)\)\)\)\)\)\)\)\)\)\)\)\)\)\)\)\)\
\)\)\)\)\)\)\)\)\)\)\)\)\)\)\)\)\)\)\)\)\)\)\)\)\)\)\)\)\)\)\)\)\)\)\)\)\)\)\)\
\)\)\)\)\)\)\)\)\)\)\)\)\),
      ShowStringCharacters->True,
      NumberMarks->True]], "Print"]
}, Closed]]
}, Open  ]],

Cell[CellGroupData[{

Cell["An example: 12 lineages and 20 mutations take 500s", "SubsectionIcon",
  CellTags->"Example"],

Cell["Here is a randomly generated genealogy with 12 lineages:", "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[
    \(g = RandomGenealogy[Array[leaf, {12}], MutationRate \[Rule] 10]; \n
    Show[PlotGenealogy[g]]; \)], "Input",
  CellLabel->"In[4]:="],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0769231 0.0769231 0.0686704 0.0686704 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
0 g
.5 Mabswid
[ ] 0 setdash
.88462 .13734 m
.84615 .06867 L
s
.88462 .13734 m
.92308 .06867 L
s
.42308 .13734 m
.38462 .06867 L
s
.42308 .13734 m
.46154 .06867 L
s
.84615 .20601 m
.76923 .06867 L
s
.84615 .20601 m
.88462 .13734 L
s
.65385 .13734 m
.61538 .06867 L
s
.65385 .13734 m
.69231 .06867 L
s
.76923 .27468 m
.65385 .13734 L
s
.76923 .27468 m
.84615 .20601 L
s
.73077 .34335 m
.53846 .06867 L
s
.73077 .34335 m
.76923 .27468 L
s
.26923 .13734 m
.23077 .06867 L
s
.26923 .13734 m
.30769 .06867 L
s
.23077 .20601 m
.15385 .06867 L
s
.23077 .20601 m
.26923 .13734 L
s
.19231 .27468 m
.07692 .06867 L
s
.19231 .27468 m
.23077 .20601 L
s
.65385 .41202 m
.42308 .13734 L
s
.65385 .41202 m
.73077 .34335 L
s
.5 .48069 m
.19231 .27468 L
s
.5 .48069 m
.65385 .41202 L
s
.5 .54936 m
.5 .48069 L
s
[(1)] .86923 .15107 0 0 Mshowa
[(2)] .40769 .15107 0 0 Mshowa
[(3)] .83077 .21975 0 0 Mshowa
[(4)] .63846 .15107 0 0 Mshowa
[(5)] .75385 .28842 0 0 Mshowa
[(6)] .71538 .35709 0 0 Mshowa
[(7)] .25385 .15107 0 0 Mshowa
[(8)] .21538 .21975 0 0 Mshowa
[(9)] .17692 .28842 0 0 Mshowa
[(10)] .63846 .42576 0 0 Mshowa
[(11)] .48462 .49443 0 0 Mshowa
[(12)] .48462 .5631 0 0 Mshowa
gsave
.07692 .05494 -84 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 16.000000 moveto
 558.000000 16.000000 lineto
 558.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 16.000000 lineto
closepath
clip newpath
63.000000 13.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(leaf) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
87.000000 13.000000 moveto
(@) show
93.000000 13.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(7) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
99.000000 13.000000 moveto
(D) show
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Math2Mono
%%+ font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Math2Mono
%%+ Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: font Math2Mono
%%+ font Courier
grestore
gsave
.15385 .05494 -84 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 16.000000 moveto
 558.000000 16.000000 lineto
 558.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 16.000000 lineto
closepath
clip newpath
63.000000 13.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(leaf) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
87.000000 13.000000 moveto
(@) show
93.000000 13.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(8) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
99.000000 13.000000 moveto
(D) show
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Math2Mono
%%+ font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Math2Mono
%%+ Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: font Math2Mono
%%+ font Courier
grestore
gsave
.23077 .05494 -84 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 16.000000 moveto
 558.000000 16.000000 lineto
 558.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 16.000000 lineto
closepath
clip newpath
63.000000 13.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(leaf) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
87.000000 13.000000 moveto
(@) show
93.000000 13.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(2) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
99.000000 13.000000 moveto
(D) show
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Math2Mono
%%+ font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Math2Mono
%%+ Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: font Math2Mono
%%+ font Courier
grestore
gsave
.30769 .05494 -87 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 16.000000 moveto
 558.000000 16.000000 lineto
 558.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 16.000000 lineto
closepath
clip newpath
63.000000 13.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(leaf) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
87.000000 13.000000 moveto
(@) show
93.000000 13.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(11) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
105.000000 13.000000 moveto
(D) show
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Math2Mono
%%+ font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Math2Mono
%%+ Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: font Math2Mono
%%+ font Courier
grestore
gsave
.38462 .05494 -84 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 16.000000 moveto
 558.000000 16.000000 lineto
 558.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 16.000000 lineto
closepath
clip newpath
63.000000 13.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(leaf) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
87.000000 13.000000 moveto
(@) show
93.000000 13.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(3) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
99.000000 13.000000 moveto
(D) show
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Math2Mono
%%+ font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Math2Mono
%%+ Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: font Math2Mono
%%+ font Courier
grestore
gsave
.46154 .05494 -84 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 16.000000 moveto
 558.000000 16.000000 lineto
 558.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 16.000000 lineto
closepath
clip newpath
63.000000 13.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(leaf) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
87.000000 13.000000 moveto
(@) show
93.000000 13.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(9) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
99.000000 13.000000 moveto
(D) show
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Math2Mono
%%+ font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Math2Mono
%%+ Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: font Math2Mono
%%+ font Courier
grestore
gsave
.53846 .05494 -84 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 16.000000 moveto
 558.000000 16.000000 lineto
 558.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 16.000000 lineto
closepath
clip newpath
63.000000 13.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(leaf) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
87.000000 13.000000 moveto
(@) show
93.000000 13.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(5) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
99.000000 13.000000 moveto
(D) show
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Math2Mono
%%+ font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Math2Mono
%%+ Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: font Math2Mono
%%+ font Courier
grestore
gsave
.61538 .05494 -84 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 16.000000 moveto
 558.000000 16.000000 lineto
 558.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 16.000000 lineto
closepath
clip newpath
63.000000 13.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(leaf) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
87.000000 13.000000 moveto
(@) show
93.000000 13.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(1) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
99.000000 13.000000 moveto
(D) show
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Math2Mono
%%+ font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Math2Mono
%%+ Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: font Math2Mono
%%+ font Courier
grestore
gsave
.69231 .05494 -84 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 16.000000 moveto
 558.000000 16.000000 lineto
 558.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 16.000000 lineto
closepath
clip newpath
63.000000 13.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(leaf) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
87.000000 13.000000 moveto
(@) show
93.000000 13.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(4) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
99.000000 13.000000 moveto
(D) show
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Math2Mono
%%+ font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Math2Mono
%%+ Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: font Math2Mono
%%+ font Courier
grestore
gsave
.76923 .05494 -84 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 16.000000 moveto
 558.000000 16.000000 lineto
 558.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 16.000000 lineto
closepath
clip newpath
63.000000 13.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(leaf) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
87.000000 13.000000 moveto
(@) show
93.000000 13.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(6) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
99.000000 13.000000 moveto
(D) show
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Math2Mono
%%+ font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Math2Mono
%%+ Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: font Math2Mono
%%+ font Courier
grestore
gsave
.84615 .05494 -87 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 16.000000 moveto
 558.000000 16.000000 lineto
 558.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 16.000000 lineto
closepath
clip newpath
63.000000 13.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(leaf) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
87.000000 13.000000 moveto
(@) show
93.000000 13.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(10) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
105.000000 13.000000 moveto
(D) show
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Math2Mono
%%+ font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Math2Mono
%%+ Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: font Math2Mono
%%+ font Courier
grestore
gsave
.92308 .05494 -87 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 16.000000 moveto
 558.000000 16.000000 lineto
 558.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 16.000000 lineto
closepath
clip newpath
63.000000 13.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(leaf) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
87.000000 13.000000 moveto
(@) show
93.000000 13.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(12) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
105.000000 13.000000 moveto
(D) show
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Math2Mono
%%+ font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Math2Mono
%%+ Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: font Math2Mono
%%+ font Courier
grestore
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[4]:=",
  ImageSize->{595, 367.562},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40009C0001Ka000`40O003h00OogooogooEGoo003o
OoooOomEOol00?mooomooeEoo`00ogooogooEGoo003oOoooOomEOol00?mooomooeEoo`00ogooogoo
EGoo003oOoooOomEOol00?mooomooeEoo`00ogooogooEGoo003oOoooOomEOol00?mooomooeEoo`00
ogooogooEGoo003oOoooOomEOol00?mooomooeEoo`00ogooogooEGoo003oOoooOomEOol00?mooomo
oeEoo`00ogooogooEGoo003oOoooOomEOol00?mooomooeEoo`00ogooogooEGoo003oOoooOomEOol0
0?mooomooeEoo`00ogooogooEGoo003oOoooOomEOol00?mooomooeEoo`00ogooogooEGoo003oOooo
OomEOol003Aoo`8000Qoo`80025oo`8000Qoo`80029oo`8000Qoo`8001ioo`8000ioo`8001moo`80
00Qoo`80029oo`8000Qoo`80025oo`8000Qoo`80029oo`8000Qoo`80029oo`8000Qoo`80025oo`80
00Qoo`8001moo`8000ioo`8001]oo`8000ioo`8001]oo`00=7oo00<007ooOol027oo00<007ooOol0
7goo00<007ooOol027oo00<007ooOol087oo00<007ooOol027oo00<007ooOol077oo00<007ooOol0
3Woo00<007ooOol07Goo00<007ooOol027oo00<007ooOol087oo00<007ooOol027oo00<007ooOol0
7goo00<007ooOol027oo00<007ooOol087oo00<007ooOol027oo00<007ooOol087oo00<007ooOol0
27oo00<007ooOol07goo00<007ooOol027oo00<007ooOol07Goo00<007ooOol03Woo00<007ooOol0
6Goo00<007ooOol03Woo00<007ooOol06Goo000JOol50002Ool400000goo0000000300000goo0000
00020004Ool00`00Oomoo`02Ool00`00Oomoo`03Ool00`00Oomoo`05Ool50002Ool400000goo0000
000300000goo000000020004Ool00`00Oomoo`02Ool20004Ool00`00Oomoo`06Ool50002Ool40000
0goo0000000300000goo000000020004Ool01000Oomoogoo10000goo00<007ooOol00Woo1@000Woo
100000=oo`0000000`0000=oo`0000000P0017oo00@007ooOomoo`<000=oo`<000Aoo`03001oogoo
00=oo`D0009oo`@00003Ool0000000<00003Ool00000008000Aoo`04001oogooOol30004Ool00`00
Oomoo`06Ool50002Ool400000goo0000000300000goo000000020004Ool01000Oomoogoo0`0017oo
00<007ooOol01Goo1@000Woo100000=oo`0000000`0000=oo`0000000P0017oo00@007ooOomoo`<0
00Aoo`03001oogoo00Ioo`D0009oo`@00003Ool0000000<00003Ool00000008000Aoo`04001oogoo
Ool30004Ool00`00Oomoo`06Ool50002Ool400000goo0000000300000goo000000020004Ool00`00
Oomoo`02Ool30003Ool00`00Oomoo`05Ool50002Ool400000goo0000000300000goo000000020004
Ool00`00Oomoo`02Ool20004Ool00`00Oomoo`03Ool50002Ool400000goo0000000300000goo0000
00020004Ool01000Oomoogoo0`0017oo0P0017oo00<007oo000010000Woo100000=oo`0000000`00
00=oo`0000000P0017oo00@007ooOomoo`<000=oo`@000=oo`03001oogoo01Uoo`0077oo00D007oo
Oomoo`0000Eoo`04001oogoo0003Ool00`00Oomoo`04Ool00`00Oomoo`02Ool00`00Oomoo`03Ool0
0`00Oomoo`07Ool01@00Oomoogoo00001Goo00@007ooOol000=oo`03001oogoo00Aoo`05001oogoo
Ool00002Ool01@00Oomoogoo00002Woo00D007ooOomoo`0000Eoo`04001oogoo0003Ool00`00Oomo
o`04Ool00`00Oomoo`02Ool00`00Oomoo`03Ool00`00Oomoo`04Ool01@00Oomoogoo00001Goo00@0
07ooOol000=oo`03001oogoo00Aoo`03001oogoo009oo`03001oogoo00=oo`03001oogoo00=oo`03
001oogoo00Eoo`05001oogooOol00005Ool01000Oomoo`000goo00<007ooOol017oo00<007ooOol0
17oo00D007ooOomoo`0000Yoo`05001oogooOol00005Ool01000Oomoo`000goo00<007ooOol017oo
00<007ooOol017oo00D007ooOomoo`0000Uoo`05001oogooOol00005Ool01000Oomoo`000goo00<0
07ooOol017oo00<007ooOol017oo00D007ooOomoo`0000Yoo`05001oogooOol00005Ool01000Oomo
o`000goo00<007ooOol017oo00<007ooOol00Woo00<007ooOol00goo00<007ooOol027oo00D007oo
Oomoo`0000Eoo`04001oogoo0003Ool00`00Oomoo`04Ool00`00Oomoo`03Ool00`00Oomoo`02Ool0
0`00Oomoo`07Ool01@00Oomoogoo00001Goo00@007ooOol000=oo`03001oogoo00Aoo`05001oogoo
Ool00002Ool01@00Oomoogoo00001goo00D007ooOomoo`0000Eoo`04001oogoo0003Ool00`00Oomo
o`04Ool00`00Oomoo`02Ool00`00Oomoo`02Ool01000Oomoo`000goo00D007ooOomoo`0000=oo`03
001oogoo00=oo`04001oogoo0003Ool00`00Oomoo`04Ool00`00Oomoo`02Ool00`00Oomoo`03Ool0
0`00Oomoo`03Ool00`00Oomoo`0IOol001aoo`04001oogooOol500000goo000000020003Ool00`00
Oomoo`04Ool00`00Oomoo`03Ool00`00Oomoo`02Ool00`00Oomoo`07Ool01000Oomoogoo1@0000=o
o`0000000P000goo00<007ooOol017oo00D007ooOomoo`00009oo`05001oogooOol0000:Ool01000
Oomoogoo1@0000=oo`0000000P000goo00<007ooOol017oo00<007ooOol00goo00<007ooOol00Woo
00<007ooOol017oo00@007ooOomoo`D00003Ool00000008000=oo`03001oogoo00Aoo`03001oogoo
009oo`03001oogoo00=oo`03001oogoo00=oo`03001oogoo00Eoo`04001oogooOol500000goo0000
00020003Ool00`00Oomoo`04Ool00`00Oomoo`04Ool01@00Oomoogoo00002Woo00@007ooOomoo`D0
0003Ool00000008000=oo`03001oogoo00Aoo`03001oogoo009oo`<000=oo`03001oogoo00Moo`04
001oogooOol500000goo000000020003Ool00`00Oomoo`04Ool00`00Oomoo`04Ool01@00Oomoogoo
00002Woo00@007ooOomoo`D00003Ool00000008000=oo`03001oogoo00Aoo`03001oogoo009oo`03
001oogoo00=oo`03001oogoo00Qoo`04001oogooOol500000goo000000020003Ool00`00Oomoo`04
Ool01000Oomoogoo10000goo00<007ooOol01goo00@007ooOomoo`D00003Ool00000008000=oo`03
001oogoo00Aoo`05001oogooOol00002Ool01@00Oomoogoo00001goo00@007ooOomoo`D00003Ool0
0000008000=oo`03001oogoo00Aoo`03001oogoo009oo`03001oogoo009oo`04001oogoo0003Ool0
1@00Oomoogoo00000goo1@0000=oo`0000000P000goo00<007ooOol017oo00<007ooOol00Woo00<0
07ooOol017oo00<007ooOol00Woo00<007ooOol06Goo000LOol01@00Oomoogoo00000goo00<007oo
Ool00Woo00D007ooOomoo`0000Ioo`03001oogoo00=oo`03001oogoo009oo`03001oogoo00Moo`05
001oogooOol00003Ool00`00Oomoo`02Ool01@00Oomoogoo00001Woo00<007ooOol00Woo0P0017oo
00<007ooOol027oo00D007ooOomoo`0000=oo`03001oogoo009oo`05001oogooOol00006Ool00`00
Oomoo`04Ool01@00Oomoogoo00001Woo00D007ooOomoo`0000=oo`03001oogoo009oo`05001oogoo
Ool00006Ool00`00Oomoo`02Ool00`00Oomoo`03Ool00`00Oomoo`03Ool00`00Oomoo`05Ool01@00
Oomoogoo00000goo00<007ooOol00Woo00D007ooOomoo`0000Ioo`03001oogoo009oo`8000Aoo`03
001oogoo00Qoo`05001oogooOol00003Ool00`00Oomoo`02Ool01@00Oomoogoo00001Woo00D007oo
Oomoo`00009oo`05001oogooOol00009Ool01@00Oomoogoo00000goo00<007ooOol00Woo00D007oo
Oomoo`0000Ioo`04001oogooOol30004Ool00`00Oomoo`08Ool01@00Oomoogoo00000goo00<007oo
Ool00Woo00D007ooOomoo`0000Ioo`03001oogoo009oo`03001oogoo00=oo`03001oogoo00Qoo`05
001oogooOol00003Ool00`00Oomoo`02Ool01@00Oomoogoo00001Woo00L007ooOomoo`00Ool00004
Ool00`00Oomoo`07Ool01@00Oomoogoo00000goo00<007ooOol00Woo00D007ooOomoo`0000Ioo`04
001oogooOol30004Ool00`00Oomoo`05Ool01@00Oomoogoo00000goo00<007ooOol00Woo00D007oo
Oomoo`0000Ioo`03001oogoo009oo`03001oogoo009oo`04001oogoo0003Ool01@00Oomoogoo0000
0goo00D007ooOomoo`0000Aoo`05001oogooOol00006Ool00`00Oomoo`02Ool00`00Oomoo`05Ool0
1@00Oomoogoo00006goo000LOol00`00Oomoo`02Ool30003Ool30002Ool40004Ool00`00Oomoo`04
Ool01@00Oomoogoo00002Goo00<007ooOol00Woo0`000goo0`000Woo100017oo00D007ooOomoo`00
009oo`05001oogooOol0000:Ool00`00Oomoo`02Ool30003Ool30002Ool40004Ool01@00Oomoogoo
00000Woo00D007ooOomoo`0000Ioo`03001oogoo009oo`<000=oo`<0009oo`@000Aoo`03001oogoo
009oo`03001oogoo00=oo`03001oogoo00=oo`03001oogoo00Eoo`03001oogoo009oo`<000=oo`<0
009oo`@000Aoo`03001oogoo00Aoo`05001oogooOol0000:Ool00`00Oomoo`02Ool30003Ool30002
Ool40004Ool01@00Oomoogoo00000Woo00D007ooOomoo`0000Uoo`03001oogoo009oo`<000=oo`<0
009oo`@000Aoo`05001oogooOol00006Ool00`00Oomoo`08Ool00`00Oomoo`02Ool30003Ool30002
Ool40004Ool00`00Oomoo`02Ool00`00Oomoo`03Ool00`00Oomoo`08Ool00`00Oomoo`02Ool30003
Ool30002Ool40004Ool01`00Oomoogoo001oo`0000Aoo`03001oogoo00Moo`03001oogoo009oo`<0
00=oo`<0009oo`@000Aoo`05001oogooOol00006Ool00`00Oomoo`05Ool00`00Oomoo`02Ool30003
Ool30002Ool40004Ool00`00Oomoo`02Ool00`00Oomoo`02Ool01000Oomoo`000goo00D007ooOomo
o`0000Aoo`<000=oo`<0009oo`@000Aoo`03001oogoo009oo`03001oogoo009oo`04001oogoo0003
Ool00`00Oomoo`0IOol001aoo`03001oogoo00ioo`03001oogoo00Aoo`80009oo`@0009oo`8000Uo
o`03001oogoo00ioo`03001oogoo00Aoo`8000=oo`8000=oo`8000Yoo`03001oogoo00ioo`03001o
ogoo00Aoo`8000=oo`8000=oo`8000Ioo`03001oogoo00ioo`03001oogoo00Aoo`80009oo`8000Ao
o`8000Aoo`8000Moo`03001oogoo00ioo`03001oogoo00Aoo`80009oo`<000=oo`8000Yoo`03001o
ogoo00ioo`03001oogoo00Aoo`8000=oo`8000=oo`8000Uoo`03001oogoo00ioo`03001oogoo00Ao
o`80009oo`@0009oo`8000Yoo`03001oogoo00ioo`03001oogoo00Aoo`80009oo`8000Aoo`8000Yo
o`03001oogoo00ioo`03001oogoo00Aoo`8000=oo`8000=oo`8000Uoo`03001oogoo00ioo`03001o
ogoo00Aoo`8000=oo`<0009oo`8000Moo`03001oogoo00ioo`03001oogoo00Aoo`80009oo`8000Eo
o`8000=oo`8000=oo`03001oogoo00ioo`03001oogoo00Aoo`80009oo`8000Eoo`8000=oo`8001]o
o`006Woo0`0047oo0`005goo0`0047oo0`0067oo0`0047oo0`0057oo0`0047oo0`006goo0`0047oo
0`0067oo0`0047oo0`005goo0`0047oo0`0067oo0`0047oo0`0067oo0`0047oo0`005goo0`0047oo
0`005Goo0`0047oo0`005goo0`0047oo0`00<Goo003oOoooOomEOol00?mooomooeEoo`00ogooogoo
EGoo000^Ool00`00Oomoo`0ZOol00`00Oomoo`0[Ool00`00Oomoo`0ZOol00`00Oomoo`0[Ool00`00
Oomoo`0[Ool00`00Oomoo`0ZOol00`00Oomoo`0[Ool00`00Oomoo`0[Ool00`00Oomoo`0ZOol00`00
Oomoo`0[Ool00`00Oomoo`0ZOol00`00Oomoo`0]Ool002ioo`03001oogoo02Yoo`03001oogoo02]o
o`03001oogoo02Yoo`03001oogoo02]oo`03001oogoo02]oo`03001oogoo02Yoo`03001oogoo02]o
o`03001oogoo02]oo`03001oogoo02Yoo`03001oogoo02]oo`03001oogoo02Yoo`03001oogoo02eo
o`00;goo00<007ooOol0:Woo00<007ooOol0:goo00<007ooOol0:7oo00<007ooOol0;Goo00<007oo
Ool0:Goo00<007ooOol0;7oo00<007ooOol0:goo00<007ooOol0:Goo00<007ooOol0;7oo00<007oo
Ool0:goo00<007ooOol0:7oo00<007ooOol0;Woo000_Ool00`00Oomoo`0ZOol00`00Oomoo`0[Ool0
0`00Oomoo`0XOol00`00Oomoo`0]Ool00`00Oomoo`0YOol00`00Oomoo`0]Ool00`00Oomoo`0ZOol0
0`00Oomoo`0YOol00`00Oomoo`0/Ool00`00Oomoo`0[Ool00`00Oomoo`0XOol00`00Oomoo`0^Ool0
031oo`03001oogoo02Yoo`03001oogoo02]oo`03001oogoo02Ioo`03001oogoo02moo`03001oogoo
02Moo`03001oogoo02ioo`03001oogoo02]oo`03001oogoo02Moo`03001oogoo02ioo`03001oogoo
02]oo`03001oogoo02Ioo`03001oogoo02moo`00<Goo00<007ooOol0:Woo00<007ooOol0:goo00<0
07ooOol09Goo00<007ooOol0<7oo00<007ooOol09Goo00<007ooOol0<7oo00<007ooOol0:goo00<0
07ooOol09Goo00<007ooOol0<7oo00<007ooOol0:goo00<007ooOol09Goo00<007ooOol0;goo000a
Ool00`00Oomoo`0ZOol00`00Oomoo`0[Ool00`00Oomoo`0TOol00`00Oomoo`0aOol00`00Oomoo`0U
Ool00`00Oomoo`0aOol00`00Oomoo`0ZOol00`00Oomoo`0UOol00`00Oomoo`0`Ool00`00Oomoo`0[
Ool00`00Oomoo`0TOol00`00Oomoo`0`Ool0039oo`03001oogoo02Yoo`03001oogoo02]oo`03001o
ogoo029oo`03001oogoo03=oo`03001oogoo02=oo`03001oogoo03=oo`03001oogoo02Yoo`03001o
ogoo02=oo`03001oogoo039oo`03001oogoo02]oo`03001oogoo029oo`03001oogoo035oo`00<Woo
00<007ooOol0:Woo00<007ooOol0:goo00<007ooOol08Woo00<007ooOol0<goo00<007ooOol08goo
00<007ooOol0<goo00<007ooOol0:Woo00<007ooOol08goo00<007ooOol0<Woo00<007ooOol0:goo
00<007ooOol08Woo00<007ooOol0<Goo000cOol00`00Oomoo`0ZOol00`00Oomoo`0[Ool00`00Oomo
o`0POol00`00Oomoo`0eOol00`00Oomoo`0QOol00`00Oomoo`0eOol00`00Oomoo`0ZOol00`00Oomo
o`0QOol00`00Oomoo`0dOol00`00Oomoo`0[Ool00`00Oomoo`0POol00`00Oomoo`0bOol003=oo`03
001oogoo02Yoo`03001oogoo02]oo`03001oogoo021oo`03001oogoo03Eoo`03001oogoo025oo`03
001oogoo03Ioo`03001oogoo02Uoo`03001oogoo025oo`03001oogoo03Aoo`03001oogoo02]oo`03
001oogoo021oo`03001oogoo039oo`00=7oo00<007ooOol0:Woo00<007ooOol0:goo00<007ooOol0
7Woo00<007ooOol0=goo00<007ooOol07goo00<007ooOol0=goo00<007ooOol0:Woo00<007ooOol0
7goo00<007ooOol0=Woo00<007ooOol0:goo00<007ooOol07Woo00<007ooOol0<goo000dOol00`00
Oomoo`0[Ool00`00Oomoo`0[Ool00`00Oomoo`0MOol00`00Oomoo`0hOol00`00Oomoo`0MOol00`00
Oomoo`0iOol00`00Oomoo`0ZOol00`00Oomoo`0MOol00`00Oomoo`0hOol00`00Oomoo`0[Ool00`00
Oomoo`0MOol00`00Oomoo`0cOol003Eoo`03001oogoo02Yoo`03001oogoo02]oo`03001oogoo01ao
o`03001oogoo03Uoo`03001oogoo01eoo`03001oogoo03Yoo`03001oogoo02Uoo`03001oogoo01eo
o`03001oogoo03Qoo`03001oogoo02]oo`03001oogoo01aoo`03001oogoo03Aoo`00=Woo00<007oo
Ool0:Woo00<007ooOol0:goo00<007ooOol06goo00<007ooOol0>Woo00<007ooOol06goo00<007oo
Ool0>goo00<007ooOol0:Woo00<007ooOol06goo00<007ooOol0>Woo00<007ooOol0:goo00<007oo
Ool06goo00<007ooOol0=7oo000fOol00`00Oomoo`0ZOol00`00Oomoo`0[Ool00`00Oomoo`0JOol0
0`00Oomoo`0kOol00`00Oomoo`0KOol00`00Oomoo`0lOol00`00Oomoo`0YOol00`00Oomoo`0KOol0
0`00Oomoo`0jOol00`00Oomoo`0[Ool00`00Oomoo`0JOol00`00Oomoo`0eOol003Moo`03001oogoo
02Yoo`03001oogoo02]oo`03001oogoo01Qoo`03001oogoo03eoo`03001oogoo01Uoo`03001oogoo
03ioo`03001oogoo02Uoo`03001oogoo01Uoo`03001oogoo03aoo`03001oogoo02]oo`03001oogoo
01Qoo`03001oogoo03Ioo`00=goo00<007ooOol0:Woo00<007ooOol0:goo00<007ooOol067oo00<0
07ooOol0?Goo00<007ooOol06Goo00<007ooOol0?goo00<007ooOol0:7oo00<007ooOol06Goo00<0
07ooOol0?7oo00<007ooOol0:goo00<007ooOol067oo00<007ooOol0=Woo000hOol00`00Oomoo`0Z
Ool00`00Oomoo`0[Ool00`00Oomoo`0FOol00`00Oomoo`0oOol00`00Oomoo`0GOol00`00Oomoo`10
Ool00`00Oomoo`0YOol00`00Oomoo`0GOol00`00Oomoo`0nOol00`00Oomoo`0[Ool00`00Oomoo`0F
Ool00`00Oomoo`0gOol003Qoo`03001oogoo02]oo`03001oogoo02]oo`03001oogoo01Eoo`03001o
ogoo041oo`03001oogoo01Eoo`03001oogoo049oo`03001oogoo02Uoo`03001oogoo01Eoo`03001o
ogoo041oo`03001oogoo02]oo`03001oogoo01Eoo`03001oogoo03Moo`00>Goo00<007ooOol0:Woo
00<007ooOol0:goo00<007ooOol057oo00<007ooOol0@Goo00<007ooOol05Goo00<007ooOol0@goo
00<007ooOol0:7oo00<007ooOol05Goo00<007ooOol0@7oo00<007ooOol0:goo00<007ooOol057oo
00<007ooOol0>7oo000iOol00`00Oomoo`0[Ool00`00Oomoo`0[Ool00`00Oomoo`0COol00`00Oomo
o`12Ool00`00Oomoo`0COol00`00Oomoo`14Ool00`00Oomoo`0YOol00`00Oomoo`0COol00`00Oomo
o`12Ool00`00Oomoo`0[Ool00`00Oomoo`0COol00`00Oomoo`0hOol003Yoo`03001oogoo02Yoo`03
001oogoo02]oo`03001oogoo019oo`03001oogoo04=oo`03001oogoo01=oo`03001oogoo04Eoo`03
001oogoo02Qoo`03001oogoo01=oo`03001oogoo049oo`03001oogoo02]oo`03001oogoo019oo`03
001oogoo03Uoo`00>goo00<007ooOol0:Woo00<007ooOol0:goo00<007ooOol04Goo00<007ooOol0
A7oo00<007ooOol04Goo00<007ooOol0Agoo00<007ooOol0:7oo00<007ooOol04Goo00<007ooOol0
A7oo00<007ooOol0:goo00<007ooOol04Goo00<007ooOol0>Goo000kOol00`00Oomoo`0ZOol00`00
Oomoo`0/Ool00`00Oomoo`0?Ool00`00Oomoo`16Ool00`00Oomoo`0?Ool00`00Oomoo`18Ool00`00
Oomoo`0YOol00`00Oomoo`0?Ool00`00Oomoo`15Ool00`00Oomoo`0/Ool00`00Oomoo`0?Ool00`00
Oomoo`0jOol003aoo`03001oogoo02Yoo`03001oogoo02]oo`03001oogoo00moo`03001oogoo04Io
o`03001oogoo00moo`03001oogoo04Uoo`03001oogoo02Qoo`03001oogoo00moo`03001oogoo04Io
o`03001oogoo02]oo`03001oogoo00moo`03001oogoo03Yoo`00?7oo00<007ooOol0:Woo00<007oo
Ool0;7oo00<007ooOol03Goo00<007ooOol0B7oo00<007ooOol03Goo00<007ooOol0Bgoo00<007oo
Ool0:7oo00<007ooOol03Goo00<007ooOol0Agoo00<007ooOol0;7oo00<007ooOol03Goo00<007oo
Ool0>goo000mOol00`00Oomoo`0ZOol00`00Oomoo`0[Ool00`00Oomoo`0<Ool00`00Oomoo`19Ool0
0`00Oomoo`0=Ool00`00Oomoo`1<Ool00`00Oomoo`0WOol00`00Oomoo`0=Ool00`00Oomoo`18Ool0
0`00Oomoo`0[Ool00`00Oomoo`0<Ool00`00Oomoo`0lOol003eoo`03001oogoo02]oo`03001oogoo
02]oo`03001oogoo00]oo`03001oogoo04Yoo`03001oogoo00]oo`03001oogoo04eoo`03001oogoo
02Qoo`03001oogoo00]oo`03001oogoo04Yoo`03001oogoo02]oo`03001oogoo00]oo`03001oogoo
03aoo`00?Woo00<007ooOol0:Woo00<007ooOol0:goo00<007ooOol02Woo00<007ooOol0Bgoo00<0
07ooOol02goo00<007ooOol0CWoo00<007ooOol09goo00<007ooOol02goo00<007ooOol0BWoo00<0
07ooOol0:goo00<007ooOol02Woo00<007ooOol0?Goo000nOol00`00Oomoo`0[Ool00`00Oomoo`0[
Ool00`00Oomoo`09Ool00`00Oomoo`1<Ool00`00Oomoo`09Ool00`00Oomoo`1@Ool00`00Oomoo`0W
Ool00`00Oomoo`09Ool00`00Oomoo`1<Ool00`00Oomoo`0[Ool00`00Oomoo`09Ool00`00Oomoo`0m
Ool003moo`03001oogoo02Yoo`03001oogoo02aoo`03001oogoo00Moo`03001oogoo04ioo`03001o
ogoo00Moo`03001oogoo055oo`03001oogoo02Qoo`03001oogoo00Moo`03001oogoo04eoo`03001o
ogoo02aoo`03001oogoo00Moo`03001oogoo03ioo`00@7oo00<007ooOol0:Woo00<007ooOol0:goo
00<007ooOol01goo00<007ooOol0CWoo00<007ooOol01goo00<007ooOol0DWoo00<007ooOol09goo
00<007ooOol01goo00<007ooOol0CWoo00<007ooOol0:goo00<007ooOol01goo00<007ooOol0?Woo
0010Ool00`00Oomoo`0ZOol00`00Oomoo`0/Ool00`00Oomoo`05Ool00`00Oomoo`1@Ool00`00Oomo
o`05Ool00`00Oomoo`1DOol00`00Oomoo`0WOol00`00Oomoo`05Ool00`00Oomoo`1?Ool00`00Oomo
o`0/Ool00`00Oomoo`05Ool00`00Oomoo`0oOol0045oo`03001oogoo02Yoo`03001oogoo02]oo`03
001oogoo00Eoo`03001oogoo051oo`03001oogoo00Eoo`03001oogoo05Aoo`03001oogoo02Moo`03
001oogoo00Eoo`03001oogoo051oo`03001oogoo02]oo`03001oogoo00Eoo`03001oogoo03moo`00
@Goo00<007ooOol0:goo00<007ooOol0:goo00<007ooOol00goo00<007ooOol0DWoo00<007ooOol0
0goo00<007ooOol0EWoo00<007ooOol09goo00<007ooOol00goo00<007ooOol0DWoo00<007ooOol0
:goo00<007ooOol00goo00<007ooOol0@7oo0012Ool00`00Oomoo`0ZOol00`00Oomoo`0[Ool00`00
Oomoo`02Ool00`00Oomoo`1COol00`00Oomoo`03Ool00`00Oomoo`1GOol00`00Oomoo`0VOol00`00
Oomoo`03Ool00`00Oomoo`1BOol00`00Oomoo`0[Ool00`00Oomoo`02Ool00`00Oomoo`11Ool0049o
o`03001oogoo02]oo`03001oogoo02]oo`05001oogooOol0001FOol01@00Oomoogoo0000Fgoo00<0
07ooOol09Woo00D007ooOomoo`0005Ioo`03001oogoo02]oo`05001oogooOol00013Ool004=oo`03
001oogoo02Yoo`03001oogoo02aoo`03001oo`0005Qoo`03001oo`0005aoo`03001oogoo02Moo`03
001oo`0005Moo`03001oogoo02aoo`03001oo`0004Aoo`00@goo00<007ooOol0:goo00<007ooOol0
:goo00<007oo0000F7oo00<007oo0000GGoo00<007ooOol09Woo00<007oo0000F7oo00<007ooOol0
:goo00<007oo0000A7oo0014Ool00`00Oomoo`0ZOol00`00Oomoo`0/Ool00`00Oomoo`1HOol00`00
Oomoo`1MOol00`00Oomoo`0VOol00`00Oomoo`1GOol00`00Oomoo`0/Ool00`00Oomoo`13Ool004Eo
o`03001oogoo02Yoo`03001oogoo02]oo`03001oogoo05Qoo`03001oogoo05eoo`03001oogoo02Io
o`03001oogoo05Qoo`03001oogoo02]oo`03001oogoo04=oo`00AGoo00<007ooOol0:goo00<007oo
Ool0:Goo00<007ooOol0FWoo00<007ooOol0GGoo00<007ooOol09Woo00<007ooOol0F7oo00<007oo
Ool0:Goo00<007ooOol0A7oo0016Ool00`00Oomoo`0ZOol00`00Oomoo`0YOol00`00Oomoo`1KOol0
0`00Oomoo`1MOol00`00Oomoo`0VOol00`00Oomoo`1GOol00`00Oomoo`0YOol00`00Oomoo`14Ool0
04Ioo`03001oogoo02]oo`03001oogoo02Moo`03001oogoo05eoo`03001oogoo05aoo`03001oogoo
02Moo`03001oogoo05Moo`03001oogoo02Moo`03001oogoo04Eoo`00Agoo00<007ooOol0:Woo00<0
07ooOol09Woo00<007ooOol0Ggoo00<007ooOol0G7oo00<007ooOol09goo00<007ooOol0EWoo00<0
07ooOol09Woo00<007ooOol0AWoo0017Ool00`00Oomoo`0[Ool00`00Oomoo`0UOol00`00Oomoo`1P
Ool00`00Oomoo`1LOol00`00Oomoo`0WOol00`00Oomoo`1FOol00`00Oomoo`0UOol00`00Oomoo`16
Ool004Qoo`03001oogoo02Yoo`03001oogoo01ioo`03001oogoo00=oo`03001oogoo055oo`@000ao
o`03001oogoo05eoo`03001oogoo01Moo`<000aoo`03001oogoo05Ioo`03001oogoo01aoo`<000Eo
o`03001oogoo04Moo`00B7oo00<007ooOol0:goo00<007ooOol07Goo00<007ooOol00goo00<007oo
Ool0DWoo00<007ooOol03Goo00<007ooOol0G7oo00<007ooOol067oo00<007ooOol037oo00<007oo
Ool0EWoo00<007ooOol077oo00<007ooOol017oo00<007ooOol0Agoo0019Ool00`00Oomoo`0[Ool0
0`00Oomoo`0MOol01@00Oomoogoo0000EWoo00<007ooOol03Goo00<007ooOol0G7oo00<007ooOol0
5Goo10003Woo00<007ooOol0EWoo00<007ooOol06goo00<007ooOol00goo00<007ooOol0B7oo001:
Ool00`00Oomoo`0ZOol00`00Oomoo`0MOol01@00Oomoogoo0000Egoo00<007ooOol03Goo00<007oo
Ool0G7oo00<007ooOol057oo00<007oo000047oo00<007ooOol0EGoo00<007ooOol06goo00<007oo
Ool00goo00<007ooOol0B7oo001:Ool00`00Oomoo`0[Ool00`00Oomoo`0MOol00`00Ool0001EOol0
1000Oomoo`0047oo00<007ooOol0Fgoo00<007ooOol057oo00<007oo00004Goo00<007ooOol0EGoo
00<007ooOol06Woo00<007ooOol00Woo00<007ooOol0BGoo001;Ool00`00Oomoo`0ZOol00`00Oomo
o`0JOol400000goo001oo`1EOol2000BOol00`00Oomoo`1KOol00`00Oomoo`0DOol2000BOol00`00
Oomoo`1DOol00`00Oomoo`0IOol20004Ool00`00Oomoo`19Ool004]oo`03001oogoo02]oo`03001o
ogoo01eoo`03001oogoo06Yoo`03001oogoo05]oo`03001oogoo02Moo`03001oogoo05Eoo`03001o
ogoo01eoo`03001oogoo04Yoo`00C7oo00<007ooOol0:Woo00<007ooOol077oo00<007ooOol0Jgoo
00<007ooOol0Fgoo00<007ooOol0:7oo00<007ooOol0E7oo00<007ooOol077oo00<007ooOol0Bgoo
001<Ool00`00Oomoo`0[Ool00`00Oomoo`0KOol00`00Oomoo`1/Ool00`00Oomoo`1KOol00`00Oomo
o`0XOol00`00Oomoo`1DOol00`00Oomoo`0KOol00`00Oomoo`1;Ool004eoo`03001oogoo02]oo`03
001oogoo01Uoo`03001oogoo06ioo`03001oogoo05]oo`03001oogoo02Qoo`03001oogoo05Aoo`03
001oogoo01Uoo`03001oogoo04aoo`00CGoo00<007ooOol0:goo00<007ooOol06Goo00<007ooOol0
Kgoo00<007ooOol0Fgoo00<007ooOol0:7oo00<007ooOol0Dgoo00<007ooOol06Goo00<007ooOol0
C7oo001>Ool00`00Oomoo`0[Ool00`00Oomoo`0GOol00`00Oomoo`1aOol00`00Oomoo`1JOol00`00
Oomoo`0YOol00`00Oomoo`1COol00`00Oomoo`0GOol00`00Oomoo`1=Ool004moo`03001oogoo02Yo
o`03001oogoo01Moo`03001oogoo079oo`03001oogoo05Yoo`03001oogoo02Qoo`03001oogoo05=o
o`03001oogoo01Moo`03001oogoo04eoo`00Cgoo00<007ooOol0:goo00<007ooOol05Goo00<007oo
Ool0Lgoo00<007ooOol0Fgoo00<007ooOol0:7oo00<007ooOol0Dgoo00<007ooOol05Goo00<007oo
Ool0CWoo001@Ool00`00Oomoo`0ZOol00`00Oomoo`0DOol00`00Oomoo`1eOol00`00Oomoo`1JOol0
0`00Oomoo`0YOol00`00Oomoo`1BOol00`00Oomoo`0DOol00`00Oomoo`1?Ool0051oo`03001oogoo
02]oo`03001oogoo01=oo`03001oogoo07Ioo`03001oogoo05Yoo`03001oogoo02Uoo`03001oogoo
059oo`03001oogoo01=oo`03001oogoo04moo`00DGoo00<007ooOol0:Woo00<007ooOol04Woo00<0
07ooOol0N7oo00<007ooOol0FWoo00<007ooOol0:Goo00<007ooOol0DGoo00<007ooOol04Woo00<0
07ooOol0D7oo001AOol00`00Oomoo`0[Ool00`00Oomoo`0AOol00`00Oomoo`1iOol00`00Oomoo`1I
Ool00`00Oomoo`0YOol00`00Oomoo`1BOol00`00Oomoo`0AOol00`00Oomoo`1@Ool0059oo`03001o
ogoo02]oo`03001oogoo00moo`03001oogoo07]oo`03001oogoo05Uoo`03001oogoo02Uoo`03001o
ogoo059oo`03001oogoo00moo`03001oogoo055oo`00Dgoo00<007ooOol0:Woo00<007ooOol03goo
00<007ooOol0Ngoo00<007ooOol0FWoo00<007ooOol0:Goo00<007ooOol0DGoo00<007ooOol03goo
00<007ooOol0DGoo001COol00`00Oomoo`0[Ool00`00Oomoo`0=Ool00`00Oomoo`1mOol00`00Oomo
o`1JOol00`00Oomoo`0YOol00`00Oomoo`1AOol00`00Oomoo`0=Ool00`00Oomoo`1BOol005Aoo`03
001oogoo02Yoo`03001oogoo00eoo`03001oogoo07ioo`03001oogoo05Uoo`03001oogoo02Yoo`03
001oogoo051oo`03001oogoo00eoo`03001oogoo059oo`00E7oo00<007ooOol0:goo00<007ooOol0
2goo00<007ooOol0P7oo00<007ooOol0FGoo00<007ooOol0:Woo00<007ooOol0D7oo00<007ooOol0
2goo00<007ooOol0Dgoo001EOol00`00Oomoo`0ZOol00`00Oomoo`0:Ool00`00Oomoo`22Ool00`00
Oomoo`1IOol00`00Oomoo`0YOol00`00Oomoo`1@Ool00`00Oomoo`0:Ool00`00Oomoo`1DOol005Eo
o`03001oogoo02]oo`03001oogoo00Uoo`03001oogoo08=oo`03001oogoo05Qoo`03001oogoo02Yo
o`03001oogoo051oo`03001oogoo00Uoo`03001oogoo05Aoo`00EWoo00<007ooOol0:goo00<007oo
Ool01goo00<007ooOol0Q7oo00<007ooOol0FGoo00<007ooOol0:Woo00<007ooOol0D7oo00<007oo
Ool01goo00<007ooOol0EGoo001FOol00`00Oomoo`0[Ool00`00Oomoo`07Ool00`00Oomoo`25Ool0
0`00Oomoo`1IOol00`00Oomoo`0ZOol00`00Oomoo`1?Ool00`00Oomoo`07Ool00`00Oomoo`1EOol0
05Moo`03001oogoo02]oo`03001oogoo00Eoo`03001oogoo08Moo`03001oogoo05Qoo`03001oogoo
02]oo`03001oogoo04moo`03001oogoo00Eoo`03001oogoo05Ioo`00F7oo00<007ooOol0:Woo00<0
07ooOol01Goo00<007ooOol0R7oo00<007ooOol0F7oo00<007ooOol0:goo00<007ooOol0CWoo00<0
07ooOol01Goo00<007ooOol0EWoo001HOol00`00Oomoo`0[Ool00`00Oomoo`03Ool00`00Oomoo`2:
Ool00`00Oomoo`1HOol00`00Oomoo`0ZOol00`00Oomoo`1?Ool00`00Oomoo`03Ool00`00Oomoo`1G
Ool005Uoo`03001oogoo02Yoo`03001oogoo00=oo`03001oogoo08]oo`03001oogoo05Qoo`03001o
ogoo02Yoo`03001oogoo04ioo`03001oogoo00=oo`03001oogoo05Moo`00FGoo00<007ooOol0:goo
00D007ooOomoo`0008moo`03001oogoo05Moo`03001oogoo02]oo`03001oogoo04ioo`05001oogoo
Ool0001JOol005Yoo`03001oogoo02]oo`03001oo`00091oo`03001oogoo05Qoo`03001oogoo02]o
o`03001oogoo04ioo`03001oo`0005]oo`00FWoo00<007ooOol0:goo00<007oo0000TGoo00<007oo
Ool0F7oo00<007ooOol0:goo00<007ooOol0CGoo00<007oo0000Fgoo001KOol00`00Oomoo`0[Ool0
0`00Oomoo`2AOol00`00Oomoo`1GOol00`00Oomoo`0/Ool00`00Oomoo`1<Ool2001LOol005]oo`03
001oogoo02]oo`03001oogoo099oo`03001oogoo05Moo`03001oogoo02]oo`03001oogoo04]oo`03
001oogoo05aoo`00G7oo00<007ooOol0:Goo00<007ooOol0U7oo00<007ooOol0Egoo00<007ooOol0
:goo00<007ooOol0BGoo00<007ooOol0GGoo001MOol00`00Oomoo`0XOol00`00Oomoo`2EOol00`00
Oomoo`1FOol00`00Oomoo`0/Ool00`00Oomoo`17Ool00`00Oomoo`1NOol005eoo`03001oogoo02Mo
o`03001oogoo09Ioo`03001oogoo05Moo`03001oogoo02aoo`03001oogoo04Eoo`03001oogoo05mo
o`00GWoo00<007ooOol09Goo00<007ooOol0V7oo00<007ooOol0Egoo00<007ooOol0;7oo00<007oo
Ool0@goo00<007ooOol0H7oo001NOol00`00Oomoo`0NOol20005Ool00`00Oomoo`2IOol00`00Oomo
o`1FOol00`00Oomoo`0]Ool00`00Oomoo`0mOol300000goo001oo`1ROol005moo`03001oogoo01ao
o`04001oogoo0003Ool00`00Oomoo`2KOol00`00Oomoo`1FOol00`00Oomoo`0/Ool00`00Oomoo`10
Ool00`00Oomoo`1ROol005moo`03001oogoo01aoo`04001oogoo0003Ool00`00Oomoo`2LOol00`00
Oomoo`1FOol00`00Oomoo`0/Ool00`00Oomoo`0mOol3001TOol0061oo`03001oogoo01aoo`8000=o
o`03001oogoo09ioo`03001oogoo05Ioo`03001oogoo02aoo`03001oogoo03]oo`<006Eoo`00H7oo
00<007ooOol06goo00@007ooOol0009oo`03001oogoo09ioo`03001oogoo05Ioo`03001oogoo02eo
o`03001oogoo03Uoo`05001oogooOol0001TOol0065oo`03001oogoo01]oo`80009oo`03001oogoo
0:1oo`03001oogoo05Ioo`03001oogoo02eoo`03001oogoo03Moo`03001oo`00008006Eoo`00HWoo
00<007ooOol07Woo00<007ooOol0XGoo00<007ooOol0EWoo00<007ooOol0;Goo00<007ooOol0=Goo
00<007ooOol0J7oo001ROol00`00Oomoo`0MOol00`00Oomoo`2SOol00`00Oomoo`1EOol00`00Oomo
o`0]Ool00`00Oomoo`0dOol00`00Oomoo`1YOol006=oo`03001oogoo01]oo`03001oogoo0:Eoo`03
001oogoo05Eoo`03001oogoo02eoo`03001oogoo039oo`03001oogoo06Yoo`00Hgoo00<007ooOol0
6goo00<007ooOol0YWoo00<007ooOol0EGoo00<007ooOol0;Goo00<007ooOol0<7oo00<007ooOol0
Jgoo001TOol00`00Oomoo`0IOol00`00Oomoo`2WOol00`00Oomoo`1EOol00`00Oomoo`0^Ool00`00
Oomoo`0]Ool2001^Ool006Aoo`03001oogoo01Uoo`03001oogoo0:Qoo`03001oogoo05Eoo`03001o
ogoo02ioo`03001oogoo02]oo`03001oogoo06ioo`00IGoo00<007ooOol05goo00<007ooOol0ZWoo
00<007ooOol0EGoo00<007ooOol0;Woo00<007ooOol0:Goo00<007ooOol0Kgoo001UOol00`00Oomo
o`0GOol00`00Oomoo`2[Ool00`00Oomoo`1EOol00`00Oomoo`0]Ool00`00Oomoo`0XOol00`00Oomo
o`1`Ool006Ioo`03001oogoo01Eoo`03001oogoo0:eoo`03001oogoo05Aoo`03001oogoo02ioo`03
001oogoo02Ioo`03001oogoo075oo`00Igoo00<007ooOol04goo00<007ooOol0[goo00<007ooOol0
E7oo00<007ooOol0;Woo00<007ooOol097oo00<007ooOol0LWoo001WOol00`00Oomoo`0COol00`00
Oomoo`2`Ool00`00Oomoo`1DOol00`00Oomoo`0^Ool00`00Oomoo`0ROol00`00Oomoo`1cOol006Qo
o`03001oogoo015oo`03001oogoo0;5oo`03001oogoo05Aoo`03001oogoo02moo`03001oogoo021o
o`03001oogoo07Aoo`00J7oo00<007ooOol04Goo00<007ooOol0/Woo00<007ooOol0E7oo00<007oo
Ool0;Woo00<007ooOol07goo00<007ooOol0MGoo001YOol00`00Oomoo`0?Ool00`00Oomoo`2dOol0
0`00Oomoo`1DOol00`00Oomoo`0^Ool00`00Oomoo`0LOol2001hOol006Uoo`03001oogoo00moo`03
001oogoo0;Eoo`03001oogoo05=oo`03001oogoo02moo`03001oogoo01Yoo`03001oogoo07Qoo`00
JWoo00<007ooOol03Goo00<007ooOol0]goo00<007ooOol0Dgoo00<007ooOol0;goo00<007ooOol0
67oo00<007ooOol0NGoo001ZOol00`00Oomoo`0=Ool00`00Oomoo`2hOol00`00Oomoo`1COol00`00
Oomoo`0_Ool00`00Oomoo`0FOol00`00Oomoo`1jOol006]oo`03001oogoo00]oo`03001oogoo0;Uo
o`03001oogoo05Aoo`03001oogoo02moo`03001oogoo01Aoo`03001oogoo07]oo`00K7oo00<007oo
Ool02Goo00<007ooOol0^goo00<007ooOol0Dgoo00<007ooOol0;goo00<007ooOol04goo00<007oo
Ool0O7oo001/Ool00`00Oomoo`09Ool00`00Oomoo`2lOol00`00Oomoo`1COol00`00Oomoo`0_Ool0
0`00Oomoo`0AOol00`00Oomoo`1mOol006eoo`03001oogoo00Moo`03001oogoo0;ioo`03001oogoo
05=oo`03001oogoo02moo`03001oogoo00moo`03001oogoo07ioo`00KGoo00<007ooOol01goo00<0
07ooOol0_goo00<007ooOol0DWoo00<007ooOol0<7oo00<007ooOol037oo0P00PGoo001^Ool00`00
Oomoo`05Ool00`00Oomoo`31Ool00`00Oomoo`1BOol00`00Oomoo`0`Ool00`00Oomoo`0:Ool00`00
Oomoo`21Ool006ioo`03001oogoo00Eoo`03001oogoo0<5oo`03001oogoo05=oo`03001oogoo031o
o`03001oogoo00Qoo`03001oogoo089oo`00Kgoo00<007ooOol00goo00<007ooOol0`goo00<007oo
Ool0DWoo00<007ooOol0<7oo00<007ooOol01goo00<007ooOol0Pgoo001_Ool00`00Oomoo`03Ool0
0`00Oomoo`34Ool00`00Oomoo`1BOol00`00Oomoo`0`Ool00`00Oomoo`05Ool00`00Oomoo`24Ool0
071oo`05001oogooOol00038Ool00`00Oomoo`1BOol00`00Oomoo`0`Ool00`00Oomoo`03Ool00`00
Oomoo`25Ool0075oo`03001oo`000<Yoo`03001oogoo059oo`03001oogoo031oo`05001oogooOol0
0028Ool0075oo`03001oo`000<]oo`03001oogoo055oo`03001oogoo035oo`03001oo`0008Uoo`00
LWoo0P00c7oo00<007ooOol0DGoo00<007ooOol0<Goo00<007ooOol0R7oo001dOol00`00Oomoo`39
Ool00`00Oomoo`1BOol00`00Oomoo`0`Ool00`00Oomoo`28Ool007Eoo`800<Yoo`03001oogoo055o
o`03001oogoo02moo`03001oogoo08Uoo`00Mgoo00<007ooOol0b7oo00<007ooOol0DGoo00<007oo
Ool0;Woo00<007ooOol0RGoo001hOol20039Ool00`00Oomoo`1AOol00`00Oomoo`0/Ool00`00Oomo
o`2:Ool007Yoo`03001oogoo0<Moo`03001oogoo051oo`03001oogoo02]oo`03001oogoo08]oo`00
Igoo0`004Goo0P00b7oo00<007ooOol0D7oo00<007ooOol08Woo0`001Goo00<007ooOol0Rgoo001Z
Ool00`00Oomoo`0@Ool00`00Oomoo`35Ool00`00Oomoo`1AOol00`00Oomoo`0TOol01@00Oomoogoo
0000SWoo001XOol3000COol20036Ool00`00Oomoo`1AOol00`00Oomoo`0SOol01@00Oomoogoo0000
SWoo001WOol01000Oomoo`005Goo00<007ooOol0a7oo00<007ooOol0D7oo00<007ooOol087oo0`00
0goo00<007ooOol0SGoo001WOol01000Oomoo`005Woo0P00aGoo00<007ooOol0D7oo00<007ooOol0
7goo00<007ooOol00goo00<007ooOol0SGoo001XOol2000IOol00`00Oomoo`33Ool00`00Oomoo`1@
Ool00`00Oomoo`0NOol400000goo001oo`2?Ool008Aoo`800<Aoo`03001oogoo04moo`03001oogoo
02=oo`03001oogoo08ioo`00QWoo00<007ooOol0`Goo00<007ooOol0D7oo00<007ooOol08Goo00<0
07ooOol0Sgoo0027Ool20032Ool00`00Oomoo`1@Ool00`00Oomoo`0OOol00`00Oomoo`2@Ool008Uo
o`03001oogoo0<1oo`03001oogoo04moo`03001oogoo01moo`03001oogoo091oo`00RWoo0P00`Goo
00<007ooOol0Cgoo00<007ooOol07Goo00<007ooOol0TGoo002<Ool00`00Oomoo`2oOol00`00Oomo
o`1?Ool00`00Oomoo`0LOol00`00Oomoo`2AOol008eoo`800<1oo`03001oogoo04moo`03001oogoo
01Yoo`03001oogoo099oo`00Sgoo00<007ooOol0_Goo00<007ooOol0Cgoo00<007ooOol06Woo00<0
07ooOol0TWoo002@Ool2002nOol00`00Oomoo`1?Ool00`00Oomoo`0HOol00`00Oomoo`2COol0099o
o`03001oogoo0;aoo`03001oogoo04moo`03001oogoo01Ioo`03001oogoo09Aoo`00Tgoo0P00_Goo
00<007ooOol0CWoo00<007ooOol05Woo00<007ooOol0U7oo002EOol00`00Oomoo`2kOol00`00Oomo
o`1>Ool00`00Oomoo`0DOol00`00Oomoo`2EOol009Ioo`800;aoo`03001oogoo04ioo`03001oogoo
01=oo`03001oogoo09Eoo`00V7oo00<007ooOol0^Woo00<007ooOol0CGoo00<007ooOol04Woo00<0
07ooOol0UWoo002IOol2002jOol00`00Oomoo`1>Ool00`00Oomoo`0AOol00`00Oomoo`2FOol009]o
o`03001oogoo0;Qoo`03001oogoo04ioo`03001oogoo00moo`03001oogoo09Moo`00W7oo0P00^Goo
00<007ooOol0CWoo00<007ooOol03Woo00<007ooOol0Ugoo002NOol00`00Oomoo`2gOol00`00Oomo
o`1=Ool00`00Oomoo`0=Ool00`00Oomoo`2HOol009moo`800;Qoo`03001oogoo04eoo`03001oogoo
00]oo`03001oogoo09Uoo`00XGoo00<007ooOol0]Woo00<007ooOol0CGoo00<007ooOol02Woo00<0
07ooOol0VGoo002ROol2002fOol00`00Oomoo`1=Ool00`00Oomoo`09Ool00`00Oomoo`2JOol00:Ao
o`03001oogoo0;Aoo`03001oogoo04eoo`03001oogoo00Qoo`03001oogoo09Yoo`00YGoo0P00]Goo
00<007ooOol0CGoo00<007ooOol01Woo00<007ooOol0Vgoo002WOol00`00Oomoo`2cOol00`00Oomo
o`1<Ool00`00Oomoo`06Ool00`00Oomoo`2KOol00:Qoo`800;Aoo`03001oogoo04aoo`03001oogoo
00Aoo`03001oogoo09aoo`00ZWoo00<007ooOol0/Woo00<007ooOol0C7oo00<007ooOol00goo00<0
07ooOol0W7oo002[Ool2002bOol00`00Oomoo`1=Ool01@00Oomoogoo0000Wgoo002]Ool00`00Oomo
o`2`Ool00`00Oomoo`1<Ool01000Oomoo`00X7oo002^Ool2002aOol00`00Oomoo`1<Ool00`00Ool0
002POol00;1oo`03001oogoo0:moo`03001oogoo04]oo`800:5oo`00/Goo0P00/7oo00<007ooOol0
BGoo00<007ooOol0XGoo002cOol00`00Oomoo`2^Ool00`00Oomoo`17Ool00`00Oomoo`2ROol00;Ao
o`800:ioo`03001oogoo04Ioo`03001oogoo0:=oo`00]Woo00<007ooOol0[7oo00<007ooOol0A7oo
00<007ooOol0Y7oo002gOol2002]Ool00`00Oomoo`12Ool00`00Oomoo`2UOol00;Uoo`03001oogoo
0:]oo`03001oogoo03eoo`800003Ool007oo0:Moo`00^Woo0P00[7oo00<007ooOol0>goo00@007oo
Ool00:Uoo`00_7oo00<007ooOol0ZWoo00<007ooOol0>Woo1000ZGoo002mOol2002[Ool00`00Oomo
o`0iOol3002ZOol00;moo`03001oogoo0:Qoo`03001oogoo03Qoo`800:aoo`00`7oo0P00ZGoo00<0
07ooOol0=Woo00<007ooOol00`00ZGoo0032Ool00`00Oomoo`2WOol00`00Oomoo`0dOol00`00Oomo
o`2]Ool00<=oo`800:Qoo`03001oogoo039oo`03001oogoo0:ioo`00aGoo00<007ooOol0YWoo00<0
07ooOol0<7oo00<007ooOol0[goo0036Ool2002WOol00`00Oomoo`0^Ool00`00Oomoo`2`Ool00<Qo
o`03001oogoo0:Aoo`03001oogoo02aoo`800;=oo`00bGoo0P00YGoo00<007ooOol0:Woo00<007oo
Ool0/goo003;Ool00`00Oomoo`2SOol00`00Oomoo`0XOol00`00Oomoo`2dOol00<aoo`800:Aoo`03
001oogoo02Ioo`03001oogoo0;Eoo`00cWoo00<007ooOol0XWoo00<007ooOol097oo00<007ooOol0
]Woo003?Ool2002SOol00`00Oomoo`0ROol00`00Oomoo`2gOol00=5oo`03001oogoo0:1oo`03001o
ogoo025oo`03001oogoo0;Qoo`00dWoo0P00XGoo00<007ooOol07goo00<007ooOol0^Goo003DOol0
0`00Oomoo`2OOol00`00Oomoo`0LOol2002lOol00=Eoo`800:1oo`03001oogoo01Yoo`03001oogoo
0;aoo`00egoo00<007ooOol0WWoo00<007ooOol067oo00<007ooOol0_Goo003HOol2002OOol00`00
Oomoo`0FOol00`00Oomoo`2nOol00=Yoo`03001oogoo09aoo`03001oogoo01Eoo`03001oogoo0;mo
o`00fgoo0P00WGoo00<007ooOol04goo00<007ooOol0`7oo003MOol00`00Oomoo`2KOol00`00Oomo
o`0AOol00`00Oomoo`31Ool00=ioo`8009aoo`03001oogoo00moo`03001oogoo0<9oo`00h7oo00<0
07ooOol0VWoo00<007ooOol037oo0P00aGoo003QOol2002KOol00`00Oomoo`0:Ool00`00Oomoo`35
Ool00>=oo`03001oogoo09Uoo`03001oogoo00Qoo`03001oogoo0<Ioo`00i7oo0P00VGoo00<007oo
Ool01goo00<007ooOol0agoo003VOol00`00Oomoo`2GOol00`00Oomoo`05Ool00`00Oomoo`38Ool0
0>Moo`8009Qoo`03001oogoo00=oo`03001oogoo0<Uoo`00jGoo00<007ooOol0UWoo00D007ooOomo
o`000<aoo`00jWoo0P00Ugoo00<007oo0000cGoo003/Ool00`00Oomoo`2DOol2003>Ool00>eoo`80
099oo`800=1oo`00kgoo00<007ooOol0S7oo0`00dWoo003`Ool2002:Ool2003EOol00?9oo`03001o
ogoo08Eoo`800=Moo`00lgoo0P00Pgoo0P00fGoo003eOol00`00Oomoo`1nOol30004Ool2003DOol0
0?Ioo`8007]oo`<00003Ool007oo00=oo`04001oogoo003COol00?Qoo`03001oogoo07Ioo`8000Ao
o`03001oogoo009oo`04001oogoo003COol00?Uoo`8007Aoo`8000Ioo`03001oogoo009oo`04001o
ogoo003COol00?]oo`03001oogoo06moo`8000Qoo`03001oogoo009oo`04001oogoo003COol00?ao
o`8006aoo`<000Uoo`8000Eoo`800=Aoo`00oWoo00<007ooOol0Igoo0P00jGoo003oOol2001UOol2
003[Ool00?moo`9oo`03001oogoo061oo`800>eoo`00ogoo0goo0P00GWoo0P00kgoo003oOol5Ool0
0`00Oomoo`1HOol3003aOol00?moo`Ioo`8005Ioo`800?Aoo`00ogoo27oo00<007ooOol0DGoo0P00
mWoo003oOol9Ool2001?Ool2003hOol00?moo`]oo`03001oogoo04Uoo`<00?Yoo`00ogoo37oo0P00
Agoo0P00oGoo003oOol>Ool00`00Oomoo`12Ool2003oOol00?moo`moo`80041oo`800?moo`9oo`00
ogoo4Goo00<007ooOol0>goo0P00ogoo17oo003oOolBOol2000hOol3003oOol6Ool00?mooaAoo`03
001oogoo03=oo`800?moo`Uoo`00ogoo5Goo0P00<Goo0P00ogoo2goo003oOolGOol00`00Oomoo`0/
Ool2003oOol=Ool00?mooaQoo`8002Yoo`800?moo`moo`00ogoo6Woo00<007ooOol097oo0`00ogoo
4Goo003oOolKOol2000ROol2003oOolDOol00?mooaeoo`03001oogoo01eoo`800?mooaIoo`00ogoo
7Woo0P006goo0P00ogoo67oo003oOolPOol00`00Oomoo`0EOol3003oOolJOol00?moob5oo`8001=o
o`800?mooaeoo`00ogoo8goo00<007ooOol03Woo0P00ogoo7goo003oOolTOol2000<Ool2003oOolQ
Ool00?moobIoo`03001oogoo00Moo`800?moob=oo`00ogoo9goo0P0017oo0`00ogoo9Goo003oOolY
Ool01000Ool00000ogoo:7oo003oOolZOol00`00Oomoo`3oOolXOol00?moobYoo`03001oogoo0?mo
obQoo`00ogoo:Woo00<007ooOol0ogoo:7oo003oOolZOol00`00Oomoo`3oOolXOol00?moobYoo`03
001oogoo0?moobQoo`00ogoo:Woo00<007ooOol0ogoo:7oo003oOolKOol30003Ool30006Ool00`00
Oomoo`3oOolXOol00?mooaaoo`03001oogoo00=oo`03001oogoo00Eoo`03001oogoo0?moobQoo`00
ogoo77oo00<007ooOol00goo00<007ooOol01Goo00<007ooOol0ogoo:7oo003oOolLOol00`00Oomo
o`03Ool00`00Oomoo`05Ool00`00Oomoo`3oOolXOol00?mooaaoo`03001oogoo00=oo`03001oogoo
00Eoo`03001oogoo0?moobQoo`00ogoo6goo0P0017oo0P001goo00<007ooOol0ogoo:7oo003oOolZ
Ool00`00Oomoo`3oOolXOol00?moobYoo`03001oogoo0?moobQoo`00ogoo:Woo00<007ooOol0ogoo
:7oo003oOolZOol00`00Oomoo`3oOolXOol00?moobYoo`03001oogoo0?moobQoo`00ogoo:Woo00<0
07ooOol0ogoo:7oo003oOolZOol00`00Oomoo`3oOolXOol00?moobYoo`03001oogoo0?moobQoo`00
ogoo:Woo00<007ooOol0ogoo:7oo003oOolZOol00`00Oomoo`3oOolXOol00?moobYoo`03001oogoo
0?moobQoo`00ogoo:Woo00<007ooOol0ogoo:7oo003oOolZOol00`00Oomoo`3oOolXOol00?moobYo
o`03001oogoo0?moobQoo`00ogoo:Woo00<007ooOol0ogoo:7oo003oOolZOol00`00Oomoo`3oOolX
Ool00?moobYoo`03001oogoo0?moobQoo`00ogoo:Woo00<007ooOol0ogoo:7oo003oOolZOol00`00
Oomoo`3oOolXOol00?moobYoo`03001oogoo0?moobQoo`00ogoo:Woo00<007ooOol0ogoo:7oo003o
OolZOol00`00Oomoo`3oOolXOol00?moobYoo`03001oogoo0?moobQoo`00ogoo:Woo00<007ooOol0
ogoo:7oo003oOolZOol00`00Oomoo`3oOolXOol00?moobYoo`03001oogoo0?moobQoo`00ogoo:Woo
00<007ooOol0ogoo:7oo003oOolZOol00`00Oomoo`3oOolXOol00?moobYoo`03001oogoo0?moobQo
o`00ogoo:Woo00<007ooOol0ogoo:7oo003oOoooOomEOol00?mooomooeEoo`00ogooogooEGoo003o
OoooOomEOol00?mooomooeEoo`00ogoo6goo0`000goo1000ogoo<7oo003oOolLOol00`00Oomoo`03
Ool00`00Oomoo`3oOol`Ool00?mooaaoo`03001oogoo00Aoo`03001oogoo0?moobmoo`00ogoo77oo
00<007ooOol01Goo00<007ooOol0ogoo;Woo003oOolLOol00`00Oomoo`02Ool01000Oomoo`00ogoo
<7oo003oOolKOol20005Ool2003oOolaOol00?mooomooeEoo`00ogooogooEGoo003oOoooOomEOol0
0?mooomooeEoo`00ogooogooEGoo003oOoooOomEOol00?mooomooeEoo`00ogooogooEGoo003oOooo
OomEOol00?mooomooeEoo`00ogooogooEGoo003oOoooOomEOol00?mooomooeEoo`00ogooogooEGoo
003oOoooOomEOol00?mooomooeEoo`00ogooogooEGoo003oOoooOomEOol00?mooomooeEoo`00ogoo
ogooEGoo003oOoooOomEOol00?mooomooeEoo`00ogooogooEGoo003oOoooOomEOol00?mooomooeEo
o`00ogooogooEGoo003oOoooOomEOol00?mooomooeEoo`00ogooogooEGoo0000\
\>"],
  ImageRangeCache->{{{0, 594}, {366.562, 0}} -> {-1.00977, -1.00004, 
  0.0219184, 0.0245525}}]
}, Closed]],

Cell["There are 20 mutations:", "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(NumberOfMutations[g, #]&\)/@
      CollapseGenealogy[g, Nested \[Rule] False]\)], "Input",
  CellLabel->"In[10]:="],

Cell[BoxData[
    \({2, 1, 0, 2, 0, 0, 4, 0, 2, 4, 0, 0, 1, 0, 0, 1, 0, 0, 0, 1, 1, 1, 0, 0}
      \)], "Output",
  CellLabel->"Out[10]="]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    \(S = GenealogyToMatrix[g]; S // MatrixForm\)], "Input",
  CellLabel->"In[6]:="],

Cell[BoxData[
    TagBox[
      RowBox[{"(", GridBox[{
            {"1", "1", "1", "1", "0", "1", "1", "0", "0", "0", "0", "0", "0", 
              "0", "0", "0", "0", "0", "0", "0"},
            {"1", "1", "1", "1", "0", "0", "0", "0", "0", "0", "0", "0", "1", 
              "0", "0", "0", "0", "0", "0", "0"},
            {"1", "1", "1", "1", "0", "0", "0", "0", "0", "0", "0", "0", "0", 
              "0", "0", "0", "0", "0", "0", "0"},
            {"1", "1", "1", "1", "0", "0", "0", "0", "0", "0", "0", "0", "0", 
              "0", "0", "0", "1", "1", "0", "0"},
            {"0", "0", "0", "0", "1", "0", "0", "1", "1", "1", "1", "0", "0", 
              "0", "0", "0", "0", "0", "0", "0"},
            {"0", "0", "0", "0", "1", "0", "0", "1", "1", "1", "1", "0", "0", 
              "1", "1", "0", "0", "0", "0", "0"},
            {"0", "0", "0", "0", "1", "0", "0", "0", "0", "0", "0", "1", "0", 
              "0", "0", "0", "0", "0", "0", "0"},
            {"0", "0", "0", "0", "1", "0", "0", "0", "0", "0", "0", "1", "0", 
              "0", "0", "1", "0", "0", "0", "0"},
            {"0", "0", "0", "0", "1", "0", "0", "0", "0", "0", "0", "1", "0", 
              "0", "0", "1", "0", "0", "1", "0"},
            {"0", "0", "0", "0", "1", "0", "0", "0", "0", "0", "0", "1", "0", 
              "0", "0", "1", "0", "0", "0", "0"},
            {"0", "0", "0", "0", "1", "0", "0", "0", "0", "0", "0", "1", "0", 
              "0", "0", "1", "0", "0", "0", "1"},
            {"0", "0", "0", "0", "1", "0", "0", "0", "0", "0", "0", "1", "0", 
              "0", "0", "1", "0", "0", "0", "0"}
            }], ")"}],
      (MatrixForm[ #]&)]], "Output",
  CellLabel->"Out[6]//MatrixForm="]
}, Closed]],

Cell["The calculation is very slow:", "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[
    \(Timing[gt = GriffithsTavare[S, \[Theta]]; ]\)], "Input",
  CellLabel->"In[7]:="],

Cell[BoxData[
    \({501.799999999999979`\ Second, Null}\)], "Output",
  CellLabel->"Out[7]="]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(Plot[gt, {\[Theta], 0, 30}]; \)\)], "Input",
  CellLabel->"In[13]:="],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.0456014 0.0147151 3.0618e+18 [
[.25182 .00222 -3 -9 ]
[.25182 .00222 3 0 ]
[.47982 .00222 -6 -9 ]
[.47982 .00222 6 0 ]
[.70783 .00222 -6 -9 ]
[.70783 .00222 6 0 ]
[.93584 .00222 -6 -9 ]
[.93584 .00222 6 0 ]
[.01131 .16781 -37.5 -6.25 ]
[.01131 .16781 0 6.25 ]
[.01131 .3209 -37.5 -6.25 ]
[.01131 .3209 0 6.25 ]
[.01131 .47398 -49.5 -6.25 ]
[.01131 .47398 0 6.25 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.25182 .01472 m
.25182 .02097 L
s
[(5)] .25182 .00222 0 1 Mshowa
.47982 .01472 m
.47982 .02097 L
s
[(10)] .47982 .00222 0 1 Mshowa
.70783 .01472 m
.70783 .02097 L
s
[(15)] .70783 .00222 0 1 Mshowa
.93584 .01472 m
.93584 .02097 L
s
[(20)] .93584 .00222 0 1 Mshowa
.125 Mabswid
.06941 .01472 m
.06941 .01847 L
s
.11501 .01472 m
.11501 .01847 L
s
.16061 .01472 m
.16061 .01847 L
s
.20621 .01472 m
.20621 .01847 L
s
.29742 .01472 m
.29742 .01847 L
s
.34302 .01472 m
.34302 .01847 L
s
.38862 .01472 m
.38862 .01847 L
s
.43422 .01472 m
.43422 .01847 L
s
.52542 .01472 m
.52542 .01847 L
s
.57103 .01472 m
.57103 .01847 L
s
.61663 .01472 m
.61663 .01847 L
s
.66223 .01472 m
.66223 .01847 L
s
.75343 .01472 m
.75343 .01847 L
s
.79903 .01472 m
.79903 .01847 L
s
.84463 .01472 m
.84463 .01847 L
s
.89024 .01472 m
.89024 .01847 L
s
.98144 .01472 m
.98144 .01847 L
s
.25 Mabswid
0 .01472 m
1 .01472 L
s
.02381 .16781 m
.03006 .16781 L
s
gsave
.01131 .16781 -37.5 -4.25 Mabsadd m
1 1 Mabs scale
/Courier findfont 10 scalefont setfont
(5) show
/Math1Mono findfont 10 scalefont setfont
(\\264) show
/Courier findfont 10 scalefont setfont
(10) show
0 5.25 rmoveto
/Courier findfont 7.5 scalefont setfont
(-20) show
grestore
.02381 .3209 m
.03006 .3209 L
s
gsave
.01131 .3209 -37.5 -4.25 Mabsadd m
1 1 Mabs scale
/Courier findfont 10 scalefont setfont
(1) show
/Math1Mono findfont 10 scalefont setfont
(\\264) show
/Courier findfont 10 scalefont setfont
(10) show
0 5.25 rmoveto
/Courier findfont 7.5 scalefont setfont
(-19) show
grestore
.02381 .47398 m
.03006 .47398 L
s
gsave
.01131 .47398 -49.5 -4.25 Mabsadd m
1 1 Mabs scale
/Courier findfont 10 scalefont setfont
(1.5) show
/Math1Mono findfont 10 scalefont setfont
(\\264) show
/Courier findfont 10 scalefont setfont
(10) show
0 5.25 rmoveto
/Courier findfont 7.5 scalefont setfont
(-19) show
grestore
.125 Mabswid
.02381 .04533 m
.02756 .04533 L
s
.02381 .07595 m
.02756 .07595 L
s
.02381 .10657 m
.02756 .10657 L
s
.02381 .13719 m
.02756 .13719 L
s
.02381 .19842 m
.02756 .19842 L
s
.02381 .22904 m
.02756 .22904 L
s
.02381 .25966 m
.02756 .25966 L
s
.02381 .29028 m
.02756 .29028 L
s
.02381 .35151 m
.02756 .35151 L
s
.02381 .38213 m
.02756 .38213 L
s
.02381 .41275 m
.02756 .41275 L
s
.02381 .44337 m
.02756 .44337 L
s
.02381 .5046 m
.02756 .5046 L
s
.02381 .53522 m
.02756 .53522 L
s
.02381 .56584 m
.02756 .56584 L
s
.02381 .59646 m
.02756 .59646 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .01472 m
.0255 .01472 L
.02703 .01472 L
.02881 .01472 L
.03048 .01472 L
.03204 .01472 L
.03347 .01472 L
.03504 .01472 L
.0367 .01472 L
.03837 .01472 L
.04017 .01472 L
.04187 .01472 L
.04342 .01472 L
.04524 .01472 L
.04626 .01472 L
.04722 .01472 L
.04896 .01472 L
.05083 .01472 L
.05176 .01472 L
.05275 .01472 L
.05452 .01472 L
.05551 .01472 L
.05643 .01472 L
.05744 .01472 L
.05852 .01472 L
.05945 .01472 L
.06046 .01472 L
.06231 .01472 L
.0641 .01472 L
.06576 .01472 L
.06737 .01472 L
.06888 .01472 L
.07054 .01472 L
.07233 .01472 L
.0741 .01472 L
.07597 .01472 L
.07756 .01472 L
.07931 .01472 L
.08033 .01472 L
.08127 .01472 L
.08339 .01472 L
.08527 .01473 L
.08725 .01473 L
.08902 .01474 L
.09069 .01475 L
.09251 .01476 L
.09447 .01478 L
.09654 .0148 L
.09881 .01483 L
.10095 .01487 L
Mistroke
.10293 .01491 L
.10667 .01503 L
.10877 .01511 L
.11066 .0152 L
.11443 .01544 L
.11789 .01574 L
.12168 .01617 L
.12569 .01678 L
.12918 .01746 L
.13244 .01824 L
.13628 .01938 L
.13983 .02066 L
.14705 .02409 L
.15488 .02928 L
.16179 .03536 L
.16912 .04355 L
.18181 .06242 L
.1958 .09054 L
.22364 .16803 L
.25362 .27311 L
.2819 .37613 L
.31279 .47512 L
.32708 .51251 L
.34233 .54539 L
.35672 .5695 L
.36978 .58557 L
.37677 .59197 L
.38416 .59712 L
.39047 .60026 L
.39405 .60154 L
.3974 .60242 L
.39925 .60278 L
.40023 .60293 L
.40127 .60307 L
.40217 .60316 L
.40317 .60324 L
.40494 .60332 L
.40664 .60332 L
.40848 .60324 L
.41022 .60309 L
.41182 .60288 L
.41368 .60257 L
.41541 .6022 L
.41935 .60112 L
.42319 .59974 L
.42729 .59791 L
.44198 .58866 L
.45792 .57447 L
.48685 .54031 L
.54558 .45315 L
Mistroke
.60214 .36591 L
.65651 .29048 L
.71441 .22371 L
.77014 .17283 L
.82938 .13136 L
.88645 .10142 L
.94134 .07984 L
.99975 .06278 L
Mfstroke
.99975 .06278 m
1 .06273 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[13]:=",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/A000`40O003h00Oogoo8Goo003oOolQ
Ool00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00
ogoo8Goo003oOolQOol00?moob5oo`00JGoo0`00<Goo0`0017oo0P00;Goo0`000goo0`00;Woo1000
0goo0P003Goo001/Ool00`00Oomoo`0_Ool00`00Oomoo`02Ool01000Oomoo`00;Goo00<007ooOol0
1Goo00<007ooOol0;7oo00<007ooOol00Woo00@007ooOol000aoo`00K7oo00<007ooOol0;goo00<0
07ooOol00Woo00@007ooOol002eoo`03001oogoo00Eoo`03001oogoo02eoo`05001oogooOol00002
Ool00`00Oomoo`0:Ool006Uoo`<0039oo`03001oogoo009oo`04001oogoo000]Ool00`00Oomoo`02
Ool3000aOol01000Oomoo`000Woo00<007ooOol02Woo001YOol00`00Oomoo`0bOol00`00Oomoo`02
Ool01000Oomoo`00;Goo00<007ooOol00Woo00<007ooOol0;Woo00@007ooOol0009oo`04001oogoo
000<Ool006Uoo`@0031oo`8000Eoo`8002eoo`8000Aoo`@002ioo`8000Aoo`8000eoo`00=7oo00<0
07ooOol0jGoo000dOol00`00Oomoo`3YOol003Aoo`03001oogoo0>Uoo`00=7oo00<007ooOol0jGoo
000^Ooob000003Aoo`03001oogoo01Qoo`<001Uoo`03001oogoo03Aoo`03001oogoo03=oo`03001o
ogoo03Aoo`03001oogoo00ioo`00=7oo00<007ooOol06goo00<007ooOol0bgoo000dOol00`00Oomo
o`0LOol00`00Oomoo`3:Ool003Aoo`03001oogoo01eoo`03001oogoo0<Uoo`00=7oo00<007ooOol0
7Woo0P00bGoo000dOol00`00Oomoo`0POol00`00Oomoo`36Ool003Aoo`80025oo`03001oogoo0<Io
o`00=7oo00<007ooOol08Goo00<007ooOol0aGoo000dOol00`00Oomoo`0ROol00`00Oomoo`34Ool0
03Aoo`03001oogoo029oo`03001oogoo0<Aoo`00=7oo00<007ooOol08goo00<007ooOol0_goo1000
000dOol00`00Oomoo`0SOol00`00Oomoo`2lOol30004Ool003Aoo`03001oogoo02Aoo`03001oogoo
0;Moo`@000Moo`00=7oo0P009Goo00<007ooOol0]7oo0`002goo000dOol00`00Oomoo`0UOol00`00
Oomoo`2`Ool3000>Ool003Aoo`03001oogoo02Eoo`03001oogoo0:eoo`<0015oo`00=7oo00<007oo
Ool09Goo00<007ooOol0ZWoo0`0057oo000dOol00`00Oomoo`0VOol00`00Oomoo`2WOol2000GOol0
03Aoo`03001oogoo02Ioo`03001oogoo0:Aoo`<001Uoo`00=7oo00<007ooOol09goo00<007ooOol0
XGoo0P0077oo000dOol00`00Oomoo`0WOol00`00Oomoo`2POol00`00Oomoo`0LOol003Aoo`8002Qo
o`03001oogoo09ioo`8001moo`00=7oo00<007ooOol0:7oo00<007ooOol0Vgoo0P008Goo000dOol0
0`00Oomoo`0XOol00`00Oomoo`2JOol00`00Oomoo`0QOol003Aoo`03001oogoo02Uoo`03001oogoo
09Moo`8002Aoo`00=7oo00<007ooOol0:Goo00<007ooOol0UGoo0P009Woo000dOol00`00Oomoo`0Y
Ool00`00Oomoo`2DOol00`00Oomoo`0VOol003Aoo`03001oogoo02Yoo`03001oogoo095oo`8002Uo
o`00=7oo0P00:goo00<007ooOol0T7oo00<007ooOol0:Goo000dOol00`00Oomoo`0ZOol00`00Oomo
o`2>Ool2000/Ool003Aoo`03001oogoo02]oo`03001oogoo08aoo`03001oogoo02aoo`00=7oo00<0
07ooOol0:goo00<007ooOol0RWoo0P00;goo000=Ool30003Ool01@00Oomoogoo00000Woo0`0017oo
0P004Goo00<007ooOol0;7oo00<007ooOol0R7oo00<007ooOol0;goo000@Ool01`00Oomoogoo001o
o`0000Aoo`03001oogoo009oo`04001oogoo000@Ool00`00Oomoo`0/Ool00`00Oomoo`26Ool2000b
Ool0011oo`03001oogoo009oo`03001oogoo00=oo`03001oogoo009oo`04001oogoo000@Ool00`00
Oomoo`0/Ool00`00Oomoo`25Ool00`00Oomoo`0bOol000eoo`<000Aoo`03001oo`0000Aoo`03001o
ogoo009oo`04001oogoo000@Ool3000]Ool00`00Oomoo`22Ool2000eOol000eoo`03001oogoo00=o
o`05001oogooOol00003Ool00`00Oomoo`02Ool01000Oomoo`0047oo00<007ooOol0;Goo00<007oo
Ool0PGoo00<007ooOol0=Goo000=Ool40009Ool20005Ool20008Ool30003Ool01000Oomoo`00;goo
00<007ooOol0Ogoo0P00>7oo000VOol40002Ool02@00Oomoogoo001oo`00Ool0000`Ool00`00Oomo
o`1mOol00`00Oomoo`0hOol002eoo`08001oogoo001oo`00Ool0031oo`03001oogoo07aoo`03001o
ogoo03Uoo`00;Goo00P007ooOol007oo001oo`00<7oo00<007ooOol0Ngoo00<007ooOol0>Woo000[
Ool30003Ool01000Oomoo`00<7oo00<007ooOol0NWoo00<007ooOol0>goo000dOol00`00Oomoo`0_
Ool00`00Oomoo`1hOol00`00Oomoo`0lOol003Aoo`80031oo`03001oogoo07Moo`03001oogoo03eo
o`00=7oo00<007ooOol0;goo00<007ooOol0MWoo00<007ooOol0?Woo000dOol00`00Oomoo`0`Ool0
0`00Oomoo`1dOol00`00Oomoo`0oOol003Aoo`03001oogoo031oo`03001oogoo07=oo`03001oogoo
041oo`00=7oo00<007ooOol0<7oo00<007ooOol0LWoo00<007ooOol0@Goo000dOol00`00Oomoo`0`
Ool00`00Oomoo`1aOol00`00Oomoo`12Ool003Aoo`03001oogoo035oo`03001oogoo06moo`03001o
ogoo04=oo`00=7oo0P00<Woo00<007ooOol0Kgoo00<007ooOol0@goo000dOol00`00Oomoo`0aOol0
0`00Oomoo`1^Ool00`00Oomoo`14Ool003Aoo`03001oogoo035oo`03001oogoo06eoo`03001oogoo
04Eoo`00=7oo00<007ooOol0<Woo00<007ooOol0Jgoo00<007ooOol0AWoo000dOol00`00Oomoo`0b
Ool00`00Oomoo`1ZOol00`00Oomoo`17Ool003Aoo`03001oogoo039oo`03001oogoo06Uoo`03001o
ogoo04Qoo`00=7oo00<007ooOol0<goo00<007ooOol0Igoo00<007ooOol0BGoo000dOol2000dOol0
0`00Oomoo`1VOol00`00Oomoo`1:Ool003Aoo`03001oogoo03=oo`03001oogoo06Ioo`03001oogoo
04Yoo`00=7oo00<007ooOol0<goo00<007ooOol0IGoo00<007ooOol0Bgoo000dOol00`00Oomoo`0d
Ool00`00Oomoo`1SOol00`00Oomoo`1<Ool003Aoo`03001oogoo03Aoo`03001oogoo069oo`03001o
ogoo04eoo`00=7oo00<007ooOol0=7oo00<007ooOol0HGoo00<007ooOol0CWoo000dOol00`00Oomo
o`0dOol00`00Oomoo`1POol00`00Oomoo`1?Ool003Aoo`03001oogoo03Eoo`03001oogoo05ioo`03
001oogoo051oo`00=7oo0P00=Woo00<007ooOol0GGoo00<007ooOol0DGoo000dOol00`00Oomoo`0e
Ool00`00Oomoo`1MOol00`00Oomoo`1AOol003Aoo`03001oogoo03Ioo`03001oogoo05]oo`03001o
ogoo059oo`00=7oo00<007ooOol0=Woo00<007ooOol0FWoo00<007ooOol0Dgoo000=Ool30003Ool0
1@00Oomoogoo00000Woo0`0017oo0P004Goo00<007ooOol0=Woo00<007ooOol0FGoo00<007ooOol0
E7oo000>Ool00`00Oomoo`03Ool00`00Ool00004Ool00`00Oomoo`02Ool01000Oomoo`0047oo00<0
07ooOol0=Woo00<007ooOol0FGoo00<007ooOol0E7oo000>Ool00`00Oomoo`04Ool00`00Oomoo`03
Ool00`00Oomoo`02Ool01000Oomoo`0047oo00<007ooOol0=goo00<007ooOol0Egoo00<007ooOol0
EGoo000>Ool00`00Oomoo`03Ool00`00Ool00004Ool00`00Oomoo`02Ool01000Oomoo`0047oo0`00
=goo00<007ooOol0EWoo00<007ooOol0EWoo000>Ool00`00Oomoo`02Ool01@00Oomoogoo00000goo
00<007ooOol00Woo00@007ooOol0011oo`03001oogoo03Moo`03001oogoo05Ioo`03001oogoo05Io
o`003Goo0P002goo0P001Goo0P0027oo0`000Woo0P000Woo00<007ooOol0>7oo00<007ooOol0E7oo
00<007ooOol0Egoo000VOol40002Ool00`00Oomoo`03Ool00`00Ool0000jOol00`00Oomoo`1COol0
0`00Oomoo`1HOol002aoo`04001oogooOol300000goo001oo`0iOol00`00Oomoo`1BOol00`00Oomo
o`1IOol002aoo`09001oogooOol007oo001oo`0003]oo`03001oogoo055oo`03001oogoo05Uoo`00
:goo0P000goo0P000Woo00<007ooOol0>Goo00<007ooOol0D7oo00<007ooOol0FWoo000dOol2000j
Ool00`00Oomoo`1?Ool00`00Oomoo`1KOol003Aoo`03001oogoo03Uoo`03001oogoo04moo`03001o
ogoo05]oo`00=7oo00<007ooOol0>Woo00<007ooOol0CGoo00<007ooOol0G7oo000dOol00`00Oomo
o`0jOol00`00Oomoo`1<Ool00`00Oomoo`1MOol003Aoo`03001oogoo03Yoo`03001oogoo04]oo`03
001oogoo05ioo`00=7oo00<007ooOol0>goo00<007ooOol0BWoo00<007ooOol0GWoo000dOol00`00
Oomoo`0kOol00`00Oomoo`19Ool00`00Oomoo`1OOol003Aoo`03001oogoo03]oo`03001oogoo04Qo
o`03001oogoo061oo`00=7oo0P00?7oo00<007ooOol0B7oo00<007ooOol0H7oo000dOol00`00Oomo
o`0lOol00`00Oomoo`16Ool00`00Oomoo`1QOol003Aoo`03001oogoo03aoo`03001oogoo04Eoo`03
001oogoo069oo`00=7oo00<007ooOol0?7oo00<007ooOol0AGoo00<007ooOol0HWoo000dOol00`00
Oomoo`0mOol00`00Oomoo`13Ool00`00Oomoo`1SOol003Aoo`03001oogoo03eoo`03001oogoo049o
o`03001oogoo06Aoo`00=7oo00<007ooOol0?Goo00<007ooOol0@Woo00<007ooOol0I7oo000dOol2
000nOol00`00Oomoo`11Ool00`00Oomoo`1UOol003Aoo`03001oogoo03ioo`03001oogoo03moo`03
001oogoo06Ioo`00=7oo00<007ooOol0?Woo00<007ooOol0?goo00<007ooOol0IWoo000dOol00`00
Oomoo`0nOol00`00Oomoo`0nOol00`00Oomoo`1WOol003Aoo`03001oogoo03moo`03001oogoo03ao
o`03001oogoo06Qoo`00=7oo00<007ooOol0?goo00<007ooOol0?7oo00<007ooOol0J7oo000dOol0
0`00Oomoo`0oOol00`00Oomoo`0kOol00`00Oomoo`1YOol003Aoo`03001oogoo041oo`03001oogoo
03Uoo`03001oogoo06Yoo`00=7oo0P00@Goo00<007ooOol0>Goo00<007ooOol0JWoo000dOol00`00
Oomoo`10Ool00`00Oomoo`0hOol00`00Oomoo`1[Ool003Aoo`03001oogoo041oo`03001oogoo03Mo
o`03001oogoo06aoo`00=7oo00<007ooOol0@Goo00<007ooOol0=Woo00<007ooOol0K7oo000017oo
0000000017oo0P000goo0`000goo00D007ooOomoo`00009oo`<000Aoo`80015oo`03001oogoo045o
o`03001oogoo03Eoo`03001oogoo06eoo`000Woo00<007ooOol00goo0P001Woo00L007ooOomoo`00
Ool00004Ool00`00Oomoo`02Ool01000Oomoo`0047oo00<007ooOol0@Goo00<007ooOol0=7oo00<0
07ooOol0KWoo0002Ool00`00Oomoo`0;Ool00`00Oomoo`02Ool00`00Oomoo`03Ool00`00Oomoo`02
Ool01000Oomoo`0047oo00<007ooOol0@Woo00<007ooOol0<goo00<007ooOol0KWoo0002Ool00`00
Oomoo`08Ool30004Ool00`00Ool00004Ool00`00Oomoo`02Ool01000Oomoo`0047oo0`00@Woo00<0
07ooOol0<Woo00<007ooOol0Kgoo0002Ool00`00Oomoo`08Ool00`00Oomoo`03Ool01@00Oomoogoo
00000goo00<007ooOol00Woo00@007ooOol0011oo`03001oogoo049oo`03001oogoo035oo`03001o
ogoo071oo`0000=oo`0000002Woo10002Goo0P001Goo0P0027oo0`000Woo0P000Woo00<007ooOol0
@goo00<007ooOol0<7oo00<007ooOol0L7oo000VOol40002Ool00`00Oomoo`03Ool00`00Ool00015
Ool00`00Oomoo`0_Ool00`00Oomoo`1aOol002aoo`04001oogooOol300000goo001oo`15Ool00`00
Oomoo`0]Ool00`00Oomoo`1bOol002aoo`09001oogooOol007oo001oo`0004Ioo`03001oogoo02eo
o`03001oogoo079oo`00:goo0P000goo0P000Woo00<007ooOol0A7oo00<007ooOol0;7oo00<007oo
Ool0Lgoo000dOol20016Ool00`00Oomoo`0ZOol00`00Oomoo`1dOol003Aoo`03001oogoo04Eoo`03
001oogoo02Yoo`03001oogoo07Aoo`00=7oo00<007ooOol0AWoo00<007ooOol0:7oo00<007ooOol0
MGoo000dOol00`00Oomoo`16Ool00`00Oomoo`0WOol00`00Oomoo`1fOol003Aoo`03001oogoo04Mo
o`03001oogoo02Ioo`03001oogoo07Ioo`00=7oo00<007ooOol0Agoo00<007ooOol09Goo00<007oo
Ool0Mgoo000dOol00`00Oomoo`18Ool00`00Oomoo`0SOol00`00Oomoo`1hOol003Aoo`03001oogoo
04Qoo`03001oogoo02=oo`03001oogoo07Qoo`00=7oo0P00BWoo00<007ooOol08Goo00<007ooOol0
NGoo000dOol00`00Oomoo`19Ool00`00Oomoo`0POol00`00Oomoo`1jOol003Aoo`03001oogoo04Yo
o`03001oogoo01moo`03001oogoo07Yoo`00=7oo00<007ooOol0BWoo00<007ooOol07Woo00<007oo
Ool0Ngoo000dOol00`00Oomoo`1;Ool00`00Oomoo`0LOol00`00Oomoo`1lOol003Aoo`03001oogoo
04]oo`03001oogoo01]oo`03001oogoo07eoo`00=7oo00<007ooOol0C7oo00<007ooOol06Goo00<0
07ooOol0OWoo000dOol2001=Ool00`00Oomoo`0HOol00`00Oomoo`1oOol003Aoo`03001oogoo04eo
o`03001oogoo01Ioo`03001oogoo081oo`00=7oo00<007ooOol0CGoo00<007ooOol057oo0P00Pgoo
000dOol00`00Oomoo`1>Ool00`00Oomoo`0BOol00`00Oomoo`23Ool003Aoo`03001oogoo04moo`03
001oogoo011oo`03001oogoo08Aoo`00=7oo00<007ooOol0D7oo0P003goo00<007ooOol0QGoo000d
Ool00`00Oomoo`1BOol2000<Ool00`00Oomoo`26Ool003Aoo`8005Eoo`03001oogoo00Qoo`03001o
ogoo08Moo`00=7oo00<007ooOol0EGoo00<007ooOol017oo0`00RWoo000dOol00`00Oomoo`1FOol6
002=Ool003Aoo`03001oogoo0>Uoo`00=7oo00<007ooOol0jGoo000dOol00`00Oomoo`3YOol00?mo
ob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo
003oOolQOol00?moob5oo`00\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-4.79306, -2.99216, 
  0.0912899, 1.35964}}]
}, Closed]],

Cell["\<\
It is much faster to do the calculation for a specific value of \
\[Theta]:\
\>", "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[
    \(Timing[gN[10] = GriffithsTavare[S, 10. ]]\)], "Input",
  CellLabel->"In[9]:="],

Cell[BoxData[
    \({22.4666666666665815`\ Second, 1.74637001967487766`*^-19}\)], "Output",
  CellLabel->"Out[9]="]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    \(gt /. \[Theta] \[Rule] 10. \)], "Input",
  CellLabel->"In[8]:="],

Cell[BoxData[
    \(1.74637001967487837`*^-19\)], "Output",
  CellLabel->"Out[8]="]
}, Closed]],

Cell["\<\
Note that it is best to use a decimal here, rather than an integer:\
\
\>", "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[
    \(Timing[gN[10] = GriffithsTavare[S, 10]]\)], "Input",
  CellLabel->"In[14]:="],

Cell[BoxData[
    \({24.8499999999999099`\ Second, 
      549265950025866389412402934029934205336977180012293945248329766561762048\
44300428242998768500597203/
        3145186551748770619526947533888106625409270389164780025501505860406854\
26020514877354751189535068900221601551568863232}\)], "Output",
  CellLabel->"Out[14]="]
}, Closed]],

Cell[TextData[{
  "The result is an enormous rational, though ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " doesn't seem slowed down by this."
}], "Text"],

Cell["\<\
As the number of lineages becomes large, the depth of the tree \
tends to 4N.  Hence, the number of segregating sites tends to a constant, and \
little extra information on \[Theta] comes from sampling more lineages: what \
is needed is more sequence, giving a large \[Theta].  \
\>", "Text"]
}, Open  ]]
},
FrontEndVersion->"4.0 for Macintosh",
ScreenRectangle->{{0, 1024}, {0, 748}},
WindowSize->{520, 653},
WindowMargins->{{Automatic, -8}, {Automatic, -1}},
StyleDefinitions -> "HelpBrowser.nb",
MacintoshSystemPageSetup->"\<\
00`0001804P000000_02@?o/onh3109BI085:0?l0@00005X0FP000003[0;@001
0000I00100000@0000000BL?0040000000000000000000000000000000000?nL
ojH?50^J00P100000000000000000000\>"
]


(***********************************************************************
Cached data follows.  If you edit this Notebook file directly, not using
Mathematica, you must remove the line containing CacheID at the top of 
the file.  The cache data will then be recreated when you save this file 
from within Mathematica.
***********************************************************************)

(*CellTagsOutline
CellTagsIndex->{
  "GriffithsTavare"->{
    Cell[1804, 53, 334, 6, 64, "DefinitionBox",
      CellTags->"GriffithsTavare"]},
  "Example"->{
    Cell[95986, 1488, 99, 1, 36, "SubsectionIcon",
      CellTags->"Example"]}
  }
*)

(*CellTagsIndex
CellTagsIndex->{
  {"GriffithsTavare", 170068, 3367},
  {"Example", 170168, 3370}
  }
*)

(*NotebookFileOutline
Notebook[{

Cell[CellGroupData[{
Cell[1739, 51, 62, 0, 36, "SubsectionIcon"],
Cell[1804, 53, 334, 6, 64, "DefinitionBox",
  CellTags->"GriffithsTavare"],
Cell[2141, 61, 46, 0, 28, "MathCaption"],
Cell[2190, 63, 91, 2, 27, "Input"],
Cell[2284, 67, 108, 3, 28, "MathCaption"],

Cell[CellGroupData[{
Cell[2417, 74, 603, 13, 92, "Input"],
Cell[3023, 89, 574, 10, 58, "Output"]
}, Closed]],
Cell[3612, 102, 111, 3, 18, "MathCaption"],

Cell[CellGroupData[{
Cell[3748, 109, 604, 13, 92, "Input"],
Cell[4355, 124, 573, 10, 58, "Output"]
}, Closed]],
Cell[4943, 137, 405, 7, 60, "Text"],

Cell[CellGroupData[{
Cell[5373, 148, 604, 13, 92, "Input"],
Cell[5980, 163, 576, 10, 58, "Output"]
}, Closed]],
Cell[6571, 176, 160, 4, 32, "Text"],
Cell[6734, 182, 71, 0, 28, "MathCaption"],

Cell[CellGroupData[{
Cell[6830, 186, 603, 13, 92, "Input"],
Cell[7436, 201, 577, 10, 58, "Output"]
}, Closed]],
Cell[8028, 214, 79, 0, 18, "MathCaption"],
Cell[8110, 216, 1106, 22, 101, "Text"],
Cell[9219, 240, 262, 6, 38, "Text"],

Cell[CellGroupData[{
Cell[9506, 250, 76, 2, 27, "Input"],
Cell[9585, 254, 183, 3, 35, "Print"],
Cell[9771, 259, 86166, 1223, 5690, "Print"]
}, Closed]]
}, Open  ]],

Cell[CellGroupData[{
Cell[95986, 1488, 99, 1, 36, "SubsectionIcon",
  CellTags->"Example"],
Cell[96088, 1491, 79, 0, 28, "MathCaption"],

Cell[CellGroupData[{
Cell[96192, 1495, 153, 3, 42, "Input"],
Cell[96348, 1500, 53425, 1236, 374, 18827, 804, "GraphicsData", "PostScript", \
"Graphics"]
}, Closed]],
Cell[149788, 2739, 46, 0, 18, "MathCaption"],

Cell[CellGroupData[{
Cell[149859, 2743, 137, 3, 27, "Input"],
Cell[149999, 2748, 138, 3, 20, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[150174, 2756, 98, 2, 23, "Input"],
Cell[150275, 2760, 1697, 29, 206, "Output"]
}, Closed]],
Cell[151987, 2792, 52, 0, 18, "MathCaption"],

Cell[CellGroupData[{
Cell[152064, 2796, 100, 2, 27, "Input"],
Cell[152167, 2800, 94, 2, 20, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[152298, 2807, 91, 2, 23, "Input"],
Cell[152392, 2811, 15198, 470, 184, 5184, 341, "GraphicsData", "PostScript", \
"Graphics"]
}, Closed]],
Cell[167605, 3284, 106, 3, 18, "MathCaption"],

Cell[CellGroupData[{
Cell[167736, 3291, 98, 2, 27, "Input"],
Cell[167837, 3295, 115, 2, 22, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[167989, 3302, 84, 2, 23, "Input"],
Cell[168076, 3306, 83, 2, 22, "Output"]
}, Closed]],
Cell[168174, 3311, 100, 3, 18, "MathCaption"],

Cell[CellGroupData[{
Cell[168299, 3318, 97, 2, 27, "Input"],
Cell[168399, 3322, 327, 6, 72, "Output"]
}, Closed]],
Cell[168741, 3331, 167, 5, 20, "Text"],
Cell[168911, 3338, 302, 5, 50, "Text"]
}, Open  ]]
}
]
*)




(***********************************************************************
End of Mathematica Notebook file.
***********************************************************************)

