(***********************************************************************

                    Mathematica-Compatible Notebook

This notebook can be used on any computer system with Mathematica 4.0,
MathReader 4.0, or any compatible application. The data for the notebook 
starts with the line containing stars above.

To get the notebook into a Mathematica-compatible application, do one of 
the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing the 
word CacheID, otherwise Mathematica-compatible applications may try to 
use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
***********************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[     25484,        783]*)
(*NotebookOutlinePosition[     26693,        821]*)
(*  CellTagsIndexPosition[     26579,        814]*)
(*WindowFrame->Normal*)



Notebook[{

Cell[CellGroupData[{
Cell["Finding the probability of a specific configuration", \
"SubsubsectionIcon"],

Cell[TextData[Cell[BoxData[
    FormBox[GridBox[{
          {\(ExactProbability[
              g, \[Theta]]\), \(gives\ the\ probability\ of\ this\ genealogy, \
\ given\ a\ scaled\ mutation\ rate\ \[Theta] = 
              4  N\[VeryThinSpace]\[Mu] . \ By\ default, \ 
            the\ number\ of\ mutations\ is\ deduced\ from\ a\ list\ of\ \
unique\ mutations\ held\ in\ the\ second\ element\ of\ the\ information\ \
\(\(list\)\(.\)\)\)},
          {\(ExactProbability[g, \[Theta], 
              NodeFunction \[Rule] f]\), \(uses\ f[i, 
                info]\ to\ find\ the\ number\ of\ \(\(mutations\)\(.\)\)\)}
          }], TraditionalForm]]]], "DefinitionBox",
  CellTags->{"ExactProbability", "NodeFunction"}],

Cell["\<\
This is a randomly generated genealogy; the set of mutations \
carried by each node is held as the second element of the information list.\
\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(g = 
      RandomGenealogy[{a, b, c, d, e}, MutationRate \[Rule] 10]\)], "Input",
  CellLabel->"In[299]:="],

Cell[BoxData[
    \(Node[
      5, {1.19230699182641952`, {}}, {Node[
          4, {1.19230699182641952`, {}}, {Node[
              1, {0.0323713637929897668`, {1}}, {Node[a, {0, {1}}, {}], 
                Node[c, {0, {1, 6}}, {}]}], 
            Node[3, {0.807300593403853739`, {2, 3}}, {Node[
                  d, {0, {2, 3, 4, 5}}, {}], 
                Node[2, {0.190982424856526478`, {2, 3, 7, 8, 9, 10}}, {Node[
                      b, {0, {2, 3, 7, 8, 9, 10, 11}}, {}], 
                    Node[e, {0, {2, 3, 7, 8, 9, 10, 12, 
                          13}}, {}]}]}]}]}]\)], "Output",
  CellLabel->"Out[299]="]
}, Closed]],

Cell["\<\
This is the probability of that configurastion of mutations and of \
that ordered topology, as a function of \[Theta]:\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(ep = ExactProbability[g, \[Theta]]\)], "Input",
  CellLabel->"In[309]:="],

Cell[BoxData[
    \(\((\[Theta]\^13\ \((13795291201536 + 50131091662848\ \[Theta] + 
              81043083145728\ \[Theta]\^2 + 76947429536640\ \[Theta]\^3 + 
              47609208437792\ \[Theta]\^4 + 20088043157072\ \[Theta]\^5 + 
              5860754353968\ \[Theta]\^6 + 1168599301216\ \[Theta]\^7 + 
              152522957642\ \[Theta]\^8 + 11773613661\ \[Theta]\^9 + 
              408357224\ \[Theta]\^10)\))\)/\((1944000000\ \((1 + \[Theta])\)\
\^4\ \((2 + \[Theta])\)\^8\ \((3 + \[Theta])\)\^8\ \((4 + \
\[Theta])\)\^7)\)\)], "Output",
  CellLabel->"Out[309]="]
}, Closed]],

Cell["\<\
The most likely \[Theta] is close to the actual value of \
\[Theta]=10:\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(Plot[ep, {\[Theta], 0, 30}];\)\)], "Input",
  CellLabel->"In[311]:="],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.031746 0.0147151 1.1072e+06 [
[.18254 .00222 -3 -9 ]
[.18254 .00222 3 0 ]
[.34127 .00222 -6 -9 ]
[.34127 .00222 6 0 ]
[.5 .00222 -6 -9 ]
[.5 .00222 6 0 ]
[.65873 .00222 -6 -9 ]
[.65873 .00222 6 0 ]
[.81746 .00222 -6 -9 ]
[.81746 .00222 6 0 ]
[.97619 .00222 -6 -9 ]
[.97619 .00222 6 0 ]
[.01131 .12544 -33 -6.25 ]
[.01131 .12544 0 6.25 ]
[.01131 .23616 -33 -6.25 ]
[.01131 .23616 0 6.25 ]
[.01131 .34688 -33 -6.25 ]
[.01131 .34688 0 6.25 ]
[.01131 .4576 -33 -6.25 ]
[.01131 .4576 0 6.25 ]
[.01131 .56832 -33 -6.25 ]
[.01131 .56832 0 6.25 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.18254 .01472 m
.18254 .02097 L
s
[(5)] .18254 .00222 0 1 Mshowa
.34127 .01472 m
.34127 .02097 L
s
[(10)] .34127 .00222 0 1 Mshowa
.5 .01472 m
.5 .02097 L
s
[(15)] .5 .00222 0 1 Mshowa
.65873 .01472 m
.65873 .02097 L
s
[(20)] .65873 .00222 0 1 Mshowa
.81746 .01472 m
.81746 .02097 L
s
[(25)] .81746 .00222 0 1 Mshowa
.97619 .01472 m
.97619 .02097 L
s
[(30)] .97619 .00222 0 1 Mshowa
.125 Mabswid
.05556 .01472 m
.05556 .01847 L
s
.0873 .01472 m
.0873 .01847 L
s
.11905 .01472 m
.11905 .01847 L
s
.15079 .01472 m
.15079 .01847 L
s
.21429 .01472 m
.21429 .01847 L
s
.24603 .01472 m
.24603 .01847 L
s
.27778 .01472 m
.27778 .01847 L
s
.30952 .01472 m
.30952 .01847 L
s
.37302 .01472 m
.37302 .01847 L
s
.40476 .01472 m
.40476 .01847 L
s
.43651 .01472 m
.43651 .01847 L
s
.46825 .01472 m
.46825 .01847 L
s
.53175 .01472 m
.53175 .01847 L
s
.56349 .01472 m
.56349 .01847 L
s
.59524 .01472 m
.59524 .01847 L
s
.62698 .01472 m
.62698 .01847 L
s
.69048 .01472 m
.69048 .01847 L
s
.72222 .01472 m
.72222 .01847 L
s
.75397 .01472 m
.75397 .01847 L
s
.78571 .01472 m
.78571 .01847 L
s
.84921 .01472 m
.84921 .01847 L
s
.88095 .01472 m
.88095 .01847 L
s
.9127 .01472 m
.9127 .01847 L
s
.94444 .01472 m
.94444 .01847 L
s
.25 Mabswid
0 .01472 m
1 .01472 L
s
.02381 .12544 m
.03006 .12544 L
s
gsave
.01131 .12544 -33 -4.25 Mabsadd m
1 1 Mabs scale
/Courier findfont 10 scalefont setfont
(1) show
/Math1Mono findfont 10 scalefont setfont
(\\264) show
/Courier findfont 10 scalefont setfont
(10) show
0 5.25 rmoveto
/Courier findfont 7.5 scalefont setfont
(-7) show
grestore
.02381 .23616 m
.03006 .23616 L
s
gsave
.01131 .23616 -33 -4.25 Mabsadd m
1 1 Mabs scale
/Courier findfont 10 scalefont setfont
(2) show
/Math1Mono findfont 10 scalefont setfont
(\\264) show
/Courier findfont 10 scalefont setfont
(10) show
0 5.25 rmoveto
/Courier findfont 7.5 scalefont setfont
(-7) show
grestore
.02381 .34688 m
.03006 .34688 L
s
gsave
.01131 .34688 -33 -4.25 Mabsadd m
1 1 Mabs scale
/Courier findfont 10 scalefont setfont
(3) show
/Math1Mono findfont 10 scalefont setfont
(\\264) show
/Courier findfont 10 scalefont setfont
(10) show
0 5.25 rmoveto
/Courier findfont 7.5 scalefont setfont
(-7) show
grestore
.02381 .4576 m
.03006 .4576 L
s
gsave
.01131 .4576 -33 -4.25 Mabsadd m
1 1 Mabs scale
/Courier findfont 10 scalefont setfont
(4) show
/Math1Mono findfont 10 scalefont setfont
(\\264) show
/Courier findfont 10 scalefont setfont
(10) show
0 5.25 rmoveto
/Courier findfont 7.5 scalefont setfont
(-7) show
grestore
.02381 .56832 m
.03006 .56832 L
s
gsave
.01131 .56832 -33 -4.25 Mabsadd m
1 1 Mabs scale
/Courier findfont 10 scalefont setfont
(5) show
/Math1Mono findfont 10 scalefont setfont
(\\264) show
/Courier findfont 10 scalefont setfont
(10) show
0 5.25 rmoveto
/Courier findfont 7.5 scalefont setfont
(-7) show
grestore
.125 Mabswid
.02381 .03686 m
.02756 .03686 L
s
.02381 .059 m
.02756 .059 L
s
.02381 .08115 m
.02756 .08115 L
s
.02381 .10329 m
.02756 .10329 L
s
.02381 .14758 m
.02756 .14758 L
s
.02381 .16972 m
.02756 .16972 L
s
.02381 .19187 m
.02756 .19187 L
s
.02381 .21401 m
.02756 .21401 L
s
.02381 .2583 m
.02756 .2583 L
s
.02381 .28044 m
.02756 .28044 L
s
.02381 .30259 m
.02756 .30259 L
s
.02381 .32473 m
.02756 .32473 L
s
.02381 .36902 m
.02756 .36902 L
s
.02381 .39116 m
.02756 .39116 L
s
.02381 .41331 m
.02756 .41331 L
s
.02381 .43545 m
.02756 .43545 L
s
.02381 .47974 m
.02756 .47974 L
s
.02381 .50188 m
.02756 .50188 L
s
.02381 .52403 m
.02756 .52403 L
s
.02381 .54617 m
.02756 .54617 L
s
.02381 .59046 m
.02756 .59046 L
s
.02381 .6126 m
.02756 .6126 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .01472 m
.02499 .01472 L
.02605 .01472 L
.02729 .01472 L
.02846 .01472 L
.02954 .01472 L
.03053 .01472 L
.03163 .01472 L
.03279 .01472 L
.03395 .01472 L
.0352 .01472 L
.03638 .01472 L
.03746 .01472 L
.03873 .01472 L
.03944 .01472 L
.04011 .01472 L
.04132 .01472 L
.04262 .01472 L
.04327 .01472 L
.04396 .01472 L
.04519 .01473 L
.04588 .01473 L
.04652 .01474 L
.04726 .01474 L
.04797 .01475 L
.04925 .01477 L
.05041 .01479 L
.05166 .01483 L
.05302 .01488 L
.05414 .01494 L
.05539 .01502 L
.05669 .01512 L
.05791 .01525 L
.06009 .01555 L
.06244 .01601 L
.06509 .01674 L
.06756 .01766 L
.07026 .01901 L
.07315 .0209 L
.07619 .02347 L
.07906 .02651 L
.08443 .034 L
.08946 .04336 L
.0941 .05411 L
.10458 .08589 L
.12334 .16464 L
.14398 .26857 L
.16506 .37319 L
.18432 .45514 L
.19385 .48903 L
Mistroke
.20424 .52057 L
.21398 .54505 L
.22315 .56373 L
.23349 .58003 L
.24286 .59076 L
.24812 .59522 L
.25295 .5984 L
.25825 .60094 L
.26092 .60186 L
.26244 .60228 L
.26384 .6026 L
.26504 .60283 L
.26636 .60303 L
.26769 .60318 L
.26842 .60324 L
.2691 .60328 L
.27035 .60332 L
.2715 .60332 L
.27275 .60327 L
.27408 .60318 L
.27519 .60307 L
.27638 .60291 L
.27853 .60253 L
.28108 .60193 L
.28339 .60124 L
.28856 .59927 L
.29416 .59649 L
.30432 .5899 L
.32424 .57232 L
.34529 .54893 L
.38323 .50011 L
.42362 .44556 L
.4625 .39508 L
.50383 .34598 L
.54364 .30392 L
.58194 .26836 L
.62269 .23545 L
.66192 .20809 L
.69964 .1853 L
.73981 .16431 L
.77847 .14689 L
.81957 .1309 L
.85917 .11762 L
.89724 .10652 L
.93777 .09624 L
.97619 .08775 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[311]:=",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/A000`40O003h00Oogoo8Goo003oOolQ
Ool00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00BWoo0`008goo0`0017oo0P0087oo0`00
0goo0`0087oo10000goo0P0087oo10000Woo0`007goo0`0017oo0P0017oo001=Ool00`00Oomoo`0Q
Ool00`00Oomoo`02Ool01000Oomoo`0087oo00<007ooOol01Goo00<007ooOol07Woo00<007ooOol0
0Woo00@007ooOol0021oo`03001oogoo00Eoo`03001oogoo01moo`04001oogoo0002Ool00`00Oomo
o`01Ool004eoo`03001oogoo025oo`03001oogoo009oo`04001oogoo000POol00`00Oomoo`05Ool0
0`00Oomoo`0OOol01@00Oomoogoo00000Woo00<007ooOol07goo00<007ooOol017oo00<007ooOol0
7goo00@007ooOol0009oo`03001oogoo005oo`00BWoo0`0097oo00<007ooOol00Woo00@007ooOol0
021oo`03001oogoo009oo`<002=oo`04001oogoo0002Ool00`00Oomoo`0POol00`00Oomoo`03000P
Ool20003Ool01000Oomoo`000goo001:Ool00`00Oomoo`0TOol00`00Oomoo`02Ool01000Oomoo`00
87oo00<007ooOol00Woo00<007ooOol087oo00@007ooOol0009oo`04001oogoo000OOol01000Oomo
o`000Woo00<007ooOol08Woo00@007ooOol0009oo`03001oogoo005oo`00BWoo10008Woo0P001Goo
0P0087oo0P0017oo100087oo0P0017oo0P008Goo0P000goo10007Woo0`0017oo0P0017oo003oOolQ
Ool002Aoo`03001oogoo0?Uoo`0097oo00<007ooOol0nGoo000TOol00`00Oomoo`3iOol002Aoo`03
001oogoo0?Uoo`007Wooo`000`00000TOol00`00Oomoo`05Ool01@00Oomoogoo00000goo00<007oo
Ool01Goo00<007ooOol01Goo00<007ooOol01Goo00<007ooOol01Woo00<007ooOol01Goo00<007oo
Ool01Goo00<007ooOol01Goo00<007ooOol01Goo00<007ooOol01Goo00<007ooOol01Woo00<007oo
Ool01Goo00<007ooOol01Goo00<007ooOol01Goo00<007ooOol01Goo00<007ooOol01Goo00<007oo
Ool01Woo00<007ooOol01Goo00<007ooOol01Goo00<007ooOol01Goo00<007ooOol01Goo00<007oo
Ool01Goo00<007ooOol01Goo00<007ooOol01Woo00<007ooOol01Goo00<007ooOol01Goo00<007oo
Ool01Goo00<007ooOol01Goo00<007ooOol01Goo00<007ooOol01Goo000TOol00`00Oomoo`0:Ool0
0`00Oomoo`3/Ool002Aoo`03001oogoo00]oo`03001oogoo0>]oo`0097oo00<007ooOol02goo00<0
07ooOol0jgoo000TOol2000=Ool00`00Oomoo`3ZOol002Aoo`03001oogoo00eoo`03001oogoo0>Uo
o`0097oo00<007ooOol03Woo00<007ooOol0j7oo000TOol00`00Oomoo`0>Ool00`00Oomoo`3XOol0
02Aoo`03001oogoo00moo`03001oogoo0>Moo`0097oo00<007ooOol03goo00<007ooOol0igoo000T
Ool2000@Ool00`00Oomoo`3WOol002Aoo`03001oogoo00moo`03001oogoo0>Moo`0097oo00<007oo
Ool047oo00<007ooOol0iWoo000TOol00`00Oomoo`0@Ool00`00Oomoo`3VOol002Aoo`03001oogoo
011oo`03001oogoo0>Ioo`0097oo00<007ooOol047oo00<007ooOol0iWoo000TOol2000BOol00`00
Oomoo`3UOol002Aoo`03001oogoo015oo`03001oogoo0=aoo`8000Moo`0097oo00<007ooOol04Goo
00<007ooOol0fGoo0`002Goo000TOol00`00Oomoo`0AOol00`00Oomoo`3FOol3000<Ool002Aoo`03
001oogoo019oo`03001oogoo0=1oo`D000moo`0097oo0P004goo00<007ooOol0bgoo1@0057oo000T
Ool00`00Oomoo`0BOol00`00Oomoo`36Ool5000IOol002Aoo`03001oogoo019oo`03001oogoo0<=o
o`<001ioo`0000Aoo`00000000=oo`05001oogooOol00002Ool30004Ool2000=Ool00`00Oomoo`0C
Ool00`00Oomoo`2oOol3000QOol0009oo`03001oogoo00=oo`03001oo`0000Aoo`03001oogoo009o
o`04001oogoo000<Ool00`00Oomoo`0COol00`00Oomoo`2kOol4000TOol0009oo`03001oogoo00Ao
o`03001oogoo00=oo`03001oogoo009oo`04001oogoo000<Ool00`00Oomoo`0COol00`00Oomoo`2h
Ool3000XOol0009oo`03001oogoo00=oo`03001oo`0000Aoo`03001oogoo009oo`04001oogoo000<
Ool2000DOol00`00Oomoo`2eOol3000[Ool0009oo`03001oogoo009oo`05001oogooOol00003Ool0
0`00Oomoo`02Ool01000Oomoo`0037oo00<007ooOol057oo00<007ooOol0/Goo0`00;Woo00000goo
0000000;Ool20005Ool20009Ool01@00Oomoogoo00005Woo00<007ooOol0[goo0P00<Goo000JOol4
0002Ool01@00Oomoogoo00005Woo00<007ooOol0[Goo0P00<goo000POol01@00Oomoogoo00005Woo
00<007ooOol0Zgoo0P00=Goo000QOol01000Oomoo`005goo00<007ooOol0Z7oo0P00=goo000OOol3
0002Ool2000FOol00`00Oomoo`2VOol2000iOol002Aoo`03001oogoo01Eoo`03001oogoo0:=oo`<0
03]oo`0097oo00<007ooOol05Goo00<007ooOol0XGoo0P00?Woo000TOol00`00Oomoo`0FOol00`00
Oomoo`2MOol30010Ool002Aoo`03001oogoo01Ioo`03001oogoo09]oo`8004=oo`0097oo0P005goo
00<007ooOol0VGoo0P00AGoo000TOol00`00Oomoo`0FOol00`00Oomoo`2FOol30017Ool002Aoo`03
001oogoo01Moo`03001oogoo09=oo`8004Yoo`0097oo00<007ooOol05goo00<007ooOol0TGoo0P00
C7oo000TOol00`00Oomoo`0GOol00`00Oomoo`2?Ool2001>Ool002Aoo`03001oogoo01Moo`03001o
ogoo08ioo`03001oogoo04ioo`0097oo0P0067oo00<007ooOol0S7oo0P00DGoo000TOol00`00Oomo
o`0HOol00`00Oomoo`2:Ool00`00Oomoo`1AOol002Aoo`03001oogoo01Qoo`03001oogoo08Qoo`80
05Aoo`0097oo00<007ooOol067oo00<007ooOol0Qgoo00<007ooOol0E7oo000TOol00`00Oomoo`0H
Ool00`00Oomoo`25Ool2001GOol002Aoo`03001oogoo01Uoo`03001oogoo08=oo`03001oogoo05Mo
o`0097oo0P006Woo00<007ooOol0PGoo0P00FWoo000TOol00`00Oomoo`0IOol00`00Oomoo`20Ool0
0`00Oomoo`1JOol00003Ool000000080009oo`05001oogooOol00002Ool30004Ool2000=Ool00`00
Oomoo`0IOol00`00Oomoo`1oOol00`00Oomoo`1KOol0009oo`03001oogoo00=oo`03001oo`0000Ao
o`03001oogoo009oo`04001oogoo000<Ool00`00Oomoo`0IOol00`00Oomoo`1mOol2001NOol000=o
o`03001oogoo00=oo`03001oogoo00=oo`03001oogoo009oo`04001oogoo000<Ool00`00Oomoo`0J
Ool00`00Oomoo`1kOol00`00Oomoo`1NOol000Aoo`07001oogooOol007oo000017oo00<007ooOol0
0Woo00@007ooOol000aoo`03001oogoo01Yoo`03001oogoo07Uoo`80065oo`0000Eoo`00Oomoo`00
009oo`05001oogooOol00003Ool00`00Oomoo`02Ool01000Oomoo`0037oo0P006goo00<007ooOol0
N7oo00<007ooOol0HGoo0002Ool2000:Ool20005Ool2000=Ool00`00Oomoo`0JOol00`00Oomoo`1g
Ool00`00Oomoo`1ROol0021oo`05001oogooOol0000MOol00`00Oomoo`1eOol00`00Oomoo`1SOol0
01Yoo`@0009oo`05001oogooOol0000MOol00`00Oomoo`1cOol2001VOol0021oo`05001oogooOol0
000MOol00`00Oomoo`1bOol00`00Oomoo`1VOol0025oo`03001oogoo008001aoo`03001oogoo075o
o`03001oogoo06Moo`007goo0`000Woo00<007ooOol06goo00<007ooOol0L7oo00<007ooOol0J7oo
000TOol00`00Oomoo`0LOol00`00Oomoo`1^Ool00`00Oomoo`1YOol002Aoo`03001oogoo01aoo`03
001oogoo06aoo`8006aoo`0097oo00<007ooOol077oo00<007ooOol0Jgoo00<007ooOol0K7oo000T
Ool00`00Oomoo`0LOol00`00Oomoo`1ZOol00`00Oomoo`1]Ool002Aoo`8001eoo`03001oogoo06Uo
o`03001oogoo06ioo`0097oo00<007ooOol07Goo00<007ooOol0Igoo00<007ooOol0Kgoo000TOol0
0`00Oomoo`0MOol00`00Oomoo`1VOol00`00Oomoo`1`Ool002Aoo`03001oogoo01eoo`03001oogoo
06Eoo`03001oogoo075oo`0097oo00<007ooOol07Goo00<007ooOol0I7oo00<007ooOol0LWoo000T
Ool00`00Oomoo`0MOol00`00Oomoo`1SOol00`00Oomoo`1cOol002Aoo`8001moo`03001oogoo065o
o`03001oogoo07Aoo`0097oo00<007ooOol07Woo00<007ooOol0HGoo00<007ooOol0M7oo000TOol0
0`00Oomoo`0NOol00`00Oomoo`1POol00`00Oomoo`1eOol002Aoo`03001oogoo01ioo`03001oogoo
05moo`03001oogoo07Ioo`0097oo00<007ooOol07Woo00<007ooOol0GWoo00<007ooOol0Mgoo000T
Ool2000POol00`00Oomoo`1LOol00`00Oomoo`1hOol002Aoo`03001oogoo01moo`03001oogoo05]o
o`03001oogoo07Uoo`0097oo00<007ooOol07goo00<007ooOol0FWoo00<007ooOol0NWoo000017oo
000000000goo00D007ooOomoo`00009oo`<000Aoo`8000eoo`03001oogoo01moo`03001oogoo05Uo
o`03001oogoo07]oo`0017oo00L007ooOomoo`00Ool00004Ool00`00Oomoo`02Ool01000Oomoo`00
37oo00<007ooOol07goo00<007ooOol0F7oo00<007ooOol0O7oo0004Ool00`00Oomoo`02Ool00`00
Oomoo`03Ool00`00Oomoo`02Ool01000Oomoo`0037oo00<007ooOol07goo00<007ooOol0Egoo00<0
07ooOol0OGoo0002Ool20004Ool00`00Ool00004Ool00`00Oomoo`02Ool01000Oomoo`0037oo0P00
8Goo00<007ooOol0EGoo00<007ooOol0OWoo0004Ool01000Oomoo`000goo00D007ooOomoo`0000Ao
o`04001oogoo000<Ool00`00Oomoo`0POol00`00Oomoo`1EOol00`00Oomoo`1nOol00004Ool00000
000:Ool20005Ool20009Ool01@00Oomoogoo00008Woo00<007ooOol0E7oo00<007ooOol0Ogoo000J
Ool40002Ool01@00Oomoogoo00008Woo00<007ooOol0Dgoo00<007ooOol0P7oo000POol01@00Oomo
ogoo00008Woo00<007ooOol0DWoo00<007ooOol0PGoo000QOol01000Oomoo`008goo00<007ooOol0
D7oo00<007ooOol0PWoo000OOol30002Ool2000ROol00`00Oomoo`1?Ool00`00Oomoo`23Ool002Ao
o`03001oogoo025oo`03001oogoo04ioo`03001oogoo08Aoo`0097oo00<007ooOol08Goo00<007oo
Ool0CGoo00<007ooOol0QGoo000TOol00`00Oomoo`0QOol00`00Oomoo`1<Ool00`00Oomoo`26Ool0
02Aoo`03001oogoo029oo`03001oogoo04Yoo`03001oogoo08Moo`0097oo0P008goo00<007ooOol0
BGoo00<007ooOol0R7oo000TOol00`00Oomoo`0ROol00`00Oomoo`18Ool00`00Oomoo`29Ool002Ao
o`03001oogoo029oo`03001oogoo04Qoo`03001oogoo08Uoo`0097oo00<007ooOol08goo00<007oo
Ool0AWoo00<007ooOol0RWoo000TOol00`00Oomoo`0SOol00`00Oomoo`15Ool00`00Oomoo`2;Ool0
02Aoo`03001oogoo02=oo`03001oogoo04Aoo`03001oogoo08aoo`0097oo0P0097oo00<007ooOol0
A7oo00<007ooOol0S7oo000TOol00`00Oomoo`0TOol00`00Oomoo`12Ool00`00Oomoo`2=Ool002Ao
o`03001oogoo02Aoo`03001oogoo045oo`03001oogoo08ioo`0097oo00<007ooOol097oo00<007oo
Ool0@7oo00<007ooOol0Sgoo000TOol00`00Oomoo`0TOol00`00Oomoo`0oOol00`00Oomoo`2@Ool0
02Aoo`03001oogoo02Aoo`03001oogoo03moo`03001oogoo091oo`0097oo0P009Woo00<007ooOol0
?Goo00<007ooOol0TGoo000TOol00`00Oomoo`0UOol00`00Oomoo`0lOol00`00Oomoo`2BOol0009o
o`<0009oo`05001oogooOol00002Ool30004Ool2000=Ool00`00Oomoo`0UOol00`00Oomoo`0kOol0
0`00Oomoo`2COol000=oo`03001oogoo009oo`03001oo`0000Aoo`03001oogoo009oo`04001oogoo
000<Ool00`00Oomoo`0UOol00`00Oomoo`0kOol00`00Oomoo`2COol00003Ool00000008000Aoo`03
001oogoo00=oo`03001oogoo009oo`04001oogoo000<Ool00`00Oomoo`0VOol00`00Oomoo`0iOol0
0`00Oomoo`2DOol00004Ool007oo0004Ool00`00Ool00004Ool00`00Oomoo`02Ool01000Oomoo`00
37oo0P009goo00<007ooOol0>7oo00<007ooOol0UGoo000017oo001oo`000goo00D007ooOomoo`00
00=oo`03001oogoo009oo`04001oogoo000<Ool00`00Oomoo`0VOol00`00Oomoo`0gOol00`00Oomo
o`2FOol0009oo`8000Yoo`8000Eoo`8000Uoo`05001oogooOol0000XOol00`00Oomoo`0gOol00`00
Oomoo`2FOol001Yoo`@0009oo`05001oogooOol0000YOol00`00Oomoo`0eOol00`00Oomoo`2GOol0
021oo`05001oogooOol0000YOol00`00Oomoo`0dOol00`00Oomoo`2HOol0025oo`04001oogoo000Y
Ool00`00Oomoo`0dOol00`00Oomoo`2HOol001moo`<0009oo`8002Qoo`03001oogoo03=oo`03001o
ogoo09Uoo`0097oo00<007ooOol0:7oo00<007ooOol0<Goo00<007ooOol0VWoo000TOol00`00Oomo
o`0XOol00`00Oomoo`0`Ool00`00Oomoo`2KOol002Aoo`03001oogoo02Qoo`03001oogoo031oo`03
001oogoo09]oo`0097oo00<007ooOol0:Goo00<007ooOol0;Woo00<007ooOol0W7oo000TOol00`00
Oomoo`0YOol00`00Oomoo`0]Ool00`00Oomoo`2MOol002Aoo`8002Yoo`03001oogoo02eoo`03001o
ogoo09eoo`0097oo00<007ooOol0:Woo00<007ooOol0:goo00<007ooOol0WWoo000TOol00`00Oomo
o`0ZOol00`00Oomoo`0ZOol00`00Oomoo`2OOol002Aoo`03001oogoo02Yoo`03001oogoo02Uoo`03
001oogoo0:1oo`0097oo00<007ooOol0:goo00<007ooOol0:7oo00<007ooOol0X7oo000TOol2000/
Ool00`00Oomoo`0WOol00`00Oomoo`2QOol002Aoo`03001oogoo02]oo`03001oogoo02Ioo`03001o
ogoo0:9oo`0097oo00<007ooOol0;7oo00<007ooOol097oo00<007ooOol0Xgoo000TOol00`00Oomo
o`0/Ool00`00Oomoo`0SOol00`00Oomoo`2TOol002Aoo`03001oogoo02eoo`03001oogoo029oo`03
001oogoo0:Aoo`0097oo00<007ooOol0;Goo00<007ooOol08Goo00<007ooOol0YGoo000TOol2000_
Ool00`00Oomoo`0OOol00`00Oomoo`2VOol002Aoo`03001oogoo02ioo`03001oogoo01ioo`03001o
ogoo0:Moo`0097oo00<007ooOol0;goo00<007ooOol07Goo00<007ooOol0Ygoo000017oo00000000
0goo00D007ooOomoo`00009oo`<000Aoo`8000eoo`03001oogoo02moo`03001oogoo01aoo`03001o
ogoo0:Qoo`0017oo00L007ooOomoo`00Ool00004Ool00`00Oomoo`02Ool01000Oomoo`0037oo00<0
07ooOol0;goo00<007ooOol06goo00<007ooOol0ZGoo0004Ool00`00Oomoo`02Ool00`00Oomoo`03
Ool00`00Oomoo`02Ool01000Oomoo`0037oo00<007ooOol0<7oo00<007ooOol06Goo00<007ooOol0
ZWoo000017oo0000000017oo00<007oo000017oo00<007ooOol00Woo00@007ooOol000aoo`80035o
o`03001oogoo01Qoo`03001oogoo0:]oo`0000=oo`00Ool017oo00D007ooOomoo`0000=oo`03001o
ogoo009oo`04001oogoo000<Ool00`00Oomoo`0aOol00`00Oomoo`0EOol2002^Ool00003Ool00000
008000Uoo`8000Eoo`8000Uoo`05001oogooOol0000dOol00`00Oomoo`0COol00`00Oomoo`2^Ool0
01Yoo`@0009oo`05001oogooOol0000eOol00`00Oomoo`0AOol00`00Oomoo`2_Ool0021oo`05001o
ogooOol0000eOol00`00Oomoo`0@Ool00`00Oomoo`2`Ool0025oo`04001oogoo000fOol00`00Oomo
o`0=Ool2002cOol001moo`<0009oo`8003Ioo`03001oogoo00]oo`03001oogoo0;=oo`0097oo00<0
07ooOol0=Woo0P002Woo00<007ooOol0]7oo000TOol00`00Oomoo`0hOol30004Ool3002gOol002Ao
o`03001oogoo03Yoo`D00;Yoo`0097oo00<007ooOol0nGoo000TOol2003jOol002Aoo`03001oogoo
0?Uoo`0097oo00<007ooOol0nGoo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00001\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-4.44017, -6.00368, \
0.122614, 3.51564}}]
}, Closed]],

Cell["\<\
Here is a genealogy where the number of mutations leading down to \
each node is held as the first element of the information list:\
\>", "Text"],

Cell[BoxData[
    \(\(g2 = 
        Node[4, {0}, {Node[1, {1}, {Node[a, {0}, {}], Node[c, {1}, {}]}], 
            Node[3, {2}, {Node[d, {2}, {}], 
                Node[2, {4}, {Node[b, {1}, {}], 
                    Node[e, {2}, {}]}]}]}];\)\)], "Input",
  CellLabel->"In[316]:="],

Cell["The exact probability is the same as before:", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(ep2 = 
      ExactProbability[g2, \[Theta], 
        NodeFunction \[Rule] \((#2\[LeftDoubleBracket]1\[RightDoubleBracket] \
&)\)]\)], "Input",
  CellLabel->"In[320]:="],

Cell[BoxData[
    \(\((\[Theta]\^13\ \((13795291201536 + 50131091662848\ \[Theta] + 
              81043083145728\ \[Theta]\^2 + 76947429536640\ \[Theta]\^3 + 
              47609208437792\ \[Theta]\^4 + 20088043157072\ \[Theta]\^5 + 
              5860754353968\ \[Theta]\^6 + 1168599301216\ \[Theta]\^7 + 
              152522957642\ \[Theta]\^8 + 11773613661\ \[Theta]\^9 + 
              408357224\ \[Theta]\^10)\))\)/\((1944000000\ \((1 + \[Theta])\)\
\^4\ \((2 + \[Theta])\)\^8\ \((3 + \[Theta])\)\^8\ \((4 + \
\[Theta])\)\^7)\)\)], "Output",
  CellLabel->"Out[320]="]
}, Closed]],

Cell[TextData[Cell[BoxData[
    FormBox[GridBox[{
          {\(ExactProbability[
              S, \[Theta]]\), \(uses\ the\ generating\ function\ over\ all\ \
topologies\ to\ find\ the\ net\ probability\ of\ the\ configuration\ of\ \
mutations\ represented\ by\ the\ matrix\ \(\(S\)\(.\)\)\)}
          }], TraditionalForm]]]], "DefinitionBox"],

Cell["Here is a set of 5 alleles which carry mutations at 9 sites:", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(S // MatrixForm\)], "Input",
  CellLabel->"In[323]:="],

Cell[BoxData[
    TagBox[
      RowBox[{"(", GridBox[{
            {"0", "0", "0", "0", "0", "0", "0", "0", "0"},
            {"1", "1", "1", "0", "0", "1", "0", "0", "0"},
            {"1", "1", "1", "0", "0", "0", "0", "0", "0"},
            {"0", "0", "0", "1", "1", "0", "1", "0", "0"},
            {"0", "0", "0", "1", "1", "0", "0", "1", "1"}
            }], ")"}],
      (MatrixForm[ #]&)]], "Output",
  CellLabel->"Out[323]//MatrixForm="]
}, Closed]],

Cell["This is the probability of that configuration:", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(ExactProbability[S, \[Theta]]\)], "Input",
  CellLabel->"In[364]:="],

Cell[BoxData[
    \(\((\[Theta]\^9\ \((3141821952 + 13483366272\ \[Theta] + 
              25217739648\ \[Theta]\^2 + 26937488864\ \[Theta]\^3 + 
              18096993360\ \[Theta]\^4 + 7930297836\ \[Theta]\^5 + 
              2268383044\ \[Theta]\^6 + 408842683\ \[Theta]\^7 + 
              42184385\ \[Theta]\^8 + 
              1900974\ \[Theta]\^9)\))\)/\((259200000\ \((1 + \[Theta])\)\^4\ \
\((2 + \[Theta])\)\^6\ \((3 + \[Theta])\)\^7\ \((4 + \[Theta])\)\^5)\)\)], \
"Output",
  CellLabel->"Out[364]="]
}, Closed]],

Cell["\<\
This method can be used for moderate sized genealogies, but fails \
for more than a few mutations: multiple derivatives are needed.\
\>", "Text"]
}, Open  ]]
},
FrontEndVersion->"4.0 for Macintosh",
ScreenRectangle->{{0, 1152}, {0, 748}},
WindowSize->{831, 611},
WindowMargins->{{Automatic, 45}, {Automatic, 21}},
StyleDefinitions -> "HelpBrowser.nb",
MacintoshSystemPageSetup->"\<\
00<0001804P000000`d26_oQon@3:`8g0dL5N`?P0080001804P000000]P2:001
0000I00000400`<30?l00BL?00400@0000000000000006P801T1T00000000000
00000000004000000000000000000000\>"
]


(***********************************************************************
Cached data follows.  If you edit this Notebook file directly, not using
Mathematica, you must remove the line containing CacheID at the top of 
the file.  The cache data will then be recreated when you save this file 
from within Mathematica.
***********************************************************************)

(*CellTagsOutline
CellTagsIndex->{
  "ExactProbability"->{
    Cell[1824, 54, 716, 13, 88, "DefinitionBox",
      CellTags->{"ExactProbability", "NodeFunction"}]},
  "NodeFunction"->{
    Cell[1824, 54, 716, 13, 88, "DefinitionBox",
      CellTags->{"ExactProbability", "NodeFunction"}]}
  }
*)

(*CellTagsIndex
CellTagsIndex->{
  {"ExactProbability", 26324, 804},
  {"NodeFunction", 26449, 807}
  }
*)

(*NotebookFileOutline
Notebook[{

Cell[CellGroupData[{
Cell[1739, 51, 82, 1, 24, "SubsubsectionIcon"],
Cell[1824, 54, 716, 13, 88, "DefinitionBox",
  CellTags->{"ExactProbability", "NodeFunction"}],
Cell[2543, 69, 164, 4, 22, "Text"],

Cell[CellGroupData[{
Cell[2732, 77, 127, 3, 26, "Input"],
Cell[2862, 82, 620, 12, 65, "Output"]
}, Closed]],
Cell[3497, 97, 142, 3, 18, "Text"],

Cell[CellGroupData[{
Cell[3664, 104, 93, 2, 26, "Input"],
Cell[3760, 108, 574, 9, 58, "Output"]
}, Closed]],
Cell[4349, 120, 95, 3, 18, "Text"],

Cell[CellGroupData[{
Cell[4469, 127, 91, 2, 26, "Input"],
Cell[4563, 131, 17738, 558, 184, 6296, 412, "GraphicsData", "PostScript", \
"Graphics"]
}, Closed]],
Cell[22316, 692, 155, 3, 18, "Text"],
Cell[22474, 697, 281, 6, 42, "Input"],
Cell[22758, 705, 60, 0, 22, "Text"],

Cell[CellGroupData[{
Cell[22843, 709, 188, 5, 26, "Input"],
Cell[23034, 716, 574, 9, 58, "Output"]
}, Closed]],
Cell[23623, 728, 344, 6, 48, "DefinitionBox"],
Cell[23970, 736, 76, 0, 22, "Text"],

Cell[CellGroupData[{
Cell[24071, 740, 74, 2, 26, "Input"],
Cell[24148, 744, 446, 10, 94, "Output"]
}, Closed]],
Cell[24609, 757, 62, 0, 18, "Text"],

Cell[CellGroupData[{
Cell[24696, 761, 88, 2, 26, "Input"],
Cell[24787, 765, 511, 9, 58, "Output"]
}, Closed]],
Cell[25313, 777, 155, 3, 18, "Text"]
}, Open  ]]
}
]
*)




(***********************************************************************
End of Mathematica Notebook file.
***********************************************************************)

