(***********************************************************************

                    Mathematica-Compatible Notebook

This notebook can be used on any computer system with Mathematica 4.0,
MathReader 4.0, or any compatible application. The data for the notebook 
starts with the line containing stars above.

To get the notebook into a Mathematica-compatible application, do one of 
the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing the 
word CacheID, otherwise Mathematica-compatible applications may try to 
use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
***********************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[      4398,        142]*)
(*NotebookOutlinePosition[      5625,        180]*)
(*  CellTagsIndexPosition[      5508,        173]*)
(*WindowFrame->Normal*)



Notebook[{

Cell[CellGroupData[{
Cell["\<\
The probability of family structures under simple coalescence\
\>", \
"SubsectionIcon"],

Cell[TextData[Cell[BoxData[
    FormBox[GridBox[{
          {\(FamilyProbability[
              S]\), \(gives\ the\ probability\ that\ the\ family\ structure\ \
S\ would\ be\ produced, \ \n
            given\ a\ certain\ number\ of\ coalescence\ \
\(\(events\)\(.\)\)\)},
          {\(\(SimplifyFamilies\)\(\ \)\), \(a\ rule\ which\ replaces\ \
duplications\ such\ as\ {{3, 1}, {2, 2}, {1, 2}}\ by\ {{3, 1}, {3, 2}}\)}
          }], TraditionalForm]]]], "DefinitionBox",
  CellTags->{"FamilyProbability", "SimplifyFamilies"}],

Cell[TextData[{
  "Given that a certain number of coalescence events have occurred (reducing \
the number of lineages from ",
  Cell[BoxData[
      \(TraditionalForm\`k\)]],
  " to ",
  Cell[BoxData[
      \(TraditionalForm\`j\)]],
  "), the probability of a certain family structure, FamilyProbability[S], is \
simply a combinatorial problem.   FamilyProbability[S] is calculated \
recursively; each family ",
  Cell[BoxData[
      \(TraditionalForm\`\(n\_i\ \)\)]],
  "could have arisen through coalescence of two smaller families, such that ",
  
  Cell[BoxData[
      \(TraditionalForm\`n\_i = \[Alpha] + \((n\_i - \[Alpha])\)\)]],
  "; therefore, FamilyProbability[] for ",
  Cell[BoxData[
      \(TraditionalForm\`j\)]],
  " lineages can be expressed as a sum over FamilyProbability[]'s for j+1 \
lineages, and so on up to ",
  "FamilyProbability",
  "[{1,1,1..}]=1 (since with no coalescence, families must have this \
structure). "
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(FamilyProbability[{1, 1, 1, 3, 3, 7}]\)], "Input",
  CellLabel->"In[151]:="],

Cell[BoxData[
    \(20\/1001\)], "Output",
  CellLabel->"Out[151]="]
}, Closed]],

Cell["\<\
This simplifies by removing duplicates from the frequencies of \
different kinds of family.\
\>", "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[
    \({{3, 1}, {2, 2}, {1, 2}} /. SimplifyFamilies\)], "Input",
  CellLabel->"In[155]:="],

Cell[BoxData[
    \({{3, 1}, {3, 2}}\)], "Output",
  CellLabel->"Out[155]="]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    \({FamilyProbability[{{3, 1}, {2, 2}, {1, 2}}], 
      FamilyProbability[{{3, 1}, {3, 2}}]}\)], "Input",
  CellLabel->"In[156]:="],

Cell[BoxData[
    \({5\/14, 5\/14}\)], "Output",
  CellLabel->"Out[156]="]
}, Closed]],

Cell["\<\
Note that FamilyProbability[] stores results, and can use a lot of \
memory for large numbers of lineages.  The key constraint, however, is that \
$RecursionLimit may need to be set to (say) 2048, rather than the default \
256.\
\>", "Text"]
}, Open  ]]
},
FrontEndVersion->"4.0 for Macintosh",
ScreenRectangle->{{0, 1024}, {0, 748}},
WindowSize->{520, 653},
WindowMargins->{{Automatic, 19}, {Automatic, -1}},
StyleDefinitions -> "HelpBrowser.nb",
MacintoshSystemPageSetup->"\<\
00`0001804P000000_02@?o/onh3109BI085:0?l0@00005X0FP000003[0;@001
0000I00100000@0000000BL?0040000000000000000000000000000000000?nL
ojH?50^J00P100000000000000000000\>"
]


(***********************************************************************
Cached data follows.  If you edit this Notebook file directly, not using
Mathematica, you must remove the line containing CacheID at the top of 
the file.  The cache data will then be recreated when you save this file 
from within Mathematica.
***********************************************************************)

(*CellTagsOutline
CellTagsIndex->{
  "FamilyProbability"->{
    Cell[1839, 56, 525, 10, 98, "DefinitionBox",
      CellTags->{"FamilyProbability", "SimplifyFamilies"}]},
  "SimplifyFamilies"->{
    Cell[1839, 56, 525, 10, 98, "DefinitionBox",
      CellTags->{"FamilyProbability", "SimplifyFamilies"}]}
  }
*)

(*CellTagsIndex
CellTagsIndex->{
  {"FamilyProbability", 5239, 163},
  {"SimplifyFamilies", 5373, 166}
  }
*)

(*NotebookFileOutline
Notebook[{

Cell[CellGroupData[{
Cell[1739, 51, 97, 3, 54, "SubsectionIcon"],
Cell[1839, 56, 525, 10, 98, "DefinitionBox",
  CellTags->{"FamilyProbability", "SimplifyFamilies"}],
Cell[2367, 68, 951, 25, 92, "Text"],

Cell[CellGroupData[{
Cell[3343, 97, 96, 2, 27, "Input"],
Cell[3442, 101, 68, 2, 36, "Output"]
}, Closed]],
Cell[3525, 106, 122, 3, 18, "MathCaption"],

Cell[CellGroupData[{
Cell[3672, 113, 103, 2, 27, "Input"],
Cell[3778, 117, 76, 2, 20, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[3891, 124, 148, 3, 23, "Input"],
Cell[4042, 129, 74, 2, 36, "Output"]
}, Closed]],
Cell[4131, 134, 251, 5, 46, "Text"]
}, Open  ]]
}
]
*)




(***********************************************************************
End of Mathematica Notebook file.
***********************************************************************)

