(***********************************************************************

                    Mathematica-Compatible Notebook

This notebook can be used on any computer system with Mathematica 4.0,
MathReader 4.0, or any compatible application. The data for the notebook 
starts with the line containing stars above.

To get the notebook into a Mathematica-compatible application, do one of 
the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing the 
word CacheID, otherwise Mathematica-compatible applications may try to 
use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
***********************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[     15747,        425]*)
(*NotebookOutlinePosition[     16631,        453]*)
(*  CellTagsIndexPosition[     16587,        449]*)
(*WindowFrame->Normal*)



Notebook[{
Cell["Family structures", "Chapter"],

Cell["This loads the package:", "MathCaption"],

Cell[BoxData[
    \(\(<< Genealogies`Genealogies`; \)\)], "Input",
  CellLabel->"In[679]:="],

Cell[CellGroupData[{

Cell["\<\
Family structure: NumberOfFamilies[], NumberOfLineages[], \
PairwiseIdentity[]\
\>", "SubsubsectionIcon"],

Cell["\<\
\tTracing back in time, genealogies coalesce into a smaller number \
of families, and eventually into one family, rooted at the common ancestor. A \
period of random drift, or an abrupt population bottleneck, can be \
represented by the net coalescence into families of different sizes.   The \
whole genealogy can be described by a sequence of family structures.  For the \
example above, this is:\
\>", "Text"],

Cell[BoxData[
    FormBox[
      InterpretationBox[GridBox[{
            {"1", "1", "1", "1", "1", "1", "1", "1"},
            {"1", "1", "1", "1", "1", "1", "2", "\<\"\"\>"},
            {"1", "1", "1", "1", "2", "2", "\<\"\"\>", "\<\"\"\>"},
            {"1", "2", "2", "3", "\<\"\"\>", "\<\"\"\>", "\<\"\"\>", 
              "\<\"\"\>"},
            {"2", "2", "4", "\<\"\"\>", "\<\"\"\>", "\<\"\"\>", "\<\"\"\>", 
              "\<\"\"\>"},
            {"2", "6", "\<\"\"\>", "\<\"\"\>", "\<\"\"\>", "\<\"\"\>", 
              "\<\"\"\>", "\<\"\"\>"},
            {"8", "\<\"\"\>", "\<\"\"\>", "\<\"\"\>", "\<\"\"\>", "\<\"\"\>", 
              "\<\"\"\>", "\<\"\"\>"}
            },
          RowSpacings->1,
          ColumnSpacings->3,
          RowAlignments->Baseline,
          ColumnAlignments->{Left}],
        TableForm[ {{1, 1, 1, 1, 1, 1, 1, 1}, {1, 1, 1, 1, 1, 1, 2}, {1, 1, 
          1, 1, 2, 2}, {1, 2, 2, 3}, {2, 2, 4}, {2, 6}, {8}}]], TextForm]], 
  "Text",
  CellLabel->"Out[98]//TableForm="],

Cell["\<\
These coalescences occur at the times {0.4, 1, 1.5, 1.7, 1.8, 2.3}. \
 The event at T=1.5 involves a coalescence of three lineages.\
\>", "Text"],

Cell["\<\
\tNote that this description discards information about which \
elements coalesce, but requires that the order of coalescence be known.  It \
is not equivalent to the description provided by CollapseGenealogy[], but \
contains different information.  It is useful when constructing random \
coalescences, because the choice of coalescence times can be separated from \
the topology of the coalescence.\
\>", "Text"],

Cell["\<\
\tA family structure can be represented in two ways; both can be \
used in (most of) the routines in this section.  Most direct is a list of the \
sizes of the various families of lineages that become related during a period \
of random drift: for example, {1,1,1,2,2,6} would represent three lineages \
which passed through unaffected, two sets of two lineages, and one of 6.  A \
more compact representation is {{3,1},{2,2},{1,6}}.  The compact \
representation is obtained from Frequencies[{1,1,1,2,2,6}], which is \
contained in Statistics`DataManipulation`.  That is used internally and must \
be loaded separately to be used explicitly.\
\>", "Text"],

Cell[TextData[Cell[BoxData[
    FormBox[GridBox[{
          {\({1, 1, 1, 2, 2, 6}\), \(A\ representation\ of\ three\ singlets, 
            \ two\ sets\ of\ two\ related\ genes, \ and\ one\ set\ of\ 6\)},
          {\({{3, 1}, {2, 2}, {1, 6}}\), 
            RowBox[{\(An\ equivalent\ representation\), ",", " ", 
              RowBox[{"as", " ", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{"{", 
                      StyleBox[\(#\ of\ instances, \ family\ size\),
                        FontSlant->"Italic"], "}"}], "..."}], "}"}]}]}]},
          {\(NumberOfFamilies[S]\), 
            \(gives\ the\ number\ of\ families\ 
              \((i . e . , \ the\ number\ of\ lineages\ before\ coalescence)
                \)\)},
          {\(NumberOfLineages[S]\ \), 
            \(gives\ the\ total\ number\ of\ lineages\ involved\)},
          {\(PairwiseIdentity[S]\ \), 
            \(gives\ the\ mean\ pairwise\ identity\ amongst\ the\ lineages\)}
          }], TraditionalForm]]]], "DefinitionBox"],

Cell["Here is a list of 6 families, making a total of 13 lineages.", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \({NumberOfFamilies[{1, 1, 1, 2, 2, 6}], 
      NumberOfLineages[{1, 1, 1, 2, 2, 6}]}\)], "Input",
  CellLabel->"In[8]:="],

Cell[BoxData[
    \({6, 13}\)], "Output",
  CellLabel->"Out[8]="]
}, Closed]],

Cell[TextData[{
  " The distribution of pairwise identity is found as F = ",
  Cell[BoxData[
      \(TraditionalForm\`\(\[Sum]\_i\( n\_i\)(n\_i - 1)\)\/\(k(k - 1)\)\)]],
  ".  Other features could be found in a similar way.  However, the overall \
length (say) would also need the dates of the coalescences, as well as the \
sizes of the families they produce."
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(PairwiseIdentity[{1, 1, 1, 2, 2, 6}]\)], "Input",
  CellLabel->"In[9]:="],

Cell[BoxData[
    \(17\/78\)], "Output",
  CellLabel->"Out[9]="]
}, Closed]]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
Genealogies and family structure: OrderedNodes[], \
GenealogyToFamily[], FamilyToGenealogy[]\
\>", "SubsubsectionIcon"],

Cell["\<\
\tThis section provides methods for extracting the sequence of \
family structures from a genealogy, and conversely, for constructing a \
genealogy from a sequence of family structures.  In order to find the \
sequence of structures, information on the ordering of coalescences must be \
provided.  By convention, these are counted backwards in time.\
\>", "Text"],

Cell[TextData[Cell[BoxData[
    FormBox[GridBox[{
          {\(OrderedNodes[g, f]\), 
            \(gives\ a\ list\ of\ the\ nodes\ in\ the\ genealogy, \ 
            in\ the\ order\ defined\ by\ f[\ i, {info}]\)},
          {\(OrderedNodes[g, f, Node \[Rule] True]\), 
            \(only\ lists\ internal\ \(nodes . \)\)}
          }], TraditionalForm]]]], "DefinitionBox"],

Cell[TextData[
"In the example above, the time of coalescence was given in the form \
Node[label,{t},{Node[],Node[],\[Ellipsis]}].  Hence, the function \
(First[#2]&) extracts the coalescence times, which can then be used to order \
the nodes.  Note that it is possible to label the nodes as lists."], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(OrderedNodes[tr, \((First[#2]&)\)]\)], "Input",
  CellLabel->"In[142]:="],

Cell[BoxData[
    \({{a}, {b}, {c}, {d}, {e}, {f}, {g}, {h}, {a, b}, {c, d}, {e, f, g}, {e, 
        f, g, h}, {c, d, e, f, g, h}, {a, b, c, d, e, f, g, h}}\)], "Output",
  CellLabel->"Out[142]="]
}, Closed]],

Cell["\<\
Setting Node\[Rule]True ensures that only non-terminal nodes are \
listed:\
\>", "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[
    \(OrderedNodes[tr, \((First[#2]&)\), Node \[Rule] True]\)], "Input",
  CellLabel->"In[145]:="],

Cell[BoxData[
    \({{a, b}, {c, d}, {e, f, g}, {e, f, g, h}, {c, d, e, f, g, h}, {a, b, c, 
        d, e, f, g, h}}\)], "Output",
  CellLabel->"Out[145]="]
}, Closed]],

Cell[TextData[Cell[BoxData[
    FormBox[GridBox[{
          {\(GenealogyToFamily[g, f]\), 
            \(gives\ a\ list\ of\ the\ family\ structures\ following\ 
              successive\ coalescences . \ The\ function\ f[i, {info}]\ gives
              \ the\ ordering\ of\ the\ coalescence\ for\ node\ \(i . \)\)}
          }], TraditionalForm]]]], "DefinitionBox"],

Cell["\<\
This gives a list of the family structures associated with the \
genealogy.\
\>", "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{" ", 
      RowBox[{
        RowBox[{
          FormBox[\(fs = GenealogyToFamily\),
            "TraditionalForm"], "[", \(tr, \((First[#2]&)\)\), "]"}], "//", 
        "TableForm"}]}]], "Input",
  CellLabel->"In[10]:="],

Cell[BoxData[
    InterpretationBox[GridBox[{
          {"1", "1", "1", "1", "1", "1", "1", "1"},
          {"2", "1", "1", "1", "1", "1", "1", "\<\"\"\>"},
          {"2", "2", "1", "1", "1", "1", "\<\"\"\>", "\<\"\"\>"},
          {"2", "2", "3", "1", "\<\"\"\>", "\<\"\"\>", "\<\"\"\>", 
            "\<\"\"\>"},
          {"2", "2", "4", "\<\"\"\>", "\<\"\"\>", "\<\"\"\>", "\<\"\"\>", 
            "\<\"\"\>"},
          {"2", "6", "\<\"\"\>", "\<\"\"\>", "\<\"\"\>", "\<\"\"\>", 
            "\<\"\"\>", "\<\"\"\>"},
          {"8", "\<\"\"\>", "\<\"\"\>", "\<\"\"\>", "\<\"\"\>", "\<\"\"\>", 
            "\<\"\"\>", "\<\"\"\>"}
          },
        RowSpacings->1,
        ColumnSpacings->3,
        RowAlignments->Baseline,
        ColumnAlignments->{Left}],
      TableForm[ {{1, 1, 1, 1, 1, 1, 1, 1}, {2, 1, 1, 1, 1, 1, 1}, {2, 2, 1, 
        1, 1, 1}, {2, 2, 3, 1}, {2, 2, 4}, {2, 6}, {8}}]]], "Output",
  CellLabel->"Out[10]//TableForm="]
}, Closed]],

Cell[TextData[Cell[BoxData[
    FormBox[GridBox[{
          {\(FamilyToGenealogy[{a, b, c, \[Ellipsis]}, S]\), 
            \(gives\ a\ randomly\ constructed\ genealogy\ which\ satistfies\ 
              the\ sequence\ of\ family\ structures\ S, \ 
            and\ which\ relates\ \({a, b, c, \[Ellipsis]} . \)\ \), 
            "\[Placeholder]"},
          {\(NodeLabels \[Rule] {label\_1, \[Ellipsis]}\), 
            \(allows\ an\ arbitrary\ list\ of\ labels\ for\ the\ internal\ 
              \(nodes . \)\), "\[Placeholder]"},
          {\(NodeInformation \[Rule] {info\_1, \[Ellipsis]}\), 
            \(allows\ an\ arbitrary\ list\ of\ information\ for\ the\ internal
              \ \(nodes . \)\), "\[Placeholder]"},
          {\(LeafInformation \[Rule] {info\_1, \[Ellipsis]}\), 
            \(allows\ an\ arbitrary\ list\ of\ information\ for\ the\ terminal
              \ \(nodes . \)\), "\[Placeholder]"}
          }], TraditionalForm]]]], "DefinitionBox"],

Cell["\<\
This reconstructs a genealogy which has the same structure as the \
example above:\
\>", "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[
    \(FamilyToGenealogy[{a, b, c, d, e, f, g, h, i, j}, sf]\)], "Input",
  CellLabel->"In[12]:="],

Cell[BoxData[
    \(Node[
      10, {}, {Node[
          9, {}, {Node[5, {}, {Node[g, {}, {}], Node[h, {}, {}]}], 
            Node[8, {}, {Node[b, {}, {}], 
                Node[7, {}, {Node[i, {}, {}], 
                    Node[6, {}, {Node[f, {}, {}], 
                        Node[4, {}, {Node[e, {}, {}], 
                            Node[3, {}, {
                                Node[1, {}, {Node[d, {}, {}], 
                                    Node[j, {}, {}]}], 
                                Node[2, {}, {Node[a, {}, {}], 
                                    Node[c, {}, {}]}]}]}]}]}]}]}]}]\)], 
  "Output",
  CellLabel->"Out[12]="]
}, Closed]],

Cell[TextData[{
  "However, ",
  StyleBox["which",
    FontSlant->"Italic"],
  " elements are combined is random."
}], "Text"],

Cell["\<\
By default,  The terminal nodes are labelled by \
{a,b,c,\[Ellipsis]}, and the internal nodes are labelled by integers giving \
the order of the coalescence events.  However, these defaults can be changes \
by supplying optional lists. \
\>", "Text"],

Cell["\<\
Here, coalescence times are specified for leaves and for internal \
nodes:\
\>", "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[
    \(FamilyToGenealogy[{a, b, c, d, e, f, g, h, i, j}, sf, 
      NodeLabels 
        \[Rule] {node\_1, node\_2, node\_3, node\_4, node\_5, node\_6, 
          node\_7, node\_8, node\_9, node\_10}, 
      NodeInformation \[Rule] \((List/@RandomCoalescenceTimes[10])\), 
      LeafInformation \[Rule] Array[{0}&, 10]]\)], "Input",
  CellLabel->"In[8]:="],

Cell[BoxData[
    \(Node[
      node\_10, {4.56406406717318802`}, {
        Node[node\_9, {4.56406406717318802`}, {
            Node[node\_5, {0.405501312201995034`}, {Node[f, {0}, {}], 
                Node[i, {0}, {}]}], 
            Node[node\_8, {1.48003471702607569`}, {Node[b, {0}, {}], 
                Node[node\_7, {0.83172592321207972`}, {Node[d, {0}, {}], 
                    Node[node\_6, {0.609678770905849809`}, {Node[h, {0}, {}], 
                        Node[node\_4, {0.246451888070433389`}, {
                            Node[c, {0}, {}], 
                            Node[node\_3, {0.0803130837597443481`}, {
                                Node[node\_1, {0.0244798434913901896`}, {
                                    Node[a, {0}, {}], Node[g, {0}, {}]}], 
                                Node[node\_2, {0.0545679545412174249`}, {
                                    Node[e, {0}, {}], 
                                    Node[j, {0}, {}]}]}]}]}]}]}]}]}]\)], 
  "Output",
  CellLabel->"Out[8]="]
}, Closed]],

Cell["\<\
Note that  with n items, there are n nodes, and so all the optional \
lists must have length n.\
\>", "Text"],

Cell["\<\
FamilyToGenealogy[] and RandomFamilies[] can be usd to generate \
random genealogies under the coalescent process.  For example:\
\>", \
"MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[
    \(FamilyToGenealogy[{a, b, c, d, e, f, g, h, i, j}, RandomFamilies[10], 
      NodeInformation \[Rule] \((List/@RandomCoalescenceTimes[10])\), 
      LeafInformation \[Rule] Array[{0}&, 10]]\)], "Input",
  CellLabel->"In[14]:="],

Cell[BoxData[
    \(Node[
      10, {1.49683687479109828`}, {
        Node[9, {1.49683687479109828`}, {
            Node[7, {0.839943991659580646`}, {Node[a, {0}, {}], 
                Node[j, {0}, {}]}], 
            Node[8, {0.858889969481490567`}, {Node[i, {0}, {}], 
                Node[6, {0.443235152734892956`}, {
                    Node[5, {0.277598113493896114`}, {Node[d, {0}, {}], 
                        Node[h, {0}, {}]}], 
                    Node[4, {0.244939870829094896`}, {
                        Node[2, {0.0117586989859474866`}, {Node[b, {0}, {}], 
                            Node[e, {0}, {}]}], 
                        Node[3, {0.106978959192349765`}, {Node[f, {0}, {}], 
                            Node[1, {0.000018003531961334751`}, {
                                Node[c, {0}, {}], 
                                Node[g, {0}, {}]}]}]}]}]}]}]}]\)], "Output",
  CellLabel->"Out[14]="]
}, Closed]],

Cell["This procedure is used by RandomGenealogy[]", "Text"]
}, Open  ]]
},
FrontEndVersion->"4.0 for Macintosh",
ScreenRectangle->{{0, 1024}, {0, 748}},
WindowSize->{740, 681},
WindowMargins->{{132, Automatic}, {Automatic, 10}},
StyleDefinitions -> "HelpBrowser.nb",
MacintoshSystemPageSetup->"\<\
00`0001804P000000_02@?o/onh3109BI085:0?l0@00005X0FP000003[0;@001
0000I00100000@0000000BL?0040000000000000000000000000000000000?nL
ojH?50^J00P100000000000000000000\>"
]


(***********************************************************************
Cached data follows.  If you edit this Notebook file directly, not using
Mathematica, you must remove the line containing CacheID at the top of 
the file.  The cache data will then be recreated when you save this file 
from within Mathematica.
***********************************************************************)

(*CellTagsOutline
CellTagsIndex->{}
*)

(*CellTagsIndex
CellTagsIndex->{}
*)

(*NotebookFileOutline
Notebook[{
Cell[1717, 49, 36, 0, 59, "Chapter"],
Cell[1756, 51, 46, 0, 28, "MathCaption"],
Cell[1805, 53, 92, 2, 27, "Input"],

Cell[CellGroupData[{
Cell[1922, 59, 115, 3, 24, "SubsubsectionIcon"],
Cell[2040, 64, 422, 7, 50, "Text"],
Cell[2465, 73, 1014, 22, 117, "Text"],
Cell[3482, 97, 155, 3, 22, "Text"],
Cell[3640, 102, 425, 7, 50, "Text"],
Cell[4068, 111, 666, 10, 78, "Text"],
Cell[4737, 123, 1043, 20, 112, "DefinitionBox"],
Cell[5783, 145, 76, 0, 22, "Text"],

Cell[CellGroupData[{
Cell[5884, 149, 140, 3, 27, "Input"],
Cell[6027, 154, 65, 2, 20, "Output"]
}, Closed]],
Cell[6107, 159, 373, 7, 50, "Text"],

Cell[CellGroupData[{
Cell[6505, 170, 93, 2, 27, "Input"],
Cell[6601, 174, 64, 2, 36, "Output"]
}, Closed]]
}, Open  ]],

Cell[CellGroupData[{
Cell[6714, 182, 129, 3, 24, "SubsubsectionIcon"],
Cell[6846, 187, 374, 6, 50, "Text"],
Cell[7223, 195, 374, 7, 54, "DefinitionBox"],
Cell[7600, 204, 309, 4, 36, "Text"],

Cell[CellGroupData[{
Cell[7934, 212, 93, 2, 27, "Input"],
Cell[8030, 216, 196, 3, 35, "Output"]
}, Closed]],
Cell[8241, 222, 105, 3, 18, "MathCaption"],

Cell[CellGroupData[{
Cell[8371, 229, 112, 2, 27, "Input"],
Cell[8486, 233, 156, 3, 20, "Output"]
}, Closed]],
Cell[8657, 239, 367, 6, 46, "DefinitionBox"],
Cell[9027, 247, 106, 3, 28, "MathCaption"],

Cell[CellGroupData[{
Cell[9158, 254, 246, 7, 27, "Input"],
Cell[9407, 263, 951, 20, 126, "Output"]
}, Closed]],
Cell[10373, 286, 972, 16, 104, "DefinitionBox"],
Cell[11348, 304, 113, 3, 28, "MathCaption"],

Cell[CellGroupData[{
Cell[11486, 311, 111, 2, 27, "Input"],
Cell[11600, 315, 644, 14, 65, "Output"]
}, Closed]],
Cell[12259, 332, 126, 5, 20, "Text"],
Cell[12388, 339, 260, 5, 36, "Text"],
Cell[12651, 346, 105, 3, 28, "MathCaption"],

Cell[CellGroupData[{
Cell[12781, 353, 368, 7, 57, "Input"],
Cell[13152, 362, 1016, 18, 80, "Output"]
}, Closed]],
Cell[14183, 383, 119, 3, 18, "Text"],
Cell[14305, 388, 161, 4, 28, "MathCaption"],

Cell[CellGroupData[{
Cell[14491, 396, 246, 4, 42, "Input"],
Cell[14740, 402, 917, 17, 65, "Output"]
}, Closed]],
Cell[15672, 422, 59, 0, 18, "Text"]
}, Open  ]]
}
]
*)




(***********************************************************************
End of Mathematica Notebook file.
***********************************************************************)

