(***********************************************************************

                    Mathematica-Compatible Notebook

This notebook can be used on any computer system with Mathematica 4.0,
MathReader 4.0, or any compatible application. The data for the notebook 
starts with the line containing stars above.

To get the notebook into a Mathematica-compatible application, do one of 
the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing the 
word CacheID, otherwise Mathematica-compatible applications may try to 
use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
***********************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[    103785,       3244]*)
(*NotebookOutlinePosition[    105199,       3286]*)
(*  CellTagsIndexPosition[    105013,       3278]*)
(*WindowFrame->Normal*)



Notebook[{

Cell[CellGroupData[{
Cell["Finding possible orders", "SubsectionIcon"],

Cell[TextData[Cell[BoxData[
    FormBox[GridBox[{
          {\(PossibleCoalescenceOrder[
              g]\), \(lists\ the\ possible\ orders\ in\ which\ coalescence\ \
events\ might\ occur; \ 
            each\ is\ given\ by\ an\ ordered\ list\ of\ nodes . \ \ Leaves\ \
are\ listed\ first, \ and\ the\ root\ node\ \(\(last\)\(.\)\)\)}
          }], TraditionalForm]]]], "DefinitionBox",
  CellTags->"PossibleCoalescenceOrder"],

Cell["Here is a genealogy connecting eight lineages:", "MathCaption"],

Cell[BoxData[
    \(\(tr = 
      Node[{a, b, c, d, e, f, g, h}, {2.3}, {
          Node[{a, b}, {0.4}, {Node[{a}, {0}, {}], Node[{b}, {0}, {}]}], 
          Node[{c, d, e, f, g, h}, {1.8}, {
              Node[{c, d}, {1}, {Node[{c}, {0}, {}], Node[{d}, {0}, {}]}], 
              Node[{e, f, g, h}, {1.7}, {
                  Node[{e, f, g}, {1.5}, {Node[{e}, {0}, {}], 
                      Node[{f, g}, {0}, {Node[{f}, {0}, {}], 
                          Node[{g}, {0}, {}]}]}], Node[{h}, {0}, {}]}]}]}]; 
    \)\)], "Input",
  CellLabel->"In[121]:="],

Cell["\<\
These are the 24 possible orders in which coalescence events might \
occur:\
\>", "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[
    \(ords = PossibleCoalescenceOrder[tr]; ords // TableForm\)], "Input",
  CellLabel->"In[410]:="],

Cell[BoxData[
    InterpretationBox[GridBox[{
          {GridBox[{
                {"a"}
                },
              RowSpacings->0.25,
              ColumnSpacings->1,
              RowAlignments->Baseline,
              ColumnAlignments->{Left}], GridBox[{
                {"b"}
                },
              RowSpacings->0.25,
              ColumnSpacings->1,
              RowAlignments->Baseline,
              ColumnAlignments->{Left}], GridBox[{
                {"c"}
                },
              RowSpacings->0.25,
              ColumnSpacings->1,
              RowAlignments->Baseline,
              ColumnAlignments->{Left}], GridBox[{
                {"d"}
                },
              RowSpacings->0.25,
              ColumnSpacings->1,
              RowAlignments->Baseline,
              ColumnAlignments->{Left}], GridBox[{
                {"e"}
                },
              RowSpacings->0.25,
              ColumnSpacings->1,
              RowAlignments->Baseline,
              ColumnAlignments->{Left}], GridBox[{
                {"f"}
                },
              RowSpacings->0.25,
              ColumnSpacings->1,
              RowAlignments->Baseline,
              ColumnAlignments->{Left}], GridBox[{
                {"g"}
                },
              RowSpacings->0.25,
              ColumnSpacings->1,
              RowAlignments->Baseline,
              ColumnAlignments->{Left}], GridBox[{
                {"h"}
                },
              RowSpacings->0.25,
              ColumnSpacings->1,
              RowAlignments->Baseline,
              ColumnAlignments->{Left}], GridBox[{
                {"a"},
                {"b"}
                },
              RowSpacings->0.25,
              ColumnSpacings->1,
              RowAlignments->Baseline,
              ColumnAlignments->{Left}], GridBox[{
                {"c"},
                {"d"}
                },
              RowSpacings->0.25,
              ColumnSpacings->1,
              RowAlignments->Baseline,
              ColumnAlignments->{Left}], GridBox[{
                {"f"},
                {"g"}
                },
              RowSpacings->0.25,
              ColumnSpacings->1,
              RowAlignments->Baseline,
              ColumnAlignments->{Left}], GridBox[{
                {"e"},
                {"f"},
                {"g"}
                },
              RowSpacings->0.25,
              ColumnSpacings->1,
              RowAlignments->Baseline,
              ColumnAlignments->{Left}], GridBox[{
                {"e"},
                {"f"},
                {"g"},
                {"h"}
                },
              RowSpacings->0.25,
              ColumnSpacings->1,
              RowAlignments->Baseline,
              ColumnAlignments->{Left}], GridBox[{
                {"c"},
                {"d"},
                {"e"},
                {"f"},
                {"g"},
                {"h"}
                },
              RowSpacings->0.25,
              ColumnSpacings->1,
              RowAlignments->Baseline,
              ColumnAlignments->{Left}], GridBox[{
                {"a"},
                {"b"},
                {"c"},
                {"d"},
                {"e"},
                {"f"},
                {"g"},
                {"h"}
                },
              RowSpacings->0.25,
              ColumnSpacings->1,
              RowAlignments->Baseline,
              ColumnAlignments->{Left}]},
          {GridBox[{
                {"a"}
                },
              RowSpacings->0.25,
              ColumnSpacings->1,
              RowAlignments->Baseline,
              ColumnAlignments->{Left}], GridBox[{
                {"b"}
                },
              RowSpacings->0.25,
              ColumnSpacings->1,
              RowAlignments->Baseline,
              ColumnAlignments->{Left}], GridBox[{
                {"c"}
                },
              RowSpacings->0.25,
              ColumnSpacings->1,
              RowAlignments->Baseline,
              ColumnAlignments->{Left}], GridBox[{
                {"d"}
                },
              RowSpacings->0.25,
              ColumnSpacings->1,
              RowAlignments->Baseline,
              ColumnAlignments->{Left}], GridBox[{
                {"e"}
                },
              RowSpacings->0.25,
              ColumnSpacings->1,
              RowAlignments->Baseline,
              ColumnAlignments->{Left}], GridBox[{
                {"f"}
                },
              RowSpacings->0.25,
              ColumnSpacings->1,
              RowAlignments->Baseline,
              ColumnAlignments->{Left}], GridBox[{
                {"g"}
                },
              RowSpacings->0.25,
              ColumnSpacings->1,
              RowAlignments->Baseline,
              ColumnAlignments->{Left}], GridBox[{
                {"h"}
                },
              RowSpacings->0.25,
              ColumnSpacings->1,
              RowAlignments->Baseline,
              ColumnAlignments->{Left}], GridBox[{
                {"a"},
                {"b"}
                },
              RowSpacings->0.25,
              ColumnSpacings->1,
              RowAlignments->Baseline,
              ColumnAlignments->{Left}], GridBox[{
                {"f"},
                {"g"}
                },
              RowSpacings->0.25,
              ColumnSpacings->1,
              RowAlignments->Baseline,
              ColumnAlignments->{Left}], GridBox[{
                {"c"},
                {"d"}
                },
              RowSpacings->0.25,
              ColumnSpacings->1,
              RowAlignments->Baseline,
              ColumnAlignments->{Left}], GridBox[{
                {"e"},
                {"f"},
                {"g"}
                },
              RowSpacings->0.25,
              ColumnSpacings->1,
              RowAlignments->Baseline,
              ColumnAlignments->{Left}], GridBox[{
                {"e"},
                {"f"},
                {"g"},
                {"h"}
                },
              RowSpacings->0.25,
              ColumnSpacings->1,
              RowAlignments->Baseline,
              ColumnAlignments->{Left}], GridBox[{
                {"c"},
                {"d"},
                {"e"},
                {"f"},
                {"g"},
                {"h"}
                },
              RowSpacings->0.25,
              ColumnSpacings->1,
              RowAlignments->Baseline,
              ColumnAlignments->{Left}], GridBox[{
                {"a"},
                {"b"},
                {"c"},
                {"d"},
                {"e"},
                {"f"},
                {"g"},
                {"h"}
                },
              RowSpacings->0.25,
              ColumnSpacings->1,
              RowAlignments->Baseline,
              ColumnAlignments->{Left}]},
          {GridBox[{
                {"a"}
                },
              RowSpacings->0.25,
              ColumnSpacings->1,
              RowAlignments->Baseline,
              ColumnAlignments->{Left}], GridBox[{
                {"b"}
                },
              RowSpacings->0.25,
              ColumnSpacings->1,
              RowAlignments->Baseline,
              ColumnAlignments->{Left}], GridBox[{
                {"c"}
                },
              RowSpacings->0.25,
              ColumnSpacings->1,
              RowAlignments->Baseline,
              ColumnAlignments->{Left}], GridBox[{
                {"d"}
                },
              RowSpacings->0.25,
              ColumnSpacings->1,
              RowAlignments->Baseline,
              ColumnAlignments->{Left}], GridBox[{
                {"e"}
                },
              RowSpacings->0.25,
              ColumnSpacings->1,
              RowAlignments->Baseline,
              ColumnAlignments->{Left}], GridBox[{
                {"f"}
                },
              RowSpacings->0.25,
              ColumnSpacings->1,
              RowAlignments->Baseline,
              ColumnAlignments->{Left}], GridBox[{
                {"g"}
                },
              RowSpacings->0.25,
              ColumnSpacings->1,
              RowAlignments->Baseline,
              ColumnAlignments->{Left}], GridBox[{
                {"h"}
                },
              RowSpacings->0.25,
              ColumnSpacings->1,
              RowAlignments->Baseline,
              ColumnAlignments->{Left}], GridBox[{
                {"a"},
                {"b"}
                },
              RowSpacings->0.25,
              ColumnSpacings->1,
              RowAlignments->Baseline,
              ColumnAlignments->{Left}], GridBox[{
                {"f"},
                {"g"}
                },
              RowSpacings->0.25,
              ColumnSpacings->1,
              RowAlignments->Baseline,
              ColumnAlignments->{Left}], GridBox[{
                {"e"},
                {"f"},
                {"g"}
                },
              RowSpacings->0.25,
              ColumnSpacings->1,
              RowAlignments->Baseline,
              ColumnAlignments->{Left}], GridBox[{
                {"c"},
                {"d"}
                },
              RowSpacings->0.25,
              ColumnSpacings->1,
              RowAlignments->Baseline,
              ColumnAlignments->{Left}], GridBox[{
                {"e"},
                {"f"},
                {"g"},
                {"h"}
                },
              RowSpacings->0.25,
              ColumnSpacings->1,
              RowAlignments->Baseline,
              ColumnAlignments->{Left}], GridBox[{
                {"c"},
                {"d"},
                {"e"},
                {"f"},
                {"g"},
                {"h"}
                },
              RowSpacings->0.25,
              ColumnSpacings->1,
              RowAlignments->Baseline,
              ColumnAlignments->{Left}], GridBox[{
                {"a"},
                {"b"},
                {"c"},
                {"d"},
                {"e"},
                {"f"},
                {"g"},
                {"h"}
                },
              RowSpacings->0.25,
              ColumnSpacings->1,
              RowAlignments->Baseline,
              ColumnAlignments->{Left}]},
          {GridBox[{
                {"a"}
                },
              RowSpacings->0.25,
              ColumnSpacings->1,
              RowAlignments->Baseline,
              ColumnAlignments->{Left}], GridBox[{
                {"b"}
                },
              RowSpacings->0.25,
              ColumnSpacings->1,
              RowAlignments->Baseline,
              ColumnAlignments->{Left}], GridBox[{
                {"c"}
                },
              RowSpacings->0.25,
              ColumnSpacings->1,
              RowAlignments->Baseline,
              ColumnAlignments->{Left}], GridBox[{
                {"d"}
                },
              RowSpacings->0.25,
              ColumnSpacings->1,
              RowAlignments->Baseline,
              ColumnAlignments->{Left}], GridBox[{
                {"e"}
                },
              RowSpacings->0.25,
              ColumnSpacings->1,
              RowAlignments->Baseline,
              ColumnAlignments->{Left}], GridBox[{
                {"f"}
                },
              RowSpacings->0.25,
              ColumnSpacings->1,
              RowAlignments->Baseline,
              ColumnAlignments->{Left}], GridBox[{
                {"g"}
                },
              RowSpacings->0.25,
              ColumnSpacings->1,
              RowAlignments->Baseline,
              ColumnAlignments->{Left}], GridBox[{
                {"h"}
                },
              RowSpacings->0.25,
              ColumnSpacings->1,
              RowAlignments->Baseline,
              ColumnAlignments->{Left}], GridBox[{
                {"a"},
                {"b"}
                },
              RowSpacings->0.25,
              ColumnSpacings->1,
              RowAlignments->Baseline,
              ColumnAlignments->{Left}], GridBox[{
                {"f"},
                {"g"}
                },
              RowSpacings->0.25,
              ColumnSpacings->1,
              RowAlignments->Baseline,
              ColumnAlignments->{Left}], GridBox[{
                {"e"},
                {"f"},
                {"g"}
                },
              RowSpacings->0.25,
              ColumnSpacings->1,
              RowAlignments->Baseline,
              ColumnAlignments->{Left}], GridBox[{
                {"e"},
                {"f"},
                {"g"},
                {"h"}
                },
              RowSpacings->0.25,
              ColumnSpacings->1,
              RowAlignments->Baseline,
              ColumnAlignments->{Left}], GridBox[{
                {"c"},
                {"d"}
                },
              RowSpacings->0.25,
              ColumnSpacings->1,
              RowAlignments->Baseline,
              ColumnAlignments->{Left}], GridBox[{
                {"c"},
                {"d"},
                {"e"},
                {"f"},
                {"g"},
                {"h"}
                },
              RowSpacings->0.25,
              ColumnSpacings->1,
              RowAlignments->Baseline,
              ColumnAlignments->{Left}], GridBox[{
                {"a"},
                {"b"},
                {"c"},
                {"d"},
                {"e"},
                {"f"},
                {"g"},
                {"h"}
                },
              RowSpacings->0.25,
              ColumnSpacings->1,
              RowAlignments->Baseline,
              ColumnAlignments->{Left}]},
          {GridBox[{
                {"a"}
                },
              RowSpacings->0.25,
              ColumnSpacings->1,
              RowAlignments->Baseline,
              ColumnAlignments->{Left}], GridBox[{
                {"b"}
                },
              RowSpacings->0.25,
              ColumnSpacings->1,
              RowAlignments->Baseline,
              ColumnAlignments->{Left}], GridBox[{
                {"c"}
                },
              RowSpacings->0.25,
              ColumnSpacings->1,
              RowAlignments->Baseline,
              ColumnAlignments->{Left}], GridBox[{
                {"d"}
                },
              RowSpacings->0.25,
              ColumnSpacings->1,
              RowAlignments->Baseline,
              ColumnAlignments->{Left}], GridBox[{
                {"e"}
                },
              RowSpacings->0.25,
              ColumnSpacings->1,
              RowAlignments->Baseline,
              ColumnAlignments->{Left}], GridBox[{
                {"f"}
                },
              RowSpacings->0.25,
              ColumnSpacings->1,
              RowAlignments->Baseline,
              ColumnAlignments->{Left}], GridBox[{
                {"g"}
                },
              RowSpacings->0.25,
              ColumnSpacings->1,
              RowAlignments->Baseline,
              ColumnAlignments->{Left}], GridBox[{
                {"h"}
                },
              RowSpacings->0.25,
              ColumnSpacings->1,
              RowAlignments->Baseline,
              ColumnAlignments->{Left}], GridBox[{
                {"c"},
                {"d"}
                },
              RowSpacings->0.25,
              ColumnSpacings->1,
              RowAlignments->Baseline,
              ColumnAlignments->{Left}], GridBox[{
                {"a"},
                {"b"}
                },
              RowSpacings->0.25,
              ColumnSpacings->1,
              RowAlignments->Baseline,
              ColumnAlignments->{Left}], GridBox[{
                {"f"},
                {"g"}
                },
              RowSpacings->0.25,
              ColumnSpacings->1,
              RowAlignments->Baseline,
              ColumnAlignments->{Left}], GridBox[{
                {"e"},
                {"f"},
                {"g"}
                },
              RowSpacings->0.25,
              ColumnSpacings->1,
              RowAlignments->Baseline,
              ColumnAlignments->{Left}], GridBox[{
                {"e"},
                {"f"},
                {"g"},
                {"h"}
                },
              RowSpacings->0.25,
              ColumnSpacings->1,
              RowAlignments->Baseline,
              ColumnAlignments->{Left}], GridBox[{
                {"c"},
                {"d"},
                {"e"},
                {"f"},
                {"g"},
                {"h"}
                },
              RowSpacings->0.25,
              ColumnSpacings->1,
              RowAlignments->Baseline,
              ColumnAlignments->{Left}], GridBox[{
                {"a"},
                {"b"},
                {"c"},
                {"d"},
                {"e"},
                {"f"},
                {"g"},
                {"h"}
                },
              RowSpacings->0.25,
              ColumnSpacings->1,
              RowAlignments->Baseline,
              ColumnAlignments->{Left}]},
          {GridBox[{
                {"a"}
                },
              RowSpacings->0.25,
              ColumnSpacings->1,
              RowAlignments->Baseline,
              ColumnAlignments->{Left}], GridBox[{
                {"b"}
                },
              RowSpacings->0.25,
              ColumnSpacings->1,
              RowAlignments->Baseline,
              ColumnAlignments->{Left}], GridBox[{
                {"c"}
                },
              RowSpacings->0.25,
              ColumnSpacings->1,
              RowAlignments->Baseline,
              ColumnAlignments->{Left}], GridBox[{
                {"d"}
                },
              RowSpacings->0.25,
              ColumnSpacings->1,
              RowAlignments->Baseline,
              ColumnAlignments->{Left}], GridBox[{
                {"e"}
                },
              RowSpacings->0.25,
              ColumnSpacings->1,
              RowAlignments->Baseline,
              ColumnAlignments->{Left}], GridBox[{
                {"f"}
                },
              RowSpacings->0.25,
              ColumnSpacings->1,
              RowAlignments->Baseline,
              ColumnAlignments->{Left}], GridBox[{
                {"g"}
                },
              RowSpacings->0.25,
              ColumnSpacings->1,
              RowAlignments->Baseline,
              ColumnAlignments->{Left}], GridBox[{
                {"h"}
                },
              RowSpacings->0.25,
              ColumnSpacings->1,
              RowAlignments->Baseline,
              ColumnAlignments->{Left}], GridBox[{
                {"c"},
                {"d"}
                },
              RowSpacings->0.25,
              ColumnSpacings->1,
              RowAlignments->Baseline,
              ColumnAlignments->{Left}], GridBox[{
                {"f"},
                {"g"}
                },
              RowSpacings->0.25,
              ColumnSpacings->1,
              RowAlignments->Baseline,
              ColumnAlignments->{Left}], GridBox[{
                {"a"},
                {"b"}
                },
              RowSpacings->0.25,
              ColumnSpacings->1,
              RowAlignments->Baseline,
              ColumnAlignments->{Left}], GridBox[{
                {"e"},
                {"f"},
                {"g"}
                },
              RowSpacings->0.25,
              ColumnSpacings->1,
              RowAlignments->Baseline,
              ColumnAlignments->{Left}], GridBox[{
                {"e"},
                {"f"},
                {"g"},
                {"h"}
                },
              RowSpacings->0.25,
              ColumnSpacings->1,
              RowAlignments->Baseline,
              ColumnAlignments->{Left}], GridBox[{
                {"c"},
                {"d"},
                {"e"},
                {"f"},
                {"g"},
                {"h"}
                },
              RowSpacings->0.25,
              ColumnSpacings->1,
              RowAlignments->Baseline,
              ColumnAlignments->{Left}], GridBox[{
                {"a"},
                {"b"},
                {"c"},
                {"d"},
                {"e"},
                {"f"},
                {"g"},
                {"h"}
                },
              RowSpacings->0.25,
              ColumnSpacings->1,
              RowAlignments->Baseline,
              ColumnAlignments->{Left}]},
          {GridBox[{
                {"a"}
                },
              RowSpacings->0.25,
              ColumnSpacings->1,
              RowAlignments->Baseline,
              ColumnAlignments->{Left}], GridBox[{
                {"b"}
                },
              RowSpacings->0.25,
              ColumnSpacings->1,
              RowAlignments->Baseline,
              ColumnAlignments->{Left}], GridBox[{
                {"c"}
                },
              RowSpacings->0.25,
              ColumnSpacings->1,
              RowAlignments->Baseline,
              ColumnAlignments->{Left}], GridBox[{
                {"d"}
                },
              RowSpacings->0.25,
              ColumnSpacings->1,
              RowAlignments->Baseline,
              ColumnAlignments->{Left}], GridBox[{
                {"e"}
                },
              RowSpacings->0.25,
              ColumnSpacings->1,
              RowAlignments->Baseline,
              ColumnAlignments->{Left}], GridBox[{
                {"f"}
                },
              RowSpacings->0.25,
              ColumnSpacings->1,
              RowAlignments->Baseline,
              ColumnAlignments->{Left}], GridBox[{
                {"g"}
                },
              RowSpacings->0.25,
              ColumnSpacings->1,
              RowAlignments->Baseline,
              ColumnAlignments->{Left}], GridBox[{
                {"h"}
                },
              RowSpacings->0.25,
              ColumnSpacings->1,
              RowAlignments->Baseline,
              ColumnAlignments->{Left}], GridBox[{
                {"c"},
                {"d"}
                },
              RowSpacings->0.25,
              ColumnSpacings->1,
              RowAlignments->Baseline,
              ColumnAlignments->{Left}], GridBox[{
                {"f"},
                {"g"}
                },
              RowSpacings->0.25,
              ColumnSpacings->1,
              RowAlignments->Baseline,
              ColumnAlignments->{Left}], GridBox[{
                {"e"},
                {"f"},
                {"g"}
                },
              RowSpacings->0.25,
              ColumnSpacings->1,
              RowAlignments->Baseline,
              ColumnAlignments->{Left}], GridBox[{
                {"a"},
                {"b"}
                },
              RowSpacings->0.25,
              ColumnSpacings->1,
              RowAlignments->Baseline,
              ColumnAlignments->{Left}], GridBox[{
                {"e"},
                {"f"},
                {"g"},
                {"h"}
                },
              RowSpacings->0.25,
              ColumnSpacings->1,
              RowAlignments->Baseline,
              ColumnAlignments->{Left}], GridBox[{
                {"c"},
                {"d"},
                {"e"},
                {"f"},
                {"g"},
                {"h"}
                },
              RowSpacings->0.25,
              ColumnSpacings->1,
              RowAlignments->Baseline,
              ColumnAlignments->{Left}], GridBox[{
                {"a"},
                {"b"},
                {"c"},
                {"d"},
                {"e"},
                {"f"},
                {"g"},
                {"h"}
                },
              RowSpacings->0.25,
              ColumnSpacings->1,
              RowAlignments->Baseline,
              ColumnAlignments->{Left}]},
          {GridBox[{
                {"a"}
                },
              RowSpacings->0.25,
              ColumnSpacings->1,
              RowAlignments->Baseline,
              ColumnAlignments->{Left}], GridBox[{
                {"b"}
                },
              RowSpacings->0.25,
              ColumnSpacings->1,
              RowAlignments->Baseline,
              ColumnAlignments->{Left}], GridBox[{
                {"c"}
                },
              RowSpacings->0.25,
              ColumnSpacings->1,
              RowAlignments->Baseline,
              ColumnAlignments->{Left}], GridBox[{
                {"d"}
                },
              RowSpacings->0.25,
              ColumnSpacings->1,
              RowAlignments->Baseline,
              ColumnAlignments->{Left}], GridBox[{
                {"e"}
                },
              RowSpacings->0.25,
              ColumnSpacings->1,
              RowAlignments->Baseline,
              ColumnAlignments->{Left}], GridBox[{
                {"f"}
                },
              RowSpacings->0.25,
              ColumnSpacings->1,
              RowAlignments->Baseline,
              ColumnAlignments->{Left}], GridBox[{
                {"g"}
                },
              RowSpacings->0.25,
              ColumnSpacings->1,
              RowAlignments->Baseline,
              ColumnAlignments->{Left}], GridBox[{
                {"h"}
                },
              RowSpacings->0.25,
              ColumnSpacings->1,
              RowAlignments->Baseline,
              ColumnAlignments->{Left}], GridBox[{
                {"c"},
                {"d"}
                },
              RowSpacings->0.25,
              ColumnSpacings->1,
              RowAlignments->Baseline,
              ColumnAlignments->{Left}], GridBox[{
                {"f"},
                {"g"}
                },
              RowSpacings->0.25,
              ColumnSpacings->1,
              RowAlignments->Baseline,
              ColumnAlignments->{Left}], GridBox[{
                {"e"},
                {"f"},
                {"g"}
                },
              RowSpacings->0.25,
              ColumnSpacings->1,
              RowAlignments->Baseline,
              ColumnAlignments->{Left}], GridBox[{
                {"e"},
                {"f"},
                {"g"},
                {"h"}
                },
              RowSpacings->0.25,
              ColumnSpacings->1,
              RowAlignments->Baseline,
              ColumnAlignments->{Left}], GridBox[{
                {"a"},
                {"b"}
                },
              RowSpacings->0.25,
              ColumnSpacings->1,
              RowAlignments->Baseline,
              ColumnAlignments->{Left}], GridBox[{
                {"c"},
                {"d"},
                {"e"},
                {"f"},
                {"g"},
                {"h"}
                },
              RowSpacings->0.25,
              ColumnSpacings->1,
              RowAlignments->Baseline,
              ColumnAlignments->{Left}], GridBox[{
                {"a"},
                {"b"},
                {"c"},
                {"d"},
                {"e"},
                {"f"},
                {"g"},
                {"h"}
                },
              RowSpacings->0.25,
              ColumnSpacings->1,
              RowAlignments->Baseline,
              ColumnAlignments->{Left}]},
          {GridBox[{
                {"a"}
                },
              RowSpacings->0.25,
              ColumnSpacings->1,
              RowAlignments->Baseline,
              ColumnAlignments->{Left}], GridBox[{
                {"b"}
                },
              RowSpacings->0.25,
              ColumnSpacings->1,
              RowAlignments->Baseline,
              ColumnAlignments->{Left}], GridBox[{
                {"c"}
                },
              RowSpacings->0.25,
              ColumnSpacings->1,
              RowAlignments->Baseline,
              ColumnAlignments->{Left}], GridBox[{
                {"d"}
                },
              RowSpacings->0.25,
              ColumnSpacings->1,
              RowAlignments->Baseline,
              ColumnAlignments->{Left}], GridBox[{
                {"e"}
                },
              RowSpacings->0.25,
              ColumnSpacings->1,
              RowAlignments->Baseline,
              ColumnAlignments->{Left}], GridBox[{
                {"f"}
                },
              RowSpacings->0.25,
              ColumnSpacings->1,
              RowAlignments->Baseline,
              ColumnAlignments->{Left}], GridBox[{
                {"g"}
                },
              RowSpacings->0.25,
              ColumnSpacings->1,
              RowAlignments->Baseline,
              ColumnAlignments->{Left}], GridBox[{
                {"h"}
                },
              RowSpacings->0.25,
              ColumnSpacings->1,
              RowAlignments->Baseline,
              ColumnAlignments->{Left}], GridBox[{
                {"c"},
                {"d"}
                },
              RowSpacings->0.25,
              ColumnSpacings->1,
              RowAlignments->Baseline,
              ColumnAlignments->{Left}], GridBox[{
                {"f"},
                {"g"}
                },
              RowSpacings->0.25,
              ColumnSpacings->1,
              RowAlignments->Baseline,
              ColumnAlignments->{Left}], GridBox[{
                {"e"},
                {"f"},
                {"g"}
                },
              RowSpacings->0.25,
              ColumnSpacings->1,
              RowAlignments->Baseline,
              ColumnAlignments->{Left}], GridBox[{
                {"e"},
                {"f"},
                {"g"},
                {"h"}
                },
              RowSpacings->0.25,
              ColumnSpacings->1,
              RowAlignments->Baseline,
              ColumnAlignments->{Left}], GridBox[{
                {"c"},
                {"d"},
                {"e"},
                {"f"},
                {"g"},
                {"h"}
                },
              RowSpacings->0.25,
              ColumnSpacings->1,
              RowAlignments->Baseline,
              ColumnAlignments->{Left}], GridBox[{
                {"a"},
                {"b"}
                },
              RowSpacings->0.25,
              ColumnSpacings->1,
              RowAlignments->Baseline,
              ColumnAlignments->{Left}], GridBox[{
                {"a"},
                {"b"},
                {"c"},
                {"d"},
                {"e"},
                {"f"},
                {"g"},
                {"h"}
                },
              RowSpacings->0.25,
              ColumnSpacings->1,
              RowAlignments->Baseline,
              ColumnAlignments->{Left}]},
          {GridBox[{
                {"a"}
                },
              RowSpacings->0.25,
              ColumnSpacings->1,
              RowAlignments->Baseline,
              ColumnAlignments->{Left}], GridBox[{
                {"b"}
                },
              RowSpacings->0.25,
              ColumnSpacings->1,
              RowAlignments->Baseline,
              ColumnAlignments->{Left}], GridBox[{
                {"c"}
                },
              RowSpacings->0.25,
              ColumnSpacings->1,
              RowAlignments->Baseline,
              ColumnAlignments->{Left}], GridBox[{
                {"d"}
                },
              RowSpacings->0.25,
              ColumnSpacings->1,
              RowAlignments->Baseline,
              ColumnAlignments->{Left}], GridBox[{
                {"e"}
                },
              RowSpacings->0.25,
              ColumnSpacings->1,
              RowAlignments->Baseline,
              ColumnAlignments->{Left}], GridBox[{
                {"f"}
                },
              RowSpacings->0.25,
              ColumnSpacings->1,
              RowAlignments->Baseline,
              ColumnAlignments->{Left}], GridBox[{
                {"g"}
                },
              RowSpacings->0.25,
              ColumnSpacings->1,
              RowAlignments->Baseline,
              ColumnAlignments->{Left}], GridBox[{
                {"h"}
                },
              RowSpacings->0.25,
              ColumnSpacings->1,
              RowAlignments->Baseline,
              ColumnAlignments->{Left}], GridBox[{
                {"f"},
                {"g"}
                },
              RowSpacings->0.25,
              ColumnSpacings->1,
              RowAlignments->Baseline,
              ColumnAlignments->{Left}], GridBox[{
                {"a"},
                {"b"}
                },
              RowSpacings->0.25,
              ColumnSpacings->1,
              RowAlignments->Baseline,
              ColumnAlignments->{Left}], GridBox[{
                {"c"},
                {"d"}
                },
              RowSpacings->0.25,
              ColumnSpacings->1,
              RowAlignments->Baseline,
              ColumnAlignments->{Left}], GridBox[{
                {"e"},
                {"f"},
                {"g"}
                },
              RowSpacings->0.25,
              ColumnSpacings->1,
              RowAlignments->Baseline,
              ColumnAlignments->{Left}], GridBox[{
                {"e"},
                {"f"},
                {"g"},
                {"h"}
                },
              RowSpacings->0.25,
              ColumnSpacings->1,
              RowAlignments->Baseline,
              ColumnAlignments->{Left}], GridBox[{
                {"c"},
                {"d"},
                {"e"},
                {"f"},
                {"g"},
                {"h"}
                },
              RowSpacings->0.25,
              ColumnSpacings->1,
              RowAlignments->Baseline,
              ColumnAlignments->{Left}], GridBox[{
                {"a"},
                {"b"},
                {"c"},
                {"d"},
                {"e"},
                {"f"},
                {"g"},
                {"h"}
                },
              RowSpacings->0.25,
              ColumnSpacings->1,
              RowAlignments->Baseline,
              ColumnAlignments->{Left}]},
          {GridBox[{
                {"a"}
                },
              RowSpacings->0.25,
              ColumnSpacings->1,
              RowAlignments->Baseline,
              ColumnAlignments->{Left}], GridBox[{
                {"b"}
                },
              RowSpacings->0.25,
              ColumnSpacings->1,
              RowAlignments->Baseline,
              ColumnAlignments->{Left}], GridBox[{
                {"c"}
                },
              RowSpacings->0.25,
              ColumnSpacings->1,
              RowAlignments->Baseline,
              ColumnAlignments->{Left}], GridBox[{
                {"d"}
                },
              RowSpacings->0.25,
              ColumnSpacings->1,
              RowAlignments->Baseline,
              ColumnAlignments->{Left}], GridBox[{
                {"e"}
                },
              RowSpacings->0.25,
              ColumnSpacings->1,
              RowAlignments->Baseline,
              ColumnAlignments->{Left}], GridBox[{
                {"f"}
                },
              RowSpacings->0.25,
              ColumnSpacings->1,
              RowAlignments->Baseline,
              ColumnAlignments->{Left}], GridBox[{
                {"g"}
                },
              RowSpacings->0.25,
              ColumnSpacings->1,
              RowAlignments->Baseline,
              ColumnAlignments->{Left}], GridBox[{
                {"h"}
                },
              RowSpacings->0.25,
              ColumnSpacings->1,
              RowAlignments->Baseline,
              ColumnAlignments->{Left}], GridBox[{
                {"f"},
                {"g"}
                },
              RowSpacings->0.25,
              ColumnSpacings->1,
              RowAlignments->Baseline,
              ColumnAlignments->{Left}], GridBox[{
                {"a"},
                {"b"}
                },
              RowSpacings->0.25,
              ColumnSpacings->1,
              RowAlignments->Baseline,
              ColumnAlignments->{Left}], GridBox[{
                {"e"},
                {"f"},
                {"g"}
                },
              RowSpacings->0.25,
              ColumnSpacings->1,
              RowAlignments->Baseline,
              ColumnAlignments->{Left}], GridBox[{
                {"c"},
                {"d"}
                },
              RowSpacings->0.25,
              ColumnSpacings->1,
              RowAlignments->Baseline,
              ColumnAlignments->{Left}], GridBox[{
                {"e"},
                {"f"},
                {"g"},
                {"h"}
                },
              RowSpacings->0.25,
              ColumnSpacings->1,
              RowAlignments->Baseline,
              ColumnAlignments->{Left}], GridBox[{
                {"c"},
                {"d"},
                {"e"},
                {"f"},
                {"g"},
                {"h"}
                },
              RowSpacings->0.25,
              ColumnSpacings->1,
              RowAlignments->Baseline,
              ColumnAlignments->{Left}], GridBox[{
                {"a"},
                {"b"},
                {"c"},
                {"d"},
                {"e"},
                {"f"},
                {"g"},
                {"h"}
                },
              RowSpacings->0.25,
              ColumnSpacings->1,
              RowAlignments->Baseline,
              ColumnAlignments->{Left}]},
          {GridBox[{
                {"a"}
                },
              RowSpacings->0.25,
              ColumnSpacings->1,
              RowAlignments->Baseline,
              ColumnAlignments->{Left}], GridBox[{
                {"b"}
                },
              RowSpacings->0.25,
              ColumnSpacings->1,
              RowAlignments->Baseline,
              ColumnAlignments->{Left}], GridBox[{
                {"c"}
                },
              RowSpacings->0.25,
              ColumnSpacings->1,
              RowAlignments->Baseline,
              ColumnAlignments->{Left}], GridBox[{
                {"d"}
                },
              RowSpacings->0.25,
              ColumnSpacings->1,
              RowAlignments->Baseline,
              ColumnAlignments->{Left}], GridBox[{
                {"e"}
                },
              RowSpacings->0.25,
              ColumnSpacings->1,
              RowAlignments->Baseline,
              ColumnAlignments->{Left}], GridBox[{
                {"f"}
                },
              RowSpacings->0.25,
              ColumnSpacings->1,
              RowAlignments->Baseline,
              ColumnAlignments->{Left}], GridBox[{
                {"g"}
                },
              RowSpacings->0.25,
              ColumnSpacings->1,
              RowAlignments->Baseline,
              ColumnAlignments->{Left}], GridBox[{
                {"h"}
                },
              RowSpacings->0.25,
              ColumnSpacings->1,
              RowAlignments->Baseline,
              ColumnAlignments->{Left}], GridBox[{
                {"f"},
                {"g"}
                },
              RowSpacings->0.25,
              ColumnSpacings->1,
              RowAlignments->Baseline,
              ColumnAlignments->{Left}], GridBox[{
                {"a"},
                {"b"}
                },
              RowSpacings->0.25,
              ColumnSpacings->1,
              RowAlignments->Baseline,
              ColumnAlignments->{Left}], GridBox[{
                {"e"},
                {"f"},
                {"g"}
                },
              RowSpacings->0.25,
              ColumnSpacings->1,
              RowAlignments->Baseline,
              ColumnAlignments->{Left}], GridBox[{
                {"e"},
                {"f"},
                {"g"},
                {"h"}
                },
              RowSpacings->0.25,
              ColumnSpacings->1,
              RowAlignments->Baseline,
              ColumnAlignments->{Left}], GridBox[{
                {"c"},
                {"d"}
                },
              RowSpacings->0.25,
              ColumnSpacings->1,
              RowAlignments->Baseline,
              ColumnAlignments->{Left}], GridBox[{
                {"c"},
                {"d"},
                {"e"},
                {"f"},
                {"g"},
                {"h"}
                },
              RowSpacings->0.25,
              ColumnSpacings->1,
              RowAlignments->Baseline,
              ColumnAlignments->{Left}], GridBox[{
                {"a"},
                {"b"},
                {"c"},
                {"d"},
                {"e"},
                {"f"},
                {"g"},
                {"h"}
                },
              RowSpacings->0.25,
              ColumnSpacings->1,
              RowAlignments->Baseline,
              ColumnAlignments->{Left}]},
          {GridBox[{
                {"a"}
                },
              RowSpacings->0.25,
              ColumnSpacings->1,
              RowAlignments->Baseline,
              ColumnAlignments->{Left}], GridBox[{
                {"b"}
                },
              RowSpacings->0.25,
              ColumnSpacings->1,
              RowAlignments->Baseline,
              ColumnAlignments->{Left}], GridBox[{
                {"c"}
                },
              RowSpacings->0.25,
              ColumnSpacings->1,
              RowAlignments->Baseline,
              ColumnAlignments->{Left}], GridBox[{
                {"d"}
                },
              RowSpacings->0.25,
              ColumnSpacings->1,
              RowAlignments->Baseline,
              ColumnAlignments->{Left}], GridBox[{
                {"e"}
                },
              RowSpacings->0.25,
              ColumnSpacings->1,
              RowAlignments->Baseline,
              ColumnAlignments->{Left}], GridBox[{
                {"f"}
                },
              RowSpacings->0.25,
              ColumnSpacings->1,
              RowAlignments->Baseline,
              ColumnAlignments->{Left}], GridBox[{
                {"g"}
                },
              RowSpacings->0.25,
              ColumnSpacings->1,
              RowAlignments->Baseline,
              ColumnAlignments->{Left}], GridBox[{
                {"h"}
                },
              RowSpacings->0.25,
              ColumnSpacings->1,
              RowAlignments->Baseline,
              ColumnAlignments->{Left}], GridBox[{
                {"f"},
                {"g"}
                },
              RowSpacings->0.25,
              ColumnSpacings->1,
              RowAlignments->Baseline,
              ColumnAlignments->{Left}], GridBox[{
                {"c"},
                {"d"}
                },
              RowSpacings->0.25,
              ColumnSpacings->1,
              RowAlignments->Baseline,
              ColumnAlignments->{Left}], GridBox[{
                {"a"},
                {"b"}
                },
              RowSpacings->0.25,
              ColumnSpacings->1,
              RowAlignments->Baseline,
              ColumnAlignments->{Left}], GridBox[{
                {"e"},
                {"f"},
                {"g"}
                },
              RowSpacings->0.25,
              ColumnSpacings->1,
              RowAlignments->Baseline,
              ColumnAlignments->{Left}], GridBox[{
                {"e"},
                {"f"},
                {"g"},
                {"h"}
                },
              RowSpacings->0.25,
              ColumnSpacings->1,
              RowAlignments->Baseline,
              ColumnAlignments->{Left}], GridBox[{
                {"c"},
                {"d"},
                {"e"},
                {"f"},
                {"g"},
                {"h"}
                },
              RowSpacings->0.25,
              ColumnSpacings->1,
              RowAlignments->Baseline,
              ColumnAlignments->{Left}], GridBox[{
                {"a"},
                {"b"},
                {"c"},
                {"d"},
                {"e"},
                {"f"},
                {"g"},
                {"h"}
                },
              RowSpacings->0.25,
              ColumnSpacings->1,
              RowAlignments->Baseline,
              ColumnAlignments->{Left}]},
          {GridBox[{
                {"a"}
                },
              RowSpacings->0.25,
              ColumnSpacings->1,
              RowAlignments->Baseline,
              ColumnAlignments->{Left}], GridBox[{
                {"b"}
                },
              RowSpacings->0.25,
              ColumnSpacings->1,
              RowAlignments->Baseline,
              ColumnAlignments->{Left}], GridBox[{
                {"c"}
                },
              RowSpacings->0.25,
              ColumnSpacings->1,
              RowAlignments->Baseline,
              ColumnAlignments->{Left}], GridBox[{
                {"d"}
                },
              RowSpacings->0.25,
              ColumnSpacings->1,
              RowAlignments->Baseline,
              ColumnAlignments->{Left}], GridBox[{
                {"e"}
                },
              RowSpacings->0.25,
              ColumnSpacings->1,
              RowAlignments->Baseline,
              ColumnAlignments->{Left}], GridBox[{
                {"f"}
                },
              RowSpacings->0.25,
              ColumnSpacings->1,
              RowAlignments->Baseline,
              ColumnAlignments->{Left}], GridBox[{
                {"g"}
                },
              RowSpacings->0.25,
              ColumnSpacings->1,
              RowAlignments->Baseline,
              ColumnAlignments->{Left}], GridBox[{
                {"h"}
                },
              RowSpacings->0.25,
              ColumnSpacings->1,
              RowAlignments->Baseline,
              ColumnAlignments->{Left}], GridBox[{
                {"f"},
                {"g"}
                },
              RowSpacings->0.25,
              ColumnSpacings->1,
              RowAlignments->Baseline,
              ColumnAlignments->{Left}], GridBox[{
                {"c"},
                {"d"}
                },
              RowSpacings->0.25,
              ColumnSpacings->1,
              RowAlignments->Baseline,
              ColumnAlignments->{Left}], GridBox[{
                {"e"},
                {"f"},
                {"g"}
                },
              RowSpacings->0.25,
              ColumnSpacings->1,
              RowAlignments->Baseline,
              ColumnAlignments->{Left}], GridBox[{
                {"a"},
                {"b"}
                },
              RowSpacings->0.25,
              ColumnSpacings->1,
              RowAlignments->Baseline,
              ColumnAlignments->{Left}], GridBox[{
                {"e"},
                {"f"},
                {"g"},
                {"h"}
                },
              RowSpacings->0.25,
              ColumnSpacings->1,
              RowAlignments->Baseline,
              ColumnAlignments->{Left}], GridBox[{
                {"c"},
                {"d"},
                {"e"},
                {"f"},
                {"g"},
                {"h"}
                },
              RowSpacings->0.25,
              ColumnSpacings->1,
              RowAlignments->Baseline,
              ColumnAlignments->{Left}], GridBox[{
                {"a"},
                {"b"},
                {"c"},
                {"d"},
                {"e"},
                {"f"},
                {"g"},
                {"h"}
                },
              RowSpacings->0.25,
              ColumnSpacings->1,
              RowAlignments->Baseline,
              ColumnAlignments->{Left}]},
          {GridBox[{
                {"a"}
                },
              RowSpacings->0.25,
              ColumnSpacings->1,
              RowAlignments->Baseline,
              ColumnAlignments->{Left}], GridBox[{
                {"b"}
                },
              RowSpacings->0.25,
              ColumnSpacings->1,
              RowAlignments->Baseline,
              ColumnAlignments->{Left}], GridBox[{
                {"c"}
                },
              RowSpacings->0.25,
              ColumnSpacings->1,
              RowAlignments->Baseline,
              ColumnAlignments->{Left}], GridBox[{
                {"d"}
                },
              RowSpacings->0.25,
              ColumnSpacings->1,
              RowAlignments->Baseline,
              ColumnAlignments->{Left}], GridBox[{
                {"e"}
                },
              RowSpacings->0.25,
              ColumnSpacings->1,
              RowAlignments->Baseline,
              ColumnAlignments->{Left}], GridBox[{
                {"f"}
                },
              RowSpacings->0.25,
              ColumnSpacings->1,
              RowAlignments->Baseline,
              ColumnAlignments->{Left}], GridBox[{
                {"g"}
                },
              RowSpacings->0.25,
              ColumnSpacings->1,
              RowAlignments->Baseline,
              ColumnAlignments->{Left}], GridBox[{
                {"h"}
                },
              RowSpacings->0.25,
              ColumnSpacings->1,
              RowAlignments->Baseline,
              ColumnAlignments->{Left}], GridBox[{
                {"f"},
                {"g"}
                },
              RowSpacings->0.25,
              ColumnSpacings->1,
              RowAlignments->Baseline,
              ColumnAlignments->{Left}], GridBox[{
                {"c"},
                {"d"}
                },
              RowSpacings->0.25,
              ColumnSpacings->1,
              RowAlignments->Baseline,
              ColumnAlignments->{Left}], GridBox[{
                {"e"},
                {"f"},
                {"g"}
                },
              RowSpacings->0.25,
              ColumnSpacings->1,
              RowAlignments->Baseline,
              ColumnAlignments->{Left}], GridBox[{
                {"e"},
                {"f"},
                {"g"},
                {"h"}
                },
              RowSpacings->0.25,
              ColumnSpacings->1,
              RowAlignments->Baseline,
              ColumnAlignments->{Left}], GridBox[{
                {"a"},
                {"b"}
                },
              RowSpacings->0.25,
              ColumnSpacings->1,
              RowAlignments->Baseline,
              ColumnAlignments->{Left}], GridBox[{
                {"c"},
                {"d"},
                {"e"},
                {"f"},
                {"g"},
                {"h"}
                },
              RowSpacings->0.25,
              ColumnSpacings->1,
              RowAlignments->Baseline,
              ColumnAlignments->{Left}], GridBox[{
                {"a"},
                {"b"},
                {"c"},
                {"d"},
                {"e"},
                {"f"},
                {"g"},
                {"h"}
                },
              RowSpacings->0.25,
              ColumnSpacings->1,
              RowAlignments->Baseline,
              ColumnAlignments->{Left}]},
          {GridBox[{
                {"a"}
                },
              RowSpacings->0.25,
              ColumnSpacings->1,
              RowAlignments->Baseline,
              ColumnAlignments->{Left}], GridBox[{
                {"b"}
                },
              RowSpacings->0.25,
              ColumnSpacings->1,
              RowAlignments->Baseline,
              ColumnAlignments->{Left}], GridBox[{
                {"c"}
                },
              RowSpacings->0.25,
              ColumnSpacings->1,
              RowAlignments->Baseline,
              ColumnAlignments->{Left}], GridBox[{
                {"d"}
                },
              RowSpacings->0.25,
              ColumnSpacings->1,
              RowAlignments->Baseline,
              ColumnAlignments->{Left}], GridBox[{
                {"e"}
                },
              RowSpacings->0.25,
              ColumnSpacings->1,
              RowAlignments->Baseline,
              ColumnAlignments->{Left}], GridBox[{
                {"f"}
                },
              RowSpacings->0.25,
              ColumnSpacings->1,
              RowAlignments->Baseline,
              ColumnAlignments->{Left}], GridBox[{
                {"g"}
                },
              RowSpacings->0.25,
              ColumnSpacings->1,
              RowAlignments->Baseline,
              ColumnAlignments->{Left}], GridBox[{
                {"h"}
                },
              RowSpacings->0.25,
              ColumnSpacings->1,
              RowAlignments->Baseline,
              ColumnAlignments->{Left}], GridBox[{
                {"f"},
                {"g"}
                },
              RowSpacings->0.25,
              ColumnSpacings->1,
              RowAlignments->Baseline,
              ColumnAlignments->{Left}], GridBox[{
                {"c"},
                {"d"}
                },
              RowSpacings->0.25,
              ColumnSpacings->1,
              RowAlignments->Baseline,
              ColumnAlignments->{Left}], GridBox[{
                {"e"},
                {"f"},
                {"g"}
                },
              RowSpacings->0.25,
              ColumnSpacings->1,
              RowAlignments->Baseline,
              ColumnAlignments->{Left}], GridBox[{
                {"e"},
                {"f"},
                {"g"},
                {"h"}
                },
              RowSpacings->0.25,
              ColumnSpacings->1,
              RowAlignments->Baseline,
              ColumnAlignments->{Left}], GridBox[{
                {"c"},
                {"d"},
                {"e"},
                {"f"},
                {"g"},
                {"h"}
                },
              RowSpacings->0.25,
              ColumnSpacings->1,
              RowAlignments->Baseline,
              ColumnAlignments->{Left}], GridBox[{
                {"a"},
                {"b"}
                },
              RowSpacings->0.25,
              ColumnSpacings->1,
              RowAlignments->Baseline,
              ColumnAlignments->{Left}], GridBox[{
                {"a"},
                {"b"},
                {"c"},
                {"d"},
                {"e"},
                {"f"},
                {"g"},
                {"h"}
                },
              RowSpacings->0.25,
              ColumnSpacings->1,
              RowAlignments->Baseline,
              ColumnAlignments->{Left}]},
          {GridBox[{
                {"a"}
                },
              RowSpacings->0.25,
              ColumnSpacings->1,
              RowAlignments->Baseline,
              ColumnAlignments->{Left}], GridBox[{
                {"b"}
                },
              RowSpacings->0.25,
              ColumnSpacings->1,
              RowAlignments->Baseline,
              ColumnAlignments->{Left}], GridBox[{
                {"c"}
                },
              RowSpacings->0.25,
              ColumnSpacings->1,
              RowAlignments->Baseline,
              ColumnAlignments->{Left}], GridBox[{
                {"d"}
                },
              RowSpacings->0.25,
              ColumnSpacings->1,
              RowAlignments->Baseline,
              ColumnAlignments->{Left}], GridBox[{
                {"e"}
                },
              RowSpacings->0.25,
              ColumnSpacings->1,
              RowAlignments->Baseline,
              ColumnAlignments->{Left}], GridBox[{
                {"f"}
                },
              RowSpacings->0.25,
              ColumnSpacings->1,
              RowAlignments->Baseline,
              ColumnAlignments->{Left}], GridBox[{
                {"g"}
                },
              RowSpacings->0.25,
              ColumnSpacings->1,
              RowAlignments->Baseline,
              ColumnAlignments->{Left}], GridBox[{
                {"h"}
                },
              RowSpacings->0.25,
              ColumnSpacings->1,
              RowAlignments->Baseline,
              ColumnAlignments->{Left}], GridBox[{
                {"f"},
                {"g"}
                },
              RowSpacings->0.25,
              ColumnSpacings->1,
              RowAlignments->Baseline,
              ColumnAlignments->{Left}], GridBox[{
                {"e"},
                {"f"},
                {"g"}
                },
              RowSpacings->0.25,
              ColumnSpacings->1,
              RowAlignments->Baseline,
              ColumnAlignments->{Left}], GridBox[{
                {"a"},
                {"b"}
                },
              RowSpacings->0.25,
              ColumnSpacings->1,
              RowAlignments->Baseline,
              ColumnAlignments->{Left}], GridBox[{
                {"c"},
                {"d"}
                },
              RowSpacings->0.25,
              ColumnSpacings->1,
              RowAlignments->Baseline,
              ColumnAlignments->{Left}], GridBox[{
                {"e"},
                {"f"},
                {"g"},
                {"h"}
                },
              RowSpacings->0.25,
              ColumnSpacings->1,
              RowAlignments->Baseline,
              ColumnAlignments->{Left}], GridBox[{
                {"c"},
                {"d"},
                {"e"},
                {"f"},
                {"g"},
                {"h"}
                },
              RowSpacings->0.25,
              ColumnSpacings->1,
              RowAlignments->Baseline,
              ColumnAlignments->{Left}], GridBox[{
                {"a"},
                {"b"},
                {"c"},
                {"d"},
                {"e"},
                {"f"},
                {"g"},
                {"h"}
                },
              RowSpacings->0.25,
              ColumnSpacings->1,
              RowAlignments->Baseline,
              ColumnAlignments->{Left}]},
          {GridBox[{
                {"a"}
                },
              RowSpacings->0.25,
              ColumnSpacings->1,
              RowAlignments->Baseline,
              ColumnAlignments->{Left}], GridBox[{
                {"b"}
                },
              RowSpacings->0.25,
              ColumnSpacings->1,
              RowAlignments->Baseline,
              ColumnAlignments->{Left}], GridBox[{
                {"c"}
                },
              RowSpacings->0.25,
              ColumnSpacings->1,
              RowAlignments->Baseline,
              ColumnAlignments->{Left}], GridBox[{
                {"d"}
                },
              RowSpacings->0.25,
              ColumnSpacings->1,
              RowAlignments->Baseline,
              ColumnAlignments->{Left}], GridBox[{
                {"e"}
                },
              RowSpacings->0.25,
              ColumnSpacings->1,
              RowAlignments->Baseline,
              ColumnAlignments->{Left}], GridBox[{
                {"f"}
                },
              RowSpacings->0.25,
              ColumnSpacings->1,
              RowAlignments->Baseline,
              ColumnAlignments->{Left}], GridBox[{
                {"g"}
                },
              RowSpacings->0.25,
              ColumnSpacings->1,
              RowAlignments->Baseline,
              ColumnAlignments->{Left}], GridBox[{
                {"h"}
                },
              RowSpacings->0.25,
              ColumnSpacings->1,
              RowAlignments->Baseline,
              ColumnAlignments->{Left}], GridBox[{
                {"f"},
                {"g"}
                },
              RowSpacings->0.25,
              ColumnSpacings->1,
              RowAlignments->Baseline,
              ColumnAlignments->{Left}], GridBox[{
                {"e"},
                {"f"},
                {"g"}
                },
              RowSpacings->0.25,
              ColumnSpacings->1,
              RowAlignments->Baseline,
              ColumnAlignments->{Left}], GridBox[{
                {"a"},
                {"b"}
                },
              RowSpacings->0.25,
              ColumnSpacings->1,
              RowAlignments->Baseline,
              ColumnAlignments->{Left}], GridBox[{
                {"e"},
                {"f"},
                {"g"},
                {"h"}
                },
              RowSpacings->0.25,
              ColumnSpacings->1,
              RowAlignments->Baseline,
              ColumnAlignments->{Left}], GridBox[{
                {"c"},
                {"d"}
                },
              RowSpacings->0.25,
              ColumnSpacings->1,
              RowAlignments->Baseline,
              ColumnAlignments->{Left}], GridBox[{
                {"c"},
                {"d"},
                {"e"},
                {"f"},
                {"g"},
                {"h"}
                },
              RowSpacings->0.25,
              ColumnSpacings->1,
              RowAlignments->Baseline,
              ColumnAlignments->{Left}], GridBox[{
                {"a"},
                {"b"},
                {"c"},
                {"d"},
                {"e"},
                {"f"},
                {"g"},
                {"h"}
                },
              RowSpacings->0.25,
              ColumnSpacings->1,
              RowAlignments->Baseline,
              ColumnAlignments->{Left}]},
          {GridBox[{
                {"a"}
                },
              RowSpacings->0.25,
              ColumnSpacings->1,
              RowAlignments->Baseline,
              ColumnAlignments->{Left}], GridBox[{
                {"b"}
                },
              RowSpacings->0.25,
              ColumnSpacings->1,
              RowAlignments->Baseline,
              ColumnAlignments->{Left}], GridBox[{
                {"c"}
                },
              RowSpacings->0.25,
              ColumnSpacings->1,
              RowAlignments->Baseline,
              ColumnAlignments->{Left}], GridBox[{
                {"d"}
                },
              RowSpacings->0.25,
              ColumnSpacings->1,
              RowAlignments->Baseline,
              ColumnAlignments->{Left}], GridBox[{
                {"e"}
                },
              RowSpacings->0.25,
              ColumnSpacings->1,
              RowAlignments->Baseline,
              ColumnAlignments->{Left}], GridBox[{
                {"f"}
                },
              RowSpacings->0.25,
              ColumnSpacings->1,
              RowAlignments->Baseline,
              ColumnAlignments->{Left}], GridBox[{
                {"g"}
                },
              RowSpacings->0.25,
              ColumnSpacings->1,
              RowAlignments->Baseline,
              ColumnAlignments->{Left}], GridBox[{
                {"h"}
                },
              RowSpacings->0.25,
              ColumnSpacings->1,
              RowAlignments->Baseline,
              ColumnAlignments->{Left}], GridBox[{
                {"f"},
                {"g"}
                },
              RowSpacings->0.25,
              ColumnSpacings->1,
              RowAlignments->Baseline,
              ColumnAlignments->{Left}], GridBox[{
                {"e"},
                {"f"},
                {"g"}
                },
              RowSpacings->0.25,
              ColumnSpacings->1,
              RowAlignments->Baseline,
              ColumnAlignments->{Left}], GridBox[{
                {"c"},
                {"d"}
                },
              RowSpacings->0.25,
              ColumnSpacings->1,
              RowAlignments->Baseline,
              ColumnAlignments->{Left}], GridBox[{
                {"a"},
                {"b"}
                },
              RowSpacings->0.25,
              ColumnSpacings->1,
              RowAlignments->Baseline,
              ColumnAlignments->{Left}], GridBox[{
                {"e"},
                {"f"},
                {"g"},
                {"h"}
                },
              RowSpacings->0.25,
              ColumnSpacings->1,
              RowAlignments->Baseline,
              ColumnAlignments->{Left}], GridBox[{
                {"c"},
                {"d"},
                {"e"},
                {"f"},
                {"g"},
                {"h"}
                },
              RowSpacings->0.25,
              ColumnSpacings->1,
              RowAlignments->Baseline,
              ColumnAlignments->{Left}], GridBox[{
                {"a"},
                {"b"},
                {"c"},
                {"d"},
                {"e"},
                {"f"},
                {"g"},
                {"h"}
                },
              RowSpacings->0.25,
              ColumnSpacings->1,
              RowAlignments->Baseline,
              ColumnAlignments->{Left}]},
          {GridBox[{
                {"a"}
                },
              RowSpacings->0.25,
              ColumnSpacings->1,
              RowAlignments->Baseline,
              ColumnAlignments->{Left}], GridBox[{
                {"b"}
                },
              RowSpacings->0.25,
              ColumnSpacings->1,
              RowAlignments->Baseline,
              ColumnAlignments->{Left}], GridBox[{
                {"c"}
                },
              RowSpacings->0.25,
              ColumnSpacings->1,
              RowAlignments->Baseline,
              ColumnAlignments->{Left}], GridBox[{
                {"d"}
                },
              RowSpacings->0.25,
              ColumnSpacings->1,
              RowAlignments->Baseline,
              ColumnAlignments->{Left}], GridBox[{
                {"e"}
                },
              RowSpacings->0.25,
              ColumnSpacings->1,
              RowAlignments->Baseline,
              ColumnAlignments->{Left}], GridBox[{
                {"f"}
                },
              RowSpacings->0.25,
              ColumnSpacings->1,
              RowAlignments->Baseline,
              ColumnAlignments->{Left}], GridBox[{
                {"g"}
                },
              RowSpacings->0.25,
              ColumnSpacings->1,
              RowAlignments->Baseline,
              ColumnAlignments->{Left}], GridBox[{
                {"h"}
                },
              RowSpacings->0.25,
              ColumnSpacings->1,
              RowAlignments->Baseline,
              ColumnAlignments->{Left}], GridBox[{
                {"f"},
                {"g"}
                },
              RowSpacings->0.25,
              ColumnSpacings->1,
              RowAlignments->Baseline,
              ColumnAlignments->{Left}], GridBox[{
                {"e"},
                {"f"},
                {"g"}
                },
              RowSpacings->0.25,
              ColumnSpacings->1,
              RowAlignments->Baseline,
              ColumnAlignments->{Left}], GridBox[{
                {"c"},
                {"d"}
                },
              RowSpacings->0.25,
              ColumnSpacings->1,
              RowAlignments->Baseline,
              ColumnAlignments->{Left}], GridBox[{
                {"e"},
                {"f"},
                {"g"},
                {"h"}
                },
              RowSpacings->0.25,
              ColumnSpacings->1,
              RowAlignments->Baseline,
              ColumnAlignments->{Left}], GridBox[{
                {"a"},
                {"b"}
                },
              RowSpacings->0.25,
              ColumnSpacings->1,
              RowAlignments->Baseline,
              ColumnAlignments->{Left}], GridBox[{
                {"c"},
                {"d"},
                {"e"},
                {"f"},
                {"g"},
                {"h"}
                },
              RowSpacings->0.25,
              ColumnSpacings->1,
              RowAlignments->Baseline,
              ColumnAlignments->{Left}], GridBox[{
                {"a"},
                {"b"},
                {"c"},
                {"d"},
                {"e"},
                {"f"},
                {"g"},
                {"h"}
                },
              RowSpacings->0.25,
              ColumnSpacings->1,
              RowAlignments->Baseline,
              ColumnAlignments->{Left}]},
          {GridBox[{
                {"a"}
                },
              RowSpacings->0.25,
              ColumnSpacings->1,
              RowAlignments->Baseline,
              ColumnAlignments->{Left}], GridBox[{
                {"b"}
                },
              RowSpacings->0.25,
              ColumnSpacings->1,
              RowAlignments->Baseline,
              ColumnAlignments->{Left}], GridBox[{
                {"c"}
                },
              RowSpacings->0.25,
              ColumnSpacings->1,
              RowAlignments->Baseline,
              ColumnAlignments->{Left}], GridBox[{
                {"d"}
                },
              RowSpacings->0.25,
              ColumnSpacings->1,
              RowAlignments->Baseline,
              ColumnAlignments->{Left}], GridBox[{
                {"e"}
                },
              RowSpacings->0.25,
              ColumnSpacings->1,
              RowAlignments->Baseline,
              ColumnAlignments->{Left}], GridBox[{
                {"f"}
                },
              RowSpacings->0.25,
              ColumnSpacings->1,
              RowAlignments->Baseline,
              ColumnAlignments->{Left}], GridBox[{
                {"g"}
                },
              RowSpacings->0.25,
              ColumnSpacings->1,
              RowAlignments->Baseline,
              ColumnAlignments->{Left}], GridBox[{
                {"h"}
                },
              RowSpacings->0.25,
              ColumnSpacings->1,
              RowAlignments->Baseline,
              ColumnAlignments->{Left}], GridBox[{
                {"f"},
                {"g"}
                },
              RowSpacings->0.25,
              ColumnSpacings->1,
              RowAlignments->Baseline,
              ColumnAlignments->{Left}], GridBox[{
                {"e"},
                {"f"},
                {"g"}
                },
              RowSpacings->0.25,
              ColumnSpacings->1,
              RowAlignments->Baseline,
              ColumnAlignments->{Left}], GridBox[{
                {"c"},
                {"d"}
                },
              RowSpacings->0.25,
              ColumnSpacings->1,
              RowAlignments->Baseline,
              ColumnAlignments->{Left}], GridBox[{
                {"e"},
                {"f"},
                {"g"},
                {"h"}
                },
              RowSpacings->0.25,
              ColumnSpacings->1,
              RowAlignments->Baseline,
              ColumnAlignments->{Left}], GridBox[{
                {"c"},
                {"d"},
                {"e"},
                {"f"},
                {"g"},
                {"h"}
                },
              RowSpacings->0.25,
              ColumnSpacings->1,
              RowAlignments->Baseline,
              ColumnAlignments->{Left}], GridBox[{
                {"a"},
                {"b"}
                },
              RowSpacings->0.25,
              ColumnSpacings->1,
              RowAlignments->Baseline,
              ColumnAlignments->{Left}], GridBox[{
                {"a"},
                {"b"},
                {"c"},
                {"d"},
                {"e"},
                {"f"},
                {"g"},
                {"h"}
                },
              RowSpacings->0.25,
              ColumnSpacings->1,
              RowAlignments->Baseline,
              ColumnAlignments->{Left}]},
          {GridBox[{
                {"a"}
                },
              RowSpacings->0.25,
              ColumnSpacings->1,
              RowAlignments->Baseline,
              ColumnAlignments->{Left}], GridBox[{
                {"b"}
                },
              RowSpacings->0.25,
              ColumnSpacings->1,
              RowAlignments->Baseline,
              ColumnAlignments->{Left}], GridBox[{
                {"c"}
                },
              RowSpacings->0.25,
              ColumnSpacings->1,
              RowAlignments->Baseline,
              ColumnAlignments->{Left}], GridBox[{
                {"d"}
                },
              RowSpacings->0.25,
              ColumnSpacings->1,
              RowAlignments->Baseline,
              ColumnAlignments->{Left}], GridBox[{
                {"e"}
                },
              RowSpacings->0.25,
              ColumnSpacings->1,
              RowAlignments->Baseline,
              ColumnAlignments->{Left}], GridBox[{
                {"f"}
                },
              RowSpacings->0.25,
              ColumnSpacings->1,
              RowAlignments->Baseline,
              ColumnAlignments->{Left}], GridBox[{
                {"g"}
                },
              RowSpacings->0.25,
              ColumnSpacings->1,
              RowAlignments->Baseline,
              ColumnAlignments->{Left}], GridBox[{
                {"h"}
                },
              RowSpacings->0.25,
              ColumnSpacings->1,
              RowAlignments->Baseline,
              ColumnAlignments->{Left}], GridBox[{
                {"f"},
                {"g"}
                },
              RowSpacings->0.25,
              ColumnSpacings->1,
              RowAlignments->Baseline,
              ColumnAlignments->{Left}], GridBox[{
                {"e"},
                {"f"},
                {"g"}
                },
              RowSpacings->0.25,
              ColumnSpacings->1,
              RowAlignments->Baseline,
              ColumnAlignments->{Left}], GridBox[{
                {"e"},
                {"f"},
                {"g"},
                {"h"}
                },
              RowSpacings->0.25,
              ColumnSpacings->1,
              RowAlignments->Baseline,
              ColumnAlignments->{Left}], GridBox[{
                {"a"},
                {"b"}
                },
              RowSpacings->0.25,
              ColumnSpacings->1,
              RowAlignments->Baseline,
              ColumnAlignments->{Left}], GridBox[{
                {"c"},
                {"d"}
                },
              RowSpacings->0.25,
              ColumnSpacings->1,
              RowAlignments->Baseline,
              ColumnAlignments->{Left}], GridBox[{
                {"c"},
                {"d"},
                {"e"},
                {"f"},
                {"g"},
                {"h"}
                },
              RowSpacings->0.25,
              ColumnSpacings->1,
              RowAlignments->Baseline,
              ColumnAlignments->{Left}], GridBox[{
                {"a"},
                {"b"},
                {"c"},
                {"d"},
                {"e"},
                {"f"},
                {"g"},
                {"h"}
                },
              RowSpacings->0.25,
              ColumnSpacings->1,
              RowAlignments->Baseline,
              ColumnAlignments->{Left}]},
          {GridBox[{
                {"a"}
                },
              RowSpacings->0.25,
              ColumnSpacings->1,
              RowAlignments->Baseline,
              ColumnAlignments->{Left}], GridBox[{
                {"b"}
                },
              RowSpacings->0.25,
              ColumnSpacings->1,
              RowAlignments->Baseline,
              ColumnAlignments->{Left}], GridBox[{
                {"c"}
                },
              RowSpacings->0.25,
              ColumnSpacings->1,
              RowAlignments->Baseline,
              ColumnAlignments->{Left}], GridBox[{
                {"d"}
                },
              RowSpacings->0.25,
              ColumnSpacings->1,
              RowAlignments->Baseline,
              ColumnAlignments->{Left}], GridBox[{
                {"e"}
                },
              RowSpacings->0.25,
              ColumnSpacings->1,
              RowAlignments->Baseline,
              ColumnAlignments->{Left}], GridBox[{
                {"f"}
                },
              RowSpacings->0.25,
              ColumnSpacings->1,
              RowAlignments->Baseline,
              ColumnAlignments->{Left}], GridBox[{
                {"g"}
                },
              RowSpacings->0.25,
              ColumnSpacings->1,
              RowAlignments->Baseline,
              ColumnAlignments->{Left}], GridBox[{
                {"h"}
                },
              RowSpacings->0.25,
              ColumnSpacings->1,
              RowAlignments->Baseline,
              ColumnAlignments->{Left}], GridBox[{
                {"f"},
                {"g"}
                },
              RowSpacings->0.25,
              ColumnSpacings->1,
              RowAlignments->Baseline,
              ColumnAlignments->{Left}], GridBox[{
                {"e"},
                {"f"},
                {"g"}
                },
              RowSpacings->0.25,
              ColumnSpacings->1,
              RowAlignments->Baseline,
              ColumnAlignments->{Left}], GridBox[{
                {"e"},
                {"f"},
                {"g"},
                {"h"}
                },
              RowSpacings->0.25,
              ColumnSpacings->1,
              RowAlignments->Baseline,
              ColumnAlignments->{Left}], GridBox[{
                {"c"},
                {"d"}
                },
              RowSpacings->0.25,
              ColumnSpacings->1,
              RowAlignments->Baseline,
              ColumnAlignments->{Left}], GridBox[{
                {"a"},
                {"b"}
                },
              RowSpacings->0.25,
              ColumnSpacings->1,
              RowAlignments->Baseline,
              ColumnAlignments->{Left}], GridBox[{
                {"c"},
                {"d"},
                {"e"},
                {"f"},
                {"g"},
                {"h"}
                },
              RowSpacings->0.25,
              ColumnSpacings->1,
              RowAlignments->Baseline,
              ColumnAlignments->{Left}], GridBox[{
                {"a"},
                {"b"},
                {"c"},
                {"d"},
                {"e"},
                {"f"},
                {"g"},
                {"h"}
                },
              RowSpacings->0.25,
              ColumnSpacings->1,
              RowAlignments->Baseline,
              ColumnAlignments->{Left}]},
          {GridBox[{
                {"a"}
                },
              RowSpacings->0.25,
              ColumnSpacings->1,
              RowAlignments->Baseline,
              ColumnAlignments->{Left}], GridBox[{
                {"b"}
                },
              RowSpacings->0.25,
              ColumnSpacings->1,
              RowAlignments->Baseline,
              ColumnAlignments->{Left}], GridBox[{
                {"c"}
                },
              RowSpacings->0.25,
              ColumnSpacings->1,
              RowAlignments->Baseline,
              ColumnAlignments->{Left}], GridBox[{
                {"d"}
                },
              RowSpacings->0.25,
              ColumnSpacings->1,
              RowAlignments->Baseline,
              ColumnAlignments->{Left}], GridBox[{
                {"e"}
                },
              RowSpacings->0.25,
              ColumnSpacings->1,
              RowAlignments->Baseline,
              ColumnAlignments->{Left}], GridBox[{
                {"f"}
                },
              RowSpacings->0.25,
              ColumnSpacings->1,
              RowAlignments->Baseline,
              ColumnAlignments->{Left}], GridBox[{
                {"g"}
                },
              RowSpacings->0.25,
              ColumnSpacings->1,
              RowAlignments->Baseline,
              ColumnAlignments->{Left}], GridBox[{
                {"h"}
                },
              RowSpacings->0.25,
              ColumnSpacings->1,
              RowAlignments->Baseline,
              ColumnAlignments->{Left}], GridBox[{
                {"f"},
                {"g"}
                },
              RowSpacings->0.25,
              ColumnSpacings->1,
              RowAlignments->Baseline,
              ColumnAlignments->{Left}], GridBox[{
                {"e"},
                {"f"},
                {"g"}
                },
              RowSpacings->0.25,
              ColumnSpacings->1,
              RowAlignments->Baseline,
              ColumnAlignments->{Left}], GridBox[{
                {"e"},
                {"f"},
                {"g"},
                {"h"}
                },
              RowSpacings->0.25,
              ColumnSpacings->1,
              RowAlignments->Baseline,
              ColumnAlignments->{Left}], GridBox[{
                {"c"},
                {"d"}
                },
              RowSpacings->0.25,
              ColumnSpacings->1,
              RowAlignments->Baseline,
              ColumnAlignments->{Left}], GridBox[{
                {"c"},
                {"d"},
                {"e"},
                {"f"},
                {"g"},
                {"h"}
                },
              RowSpacings->0.25,
              ColumnSpacings->1,
              RowAlignments->Baseline,
              ColumnAlignments->{Left}], GridBox[{
                {"a"},
                {"b"}
                },
              RowSpacings->0.25,
              ColumnSpacings->1,
              RowAlignments->Baseline,
              ColumnAlignments->{Left}], GridBox[{
                {"a"},
                {"b"},
                {"c"},
                {"d"},
                {"e"},
                {"f"},
                {"g"},
                {"h"}
                },
              RowSpacings->0.25,
              ColumnSpacings->1,
              RowAlignments->Baseline,
              ColumnAlignments->{Left}]}
          },
        RowSpacings->1,
        ColumnSpacings->3,
        RowAlignments->Baseline,
        ColumnAlignments->{Left}],
      TableForm[ {{{a}, {b}, {c}, {d}, {e}, {f}, {g}, {h}, {a, b}, {c, d}, {
        f, g}, {e, f, g}, {e, f, g, h}, {c, d, e, f, g, h}, {a, b, c, d, e, 
        f, g, h}}, {{a}, {b}, {c}, {d}, {e}, {f}, {g}, {h}, {a, b}, {f, g}, {
        c, d}, {e, f, g}, {e, f, g, h}, {c, d, e, f, g, h}, {a, b, c, d, e, 
        f, g, h}}, {{a}, {b}, {c}, {d}, {e}, {f}, {g}, {h}, {a, b}, {f, g}, {
        e, f, g}, {c, d}, {e, f, g, h}, {c, d, e, f, g, h}, {a, b, c, d, e, 
        f, g, h}}, {{a}, {b}, {c}, {d}, {e}, {f}, {g}, {h}, {a, b}, {f, g}, {
        e, f, g}, {e, f, g, h}, {c, d}, {c, d, e, f, g, h}, {a, b, c, d, e, 
        f, g, h}}, {{a}, {b}, {c}, {d}, {e}, {f}, {g}, {h}, {c, d}, {a, b}, {
        f, g}, {e, f, g}, {e, f, g, h}, {c, d, e, f, g, h}, {a, b, c, d, e, 
        f, g, h}}, {{a}, {b}, {c}, {d}, {e}, {f}, {g}, {h}, {c, d}, {f, g}, {
        a, b}, {e, f, g}, {e, f, g, h}, {c, d, e, f, g, h}, {a, b, c, d, e, 
        f, g, h}}, {{a}, {b}, {c}, {d}, {e}, {f}, {g}, {h}, {c, d}, {f, g}, {
        e, f, g}, {a, b}, {e, f, g, h}, {c, d, e, f, g, h}, {a, b, c, d, e, 
        f, g, h}}, {{a}, {b}, {c}, {d}, {e}, {f}, {g}, {h}, {c, d}, {f, g}, {
        e, f, g}, {e, f, g, h}, {a, b}, {c, d, e, f, g, h}, {a, b, c, d, e, 
        f, g, h}}, {{a}, {b}, {c}, {d}, {e}, {f}, {g}, {h}, {c, d}, {f, g}, {
        e, f, g}, {e, f, g, h}, {c, d, e, f, g, h}, {a, b}, {a, b, c, d, e, 
        f, g, h}}, {{a}, {b}, {c}, {d}, {e}, {f}, {g}, {h}, {f, g}, {a, b}, {
        c, d}, {e, f, g}, {e, f, g, h}, {c, d, e, f, g, h}, {a, b, c, d, e, 
        f, g, h}}, {{a}, {b}, {c}, {d}, {e}, {f}, {g}, {h}, {f, g}, {a, b}, {
        e, f, g}, {c, d}, {e, f, g, h}, {c, d, e, f, g, h}, {a, b, c, d, e, 
        f, g, h}}, {{a}, {b}, {c}, {d}, {e}, {f}, {g}, {h}, {f, g}, {a, b}, {
        e, f, g}, {e, f, g, h}, {c, d}, {c, d, e, f, g, h}, {a, b, c, d, e, 
        f, g, h}}, {{a}, {b}, {c}, {d}, {e}, {f}, {g}, {h}, {f, g}, {c, d}, {
        a, b}, {e, f, g}, {e, f, g, h}, {c, d, e, f, g, h}, {a, b, c, d, e, 
        f, g, h}}, {{a}, {b}, {c}, {d}, {e}, {f}, {g}, {h}, {f, g}, {c, d}, {
        e, f, g}, {a, b}, {e, f, g, h}, {c, d, e, f, g, h}, {a, b, c, d, e, 
        f, g, h}}, {{a}, {b}, {c}, {d}, {e}, {f}, {g}, {h}, {f, g}, {c, d}, {
        e, f, g}, {e, f, g, h}, {a, b}, {c, d, e, f, g, h}, {a, b, c, d, e, 
        f, g, h}}, {{a}, {b}, {c}, {d}, {e}, {f}, {g}, {h}, {f, g}, {c, d}, {
        e, f, g}, {e, f, g, h}, {c, d, e, f, g, h}, {a, b}, {a, b, c, d, e, 
        f, g, h}}, {{a}, {b}, {c}, {d}, {e}, {f}, {g}, {h}, {f, g}, {e, f, 
        g}, {a, b}, {c, d}, {e, f, g, h}, {c, d, e, f, g, h}, {a, b, c, d, e, 
        f, g, h}}, {{a}, {b}, {c}, {d}, {e}, {f}, {g}, {h}, {f, g}, {e, f, 
        g}, {a, b}, {e, f, g, h}, {c, d}, {c, d, e, f, g, h}, {a, b, c, d, e, 
        f, g, h}}, {{a}, {b}, {c}, {d}, {e}, {f}, {g}, {h}, {f, g}, {e, f, 
        g}, {c, d}, {a, b}, {e, f, g, h}, {c, d, e, f, g, h}, {a, b, c, d, e, 
        f, g, h}}, {{a}, {b}, {c}, {d}, {e}, {f}, {g}, {h}, {f, g}, {e, f, 
        g}, {c, d}, {e, f, g, h}, {a, b}, {c, d, e, f, g, h}, {a, b, c, d, e, 
        f, g, h}}, {{a}, {b}, {c}, {d}, {e}, {f}, {g}, {h}, {f, g}, {e, f, 
        g}, {c, d}, {e, f, g, h}, {c, d, e, f, g, h}, {a, b}, {a, b, c, d, e, 
        f, g, h}}, {{a}, {b}, {c}, {d}, {e}, {f}, {g}, {h}, {f, g}, {e, f, 
        g}, {e, f, g, h}, {a, b}, {c, d}, {c, d, e, f, g, h}, {a, b, c, d, e, 
        f, g, h}}, {{a}, {b}, {c}, {d}, {e}, {f}, {g}, {h}, {f, g}, {e, f, 
        g}, {e, f, g, h}, {c, d}, {a, b}, {c, d, e, f, g, h}, {a, b, c, d, e, 
        f, g, h}}, {{a}, {b}, {c}, {d}, {e}, {f}, {g}, {h}, {f, g}, {e, f, 
        g}, {e, f, g, h}, {c, d}, {c, d, e, f, g, h}, {a, b}, {a, b, c, d, e, 
        f, g, h}}}]]], "Output",
  CellLabel->"Out[410]//TableForm="]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    \(Length[ords]\)], "Input",
  CellLabel->"In[411]:="],

Cell[BoxData[
    \(24\)], "Output",
  CellLabel->"Out[411]="]
}, Closed]],

Cell["\<\
For large genealogies, there may be very many possible \
orderings\
\>", "Text"],

Cell[TextData[Cell[BoxData[
    FormBox[GridBox[{
          {\(RandomCoalescenceOrder[
              g]\), \(gives\ a\ random\ ordering\ of\ the\ possible\ \
coalescence\ events\)}
          }], TraditionalForm]]]], "DefinitionBox",
  CellTags->"RandomCoalescenceOrder"],

Cell["Here are some randomly chosen orderings of the events.  ", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(nl1 = RandomCoalescenceOrder[tr]\)], "Input",
  CellLabel->"In[138]:="],

Cell[BoxData[
    \({{a}, {b}, {c}, {d}, {e}, {f}, {g}, {h}, {f, g}, {c, d}, {a, b}, {e, f, 
        g}, {e, f, g, h}, {c, d, e, f, g, h}, {a, b, c, d, e, f, g, h}}\)], 
  "Output",
  CellLabel->"Out[138]="]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"nl2", "=", 
      RowBox[{
        FormBox["RandomCoalescenceOrder",
          "TraditionalForm"], "[", "tr", "]"}]}]], "Input",
  CellLabel->"In[145]:="],

Cell[BoxData[
    \({{a}, {b}, {c}, {d}, {e}, {f}, {g}, {h}, {c, d}, {f, g}, {e, f, g}, {a, 
        b}, {e, f, g, h}, {c, d, e, f, g, h}, {a, b, c, d, e, f, g, h}}\)], 
  "Output",
  CellLabel->"Out[145]="]
}, Closed]],

Cell["\<\
RandomCoalescenceOrder[] does not call PossibleCoalescenceOrder[], \
and so can be used on large genealogies \
\>", "Text"],

Cell[TextData[Cell[BoxData[
    FormBox[GridBox[{
          {\(NumberOfPossibleCoalescences[g, 
              nodelist]\), \(gives\ the\ number\ of\ possible\ coalescences\ \
that\ could\ occur\ at\ each\ \(\(step\)\(.\)\)\)}
          }], TraditionalForm]]]], "DefinitionBox",
  CellTags->"NumberOfPossibleCoalescences"],

Cell["\<\
These are the numbers of possible coalescences that could occur at \
each stage.  Elements correspond to the internal nodes.  \
\>", "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{" ", 
      RowBox[{
        FormBox["NumberOfPossibleCoalescences",
          "TraditionalForm"], "[", \(tr, nl1\), "]"}]}]], "Input",
  CellLabel->"In[140]:="],

Cell[BoxData[
    \({3, 3, 2, 1, 1, 1, 1}\)], "Output",
  CellLabel->"Out[140]="]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{" ", 
      RowBox[{
        FormBox["NumberOfPossibleCoalescences",
          "TraditionalForm"], "[", \(tr, nl2\), "]"}]}]], "Input",
  CellLabel->"In[146]:="],

Cell[BoxData[
    \({3, 2, 2, 2, 1, 1, 1}\)], "Output",
  CellLabel->"Out[146]="]
}, Closed]],

Cell["\<\
Here is a genealogy with a root node that has only one \
descendant:\
\>", "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[
    \(tr3 = RandomGenealogy[{a, b, c, d}]; Show[PlotGenealogy[tr]]; \)], 
  "Input",
  CellLabel->"In[148]:="],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.2 0.2 0.103006 0.103006 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
0 g
.5 Mabswid
[ ] 0 setdash
.7 .20601 m
.6 .10301 L
s
.7 .20601 m
.8 .10301 L
s
.6 .30902 m
.4 .10301 L
s
.6 .30902 m
.7 .20601 L
s
.5 .41202 m
.2 .10301 L
s
.5 .41202 m
.6 .30902 L
s
.5 .51503 m
.5 .41202 L
s
[(1)] .66 .22661 0 0 Mshowa
[(2)] .56 .32962 0 0 Mshowa
[(3)] .46 .43262 0 0 Mshowa
[(4)] .46 .53563 0 0 Mshowa
gsave
.2 .0824 -66 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 16.000000 moveto
 558.000000 16.000000 lineto
 558.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 16.000000 lineto
closepath
clip newpath
63.000000 13.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(a) show
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: font Courier
grestore
gsave
.4 .0824 -66 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 16.000000 moveto
 558.000000 16.000000 lineto
 558.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 16.000000 lineto
closepath
clip newpath
63.000000 13.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(d) show
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: font Courier
grestore
gsave
.6 .0824 -66 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 16.000000 moveto
 558.000000 16.000000 lineto
 558.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 16.000000 lineto
closepath
clip newpath
63.000000 13.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(b) show
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: font Courier
grestore
gsave
.8 .0824 -66 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 16.000000 moveto
 558.000000 16.000000 lineto
 558.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 16.000000 lineto
closepath
clip newpath
63.000000 13.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(c) show
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: font Courier
grestore
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[148]:=",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/A000`40O003h00Oogoo8Goo003oOolQ
Ool00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00
ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQ
Ool00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00=goo1@00=Goo1@00=7oo1000=Woo0`00
>Goo000gOol01000Oomoo`00=Goo00D007ooOomoo`0003Eoo`05001oogooOol0000dOol01@00Oomo
ogoo0000>7oo000gOol4000eOol01@00Oomoogoo0000=Goo00D007ooOomoo`0003Aoo`03001oogoo
03Yoo`00>Woo00<007ooOol0<goo00D007ooOomoo`0003Eoo`05001oogooOol0000dOol01@00Oomo
ogoo0000>7oo000hOol3000fOol4000eOol4000fOol4000hOol007Aoo`03001oogoo03=oo`03001o
ogoo07=oo`00Lgoo0P00=7oo0P00MGoo003oOolQOol003Uoo`03001oogoo03Ioo`03001oogoo03Mo
o`03001oogoo03Ioo`03001oogoo03Qoo`00>Goo00<007ooOol0=Woo00<007ooOol0=goo00<007oo
Ool0=Woo00<007ooOol0>7oo000jOol00`00Oomoo`0fOol00`00Oomoo`0gOol00`00Oomoo`0dOol0
0`00Oomoo`0iOol003]oo`03001oogoo03Ioo`03001oogoo03Moo`03001oogoo039oo`03001oogoo
03Yoo`00?7oo00<007ooOol0=Woo00<007ooOol0=goo00<007ooOol0<7oo00<007ooOol0>goo000m
Ool00`00Oomoo`0fOol00`00Oomoo`0gOol00`00Oomoo`0^Ool00`00Oomoo`0lOol003ioo`03001o
ogoo03Ioo`03001oogoo03Moo`03001oogoo02aoo`03001oogoo03eoo`00?goo00<007ooOol0=Woo
00<007ooOol0=goo00<007ooOol0:Woo00<007ooOol0?Woo0010Ool00`00Oomoo`0fOol00`00Oomo
o`0gOol00`00Oomoo`0XOol00`00Oomoo`0oOol0045oo`03001oogoo03Ioo`03001oogoo03Moo`03
001oogoo02Ioo`03001oogoo041oo`00@Woo00<007ooOol0=Woo00<007ooOol0=goo00<007ooOol0
97oo00<007ooOol0@Goo0013Ool00`00Oomoo`0fOol00`00Oomoo`0gOol00`00Oomoo`0ROol00`00
Oomoo`12Ool004Aoo`03001oogoo03Ioo`03001oogoo03Moo`03001oogoo021oo`03001oogoo04=o
o`00AGoo00<007ooOol0=Woo00<007ooOol0=goo00<007ooOol07Woo00<007ooOol0A7oo0016Ool0
0`00Oomoo`0fOol00`00Oomoo`0gOol00`00Oomoo`0LOol00`00Oomoo`15Ool004Moo`03001oogoo
03Ioo`03001oogoo03Moo`03001oogoo01Yoo`03001oogoo04Ioo`00B7oo00<007ooOol0=Woo00<0
07ooOol0=Woo00<007ooOol06Goo00<007ooOol0Agoo0019Ool00`00Oomoo`0fOol00`00Oomoo`0f
Ool00`00Oomoo`0GOol00`00Oomoo`18Ool004Yoo`03001oogoo03Ioo`03001oogoo03Ioo`03001o
ogoo01Eoo`03001oogoo04Uoo`00Bgoo00<007ooOol0=Woo00<007ooOol0=Woo00<007ooOol04goo
00<007ooOol0BWoo001<Ool00`00Oomoo`0fOol00`00Oomoo`0fOol00`00Oomoo`0AOol00`00Oomo
o`1;Ool004eoo`03001oogoo03Ioo`03001oogoo03Ioo`03001oogoo00moo`03001oogoo04aoo`00
CWoo00<007ooOol0=Woo00<007ooOol0=Woo00<007ooOol03Goo00<007ooOol0CGoo001?Ool00`00
Oomoo`0fOol00`00Oomoo`0fOol00`00Oomoo`0;Ool00`00Oomoo`1>Ool0051oo`03001oogoo03Io
o`03001oogoo03Ioo`03001oogoo00Uoo`03001oogoo04moo`00DGoo00<007ooOol0=Woo00<007oo
Ool0=Woo00<007ooOol01goo00<007ooOol0D7oo001BOol00`00Oomoo`0fOol00`00Oomoo`0fOol0
0`00Oomoo`05Ool00`00Oomoo`1AOol005=oo`03001oogoo03Ioo`03001oogoo03Ioo`03001oogoo
00=oo`03001oogoo059oo`00E7oo00<007ooOol0=Woo00<007ooOol0=Woo00D007ooOomoo`0005Eo
o`00EGoo00<007ooOol0=Woo00<007ooOol0=Woo00<007oo0000EWoo001FOol00`00Oomoo`0fOol0
0`00Oomoo`0fOol00`00Oomoo`1EOol005Ioo`03001oogoo03Moo`03001oogoo03Eoo`03001oogoo
05Eoo`00Egoo00<007ooOol0=goo00<007ooOol0<goo00<007ooOol0EWoo001HOol00`00Oomoo`0g
Ool00`00Oomoo`0VOol30008Ool00`00Oomoo`1GOol005Uoo`03001oogoo03Moo`03001oogoo02Io
o`03001oogoo00Ioo`03001oogoo05Qoo`00FWoo00<007ooOol0=goo00<007ooOol09Goo00<007oo
Ool01Goo00<007ooOol0FGoo001KOol00`00Oomoo`0gOol00`00Oomoo`0TOol00`00Oomoo`04Ool0
0`00Oomoo`1JOol005aoo`03001oogoo03Moo`03001oogoo02=oo`03001oogoo00=oo`03001oogoo
05]oo`00GGoo00<007ooOol0=goo00<007ooOol08Goo0P0017oo00<007ooOol0G7oo001NOol00`00
Oomoo`0gOol00`00Oomoo`0UOol00`00Oomoo`1MOol005moo`03001oogoo03Moo`03001oogoo02=o
o`03001oogoo05ioo`00H7oo00<007ooOol0=goo00<007ooOol08Goo00<007ooOol0Ggoo001QOol0
0`00Oomoo`0gOol00`00Oomoo`0OOol00`00Oomoo`1POol0069oo`03001oogoo03Moo`03001oogoo
01eoo`03001oogoo065oo`00Hgoo00<007ooOol0=goo00<007ooOol06goo00<007ooOol0HWoo001T
Ool00`00Oomoo`0gOol00`00Oomoo`0IOol00`00Oomoo`1SOol006Eoo`03001oogoo03Moo`03001o
ogoo01Moo`03001oogoo06Aoo`00IWoo00<007ooOol0=goo00<007ooOol05Goo00<007ooOol0IGoo
001WOol00`00Oomoo`0gOol00`00Oomoo`0COol00`00Oomoo`1VOol006Qoo`03001oogoo03Moo`03
001oogoo015oo`03001oogoo06Moo`00JGoo00<007ooOol0=goo00<007ooOol03goo00<007ooOol0
J7oo001ZOol00`00Oomoo`0gOol00`00Oomoo`0=Ool00`00Oomoo`1YOol006]oo`03001oogoo03Mo
o`03001oogoo00]oo`03001oogoo06Yoo`00K7oo00<007ooOol0=goo00<007ooOol02Goo00<007oo
Ool0Jgoo001]Ool00`00Oomoo`0gOol00`00Oomoo`07Ool00`00Oomoo`1/Ool006ioo`03001oogoo
03Moo`03001oogoo00Eoo`03001oogoo06eoo`00Kgoo00<007ooOol0=goo00<007ooOol00goo00<0
07ooOol0KWoo001`Ool00`00Oomoo`0gOol01@00Oomoogoo0000LGoo001aOol00`00Oomoo`0gOol0
0`00Ool0001bOol0079oo`03001oogoo03Moo`03001oogoo075oo`00LWoo00<007ooOol0=goo00<0
07ooOol0LGoo001cOol00`00Oomoo`0eOol00`00Oomoo`1bOol007Aoo`03001oogoo03=oo`03001o
ogoo07=oo`00MGoo00<007ooOol09Woo10001goo00<007ooOol0M7oo001fOol00`00Oomoo`0VOol0
0`00Oomoo`06Ool00`00Oomoo`1eOol007Moo`03001oogoo02Ioo`03001oogoo00Aoo`03001oogoo
07Ioo`00N7oo00<007ooOol09Woo00<007ooOol00Woo00<007ooOol0Mgoo001iOol00`00Oomoo`0R
Ool01000Oomoo`000goo00<007ooOol0N7oo001jOol00`00Oomoo`0ROol20003Ool00`00Oomoo`1i
Ool007]oo`03001oogoo02Eoo`03001oogoo07Yoo`00O7oo00<007ooOol08goo00<007ooOol0Ngoo
001mOol00`00Oomoo`0QOol00`00Oomoo`1lOol007ioo`03001oogoo01moo`03001oogoo07eoo`00
Ogoo00<007ooOol07Goo00<007ooOol0OWoo0020Ool00`00Oomoo`0KOol00`00Oomoo`1oOol0085o
o`03001oogoo01Uoo`03001oogoo081oo`00PWoo00<007ooOol05goo00<007ooOol0PGoo0023Ool0
0`00Oomoo`0EOol00`00Oomoo`22Ool008Aoo`03001oogoo01=oo`03001oogoo08=oo`00QGoo00<0
07ooOol04Goo00<007ooOol0Q7oo0026Ool00`00Oomoo`0?Ool00`00Oomoo`25Ool008Moo`03001o
ogoo00eoo`03001oogoo08Ioo`00R7oo00<007ooOol02goo00<007ooOol0Qgoo0029Ool00`00Oomo
o`09Ool00`00Oomoo`28Ool008Yoo`03001oogoo00Moo`03001oogoo08Uoo`00Rgoo00<007ooOol0
1Goo00<007ooOol0RWoo002<Ool00`00Oomoo`03Ool00`00Oomoo`2;Ool008eoo`05001oogooOol0
002>Ool008ioo`03001oo`0008moo`00Sgoo00<007ooOol0SWoo002?Ool00`00Oomoo`2>Ool008mo
o`03001oogoo08ioo`00PWoo0`002Woo00<007ooOol0SWoo0025Ool00`00Oomoo`07Ool00`00Oomo
o`2>Ool008Eoo`03001oogoo00Moo`03001oogoo08ioo`00Pgoo0P002Woo00<007ooOol0SWoo0025
Ool00`00Oomoo`07Ool00`00Oomoo`2>Ool0089oo`<000Yoo`03001oogoo08ioo`00Sgoo00<007oo
Ool0SWoo002?Ool00`00Oomoo`2>Ool008moo`03001oogoo08ioo`00Sgoo00<007ooOol0SWoo002?
Ool00`00Oomoo`2>Ool008moo`03001oogoo08ioo`00Sgoo00<007ooOol0SWoo002?Ool00`00Oomo
o`2>Ool008moo`03001oogoo08ioo`00Sgoo00<007ooOol0SWoo002?Ool00`00Oomoo`2>Ool008mo
o`03001oogoo08ioo`00Sgoo00<007ooOol0SWoo002?Ool00`00Oomoo`2>Ool008moo`03001oogoo
08ioo`00Sgoo00<007ooOol0SWoo002?Ool00`00Oomoo`2>Ool008moo`03001oogoo08ioo`00Sgoo
00<007ooOol0SWoo002?Ool00`00Oomoo`2>Ool008moo`03001oogoo08ioo`00ogoo8Goo003oOolQ
Ool00?moob5oo`00Pgoo0`00VWoo0024Ool00`00Oomoo`2IOol0089oo`@009Yoo`00PWoo00<007oo
0000Vgoo0022Ool00`00Ool0002KOol008=oo`8009]oo`00ogoo8Goo003oOolQOol00?moob5oo`00
ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQ
Ool00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00
ogoo8Goo003oOolQOol00001\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-1.0062, -1.00003, 
  0.0174648, 0.0339103}}]
}, Closed]],

Cell["For the root node, there are no possible coalescences:", "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[
    \(nl3 = RandomCoalescenceOrder[tr3]\)], "Input",
  CellLabel->"In[149]:="],

Cell[BoxData[
    \({a, b, c, d, 1, 2, 3, 4}\)], "Output",
  CellLabel->"Out[149]="]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      FormBox["NumberOfPossibleCoalescences",
        "TraditionalForm"], "[", \(tr3, nl3\), "]"}]], "Input",
  CellLabel->"In[150]:="],

Cell[BoxData[
    \({1, 1, 1, 0}\)], "Output",
  CellLabel->"Out[150]="]
}, Closed]]
}, Open  ]]
},
FrontEndVersion->"4.0 for Macintosh",
ScreenRectangle->{{0, 1024}, {0, 748}},
WindowSize->{520, 653},
WindowMargins->{{Automatic, 0}, {Automatic, -1}},
StyleDefinitions -> "HelpBrowser.nb",
MacintoshSystemPageSetup->"\<\
00`0001804P000000_02@?o/onh3109BI085:0?l0@00005X0FP000003[0;@001
0000I00100000@0000000BL?0040000000000000000000000000000000000?nL
ojH?50^J00P100000000000000000000\>"
]


(***********************************************************************
Cached data follows.  If you edit this Notebook file directly, not using
Mathematica, you must remove the line containing CacheID at the top of 
the file.  The cache data will then be recreated when you save this file 
from within Mathematica.
***********************************************************************)

(*CellTagsOutline
CellTagsIndex->{
  "PossibleCoalescenceOrder"->{
    Cell[1791, 53, 426, 8, 76, "DefinitionBox",
      CellTags->"PossibleCoalescenceOrder"]},
  "RandomCoalescenceOrder"->{
    Cell[89593, 2828, 270, 6, 50, "DefinitionBox",
      CellTags->"RandomCoalescenceOrder"]},
  "NumberOfPossibleCoalescences"->{
    Cell[90843, 2872, 321, 6, 50, "DefinitionBox",
      CellTags->"NumberOfPossibleCoalescences"]}
  }
*)

(*CellTagsIndex
CellTagsIndex->{
  {"PossibleCoalescenceOrder", 104632, 3265},
  {"RandomCoalescenceOrder", 104756, 3268},
  {"NumberOfPossibleCoalescences", 104887, 3271}
  }
*)

(*NotebookFileOutline
Notebook[{

Cell[CellGroupData[{
Cell[1739, 51, 49, 0, 36, "SubsectionIcon"],
Cell[1791, 53, 426, 8, 76, "DefinitionBox",
  CellTags->"PossibleCoalescenceOrder"],
Cell[2220, 63, 69, 0, 28, "MathCaption"],
Cell[2292, 65, 557, 11, 102, "Input"],
Cell[2852, 78, 106, 3, 28, "MathCaption"],

Cell[CellGroupData[{
Cell[2983, 85, 113, 2, 27, "Input"],
Cell[3099, 89, 86213, 2720, 2342, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[89349, 2814, 71, 2, 23, "Input"],
Cell[89423, 2818, 62, 2, 20, "Output"]
}, Closed]],
Cell[89500, 2823, 90, 3, 18, "Text"],
Cell[89593, 2828, 270, 6, 50, "DefinitionBox",
  CellTags->"RandomCoalescenceOrder"],
Cell[89866, 2836, 72, 0, 22, "Text"],

Cell[CellGroupData[{
Cell[89963, 2840, 91, 2, 27, "Input"],
Cell[90057, 2844, 207, 4, 35, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[90301, 2853, 181, 5, 23, "Input"],
Cell[90485, 2860, 207, 4, 35, "Output"]
}, Closed]],
Cell[90707, 2867, 133, 3, 32, "Text"],
Cell[90843, 2872, 321, 6, 50, "DefinitionBox",
  CellTags->"NumberOfPossibleCoalescences"],
Cell[91167, 2880, 157, 3, 42, "MathCaption"],

Cell[CellGroupData[{
Cell[91349, 2887, 187, 5, 27, "Input"],
Cell[91539, 2894, 81, 2, 20, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[91657, 2901, 187, 5, 23, "Input"],
Cell[91847, 2908, 81, 2, 20, "Output"]
}, Closed]],
Cell[91943, 2913, 99, 3, 18, "MathCaption"],

Cell[CellGroupData[{
Cell[92067, 2920, 124, 3, 27, "Input"],
Cell[92194, 2925, 10993, 289, 184, 3893, 196, "GraphicsData", "PostScript", \
"Graphics"]
}, Closed]],
Cell[103202, 3217, 77, 0, 18, "MathCaption"],

Cell[CellGroupData[{
Cell[103304, 3221, 92, 2, 27, "Input"],
Cell[103399, 3225, 84, 2, 20, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[103520, 3232, 162, 4, 23, "Input"],
Cell[103685, 3238, 72, 2, 20, "Output"]
}, Closed]]
}, Open  ]]
}
]
*)




(***********************************************************************
End of Mathematica Notebook file.
***********************************************************************)

