(***********************************************************************

                    Mathematica-Compatible Notebook

This notebook can be used on any computer system with Mathematica 4.0,
MathReader 4.0, or any compatible application. The data for the notebook 
starts with the line containing stars above.

To get the notebook into a Mathematica-compatible application, do one of 
the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing the 
word CacheID, otherwise Mathematica-compatible applications may try to 
use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
***********************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[     61584,       1611]*)
(*NotebookOutlinePosition[     63143,       1659]*)
(*  CellTagsIndexPosition[     62966,       1650]*)
(*WindowFrame->Normal*)



Notebook[{
Cell["This loads the package:", "MathCaption"],

Cell[BoxData[
    \(\(<< Genealogies`Genealogies`;\)\)], "Input",
  CellLabel->"In[37]:="],

Cell[CellGroupData[{

Cell["Inferring a rooted genealogy from a set of mutations", \
"SubsubsectionIcon"],

Cell[TextData[Cell[BoxData[
    FormBox[GridBox[{
          {\(MatrixToGenealogy[
              S, {leaf\_1, \ 
                leaf\_2, \[Ellipsis]}, {\[Mu]\_1, \[Ellipsis]}]\), \
\(constructs\ a\ genealogy\ from\ the\ matrix\ S . \ \ The\ leaves\ are\ \
labelled\ by\ {leaf\_1, \ \[Ellipsis]}\ and\ the\ mutations\ by\ {\[Mu]\_1, \
\[Ellipsis]}; \ internal\ nodes\ are\ labelled\ by\ unique\ integers\)}
          }], TraditionalForm]]]], "DefinitionBox",
  CellTags->"MatrixToGenealogy"],

Cell["\<\
The matrix of allelic states defines the genealogy, though that \
genealogy may contain multifurcations if there are no mutations on a branch.  \
\
\>", "Text"],

Cell["\<\
This genealogy does not contain any mutations that resolve the \
relation between {c,d,e}; therefore, a trifurcation is inferred:\
\>", \
"MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"g", "=", 
      RowBox[{"MatrixToGenealogy", "[", 
        RowBox[{
          RowBox[{"(", GridBox[{
                {"1", "1", "0", "0", "0", "0", "0", "1", "0", "0", "1"},
                {"1", "1", "0", "0", "0", "0", "0", "0", "0", "0", "1"},
                {"0", "0", "1", "1", "1", "1", "1", "0", "1", "0", "1"},
                {"0", "0", "1", "1", "1", "1", "1", "0", "0", "0", "1"},
                {"0", "0", "1", "1", "1", "1", "1", "0", "0", "1", "1"}
                }], ")"}], ",", \({a, b, c, d, e}\), ",", \(Range[11]\)}], 
        "]"}]}]], "Input",
  CellLabel->"In[16]:="],

Cell[BoxData[
    \(Node[
      1, {0, {11}}, {Node[
          2, {0, {11, 1, 2}}, {Node[a, {0, {1, 2, 8, 11}}, {}], 
            Node[b, {0, {1, 2, 11}}, {}]}], 
        Node[3, {0, {11, 3, 4, 5, 6, 7}}, {Node[
              c, {0, {3, 4, 5, 6, 7, 9, 11}}, {}], 
            Node[d, {0, {3, 4, 5, 6, 7, 11}}, {}], 
            Node[e, {0, {3, 4, 5, 6, 7, 10, 11}}, {}]}]}]\)], "Output",
  CellLabel->"Out[16]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(Show[PlotGenealogy[g]];\)\)], "Input",
  CellLabel->"In[17]:="],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.166667 0.166667 0.154508 0.154508 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
0 g
.5 Mabswid
[ ] 0 setdash
.5 .46353 m
.25 .30902 L
s
.5 .46353 m
.66667 .30902 L
s
.25 .30902 m
.16667 .15451 L
s
.25 .30902 m
.33333 .15451 L
s
.66667 .30902 m
.5 .15451 L
s
.66667 .30902 m
.66667 .15451 L
s
.66667 .30902 m
.83333 .15451 L
s
[(1)] .46667 .49443 0 0 Mshowa
[(2)] .21667 .33992 0 0 Mshowa
[(3)] .63333 .33992 0 0 Mshowa
gsave
.16667 .12361 -66 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(a) show
1.000 setlinewidth
grestore
gsave
.33333 .12361 -66 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(b) show
1.000 setlinewidth
grestore
gsave
.5 .12361 -66 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(c) show
1.000 setlinewidth
grestore
gsave
.66667 .12361 -66 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(d) show
1.000 setlinewidth
grestore
gsave
.83333 .12361 -66 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(e) show
1.000 setlinewidth
grestore
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[17]:=",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/B000`400?l00000o`00003oo`3ooolQ
0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ
0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ
0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ
0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ
0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ
0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ
0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00;P3oool4000002X0oooo1000000]0?ooo`<00000
;@3oool4000002/0oooo0`00000a0?ooo`00;@3oool010000000oooo0?ooo`00000/0?ooo`040000
003oool0oooo000002/0oooo00D000000?ooo`3oool0oooo0000000[0?ooo`040000003oool0oooo
000002/0oooo00<000000?ooo`3oool0<P3oool002h0oooo0`00000/0?ooo`040000003oool0oooo
000002/0oooo00<000000?ooo`3oool0;@3oool010000000oooo0?ooo`00000[0?ooo`D00000<03o
ool002d0oooo00@000000?ooo`3oool00000;03oool010000000oooo0?ooo`00000[0?ooo`050000
003oool0oooo0?ooo`000000:`3oool010000000oooo0?ooo`00000[0?ooo`050000003oool0oooo
0?ooo`000000<03oool002h0oooo0P00000]0?ooo`<00000;@3oool3000002d0oooo0`00000/0?oo
o`<00000<@3oool005d0oooo00<000000?ooo`3oool0G`3oool00`000000oooo0?ooo`1N0?ooo`00
G03oool200000600oooo0P00001P0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?oo
o`00o`3ooolQ0?ooo`00<03oool00`000000oooo0?ooo`0/0?ooo`030000003oool0oooo02d0oooo
0P00000^0?ooo`030000003oool0oooo02/0oooo0P00000a0?ooo`00<03oool00`000000oooo0?oo
o`0/0?ooo`030000003oool0oooo02l0oooo00<000000?ooo`3oool0:`3oool00`000000oooo0?oo
o`0Z0?ooo`030000003oool0oooo0340oooo000a0?ooo`030000003oool0oooo02X0oooo00<00000
0?ooo`3oool0<@3oool00`000000oooo0?ooo`0Z0?ooo`030000003oool0oooo02T0oooo00<00000
0?ooo`3oool0<P3oool00340oooo00<000000?ooo`3oool0:P3oool00`000000oooo0?ooo`0b0?oo
o`030000003oool0oooo02T0oooo00<000000?ooo`3oool0:03oool00`000000oooo0?ooo`0c0?oo
o`00<P3oool00`000000oooo0?ooo`0X0?ooo`030000003oool0oooo03@0oooo00<000000?ooo`3o
ool0:03oool00`000000oooo0?ooo`0W0?ooo`030000003oool0oooo03@0oooo000b0?ooo`030000
003oool0oooo02P0oooo00<000000?ooo`3oool0=@3oool00`000000oooo0?ooo`0W0?ooo`030000
003oool0oooo02H0oooo00<000000?ooo`3oool0=@3oool003<0oooo00<000000?ooo`3oool09P3o
ool00`000000oooo0?ooo`0g0?ooo`030000003oool0oooo02H0oooo00<000000?ooo`3oool09@3o
ool00`000000oooo0?ooo`0f0?ooo`00<`3oool00`000000oooo0?ooo`0U0?ooo`030000003oool0
oooo03T0oooo00<000000?ooo`3oool09@3oool00`000000oooo0?ooo`0T0?ooo`030000003oool0
oooo03L0oooo000d0?ooo`030000003oool0oooo02@0oooo00<000000?ooo`3oool0>P3oool00`00
0000oooo0?ooo`0T0?ooo`030000003oool0oooo02<0oooo00<000000?ooo`3oool0>03oool003@0
oooo00<000000?ooo`3oool08`3oool00`000000oooo0?ooo`0l0?ooo`030000003oool0oooo02<0
oooo00<000000?ooo`3oool08P3oool00`000000oooo0?ooo`0i0?ooo`00=@3oool00`000000oooo
0?ooo`0R0?ooo`030000003oool0oooo03d0oooo00<000000?ooo`3oool08P3oool00`000000oooo
0?ooo`0Q0?ooo`030000003oool0oooo03X0oooo000e0?ooo`030000003oool0oooo0240oooo00<0
00000?ooo`3oool0?`3oool200000280oooo00<000000?ooo`3oool0803oool00`000000oooo0?oo
o`0k0?ooo`00=P3oool00`000000oooo0?ooo`0P0?ooo`030000003oool0oooo0440oooo00<00000
0?ooo`3oool07`3oool00`000000oooo0?ooo`0O0?ooo`030000003oool0oooo03`0oooo000g0?oo
o`030000003oool0oooo01h0oooo00<000000?ooo`3oool0@`3oool00`000000oooo0?ooo`0N0?oo
o`030000003oool0oooo01h0oooo00<000000?ooo`3oool0?@3oool003L0oooo00<000000?ooo`3o
ool07P3oool00`000000oooo0?ooo`140?ooo`030000003oool0oooo01d0oooo00<000000?ooo`3o
ool07@3oool00`000000oooo0?ooo`0n0?ooo`00>03oool00`000000oooo0?ooo`0L0?ooo`030000
003oool0oooo04H0oooo00<000000?ooo`3oool0703oool00`000000oooo0?ooo`0K0?ooo`800000
@@3oool003P0oooo00<000000?ooo`3oool0703oool00`000000oooo0?ooo`170?ooo`030000003o
ool0oooo01/0oooo00<000000?ooo`3oool06P3oool00`000000oooo0?ooo`110?ooo`00>@3oool0
0`000000oooo0?ooo`0J0?ooo`030000003oool0oooo04T0oooo00<000000?ooo`3oool06P3oool0
0`000000oooo0?ooo`0I0?ooo`030000003oool0oooo0480oooo000i0?ooo`030000003oool0oooo
01T0oooo00<000000?ooo`3oool0B`3oool00`000000oooo0?ooo`0I0?ooo`030000003oool0oooo
01P0oooo00<000000?ooo`3oool0@`3oool003X0oooo00<000000?ooo`3oool0603oool00`000000
oooo0?ooo`1<0?ooo`030000003oool0oooo01P0oooo00<000000?ooo`3oool05`3oool00`000000
oooo0?ooo`140?ooo`00>P3oool00`000000oooo0?ooo`0G0?ooo`030000003oool0oooo04h0oooo
00<000000?ooo`3oool05`3oool00`000000oooo0?ooo`0F0?ooo`030000003oool0oooo04D0oooo
000k0?ooo`030000003oool0oooo01H0oooo00<000000?ooo`3oool0C`3oool00`000000oooo0?oo
o`0F0?ooo`030000003oool0oooo01D0oooo00<000000?ooo`3oool0AP3oool003/0oooo00<00000
0?ooo`3oool05@3oool00`000000oooo0?ooo`1A0?ooo`8000005P3oool00`000000oooo0?ooo`0D
0?ooo`030000003oool0oooo04L0oooo000l0?ooo`030000003oool0oooo01@0oooo00<000000?oo
o`3oool0D`3oool00`000000oooo0?ooo`0C0?ooo`030000003oool0oooo01<0oooo00<000000?oo
o`3oool0B03oool003`0oooo00<000000?ooo`3oool04`3oool00`000000oooo0?ooo`1E0?ooo`03
0000003oool0oooo0180oooo00<000000?ooo`3oool04P3oool00`000000oooo0?ooo`190?ooo`00
?@3oool00`000000oooo0?ooo`0B0?ooo`030000003oool0oooo05H0oooo00<000000?ooo`3oool0
4@3oool00`000000oooo0?ooo`0A0?ooo`030000003oool0oooo04X0oooo000m0?ooo`030000003o
ool0oooo0140oooo00<000000?ooo`3oool0F03oool00`000000oooo0?ooo`0@0?ooo`030000003o
ool0oooo0100oooo00<000000?ooo`3oool0B`3oool003h0oooo00<000000?ooo`3oool0403oool0
0`000000oooo0?ooo`1I0?ooo`030000003oool0oooo00l0oooo00<000000?ooo`3oool03`3oool0
0`000000oooo0?ooo`1<0?ooo`00?P3oool00`000000oooo0?ooo`0?0?ooo`030000003oool0oooo
05/0oooo00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo
04d0oooo000o0?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool0G@3oool00`000000
oooo0?ooo`0=0?ooo`030000003oool0oooo00`0oooo0P00001@0?ooo`00?`3oool00`000000oooo
0?ooo`0=0?ooo`030000003oool0oooo05h0oooo00<000000?ooo`3oool0303oool00`000000oooo
0?ooo`0;0?ooo`030000003oool0oooo0500oooo00100?ooo`030000003oool0oooo00/0oooo00<0
00000?ooo`3oool0H03oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo00X0oooo00<0
00000?ooo`3oool0D@3oool00400oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`1Q
0?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`1B
0?ooo`00@@3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo06<0oooo0P00000:0?oo
o`030000003oool0oooo00P0oooo00<000000?ooo`3oool0D`3oool00480oooo00<000000?ooo`3o
ool0203oool00`000000oooo0?ooo`1U0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3o
ool01`3oool00`000000oooo0?ooo`1D0?ooo`00@P3oool00`000000oooo0?ooo`070?ooo`030000
003oool0oooo06L0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`060?ooo`030000
003oool0oooo05D0oooo00130?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool0J03o
ool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool0EP3o
ool004<0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`1Z0?ooo`030000003oool0
oooo00@0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`1G0?ooo`00A03oool00`00
0000oooo0?ooo`040?ooo`030000003oool0oooo06/0oooo00<000000?ooo`3oool00`3oool00`00
0000oooo0?ooo`030?ooo`030000003oool0oooo05P0oooo00140?ooo`030000003oool0oooo00<0
oooo00<000000?ooo`3oool0K@3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0080
oooo00<000000?ooo`3oool0F@3oool004D0oooo00D000000?ooo`3oool0oooo0000001a0?ooo`05
0000003oool0oooo0?ooo`0000000`3oool00`000000oooo0?ooo`1J0?ooo`00A@3oool01@000000
oooo0?ooo`3oool000000780oooo00@000000?ooo`3oool000000P3oool00`000000oooo0?ooo`1K
0?ooo`00AP3oool00`000000oooo0000001d0?ooo`050000003oool000000?ooo`000000GP3oool0
04H0oooo00<000000?ooo`000000M@3oool3000005l0oooo00170?ooo`800000M@3oool200000600
oooo00190?ooo`030000003oool0oooo0740oooo00<000000?ooo`3oool0H03oool004X0oooo0P00
001`0?ooo`030000003oool0oooo0640oooo001<0?ooo`800000K@3oool00`000000oooo0?ooo`1R
0?ooo`00CP3oool00`000000oooo0?ooo`1Y0?ooo`030000003oool0oooo06<0oooo001?0?ooo`80
0000J03oool00`000000oooo0?ooo`1T0?ooo`00>`3oool500000140oooo0P00001P0?ooo`<00000
0P3oool00`000000oooo0?ooo`1U0?ooo`00?03oool010000000oooo0?ooo`00000C0?ooo`030000
003oool0oooo05`0oooo00@000000?ooo`3oool0oooo0P00001X0?ooo`00?@3oool00`000000oooo
0?ooo`0D0?ooo`800000H03oool00`000000oooo0?ooo`1W0?ooo`00?P3oool00`000000oooo0?oo
o`0E0?ooo`800000G03oool2000006X0oooo000k0?ooo`050000003oool0oooo0?ooo`000000603o
ool00`000000oooo0?ooo`1I0?ooo`030000003oool0000006T0oooo000k0?ooo`050000003oool0
oooo0?ooo`0000006@3oool2000005L0oooo0P0000020?ooo`030000003oool0oooo06L0oooo000l
0?ooo`<00000703oool00`000000oooo0?ooo`1C0?ooo`030000003oool0000000800000JP3oool0
05`0oooo0P00001B0?ooo`030000003oool0oooo06d0oooo001N0?ooo`800000C`3oool00`000000
oooo0?ooo`1^0?ooo`00H03oool00`000000oooo0?ooo`1;0?ooo`030000003oool0oooo06l0oooo
001Q0?ooo`800000BP3oool00`000000oooo0?ooo`1`0?ooo`00H`3oool2000004L0oooo00<00000
0?ooo`3oool0L@3oool006D0oooo00<000000?ooo`3oool0@`3oool00`000000oooo0?ooo`1b0?oo
o`00IP3oool200000480oooo00<000000?ooo`3oool0L`3oool006P0oooo0P00000o0?ooo`030000
003oool0oooo07@0oooo001Z0?ooo`030000003oool0oooo03/0oooo00<000000?ooo`3oool0M@3o
ool006/0oooo0P00000i0?ooo`800000N03oool006d0oooo00<000000?ooo`3oool0=@3oool00`00
0000oooo0?ooo`1h0?ooo`00KP3oool2000003@0oooo00<000000?ooo`3oool0N@3oool00700oooo
0P00000a0?ooo`030000003oool0oooo07X0oooo001b0?ooo`030000003oool0oooo02d0oooo00<0
00000?ooo`3oool0N`3oool007<0oooo0P00000/0?ooo`030000003oool0oooo07`0oooo001e0?oo
o`800000:@3oool00`000000oooo0?ooo`1m0?ooo`00M`3oool00`000000oooo0?ooo`0U0?ooo`03
0000003oool0oooo07h0oooo001h0?ooo`800000903oool00`000000oooo0?ooo`1o0?ooo`00NP3o
ool200000240oooo00<000000?ooo`3oool0P03oool007`0oooo00<000000?ooo`3oool07@3oool0
0`000000oooo0?ooo`210?ooo`00O@3oool2000001/0oooo0P0000240?ooo`00O`3oool00`000000
oooo0?ooo`0G0?ooo`030000003oool0oooo08@0oooo00200?ooo`8000005P3oool00`000000oooo
0?ooo`250?ooo`00PP3oool2000001<0oooo00<000000?ooo`3oool0QP3oool008@0oooo00<00000
0?ooo`3oool03`3oool00`000000oooo0?ooo`270?ooo`00Q@3oool2000000h0oooo00<000000?oo
o`3oool0R03oool008L0oooo0P00000;0?ooo`030000003oool0oooo08T0oooo00290?ooo`030000
003oool0oooo00L0oooo00<000000?ooo`3oool0RP3oool008X0oooo0P0000060?ooo`030000003o
ool0oooo08/0oooo002<0?ooo`8000000`3oool00`000000oooo0?ooo`2<0?ooo`00SP3oool00`00
0000oooo0000002?0?ooo`00S`3oool00`000000oooo0?ooo`2>0?ooo`00o`3ooolQ0?ooo`00o`3o
oolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00P`3o
ool3000009X0oooo00240?ooo`030000003oool0oooo09T0oooo00240?ooo`030000003oool0oooo
09T0oooo00240?ooo`030000003oool0oooo09T0oooo00240?ooo`030000003oool0oooo09T0oooo
00230?ooo`800000V`3oool008@0oooo00<000000?ooo`3oool0V@3oool00?l0oooo8@3oool00?l0
oooo8@3oool00?l0oooo8@3oool00?l0oooo8@3oool00?l0oooo8@3oool00?l0oooo8@3oool00?l0
oooo8@3oool00?l0oooo8@3oool00?l0oooo8@3oool00?l0oooo8@3oool00?l0oooo8@3oool00?l0
oooo8@3oool00?l0oooo8@3oool00?l0oooo8@3oool00?l0oooo8@3oool00?l0oooo8@3oool00?l0
oooo8@3oool00?l0oooo8@3oool00?l0oooo8@3oool00?l0oooo8@3oool00?l0oooo8@3oool00?l0
oooo8@3oool00?l0oooo8@3oool00?l0oooo8@3oool00?l0oooo8@3oool00?l0oooo8@3oool00?l0
oooo8@3oool00?l0oooo8@3oool00?l0oooo8@3oool00?l0oooo8@3oool00?l0oooo8@3oool00001
\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-1.00744, -1.00002, \
0.0209577, 0.022607}}]
}, Open  ]],

Cell["A mutation found only in leaves d, e resolves the genealogy:", \
"MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"g", "=", 
      RowBox[{"MatrixToGenealogy", "[", 
        RowBox[{
          TagBox[
            RowBox[{"(", GridBox[{
                  {"1", "1", "0", "0", "0", "0", "0", "1", "0", "0", "1", 
                    "0"},
                  {"1", "1", "0", "0", "0", "0", "0", "0", "0", "0", "1", 
                    "0"},
                  {"0", "0", "1", "1", "1", "1", "1", "0", "1", "0", "1", 
                    "0"},
                  {"0", "0", "1", "1", "1", "1", "1", "0", "0", "0", "1", 
                    "1"},
                  {"0", "0", "1", "1", "1", "1", "1", "0", "0", "1", "1", 
                    "1"}
                  }], ")"}],
            (MatrixForm[ #]&)], ",", \({a, b, c, d, e}\), 
          ",", \(Range[12]\)}], "]"}]}]], "Input",
  CellLabel->"In[18]:="],

Cell[BoxData[
    \(Node[
      1, {0, {11}}, {Node[
          2, {0, {11, 1, 2}}, {Node[a, {0, {1, 2, 8, 11}}, {}], 
            Node[b, {0, {1, 2, 11}}, {}]}], 
        Node[3, {0, {11, 3, 4, 5, 6, 7}}, {Node[
              c, {0, {3, 4, 5, 6, 7, 9, 11}}, {}], 
            Node[4, {0, {3, 4, 5, 6, 7, 11, 12}}, {Node[
                  d, {0, {3, 4, 5, 6, 7, 11, 12}}, {}], 
                Node[e, {0, {3, 4, 5, 6, 7, 10, 11, 
                      12}}, {}]}]}]}]\)], "Output",
  CellLabel->"Out[18]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(Show[PlotGenealogy[g]];\)\)], "Input",
  CellLabel->"In[19]:="],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.166667 0.166667 0.123607 0.123607 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
0 g
.5 Mabswid
[ ] 0 setdash
.5 .49443 m
.25 .24721 L
s
.5 .49443 m
.66667 .37082 L
s
.25 .24721 m
.16667 .12361 L
s
.25 .24721 m
.33333 .12361 L
s
.66667 .37082 m
.5 .12361 L
s
.66667 .37082 m
.75 .24721 L
s
.75 .24721 m
.66667 .12361 L
s
.75 .24721 m
.83333 .12361 L
s
[(1)] .46667 .51915 0 0 Mshowa
[(2)] .21667 .27193 0 0 Mshowa
[(3)] .63333 .39554 0 0 Mshowa
[(4)] .71667 .27193 0 0 Mshowa
gsave
.16667 .09889 -66 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(a) show
1.000 setlinewidth
grestore
gsave
.33333 .09889 -66 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(b) show
1.000 setlinewidth
grestore
gsave
.5 .09889 -66 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(c) show
1.000 setlinewidth
grestore
gsave
.66667 .09889 -66 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(d) show
1.000 setlinewidth
grestore
gsave
.83333 .09889 -66 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(e) show
1.000 setlinewidth
grestore
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[19]:=",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/B000`400?l00000o`00003oo`3ooolQ
0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ
0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ
0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ
0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ
0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ
0?ooo`00;P3oool4000002X0oooo1000000]0?ooo`<00000;@3oool4000002/0oooo0`00000a0?oo
o`00;@3oool010000000oooo0?ooo`00000/0?ooo`040000003oool0oooo000002/0oooo00D00000
0?ooo`3oool0oooo0000000[0?ooo`040000003oool0oooo000002/0oooo00<000000?ooo`3oool0
<P3oool002h0oooo0`00000/0?ooo`040000003oool0oooo000002/0oooo00<000000?ooo`3oool0
;@3oool010000000oooo0?ooo`00000[0?ooo`D00000<03oool002d0oooo00@000000?ooo`3oool0
0000;03oool010000000oooo0?ooo`00000[0?ooo`050000003oool0oooo0?ooo`000000:`3oool0
10000000oooo0?ooo`00000[0?ooo`050000003oool0oooo0?ooo`000000<03oool002h0oooo0P00
000]0?ooo`<00000;@3oool3000002d0oooo0`00000/0?ooo`<00000<@3oool005d0oooo00<00000
0?ooo`3oool0G`3oool00`000000oooo0?ooo`1N0?ooo`00G03oool200000600oooo0P00001P0?oo
o`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00<03oool00`000000oooo0?ooo`0/0?ooo`030000003o
ool0oooo02d0oooo00<000000?ooo`3oool0;@3oool00`000000oooo0?ooo`0/0?ooo`030000003o
ool0oooo02l0oooo000`0?ooo`030000003oool0oooo02`0oooo00<000000?ooo`3oool0;@3oool0
0`000000oooo0?ooo`0]0?ooo`030000003oool0oooo02`0oooo00<000000?ooo`3oool0;`3oool0
0340oooo00<000000?ooo`3oool0:P3oool00`000000oooo0?ooo`0_0?ooo`030000003oool0oooo
02d0oooo00<000000?ooo`3oool0:P3oool00`000000oooo0?ooo`0`0?ooo`00<P3oool00`000000
oooo0?ooo`0X0?ooo`030000003oool0oooo0340oooo00<000000?ooo`3oool0;@3oool00`000000
oooo0?ooo`0X0?ooo`030000003oool0oooo0340oooo000b0?ooo`030000003oool0oooo02P0oooo
00<000000?ooo`3oool0<@3oool00`000000oooo0?ooo`0]0?ooo`030000003oool0oooo02P0oooo
00<000000?ooo`3oool0<@3oool003<0oooo00<000000?ooo`3oool09P3oool00`000000oooo0?oo
o`0c0?ooo`030000003oool0oooo02d0oooo00<000000?ooo`3oool09P3oool00`000000oooo0?oo
o`0b0?ooo`00=03oool00`000000oooo0?ooo`0T0?ooo`030000003oool0oooo03D0oooo00<00000
0?ooo`3oool0;@3oool00`000000oooo0?ooo`0T0?ooo`030000003oool0oooo03<0oooo000d0?oo
o`030000003oool0oooo02@0oooo00<000000?ooo`3oool0=@3oool00`000000oooo0?ooo`0]0?oo
o`030000003oool0oooo02@0oooo00<000000?ooo`3oool0<`3oool003D0oooo00<000000?ooo`3o
ool08P3oool00`000000oooo0?ooo`0g0?ooo`030000003oool0oooo02d0oooo00<000000?ooo`3o
ool08P3oool00`000000oooo0?ooo`0d0?ooo`00=P3oool00`000000oooo0?ooo`0P0?ooo`030000
003oool0oooo03T0oooo00<000000?ooo`3oool0;@3oool00`000000oooo0?ooo`0P0?ooo`030000
003oool0oooo03D0oooo000f0?ooo`030000003oool0oooo01l0oooo00<000000?ooo`3oool0>P3o
ool00`000000oooo0?ooo`0^0?ooo`030000003oool0oooo01l0oooo00<000000?ooo`3oool0=@3o
ool003L0oooo00<000000?ooo`3oool07P3oool00`000000oooo0?ooo`0k0?ooo`030000003oool0
oooo02d0oooo00<000000?ooo`3oool07P3oool00`000000oooo0?ooo`0f0?ooo`00>03oool00`00
0000oooo0?ooo`0L0?ooo`030000003oool0oooo03d0oooo00<000000?ooo`3oool0;@3oool00`00
0000oooo0?ooo`0L0?ooo`030000003oool0oooo03L0oooo000h0?ooo`030000003oool0oooo01/0
oooo00<000000?ooo`3oool0?P3oool00`000000oooo0?ooo`0^0?ooo`030000003oool0oooo01/0
oooo00<000000?ooo`3oool0=`3oool003T0oooo00<000000?ooo`3oool06P3oool00`000000oooo
0?ooo`0o0?ooo`030000003oool0oooo02d0oooo00<000000?ooo`3oool06P3oool00`000000oooo
0?ooo`0h0?ooo`00>P3oool00`000000oooo0?ooo`0H0?ooo`030000003oool0oooo0440oooo00<0
00000?ooo`3oool0;@3oool00`000000oooo0?ooo`0H0?ooo`030000003oool0oooo03T0oooo000j
0?ooo`030000003oool0oooo01L0oooo00<000000?ooo`3oool0@P3oool00`000000oooo0?ooo`0^
0?ooo`030000003oool0oooo01L0oooo00<000000?ooo`3oool0>@3oool003/0oooo00<000000?oo
o`3oool05P3oool00`000000oooo0?ooo`130?ooo`030000003oool0oooo02d0oooo00<000000?oo
o`3oool05P3oool00`000000oooo0?ooo`0j0?ooo`00?03oool00`000000oooo0?ooo`0D0?ooo`03
0000003oool0oooo04D0oooo00<000000?ooo`3oool0;@3oool00`000000oooo0?ooo`0D0?ooo`03
0000003oool0oooo03/0oooo000l0?ooo`030000003oool0oooo01<0oooo00<000000?ooo`3oool0
A`3oool00`000000oooo0?ooo`0]0?ooo`030000003oool0oooo01<0oooo00<000000?ooo`3oool0
>`3oool003d0oooo00<000000?ooo`3oool04P3oool00`000000oooo0?ooo`170?ooo`030000003o
ool0oooo02d0oooo00<000000?ooo`3oool04P3oool00`000000oooo0?ooo`0l0?ooo`00?@3oool0
0`000000oooo0?ooo`0A0?ooo`030000003oool0oooo04T0oooo00<000000?ooo`3oool0;@3oool0
0`000000oooo0?ooo`0A0?ooo`030000003oool0oooo03`0oooo000n0?ooo`030000003oool0oooo
00l0oooo00<000000?ooo`3oool0B`3oool00`000000oooo0?ooo`0]0?ooo`030000003oool0oooo
00l0oooo00<000000?ooo`3oool0?@3oool003l0oooo00<000000?ooo`3oool03P3oool00`000000
oooo0?ooo`1;0?ooo`030000003oool0oooo02d0oooo00<000000?ooo`3oool03P3oool00`000000
oooo0?ooo`0n0?ooo`00?`3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo04d0oooo
00<000000?ooo`3oool0;@3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo03h0oooo
00100?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool0C`3oool00`000000oooo0?oo
o`0]0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool0?`3oool00440oooo00<00000
0?ooo`3oool02P3oool00`000000oooo0?ooo`1?0?ooo`030000003oool0oooo02d0oooo00<00000
0?ooo`3oool02P3oool00`000000oooo0?ooo`100?ooo`00@@3oool00`000000oooo0?ooo`090?oo
o`030000003oool0oooo0540oooo00<000000?ooo`3oool0;@3oool00`000000oooo0?ooo`090?oo
o`030000003oool0oooo0400oooo00120?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3o
ool0D`3oool00`000000oooo0?ooo`0]0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3o
ool0@@3oool004<0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`1D0?ooo`030000
003oool0oooo02h0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`120?ooo`00@`3o
ool00`000000oooo0?ooo`050?ooo`030000003oool0oooo05D0oooo00<000000?ooo`3oool0;@3o
ool00`000000oooo0?ooo`050?ooo`030000003oool0oooo0480oooo00140?ooo`030000003oool0
oooo00<0oooo00<000000?ooo`3oool0E`3oool00`000000oooo0?ooo`0]0?ooo`030000003oool0
oooo00<0oooo00<000000?ooo`3oool0@`3oool004D0oooo00D000000?ooo`3oool0oooo0000001J
0?ooo`030000003oool0oooo02h0oooo00D000000?ooo`3oool0oooo000000160?ooo`00A@3oool0
1@000000oooo0?ooo`3oool0000005/0oooo00<000000?ooo`3oool0;@3oool01@000000oooo0?oo
o`3oool0000004H0oooo00160?ooo`030000003oool0000005d0oooo00<000000?ooo`3oool0;@3o
ool00`000000oooo000000170?ooo`00A`3oool2000005d0oooo00<000000?ooo`3oool0;P3oool0
0`000000oooo0?ooo`160?ooo`00B@3oool00`000000oooo0?ooo`1K0?ooo`030000003oool0oooo
02d0oooo00<000000?ooo`3oool0AP3oool004X0oooo00<000000?ooo`3oool0F`3oool00`000000
oooo0?ooo`0[0?ooo`030000003oool0oooo04L0oooo001;0?ooo`030000003oool0oooo05X0oooo
00<000000?ooo`3oool0:P3oool00`000000oooo0?ooo`180?ooo`00C03oool00`000000oooo0?oo
o`1J0?ooo`030000003oool0oooo02T0oooo00<000000?ooo`3oool0B03oool003/0oooo1@00000=
0?ooo`030000003oool0oooo05X0oooo00<000000?ooo`3oool07`3oool3000000D0oooo00<00000
0?ooo`3oool0B@3oool003`0oooo00@000000?ooo`3oool000003P3oool00`000000oooo0?ooo`1I
0?ooo`030000003oool0oooo0200oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`1:
0?ooo`00?@3oool00`000000oooo0?ooo`0?0?ooo`030000003oool0oooo05T0oooo00<000000?oo
o`3oool0703oool5000000@0oooo00<000000?ooo`3oool0BP3oool003h0oooo00<000000?ooo`3o
ool03`3oool00`000000oooo0?ooo`1I0?ooo`030000003oool0oooo01/0oooo00@000000?ooo`3o
ool00000103oool00`000000oooo0?ooo`1;0?ooo`00>`3oool01@000000oooo0?ooo`3oool00000
0140oooo00<000000?ooo`3oool0F03oool00`000000oooo0?ooo`0L0?ooo`030000003oool00000
00<0oooo00<000000?ooo`3oool0C03oool003/0oooo00D000000?ooo`3oool0oooo0000000B0?oo
o`030000003oool0oooo05P0oooo00<000000?ooo`3oool0703oool2000000<0oooo00<000000?oo
o`3oool0C03oool003`0oooo0`00000D0?ooo`030000003oool0oooo05P0oooo00<000000?ooo`3o
ool0703oool010000000oooo0?ooo`00001?0?ooo`00E03oool00`000000oooo0?ooo`1G0?ooo`03
0000003oool0oooo01h0oooo00<000000?ooo`3oool0CP3oool005D0oooo00<000000?ooo`3oool0
E`3oool00`000000oooo0?ooo`0M0?ooo`030000003oool0oooo04h0oooo001F0?ooo`030000003o
ool0oooo05L0oooo00<000000?ooo`3oool06`3oool00`000000oooo0?ooo`1?0?ooo`00E`3oool0
0`000000oooo0?ooo`1F0?ooo`030000003oool0oooo01X0oooo00<000000?ooo`3oool0D03oool0
05P0oooo00<000000?ooo`3oool0EP3oool00`000000oooo0?ooo`0I0?ooo`030000003oool0oooo
0500oooo001I0?ooo`030000003oool0oooo05H0oooo00<000000?ooo`3oool05`3oool00`000000
oooo0?ooo`1A0?ooo`00FP3oool00`000000oooo0?ooo`1E0?ooo`030000003oool0oooo01H0oooo
00<000000?ooo`3oool0DP3oool005/0oooo00<000000?ooo`3oool0E@3oool00`000000oooo0?oo
o`0E0?ooo`030000003oool0oooo0580oooo001L0?ooo`030000003oool0oooo05D0oooo00<00000
0?ooo`3oool04`3oool00`000000oooo0?ooo`1C0?ooo`00G@3oool00`000000oooo0?ooo`1E0?oo
o`030000003oool0oooo0140oooo00<000000?ooo`3oool0E03oool005h0oooo00<000000?ooo`3o
ool0E03oool00`000000oooo0?ooo`0A0?ooo`030000003oool0oooo05@0oooo001O0?ooo`030000
003oool0oooo05@0oooo00<000000?ooo`3oool03`3oool00`000000oooo0?ooo`1E0?ooo`00H03o
ool00`000000oooo0?ooo`1D0?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool0EP3o
ool00640oooo00<000000?ooo`3oool0D`3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0
oooo05H0oooo001R0?ooo`030000003oool0oooo05<0oooo00<000000?ooo`3oool02`3oool00`00
0000oooo0?ooo`1G0?ooo`00H`3oool00`000000oooo0?ooo`1C0?ooo`030000003oool0oooo00T0
oooo00<000000?ooo`3oool0F03oool006@0oooo00<000000?ooo`3oool0DP3oool00`000000oooo
0?ooo`090?ooo`030000003oool0oooo05P0oooo001U0?ooo`030000003oool0oooo0580oooo00<0
00000?ooo`3oool01`3oool00`000000oooo0?ooo`1I0?ooo`00IP3oool00`000000oooo0?ooo`1B
0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool0FP3oool006L0oooo00<000000?oo
o`3oool0D@3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo05X0oooo001X0?ooo`03
0000003oool0oooo0540oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`1K0?ooo`00
J@3oool00`000000oooo0?ooo`1A0?ooo`050000003oool0oooo0?ooo`000000GP3oool006X0oooo
00<000000?ooo`3oool0D03oool01@000000oooo0?ooo`3oool0000005h0oooo001[0?ooo`030000
003oool0oooo0500oooo00<000000?ooo`000000G`3oool006`0oooo00<000000?ooo`3oool0C`3o
ool200000600oooo001]0?ooo`030000003oool0oooo04d0oooo00<000000?ooo`3oool0H03oool0
06h0oooo00<000000?ooo`3oool0B`3oool00`000000oooo0?ooo`1Q0?ooo`00K`3oool00`000000
oooo0?ooo`180?ooo`800000I03oool00700oooo00<000000?ooo`3oool0@03oool3000000<0oooo
00<000000?ooo`3oool0I03oool00740oooo00<000000?ooo`3oool0?P3oool010000000oooo0?oo
o`3oool3000006L0oooo001b0?ooo`030000003oool0oooo0440oooo00<000000?ooo`3oool0I`3o
ool007<0oooo00<000000?ooo`3oool0?P3oool2000006X0oooo001d0?ooo`030000003oool0oooo
03`0oooo0P0000000`3oool000000?ooo`1X0?ooo`00M@3oool00`000000oooo0?ooo`0j0?ooo`05
0000003oool0oooo0?ooo`000000J@3oool007H0oooo00<000000?ooo`3oool0>03oool00`000000
oooo00000002000006X0oooo001g0?ooo`030000003oool0oooo03D0oooo0P00001_0?ooo`00N03o
ool00`000000oooo0?ooo`0c0?ooo`030000003oool0oooo06l0oooo001i0?ooo`030000003oool0
oooo0300oooo0P00001b0?ooo`00NP3oool00`000000oooo0?ooo`0^0?ooo`030000003oool0oooo
0780oooo001k0?ooo`030000003oool0oooo02`0oooo00<000000?ooo`3oool0L`3oool007`0oooo
00<000000?ooo`3oool0:@3oool2000007H0oooo001m0?ooo`030000003oool0oooo02L0oooo00<0
00000?ooo`3oool0MP3oool007h0oooo00<000000?ooo`3oool09@3oool00`000000oooo0?ooo`1g
0?ooo`00O`3oool00`000000oooo0?ooo`0R0?ooo`800000NP3oool00800oooo00<000000?ooo`3o
ool0803oool00`000000oooo0?ooo`1j0?ooo`00P@3oool00`000000oooo0?ooo`0N0?ooo`030000
003oool0oooo07/0oooo00220?ooo`030000003oool0oooo01/0oooo0P00001n0?ooo`00P`3oool0
0`000000oooo0?ooo`0I0?ooo`030000003oool0oooo07h0oooo00240?ooo`030000003oool0oooo
01H0oooo0P0000210?ooo`00Q@3oool00`000000oooo0?ooo`0D0?ooo`030000003oool0oooo0840
oooo00260?ooo`030000003oool0oooo0180oooo00<000000?ooo`3oool0PP3oool008L0oooo00<0
00000?ooo`3oool03`3oool2000008D0oooo00280?ooo`030000003oool0oooo00d0oooo00<00000
0?ooo`3oool0Q@3oool008T0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`260?oo
o`00RP3oool00`000000oooo0?ooo`080?ooo`800000R@3oool008/0oooo00<000000?ooo`3oool0
1P3oool00`000000oooo0?ooo`290?ooo`00S03oool00`000000oooo0?ooo`030?ooo`800000S03o
ool008d0oooo00D000000?ooo`3oool0oooo0000002>0?ooo`00SP3oool00`000000oooo0000002?
0?ooo`00S`3oool00`000000oooo0?ooo`2>0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3o
oolQ0?ooo`00o`3ooolQ0?ooo`00P`3oool3000009X0oooo00240?ooo`030000003oool0oooo09T0
oooo00240?ooo`030000003oool0oooo09T0oooo00240?ooo`030000003oool0oooo09T0oooo0024
0?ooo`030000003oool0oooo09T0oooo00230?ooo`800000V`3oool008@0oooo00<000000?ooo`3o
ool0V@3oool00?l0oooo8@3oool00?l0oooo8@3oool00?l0oooo8@3oool00?l0oooo8@3oool00?l0
oooo8@3oool00?l0oooo8@3oool00?l0oooo8@3oool00?l0oooo8@3oool00?l0oooo8@3oool00?l0
oooo8@3oool00?l0oooo8@3oool00?l0oooo8@3oool00?l0oooo8@3oool00?l0oooo8@3oool00?l0
oooo8@3oool00?l0oooo8@3oool00?l0oooo8@3oool00?l0oooo8@3oool00?l0oooo8@3oool00?l0
oooo8@3oool00?l0oooo8@3oool00?l0oooo8@3oool00?l0oooo8@3oool00?l0oooo8@3oool00001
\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-1.00744, -1.00003, \
0.0209577, 0.0282586}}]
}, Open  ]],

Cell["\<\
If MatrixToGenealogy[] is given an impossible configuration of \
mutations, an error message is generated, and $Failed is returned.\
\>", \
"Text"],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"g", "=", 
      RowBox[{"MatrixToGenealogy", "[", 
        RowBox[{
          RowBox[{"(", GridBox[{
                {"1", "0", "0"},
                {"1", "0", "1"},
                {"0", "1", "1"},
                {"0", "1", "0"},
                {"0", "1", "0"}
                }], ")"}], ",", \({a, b, c, d, e}\), ",", \(Range[12]\)}], 
        "]"}]}]], "Input",
  CellLabel->"In[20]:="],

Cell[BoxData[
    \(MatrixToGenealogy::"invalidMatrix" \(\(:\)\(\ \)\) 
      "The matrix \!\({\(\({1, 0, 0}\)\), \(\({1, 0, 1}\)\), \(\({0, 1, \
1}\)\), \(\({0, 1, 0}\)\), \(\({0, 1, 0}\)\)}\) is not consistent with any \
genealogy"\)], "Message",
  CellLabel->"From In[20]:="],

Cell[BoxData[
    \($Failed\)], "Output",
  CellLabel->"Out[20]="]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Inferring an unrooted genealogy from a set of alleles", \
"SubsubsectionIcon"],

Cell[TextData[Cell[BoxData[
    FormBox[GridBox[{
          {\(MatrixToGenealogy[
              S, {leaf\_1, \ leaf\_2, \[Ellipsis]}, {\[Mu]\_1, \[Ellipsis]}, 
              Unrooted \[Rule] 
                True]\), \(constructs\ an\ unrooted\ genealogy\ from\ the\ \
matrix\ \(\(S\)\(.\)\(\ \ \)\)\)}
          }], TraditionalForm]]]], "DefinitionBox",
  CellTags->{"MatrixToGenealogy", "Unrooted"}],

Cell["\<\
Often, we do not know which allele is ancestral, and which is \
derived.  The matrix S then represents a set of allelic states, rather than \
presence or absence of a mutation.  It then defines a unique unrooted \
genealogy.   The root of the genealogy can be at any position, and a choice \
of root implies a choice as to which allele is ancestral, and which is \
derived.\
\>", "Text"],

Cell["\<\
This matrix leads to the same topology as in the example above, but \
no assumption is made about the position of the root.  The list shows the \
connections from each leaf or internal node:\
\>", "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"ug", "=", 
        RowBox[{"MatrixToGenealogy", "[", 
          RowBox[{
            TagBox[
              RowBox[{"(", GridBox[{
                    {"1", "1", "0", "0", "0", "0", "0", "1", "0", "0", "1", 
                      "0"},
                    {"1", "1", "0", "0", "0", "0", "0", "0", "0", "0", "1", 
                      "0"},
                    {"0", "0", "1", "1", "1", "1", "1", "0", "1", "0", "1", 
                      "0"},
                    {"0", "0", "1", "1", "1", "1", "1", "0", "0", "0", "1", 
                      "1"},
                    {"0", "0", "1", "1", "1", "1", "1", "0", "0", "1", "1", 
                      "1"}
                    }], ")"}],
              (MatrixForm[ #]&)], ",", \({a, b, c, d, e}\), 
            ",", \(Range[12]\), ",", \(Unrooted \[Rule] True\)}], "]"}]}], 
      ";", \(ug // TableForm\)}]], "Input",
  CellLabel->"In[38]:="],

Cell[BoxData[
    InterpretationBox[GridBox[{
          {\(Node[a, {0, {1, 2, 8, 11}}, {1}]\)},
          {\(Node[b, {0, {1, 2, 11}}, {1}]\)},
          {\(Node[c, {0, {3, 4, 5, 6, 7, 9, 11}}, {3}]\)},
          {\(Node[d, {0, {3, 4, 5, 6, 7, 11, 12}}, {2}]\)},
          {\(Node[e, {0, {3, 4, 5, 6, 7, 10, 11, 12}}, {2}]\)},
          {\(Node[1, {0, {1, 2, 11}}, {a, b, 3}]\)},
          {\(Node[2, {0, {3, 4, 5, 6, 7, 11, 12}}, {d, e, 3}]\)},
          {\(Node[3, {0, {3, 4, 5, 6, 7, 11}}, {1, c, 2}]\)}
          },
        RowSpacings->1,
        ColumnSpacings->3,
        RowAlignments->Baseline,
        ColumnAlignments->{Left}],
      TableForm[ {
        Node[ a, {0, {1, 2, 8, 11}}, {1}], 
        Node[ b, {0, {1, 2, 11}}, {1}], 
        Node[ c, {0, {3, 4, 5, 6, 7, 9, 11}}, {3}], 
        Node[ d, {0, {3, 4, 5, 6, 7, 11, 12}}, {2}], 
        Node[ e, {0, {3, 4, 5, 6, 7, 10, 11, 12}}, {2}], 
        Node[ 1, {0, {1, 2, 11}}, {a, b, 3}], 
        Node[ 2, {0, {3, 4, 5, 6, 7, 11, 12}}, {d, e, 3}], 
        Node[ 3, {0, {3, 4, 5, 6, 7, 11}}, {1, c, 2}]}]]], "Output",
  CellLabel->"Out[38]//TableForm="]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Technicalities", "SubsubsectionIcon"],

Cell[TextData[Cell[BoxData[
    FormBox[GridBox[{
          {
            RowBox[{
              RowBox[{
                RowBox[{
                  RowBox[{
                    FormBox[\(\(FindNode\)\([\)\(g, {m\_1\)\),
                      "TraditionalForm"], ",", "\[Ellipsis]"}], "}"}], ",", 
                "newNode"}], 
              "]"}], \(finds\ from\ where\ in\ the\ genealogy\ g\ a\ leaf\ \
carrying\ mutations\ {m\_1, \[Ellipsis]}\ descends . \ 
                If\ a\ new\ node\ is\ added, \ 
            it\ is\ labelled\ by\ \(\(newNode\)\(.\)\)\)}
          }], TraditionalForm]]]], "DefinitionBox",
  CellTags->"FindNode"],

Cell["\<\
For rooted genealogies, MatrixToGenealogy[] uses FindNode[] to add \
successive leaves to the genealogy.  For example, consider additions to this \
genealogy:\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"g", "=", 
      RowBox[{"MatrixToGenealogy", "[", 
        RowBox[{
          RowBox[{"(", GridBox[{
                {"1", "1", "0", "0", "0", "0", "0", "1", "0", "0", "1", "0"},
                {"1", "1", "0", "0", "0", "0", "0", "0", "0", "0", "1", "0"},
                {"0", "0", "1", "1", "1", "1", "1", "0", "1", "0", "1", "0"},
                {"0", "0", "1", "1", "1", "1", "1", "0", "0", "0", "1", "1"},
                {"0", "0", "1", "1", "1", "1", "1", "0", "0", "1", "1", "1"}
                }], ")"}], ",", \({a, b, c, d, e}\), ",", \(Range[12]\)}], 
        "]"}]}]], "Input",
  CellLabel->"In[280]:="],

Cell[BoxData[
    \(Node[
      1, {0, {11}}, {
        Node[2, {0, {11, 1, 2}}, {Node[a, {0, {1, 2, 8, 11}}, {}], 
            Node[b, {0, {1, 2, 11}}, {}]}], 
        Node[3, {0, {11, 3, 4, 5, 6, 7}}, {
            Node[c, {0, {3, 4, 5, 6, 7, 9, 11}}, {}], 
            Node[4, {0, {3, 4, 5, 6, 7, 11, 12}}, {
                Node[d, {0, {3, 4, 5, 6, 7, 11, 12}}, {}], 
                Node[e, {0, {3, 4, 5, 6, 7, 10, 11, 12}}, {}]}]}]}]\)], 
  "Output",
  CellLabel->"Out[280]="]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(Show[PlotGenealogy[g]]; \)\)], "Input",
  CellLabel->"In[281]:="],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.166667 0.166667 0.123607 0.123607 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
0 g
.5 Mabswid
[ ] 0 setdash
.5 .49443 m
.25 .24721 L
s
.5 .49443 m
.66667 .37082 L
s
.25 .24721 m
.16667 .12361 L
s
.25 .24721 m
.33333 .12361 L
s
.66667 .37082 m
.5 .12361 L
s
.66667 .37082 m
.75 .24721 L
s
.75 .24721 m
.66667 .12361 L
s
.75 .24721 m
.83333 .12361 L
s
[(1)] .46667 .51915 0 0 Mshowa
[(2)] .21667 .27193 0 0 Mshowa
[(3)] .63333 .39554 0 0 Mshowa
[(4)] .71667 .27193 0 0 Mshowa
gsave
.16667 .09889 -66 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 16.000000 moveto
 558.000000 16.000000 lineto
 558.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 16.000000 lineto
closepath
clip newpath
63.000000 13.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(a) show
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: font Courier
grestore
gsave
.33333 .09889 -66 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 16.000000 moveto
 558.000000 16.000000 lineto
 558.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 16.000000 lineto
closepath
clip newpath
63.000000 13.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(b) show
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: font Courier
grestore
gsave
.5 .09889 -66 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 16.000000 moveto
 558.000000 16.000000 lineto
 558.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 16.000000 lineto
closepath
clip newpath
63.000000 13.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(c) show
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: font Courier
grestore
gsave
.66667 .09889 -66 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 16.000000 moveto
 558.000000 16.000000 lineto
 558.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 16.000000 lineto
closepath
clip newpath
63.000000 13.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(d) show
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: font Courier
grestore
gsave
.83333 .09889 -66 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 16.000000 moveto
 558.000000 16.000000 lineto
 558.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 16.000000 lineto
closepath
clip newpath
63.000000 13.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(e) show
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: font Courier
grestore
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[281]:=",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/A000`40O003h00Oogoo8Goo003oOolQ
Ool00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00
ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQ
Ool00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00
ogoo8Goo003oOolQOol002ioo`D002Yoo`@002eoo`<002eoo`D002Yoo`@002moo`00;Woo00@007oo
Ool002]oo`05001oogooOol0000[Ool01@00Oomoogoo0000:goo00D007ooOomoo`0002Yoo`03001o
ogoo035oo`00;Woo1000:goo00D007ooOomoo`0002]oo`03001oogoo02eoo`05001oogooOol0000Z
Ool5000_Ool0035oo`03001oogoo02Uoo`05001oogooOol0000[Ool01@00Oomoogoo0000:goo00D0
07ooOomoo`0002Yoo`05001oogooOol0000_Ool002moo`<002]oo`@002eoo`@002aoo`@002]oo`<0
031oo`00GGoo00<007ooOol0HGoo00<007ooOol0G7oo001LOol2001ROol2001NOol00?moob5oo`00
ogoo8Goo000`Ool00`00Oomoo`0/Ool00`00Oomoo`0]Ool00`00Oomoo`0]Ool00`00Oomoo`0/Ool0
0`00Oomoo`0_Ool0031oo`03001oogoo02aoo`03001oogoo02eoo`03001oogoo02eoo`03001oogoo
02aoo`03001oogoo02moo`00<Goo00<007ooOol0:Woo00<007ooOol0;goo00<007ooOol0;Goo00<0
07ooOol0:Woo00<007ooOol0<7oo000bOol00`00Oomoo`0XOol00`00Oomoo`0aOol00`00Oomoo`0]
Ool00`00Oomoo`0XOol00`00Oomoo`0aOol0039oo`03001oogoo02Qoo`03001oogoo035oo`03001o
ogoo02eoo`03001oogoo02Qoo`03001oogoo035oo`00<goo00<007ooOol09Woo00<007ooOol0<goo
00<007ooOol0;Goo00<007ooOol09Woo00<007ooOol0<Woo000dOol00`00Oomoo`0TOol00`00Oomo
o`0eOol00`00Oomoo`0]Ool00`00Oomoo`0TOol00`00Oomoo`0cOol003Aoo`03001oogoo02Aoo`03
001oogoo03Eoo`03001oogoo02eoo`03001oogoo02Aoo`03001oogoo03=oo`00=Goo00<007ooOol0
8Woo00<007ooOol0=goo00<007ooOol0;Goo00<007ooOol08Woo00<007ooOol0=7oo000fOol00`00
Oomoo`0POol00`00Oomoo`0iOol00`00Oomoo`0]Ool00`00Oomoo`0POol00`00Oomoo`0eOol003Io
o`03001oogoo01moo`03001oogoo03Yoo`03001oogoo02ioo`03001oogoo01moo`03001oogoo03Eo
o`00=goo00<007ooOol07Woo00<007ooOol0>goo00<007ooOol0;Goo00<007ooOol07Woo00<007oo
Ool0=Woo000hOol00`00Oomoo`0LOol00`00Oomoo`0mOol00`00Oomoo`0]Ool00`00Oomoo`0LOol0
0`00Oomoo`0gOol003Qoo`03001oogoo01]oo`03001oogoo03ioo`03001oogoo02ioo`03001oogoo
01]oo`03001oogoo03Moo`00>Goo00<007ooOol06Woo00<007ooOol0?goo00<007ooOol0;Goo00<0
07ooOol06Woo00<007ooOol0>7oo000jOol00`00Oomoo`0HOol00`00Oomoo`11Ool00`00Oomoo`0]
Ool00`00Oomoo`0HOol00`00Oomoo`0iOol003Yoo`03001oogoo01Moo`03001oogoo049oo`03001o
ogoo02ioo`03001oogoo01Moo`03001oogoo03Uoo`00>goo00<007ooOol05Woo00<007ooOol0@goo
00<007ooOol0;Goo00<007ooOol05Woo00<007ooOol0>Woo000lOol00`00Oomoo`0DOol00`00Oomo
o`15Ool00`00Oomoo`0]Ool00`00Oomoo`0DOol00`00Oomoo`0kOol003aoo`03001oogoo01=oo`03
001oogoo04Moo`03001oogoo02eoo`03001oogoo01=oo`03001oogoo03]oo`00?Goo00<007ooOol0
4Woo00<007ooOol0Agoo00<007ooOol0;Goo00<007ooOol04Woo00<007ooOol0?7oo000mOol00`00
Oomoo`0AOol00`00Oomoo`19Ool00`00Oomoo`0]Ool00`00Oomoo`0AOol00`00Oomoo`0lOol003io
o`03001oogoo00moo`03001oogoo04]oo`03001oogoo02eoo`03001oogoo00moo`03001oogoo03eo
o`00?goo00<007ooOol03Woo00<007ooOol0Bgoo00<007ooOol0;Goo00<007ooOol03Woo00<007oo
Ool0?Woo000oOol00`00Oomoo`0=Ool00`00Oomoo`1=Ool00`00Oomoo`0]Ool00`00Oomoo`0=Ool0
0`00Oomoo`0nOol0041oo`03001oogoo00]oo`03001oogoo04moo`03001oogoo02eoo`03001oogoo
00]oo`03001oogoo03moo`00@Goo00<007ooOol02Woo00<007ooOol0Cgoo00<007ooOol0;Goo00<0
07ooOol02Woo00<007ooOol0@7oo0011Ool00`00Oomoo`09Ool00`00Oomoo`1AOol00`00Oomoo`0]
Ool00`00Oomoo`09Ool00`00Oomoo`10Ool0049oo`03001oogoo00Moo`03001oogoo05=oo`03001o
ogoo02eoo`03001oogoo00Moo`03001oogoo045oo`00@goo00<007ooOol01Goo00<007ooOol0E7oo
00<007ooOol0;Woo00<007ooOol01Goo00<007ooOol0@Woo0013Ool00`00Oomoo`05Ool00`00Oomo
o`1EOol00`00Oomoo`0]Ool00`00Oomoo`05Ool00`00Oomoo`12Ool004Aoo`03001oogoo00=oo`03
001oogoo05Moo`03001oogoo02eoo`03001oogoo00=oo`03001oogoo04=oo`00AGoo00D007ooOomo
o`0005Yoo`03001oogoo02ioo`05001oogooOol00016Ool004Eoo`05001oogooOol0001KOol00`00
Oomoo`0]Ool01@00Oomoogoo0000AWoo0016Ool00`00Ool0001MOol00`00Oomoo`0]Ool00`00Ool0
0017Ool004Moo`8005eoo`03001oogoo02ioo`03001oogoo04Ioo`00BGoo00<007ooOol0Fgoo00<0
07ooOol0;Goo00<007ooOol0AWoo001:Ool00`00Oomoo`1KOol00`00Oomoo`0[Ool00`00Oomoo`17
Ool004]oo`03001oogoo05Yoo`03001oogoo02Yoo`03001oogoo04Qoo`00C7oo00<007ooOol0FWoo
00<007ooOol0:Goo00<007ooOol0B7oo000lOol4000=Ool00`00Oomoo`1JOol00`00Oomoo`0OOol3
0005Ool00`00Oomoo`19Ool003eoo`03001oogoo00ioo`03001oogoo05Uoo`03001oogoo021oo`03
001oogoo00=oo`03001oogoo04Yoo`00?Woo00<007ooOol03Woo00<007ooOol0FGoo00<007ooOol0
7Goo100017oo00<007ooOol0BWoo000oOol00`00Oomoo`0>Ool00`00Oomoo`1IOol00`00Oomoo`0L
Ool00`00Ool00004Ool00`00Oomoo`1;Ool003aoo`04001oogoo000AOol00`00Oomoo`1HOol00`00
Oomoo`0LOol00`00Ool00003Ool00`00Oomoo`1<Ool003eoo`8001=oo`03001oogoo05Qoo`03001o
ogoo01aoo`8000=oo`03001oogoo04aoo`00Dgoo00<007ooOol0F7oo00<007ooOol07goo00<007oo
Ool0CGoo001DOol00`00Oomoo`1GOol00`00Oomoo`0NOol00`00Oomoo`1>Ool005Eoo`03001oogoo
05Moo`03001oogoo01eoo`03001oogoo04ioo`00EWoo00<007ooOol0Egoo00<007ooOol06goo00<0
07ooOol0Cgoo001GOol00`00Oomoo`1FOol00`00Oomoo`0JOol00`00Oomoo`1@Ool005Qoo`03001o
ogoo05Ioo`03001oogoo01Uoo`03001oogoo051oo`00FGoo00<007ooOol0EWoo00<007ooOol05goo
00<007ooOol0DGoo001JOol00`00Oomoo`1EOol00`00Oomoo`0FOol00`00Oomoo`1BOol005]oo`03
001oogoo05Eoo`03001oogoo01Eoo`03001oogoo059oo`00G7oo00<007ooOol0EGoo00<007ooOol0
4goo00<007ooOol0Dgoo001MOol00`00Oomoo`1EOol00`00Oomoo`0AOol00`00Oomoo`1DOol005io
o`03001oogoo05Aoo`03001oogoo015oo`03001oogoo05Aoo`00Ggoo00<007ooOol0E7oo00<007oo
Ool03goo00<007ooOol0EGoo001POol00`00Oomoo`1DOol00`00Oomoo`0=Ool00`00Oomoo`1FOol0
065oo`03001oogoo05=oo`03001oogoo00eoo`03001oogoo05Ioo`00HWoo00<007ooOol0Dgoo00<0
07ooOol02goo00<007ooOol0Egoo001SOol00`00Oomoo`1COol00`00Oomoo`09Ool00`00Oomoo`1H
Ool006Aoo`03001oogoo059oo`03001oogoo00Uoo`03001oogoo05Qoo`00IGoo00<007ooOol0DWoo
00<007ooOol01goo00<007ooOol0FGoo001VOol00`00Oomoo`1BOol00`00Oomoo`05Ool00`00Oomo
o`1JOol006Moo`03001oogoo055oo`03001oogoo00Eoo`03001oogoo05Yoo`00J7oo00<007ooOol0
DGoo00<007ooOol00goo00<007ooOol0Fgoo001YOol00`00Oomoo`1AOol01@00Oomoogoo0000GWoo
001ZOol00`00Oomoo`1@Ool01@00Oomoogoo0000GWoo001[Ool00`00Oomoo`1@Ool00`00Ool0001O
Ool006aoo`03001oogoo04moo`80061oo`00KGoo00<007ooOol0CGoo00<007ooOol0H7oo001^Ool0
0`00Oomoo`1;Ool00`00Oomoo`1QOol006moo`03001oogoo04Qoo`8006Aoo`00L7oo00<007ooOol0
AWoo00<007ooOol0I7oo001aOol00`00Oomoo`0oOol300000goo0000001WOol0079oo`03001oogoo
045oo`03001oogoo06Moo`00Lgoo00<007ooOol0?goo0P00JGoo001dOol00`00Oomoo`0lOol3001Z
Ool007Eoo`03001oogoo03Yoo`05001oogooOol0001YOol007Ioo`03001oogoo03Qoo`03001oo`00
008006Yoo`00Mgoo00<007ooOol0=Goo0P00Kgoo001hOol00`00Oomoo`0cOol00`00Oomoo`1_Ool0
07Uoo`03001oogoo031oo`80079oo`00NWoo00<007ooOol0;Woo00<007ooOol0LWoo001kOol00`00
Oomoo`0/Ool00`00Oomoo`1cOol007aoo`03001oogoo02Uoo`8007Ioo`00OGoo00<007ooOol09goo
00<007ooOol0MWoo001nOol00`00Oomoo`0UOol00`00Oomoo`1gOol007moo`03001oogoo029oo`80
07Yoo`00P7oo00<007ooOol087oo00<007ooOol0NWoo0021Ool00`00Oomoo`0NOol00`00Oomoo`1k
Ool0089oo`03001oogoo01]oo`8007ioo`00Pgoo00<007ooOol06Goo00<007ooOol0OWoo0024Ool0
0`00Oomoo`0FOol20021Ool008Eoo`03001oogoo01Aoo`03001oogoo085oo`00QWoo00<007ooOol0
4Woo00<007ooOol0PWoo0027Ool00`00Oomoo`0?Ool20025Ool008Qoo`03001oogoo00eoo`03001o
ogoo08Eoo`00RGoo00<007ooOol02goo00<007ooOol0QWoo002:Ool00`00Oomoo`08Ool20029Ool0
08]oo`03001oogoo00Ioo`03001oogoo08Uoo`00S7oo00<007ooOol00goo0P00S7oo002=Ool01@00
Oomoogoo0000SWoo002>Ool00`00Ool0002?Ool008moo`03001oogoo08ioo`00ogoo8Goo003oOolQ
Ool00?moob5oo`00ogoo8Goo0023Ool3002JOol008Aoo`03001oogoo09Uoo`00Q7oo00<007ooOol0
VGoo0024Ool00`00Oomoo`2IOol008Aoo`03001oogoo09Uoo`00Pgoo0P00Vgoo003oOolQOol00?mo
ob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo
003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?mo
ob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo
003oOolQOol00001\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-1.00744, -1.00003, 
  0.0209577, 0.0282586}}]
}, Closed]],

Cell["\<\
If no node or branch matches, FindNode[] returns $Failed, and \
indicates the problem:\
\>", "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[
    \(FindNode[g, {8}, 5]\)], "Input",
  CellLabel->"In[282]:="],

Cell[BoxData[
    InterpretationBox[
      \("New leaf"\[InvisibleSpace]{8}
          \[InvisibleSpace]"does not contain all mutations in node "\
\[InvisibleSpace]1\),
      SequenceForm[ 
      "New leaf", {8}, "does not contain all mutations in node ", 1],
      Editable->False]], "Print"],

Cell[BoxData[
    \($Failed\)], "Output",
  CellLabel->"Out[282]="]
}, Closed]],

Cell["\<\
However, FindNode[] does not check all descendant nodes to make \
sure that the result is consistent: it tests nodes for compatibility from the \
top down.  \
\>", "Text"],

Cell["So, this leaf is in fact inconsistent with the genealogy:", \
"MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[
    \(FindNode[g, {8, 11, 12}, 5]\)], "Input",
  CellLabel->"In[284]:="],

Cell[BoxData[
    \({1, 1, {11}}\)], "Output",
  CellLabel->"Out[284]="]
}, Closed]],

Cell[TextData[{
  "If the leaf joins the branch above node ",
  Cell[BoxData[
      \(TraditionalForm\`i\)]],
  ", FindNode[] returns ",
  Cell[BoxData[
      \(TraditionalForm\`{i, newNode, {\(m\_1\) \[Ellipsis]}}\)]],
  "; the last element lists the mutations carried by the new node:"
}], "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[
    \(FindNode[g, {3, 4, 11}, 6]\)], "Input",
  CellLabel->"In[285]:="],

Cell[BoxData[
    \({3, 6, {11, 3, 4}}\)], "Output",
  CellLabel->"Out[285]="]
}, Closed]],

Cell[TextData[{
  "If the leaf joins at node ",
  Cell[BoxData[
      \(TraditionalForm\`i\)]],
  ", FindNode[] returns ",
  Cell[BoxData[
      \(TraditionalForm\`{i, i, {\(m\_1\) \[Ellipsis]}}\)]],
  ":"
}], "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[
    \(FindNode[g, {3, 4, 5, 6, 7, 11}, 6]\)], "Input",
  CellLabel->"In[286]:="],

Cell[BoxData[
    \({3, 3, {11, 3, 4, 5, 6, 7}}\)], "Output",
  CellLabel->"Out[286]="]
}, Closed]],

Cell["\<\
FindNode[] is desgned to work with MatrixToGenealogy[], and so it \
only gives unambiguous results if the genealogy contains at least one \
mutation on each branch, except for terminal branches, and the new leaf must \
contain all mutations in the root node of g.\
\>", "Text"]
}, Closed]],

Cell[CellGroupData[{

Cell["Condensing a matrix", "SubsubsectionIcon"],

Cell[TextData[Cell[BoxData[
    FormBox[GridBox[{
          {\(CondenseMatrix[
              S]\), \(reduces\ the\ matrix\ S\ to\ the\ minimum\ informative\ \
size\)},
          {\(CondenseMatrix[S, 
              Unrooted \[Rule] 
                True]\), \(makes\ further\ reductions\ allowed\ by\ assuming\ \
that\ which\ allele\ is\ ancestral\ is\ unknown\)}
          }], TraditionalForm]]]], "DefinitionBox",
  CellTags->"CondenseMatrix"],

Cell["\<\
A matrix representing the distribution of mutations across leaves \
may contain superfluous information:\
\>", "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[
    \(S // TableForm\)], "Input",
  CellLabel->"In[14]:="],

Cell[BoxData[
    TagBox[GridBox[{
          {"1", "1", "0", "0", "0", "0", "0", "1", "0", "0", "0"},
          {"1", "1", "0", "0", "0", "0", "0", "0", "0", "0", "0"},
          {"0", "0", "1", "1", "1", "1", "1", "0", "1", "0", "0"},
          {"0", "0", "1", "1", "1", "1", "1", "0", "0", "1", "0"},
          {"0", "0", "1", "1", "1", "1", "1", "0", "0", "1", "1"}
          },
        RowSpacings->1,
        ColumnSpacings->3,
        RowAlignments->Baseline,
        ColumnAlignments->{Left}],
      (TableForm[ #]&)]], "Output",
  CellLabel->"Out[14]//TableForm="]
}, Open  ]],

Cell["\<\
In this example, several mutations have the same distribution \
across leaves, and so only one need be given.  Also, mutations fixed across \
the whole sample, or present in only one leaf, arenot informative.  The same \
topology will be inferred from this reduced set of mutations:\
\>", \
"MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[
    \(CondenseMatrix[S] // TableForm\)], "Input",
  CellLabel->"In[19]:="],

Cell[BoxData[
    TagBox[GridBox[{
          {"0", "0", "1"},
          {"0", "0", "1"},
          {"0", "1", "0"},
          {"1", "1", "0"},
          {"1", "1", "0"}
          },
        RowSpacings->1,
        ColumnSpacings->3,
        RowAlignments->Baseline,
        ColumnAlignments->{Left}],
      (TableForm[ #]&)]], "Output",
  CellLabel->"Out[19]//TableForm="]
}, Open  ]],

Cell["\<\
If `1` alleles are not known to be derived, then only an unrooted \
genealogy can be inferred. Thus, 'complementary' pairs of mutations (e.g. \
{1,1,0,0,0} and {0,0,1,1,1}) can be condensed:\
\>", "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[
    \(CondenseMatrix[S, Unrooted \[Rule] True] // TableForm\)], "Input",
  CellLabel->"In[20]:="],

Cell[BoxData[
    TagBox[GridBox[{
          {"0", "0"},
          {"0", "0"},
          {"0", "1"},
          {"1", "1"},
          {"1", "1"}
          },
        RowSpacings->1,
        ColumnSpacings->3,
        RowAlignments->Baseline,
        ColumnAlignments->{Left}],
      (TableForm[ #]&)]], "Output",
  CellLabel->"Out[20]//TableForm="]
}, Open  ]]
}, Open  ]]
},
FrontEndVersion->"4.0 for Macintosh",
ScreenRectangle->{{0, 1152}, {0, 748}},
WindowSize->{969, 679},
WindowMargins->{{Automatic, 53}, {11, Automatic}},
StyleDefinitions -> "HelpBrowser.nb",
MacintoshSystemPageSetup->"\<\
00`0001804P000000_02@?o/onh3109BI085:0?l0@00005X0FP000003[0;@001
0000I00100000@0000000BL?0040000000000000000000000000000000000?nL
ojH?50^J00P100000000000000000000\>"
]


(***********************************************************************
Cached data follows.  If you edit this Notebook file directly, not using
Mathematica, you must remove the line containing CacheID at the top of 
the file.  The cache data will then be recreated when you save this file 
from within Mathematica.
***********************************************************************)

(*CellTagsOutline
CellTagsIndex->{
  "MatrixToGenealogy"->{
    Cell[1967, 60, 490, 9, 52, "DefinitionBox",
      CellTags->"MatrixToGenealogy"],
    Cell[38393, 935, 401, 8, 37, "DefinitionBox",
      CellTags->{"MatrixToGenealogy", "Unrooted"}]},
  "Unrooted"->{
    Cell[38393, 935, 401, 8, 37, "DefinitionBox",
      CellTags->{"MatrixToGenealogy", "Unrooted"}]},
  "FindNode"->{
    Cell[41591, 1017, 642, 15, 52, "DefinitionBox",
      CellTags->"FindNode"]},
  "CondenseMatrix"->{
    Cell[58762, 1513, 444, 10, 54, "DefinitionBox",
      CellTags->"CondenseMatrix"]}
  }
*)

(*CellTagsIndex
CellTagsIndex->{
  {"MatrixToGenealogy", 62425, 1632},
  {"Unrooted", 62630, 1637},
  {"FindNode", 62749, 1640},
  {"CondenseMatrix", 62853, 1643}
  }
*)

(*NotebookFileOutline
Notebook[{
Cell[1717, 49, 46, 0, 28, "MathCaption"],
Cell[1766, 51, 90, 2, 26, "Input"],

Cell[CellGroupData[{
Cell[1881, 57, 83, 1, 24, "SubsubsectionIcon"],
Cell[1967, 60, 490, 9, 52, "DefinitionBox",
  CellTags->"MatrixToGenealogy"],
Cell[2460, 71, 170, 4, 22, "Text"],
Cell[2633, 77, 162, 4, 28, "MathCaption"],

Cell[CellGroupData[{
Cell[2820, 85, 619, 12, 88, "Input"],
Cell[3442, 99, 412, 9, 50, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[3891, 113, 85, 2, 26, "Input"],
Cell[3979, 117, 15030, 351, 184, 3906, 208, "GraphicsData", "PostScript", \
"Graphics"]
}, Open  ]],
Cell[19024, 471, 85, 1, 28, "MathCaption"],

Cell[CellGroupData[{
Cell[19134, 476, 815, 19, 88, "Input"],
Cell[19952, 497, 507, 11, 50, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[20496, 513, 85, 2, 26, "Input"],
Cell[20584, 517, 16707, 375, 184, 3962, 212, "GraphicsData", "PostScript", \
"Graphics"]
}, Open  ]],
Cell[37306, 895, 157, 4, 22, "Text"],

Cell[CellGroupData[{
Cell[37488, 903, 419, 12, 88, "Input"],
Cell[37910, 917, 278, 5, 35, "Message"],
Cell[38191, 924, 66, 2, 20, "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[38306, 932, 84, 1, 24, "SubsubsectionIcon"],
Cell[38393, 935, 401, 8, 37, "DefinitionBox",
  CellTags->{"MatrixToGenealogy", "Unrooted"}],
Cell[38797, 945, 397, 7, 36, "Text"],
Cell[39197, 954, 221, 4, 42, "MathCaption"],

Cell[CellGroupData[{
Cell[39443, 962, 932, 21, 111, "Input"],
Cell[40378, 985, 1118, 24, 143, "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[41545, 1015, 43, 0, 24, "SubsubsectionIcon"],
Cell[41591, 1017, 642, 15, 52, "DefinitionBox",
  CellTags->"FindNode"],
Cell[42236, 1034, 182, 4, 22, "Text"],

Cell[CellGroupData[{
Cell[42443, 1042, 645, 12, 88, "Input"],
Cell[43091, 1056, 482, 11, 50, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[43610, 1072, 87, 2, 22, "Input"],
Cell[43700, 1076, 12645, 335, 184, 4742, 232, "GraphicsData", "PostScript", \
"Graphics"]
}, Closed]],
Cell[56360, 1414, 117, 3, 18, "MathCaption"],

Cell[CellGroupData[{
Cell[56502, 1421, 78, 2, 26, "Input"],
Cell[56583, 1425, 292, 7, 20, "Print"],
Cell[56878, 1434, 67, 2, 20, "Output"]
}, Closed]],
Cell[56960, 1439, 181, 4, 18, "Text"],
Cell[57144, 1445, 82, 1, 28, "MathCaption"],

Cell[CellGroupData[{
Cell[57251, 1450, 86, 2, 26, "Input"],
Cell[57340, 1454, 72, 2, 20, "Output"]
}, Closed]],
Cell[57427, 1459, 306, 8, 18, "MathCaption"],

Cell[CellGroupData[{
Cell[57758, 1471, 85, 2, 26, "Input"],
Cell[57846, 1475, 78, 2, 20, "Output"]
}, Closed]],
Cell[57939, 1480, 224, 8, 18, "MathCaption"],

Cell[CellGroupData[{
Cell[58188, 1492, 94, 2, 26, "Input"],
Cell[58285, 1496, 87, 2, 20, "Output"]
}, Closed]],
Cell[58387, 1501, 287, 5, 32, "Text"]
}, Closed]],

Cell[CellGroupData[{
Cell[58711, 1511, 48, 0, 20, "SubsubsectionIcon"],
Cell[58762, 1513, 444, 10, 54, "DefinitionBox",
  CellTags->"CondenseMatrix"],
Cell[59209, 1525, 135, 3, 28, "MathCaption"],

Cell[CellGroupData[{
Cell[59369, 1532, 72, 2, 26, "Input"],
Cell[59444, 1536, 572, 13, 95, "Output"]
}, Open  ]],
Cell[60031, 1552, 315, 6, 42, "MathCaption"],

Cell[CellGroupData[{
Cell[60371, 1562, 88, 2, 26, "Input"],
Cell[60462, 1566, 372, 13, 95, "Output"]
}, Open  ]],
Cell[60849, 1582, 221, 4, 42, "MathCaption"],

Cell[CellGroupData[{
Cell[61095, 1590, 111, 2, 26, "Input"],
Cell[61209, 1594, 347, 13, 95, "Output"]
}, Open  ]]
}, Open  ]]
}
]
*)




(***********************************************************************
End of Mathematica Notebook file.
***********************************************************************)

