(***********************************************************************

                    Mathematica-Compatible Notebook

This notebook can be used on any computer system with Mathematica 4.0,
MathReader 4.0, or any compatible application. The data for the notebook 
starts with the line containing stars above.

To get the notebook into a Mathematica-compatible application, do one of 
the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing the 
word CacheID, otherwise Mathematica-compatible applications may try to 
use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
***********************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[     42736,       1128]*)
(*NotebookOutlinePosition[     44506,       1182]*)
(*  CellTagsIndexPosition[     44256,       1171]*)
(*WindowFrame->Normal*)



Notebook[{

Cell[CellGroupData[{
Cell["Manipulating genealogies", "SubsectionIcon"],

Cell[TextData[Cell[BoxData[
    FormBox[GridBox[{
          {\(ExtractGenealogy[g, 
              i]\), \(gives\ the\ genealogy\ that\ descends\ from\ node\ \
\(\(i\)\(.\)\)\)},
          {\(DeleteGenealogy[g, 
              i]\), \(deletes\ the\ genealogy\ that\ descends\ from\ node\ \(\
\(i\)\(.\)\)\)}
          }], TraditionalForm]]]], "DefinitionBox",
  CellTags->{"ExtractGenealogy", "DeleteGenealogy"}],

Cell["\<\
This extracts the genealogy that descends from the node labelled \
{c,d,e,f,g,h}:\
\>", "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[
    \(tr1 = ExtractGenealogy[tr, {c, d, e, f, g, h}]\)], "Input",
  CellLabel->"In[275]:="],

Cell[BoxData[
    RowBox[{"Node", "[", 
      RowBox[{\({c, d, e, f, g, h}\), ",", 
        RowBox[{"{", 
          StyleBox["1.8`",
            StyleBoxAutoDelete->True,
            PrintPrecision->2], "}"}], ",", 
        RowBox[{"{", 
          RowBox[{
          \(Node[{c, d}, {1}, {Node[{c}, {0}, {}], Node[{d}, {0}, {}]}]\), 
            ",", 
            RowBox[{"Node", "[", 
              RowBox[{\({e, f, g, h}\), ",", 
                RowBox[{"{", 
                  StyleBox["1.7`",
                    StyleBoxAutoDelete->True,
                    PrintPrecision->2], "}"}], ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{"Node", "[", 
                      RowBox[{\({e, f, g}\), ",", 
                        RowBox[{"{", 
                          StyleBox["1.5`",
                            StyleBoxAutoDelete->True,
                            PrintPrecision->2], "}"}], ",", 
                        \({Node[{e}, {0}, {}], Node[{f}, {0}, {}], 
                          Node[{g}, {0}, {}]}\)}], "]"}], ",", 
                    \(Node[{h}, {0}, {}]\)}], "}"}]}], "]"}]}], "}"}]}], 
      "]"}]], "Output",
  CellLabel->"Out[275]="]
}, Closed]],

Cell["This deletes that part of the genealogy:", "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[
    \(tr2 = DeleteGenealogy[tr, {c, d, e, f, g, h}]\)], "Input",
  CellLabel->"In[276]:="],

Cell[BoxData[
    RowBox[{"Node", "[", 
      RowBox[{\({a, b, c, d, e, f, g, h}\), ",", 
        RowBox[{"{", 
          StyleBox["2.29999999999999982`",
            StyleBoxAutoDelete->True,
            PrintPrecision->2], "}"}], ",", 
        RowBox[{"{", 
          RowBox[{"Node", "[", 
            RowBox[{\({a, b}\), ",", 
              RowBox[{"{", 
                StyleBox["0.4`",
                  StyleBoxAutoDelete->True,
                  PrintPrecision->1], "}"}], ",", 
              \({Node[{a}, {0}, {}], Node[{b}, {0}, {}]}\)}], "]"}], "}"}]}], 
      "]"}]], "Output",
  CellLabel->"Out[276]="]
}, Closed]],

Cell["These functions apply only to rooted genealogies.", "Text"],

Cell[TextData[Cell[BoxData[
    FormBox[GridBox[{
          {
            RowBox[{"AddGenealogy", "[", 
              RowBox[{\(g\_1\), ",", \(g\_2\), ",", "i", ",", "j", ",", 
                StyleBox["info",
                  FontSlant->"Italic"]}], "]"}], 
            
            RowBox[{\(adds\ rooted\ genealogy\ g\_2\ to\ rooted\ genealogy\ g\
\_1\), ",", 
              " ", \(immediately\ above\ existing\ node\ i\ of\ g\_1 . \ \ \
The\ new\ node\ is\ labelled\ j\), ",", " ", 
              RowBox[{"and", " ", "carries", " ", "information", " ", 
                RowBox[{
                  StyleBox["info",
                    FontSlant->"Italic"], "."}]}]}]},
          {\(AddGenealogy[g\_1, g\_2, i, 
              i]\), \(\(\ \)\(adds\ the\ rooted\ genealogy\ \(g\_2\) 
              to\ existing\ node\ i; \ \(\(its\)\(\ \)\(information\)\(\ \
\)\(is\)\(\ \)\(\(unaltered\)\(.\)\)\(\ \ \)\)\)\)},
          {
            RowBox[{"AddGenealogy", "[", 
              RowBox[{\(u\_1\), ",", \(u\_2\), ",", \(i\_1\), ",", 
                SubscriptBox[
                  StyleBox["i",
                    FontSlant->"Italic"], "2"]}], 
              "]"}], \(joins\ the\ unrooted\ genealogies\ u\_1, \ 
            u\_2\ at\ their\ nodes\ i\_1, \ \(\(i\_2\)\(.\)\)\)}
          }], TraditionalForm]]]], "DefinitionBox",
  CellTags->"AddGenealogy"],

Cell["\<\
This adds back the deleted part of the genealogy, at a new node \
labelled x, and lying just above node {a,b}:\
\>", "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[
    \(tr3 = AddGenealogy[tr2, tr1, {a, b}, {x}, {2.1}]\)], "Input",
  CellLabel->"In[281]:="],

Cell[BoxData[
    RowBox[{"Node", "[", 
      RowBox[{\({a, b, c, d, e, f, g, h}\), ",", 
        RowBox[{"{", 
          StyleBox["2.29999999999999982`",
            StyleBoxAutoDelete->True,
            PrintPrecision->2], "}"}], ",", 
        RowBox[{"{", 
          RowBox[{"Node", "[", 
            RowBox[{\({x}\), ",", 
              RowBox[{"{", 
                StyleBox["2.10000000000000008`",
                  StyleBoxAutoDelete->True,
                  PrintPrecision->2], "}"}], ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{"Node", "[", 
                    RowBox[{\({a, b}\), ",", 
                      RowBox[{"{", 
                        StyleBox["0.4`",
                          StyleBoxAutoDelete->True,
                          PrintPrecision->1], "}"}], ",", 
                      \({Node[{a}, {0}, {}], Node[{b}, {0}, {}]}\)}], "]"}], 
                  ",", 
                  RowBox[{"Node", "[", 
                    RowBox[{\({c, d, e, f, g, h}\), ",", 
                      RowBox[{"{", 
                        StyleBox["1.8`",
                          StyleBoxAutoDelete->True,
                          PrintPrecision->2], "}"}], ",", 
                      RowBox[{"{", 
                        RowBox[{
                        \(Node[{c, d}, {1}, {Node[{c}, {0}, {}], 
                              Node[{d}, {0}, {}]}]\), ",", 
                          RowBox[{"Node", "[", 
                            RowBox[{\({e, f, g, h}\), ",", 
                              RowBox[{"{", 
                                StyleBox["1.7`",
                                  StyleBoxAutoDelete->True,
                                  PrintPrecision->2], "}"}], ",", 
                              RowBox[{"{", 
                                RowBox[{
                                  RowBox[{"Node", "[", 
                                    RowBox[{\({e, f, g}\), ",", 
                                      RowBox[{"{", 
                                        StyleBox["1.5`",
                                        StyleBoxAutoDelete->True,
                                        PrintPrecision->2], "}"}], ",", 
                                      \({Node[{e}, {0}, {}], 
                                        Node[{f}, {0}, {}], 
                                        Node[{g}, {0}, {}]}\)}], "]"}], ",", 
                                  \(Node[{h}, {0}, {}]\)}], "}"}]}], "]"}]}], 
                        "}"}]}], "]"}]}], "}"}]}], "]"}], "}"}]}], "]"}]], 
  "Output",
  CellLabel->"Out[281]="]
}, Closed]],

Cell["This joins tr1 at the node {a,b}, giving a trifurcation:", "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[
    \(tr3 = AddGenealogy[tr2, tr1, {a, b}, {a, b}]\)], "Input",
  CellLabel->"In[284]:="],

Cell[BoxData[
    RowBox[{"Node", "[", 
      RowBox[{\({a, b, c, d, e, f, g, h}\), ",", 
        RowBox[{"{", 
          StyleBox["2.29999999999999982`",
            StyleBoxAutoDelete->True,
            PrintPrecision->2], "}"}], ",", 
        RowBox[{"{", 
          RowBox[{"Node", "[", 
            RowBox[{\({a, b}\), ",", 
              RowBox[{"{", 
                StyleBox["0.4`",
                  StyleBoxAutoDelete->True,
                  PrintPrecision->1], "}"}], ",", 
              RowBox[{"{", 
                RowBox[{
                \(Node[{a}, {0}, {}]\), ",", \(Node[{b}, {0}, {}]\), ",", 
                  RowBox[{"Node", "[", 
                    RowBox[{\({c, d, e, f, g, h}\), ",", 
                      RowBox[{"{", 
                        StyleBox["1.8`",
                          StyleBoxAutoDelete->True,
                          PrintPrecision->2], "}"}], ",", 
                      RowBox[{"{", 
                        RowBox[{
                        \(Node[{c, d}, {1}, {Node[{c}, {0}, {}], 
                              Node[{d}, {0}, {}]}]\), ",", 
                          RowBox[{"Node", "[", 
                            RowBox[{\({e, f, g, h}\), ",", 
                              RowBox[{"{", 
                                StyleBox["1.7`",
                                  StyleBoxAutoDelete->True,
                                  PrintPrecision->2], "}"}], ",", 
                              RowBox[{"{", 
                                RowBox[{
                                  RowBox[{"Node", "[", 
                                    RowBox[{\({e, f, g}\), ",", 
                                      RowBox[{"{", 
                                        StyleBox["1.5`",
                                        StyleBoxAutoDelete->True,
                                        PrintPrecision->2], "}"}], ",", 
                                      \({Node[{e}, {0}, {}], 
                                        Node[{f}, {0}, {}], 
                                        Node[{g}, {0}, {}]}\)}], "]"}], ",", 
                                  \(Node[{h}, {0}, {}]\)}], "}"}]}], "]"}]}], 
                        "}"}]}], "]"}]}], "}"}]}], "]"}], "}"}]}], "]"}]], 
  "Output",
  CellLabel->"Out[284]="]
}, Closed]],

Cell["\<\
This joins the unrooted genealogies tr1, tr2 at nodes {c,d}, {a,b}:\
\
\>", "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[
    \(utr1 = UnrootedGenealogy[tr1]; utr2 = UnrootedGenealogy[tr2]; \n
    AddGenealogy[utr2, utr1, {c, d}, {a, b}] // TableForm\)], "Input",
  CellLabel->"In[297]:="],

Cell[BoxData[
    InterpretationBox[GridBox[{
          {\(Node[{a}, {0}, {{a, b}}]\)},
          {\(Node[{b}, {0}, {{a, b}}]\)},
          {\(Node[{c}, {0}, {{c, d}}]\)},
          {\(Node[{d}, {0}, {{c, d}}]\)},
          {\(Node[{e}, {0}, {{e, f, g}}]\)},
          {\(Node[{f}, {0}, {{e, f, g}}]\)},
          {\(Node[{g}, {0}, {{e, f, g}}]\)},
          {\(Node[{h}, {0}, {{e, f, g, h}}]\)},
          {
            RowBox[{"Node", "[", 
              RowBox[{\({a, b}\), ",", 
                RowBox[{"{", 
                  StyleBox["0.4`",
                    StyleBoxAutoDelete->True,
                    PrintPrecision->1], "}"}], ",", 
                \({{a}, {b}, {a, b, c, d, e, f, g, h}, {c, d}}\)}], "]"}]},
          {\(Node[{c, d}, {1}, {{c}, {d}, {c, d, e, f, g, h}, {a, b}}]\)},
          {
            RowBox[{"Node", "[", 
              RowBox[{\({e, f, g}\), ",", 
                RowBox[{"{", 
                  StyleBox["1.5`",
                    StyleBoxAutoDelete->True,
                    PrintPrecision->2], "}"}], ",", 
                \({{e}, {f}, {g}, {e, f, g, h}}\)}], "]"}]},
          {
            RowBox[{"Node", "[", 
              RowBox[{\({e, f, g, h}\), ",", 
                RowBox[{"{", 
                  StyleBox["1.7`",
                    StyleBoxAutoDelete->True,
                    PrintPrecision->2], "}"}], ",", 
                \({{e, f, g}, {h}, {c, d, e, f, g, h}}\)}], "]"}]},
          {
            RowBox[{"Node", "[", 
              RowBox[{\({c, d, e, f, g, h}\), ",", 
                RowBox[{"{", 
                  StyleBox["1.8`",
                    StyleBoxAutoDelete->True,
                    PrintPrecision->2], "}"}], ",", 
                \({{c, d}, {e, f, g, h}}\)}], "]"}]},
          {
            RowBox[{"Node", "[", 
              RowBox[{\({a, b, c, d, e, f, g, h}\), ",", 
                RowBox[{"{", 
                  StyleBox["2.29999999999999982`",
                    StyleBoxAutoDelete->True,
                    PrintPrecision->2], "}"}], ",", \({{a, b}}\)}], "]"}]}
          },
        RowSpacings->1,
        ColumnSpacings->3,
        RowAlignments->Baseline,
        ColumnAlignments->{Left}],
      TableForm[ {
        Node[ {a}, {0}, {{a, b}}], 
        Node[ {b}, {0}, {{a, b}}], 
        Node[ {c}, {0}, {{c, d}}], 
        Node[ {d}, {0}, {{c, d}}], 
        Node[ {e}, {0}, {{e, f, g}}], 
        Node[ {f}, {0}, {{e, f, g}}], 
        Node[ {g}, {0}, {{e, f, g}}], 
        Node[ {h}, {0}, {{e, f, g, h}}], 
        Node[ {a, b}, {0.40000000000000002}, {{a}, {b}, {a, b, c, d, e, f, g, 
          h}, {c, d}}], 
        Node[ {c, d}, {1}, {{c}, {d}, {c, d, e, f, g, h}, {a, b}}], 
        Node[ {e, f, g}, {1.5}, {{e}, {f}, {g}, {e, f, g, h}}], 
        Node[ {e, f, g, h}, {1.7}, {{e, f, g}, {h}, {c, d, e, f, g, h}}], 
        Node[ {c, d, e, f, g, h}, {1.8}, {{c, d}, {e, f, g, h}}], 
        Node[ {a, b, c, d, e, f, g, h}, {2.2999999999999998}, {{a, b}}]}]]], 
  "Output",
  CellLabel->"Out[297]//TableForm="]
}, Closed]],

Cell[TextData[{
  "This will give a meaningless result if ",
  Cell[BoxData[
      \(TraditionalForm\`\(i\_1\ \)\)]],
  "is not a node of ",
  Cell[BoxData[
      \(TraditionalForm\`g\_1\)]],
  ", or ",
  Cell[BoxData[
      \(TraditionalForm\`\(i\_2\ \)\)]],
  "is not a node of ",
  Cell[BoxData[
      \(TraditionalForm\`g\_2\)]],
  "."
}], "Text"],

Cell[TextData[Cell[BoxData[
    FormBox[GridBox[{
          {
            RowBox[{"AddNode", "[", 
              RowBox[{"g", ",", "i", ",", "k", ",", 
                StyleBox["info",
                  FontSlant->"Italic"]}], 
              "]"}], \(adds\ a\ new\ node\ k\ immediately\ above\ existing\ \
node\ i\ of\ the\ rooted\ genealogy\ \(\(g\)\(.\)\)\)},
          {
            RowBox[{
              RowBox[{"AddNode", "[", 
                RowBox[{"g", ",", "i", ",", "j", ",", "k", ",", 
                  StyleBox["info",
                    FontSlant->"Italic"]}], "]"}], 
              " "}], \(adds\ a\ new\ node\ k\ between\ nodes\ i\ and\ j\ of\ \
the\ unrooted\ genealogy\ \(\(g\)\(.\)\)\)}
          }], TraditionalForm]]]], "DefinitionBox",
  CellTags->"AddNode"],

Cell["\<\
This adds a node labelled {x}, and with information {1.2}, above \
existing node {a,b}:\
\>", "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[
    \(ntr = AddNode[tr, {a, b}, {x}, {1.2}]\)], "Input",
  CellLabel->"In[304]:="],

Cell[BoxData[
    RowBox[{"Node", "[", 
      RowBox[{\({a, b, c, d, e, f, g, h}\), ",", 
        RowBox[{"{", 
          StyleBox["2.29999999999999982`",
            StyleBoxAutoDelete->True,
            PrintPrecision->2], "}"}], ",", 
        RowBox[{"{", 
          RowBox[{
            RowBox[{"Node", "[", 
              RowBox[{\({x}\), ",", 
                RowBox[{"{", 
                  StyleBox["1.19999999999999996`",
                    StyleBoxAutoDelete->True,
                    PrintPrecision->2], "}"}], ",", 
                RowBox[{"{", 
                  RowBox[{"Node", "[", 
                    RowBox[{\({a, b}\), ",", 
                      RowBox[{"{", 
                        StyleBox["0.4`",
                          StyleBoxAutoDelete->True,
                          PrintPrecision->1], "}"}], ",", 
                      \({Node[{a}, {0}, {}], Node[{b}, {0}, {}]}\)}], "]"}], 
                  "}"}]}], "]"}], ",", 
            RowBox[{"Node", "[", 
              RowBox[{\({c, d, e, f, g, h}\), ",", 
                RowBox[{"{", 
                  StyleBox["1.8`",
                    StyleBoxAutoDelete->True,
                    PrintPrecision->2], "}"}], ",", 
                RowBox[{"{", 
                  RowBox[{
                  \(Node[{c, d}, {1}, {Node[{c}, {0}, {}], 
                        Node[{d}, {0}, {}]}]\), ",", 
                    RowBox[{"Node", "[", 
                      RowBox[{\({e, f, g, h}\), ",", 
                        RowBox[{"{", 
                          StyleBox["1.7`",
                            StyleBoxAutoDelete->True,
                            PrintPrecision->2], "}"}], ",", 
                        RowBox[{"{", 
                          RowBox[{
                            RowBox[{"Node", "[", 
                              RowBox[{\({e, f, g}\), ",", 
                                RowBox[{"{", 
                                  StyleBox["1.5`",
                                    StyleBoxAutoDelete->True,
                                    PrintPrecision->2], "}"}], ",", 
                                \({Node[{e}, {0}, {}], Node[{f}, {0}, {}], 
                                  Node[{g}, {0}, {}]}\)}], "]"}], ",", 
                            \(Node[{h}, {0}, {}]\)}], "}"}]}], "]"}]}], 
                  "}"}]}], "]"}]}], "}"}]}], "]"}]], "Output",
  CellLabel->"Out[304]="]
}, Closed]],

Cell["\<\
The new node is superfluous, and so is removed  by \
CondenseGenealogy[]:\
\>", "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[
    \(tr === CondenseGenealogy[ntr]\)], "Input",
  CellLabel->"In[303]:="],

Cell[BoxData[
    \(True\)], "Output",
  CellLabel->"Out[303]="]
}, Closed]],

Cell["\<\
This adds a node labelled {x} between existing nodes {e,f,g} and \
{e,f,g,h} of an unrooted genealogy:\
\>", "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[
    \(ntr = 
      AddNode[utr, {e, f, g}, {e, f, g, h}, {x}, {1.2}] // TableForm\)], 
  "Input",
  CellLabel->"In[309]:="],

Cell[BoxData[
    InterpretationBox[GridBox[{
          {\(Node[{a}, {0}, {{a, b}}]\)},
          {\(Node[{b}, {0}, {{a, b}}]\)},
          {\(Node[{c}, {0}, {{c, d}}]\)},
          {\(Node[{d}, {0}, {{c, d}}]\)},
          {\(Node[{e}, {0}, {{e, f, g}}]\)},
          {\(Node[{f}, {0}, {{e, f, g}}]\)},
          {\(Node[{g}, {0}, {{e, f, g}}]\)},
          {\(Node[{h}, {0}, {{e, f, g, h}}]\)},
          {
            RowBox[{"Node", "[", 
              RowBox[{\({a, b}\), ",", 
                RowBox[{"{", 
                  StyleBox["0.4`",
                    StyleBoxAutoDelete->True,
                    PrintPrecision->1], "}"}], ",", 
                \({{a}, {b}, {a, b, c, d, e, f, g, h}}\)}], "]"}]},
          {\(Node[{c, d}, {1}, {{c}, {d}, {c, d, e, f, g, h}}]\)},
          {
            RowBox[{"Node", "[", 
              RowBox[{\({e, f, g}\), ",", 
                RowBox[{"{", 
                  StyleBox["1.5`",
                    StyleBoxAutoDelete->True,
                    PrintPrecision->2], "}"}], ",", 
                \({{e}, {f}, {g}, {e, f, g, h}}\)}], "]"}]},
          {
            RowBox[{"Node", "[", 
              RowBox[{\({e, f, g, h}\), ",", 
                RowBox[{"{", 
                  StyleBox["1.7`",
                    StyleBoxAutoDelete->True,
                    PrintPrecision->2], "}"}], ",", 
                \({{e, f, g}, {h}, {c, d, e, f, g, h}}\)}], "]"}]},
          {
            RowBox[{"Node", "[", 
              RowBox[{\({c, d, e, f, g, h}\), ",", 
                RowBox[{"{", 
                  StyleBox["1.8`",
                    StyleBoxAutoDelete->True,
                    PrintPrecision->2], "}"}], ",", 
                \({{c, d}, {e, f, g, h}, {a, b, c, d, e, f, g, h}}\)}], 
              "]"}]},
          {
            RowBox[{"Node", "[", 
              RowBox[{\({a, b, c, d, e, f, g, h}\), ",", 
                RowBox[{"{", 
                  StyleBox["2.29999999999999982`",
                    StyleBoxAutoDelete->True,
                    PrintPrecision->2], "}"}], ",", 
                \({{a, b}, {c, d, e, f, g, h}}\)}], "]"}]},
          {
            RowBox[{"Node", "[", 
              RowBox[{\({x}\), ",", 
                RowBox[{"{", 
                  StyleBox["1.19999999999999996`",
                    StyleBoxAutoDelete->True,
                    PrintPrecision->2], "}"}], ",", 
                \({{e, f, g}, {e, f, g, h}}\)}], "]"}]}
          },
        RowSpacings->1,
        ColumnSpacings->3,
        RowAlignments->Baseline,
        ColumnAlignments->{Left}],
      TableForm[ {
        Node[ {a}, {0}, {{a, b}}], 
        Node[ {b}, {0}, {{a, b}}], 
        Node[ {c}, {0}, {{c, d}}], 
        Node[ {d}, {0}, {{c, d}}], 
        Node[ {e}, {0}, {{e, f, g}}], 
        Node[ {f}, {0}, {{e, f, g}}], 
        Node[ {g}, {0}, {{e, f, g}}], 
        Node[ {h}, {0}, {{e, f, g, h}}], 
        Node[ {a, b}, {0.40000000000000002}, {{a}, {b}, {a, b, c, d, e, f, g, 
          h}}], 
        Node[ {c, d}, {1}, {{c}, {d}, {c, d, e, f, g, h}}], 
        Node[ {e, f, g}, {1.5}, {{e}, {f}, {g}, {e, f, g, h}}], 
        Node[ {e, f, g, h}, {1.7}, {{e, f, g}, {h}, {c, d, e, f, g, h}}], 
        Node[ {c, d, e, f, g, h}, {1.8}, {{c, d}, {e, f, g, h}, {a, b, c, d, 
          e, f, g, h}}], 
        Node[ {a, b, c, d, e, f, g, h}, {2.2999999999999998}, {{a, b}, {c, d, 
          e, f, g, h}}], 
        Node[ {x}, {1.2}, {{e, f, g}, {e, f, g, h}}]}]]], "Output",
  CellLabel->"Out[309]//TableForm="]
}, Closed]],

Cell["\<\
This returns meaningless results if the specified nodes are not \
adjacent.\
\>", "Text"],

Cell[TextData[Cell[BoxData[
    FormBox[GridBox[{
          {
            FormBox[
              RowBox[{"AddMutation", "[", 
                RowBox[{
                  StyleBox["n",
                    FontSlant->"Italic"], ",", 
                  StyleBox["m",
                    FontSlant->"Italic"], ",", "g"}], "]"}],
              "TraditionalForm"], \(adds\ the\ mutations\ m\ to\ node\ n; \ 
            m\ can\ be\ one\ mutation, \ 
            or\ a\ list\ of\ \(\(mutations\)\(.\)\)\)},
          {
            RowBox[{"AddMutation", "[", 
              RowBox[{
                RowBox[{"{", 
                  RowBox[{
                    SubscriptBox[
                      StyleBox["n",
                        FontSlant->"Italic"], "1"], ",", "\[Ellipsis]"}], 
                  "}"}], ",", \({m\_1, \[Ellipsis]}\), ",", "g"}], 
              "]"}], \(adds\ mutations\ to\ several\ nodes\)}
          }], TraditionalForm]]]], "DefinitionBox",
  CellTags->"AddMutation"],

Cell["\<\
Typically, the first entry in the information list represents the \
time of coalescence, and the second entry represents a list of mutations \
carried at each node. \
\>", "Text"],

Cell["\<\
This sets up a simple genealogy with no mutations ({}) at any node:\
\
\>", "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(g = 
        Node[abc, {3.1, {}}, {Node[
              ab, {2.2, {}}, {Node[a, {0, {}}, {}], Node[b, {0, {}}, {}]}], 
            Node[c, {0, {}}, {}]}];\)\), "\n", 
    \(\(Show[PlotGenealogy[g]];\)\)}], "Input",
  CellLabel->"In[23]:="],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.25 0.25 0.154508 0.154508 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
0 g
.5 Mabswid
[ ] 0 setdash
.375 .30902 m
.25 .15451 L
s
.375 .30902 m
.5 .15451 L
s
.5 .46353 m
.375 .30902 L
s
.5 .46353 m
.75 .15451 L
s
gsave
.325 .33992 -69 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(ab) show
1.000 setlinewidth
grestore
gsave
.45 .49443 -72 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(abc) show
1.000 setlinewidth
grestore
gsave
.25 .12361 -66 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(a) show
1.000 setlinewidth
grestore
gsave
.5 .12361 -66 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(b) show
1.000 setlinewidth
grestore
gsave
.75 .12361 -66 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(c) show
1.000 setlinewidth
grestore
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[24]:=",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/B000`400?l00000o`00003oo`3ooolQ
0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ
0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ
0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ
0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ
0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ
0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ
0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00A@3oool4000004<0oooo100000150?ooo`<00000
B03oool004@0oooo00@000000?ooo`3oool00000A@3oool010000000oooo0?ooo`0000130?ooo`05
0000003oool0oooo0?ooo`000000A`3oool004D0oooo0`0000150?ooo`040000003oool0oooo0000
04<0oooo00<000000?ooo`3oool0B@3oool004@0oooo00@000000?ooo`3oool00000A@3oool01000
0000oooo0?ooo`0000130?ooo`050000003oool0oooo0?ooo`000000A`3oool004D0oooo0P000016
0?ooo`<00000A@3oool3000004P0oooo002=0?ooo`030000003oool0oooo0900oooo002<0?ooo`80
0000TP3oool00?l0oooo8@3oool00?l0oooo8@3oool00?l0oooo8@3oool00?l0oooo8@3oool004L0
oooo00<000000?ooo`3oool0A@3oool00`000000oooo0?ooo`150?ooo`030000003oool0oooo04H0
oooo00170?ooo`030000003oool0oooo04D0oooo00<000000?ooo`3oool0A@3oool00`000000oooo
0?ooo`160?ooo`00B03oool00`000000oooo0?ooo`130?ooo`030000003oool0oooo04D0oooo00<0
00000?ooo`3oool0A`3oool004T0oooo00<000000?ooo`3oool0@@3oool00`000000oooo0?ooo`15
0?ooo`030000003oool0oooo04P0oooo001:0?ooo`030000003oool0oooo03l0oooo00<000000?oo
o`3oool0A@3oool00`000000oooo0?ooo`190?ooo`00B`3oool00`000000oooo0?ooo`0m0?ooo`03
0000003oool0oooo04D0oooo00<000000?ooo`3oool0BP3oool004`0oooo00<000000?ooo`3oool0
>`3oool00`000000oooo0?ooo`150?ooo`030000003oool0oooo04/0oooo001<0?ooo`030000003o
ool0oooo03/0oooo00<000000?ooo`3oool0A@3oool00`000000oooo0?ooo`1;0?ooo`00C@3oool0
0`000000oooo0?ooo`0i0?ooo`030000003oool0oooo04D0oooo00<000000?ooo`3oool0C03oool0
04h0oooo00<000000?ooo`3oool0=`3oool00`000000oooo0?ooo`150?ooo`030000003oool0oooo
04d0oooo001?0?ooo`030000003oool0oooo03D0oooo00<000000?ooo`3oool0A@3oool00`000000
oooo0?ooo`1>0?ooo`00D03oool00`000000oooo0?ooo`0c0?ooo`030000003oool0oooo04D0oooo
00<000000?ooo`3oool0C`3oool00500oooo00<000000?ooo`3oool0<`3oool00`000000oooo0?oo
o`150?ooo`030000003oool0oooo04l0oooo001A0?ooo`030000003oool0oooo0340oooo00<00000
0?ooo`3oool0A@3oool00`000000oooo0?ooo`1@0?ooo`00DP3oool00`000000oooo0?ooo`0_0?oo
o`030000003oool0oooo04D0oooo00<000000?ooo`3oool0D@3oool005<0oooo00<000000?ooo`3o
ool0;@3oool00`000000oooo0?ooo`150?ooo`030000003oool0oooo0580oooo001D0?ooo`030000
003oool0oooo02/0oooo00<000000?ooo`3oool0A@3oool00`000000oooo0?ooo`1C0?ooo`00E@3o
ool00`000000oooo0?ooo`0Y0?ooo`030000003oool0oooo04D0oooo00<000000?ooo`3oool0E03o
ool005D0oooo00<000000?ooo`3oool0:@3oool00`000000oooo0?ooo`150?ooo`030000003oool0
oooo05@0oooo001F0?ooo`030000003oool0oooo02L0oooo00<000000?ooo`3oool0A@3oool00`00
0000oooo0?ooo`1E0?ooo`00E`3oool00`000000oooo0?ooo`0U0?ooo`030000003oool0oooo04D0
oooo00<000000?ooo`3oool0EP3oool005P0oooo00<000000?ooo`3oool08`3oool00`000000oooo
0?ooo`150?ooo`030000003oool0oooo05L0oooo001I0?ooo`030000003oool0oooo0240oooo00<0
00000?ooo`3oool0A@3oool00`000000oooo0?ooo`1H0?ooo`00F@3oool00`000000oooo0?ooo`0Q
0?ooo`030000003oool0oooo04D0oooo00<000000?ooo`3oool0F03oool005X0oooo00<000000?oo
o`3oool07`3oool00`000000oooo0?ooo`150?ooo`030000003oool0oooo05T0oooo001K0?ooo`03
0000003oool0oooo01d0oooo00<000000?ooo`3oool0A@3oool00`000000oooo0?ooo`1J0?ooo`00
G03oool00`000000oooo0?ooo`0K0?ooo`030000003oool0oooo04D0oooo00<000000?ooo`3oool0
F`3oool005d0oooo00<000000?ooo`3oool06@3oool00`000000oooo0?ooo`150?ooo`030000003o
ool0oooo05`0oooo001N0?ooo`030000003oool0oooo01L0oooo00<000000?ooo`3oool0A@3oool0
0`000000oooo0?ooo`1M0?ooo`00GP3oool00`000000oooo0?ooo`0G0?ooo`030000003oool0oooo
04D0oooo00<000000?ooo`3oool0G@3oool005l0oooo00<000000?ooo`3oool05@3oool00`000000
oooo0?ooo`150?ooo`030000003oool0oooo05h0oooo001P0?ooo`030000003oool0oooo01<0oooo
00<000000?ooo`3oool0A@3oool00`000000oooo0?ooo`1O0?ooo`00H@3oool00`000000oooo0?oo
o`0A0?ooo`030000003oool0oooo04D0oooo00<000000?ooo`3oool0H03oool00680oooo00<00000
0?ooo`3oool03`3oool00`000000oooo0?ooo`150?ooo`030000003oool0oooo0640oooo001R0?oo
o`030000003oool0oooo00l0oooo00<000000?ooo`3oool0A@3oool00`000000oooo0?ooo`1Q0?oo
o`00H`3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo04D0oooo00<000000?ooo`3o
ool0HP3oool006@0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`150?ooo`030000
003oool0oooo06<0oooo001U0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool0A@3o
ool00`000000oooo0?ooo`1T0?ooo`00IP3oool00`000000oooo0?ooo`070?ooo`030000003oool0
oooo04D0oooo00<000000?ooo`3oool0I@3oool006L0oooo00<000000?ooo`3oool01@3oool00`00
0000oooo0?ooo`150?ooo`030000003oool0oooo06H0oooo001W0?ooo`030000003oool0oooo00D0
oooo00<000000?ooo`3oool0A@3oool00`000000oooo0?ooo`1V0?ooo`00J03oool00`000000oooo
0?ooo`030?ooo`030000003oool0oooo04D0oooo00<000000?ooo`3oool0I`3oool006T0oooo00D0
00000?ooo`3oool0oooo000000170?ooo`030000003oool0oooo06P0oooo001Z0?ooo`030000003o
ool0000004L0oooo00<000000?ooo`3oool0J@3oool006/0oooo00<000000?ooo`3oool0A@3oool0
0`000000oooo0?ooo`1Z0?ooo`00J`3oool00`000000oooo0?ooo`150?ooo`030000003oool0oooo
06X0oooo001/0?ooo`030000003oool0oooo04<0oooo00<000000?ooo`3oool0J`3oool006d0oooo
00<000000?ooo`3oool0@@3oool00`000000oooo0?ooo`1/0?ooo`00KP3oool00`000000oooo0?oo
o`0o0?ooo`030000003oool0oooo06d0oooo001_0?ooo`030000003oool0oooo03d0oooo00<00000
0?ooo`3oool0KP3oool00700oooo00<000000?ooo`3oool0>`3oool00`000000oooo0?ooo`1_0?oo
o`00F03oool4000000030?ooo`0000000000008000003`3oool00`000000oooo0?ooo`0k0?ooo`03
0000003oool0oooo06l0oooo001G0?ooo`040000003oool0oooo000000<0oooo00@000000?ooo`3o
ool000003`3oool00`000000oooo0?ooo`0i0?ooo`030000003oool0oooo0700oooo001H0?ooo`<0
00000`3oool010000000oooo0?ooo`00000@0?ooo`030000003oool0oooo03L0oooo00<000000?oo
o`3oool0L@3oool005L0oooo00@000000?ooo`3oool000000`3oool010000000oooo0?ooo`00000A
0?ooo`030000003oool0oooo03D0oooo00<000000?ooo`3oool0LP3oool005P0oooo0P0000040?oo
o`<000004`3oool00`000000oooo0?ooo`0c0?ooo`030000003oool0oooo07<0oooo001N0?ooo`03
0000003oool0oooo01<0oooo00<000000?ooo`3oool0<`3oool00`000000oooo0?ooo`1c0?ooo`00
G@3oool2000001H0oooo00<000000?ooo`3oool0<@3oool00`000000oooo0?ooo`1d0?ooo`00MP3o
ool00`000000oooo0?ooo`0_0?ooo`030000003oool0oooo07D0oooo001g0?ooo`030000003oool0
oooo02d0oooo00<000000?ooo`3oool0MP3oool007P0oooo00<000000?ooo`3oool0:`3oool00`00
0000oooo0?ooo`1g0?ooo`00N@3oool00`000000oooo0?ooo`0Y0?ooo`030000003oool0oooo07P0
oooo001i0?ooo`030000003oool0oooo02T0oooo00<000000?ooo`3oool0N03oool007X0oooo00<0
00000?ooo`3oool09`3oool00`000000oooo0?ooo`1i0?ooo`00N`3oool00`000000oooo0?ooo`0U
0?ooo`030000003oool0oooo07X0oooo001l0?ooo`030000003oool0oooo02<0oooo00<000000?oo
o`3oool0N`3oool007d0oooo00<000000?ooo`3oool08@3oool00`000000oooo0?ooo`1l0?ooo`00
O@3oool00`000000oooo0?ooo`0Q0?ooo`030000003oool0oooo07`0oooo001n0?ooo`030000003o
ool0oooo01l0oooo00<000000?ooo`3oool0O@3oool007l0oooo00<000000?ooo`3oool07@3oool0
0`000000oooo0?ooo`1n0?ooo`00P03oool00`000000oooo0?ooo`0K0?ooo`030000003oool0oooo
07l0oooo00210?ooo`030000003oool0oooo01T0oooo00<000000?ooo`3oool0P03oool00880oooo
00<000000?ooo`3oool05`3oool00`000000oooo0?ooo`210?ooo`00PP3oool00`000000oooo0?oo
o`0G0?ooo`030000003oool0oooo0840oooo00230?ooo`030000003oool0oooo01D0oooo00<00000
0?ooo`3oool0PP3oool008@0oooo00<000000?ooo`3oool04`3oool00`000000oooo0?ooo`230?oo
o`00Q@3oool00`000000oooo0?ooo`0A0?ooo`030000003oool0oooo08@0oooo00260?ooo`030000
003oool0oooo00l0oooo00<000000?ooo`3oool0Q@3oool008H0oooo00<000000?ooo`3oool03`3o
ool00`000000oooo0?ooo`250?ooo`00Q`3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0
oooo08H0oooo00280?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool0Q`3oool008T0
oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`280?ooo`00RP3oool00`000000oooo
0?ooo`070?ooo`030000003oool0oooo08T0oooo002;0?ooo`030000003oool0oooo00D0oooo00<0
00000?ooo`3oool0RP3oool008/0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`2:
0?ooo`00S03oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo08/0oooo002=0?ooo`05
0000003oool0oooo0?ooo`000000SP3oool008h0oooo00<000000?ooo`000000S`3oool008l0oooo
00<000000?ooo`3oool0SP3oool00?l0oooo8@3oool00?l0oooo8@3oool00?l0oooo8@3oool00?l0
oooo8@3oool00?l0oooo8@3oool00?l0oooo8@3oool007T0oooo100000000`3oool0000000000002
000000<0oooo0`00002H0?ooo`00N03oool010000000oooo0?ooo`0000030?ooo`060000003oool0
oooo0000003oool000000`3oool00`000000oooo0?ooo`2E0?ooo`00N@3oool3000000<0oooo00H0
00000?ooo`3oool000000?ooo`00002K0?ooo`00N03oool010000000oooo0?ooo`0000030?ooo`06
0000003oool0oooo0000003oool000000`3oool00`000000oooo0?ooo`2E0?ooo`00N@3oool20000
00@0oooo0`0000030?ooo`<00000V03oool007l0oooo00<000000?ooo`3oool0WP3oool007h0oooo
0P00002P0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00
o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00
o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00
o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00
o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00
o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00
o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-1.00496, -1.00002, \
0.0139719, 0.022607}}]
}, Open  ]],

Cell[TextData[{
  "This adds mutations ",
  Cell[BoxData[
      \(TraditionalForm\`m\_1, \ m\_2\)]],
  " to node ",
  Cell[BoxData[
      \(TraditionalForm\`a\)]],
  ":"
}], "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[
    \(AddMutation[a, {m\_1, m\_2}, g]\)], "Input",
  CellLabel->"In[25]:="],

Cell[BoxData[
    \(Node[
      abc, {3.1`, {}}, {Node[
          ab, {2.2`, {}}, {Node[a, {0, {m\_1, m\_2}}, {}], 
            Node[b, {0, {}}, {}]}], Node[c, {0, {}}, {}]}]\)], "Output",
  CellLabel->"Out[25]="]
}, Open  ]],

Cell["This adds mutations to several nodes:", "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[
    \(AddMutation[{a, b, ab}, {{m\_1, m\_2}, {m\_2, m\_3}, {m\_2}}, 
      g]\)], "Input",
  CellLabel->"In[26]:="],

Cell[BoxData[
    \(Node[
      abc, {3.1`, {}}, {Node[
          ab, {2.2`, {m\_2}}, {Node[a, {0, {m\_1, m\_2}}, {}], 
            Node[b, {0, {m\_2, m\_3}}, {}]}], 
        Node[c, {0, {}}, {}]}]\)], "Output",
  CellLabel->"Out[26]="]
}, Open  ]],

Cell[TextData[Cell[BoxData[
    FormBox[GridBox[{
          {\(CondenseGenealogy[
              g]\), \(removes\ all\ nodes\ in\ a\ rooted\ genealogy\ that\ \
have\ only\ one\ descendant, \ except\ the\ first\)}
          }], TraditionalForm]]]], "DefinitionBox",
  CellTags->"CondenseGenealogy"],

Cell[TextData[{
  Cell[BoxData[
      \(TraditionalForm\`CondenseGenealogy[g]\)]],
  " prunes out superfluous nodes which have only one descendant.  Information \
associated with these nodes is lost.  "
}], "Text"],

Cell[TextData[{
  "This genealogy has a superfluous node ",
  Cell[BoxData[
      \(TraditionalForm\`{x}\)]],
  " that descends only to the terminal node ",
  Cell[BoxData[
      \(TraditionalForm\`{c}\)]],
  ".  It is removed by CondenseGenealogy[]:"
}], "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[
    \(tr4 = 
      Node[{a, b, c, d}, {}, {
          Node[{a, b}, {}, {Node[{a}, {}, {}], Node[{b}, {}, {}]}], 
          Node[{c, d}, {}, {Node[{x}, {}, {Node[{c}, {}, {}]}], 
              Node[{d}, {}, {}]}]}]; \nCondenseGenealogy[tr4]\)], "Input",
  CellLabel->"In[460]:="],

Cell[BoxData[
    \(Node[{a, b, c, d}, {}, {
        Node[{a, b}, {}, {Node[{a}, {}, {}], Node[{b}, {}, {}]}], 
        Node[{c, d}, {}, {Node[{c}, {}, {}], Node[{d}, {}, {}]}]}]\)], 
  "Output",
  CellLabel->"Out[461]="]
}, Closed]],

Cell["\<\
Note that CondenseGenealogy[] does not remove the root of a \
genealogy if that leads to only one descendant node.  The previous example \
gave such a genealogy in which the root node {a,b,c,d,e,f,g,h} has only a \
single descendant node, {x}.  This is not affected by \
CondenseGenealogy[]:\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(CondenseGenealogy[tr3]\)], "Input",
  CellLabel->"In[462]:="],

Cell[BoxData[
    RowBox[{"Node", "[", 
      RowBox[{\({a, b, c, d, e, f, g, h}\), ",", 
        RowBox[{"{", 
          StyleBox["2.29999999999999982`",
            StyleBoxAutoDelete->True,
            PrintPrecision->2], "}"}], ",", 
        RowBox[{"{", 
          RowBox[{"Node", "[", 
            RowBox[{\({x}\), ",", 
              RowBox[{"{", 
                StyleBox["2.10000000000000008`",
                  StyleBoxAutoDelete->True,
                  PrintPrecision->2], "}"}], ",", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{"Node", "[", 
                    RowBox[{\({a, b}\), ",", 
                      RowBox[{"{", 
                        StyleBox["0.4`",
                          StyleBoxAutoDelete->True,
                          PrintPrecision->1], "}"}], ",", 
                      \({Node[{a}, {0}, {}], Node[{b}, {0}, {}]}\)}], "]"}], 
                  ",", 
                  RowBox[{"Node", "[", 
                    RowBox[{\({c, d, e, f, g, h}\), ",", 
                      RowBox[{"{", 
                        StyleBox["1.8`",
                          StyleBoxAutoDelete->True,
                          PrintPrecision->2], "}"}], ",", 
                      RowBox[{"{", 
                        RowBox[{
                        \(Node[{c, d}, {1}, {Node[{c}, {0}, {}], 
                              Node[{d}, {0}, {}]}]\), ",", 
                          RowBox[{"Node", "[", 
                            RowBox[{\({e, f, g, h}\), ",", 
                              RowBox[{"{", 
                                StyleBox["1.7`",
                                  StyleBoxAutoDelete->True,
                                  PrintPrecision->2], "}"}], ",", 
                              RowBox[{"{", 
                                RowBox[{
                                  RowBox[{"Node", "[", 
                                    RowBox[{\({e, f, g}\), ",", 
                                      RowBox[{"{", 
                                        StyleBox["1.5`",
                                        StyleBoxAutoDelete->True,
                                        PrintPrecision->2], "}"}], ",", 
                                      \({Node[{e}, {0}, {}], 
                                        Node[{f}, {0}, {}], 
                                        Node[{g}, {0}, {}]}\)}], "]"}], ",", 
                                  \(Node[{h}, {0}, {}]\)}], "}"}]}], "]"}]}], 
                        "}"}]}], "]"}]}], "}"}]}], "]"}], "}"}]}], "]"}]], 
  "Output",
  CellLabel->"Out[462]="]
}, Closed]]
}, Open  ]]
},
FrontEndVersion->"4.0 for Macintosh",
ScreenRectangle->{{0, 1152}, {0, 748}},
WindowSize->{1084, 721},
WindowMargins->{{-2, Automatic}, {Automatic, 1}},
StyleDefinitions -> "HelpBrowser.nb",
MacintoshSystemPageSetup->"\<\
00`0001804P000000_02@?o/onh3109BI085:0?l0@00005X0FP000003[0;@001
0000I00100000@0000000BL?0040000000000000000000000000000000000?nL
ojH?50^J00P100000000000000000000\>"
]


(***********************************************************************
Cached data follows.  If you edit this Notebook file directly, not using
Mathematica, you must remove the line containing CacheID at the top of 
the file.  The cache data will then be recreated when you save this file 
from within Mathematica.
***********************************************************************)

(*CellTagsOutline
CellTagsIndex->{
  "ExtractGenealogy"->{
    Cell[1792, 53, 410, 9, 56, "DefinitionBox",
      CellTags->{"ExtractGenealogy", "DeleteGenealogy"}]},
  "DeleteGenealogy"->{
    Cell[1792, 53, 410, 9, 56, "DefinitionBox",
      CellTags->{"ExtractGenealogy", "DeleteGenealogy"}]},
  "AddGenealogy"->{
    Cell[4553, 136, 1359, 29, 92, "DefinitionBox",
      CellTags->"AddGenealogy"]},
  "AddNode"->{
    Cell[14981, 396, 783, 18, 56, "DefinitionBox",
      CellTags->"AddNode"]},
  "AddMutation"->{
    Cell[22626, 603, 985, 24, 56, "DefinitionBox",
      CellTags->"AddMutation"]},
  "CondenseGenealogy"->{
    Cell[38358, 1013, 296, 6, 37, "DefinitionBox",
      CellTags->"CondenseGenealogy"]}
  }
*)

(*CellTagsIndex
CellTagsIndex->{
  {"ExtractGenealogy", 43576, 1149},
  {"DeleteGenealogy", 43706, 1152},
  {"AddGenealogy", 43833, 1155},
  {"AddNode", 43933, 1158},
  {"AddMutation", 44032, 1161},
  {"CondenseGenealogy", 44141, 1164}
  }
*)

(*NotebookFileOutline
Notebook[{

Cell[CellGroupData[{
Cell[1739, 51, 50, 0, 36, "SubsectionIcon"],
Cell[1792, 53, 410, 9, 56, "DefinitionBox",
  CellTags->{"ExtractGenealogy", "DeleteGenealogy"}],
Cell[2205, 64, 112, 3, 28, "MathCaption"],

Cell[CellGroupData[{
Cell[2342, 71, 105, 2, 26, "Input"],
Cell[2450, 75, 1196, 29, 35, "Output"]
}, Closed]],
Cell[3661, 107, 63, 0, 18, "MathCaption"],

Cell[CellGroupData[{
Cell[3749, 111, 104, 2, 26, "Input"],
Cell[3856, 115, 614, 16, 20, "Output"]
}, Closed]],
Cell[4485, 134, 65, 0, 18, "Text"],
Cell[4553, 136, 1359, 29, 92, "DefinitionBox",
  CellTags->"AddGenealogy"],
Cell[5915, 167, 141, 3, 28, "MathCaption"],

Cell[CellGroupData[{
Cell[6081, 174, 107, 2, 26, "Input"],
Cell[6191, 178, 2584, 54, 65, "Output"]
}, Closed]],
Cell[8790, 235, 79, 0, 18, "MathCaption"],

Cell[CellGroupData[{
Cell[8894, 239, 103, 2, 26, "Input"],
Cell[9000, 243, 2270, 47, 65, "Output"]
}, Closed]],
Cell[11285, 293, 100, 3, 18, "MathCaption"],

Cell[CellGroupData[{
Cell[11410, 300, 181, 3, 42, "Input"],
Cell[11594, 305, 3018, 72, 238, "Output"]
}, Closed]],
Cell[14627, 380, 351, 14, 18, "Text"],
Cell[14981, 396, 783, 18, 56, "DefinitionBox",
  CellTags->"AddNode"],
Cell[15767, 416, 118, 3, 28, "MathCaption"],

Cell[CellGroupData[{
Cell[15910, 423, 96, 2, 26, "Input"],
Cell[16009, 427, 2384, 52, 80, "Output"]
}, Closed]],
Cell[18408, 482, 104, 3, 18, "MathCaption"],

Cell[CellGroupData[{
Cell[18537, 489, 88, 2, 26, "Input"],
Cell[18628, 493, 64, 2, 20, "Output"]
}, Closed]],
Cell[18707, 498, 133, 3, 18, "MathCaption"],

Cell[CellGroupData[{
Cell[18865, 505, 137, 4, 26, "Input"],
Cell[19005, 511, 3504, 84, 254, "Output"]
}, Closed]],
Cell[22524, 598, 99, 3, 18, "Text"],
Cell[22626, 603, 985, 24, 56, "DefinitionBox",
  CellTags->"AddMutation"],
Cell[23614, 629, 189, 4, 22, "Text"],
Cell[23806, 635, 100, 3, 28, "MathCaption"],

Cell[CellGroupData[{
Cell[23931, 642, 261, 6, 42, "Input"],
Cell[24195, 650, 13147, 318, 184, 3692, 196, "GraphicsData", "PostScript", \
"Graphics"]
}, Open  ]],
Cell[37357, 971, 188, 8, 28, "MathCaption"],

Cell[CellGroupData[{
Cell[37570, 983, 89, 2, 26, "Input"],
Cell[37662, 987, 213, 5, 20, "Output"]
}, Open  ]],
Cell[37890, 995, 60, 0, 28, "MathCaption"],

Cell[CellGroupData[{
Cell[37975, 999, 129, 3, 26, "Input"],
Cell[38107, 1004, 236, 6, 20, "Output"]
}, Open  ]],
Cell[38358, 1013, 296, 6, 37, "DefinitionBox",
  CellTags->"CondenseGenealogy"],
Cell[38657, 1021, 214, 5, 22, "Text"],
Cell[38874, 1028, 270, 8, 28, "MathCaption"],

Cell[CellGroupData[{
Cell[39169, 1040, 292, 6, 74, "Input"],
Cell[39464, 1048, 221, 5, 35, "Output"]
}, Closed]],
Cell[39700, 1056, 315, 6, 32, "Text"],

Cell[CellGroupData[{
Cell[40040, 1066, 81, 2, 26, "Input"],
Cell[40124, 1070, 2584, 54, 65, "Output"]
}, Closed]]
}, Open  ]]
}
]
*)




(***********************************************************************
End of Mathematica Notebook file.
***********************************************************************)

