(***********************************************************************

                    Mathematica-Compatible Notebook

This notebook can be used on any computer system with Mathematica 4.0,
MathReader 4.0, or any compatible application. The data for the notebook 
starts with the line containing stars above.

To get the notebook into a Mathematica-compatible application, do one of 
the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing the 
word CacheID, otherwise Mathematica-compatible applications may try to 
use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
***********************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[      5219,        158]*)
(*NotebookOutlinePosition[      6250,        192]*)
(*  CellTagsIndexPosition[      6170,        186]*)
(*WindowFrame->Normal*)



Notebook[{

Cell[CellGroupData[{
Cell["Describing ordered genealogies", "SubsectionIcon"],

Cell[TextData[Cell[BoxData[
    FormBox[GridBox[{
          {
            RowBox[{"IncidenceMatrix", "[", 
              RowBox[{"g", ",", 
                StyleBox["nodelist",
                  FontSlant->"Italic"]}], "]"}], 
            RowBox[{
              RowBox[{
                RowBox[{
                "gives", " ", "the", " ", "matrix", " ", "describing", " ", 
                  "an", " ", "ordering", " ", "of", " ", "coalescences", " ", 
                  "defined", " ", "by", " ", 
                  RowBox[{
                    StyleBox["nodelist",
                      FontSlant->"Italic"], ".", "  ", "The"}], " ", 
                  "elements", " ", "of", " ", "the", " ", "matrix", " ", 
                  "show", " ", "whether", " ", "a", " ", "branch", " ", "is", 
                  " ", "present", " ", "during", " ", "the", " ", "time", " ",
                   "for", " ", "which", " ", "there", " ", "are", " ", "1"}], 
                "\[LessEqual]", "i", 
                "\[LessEqual]", \(n\ lineages . \ 
                    Rows\ correspond\ to\ branches\)}], ",", " ", 
              RowBox[{
              "in", " ", "the", " ", "order", " ", "specified", " ", "by", 
                " ", 
                RowBox[{
                  StyleBox["nodelist",
                    FontSlant->"Italic"], "."}]}], " "}]}
          }], TraditionalForm]]]], "DefinitionBox",
  CellTags->"IncidenceMatrix"],

Cell["This loads the package:", "MathCaption"],

Cell[BoxData[
    \(\(<< Genealogies`Genealogies`;\)\)], "Input",
  CellLabel->"In[679]:="],

Cell["Here is a genealogy conecting four lineages:", "MathCaption"],

Cell[BoxData[
    \(\(gg = 
        Node[abcd, {}, {Node[ab, {}, {Node[a, {}, {}], Node[b, {}, {}]}], 
            Node[cd, {}, {Node[c, {}, {}], Node[d, {}, {}]}]}];\)\)], "Input",\

  CellLabel->"In[511]:="],

Cell[TextData[{
  "The list of nodes specifies that ",
  StyleBox["{a,b}",
    FontSlant->"Italic"],
  " coalesce in node ",
  StyleBox["ab",
    FontSlant->"Italic"],
  " before ",
  StyleBox["{c, d}",
    FontSlant->"Italic"],
  "coalesce in node ",
  StyleBox["cd",
    FontSlant->"Italic"],
  ".  The leaves ",
  StyleBox["must",
    FontWeight->"Bold"],
  " be listed first, and the root node last:"
}], "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[
    \(IncidenceMatrix[gg, {a, b, c, d, ab, cd, abcd}] // MatrixForm\)], 
  "Input",
  CellLabel->"In[514]:="],

Cell[BoxData[
    TagBox[
      RowBox[{"(", GridBox[{
            {"0", "0", "0", "1"},
            {"0", "0", "0", "1"},
            {"0", "0", "1", "1"},
            {"0", "0", "1", "1"},
            {"0", "1", "1", "0"},
            {"0", "1", "0", "0"},
            {"1", "0", "0", "0"}
            }], ")"}],
      (MatrixForm[ #]&)]], "Output",
  CellLabel->"Out[514]//MatrixForm="]
}, Open  ]],

Cell["\<\
The first column indicates that only the root node, abcd, is \
present when there is one lineage; the next column indicates that {cd,ab} are \
present while there are two lineages; the next, that {c, d, ab} are present \
while there are three lineages; and the last column, that the four leaves \
{a,b,c,d} are present while there are four lineages.\
\>", "Text"],

Cell[TextData[{
  "Note: ",
  StyleBox["This is is an extension to the built-in function \
DiscreteMath`Combinatorica`IncidenceMatrix.",
    FontWeight->"Plain"]
}], "Text",
  FontWeight->"Bold"]
}, Open  ]]
},
FrontEndVersion->"4.0 for Macintosh",
ScreenRectangle->{{0, 1024}, {0, 748}},
WindowSize->{809, 555},
WindowMargins->{{Automatic, 36}, {Automatic, 10}},
StyleDefinitions -> "HelpBrowser.nb",
MacintoshSystemPageSetup->"\<\
00`0001804P000000_02@?o/onh3109BI085:0?l0@00005X0FP000003[0;@001
0000I00100000@0000000BL?0040000000000000000000000000000000000?nL
ojH?50^J00P100000000000000000000\>"
]


(***********************************************************************
Cached data follows.  If you edit this Notebook file directly, not using
Mathematica, you must remove the line containing CacheID at the top of 
the file.  The cache data will then be recreated when you save this file 
from within Mathematica.
***********************************************************************)

(*CellTagsOutline
CellTagsIndex->{
  "IncidenceMatrix"->{
    Cell[1798, 53, 1428, 30, 64, "DefinitionBox",
      CellTags->"IncidenceMatrix"]}
  }
*)

(*CellTagsIndex
CellTagsIndex->{
  {"IncidenceMatrix", 6058, 179}
  }
*)

(*NotebookFileOutline
Notebook[{

Cell[CellGroupData[{
Cell[1739, 51, 56, 0, 36, "SubsectionIcon"],
Cell[1798, 53, 1428, 30, 64, "DefinitionBox",
  CellTags->"IncidenceMatrix"],
Cell[3229, 85, 46, 0, 28, "MathCaption"],
Cell[3278, 87, 91, 2, 27, "Input"],
Cell[3372, 91, 67, 0, 28, "MathCaption"],
Cell[3442, 93, 209, 5, 27, "Input"],
Cell[3654, 100, 423, 17, 30, "MathCaption"],

Cell[CellGroupData[{
Cell[4102, 121, 123, 3, 27, "Input"],
Cell[4228, 126, 389, 12, 115, "Output"]
}, Open  ]],
Cell[4632, 141, 373, 6, 50, "Text"],
Cell[5008, 149, 195, 6, 24, "Text"]
}, Open  ]]
}
]
*)




(***********************************************************************
End of Mathematica Notebook file.
***********************************************************************)

