(***********************************************************************

                    Mathematica-Compatible Notebook

This notebook can be used on any computer system with Mathematica 4.0,
MathReader 4.0, or any compatible application. The data for the notebook 
starts with the line containing stars above.

To get the notebook into a Mathematica-compatible application, do one of 
the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing the 
word CacheID, otherwise Mathematica-compatible applications may try to 
use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
***********************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[      5567,        154]*)
(*NotebookOutlinePosition[      6451,        182]*)
(*  CellTagsIndexPosition[      6407,        178]*)
(*WindowFrame->Normal*)



Notebook[{

Cell[CellGroupData[{
Cell["Properties of the moment generating function", "SubsubsectionIcon"],

Cell[TextData[{
  "\tThe moment generating function has several useful properties.  Setting \
\[Omega][_]\[Rule]1 gives the probability of the tree topology, regardless of \
the mutational configuration; this must be independent of the scaled mutation \
rate, \[Theta]=4N\[VeryThinSpace]\[Mu].  ",
  Cell[BoxData[
      \(TraditionalForm\`\[PartialD]\_\(j\_k\)\)]],
  Cell[BoxData[
      \(TraditionalForm\`\(\(P\&~[\[Omega]\+_]\)\( | \_\(\[Omega][_] \[Rule] 
              1\)\)\)\)]],
  "gives the mean number of mutations along branch ",
  Cell[BoxData[
      \(TraditionalForm\`k, \ E[j\_k]\)]],
  ".  More generally, differentiating ",
  Cell[BoxData[
      \(TraditionalForm\`p\_k\)]],
  "times w.r.t. ",
  Cell[BoxData[
      \(TraditionalForm\`\[Omega][k]\)]],
  " at \[Omega][_]\[Rule]1 gives ",
  Cell[BoxData[
      \(TraditionalForm\`\(p\_k!\) E[j\_k\%p\_k]\)]],
  ".  The transformation ",
  Cell[BoxData[
      \(TraditionalForm\`\[Omega] \[Rule] \[ExponentialE]\^z\)]],
  " yields an alternative generating function, where differentiating ",
  Cell[BoxData[
      \(TraditionalForm\`p\_k\)]],
  "times w.r.t. ",
  Cell[BoxData[
      \(TraditionalForm\`\[Omega][k]\)]],
  " at z[_]\[Rule]0 gives ",
  Cell[BoxData[
      \(TraditionalForm\`E[j\_k\%p\_k]\)]],
  ". Differentiating the logarithm of this gives the cumulants of the \
distribution of mutation numbers."
}], "Text"],

Cell[TextData[{
  "\tThe probability distribution can be recovered by differentiating at \
\[Omega][_]\[Rule]0.  Thus, ",
  Cell[BoxData[
      \(TraditionalForm\`P\&~[0\+_]\)]],
  " is the probability that there are no mutations, and differentiating ",
  Cell[BoxData[
      \(TraditionalForm\`p\_k\)]],
  "times w.r.t. ",
  Cell[BoxData[
      \(TraditionalForm\`\[Omega][k]\)]],
  " at \[Omega][_]\[Rule]0 gives ",
  Cell[BoxData[
      \(TraditionalForm\`\(p\_k!\)\)]],
  " times the probability that there are ",
  Cell[BoxData[
      \(TraditionalForm\`p\_k\ \ mutations\)]],
  ".  "
}], "Text"],

Cell[TextData[{
  "\tThe m.g.f. generates probabilities that are integrated over the \
coalescence times.  However, information about coalescence times can be \
recovered: the m.g.f. can be regarded as a generating function for the \
distribution of coalescence times.  The m.g.f. can be written in terms of the \
multivariate distribution of coalescence times, ",
  Cell[BoxData[
      \(TraditionalForm\`t\+_\)]],
  ":"
}], "Text"],

Cell[BoxData[
    \(TextForm\`\(\(\ \)\(P\&~[\[Omega]\+_] = \(\[Integral]\_0\%\[Infinity]\
\[Product]\+k\((\[Sum]\+\(j\_k = 0\)\%\[Infinity]\( \[ExponentialE]\^\(\(-\
\[Theta]\)\[VeryThinSpace]t\_k/
                            2\)\) \(1\/\(j\_k!\)\) \(\((\(\[Theta]\
\[VeryThinSpace]t\_k\)\/2)\)\^j\_k\) \[Omega]\_k\%j\_k)\) 
              P[t\+_] \[DifferentialD]t\+_\  = \ \[Integral]\_0\%\[Infinity]\
\[Product]\+k\((\[ExponentialE]\^\(\(-\((1 - \[Omega]\_k)\)\) \[Theta]\
\[VeryThinSpace]t\_k/2\))\) 
              P[t\+_] \[DifferentialD]t\+_\)\)\)\)], "NumberedEquation"],

Cell[TextData[{
  "Thus, the m.g.f. is the Laplace transform for the multivariate \
distribution of coalescence times, with parameter ",
  Cell[BoxData[
      \(TraditionalForm\`\[Gamma]\_k = \((1 - \[Omega]\_k)\) \[Theta]/2\)]],
  " corresponding to time ",
  Cell[BoxData[
      \(TraditionalForm\`t\_k\)]],
  ".  Differentiating with respect to ",
  Cell[BoxData[
      \(TraditionalForm\`\[Gamma]\_k\)]],
  "gives the moments of the coalescence times.  In principle, the \
distribution itself can be recovered either by Cauchy integration, or by \
identifying each term as corresponding to an exponential fuynction within a \
restricted range of ",
  Cell[BoxData[
      \(TraditionalForm\`t\+_\)]],
  "."
}], "Text"]
}, Open  ]]
},
FrontEndVersion->"4.0 for Macintosh",
ScreenRectangle->{{0, 1152}, {0, 748}},
WindowSize->{520, 626},
WindowMargins->{{Automatic, -38}, {Automatic, -7}},
StyleDefinitions -> "HelpBrowser.nb",
MacintoshSystemPageSetup->"\<\
00<0001804P000000`d26_oQon@3:`8g0dL5N`?P0080001804P000000]P2:001
0000I00000400`<30?l00BL?00400@0000000000000006P801T1T00000000000
00000000004000000000000000000000\>"
]


(***********************************************************************
Cached data follows.  If you edit this Notebook file directly, not using
Mathematica, you must remove the line containing CacheID at the top of 
the file.  The cache data will then be recreated when you save this file 
from within Mathematica.
***********************************************************************)

(*CellTagsOutline
CellTagsIndex->{}
*)

(*CellTagsIndex
CellTagsIndex->{}
*)

(*NotebookFileOutline
Notebook[{

Cell[CellGroupData[{
Cell[1739, 51, 73, 0, 24, "SubsubsectionIcon"],
Cell[1815, 53, 1392, 36, 114, "Text"],
Cell[3210, 91, 601, 18, 53, "Text"],
Cell[3814, 111, 433, 9, 64, "Text"],
Cell[4250, 122, 577, 9, 76, "NumberedEquation"],
Cell[4830, 133, 721, 18, 78, "Text"]
}, Open  ]]
}
]
*)




(***********************************************************************
End of Mathematica Notebook file.
***********************************************************************)

