(***********************************************************************

                    Mathematica-Compatible Notebook

This notebook can be used on any computer system with Mathematica 4.0,
MathReader 4.0, or any compatible application. The data for the notebook 
starts with the line containing stars above.

To get the notebook into a Mathematica-compatible application, do one of 
the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing the 
word CacheID, otherwise Mathematica-compatible applications may try to 
use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
***********************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[    562723,      15621]*)
(*NotebookOutlinePosition[    564320,      15667]*)
(*  CellTagsIndexPosition[    564084,      15658]*)
(*WindowFrame->Normal*)



Notebook[{

Cell[CellGroupData[{
Cell["The stochastic Griffiths-Tavare algorithm", "SubsectionIcon",
  CellTags->"Stochastic GT algorithm"],

Cell[TextData[Cell[BoxData[
    FormBox[GridBox[{
          {\(MonteCarloGriffithsTavare[S, \[Theta]]\), \(uses\ the\ Monte - 
              Carlo\ Griffiths - 
              Tavare\ algorithm\ to\ find\ the\ probability\ of\ a\ \
configuration\ of\ mutations\ defined\ by\ the\ matrix\ \(\(S\)\(.\)\)\)},
          {\(MonteCarloGriffithsTavare[
              S, \[Theta], \[Phi]]\), \(makes\ random\ choices\ according\ to\
\ the\ numerical\ parameter\ \[Phi]; \ \[Theta]\ may\ be\ a\ symbol . \ \ The\
\ expected\ value\ of\ the\ result\ is\ equal\ to\ the\ probability\ of\ he\ \
configuration\ for\ arbitrary\ \(\(\[Phi]\)\(.\)\)\)}
          }], TraditionalForm]]]], "DefinitionBox",
  CellTags->"MonteCarloGriffithsTavare"],

Cell["\<\
Here is a configuration of mutations at 4 sites on 3 \
lineages:\
\>", "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"S", "=", 
        RowBox[{"(", GridBox[{
              {"1", "0", "0", "0"},
              {"0", "1", "1", "1"},
              {"0", "0", "0", "1"}
              }], ")"}]}], ";", 
      \(g = MatrixToGenealogy[S, {a, b, c}, {m\_1, m\_2, m\_3, m\_4}]\), ";", 
      \(Show[PlotGenealogy[g]]\), ";"}]], "Input",
  CellLabel->"In[33]:="],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.25 0.25 0.154508 0.154508 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
0 g
.5 Mabswid
[ ] 0 setdash
.5 .46353 m
.25 .15451 L
s
.5 .46353 m
.625 .30902 L
s
.625 .30902 m
.5 .15451 L
s
.625 .30902 m
.75 .15451 L
s
[(1)] .45 .49443 0 0 Mshowa
[(2)] .575 .33992 0 0 Mshowa
gsave
.25 .12361 -66 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 16.000000 moveto
 558.000000 16.000000 lineto
 558.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 16.000000 lineto
closepath
clip newpath
63.000000 13.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(a) show
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: font Courier
grestore
gsave
.5 .12361 -66 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 16.000000 moveto
 558.000000 16.000000 lineto
 558.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 16.000000 lineto
closepath
clip newpath
63.000000 13.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(b) show
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: font Courier
grestore
gsave
.75 .12361 -66 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 16.000000 moveto
 558.000000 16.000000 lineto
 558.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 16.000000 lineto
closepath
clip newpath
63.000000 13.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(c) show
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: font Courier
grestore
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[78]:=",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/A000`40O003h00Oogoo8Goo003oOolQ
Ool00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00
ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQ
Ool00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00
ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQ
Ool00?moob5oo`00AGoo1@00@goo1000AGoo0`00Agoo0015Ool01000Oomoo`00A7oo00D007ooOomo
o`0004=oo`05001oogooOol00016Ool004Eoo`@004Aoo`05001oogooOol00013Ool00`00Oomoo`18
Ool004Qoo`03001oogoo049oo`05001oogooOol00013Ool01@00Oomoogoo0000AWoo0016Ool30014
Ool40015Ool40016Ool008eoo`03001oogoo091oo`00S7oo0P00TWoo003oOolQOol00?moob5oo`00
ogoo8Goo003oOolQOol004Moo`03001oogoo04Eoo`03001oogoo04Eoo`03001oogoo04Ioo`00Agoo
00<007ooOol0AGoo00<007ooOol0AGoo00<007ooOol0AWoo0018Ool00`00Oomoo`15Ool00`00Oomo
o`13Ool00`00Oomoo`17Ool004Uoo`03001oogoo04Eoo`03001oogoo045oo`03001oogoo04Qoo`00
BWoo00<007ooOol0AGoo00<007ooOol0?goo00<007ooOol0BGoo001;Ool00`00Oomoo`15Ool00`00
Oomoo`0mOol00`00Oomoo`1:Ool004aoo`03001oogoo04Eoo`03001oogoo03]oo`03001oogoo04]o
o`00C7oo00<007ooOol0AGoo00<007ooOol0>goo00<007ooOol0Bgoo001=Ool00`00Oomoo`15Ool0
0`00Oomoo`0iOol00`00Oomoo`1<Ool004ioo`03001oogoo04Eoo`03001oogoo03Moo`03001oogoo
04eoo`00Cgoo00<007ooOol0AGoo00<007ooOol0=Goo00<007ooOol0CWoo001@Ool00`00Oomoo`15
Ool00`00Oomoo`0cOol00`00Oomoo`1?Ool0051oo`03001oogoo04Eoo`03001oogoo03=oo`03001o
ogoo04moo`00DGoo00<007ooOol0AGoo00<007ooOol0<Goo00<007ooOol0D7oo001BOol00`00Oomo
o`15Ool00`00Oomoo`0_Ool00`00Oomoo`1AOol005=oo`03001oogoo04Eoo`03001oogoo02eoo`03
001oogoo059oo`00E7oo00<007ooOol0AGoo00<007ooOol0:goo00<007ooOol0Dgoo001EOol00`00
Oomoo`15Ool00`00Oomoo`0YOol00`00Oomoo`1DOol005Eoo`03001oogoo04Eoo`03001oogoo02Uo
o`03001oogoo05Aoo`00EWoo00<007ooOol0AGoo00<007ooOol09goo00<007ooOol0EGoo001GOol0
0`00Oomoo`15Ool00`00Oomoo`0UOol00`00Oomoo`1FOol005Qoo`03001oogoo04Eoo`03001oogoo
02=oo`03001oogoo05Moo`00FGoo00<007ooOol0AGoo00<007ooOol08Goo00<007ooOol0F7oo001I
Ool00`00Oomoo`15Ool00`00Oomoo`0QOol00`00Oomoo`1HOol005Yoo`03001oogoo04Eoo`03001o
ogoo01moo`03001oogoo05Uoo`00Fgoo00<007ooOol0AGoo00<007ooOol07Goo00<007ooOol0FWoo
001LOol00`00Oomoo`15Ool00`00Oomoo`0KOol00`00Oomoo`1KOol005eoo`03001oogoo04Eoo`03
001oogoo01Uoo`03001oogoo05aoo`00GWoo00<007ooOol0AGoo00<007ooOol05goo00<007ooOol0
GGoo001NOol00`00Oomoo`15Ool00`00Oomoo`0GOol00`00Oomoo`1MOol005moo`03001oogoo04Eo
o`03001oogoo01Eoo`03001oogoo05ioo`00H7oo00<007ooOol0AGoo00<007ooOol04goo00<007oo
Ool0Ggoo001QOol00`00Oomoo`15Ool00`00Oomoo`0AOol00`00Oomoo`1POol0069oo`03001oogoo
04Eoo`03001oogoo00moo`03001oogoo065oo`00HWoo00<007ooOol0AGoo00<007ooOol03goo00<0
07ooOol0HGoo001SOol00`00Oomoo`15Ool00`00Oomoo`0=Ool00`00Oomoo`1ROol006Aoo`03001o
ogoo04Eoo`03001oogoo00]oo`03001oogoo06=oo`00IGoo00<007ooOol0AGoo00<007ooOol02Goo
00<007ooOol0I7oo001VOol00`00Oomoo`15Ool00`00Oomoo`07Ool00`00Oomoo`1UOol006Moo`03
001oogoo04Eoo`03001oogoo00Eoo`03001oogoo06Ioo`00Igoo00<007ooOol0AGoo00<007ooOol0
1Goo00<007ooOol0IWoo001XOol00`00Oomoo`15Ool00`00Oomoo`03Ool00`00Oomoo`1WOol006Uo
o`03001oogoo04Eoo`05001oogooOol0001ZOol006Yoo`03001oogoo04Eoo`03001oo`0006]oo`00
Jgoo00<007ooOol0AGoo00<007ooOol0JWoo001[Ool00`00Oomoo`15Ool00`00Oomoo`1ZOol006ao
o`03001oogoo04=oo`03001oogoo06]oo`00KGoo00<007ooOol0@Goo00<007ooOol0K7oo001^Ool0
0`00Oomoo`0oOol00`00Oomoo`1]Ool006moo`03001oogoo03eoo`03001oogoo06ioo`00L7oo00<0
07ooOol0>goo00<007ooOol0Kgoo001`Ool00`00Oomoo`0_Ool40008Ool00`00Oomoo`1_Ool0075o
o`03001oogoo02moo`03001oogoo00Moo`03001oogoo071oo`00LWoo00<007ooOol0;goo00<007oo
Ool01Goo00<007ooOol0LGoo001cOol00`00Oomoo`0_Ool00`00Oomoo`03Ool00`00Oomoo`1bOol0
07Aoo`03001oogoo02]oo`04001oogoo0004Ool00`00Oomoo`1cOol007Aoo`03001oogoo02aoo`80
00Eoo`03001oogoo07=oo`00MGoo00<007ooOol0<Goo00<007ooOol0M7oo001fOol00`00Oomoo`0_
Ool00`00Oomoo`1eOol007Moo`03001oogoo02eoo`03001oogoo07Ioo`00N7oo00<007ooOol0:goo
00<007ooOol0Mgoo001iOol00`00Oomoo`0YOol00`00Oomoo`1hOol007Uoo`03001oogoo02Uoo`03
001oogoo07Qoo`00NWoo00<007ooOol09goo00<007ooOol0NGoo001kOol00`00Oomoo`0UOol00`00
Oomoo`1jOol007aoo`03001oogoo02=oo`03001oogoo07]oo`00OGoo00<007ooOol08Goo00<007oo
Ool0O7oo001mOol00`00Oomoo`0QOol00`00Oomoo`1lOol007ioo`03001oogoo01moo`03001oogoo
07eoo`00Ogoo00<007ooOol07Goo00<007ooOol0OWoo0020Ool00`00Oomoo`0KOol00`00Oomoo`1o
Ool0085oo`03001oogoo01Uoo`03001oogoo081oo`00PWoo00<007ooOol05goo00<007ooOol0PGoo
0022Ool00`00Oomoo`0GOol00`00Oomoo`21Ool008=oo`03001oogoo01Eoo`03001oogoo089oo`00
Q7oo00<007ooOol04goo00<007ooOol0Pgoo0025Ool00`00Oomoo`0AOol00`00Oomoo`24Ool008Io
o`03001oogoo00moo`03001oogoo08Eoo`00QWoo00<007ooOol03goo00<007ooOol0QGoo0027Ool0
0`00Oomoo`0=Ool00`00Oomoo`26Ool008Qoo`03001oogoo00]oo`03001oogoo08Moo`00RGoo00<0
07ooOol02Goo00<007ooOol0R7oo002:Ool00`00Oomoo`07Ool00`00Oomoo`29Ool008]oo`03001o
ogoo00Eoo`03001oogoo08Yoo`00Rgoo00<007ooOol01Goo00<007ooOol0RWoo002<Ool00`00Oomo
o`03Ool00`00Oomoo`2;Ool008eoo`05001oogooOol0002>Ool008ioo`03001oo`0008moo`00Sgoo
00<007ooOol0SWoo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo
001oOol3002NOol0081oo`03001oogoo09eoo`00P7oo00<007ooOol0WGoo0020Ool00`00Oomoo`2M
Ool0081oo`03001oogoo09eoo`00Ogoo0P00Wgoo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQ
Ool00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00
ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQ
Ool00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00
ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-1.00496, -1.00002, 
  0.0139719, 0.022607}}]
}, Closed]],

Cell[TextData[{
  "There are two mutations on the branch leading down to ",
  Cell[BoxData[
      \(TraditionalForm\`b\)]],
  ", and one each on the branches leading down to 2 and ",
  Cell[BoxData[
      \(TraditionalForm\`a\)]],
  "."
}], "Text"],

Cell["This is the exact probability of the configuration:", "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[
    \({exgt = GriffithsTavare[S, \[Theta]], 
      \(\((\[Theta]\/2)\)\^4\) 
            \((3\/\(\(\[Lambda]\_3\%4\) \[Lambda]\_2\%2\) + 
                2\/\(\(\[Lambda]\_3\%3\) \[Lambda]\_2\%3\))\) /. {
            \[Lambda]\_3 \[Rule] \(3 \((2 + \[Theta])\)\)\/2, 
            \[Lambda]\_2 \[Rule] \((1 + \[Theta])\)} // Factor}\)], "Input",
  CellLabel->"In[83]:="],

Cell[BoxData[
    \({\(\[Theta]\^4\ \((3 + 2\ \[Theta])\)\)\/\(27\ \((1 + \[Theta])\)\^3\ 
          \((2 + \[Theta])\)\^4\), 
      \(\[Theta]\^4\ \((3 + 2\ \[Theta])\)\)\/\(27\ \((1 + \[Theta])\)\^3\ 
          \((2 + \[Theta])\)\^4\)}\)], "Output",
  CellLabel->"Out[83]="]
}, Closed]],

Cell[TextData[{
  "This is a sum over five possible paths back through the genealogy; these \
each involve loss of 4 mutations and 2 coalescences.  For 3 of these paths, 3 \
lineages are extant during 4 steps, and 2 during 2 steps: ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          RowBox[{
            FormBox[\(\(M\_a\) \(M\_b\) \(M\_b\) C\_\(b\[VeryThinSpace]c\)\),
              "TraditionalForm"], \(M\_\(b\[VeryThinSpace]c\)\), 
            \(C\_abc\)}], ",", 
          RowBox[{
            
            FormBox[\(\ 
              \(M\_b\) \(M\_a\) \(M\_b\) C\_\(b\[VeryThinSpace]c\)\),
              "TraditionalForm"], \(M\_\(b\[VeryThinSpace]c\)\), 
            \(C\_abc\)}], ",", " ", 
          RowBox[{
            FormBox[\(\(M\_b\) \(M\_b\) \(M\_a\) C\_\(b\[VeryThinSpace]c\)\),
              "TraditionalForm"], \(M\_\(b\[VeryThinSpace]c\)\), 
            \(C\_abc\)}]}], TraditionalForm]]],
  ".  For 2 paths, 3 lineages are extant during 3 steps, and 2 during 3 \
steps: ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          RowBox[{
            FormBox[\(\(M\_b\) \(M\_b\) C\_\(b\[VeryThinSpace]c\)\),
              "TraditionalForm"], \(M\_a\), \(M\_\(b\[VeryThinSpace]c\)\), 
            \(C\_abc\)}], ",", " ", 
          RowBox[{
            FormBox[\(\(M\_b\) \(M\_b\) C\_\(b\[VeryThinSpace]c\)\),
              "TraditionalForm"], \(M\_\(b\[VeryThinSpace]c\)\), \(M\_a\), 
            \(C\_abc\)}]}], TraditionalForm]]],
  ".  These two kinds of path correspond to the 2 terms ",
  Cell[BoxData[
      \(\((
        3\/\(\(\[Lambda]\_3\%4\) \[Lambda]\_2\%2\) + 
          2\/\(\(\[Lambda]\_3\%3\) \[Lambda]\_2\%3\))\)\)]],
  "above."
}], "Text"],

Cell[TextData[{
  "MonteCarloGriffithsTavare[S,\[Theta], \[Phi]] returns a random quantity \
whose expectation equals the probability of the genealogy.  The arbitrary \
parameter \[Phi] determines the relative chances of tracing back to loss of a \
mutation, or to a coalescence.  If there are ",
  Cell[BoxData[
      \(TraditionalForm\`J\)]],
  " leaves which carry one or more unique mutations, and ",
  Cell[BoxData[
      \(TraditionalForm\`K\)]],
  " possible coalescences between leaves carrying no unique mutations, then \
the probability of tracing back through one of the mutation losses is ",
  Cell[BoxData[
      \(TraditionalForm\`\[Phi]\/\(\[Phi]\ J + 2  K\)\)]],
  ", and the probability of tracing back through one of the coalescences is ",
  
  Cell[BoxData[
      \(TraditionalForm\`2\/\(\[Phi]\ J + 2  K\)\)]],
  ".  (The default used by MonteCarloGriffithsTavare[S,\[Theta]] is \[Phi]=\
\[Theta]; this is an arbitrary choice).  Because \[Phi] is used to determine \
a random choice, it must be a number; however, \[Theta] may be a symbol."
}], "Text"],

Cell["\<\
\tThis creates a table of 1000 functions, each corresponding to one \
of the five pathways:\
\>", "MathCaption"],

Cell[BoxData[
    \(\(tt = Table[MonteCarloGriffithsTavare[S, \[Theta], 10. ], {1000}]; 
    \)\)], "Input",
  CellLabel->"In[72]:="],

Cell[TextData[{
  "The table contains 4 kinds of term, corresponding to paths ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          FormBox[\(\(M\_a\) \(M\_b\) \(M\_b\) C\_\(b\[VeryThinSpace]c\)\),
            "TraditionalForm"], \(M\_\(b\[VeryThinSpace]c\)\), \(C\_abc\)}], 
        TraditionalForm]]],
  ", ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          FormBox[\(\ \(M\_b\) \(M\_a\) \(M\_b\) C\_\(b\[VeryThinSpace]c\)\),
            "TraditionalForm"], \(M\_\(b\[VeryThinSpace]c\)\), \(C\_abc\)}], 
        TraditionalForm]]],
  ", ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          FormBox[\(\(M\_b\) \(M\_b\) \(M\_a\) C\_\(b\[VeryThinSpace]c\)\),
            "TraditionalForm"], \(M\_\(b\[VeryThinSpace]c\)\), \(C\_abc\)}], 
        TraditionalForm]]],
  ", {",
  Cell[BoxData[
      FormBox[
        RowBox[{
          RowBox[{
            FormBox[\(\(M\_b\) \(M\_b\) C\_\(b\[VeryThinSpace]c\)\),
              "TraditionalForm"], \(M\_a\), \(M\_\(b\[VeryThinSpace]c\)\), 
            \(C\_abc\)}], ",", " ", 
          RowBox[{
            FormBox[\(\(M\_b\) \(M\_b\) C\_\(b\[VeryThinSpace]c\)\),
              "TraditionalForm"], \(M\_\(b\[VeryThinSpace]c\)\), \(M\_a\), 
            \(C\_abc\)}]}], TraditionalForm]]],
  "}, respectively.  (The last two kinds of path have the same weight, and so \
appear together in the table of frequencies).  The probailities of the five \
kinds of path are ",
  Cell[BoxData[
      \(TraditionalForm\`1\/2, \ 1\/4, \ \[Phi]\/\(4 \((2 + \[Phi])\)\), \ 
      1\/\(4 \((2 + \[Phi])\)\), \ 1\/\(4 \((2 + \[Phi])\)\)\)]],
  ", and they each contribute ",
  Cell[BoxData[
      \(2\/\(16 \( \[Lambda]\_3\%4\) \[Lambda]\_2\%2\), \ 
      4\/\(16 \( \[Lambda]\_3\%4\) \[Lambda]\_2\%2\), 
      \(4 \((2 + \[Phi])\)\)\/\(16  \[Phi]\ \(\[Lambda]\_3\%4\) 
          \[Lambda]\_2\%2\), \ 
      \(4 \((2 + \[Phi])\)\)\/\(\ 16 \( \[Lambda]\_3\%3\) \[Lambda]\_2\%3\), 
      \ \(4 \((2 + \[Phi])\)\)\/\(16\ \(\[Lambda]\_3\%3\) 
          \[Lambda]\_2\%3\)\)]],
  ".  Note that the last two kinds of path appear relatively rarely, but have \
high weight when \[Phi]>>1.  "
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(ftt = Frequencies[tt]\)], "Input",
  CellLabel->"In[91]:="],

Cell[BoxData[
    \({{511, 
        \(0.0246913580246913788`\ \[Theta]\^4\)\/\(\((1 + \[Theta])\)\^2\ 
            \((2 + \[Theta])\)\^4\)}, {234, 
        \(0.0493827160493827577`\ \[Theta]\^4\)\/\(\((1 + \[Theta])\)\^2\ 
            \((2 + \[Theta])\)\^4\)}, {212, 
        \(0.0592592592592592914`\ \[Theta]\^4\)\/\(\((1 + \[Theta])\)\^2\ 
            \((2 + \[Theta])\)\^4\)}, {43, 
        \(0.888888888888889461`\ \[Theta]\^4\)\/\(\((1 + \[Theta])\)\^3\ 
            \((2 + \[Theta])\)\^3\)}}\)], "Output",
  CellLabel->"Out[91]="]
}, Closed]],

Cell["\<\
This shows the mean \[PlusMinus] standard error of estimates of the \
likelihood, plotted against \[Theta]:\
\>", "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[
    \(<< Graphics`Graphics`; << Graphics`Colors`; \n
    se = StandardErrorOfSampleMean[tt]; mn = Mean[tt]; \n
    LogLogPlot[{exgt, mn, mn + se, mn - se}, {\[Theta], 0, 50}, 
      PlotStyle 
        \[Rule] {Red, Dashing[{1, 0}], Dashing[{0.01, 0.01}], 
          Dashing[{0.01, 0.01}]}]; \)], "Input",
  CellLabel->"In[74]:="],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.444641 0.312866 1.22491 0.198561 [
[.13178 -0.0125 -11 -12 ]
[.13178 -0.0125 11 0 ]
[.35046 -0.0125 -11 -12 ]
[.35046 -0.0125 11 0 ]
[.44464 -0.0125 -5 -12 ]
[.44464 -0.0125 5 0 ]
[.66332 -0.0125 -5 -12 ]
[.66332 -0.0125 5 0 ]
[.75751 -0.0125 -8 -12 ]
[.75751 -0.0125 8 0 ]
[.97619 -0.0125 -8 -12 ]
[.97619 -0.0125 8 0 ]
[-0.0125 .03355 -47.0625 -6.40625 ]
[-0.0125 .03355 0 6.40625 ]
[-0.0125 .17233 -47.0625 -6.40625 ]
[-0.0125 .17233 0 6.40625 ]
[-0.0125 .23211 -46 -6 ]
[-0.0125 .23211 0 6 ]
[-0.0125 .3709 -46 -6 ]
[-0.0125 .3709 0 6 ]
[-0.0125 .43067 -40 -6 ]
[-0.0125 .43067 0 6 ]
[-0.0125 .56946 -40 -6 ]
[-0.0125 .56946 0 6 ]
[ -0.0005 -0.0005 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.13178 0 m
.13178 .00625 L
s
gsave
.13178 -0.0125 -72 -16 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 16.000000 moveto
 558.000000 16.000000 lineto
 558.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 16.000000 lineto
closepath
clip newpath
63.000000 13.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 13.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(0.1) show
81.000000 13.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: font Courier
grestore
.35046 0 m
.35046 .00625 L
s
gsave
.35046 -0.0125 -72 -16 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 16.000000 moveto
 558.000000 16.000000 lineto
 558.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 16.000000 lineto
closepath
clip newpath
63.000000 13.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 13.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(0.5) show
81.000000 13.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: font Courier
grestore
.44464 0 m
.44464 .00625 L
s
gsave
.44464 -0.0125 -66 -16 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 16.000000 moveto
 558.000000 16.000000 lineto
 558.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 16.000000 lineto
closepath
clip newpath
63.000000 13.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 13.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(1) show
69.000000 13.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: font Courier
grestore
.66332 0 m
.66332 .00625 L
s
gsave
.66332 -0.0125 -66 -16 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 16.000000 moveto
 558.000000 16.000000 lineto
 558.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 16.000000 lineto
closepath
clip newpath
63.000000 13.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 13.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(5) show
69.000000 13.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: font Courier
grestore
.75751 0 m
.75751 .00625 L
s
gsave
.75751 -0.0125 -69 -16 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 16.000000 moveto
 558.000000 16.000000 lineto
 558.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 16.000000 lineto
closepath
clip newpath
63.000000 13.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 13.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(10) show
75.000000 13.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: font Courier
grestore
.97619 0 m
.97619 .00625 L
s
gsave
.97619 -0.0125 -69 -16 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 16.000000 moveto
 558.000000 16.000000 lineto
 558.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 16.000000 lineto
closepath
clip newpath
63.000000 13.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 13.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(50) show
75.000000 13.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: font Courier
grestore
.001 w
.22596 0 m
.22596 .00375 L
s
.28105 0 m
.28105 .00375 L
s
.32014 0 m
.32014 .00375 L
s
.37523 0 m
.37523 .00375 L
s
.39618 0 m
.39618 .00375 L
s
.41432 0 m
.41432 .00375 L
s
.43033 0 m
.43033 .00375 L
s
.53882 0 m
.53882 .00375 L
s
.59392 0 m
.59392 .00375 L
s
.633 0 m
.633 .00375 L
s
.6881 0 m
.6881 .00375 L
s
.70904 0 m
.70904 .00375 L
s
.72719 0 m
.72719 .00375 L
s
.74319 0 m
.74319 .00375 L
s
.85169 0 m
.85169 .00375 L
s
.90678 0 m
.90678 .00375 L
s
.94587 0 m
.94587 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .03355 m
.00625 .03355 L
s
gsave
-0.0125 .03355 -108.062 -10.4062 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.8125 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 16.812500 moveto
 558.000000 16.812500 lineto
 558.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 16.812500 lineto
closepath
clip newpath
63.000000 13.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 13.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(1.) show
75.000000 13.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
76.812500 13.812500 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(\\264) show
84.625000 13.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(10) show
96.625000 9.437500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 7.125000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
96.625000 9.437500 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 7.125000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(-) show
100.812500 9.437500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 7.125000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(6) show
105.000000 9.437500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 7.125000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Math1Mono
%%+ font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Math1Mono
%%+ Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: font Math1Mono
%%+ font Courier
grestore
0 .17233 m
.00625 .17233 L
s
gsave
-0.0125 .17233 -108.062 -10.4062 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.8125 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 16.812500 moveto
 558.000000 16.812500 lineto
 558.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 16.812500 lineto
closepath
clip newpath
63.000000 13.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 13.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(5.) show
75.000000 13.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
76.812500 13.812500 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(\\264) show
84.625000 13.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(10) show
96.625000 9.437500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 7.125000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
96.625000 9.437500 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 7.125000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(-) show
100.812500 9.437500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 7.125000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(6) show
105.000000 9.437500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 7.125000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Math1Mono
%%+ font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Math1Mono
%%+ Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: font Math1Mono
%%+ font Courier
grestore
0 .23211 m
.00625 .23211 L
s
gsave
-0.0125 .23211 -107 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 16.000000 moveto
 558.000000 16.000000 lineto
 558.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 16.000000 lineto
closepath
clip newpath
63.000000 13.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 13.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(0.00001) show
105.000000 13.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: font Courier
grestore
0 .3709 m
.00625 .3709 L
s
gsave
-0.0125 .3709 -107 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 16.000000 moveto
 558.000000 16.000000 lineto
 558.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 16.000000 lineto
closepath
clip newpath
63.000000 13.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 13.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(0.00005) show
105.000000 13.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: font Courier
grestore
0 .43067 m
.00625 .43067 L
s
gsave
-0.0125 .43067 -101 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 16.000000 moveto
 558.000000 16.000000 lineto
 558.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 16.000000 lineto
closepath
clip newpath
63.000000 13.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 13.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(0.0001) show
99.000000 13.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: font Courier
grestore
0 .56946 m
.00625 .56946 L
s
gsave
-0.0125 .56946 -101 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 16.000000 moveto
 558.000000 16.000000 lineto
 558.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 16.000000 lineto
closepath
clip newpath
63.000000 13.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 13.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(0.0005) show
99.000000 13.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: font Courier
grestore
.001 w
0 .09332 m
.00375 .09332 L
s
0 .12828 m
.00375 .12828 L
s
0 .15309 m
.00375 .15309 L
s
0 .18806 m
.00375 .18806 L
s
0 .20135 m
.00375 .20135 L
s
0 .21286 m
.00375 .21286 L
s
0 .22302 m
.00375 .22302 L
s
0 .29188 m
.00375 .29188 L
s
0 .32684 m
.00375 .32684 L
s
0 .35165 m
.00375 .35165 L
s
0 .38662 m
.00375 .38662 L
s
0 .39991 m
.00375 .39991 L
s
0 .41143 m
.00375 .41143 L
s
0 .42158 m
.00375 .42158 L
s
0 .49044 m
.00375 .49044 L
s
0 .52541 m
.00375 .52541 L
s
0 .55021 m
.00375 .55021 L
s
0 .58518 m
.00375 .58518 L
s
0 .59847 m
.00375 .59847 L
s
0 .60999 m
.00375 .60999 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
1 0 0 r
.5 Mabswid
.16183 0 m
.25296 .22656 L
.34241 .38752 L
.40401 .47553 L
.44292 .5195 L
.47261 .54644 L
.49886 .56535 L
.52199 .57815 L
.54074 .58588 L
.55746 .59081 L
.56613 .59265 L
.57377 .59387 L
.57773 .59436 L
.58138 .59472 L
.58458 .59497 L
.58798 .59516 L
.58988 .59524 L
.59158 .59529 L
.59351 .59533 L
.59531 .59534 L
.59695 .59534 L
.59845 .59532 L
.60008 .59529 L
.60177 .59523 L
.60457 .59511 L
.60707 .59495 L
.61253 .5945 L
.61739 .59394 L
.62185 .59331 L
.63133 .59161 L
.64094 .58938 L
.65589 .58493 L
.67069 .57941 L
.69647 .56733 L
.7353 .54382 L
.76444 .52254 L
.7898 .50185 L
.81044 .48373 L
.82771 .46777 L
.84396 .45216 L
.85795 .43829 L
.8714 .42464 L
.8832 .4124 L
.89367 .40137 L
.90398 .39035 L
.91323 .38035 L
.92156 .37125 L
.9299 .36205 L
.93747 .35363 L
.94509 .3451 L
Mistroke
.95204 .33726 L
.9584 .33004 L
.96487 .32267 L
.97081 .31586 L
.97619 .30967 L
Mfstroke
0 g
[ 1 0 ] 0 setdash
.16122 0 m
.25296 .22807 L
.34241 .38897 L
.40401 .47693 L
.44292 .52086 L
.47261 .54778 L
.49886 .56666 L
.52199 .57943 L
.54074 .58714 L
.55746 .59206 L
.56613 .59389 L
.57377 .5951 L
.57773 .59559 L
.58138 .59595 L
.58458 .59619 L
.58798 .59638 L
.58988 .59646 L
.59158 .59651 L
.59351 .59654 L
.59531 .59656 L
.59695 .59655 L
.59845 .59653 L
.60008 .59649 L
.60177 .59644 L
.60457 .59631 L
.60707 .59615 L
.61253 .59569 L
.61739 .59513 L
.62185 .5945 L
.63133 .59279 L
.64094 .59055 L
.65589 .58609 L
.67069 .58056 L
.69647 .56846 L
.7353 .54492 L
.76444 .52363 L
.7898 .50294 L
.81044 .4848 L
.82771 .46884 L
.84396 .45322 L
.85795 .43935 L
.8714 .4257 L
.8832 .41346 L
.89367 .40243 L
.90398 .3914 L
.91323 .3814 L
.92156 .37229 L
.9299 .36309 L
.93747 .35467 L
.94509 .34614 L
Mistroke
.95204 .3383 L
.9584 .33108 L
.96487 .32371 L
.97081 .3169 L
.97619 .31071 L
Mfstroke
[ .01 .01 ] 0 setdash
.15806 0 m
.25296 .2359 L
.34241 .39661 L
.40401 .48439 L
.44292 .52818 L
.47261 .55499 L
.49886 .57377 L
.52199 .58646 L
.54074 .5941 L
.55746 .59895 L
.56613 .60075 L
.57377 .60194 L
.57773 .60241 L
.58138 .60276 L
.58458 .60299 L
.58634 .60309 L
.58798 .60317 L
.58988 .60324 L
.59158 .60328 L
.59338 .60331 L
.59531 .60332 L
.59697 .60331 L
.59871 .60328 L
.60018 .60324 L
.60177 .60318 L
.60478 .60303 L
.60757 .60284 L
.61265 .60239 L
.61792 .60175 L
.62343 .60092 L
.6328 .59912 L
.64094 .59717 L
.66918 .58771 L
.69477 .57583 L
.73402 .55219 L
.76341 .53078 L
.78895 .50997 L
.8097 .49174 L
.82706 .4757 L
.84338 .46002 L
.85743 .44609 L
.87093 .43239 L
.88278 .4201 L
.89327 .40904 L
.90362 .39798 L
.91288 .38795 L
.92123 .37882 L
.9296 .3696 L
.93718 .36115 L
.94481 .35261 L
Mistroke
.95178 .34475 L
.95816 .33751 L
.96463 .33013 L
.97058 .32331 L
.97619 .31685 L
Mfstroke
.1647 0 m
.25296 .21945 L
.34241 .38059 L
.40401 .46878 L
.44292 .51286 L
.47261 .53991 L
.49886 .5589 L
.52199 .57178 L
.54074 .57958 L
.55746 .58456 L
.56613 .58643 L
.57377 .58768 L
.57773 .58818 L
.58138 .58855 L
.58458 .58881 L
.58798 .58901 L
.58988 .5891 L
.59158 .58915 L
.59351 .5892 L
.59531 .58922 L
.59695 .58922 L
.59845 .5892 L
.60008 .58917 L
.60177 .58912 L
.60457 .58901 L
.60707 .58886 L
.61253 .58842 L
.61739 .58788 L
.62185 .58726 L
.63133 .58558 L
.64094 .58338 L
.65589 .57896 L
.67069 .57348 L
.69647 .56146 L
.7353 .53802 L
.76444 .51679 L
.7898 .49614 L
.81044 .47804 L
.82771 .4621 L
.84396 .4465 L
.85795 .43265 L
.8714 .41901 L
.8832 .40678 L
.89367 .39576 L
.90398 .38474 L
.91323 .37475 L
.92156 .36565 L
.9299 .35645 L
.93747 .34803 L
.94509 .33951 L
Mistroke
.95204 .33168 L
.9584 .32446 L
.96487 .31709 L
.97081 .31028 L
.97619 .3041 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[75]:=",
  ImageSize->{493, 304.562},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40007]0001<1000`40O003h00OogookWoo003oOoo^
Ool00?moonioo`00ogookWoo003oOoo^Ool00?moonioo`00ogookWoo003oOoo^Ool00?moonioo`00
ogookWoo003oOoo^Ool006Moo`8000Aoo`8000=oo`<0059oo`8000Aoo`8000=oo`<0021oo`<005io
o`<002=oo`<000Aoo`8005Moo`<000Aoo`8000Qoo`00IWoo00@007ooOol000=oo`8000Aoo`03001o
ogoo051oo`04001oogoo0003Ool20006Ool00`00Oomoo`0NOol00`00Oomoo`1POol00`00Oomoo`0Q
Ool00`00Oomoo`02Ool01000Oomoo`00FGoo00@007ooOol0009oo`03001oogoo00Eoo`00IWoo00@0
07ooOol000Uoo`03001oogoo051oo`04001oogoo000;Ool00`00Oomoo`0NOol00`00Oomoo`1POol0
0`00Oomoo`0QOol00`00Oomoo`02Ool01000Oomoo`00FGoo00@007ooOol0009oo`03001oogoo00Eo
o`00IWoo00@007ooOol000Uoo`03001oogoo051oo`04001oogoo0008Ool3000QOol00`00Oomoo`1M
Ool3000TOol00`00Oomoo`02Ool01000Oomoo`00EWoo0`000goo00@007ooOol000Moo`00IWoo00@0
07ooOol000Uoo`03001oogoo051oo`04001oogoo0008Ool00`00Oomoo`0QOol00`00Oomoo`1MOol0
0`00Oomoo`0TOol00`00Oomoo`02Ool01000Oomoo`00EWoo00<007ooOol00goo00@007ooOol000Mo
o`00Igoo0P002Goo0P00Dgoo0P002Goo10007goo0P00Ggoo10008Woo0P001Goo0P00Egoo10000goo
0P0027oo003oOoo^Ool00?moonioo`00ogookWoo003oOoo^Ool00?moonioo`00ogookWoo003oOoo^
Ool00?moonioo`00=7ooo`00^@000Goo000dOol00`00Oomoo`0gOol00`00Oomoo`09Ool3000JOol0
0`00Oomoo`0FOol00`00Oomoo`0>Ool00`00Oomoo`0:Ool00`00Oomoo`08Ool00`00Oomoo`06Ool0
0`00Oomoo`05Ool00`00Oomoo`04Ool00`00Oomoo`03Ool00`00Oomoo`0WOol00`00Oomoo`0EOol0
0`00Oomoo`0>Ool00`00Oomoo`0;Ool00`00Oomoo`07Ool00`00Oomoo`07Ool00`00Oomoo`05Ool0
0`00Oomoo`04Ool00`00Oomoo`03Ool00`00Oomoo`0VOol00`00Oomoo`0FOol00`00Oomoo`0>Ool0
0`00Oomoo`0:Ool00`00Oomoo`09Ool003Aoo`03001oogoo03Moo`03001oogoo00Uoo`04001oo`00
001@Ool00`00Oomoo`0VOol00`00Oomoo`1NOol00`00Oomoo`0VOol00`00Oomoo`1MOol00`00Oomo
o`09Ool003Aoo`03001oogoo04Aoo`800003Ool007oo0?moofioo`00=7oo00<007ooOol0A7oo0P00
ogooLGoo000dOol00`00Oomoo`16Ool00`00Oomoo`3oOom^Ool003Aoo`03001oogoo04Ioo`03001o
ogoo0?moofioo`00=7oo00<007ooOol0Agoo0P00ogooKWoo000dOol00`00Oomoo`16Ool3003oOom^
Ool003Aoo`03001oogoo04Ioo`800003Ool007oo0?moofaoo`00=7oo00<007ooOol0Agoo0`00ogoo
KGoo000dOol00`00Oomoo`17Ool200000goo001oo`3oOom[Ool000=oo`<000Aoo`8000Aoo`05001o
ogooOol00003Ool30004Ool2000COol00`00Oomoo`18Ool2003oOom]Ool000Aoo`03001oogoo00=o
o`8000Eoo`03001oo`0000Eoo`03001oogoo009oo`04001oogoo000BOol00`00Oomoo`19Ool00`00
Oomoo`3oOom[Ool000Aoo`03001oogoo00]oo`03001oogoo00Aoo`03001oogoo009oo`04001oogoo
000BOol40018Ool00`00Oomoo`3oOom[Ool000Aoo`03001oogoo00Yoo`03001oo`0000Eoo`03001o
ogoo009oo`04001oogoo000BOol00`00Oomoo`1:Ool2003oOom[Ool000Aoo`03001oogoo00Uoo`05
001oogooOol00004Ool00`00Oomoo`02Ool01000Oomoo`001Woo0`002Goo00<007ooOol0BGoo0`00
ogooJgoo0003Ool2000COol20005Ool20003Ool3000017oo001oo`002Goo00<007ooOol0BGoo00@0
07oo00000?moofYoo`00:7oo0`002Goo00<007ooOol0BWoo0`00ogooJWoo000YOol20009Ool00`00
Oomoo`1:Ool200000goo001oo`3oOomXOol003Aoo`03001oogoo04]oo`800?moofYoo`00=7oo00<0
07ooOol0C7oo00<007ooOol0ogooJ7oo000dOol00`00Oomoo`1=Ool00`00Oomoo`3oOomWOol003Ao
o`03001oogoo04eoo`03001oo`000?moofMoo`00=7oo00<007ooOol0C7oo0P0000=oo`00Ool0ogoo
IWoo000dOol00`00Oomoo`1<Ool01000Ool00000ogooIgoo000dOol00`00Oomoo`1=Ool200000goo
001oo`3oOomUOol003Aoo`03001oogoo04eoo`04001oo`00003oOomVOol003Aoo`03001oogoo04io
o`800?moofMoo`00=7oo00<007ooOol0Cgoo00<007`0Ool0ogooIGoo000dOol00`00Oomoo`1@Ool0
0`00Oomoo`3oOomTOol003Aoo`03001oogoo051oo`03001oo`000?moofAoo`00=7oo00<007ooOol0
DGoo0P00ogooI7oo000dOol00`00Oomoo`1@Ool200000goo001oo`3oOomROol003Aoo`03001oogoo
051oo`800003O00007oo0?moof9oo`00=7oo00<007ooOol0D7oo00D007oo001oo`000?moof9oo`00
=7oo00<007ooOol0DGoo0P00ogooI7oo000dOol00`00Oomoo`1AOol00`00Ool0003oOomSOol003Ao
o`03001oogoo05=oo`03001oogoo0?moof5oo`00=7oo00<007ooOol0Dgoo00<007`00000ogooHGoo
000dOol00`00Oomoo`1DOol2003oOomQOol003Aoo`<005=oo`800003Ool007oo0?mooemoo`00=7oo
00<007ooOol0Dgoo00@007oo00000?moof1oo`00=7oo00<007ooOol0E7oo0P0000=oo`00Ool0ogoo
GWoo000dOol00`00Oomoo`1DOol200000g`0Oomoo`3oOomNOol003Aoo`03001oogoo05Eoo`800?mo
of1oo`00=7oo00<007ooOol0EWoo00<007ooOol0ogooGWoo000dOol00`00Oomoo`1GOol00`00Ool0
003oOomMOol003Aoo`03001oogoo05Moo`03001oo`000?mooeeoo`00=7oo00<007ooOol0EWoo0P00
00=l0000Ool0ogooG7oo000dOol00`00Oomoo`1FOol01@00Ool007oo0000ogooG7oo000dOol00`00
Oomoo`1GOol200000goo001oo`3oOomKOol003Aoo`03001oogoo05Moo`03001oo`000?mooeeoo`00
=7oo00<007ooOol0F7oo0P00ogooGGoo000dOol00`00Oomoo`1IOol00`00O01oo`3oOomKOol003Ao
o`03001oogoo05Yoo`03001oogoo0?mooeYoo`00=7oo0`00FWoo00<007oo0000ogooFWoo000dOol0
0`00Oomoo`1JOol3003oOomJOol003Aoo`03001oogoo05Yoo`<00?mooeYoo`00=7oo00<007ooOol0
FWoo0P0000=l0000Ool0ogooF7oo000dOol00`00Oomoo`1KOol3003oOomIOol003Aoo`03001oogoo
05]oo`800?mooeYoo`00=7oo00<007ooOol0GGoo00<007ooOol0ogooEgoo000dOol00`00Oomoo`1M
Ool00`00Oomoo`3oOomGOol003Aoo`03001oogoo05eoo`03001l00000?mooeMoo`00=7oo00<007oo
Ool0GGoo0`00ogooEgoo000dOol00`00Oomoo`1MOol200000goo001oo`3oOomEOol003Aoo`<005eo
o`04001oo`00003oOomFOol003Aoo`03001oogoo05ioo`800003Ool007oo0?mooeAoo`00=7oo00<0
07ooOol0GWoo0P0000=l07ooOol0ogooE7oo000dOol00`00Oomoo`1POol00`00Oomoo`3oOomDOol0
03Aoo`03001oogoo061oo`03001oogoo0?mooeAoo`00=7oo00<007ooOol0HGoo0P00ogooE7oo0003
Ool30004Ool20004Ool01@00Oomoogoo00000goo0`0017oo0P004goo00<007ooOol0H7oo0`00ogoo
E7oo0006Ool01000Oomoogoo0P001Goo00<007oo00001Goo00<007ooOol00Woo00@007ooOol0019o
o`03001oogoo061oo`800003O00007oo0?mooe9oo`001Woo00<007ooOol02Goo00<007ooOol017oo
00<007ooOol00Woo00@007ooOol0019oo`@0061oo`<00?mooe=oo`000goo0`002goo00<007oo0000
1Goo00<007ooOol00Woo00@007ooOol0019oo`03001oogoo065oo`800003O00007oo0?mooe5oo`00
0goo00<007ooOol02Woo00D007ooOomoo`0000Aoo`03001oogoo009oo`04001oogoo0006Ool30009
Ool00`00Oomoo`1ROol2003oOomCOol000=oo`@0015oo`8000Eoo`8000=oo`<00004Ool007oo0009
Ool00`00Oomoo`1SOol00`00Oomoo`3oOomAOol002Qoo`<000Uoo`03001oogoo06=oo`03001l07oo
0?mooe5oo`00:Goo0P002Goo00<007ooOol0I7oo00<007oo0000ogooD7oo000dOol00`00Oomoo`1S
Ool200000g`0001oo`3oOom?Ool003Aoo`<006=oo`04001oo`00003oOom@Ool003Aoo`03001oogoo
06Aoo`800003Ool007oo0?moodioo`00=7oo00<007ooOol0I7oo0P0000=l0000Ool0ogooCWoo000d
Ool00`00Oomoo`1TOol00`00Ool0003oOom@Ool003Aoo`03001oogoo06Eoo`800003O01oogoo0?mo
odeoo`00=7oo00<007ooOol0Igoo00<007ooOol0ogooCGoo000dOol3001WOol00`00Ool0003oOom=
Ool003Aoo`03001oogoo06Moo`03001l00000?moodeoo`00=7oo00<007ooOol0Igoo0P0000=oo`00
Ool0ogooBgoo000dOol00`00Oomoo`1WOol200000g`0001oo`3oOom;Ool003Aoo`03001oogoo06Mo
o`05001oo`00Ool0003oOom;Ool003Aoo`<006Qoo`800?moodeoo`00=7oo00<007ooOol0J7oo0P00
00=l07ooOol0ogooBWoo000dOol00`00Oomoo`1ZOol00`00Oomoo`3oOom:Ool003Aoo`03001oogoo
06Yoo`03001l00000?moodYoo`00=7oo00<007ooOol0Jgoo0P00ogooBWoo000dOol3001ZOol20000
0goo001oo`3oOom8Ool003Aoo`03001oogoo06Yoo`800003O00007oo0?moodQoo`001Goo0P0017oo
0P0017oo0P0017oo0P0017oo0P0017oo0P000goo0`002Goo00<007ooOol0Jgoo0P0000=oo`00Ool0
ogooAgoo0004Ool01000Oomoo`000goo0P000goo00@007ooOol0009oo`04001oogoo0002Ool01000
Oomoo`000Woo00@007ooOol000=oo`03001oogoo00Qoo`03001oogoo06]oo`800003O01oogoo0?mo
odMoo`0017oo00@007ooOol000Qoo`04001oogoo0002Ool01000Oomoo`000Woo00@007ooOol0009o
o`04001oogoo0003Ool00`00Oomoo`08Ool4001[Ool2003oOom9Ool000Aoo`04001oogoo0008Ool0
1000Oomoo`000Woo00@007ooOol0009oo`04001oogoo0002Ool01000Oomoo`000goo00<007ooOol0
27oo00<007ooOol0KGoo00<007`0Ool0ogooAgoo0004Ool01000Oomoo`0027oo00@007ooOol0009o
o`04001oogoo0002Ool01000Oomoo`000Woo00@007ooOol000=oo`03001oogoo00Qoo`03001oogoo
06ioo`04001l07oo003oOom5Ool000Eoo`8000Yoo`8000Aoo`8000Aoo`8000Aoo`8000=oo`8000Yo
o`03001oogoo06moo`03001oo`000?moodEoo`00=7oo00<007ooOol0KWoo0P0000=l07oo0000ogoo
A7oo000dOol00`00Oomoo`1^Ool01@00Ool007oo0000ogooA7oo000dOol00`00Oomoo`1_Ool20000
0g`0Ool0003oOom3Ool003Aoo`03001oogoo06moo`03001oo`000?moodEoo`00=7oo00<007ooOol0
L7oo0P0000=l07ooOol0ogoo@Woo000dOol00`00Oomoo`1bOol00`00Oomoo`3oOom2Ool003Aoo`03
001oogoo079oo`04001l07oo003oOom1Ool003Aoo`03001oogoo079oo`800003O00007oo0?mood1o
o`00=7oo00<007ooOol0LWoo00D007oo001oo`000?mood1oo`00=7oo00<007ooOol0Lgoo0P0000=l
07oo0000ogoo?goo000dOol00`00Oomoo`1cOol00`00Ool0003oOom1Ool003Aoo`03001oogoo07Ao
o`800003O01oogoo0?moocioo`00=7oo00<007ooOol0MWoo00<007ooOol0ogoo?Woo000dOol00`00
Oomoo`1fOol01000O01oo`00ogoo?Goo000dOol00`00Oomoo`1gOol00`00O000003oOolmOol003Ao
o`03001oogoo07Ioo`05001oo`00Ool0003oOollOol003Aoo`03001oogoo07Ioo`05001oo`00O000
003oOollOol003Aoo`03001oogoo07Moo`05001oo`00Ool0003oOolkOol003Aoo`03001oogoo07Mo
o`04001oo`00O03oOollOol003Aoo`03001oogoo07Qoo`03001oo`000?moocaoo`00=7oo00<007oo
Ool0NWoo00<007`0Ool0ogoo>Woo000dOol00`00Oomoo`1kOol00`00Ool0003oOoliOol003Aoo`<0
07]oo`03001l00000?moocUoo`00=7oo00<007ooOol0NWoo00D007oo001l00000?moocQoo`00=7oo
00<007ooOol0NWoo00<007ooOol00P00ogoo>7oo000dOol00`00Oomoo`1kOol01@00Ool007`00000
ogoo=goo000dOol00`00Oomoo`1kOol01000Oomoo`00ogoo>7oo000dOol00`00Oomoo`1lOol01000
Ool007`0ogoo:goo00<007ooOol02Goo000dOol00`00Oomoo`1oOol00`00Oomoo`3oOolYOol00`00
Oomoo`09Ool003Aoo`03001oogoo07moo`04001l07oo003oOolWOol00`00Oomoo`0:Ool003Aoo`03
001oogoo07moo`800003O00007oo0?moobEoo`03001oo`0000]oo`00=7oo00<007ooOol0Ogoo00D0
07oo001oo`000?moobAoo`04001oog`0000;Ool003Aoo`03001oogoo081oo`800003O00007oo0?mo
obAoo`03O00007oo00]oo`00=7oo00<007ooOol0P7oo00D007oo001oo`000?moob=oo`04O00007oo
000;Ool003Aoo`03001oogoo085oo`800003O01oogoo0?mooamoo`06001oog`0001oo`0037oo000d
Ool00`00Oomoo`23Ool00`00Oomoo`3oOolNOol01P00Ooml0000Ool000eoo`00=7oo00<007ooOol0
Pgoo00@007`0Ool00?mooaaoo`04001oogoo000@Ool003Aoo`<008Aoo`03001l00000?mooa]oo`04
001oogoo000AOol003Aoo`03001oogoo08=oo`05001oo`00Ool0003oOolLOol00`00Oomoo`0@Ool0
03Aoo`03001oogoo08=oo`05001oo`00O000003oOolKOol01000Oomoo`0047oo000dOol00`00Oomo
o`24Ool01@00Ool007oo0000ogoo6Goo00@007ooOol0015oo`00=7oo00<007ooOol0Q7oo00@007oo
001l0?mooaMoo`03001oo`00009oo`03001oogoo011oo`00=7oo00<007ooOol0QGoo00<007oo0000
ogoo5Woo00<007oo00000Woo00<007ooOol04Goo000dOol00`00Oomoo`27Ool00`00O01oo`3oOolC
Ool01000Ooml00005Woo000dOol00`00Oomoo`28Ool00`00Ool0003oOolBOol00`00O000000GOol0
03Aoo`03001oogoo08Qoo`03001l00000?mooa5oo`04001l0000Ool2000EOol003Aoo`03001oogoo
08Moo`05001oo`00O000003oOolAOol00`00Ool0000GOol003Aoo`03001oogoo08Moo`03001oogoo
00800?mooa1oo`03O000000001Qoo`00=7oo0`00R7oo00D007oo001l00000?moo`aoo`03001oog`0
008001Uoo`00=7oo00<007ooOol0R7oo00@007ooOol00?moo`aoo`04001oog`0000KOol003Aoo`03
001oogoo08Uoo`04001oo`00O03oOol:Ool01000Oomoo`0077oo000dOol00`00Oomoo`2<Ool00`00
Oomoo`3oOol7Ool01000Oomoo`007Goo000dOol00`00Oomoo`2<Ool00`00O000003oOol9Ool01000
Ool000006goo000dOol00`00Oomoo`2=Ool2003oOol8Ool01000Oomoo`0077oo000dOol00`00Oomo
o`2;Ool00`00Oomoo`02003oOol6Ool01000Oomoo`007Goo0005Ool20004Ool20004Ool20004Ool2
0004Ool20004Ool20003Ool30009Ool00`00Oomoo`2<Ool01@00Ool007`00000ogoo0Woo00<007oo
00000Woo00<007ooOol077oo0004Ool01000Oomoo`000goo0P000goo00@007ooOol0009oo`04001o
ogoo0002Ool01000Oomoo`000Woo00@007ooOol000Eoo`03001oogoo00Ioo`03001oogoo08eoo`05
001oo`00Ool0003oOol00`00Ool0000ROol000Aoo`04001oogoo0008Ool01000Oomoo`000Woo00@0
07ooOol0009oo`04001oogoo0002Ool01000Oomoo`001Goo00<007ooOol01Woo1000SGoo0P0000=l
07ooOol0oGoo00<007oo00008goo0004Ool01000Oomoo`0027oo00@007ooOol0009oo`04001oogoo
0002Ool01000Oomoo`000Woo00@007ooOol0009oo`<000Uoo`03001oogoo091oo`03001oogoo0?ao
o`03001oo`00009oo`03001oogoo01moo`0017oo00@007ooOol000Qoo`04001oogoo0002Ool01000
Oomoo`000Woo00@007ooOol0009oo`04001oogoo0002Ool00`00Oomoo`09Ool00`00Oomoo`2@Ool0
1000O01oo`00o7oo00@007ooOol0029oo`001Goo0P002Woo0P0017oo0P0017oo0P0017oo0P000goo
100027oo00<007ooOol0TGoo00<007oo0000ngoo00@007ooOol002=oo`00=7oo00<007ooOol0T7oo
0P0000=l07oo0000mgoo00<007oo00000Woo00<007ooOol08Woo000dOol00`00Oomoo`2@Ool01@00
Ool007`00000mWoo00@007ooO00002Moo`00=7oo00<007ooOol0TGoo00D007oo001oo`000?Aoo`04
001oog`0000XOol003Aoo`<0095oo`04001oo`00O03dOol01000Ooml0000:Goo000dOol00`00Oomo
o`2BOol00`00Ool0003eOol01G`0001oogoo00009goo000dOol00`00Oomoo`2DOol00`00O01oo`3c
Ool01000Oomoo`00:7oo000dOol00`00Oomoo`2EOol01000O01oo`00kGoo00L007ooOoml0000Ool0
000YOol003Aoo`03001oogoo09Ioo`03001oo`000>eoo`06001oog`0001oo`00:Woo000dOol3002D
Ool01P00Ool007`0Ool00>]oo`04001oog`0000]Ool003Aoo`03001oogoo09Eoo`06001oo`00O01o
o`00jGoo00@007ooO00002ioo`00=7oo00<007ooOol0UWoo00@007oo001l0>Uoo`06001oo`00001o
o`00;Goo000dOol00`00Oomoo`2GOol00`00Ool0003ZOol01000Oomoo`00;Woo000dOol00`00Oomo
o`2IOol00`00O01oo`3WOol01000Oomoo`00;goo000dOol3002JOol01000O01oo`00hWoo00<007oo
00000Woo00<007ooOol0;Woo000dOol00`00Oomoo`2KOol00`00Ool0003QOol00`00Ool0000dOol0
03Aoo`03001oogoo09Uoo`06001oo`00O01oo`00ggoo00@007ooO00003Aoo`00=7oo00<007ooOol0
VGoo00H007ooOol007`0003NOol01P00Ooml0000Ool003=oo`00=7oo00<007ooOol0VWoo00H007oo
Ool007oo003NOol017`0001oo`00=7oo000dOol3002KOol01000Oomoo`00gWoo00El0000Oomoo`00
03Aoo`00=7oo00<007ooOol0W7oo00@007oo001l0=Yoo`04001oog`00002Ool00`00Oomoo`0cOol0
00]oo`8000Aoo`8000Aoo`8000Aoo`8000Aoo`8000=oo`<000Uoo`03001oogoo09moo`04001oogoo
003FOol01000Ooml00000Woo00<007ooOol0=7oo000:Ool01000Oomoo`000goo0P000goo00@007oo
Ool0009oo`04001oogoo0002Ool01000Oomoo`000goo00<007ooOol027oo00<007ooOol0X7oo00<0
07oo0000eGoo00@007ooO00003Yoo`002Woo00@007ooOol000Qoo`04001oogoo0002Ool01000Oomo
o`000Woo00@007ooOol000=oo`03001oogoo00Qoo`@009eoo`06001oo`00O01oo`00dgoo00@007oo
O00003]oo`002Woo00@007ooOol000Qoo`04001oogoo0002Ool01000Oomoo`000Woo00@007ooOol0
00=oo`03001oogoo00Qoo`03001oogoo09ioo`06001oogoo001l0000e7oo00El0000Oomoo`0003Uo
o`002Woo00@007ooOol000Qoo`04001oogoo0002Ool01000Oomoo`000Woo00@007ooOol000=oo`03
001oogoo00Qoo`03001oogoo09moo`06001oogoo001oo`00dWoo00El0000Oomoo`0003Yoo`002goo
0P002Woo0P0017oo0P0017oo0P000goo0P002Woo00<007ooOol0X7oo00@007ooOol00<moo`05001o
ogooO0000002Ool00`00Oomoo`0iOol003Aoo`03001oogoo0:5oo`04001oo`00O03>Ool01000Ooml
00000Woo00<007ooOol0>Woo000dOol00`00Oomoo`2TOol01000Oomoo`00bWoo00@007ooO000041o
o`00=7oo00<007ooOol0YGoo00<007oo0000bGoo00@007ooO000045oo`00=7oo00<007ooOol0Xgoo
00H007oo001l07oo0037Ool01@00Ooml0000Ool00P00?goo000dOol00`00Oomoo`2SOol01P00Oomo
o`00Ool00<Qoo`04O00007oo0011Ool003Aoo`03001oogoo0:Aoo`06001oogoo001oo`00aWoo00Al
0000Ool0049oo`00=7oo00<007ooOol0YGoo00@007ooOol00<Aoo`06001oog`0001oo`00@goo000d
Ool00`00Oomoo`2VOol00`00Ool00033Ool01000Ooml0000AWoo000dOol00`00Oomoo`2YOol00`00
Oomoo`2oOol01000Ooml0000Agoo000dOol00`00Oomoo`2ZOol00`00Ool0002mOol01P00Ooml0000
Ool004Ioo`00=7oo00<007ooOol0ZWoo00<007`00000_Woo00Al0000Ool004Moo`00=7oo00<007oo
Ool0Z7oo00H007ooOol007oo002lOol017`0001oo`00B7oo000dOol00`00Oomoo`2YOol01P00Oomo
o`00Ool00;Moo`80009l0003001oo`0004Uoo`00=7oo00<007ooOol0ZWoo00@007ooOol00;Moo`03
001oog`0008004aoo`00=7oo00<007ooOol0Zgoo00<007oo0000]Woo00@007ooO00004ioo`00=7oo
00<007ooOol0[Woo00@007ooOol00;5oo`04001oog`00002Ool00`00Oomoo`1:Ool003Aoo`03001o
ogoo0:moo`03001oo`000;9oo`04O00007ooOol2001<Ool003Aoo`03001oogoo0:moo`04001oogoo
002`Ool01G`0001oogoo0000CWoo000dOol00`00Oomoo`2]Ool01000Oomoo`000Woo00<007ooOol0
ZGoo0P0000=oog`000000Woo00<007ooOol0CGoo000dOol00`00Oomoo`2^Ool01000Oomoo`000Woo
00<007ooOol0Ygoo00D007ooO01l000005=oo`00=7oo00<007ooOol0[goo00@007ooOol00:Yoo`03
001oog`0008005Aoo`00=7oo00<007ooOol0/7oo00@007ooOol00:Yoo`05O00007ooOol0001COol0
03Aoo`<00;Aoo`04001oogoo002UOol00g`0001oo`02Ool00`00Oomoo`1AOol003Aoo`03001oogoo
0;Eoo`04001oogoo002QOol01000Ooml00000Woo0P00E7oo000dOol00`00Oomoo`2eOol01@00O01o
ogoo0000Wgoo00@007ooO000009oo`03001oogoo05Aoo`00=7oo00<007ooOol0/goo00D007ooOol0
07`0009oo`03001oogoo09Yoo`800003Ooml000005Yoo`00=7oo00<007ooOol0]7oo00D007ooOol0
07`009eoo`05001oogooO000001KOol003Aoo`03001oogoo0;Eoo`04001oogoo002NOol2O0001000
Oomoo`00FGoo000dOol00`00Oomoo`2fOol01000Oomoo`00W7oo00=l000000000Woo00<007ooOol0
F7oo000dOol00`00Oomoo`2jOol01000Oomoo`00U7oo0P0000=oog`000000goo00<007ooOol0FGoo
000dOol00`00Oomoo`2jOol01@00O01oogoo0000TWoo00D007ooOoml000000=oo`03001oogoo05Yo
o`00=7oo00<007ooOol0^Goo00@007oo001l009oo`03001oogoo08ioo`05001oog`0O000001QOol0
03Aoo`03001oogoo0;Yoo`04001oo`00O002Ool00`00Oomoo`2<Ool00`00Ooml0002001ROol003Ao
o`03001oogoo0;]oo`04001oo`00O02AOol00g`0001oo`02Ool00`00Oomoo`1NOol003Aoo`03001o
ogoo0;aoo`04001oo`00O02;Ool20002Ool00g`0001oo`02Ool00`00Oomoo`1OOol003Aoo`03001o
ogoo0;moo`05001l07`0Ool00026Ool01P00OomoogooO00000=oo`03001oogoo061oo`00=7oo00<0
07ooOol0`7oo0P0000=l07oo0000Q7oo00<007ooOol00W`000D007ooOomoo`0006=oo`00=7oo00<0
07ooOol0`Woo00@007`0Ool0089oo`04001oogooO002001XOol003Aoo`<00;moo`08001oogooOol0
07`0Ool008=oo`05O00007ooOol0001WOol003Aoo`03001oogoo0<1oo`06001oogooOol007`0PWoo
00=l000000000goo00<007ooOol0IGoo000dOol00`00Oomoo`31Ool01P00Oomoogoo001l07eoo`80
0003Ooml000000=oo`8006Qoo`00=7oo00<007ooOol0`Woo00@007ooOomoo`800003Ool0000007Mo
o`80009oo`8000=oo`03001oogoo06Qoo`00=7oo00<007ooOol0b7oo00@007ooOol007Eoo`05001o
ogooOol0001`Ool003Aoo`03001oogoo0<Uoo`04001oogoo001fOol00g`0001oo`1`Ool003Aoo`03
001oogoo0<Eoo`03001oogoo009oo`04001oogoo001dOol20002Ool2001^Ool003Aoo`03001oogoo
0<Ioo`03001oogoo009oo`03001oogoo06moo`80009oo`05001oogooOol0001`Ool003Aoo`03001o
ogoo0<Moo`03001oogoo009oo`04001oogooOol2001YOol20002Ool20003Ool00`00Oomoo`1_Ool0
03Aoo`03001oogoo0<Qoo`03001oogoo009oo`8000=oo`03001oogoo06Eoo`03001oogoo008007Mo
o`00=7oo0`00cgoo00D007ooOomoo`0006Qoo`03001oogoo07Moo`00=7oo00<007ooOol0d7oo00D0
07ooOomoo`00061oo`8000=oo`8000=oo`8007Eoo`00=7oo00<007ooOol0c7oo00<007ooOol00Woo
00<007`0Ool0Ggoo0P000goo0P0017oo00<007ooOol0MGoo000dOol00`00Oomoo`3=Ool20003Ool2
001NOol00`00Oomoo`02Ool00`00Oomoo`03Ool00`00Oomoo`1fOol003Aoo`03001oogoo0<moo`03
001oogoo009oo`03001l07oo00<005]oo`8007moo`00=7oo00<007ooOol0eGoo00<007`0Ool00Woo
00<007ooOol0EWoo0P000goo0P00O7oo000dOol00`00Oomoo`3FOol00`00O01oo`02Ool00`00Oomo
o`1@Ool20002Ool00`00Oomoo`02Ool00`00Oomoo`1lOol000]oo`8000Aoo`8000Aoo`8000Aoo`80
00Aoo`8000=oo`<000Uoo`03001oogoo0==oo`80009oo`03001l07`0059oo`80009oo`8000Aoo`03
001oogoo07eoo`002Woo00@007ooOol000=oo`8000=oo`04001oogoo0002Ool01000Oomoo`000Woo
00@007ooOol000Eoo`03001oogoo00Ioo`03001oogoo0=Eoo`03001oogoo0080009l00=oo`8004Yo
o`03001oogoo008000Eoo`03001oogoo07ioo`002Woo00@007ooOol000Qoo`04001oogoo0002Ool0
1000Oomoo`000Woo00@007ooOol000Eoo`03001oogoo00Ioo`@00=Eoo`04001oogooOol200000g`0
Oomoo`02Ool00`00Oomoo`12Ool20004Ool20028Ool000Yoo`04001oogoo0008Ool01000Oomoo`00
0Woo00@007ooOol0009oo`04001oogoo0002Ool30009Ool00`00Oomoo`3LOol2000017`0Oomoogoo
0P00@Goo00D007ooOomoog`0008000Aoo`8008Aoo`002Woo00@007ooOol000Qoo`04001oogoo0002
Ool01000Oomoo`000Woo00@007ooOol0009oo`03001oogoo00Uoo`03001oogoo0=ioo`800003O01o
ogoo041oo`80009oo`9l0003001oogoo00=oo`03001oogoo08Aoo`002goo0P002Woo0P0017oo0P00
17oo0P000goo100027oo00<007ooOol0fWoo0P0017oo0P001Goo0`00>goo0W`00P0017oo0P00Qgoo
000dOol00`00Oomoo`3LOol20004Ool200000g`0Oomoo`03Ool2000`Ool30004Ool2O002002?Ool0
03Aoo`03001oogoo0=ioo`03001oogoo00=oo`80009l039oo`8000Aoo`9l00<000=oo`8008aoo`00
=7oo00<007ooOol0iWoo0`000W`017oo0`008Woo0`001goo00Al0000000000Aoo`8008ioo`00=7oo
0`00hWoo0P001Goo0P000g`017oo0P007Woo0P0027oo0`001Woo00<007ooOol0SWoo000dOol00`00
Oomoo`3TOol20005Ool30003O007Ool5000<Ool5000;Ool30004Ool2002DOol003Aoo`03001oogoo
0>Ioo`03001oogoo00Eoo`<000Al00]oo`H000moo`@000Eoo`8009Ioo`00=7oo00<007ooOol0jWoo
00<007ooOol017oo100017`057oo0g`01@0027oo00<007ooOol0UWoo000dOol00`00Oomoo`3[Ool3
0007Ool8000<O0070008Ool2002LOol003Aoo`03001oogoo0>ioo`03001oogoo00aoo``000eoo`80
09ioo`00=7oo0`00lWoo0`006goo0P000goo00<007ooOol0WWoo000dOol00`00Oomoo`3eOol20004
Ool2000?Ool4002VOol003Aoo`03001oogoo0?eoo`<000Aoo`D00:eoo`00=7oo00<007ooOol0ogoo
]goo000dOol00`00Oomoo`3oOongOol003Aoo`<00?mookMoo`00=7oo00<007ooOol0ogoo]goo000d
Ool00`00Oomoo`3oOongOol003Aoo`03001oogoo0?mookMoo`00ogookWoo003oOoo^Ool00?moonio
o`00ogookWoo003oOoo^Ool00?moonioo`00ogookWoo0000\
\>"],
  ImageRangeCache->{{{0, 492}, {303.562, 0}} -> {-1.80346, -6.4524, 
  0.00727348, 0.0114606}}]
}, Closed]],

Cell["\<\
Choosing \[Phi]=1 gives a more even weighting to the paths:\
\>", \
"MathCaption"],

Cell[BoxData[
    \(\(tt2 = Table[MonteCarloGriffithsTavare[S, \[Theta], 1. ], {1000}]; 
    \)\)], "Input",
  CellLabel->"In[102]:="],

Cell[CellGroupData[{

Cell[BoxData[
    \(ftt2 = Frequencies[tt2]\)], "Input",
  CellLabel->"In[103]:="],

Cell[BoxData[
    \({{488, 
        \(0.0246913580246913566`\ \[Theta]\^4\)\/\(\((1 + \[Theta])\)\^2\ 
            \((2 + \[Theta])\)\^4\)}, {241, 
        \(0.0493827160493827133`\ \[Theta]\^4\)\/\(\((1 + \[Theta])\)\^2\ 
            \((2 + \[Theta])\)\^4\)}, {100, 
        \(0.148148148148148139`\ \[Theta]\^4\)\/\(\((1 + \[Theta])\)\^2\ 
            \((2 + \[Theta])\)\^4\)}, {171, 
        \(0.222222222222222232`\ \[Theta]\^4\)\/\(\((1 + \[Theta])\)\^3\ 
            \((2 + \[Theta])\)\^3\)}}\)], "Output",
  CellLabel->"Out[103]="]
}, Closed]],

Cell["The estimated likelihood is therefore more accurate:", "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[
    \(se2 = StandardErrorOfSampleMean[tt2]; mn2 = Mean[tt2]; 
    \n{se, se2} /. \[Theta] -> 10. \)], "Input",
  CellLabel->"In[104]:="],

Cell[BoxData[
    \({0.0000238948774179221512`, 0.0000103171903164216427`}\)], "Output",
  CellLabel->"Out[106]="]
}, Closed]]
}, Open  ]],

Cell[CellGroupData[{

Cell["A small example", "SubsectionIcon",
  CellTags->"Small example"],

Cell["Here is an example with 6 lineages and 24 mutations:", "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[
    \(g = RandomGenealogy[{a, b, c, d, e, f}, MutationRate \[Rule] 10]\)], 
  "Input",
  CellLabel->"In[260]:="],

Cell[BoxData[
    \(Node[
      6, {1.28675042272018846`, {}}, {
        Node[5, {1.28675042272018846`, {}}, {
            Node[4, {0.460568303968890102`, {1, 2, 3, 4, 5, 6, 7, 8}}, {
                Node[a, {0, {1, 2, 3, 4, 5, 6, 7, 8, 15, 16, 17}}, {}], 
                Node[e, {0, {1, 2, 3, 4, 5, 6, 7, 8, 20, 21}}, {}]}], 
            Node[3, {0.280020725880075502`, {9, 10, 11, 12, 13, 14}}, {
                Node[b, {0, {9, 10, 11, 12, 13, 14, 18, 19}}, {}], 
                Node[2, {
                    0.030003076851307715`, {9, 10, 11, 12, 13, 14, 23}}, {
                    Node[c, {0, {9, 10, 11, 12, 13, 14, 22, 23}}, {}], 
                    Node[1, {
                        0.0194462436152796485`, {9, 10, 11, 12, 13, 14, 23, 
                          24}}, {
                        Node[d, {0, {9, 10, 11, 12, 13, 14, 23, 24}}, {}], 
                        Node[f, {
                            0, {9, 10, 11, 12, 13, 14, 23, 24}}, {}]}]}]}]}]}]
      \)], "Output",
  CellLabel->"Out[158]="]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    \(Show[PlotGenealogy[g]]; \nnm = \(NumberOfMutations[g, #]&\)/@Nodes[g]; 
    \n{Nodes[g], nm} // TableForm\)], "Input",
  CellLabel->"In[159]:="],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.142857 0.142857 0.0882906 0.0882906 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
0 g
.5 Mabswid
[ ] 0 setdash
.78571 .17658 m
.71429 .08829 L
s
.78571 .17658 m
.85714 .08829 L
s
.71429 .26487 m
.57143 .08829 L
s
.71429 .26487 m
.78571 .17658 L
s
.64286 .35316 m
.42857 .08829 L
s
.64286 .35316 m
.71429 .26487 L
s
.21429 .17658 m
.14286 .08829 L
s
.21429 .17658 m
.28571 .08829 L
s
.5 .44145 m
.21429 .17658 L
s
.5 .44145 m
.64286 .35316 L
s
.5 .52974 m
.5 .44145 L
s
[(1)] .75714 .19424 0 0 Mshowa
[(2)] .68571 .28253 0 0 Mshowa
[(3)] .61429 .37082 0 0 Mshowa
[(4)] .18571 .19424 0 0 Mshowa
[(5)] .47143 .45911 0 0 Mshowa
[(6)] .47143 .5474 0 0 Mshowa
gsave
.14286 .07063 -66 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 16.000000 moveto
 558.000000 16.000000 lineto
 558.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 16.000000 lineto
closepath
clip newpath
63.000000 13.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(a) show
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: font Courier
grestore
gsave
.28571 .07063 -66 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 16.000000 moveto
 558.000000 16.000000 lineto
 558.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 16.000000 lineto
closepath
clip newpath
63.000000 13.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(e) show
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: font Courier
grestore
gsave
.42857 .07063 -66 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 16.000000 moveto
 558.000000 16.000000 lineto
 558.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 16.000000 lineto
closepath
clip newpath
63.000000 13.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(b) show
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: font Courier
grestore
gsave
.57143 .07063 -66 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 16.000000 moveto
 558.000000 16.000000 lineto
 558.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 16.000000 lineto
closepath
clip newpath
63.000000 13.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(c) show
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: font Courier
grestore
gsave
.71429 .07063 -66 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 16.000000 moveto
 558.000000 16.000000 lineto
 558.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 16.000000 lineto
closepath
clip newpath
63.000000 13.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(d) show
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: font Courier
grestore
gsave
.85714 .07063 -66 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 16.000000 moveto
 558.000000 16.000000 lineto
 558.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 16.000000 lineto
closepath
clip newpath
63.000000 13.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(f) show
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: font Courier
grestore
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[159]:=",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/A000`40O003h00Oogoo8Goo003oOolQ
Ool00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00
ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQ
Ool00?moob5oo`009goo1@009Goo100097oo10009Goo0`009Woo1@008goo1000:Goo000WOol01000
Oomoo`009Goo00<007ooOol09Woo00D007ooOomoo`0002=oo`05001oogooOol0000TOol01@00Oomo
ogoo00009Goo00<007ooOol0:Goo000WOol4000UOol5000TOol01@00Oomoogoo00008goo00<007oo
Ool09Woo00D007ooOomoo`0002Eoo`03001oogoo02Uoo`00:Woo00<007ooOol08goo00D007ooOomo
o`0002Aoo`05001oogooOol0000SOol01@00Oomoogoo000097oo00D007ooOomoo`0002Eoo`03001o
ogoo02Uoo`00:7oo0`009Woo0`009Goo10009Goo10009Goo100097oo1000:Goo001iOol00`00Oomo
o`1BOol00`00Oomoo`0SOol00`00Oomoo`0YOol007Qoo`8005=oo`8002Eoo`<002Uoo`00:Goo00<0
07ooOol09Woo00<007ooOol09Woo00<007ooOol09Goo00<007ooOol09Woo00<007ooOol09Woo00<0
07ooOol0:7oo000YOol00`00Oomoo`0VOol00`00Oomoo`0VOol00`00Oomoo`0UOol00`00Oomoo`0V
Ool00`00Oomoo`0VOol00`00Oomoo`0XOol002Yoo`03001oogoo02Aoo`03001oogoo02Qoo`03001o
ogoo02Eoo`03001oogoo02Ioo`03001oogoo02Aoo`03001oogoo02Uoo`00:goo00<007ooOol08Woo
00<007ooOol0:Woo00<007ooOol09Goo00<007ooOol09Woo00<007ooOol08Woo00<007ooOol0:Woo
000/Ool00`00Oomoo`0POol00`00Oomoo`0/Ool00`00Oomoo`0UOol00`00Oomoo`0VOol00`00Oomo
o`0POol00`00Oomoo`0[Ool002eoo`03001oogoo01ioo`03001oogoo02ioo`03001oogoo02Eoo`03
001oogoo02Ioo`03001oogoo01ioo`03001oogoo02aoo`00;Goo00<007ooOol07Goo00<007ooOol0
;goo00<007ooOol09Woo00<007ooOol09Woo00<007ooOol07Goo00<007ooOol0;7oo000^Ool00`00
Oomoo`0LOol00`00Oomoo`0`Ool00`00Oomoo`0UOol00`00Oomoo`0VOol00`00Oomoo`0LOol00`00
Oomoo`0]Ool002moo`03001oogoo01Yoo`03001oogoo039oo`03001oogoo02Eoo`03001oogoo02Io
o`03001oogoo01Yoo`03001oogoo02ioo`00<7oo00<007ooOol067oo00<007ooOol0=7oo00<007oo
Ool09Goo00<007ooOol09Woo00<007ooOol067oo00<007ooOol0;goo000aOol00`00Oomoo`0FOol0
0`00Oomoo`0fOol00`00Oomoo`0UOol00`00Oomoo`0VOol00`00Oomoo`0FOol00`00Oomoo`0`Ool0
035oo`03001oogoo01Eoo`03001oogoo03Moo`03001oogoo02Ioo`03001oogoo02Ioo`03001oogoo
01Eoo`03001oogoo031oo`00<Woo00<007ooOol04goo00<007ooOol0>Goo00<007ooOol09Goo00<0
07ooOol09goo00<007ooOol04goo00<007ooOol0<Goo000cOol00`00Oomoo`0AOol00`00Oomoo`0k
Ool00`00Oomoo`0UOol00`00Oomoo`0WOol00`00Oomoo`0AOol00`00Oomoo`0bOol003Aoo`03001o
ogoo011oo`03001oogoo03aoo`03001oogoo02Eoo`03001oogoo02Ioo`03001oogoo011oo`03001o
ogoo03=oo`00=Goo00<007ooOol03Woo00<007ooOol0?Woo00<007ooOol09Goo00<007ooOol09Woo
00<007ooOol03Woo00<007ooOol0=7oo000eOol00`00Oomoo`0=Ool00`00Oomoo`0oOol00`00Oomo
o`0VOol00`00Oomoo`0VOol00`00Oomoo`0=Ool00`00Oomoo`0dOol003Ioo`03001oogoo00]oo`03
001oogoo045oo`03001oogoo02Ioo`03001oogoo02Ioo`03001oogoo00]oo`03001oogoo03Eoo`00
=goo00<007ooOol02Goo00<007ooOol0@goo00<007ooOol09Goo00<007ooOol09goo00<007ooOol0
2Goo00<007ooOol0=Woo000hOol00`00Oomoo`07Ool00`00Oomoo`15Ool00`00Oomoo`0UOol00`00
Oomoo`0WOol00`00Oomoo`07Ool00`00Oomoo`0gOol003Uoo`03001oogoo00Ioo`03001oogoo04Io
o`03001oogoo02Eoo`03001oogoo02Ioo`03001oogoo00Ioo`03001oogoo03Qoo`00>Goo00<007oo
Ool01Goo00<007ooOol0Agoo00<007ooOol09Woo00<007ooOol09Woo00<007ooOol01Goo00<007oo
Ool0>7oo000jOol00`00Oomoo`03Ool00`00Oomoo`19Ool00`00Oomoo`0VOol00`00Oomoo`0VOol0
0`00Oomoo`03Ool00`00Oomoo`0iOol003]oo`05001oogooOol0001=Ool00`00Oomoo`0UOol00`00
Oomoo`0WOol01@00Oomoogoo0000?7oo000lOol00`00Ool0001?Ool00`00Oomoo`0UOol00`00Oomo
o`0WOol00`00Ool0000mOol003eoo`80051oo`03001oogoo02Eoo`03001oogoo02Moo`03001oogoo
03aoo`00?goo00<007ooOol0CGoo00<007ooOol09Woo00<007ooOol09Woo00<007ooOol0?7oo0010
Ool00`00Oomoo`1=Ool00`00Oomoo`0VOol00`00Oomoo`0TOol00`00Oomoo`0mOol003Aoo`<000Yo
o`03001oogoo04eoo`03001oogoo02Ioo`03001oogoo01Yoo`<000Eoo`03001oogoo03ioo`00=Goo
00<007ooOol02Woo00<007ooOol0CGoo00<007ooOol09Goo00<007ooOol06goo00<007ooOol00goo
00<007ooOol0?goo000cOol4000<Ool00`00Oomoo`1=Ool00`00Oomoo`0UOol00`00Oomoo`0JOol0
0`00Oomoo`02Ool00`00Oomoo`10Ool003=oo`03001oo`0000ioo`03001oogoo04aoo`03001oogoo
02Ioo`03001oogoo01Uoo`05001oogooOol00013Ool003=oo`03001oo`0000moo`03001oogoo04ao
o`03001oogoo02Ioo`03001oogoo01Qoo`05001oogooOol00013Ool003Aoo`80011oo`03001oogoo
04aoo`03001oogoo02Ioo`03001oogoo01Ioo`80009oo`03001oogoo049oo`00Agoo00<007ooOol0
C7oo00<007ooOol09Goo00<007ooOol06Goo00<007ooOol0@goo0018Ool00`00Oomoo`1<Ool00`00
Oomoo`0UOol00`00Oomoo`0GOol00`00Oomoo`14Ool004Uoo`03001oogoo04]oo`03001oogoo02Io
o`03001oogoo01Eoo`03001oogoo04Eoo`00BWoo00<007ooOol0Bgoo00<007ooOol09Woo00<007oo
Ool04goo00<007ooOol0AWoo001;Ool2001<Ool00`00Oomoo`0VOol00`00Oomoo`0AOol00`00Oomo
o`17Ool004eoo`03001oogoo04Yoo`03001oogoo02Ioo`03001oogoo011oo`03001oogoo04Moo`00
CWoo00<007ooOol0BWoo00<007ooOol09Goo00<007ooOol03goo00<007ooOol0B7oo001?Ool00`00
Oomoo`1:Ool00`00Oomoo`0UOol00`00Oomoo`0=Ool00`00Oomoo`19Ool0051oo`03001oogoo04Uo
o`03001oogoo02Ioo`03001oogoo00]oo`03001oogoo04Yoo`00DGoo00<007ooOol0BGoo00<007oo
Ool09Woo00<007ooOol02Goo00<007ooOol0Bgoo001BOol00`00Oomoo`19Ool00`00Oomoo`0VOol0
0`00Oomoo`07Ool00`00Oomoo`1<Ool005=oo`03001oogoo04Uoo`03001oogoo02Eoo`03001oogoo
00Moo`03001oogoo04aoo`00E7oo00<007ooOol0BGoo00<007ooOol09Goo00<007ooOol01Goo00<0
07ooOol0CGoo001EOol00`00Oomoo`18Ool00`00Oomoo`0VOol00`00Oomoo`03Ool00`00Oomoo`1>
Ool005Ioo`03001oogoo04Qoo`03001oogoo02Ioo`05001oogooOol0001AOol005Moo`03001oogoo
04Qoo`03001oogoo02Ioo`03001oo`00059oo`00F7oo0P00BGoo00<007ooOol09Woo00<007ooOol0
DGoo001JOol00`00Oomoo`17Ool00`00Oomoo`0UOol00`00Oomoo`1AOol005]oo`03001oogoo04Io
o`03001oogoo02Aoo`03001oogoo059oo`00G7oo00<007ooOol0AWoo00<007ooOol06Woo100017oo
00<007ooOol0Dgoo001MOol00`00Oomoo`16Ool00`00Oomoo`0JOol00`00Oomoo`03Ool00`00Oomo
o`1DOol005ioo`03001oogoo04Ioo`03001oogoo01Yoo`03001oogoo009oo`03001oogoo05Aoo`00
Ggoo00<007ooOol0AWoo00<007ooOol06Woo00@007ooOol005Moo`00H7oo00<007ooOol0AGoo00<0
07ooOol05goo00H007ooOol007oo001HOol0065oo`03001oogoo04Eoo`03001oogoo01Moo`800003
Ool007oo05Qoo`00HWoo00<007ooOol0AGoo00<007ooOol067oo00<007ooOol0F7oo001SOol00`00
Oomoo`15Ool00`00Oomoo`0GOol00`00Oomoo`1HOol006Aoo`03001oogoo04Eoo`03001oogoo01Eo
o`03001oogoo05Uoo`00IGoo00<007ooOol0A7oo00<007ooOol057oo00<007ooOol0FWoo001VOol2
0015Ool00`00Oomoo`0BOol00`00Oomoo`1KOol006Qoo`03001oogoo04=oo`03001oogoo015oo`03
001oogoo05]oo`00JGoo00<007ooOol0@goo00<007ooOol03goo00<007ooOol0G7oo001ZOol00`00
Oomoo`13Ool00`00Oomoo`0=Ool00`00Oomoo`1MOol006]oo`03001oogoo049oo`03001oogoo00ao
o`03001oogoo05ioo`00K7oo00<007ooOol0@Woo00<007ooOol02goo00<007ooOol0GWoo001]Ool0
0`00Oomoo`12Ool00`00Oomoo`09Ool00`00Oomoo`1OOol006ioo`03001oogoo049oo`03001oogoo
00Moo`03001oogoo061oo`00Kgoo00<007ooOol0@Woo00<007ooOol01Goo00<007ooOol0HGoo001`
Ool00`00Oomoo`11Ool00`00Oomoo`04Ool00`00Oomoo`1ROol0075oo`03001oogoo045oo`03001o
ogoo00=oo`03001oogoo069oo`00LWoo00<007ooOol0@Goo00D007ooOomoo`0006Eoo`00Lgoo00<0
07ooOol0@Goo00<007oo0000IWoo001dOol20011Ool2001WOol007Ioo`03001oogoo03eoo`03001o
ogoo06Moo`00Mgoo00<007ooOol0>Woo0P00JWoo001hOol00`00Oomoo`0cOol300000goo0000001/
Ool007Uoo`03001oogoo03Eoo`03001oogoo06aoo`00NWoo00<007ooOol0<Woo0`00KWoo001kOol0
0`00Oomoo`0_Ool4001_Ool007aoo`03001oogoo02eoo`03001oogoo009oo`03001oogoo06aoo`00
OGoo00<007ooOol0:Woo0P000Woo0`00Kgoo001nOol00`00Oomoo`0WOol2001fOol007moo`03001o
ogoo02Eoo`03001oogoo07Ioo`00P7oo00<007ooOol08Woo0P00NGoo0021Ool2000POol2001kOol0
08=oo`03001oogoo01aoo`03001oogoo07]oo`00Q7oo00<007ooOol06Goo0P00OWoo0025Ool00`00
Oomoo`0GOol00`00Oomoo`1nOol008Ioo`03001oogoo01Aoo`80085oo`00Qgoo00<007ooOol04Goo
0P00Pgoo0028Ool00`00Oomoo`0?Ool00`00Oomoo`23Ool008Uoo`03001oogoo00aoo`8008Ioo`00
RWoo00<007ooOol02Goo0P00R7oo002;Ool00`00Oomoo`07Ool00`00Oomoo`28Ool008aoo`03001o
ogoo00Aoo`8008]oo`00SGoo00@007ooOomoo`8008eoo`00SWoo00<007oo0000Sgoo002?Ool00`00
Oomoo`2>Ool008moo`03001oogoo08ioo`00Sgoo00<007ooOol0SWoo0025Ool30007Ool00`00Oomo
o`2>Ool008Qoo`03001oogoo00Aoo`03001oogoo08ioo`00R7oo00<007ooOol017oo00<007ooOol0
SWoo0025Ool30007Ool00`00Oomoo`2>Ool008Eoo`03001oogoo00Moo`03001oogoo08ioo`00QGoo
10001Woo00<007ooOol0SWoo002?Ool00`00Oomoo`2>Ool008moo`03001oogoo08ioo`00Sgoo00<0
07ooOol0SWoo002?Ool00`00Oomoo`2>Ool008moo`03001oogoo08ioo`00Sgoo00<007ooOol0SWoo
002?Ool00`00Oomoo`2>Ool008moo`03001oogoo08ioo`00Sgoo00<007ooOol0SWoo002?Ool00`00
Oomoo`2>Ool008moo`03001oogoo08ioo`00Sgoo00<007ooOol0SWoo002?Ool00`00Oomoo`2>Ool0
08moo`03001oogoo08ioo`00Sgoo00<007ooOol0SWoo002?Ool00`00Oomoo`2>Ool008moo`03001o
ogoo08ioo`00ogoo8Goo003oOolQOol008Ioo`8009Qoo`00QGoo00@007ooOol009Moo`00QGoo00@0
07ooOol009Moo`00QGoo0`00V7oo0025Ool00`00Oomoo`2HOol008Ioo`<009Moo`00ogoo8Goo003o
OolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5o
o`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003o
OolQOol00001\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-1.00868, -1.00004, 
  0.0244508, 0.0395621}}],

Cell[BoxData[
    TagBox[GridBox[{
          {"a", "e", "4", "b", "c", "d", "f", "1", "2", "3", "5", "6"},
          {"3", "2", "8", "2", "1", "0", "0", "1", "1", "6", "0", "0"}
          },
        RowSpacings->1,
        ColumnSpacings->3,
        RowAlignments->Baseline,
        ColumnAlignments->{Left}],
      (TableForm[ #]&)]], "Output",
  CellLabel->"Out[159]//TableForm="]
}, Closed]],

Cell["Here is the configuration of mutations:", "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[
    \(S = GenealogyToMatrix[g]; S // MatrixForm\)], "Input",
  CellLabel->"In[160]:="],

Cell[BoxData[
    TagBox[
      RowBox[{"(", GridBox[{
            {"1", "1", "1", "1", "1", "1", "1", "1", "0", "0", "0", "0", "0", 
              "0", "1", "1", "1", "0", "0", "0", "0", "0", "0", "0"},
            {"1", "1", "1", "1", "1", "1", "1", "1", "0", "0", "0", "0", "0", 
              "0", "0", "0", "0", "0", "0", "1", "1", "0", "0", "0"},
            {"0", "0", "0", "0", "0", "0", "0", "0", "1", "1", "1", "1", "1", 
              "1", "0", "0", "0", "1", "1", "0", "0", "0", "0", "0"},
            {"0", "0", "0", "0", "0", "0", "0", "0", "1", "1", "1", "1", "1", 
              "1", "0", "0", "0", "0", "0", "0", "0", "1", "1", "0"},
            {"0", "0", "0", "0", "0", "0", "0", "0", "1", "1", "1", "1", "1", 
              "1", "0", "0", "0", "0", "0", "0", "0", "0", "1", "1"},
            {"0", "0", "0", "0", "0", "0", "0", "0", "1", "1", "1", "1", "1", 
              "1", "0", "0", "0", "0", "0", "0", "0", "0", "1", "1"}
            }], ")"}],
      (MatrixForm[ #]&)]], "Output",
  CellLabel->"Out[160]//MatrixForm="]
}, Closed]],

Cell["This is the relevant order of leaves in the matrix:", "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[
    \(CollapseGenealogy[g, Nested \[Rule] False, Node -> False]\)], "Input",
  CellLabel->"In[161]:="],

Cell[BoxData[
    \({a, e, b, c, d, f}\)], "Output",
  CellLabel->"Out[161]="]
}, Closed]],

Cell["In this example, the genealogy is fully resolved:", "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[
    \(g2 = MatrixToGenealogy[S, {a, e, b, c, d, f}, Range[24]]; \n
    Show[PlotGenealogy[g2]]; \)], "Input",
  CellLabel->"In[163]:="],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.142857 0.142857 0.103006 0.103006 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
0 g
.5 Mabswid
[ ] 0 setdash
.5 .51503 m
.21429 .20601 L
s
.5 .51503 m
.64286 .41202 L
s
.21429 .20601 m
.14286 .10301 L
s
.21429 .20601 m
.28571 .10301 L
s
.64286 .41202 m
.42857 .10301 L
s
.64286 .41202 m
.71429 .30902 L
s
.71429 .30902 m
.57143 .10301 L
s
.71429 .30902 m
.78571 .20601 L
s
.78571 .20601 m
.71429 .10301 L
s
.78571 .20601 m
.85714 .10301 L
s
[(1)] .47143 .53563 0 0 Mshowa
[(2)] .18571 .22661 0 0 Mshowa
[(3)] .61429 .43262 0 0 Mshowa
[(4)] .68571 .32962 0 0 Mshowa
[(5)] .75714 .22661 0 0 Mshowa
gsave
.14286 .0824 -66 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 16.000000 moveto
 558.000000 16.000000 lineto
 558.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 16.000000 lineto
closepath
clip newpath
63.000000 13.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(a) show
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: font Courier
grestore
gsave
.28571 .0824 -66 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 16.000000 moveto
 558.000000 16.000000 lineto
 558.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 16.000000 lineto
closepath
clip newpath
63.000000 13.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(e) show
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: font Courier
grestore
gsave
.42857 .0824 -66 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 16.000000 moveto
 558.000000 16.000000 lineto
 558.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 16.000000 lineto
closepath
clip newpath
63.000000 13.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(b) show
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: font Courier
grestore
gsave
.57143 .0824 -66 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 16.000000 moveto
 558.000000 16.000000 lineto
 558.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 16.000000 lineto
closepath
clip newpath
63.000000 13.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(c) show
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: font Courier
grestore
gsave
.71429 .0824 -66 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 16.000000 moveto
 558.000000 16.000000 lineto
 558.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 16.000000 lineto
closepath
clip newpath
63.000000 13.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(d) show
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: font Courier
grestore
gsave
.85714 .0824 -66 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 16.000000 moveto
 558.000000 16.000000 lineto
 558.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 16.000000 lineto
closepath
clip newpath
63.000000 13.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(f) show
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: font Courier
grestore
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[163]:=",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 8}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/A000`40O003h00Oogoo8Goo003oOolQ
Ool00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00
ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQ
Ool00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`009goo1@009Goo100097oo10009Goo0`00
9Woo1@008goo1000:Goo000WOol01000Oomoo`009Goo00<007ooOol09Woo00D007ooOomoo`0002=o
o`05001oogooOol0000TOol01@00Oomoogoo00009Goo00<007ooOol0:Goo000WOol4000UOol5000T
Ool01@00Oomoogoo00008goo00<007ooOol09Woo00D007ooOomoo`0002Eoo`03001oogoo02Uoo`00
:Woo00<007ooOol08goo00D007ooOomoo`0002Aoo`05001oogooOol0000SOol01@00Oomoogoo0000
97oo00D007ooOomoo`0002Eoo`03001oogoo02Uoo`00:7oo0`009Woo0`009Goo10009Goo10009Goo
100097oo1000:Goo001iOol00`00Oomoo`1BOol00`00Oomoo`0SOol00`00Oomoo`0YOol007Qoo`80
05=oo`8002Eoo`<002Uoo`00ogoo8Goo000YOol00`00Oomoo`0VOol00`00Oomoo`0VOol00`00Oomo
o`0UOol00`00Oomoo`0VOol00`00Oomoo`0VOol00`00Oomoo`0XOol002Uoo`03001oogoo02Ioo`03
001oogoo02Ioo`03001oogoo02Eoo`03001oogoo02Ioo`03001oogoo02Ioo`03001oogoo02Qoo`00
:Woo00<007ooOol097oo00<007ooOol0:7oo00<007ooOol09Goo00<007ooOol09Woo00<007ooOol0
97oo00<007ooOol0:Goo000[Ool00`00Oomoo`0ROol00`00Oomoo`0ZOol00`00Oomoo`0UOol00`00
Oomoo`0VOol00`00Oomoo`0ROol00`00Oomoo`0ZOol002]oo`03001oogoo029oo`03001oogoo02Yo
o`03001oogoo02Eoo`03001oogoo02Ioo`03001oogoo029oo`03001oogoo02Yoo`00;7oo00<007oo
Ool087oo00<007ooOol0;7oo00<007ooOol09Goo00<007ooOol09Woo00<007ooOol087oo00<007oo
Ool0:goo000]Ool00`00Oomoo`0NOol00`00Oomoo`0^Ool00`00Oomoo`0UOol00`00Oomoo`0VOol0
0`00Oomoo`0NOol00`00Oomoo`0/Ool002eoo`03001oogoo01eoo`03001oogoo02moo`03001oogoo
02Ioo`03001oogoo02Ioo`03001oogoo01eoo`03001oogoo02aoo`00;Woo00<007ooOol077oo00<0
07ooOol0<7oo00<007ooOol09Goo00<007ooOol09Woo00<007ooOol077oo00<007ooOol0;Goo000_
Ool00`00Oomoo`0JOol00`00Oomoo`0bOol00`00Oomoo`0UOol00`00Oomoo`0VOol00`00Oomoo`0J
Ool00`00Oomoo`0^Ool002moo`03001oogoo01Uoo`03001oogoo03Aoo`03001oogoo02Eoo`03001o
ogoo02Ioo`03001oogoo01Uoo`03001oogoo02ioo`00<7oo00<007ooOol067oo00<007ooOol0=7oo
00<007ooOol09Goo00<007ooOol09Woo00<007ooOol067oo00<007ooOol0;goo000aOol00`00Oomo
o`0FOol00`00Oomoo`0fOol00`00Oomoo`0UOol00`00Oomoo`0VOol00`00Oomoo`0FOol00`00Oomo
o`0`Ool0035oo`03001oogoo01Eoo`03001oogoo03Qoo`03001oogoo02Eoo`03001oogoo02Ioo`03
001oogoo01Eoo`03001oogoo031oo`00<Woo00<007ooOol057oo00<007ooOol0>7oo00<007ooOol0
9Goo00<007ooOol09Woo00<007ooOol057oo00<007ooOol0<Goo000cOol00`00Oomoo`0BOol00`00
Oomoo`0jOol00`00Oomoo`0UOol00`00Oomoo`0VOol00`00Oomoo`0BOol00`00Oomoo`0bOol003=o
o`03001oogoo015oo`03001oogoo03aoo`03001oogoo02Eoo`03001oogoo02Ioo`03001oogoo015o
o`03001oogoo039oo`00=7oo00<007ooOol03goo00<007ooOol0?Goo00<007ooOol09Goo00<007oo
Ool09goo00<007ooOol03goo00<007ooOol0<goo000eOol00`00Oomoo`0>Ool00`00Oomoo`0nOol0
0`00Oomoo`0UOol00`00Oomoo`0VOol00`00Oomoo`0>Ool00`00Oomoo`0dOol003Eoo`03001oogoo
00eoo`03001oogoo041oo`03001oogoo02Eoo`03001oogoo02Ioo`03001oogoo00eoo`03001oogoo
03Aoo`00=Woo00<007ooOol02goo00<007ooOol0@Goo00<007ooOol09Woo00<007ooOol09Woo00<0
07ooOol02goo00<007ooOol0=Goo000gOol00`00Oomoo`0:Ool00`00Oomoo`12Ool00`00Oomoo`0U
Ool00`00Oomoo`0VOol00`00Oomoo`0:Ool00`00Oomoo`0fOol003Moo`03001oogoo00Uoo`03001o
ogoo04Aoo`03001oogoo02Eoo`03001oogoo02Ioo`03001oogoo00Uoo`03001oogoo03Ioo`00>7oo
00<007ooOol01goo00<007ooOol0AGoo00<007ooOol09Woo00<007ooOol09Woo00<007ooOol01goo
00<007ooOol0=goo000iOol00`00Oomoo`06Ool00`00Oomoo`16Ool00`00Oomoo`0UOol00`00Oomo
o`0VOol00`00Oomoo`06Ool00`00Oomoo`0hOol003Uoo`03001oogoo00Eoo`03001oogoo04Qoo`03
001oogoo02Eoo`03001oogoo02Ioo`03001oogoo00Eoo`03001oogoo03Qoo`00>Woo00<007ooOol0
0goo00<007ooOol0BGoo00<007ooOol09Woo00<007ooOol09Woo00<007ooOol00goo00<007ooOol0
>Goo000kOol01@00Oomoogoo0000CGoo00<007ooOol09Goo00<007ooOol09goo00D007ooOomoo`00
03aoo`00>goo00D007ooOomoo`0004ioo`03001oogoo02Eoo`03001oogoo02Ioo`05001oogooOol0
000lOol003aoo`03001oo`00051oo`03001oogoo02Eoo`03001oogoo02Ioo`03001oo`0003eoo`00
?Goo00<007ooOol0Cgoo00<007ooOol09Woo00<007ooOol09Woo00<007ooOol0?7oo000mOol00`00
Oomoo`1@Ool00`00Oomoo`0UOol00`00Oomoo`0VOol00`00Oomoo`0lOol003ioo`03001oogoo051o
o`03001oogoo02Eoo`03001oogoo02Aoo`03001oogoo03eoo`00<goo100027oo00<007ooOol0Cgoo
00<007ooOol09Woo00<007ooOol06Woo0`001Goo00<007ooOol0?Woo000dOol00`00Oomoo`09Ool0
0`00Oomoo`1?Ool00`00Oomoo`0UOol00`00Oomoo`0MOol01@00Oomoogoo0000@Goo000eOol00`00
Oomoo`09Ool00`00Oomoo`1?Ool00`00Oomoo`0UOol00`00Oomoo`0LOol01@00Oomoogoo0000@Goo
000fOol00`00Oomoo`09Ool00`00Oomoo`1>Ool00`00Oomoo`0VOol00`00Oomoo`0HOol30003Ool0
0`00Oomoo`10Ool003=oo`04001oogoo000<Ool00`00Oomoo`1>Ool00`00Oomoo`0UOol00`00Oomo
o`0HOol00`00Oomoo`02Ool00`00Oomoo`11Ool003Aoo`8000ioo`03001oogoo04ioo`03001oogoo
02Eoo`03001oogoo01Moo`@00003Ool007oo049oo`00AGoo00<007ooOol0CGoo00<007ooOol09Woo
00<007ooOol06Woo00<007ooOol0@Woo0016Ool00`00Oomoo`1=Ool00`00Oomoo`0UOol00`00Oomo
o`0IOol00`00Oomoo`13Ool004Moo`03001oogoo04eoo`03001oogoo02Eoo`03001oogoo01Moo`03
001oogoo04Aoo`00B7oo00<007ooOol0C7oo00<007ooOol09Woo00<007ooOol05Woo00<007ooOol0
A7oo0019Ool00`00Oomoo`1<Ool00`00Oomoo`0VOol00`00Oomoo`0DOol00`00Oomoo`15Ool004Yo
o`03001oogoo04aoo`03001oogoo02Eoo`03001oogoo01=oo`03001oogoo04Ioo`00Bgoo00<007oo
Ool0C7oo00<007ooOol09Goo00<007ooOol04Goo00<007ooOol0Agoo001;Ool00`00Oomoo`1<Ool0
0`00Oomoo`0VOol00`00Oomoo`0@Ool00`00Oomoo`17Ool004aoo`03001oogoo04aoo`03001oogoo
02Eoo`03001oogoo00moo`03001oogoo04Qoo`00CGoo00<007ooOol0C7oo00<007ooOol09Goo00<0
07ooOol03Goo00<007ooOol0BGoo001>Ool00`00Oomoo`1;Ool00`00Oomoo`0VOol00`00Oomoo`0<
Ool00`00Oomoo`19Ool004moo`03001oogoo04]oo`03001oogoo02Eoo`03001oogoo00]oo`03001o
ogoo04Yoo`00D7oo00<007ooOol0Bgoo00<007ooOol09Goo00<007ooOol02Goo00<007ooOol0Bgoo
001AOol00`00Oomoo`1:Ool00`00Oomoo`0VOol00`00Oomoo`07Ool00`00Oomoo`1<Ool0059oo`03
001oogoo04Yoo`03001oogoo02Eoo`03001oogoo00Moo`03001oogoo04aoo`00Dgoo00<007ooOol0
BWoo00<007ooOol09Goo00<007ooOol01Goo00<007ooOol0CGoo001DOol00`00Oomoo`19Ool00`00
Oomoo`0VOol00`00Oomoo`03Ool00`00Oomoo`1>Ool005Eoo`03001oogoo04Uoo`03001oogoo02Io
o`03001oogoo009oo`03001oogoo04ioo`00EWoo00<007ooOol0BGoo00<007ooOol09Goo00D007oo
Oomoo`00055oo`00Egoo00<007ooOol0B7oo00<007ooOol09Woo00<007oo0000DWoo001HOol00`00
Oomoo`18Ool00`00Oomoo`0VOol00`00Oomoo`1AOol005Qoo`03001oogoo04Uoo`03001oogoo02Eo
o`03001oogoo055oo`00FGoo00<007ooOol0B7oo00<007ooOol097oo00<007ooOol0DWoo001JOol0
0`00Oomoo`18Ool00`00Oomoo`0ROol00`00Oomoo`1COol005]oo`03001oogoo04Qoo`03001oogoo
01Yoo`<000Aoo`03001oogoo05=oo`00G7oo00<007ooOol0B7oo00<007ooOol06Woo00<007ooOol0
0Woo00<007ooOol0E7oo001MOol00`00Oomoo`17Ool00`00Oomoo`0HOol40002Ool00`00Oomoo`1E
Ool005ioo`03001oogoo04Moo`03001oogoo01Moo`03001oo`0000=oo`03001oogoo05Eoo`00Ggoo
00<007ooOol0Agoo00<007ooOol05Woo00<007oo00000Woo00<007ooOol0EWoo001POol00`00Oomo
o`16Ool00`00Oomoo`0GOol200000goo001oo`1HOol0065oo`03001oogoo04Ioo`03001oogoo01Uo
o`03001oogoo05Moo`00HWoo00<007ooOol0AWoo00<007ooOol05goo00<007ooOol0F7oo001SOol0
0`00Oomoo`15Ool00`00Oomoo`0FOol00`00Oomoo`1IOol006Aoo`03001oogoo04Eoo`03001oogoo
01Eoo`03001oogoo05Uoo`00IGoo00<007ooOol0AGoo00<007ooOol04goo00<007ooOol0FWoo001V
Ool00`00Oomoo`14Ool00`00Oomoo`0BOol00`00Oomoo`1KOol006Ioo`03001oogoo04Eoo`03001o
ogoo015oo`03001oogoo05]oo`00Igoo00<007ooOol0AGoo00<007ooOol03goo00<007ooOol0G7oo
001XOol00`00Oomoo`14Ool00`00Oomoo`0>Ool00`00Oomoo`1MOol006Uoo`03001oogoo04Aoo`03
001oogoo00eoo`03001oogoo05eoo`00JWoo00<007ooOol0A7oo00<007ooOol02goo00<007ooOol0
GWoo001[Ool00`00Oomoo`13Ool00`00Oomoo`0:Ool00`00Oomoo`1OOol006aoo`03001oogoo04=o
o`03001oogoo00Uoo`03001oogoo05moo`00KGoo00<007ooOol0@goo00<007ooOol01goo00<007oo
Ool0H7oo001^Ool00`00Oomoo`13Ool00`00Oomoo`05Ool00`00Oomoo`1QOol006moo`03001oogoo
049oo`03001oogoo00Eoo`03001oogoo065oo`00L7oo00<007ooOol0@Woo00<007ooOol00goo00<0
07ooOol0HWoo001aOol00`00Oomoo`12Ool01@00Oomoogoo0000IGoo001bOol00`00Oomoo`11Ool0
1@00Oomoogoo0000IGoo001cOol00`00Oomoo`11Ool00`00Ool0001VOol007Aoo`03001oogoo041o
o`8006Moo`00M7oo00<007ooOol0?goo00<007ooOol0Igoo001eOol00`00Oomoo`0lOol2001ZOol0
07Ioo`03001oogoo03Eoo`<0009oo`03001oogoo06Yoo`00Mgoo00<007ooOol0=goo0P00KGoo001h
Ool00`00Oomoo`0eOol2001^Ool007Uoo`03001oogoo03=oo`8006moo`00NWoo00<007ooOol0<7oo
0P000Woo00<007ooOol0K7oo001kOol00`00Oomoo`0^Ool00`00Ool00002001_Ool007aoo`03001o
ogoo02aoo`03001oogoo079oo`00OGoo00<007ooOol0:Goo0P00MGoo001nOol00`00Oomoo`0WOol0
0`00Oomoo`1eOol007moo`03001oogoo02Aoo`8007Qoo`00P7oo00<007ooOol08Woo00<007ooOol0
N7oo0021Ool00`00Oomoo`0OOol2001kOol0085oo`03001oogoo01ioo`03001oogoo07]oo`00PWoo
00<007ooOol077oo00<007ooOol0O7oo0023Ool00`00Oomoo`0IOol2001oOol008Aoo`03001oogoo
01Moo`03001oogoo07moo`00QGoo00<007ooOol057oo0P00PWoo0026Ool00`00Oomoo`0BOol00`00
Oomoo`22Ool008Moo`03001oogoo011oo`03001oogoo08=oo`00R7oo00<007ooOol03Goo0P00QWoo
0029Ool00`00Oomoo`0;Ool00`00Oomoo`26Ool008Yoo`03001oogoo00Qoo`8008Uoo`00Rgoo00<0
07ooOol01Woo00<007ooOol0RGoo002<Ool00`00Oomoo`04Ool00`00Oomoo`2:Ool008eoo`04001o
ogooOol2002=Ool008ioo`03001oo`0008moo`00Sgoo00<007ooOol0SWoo003oOolQOol00?moob5o
o`00ogoo8Goo0025Ool3002HOol008Ioo`03001oogoo09Moo`00QWoo00<007ooOol0Ugoo0026Ool0
0`00Oomoo`2GOol008Ioo`03001oogoo09Moo`00QGoo0P00VGoo003oOolQOol00?moob5oo`00ogoo
8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol0
0?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo
8Goo003oOolQOol00?moob5oo`00\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-1.00868, -1.00003, 
  0.0244508, 0.0339103}}]
}, Closed]],

Cell["\<\
Now, we calculate the probability of this configuration of \
mutations exactly.  We use both the exact G-T algorithm and \
ExactProbability[], which (fortunately) give the same answer:\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(Timing[exGT = GriffithsTavare[S, \[Theta]]; 
      expr = ExactProbability[g, \[Theta]]; expr/exGT]\)], "Input",
  CellLabel->"In[164]:="],

Cell[BoxData[
    \({255.866666666666819`\ Second, 1}\)], "Output",
  CellLabel->"Out[164]="]
}, Closed]],

Cell[TextData[
"Note that if the genealogy had not been fully resolved, then \
GriffithsTavare[S,\[Theta]] and ExactProbability[g,\[Theta]] would give \
different answers.  GriffithsTavare[] gives the total probability of the \
configuratiuon of mutations, sumking over all possible topologies and \
orderings, while ExactProbability[] gives the probability of a specific \
topology, summing over orderings."], "Text"],

Cell["\<\
To use the stochastic Griffiths-Tavare method, construct a table of \
1000 random values; choose \[Phi]=1.  Each value is a function of \[Theta]:\
\
\>", "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[
    \(Timing[gt = Table[MonteCarloGriffithsTavare[S, \[Theta], 1], {1000}]; ]
      \)], "Input",
  CellLabel->"In[165]:="],

Cell[BoxData[
    \({92.1833333333333904`\ Second, Null}\)], "Output",
  CellLabel->"Out[165]="]
}, Closed]],

Cell["Their expectation should equal the exact value:", "MathCaption"],

Cell[BoxData[
    \(seGT[\[Theta]1_] := 
      \(seGT[\[Theta]1] = 
        StandardErrorOfSampleMean[gt /. \[Theta] -> \[Theta]1]\); \n
    mnGT[\[Theta]1_] := 
      \(mnGT[\[Theta]1] = Mean[gt /. \[Theta] -> \[Theta]1]\); \)], "Input",
  CellLabel->"In[170]:="],

Cell[TextData[
"Care is needed in manipulating mnGT, seGT: they are very large expressions.  \
Hence, it is best to set  a definite value for \[Theta] before further \
manipulation:"], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \({mnGT[1. ], seGT[1. ], exGT /. \[Theta] \[Rule] 1. , 
      \(mnGT[1. ] - exGT /. \[Theta] \[Rule] 1\)\/seGT[1. ]}\)], "Input",
  CellLabel->"In[171]:="],

Cell[BoxData[
    \({1.7141939404007223`*^-16, 1.85078998705674635`*^-17, 
      1.72735923801524471`*^-16, \(-0.071133395504580914`\)}\)], "Output",
  CellLabel->"Out[171]="]
}, Closed]],

Cell[TextData[{
  "The t-statistic ",
  Cell[BoxData[
      \(TraditionalForm\`\((t = \(-0.07\))\)\)]],
  " is not significant."
}], "Text"],

Cell["\<\
This compares the exact probability with that estimated using \
MonteCarloGriffithsTavare[] (\[PlusMinus]1 standard error):\
\>", \
"MathCaption"],

Cell[BoxData[
    \(<< Graphics`Graphics`; << Graphics`Colors`; \)], "Input",
  CellLabel->"In[22]:="],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(LogLogPlot[{mnGT[\[Theta]], mnGT[\[Theta]] - seGT[\[Theta]], 
        mnGT[\[Theta]] + seGT[\[Theta]], exGT}, {\[Theta], 0, 40}, 
      PlotStyle 
        \[Rule] {Black, Dashing[{0.01, 0.01}], Dashing[{0.01, 0.01}], Red}]; 
    \)\)], "Input",
  CellLabel->"In[172]:="],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.594473 2.70662 0.219985 [
[.02381 -0.0125 -5 -12 ]
[.02381 -0.0125 5 0 ]
[.20276 -0.0125 -5 -12 ]
[.20276 -0.0125 5 0 ]
[.43933 -0.0125 -5 -12 ]
[.43933 -0.0125 5 0 ]
[.61828 -0.0125 -8 -12 ]
[.61828 -0.0125 8 0 ]
[.79724 -0.0125 -8 -12 ]
[.79724 -0.0125 8 0 ]
[-0.0125 .0668 -51.25 -6.40625 ]
[-0.0125 .0668 0 6.40625 ]
[-0.0125 .22057 -51.25 -6.40625 ]
[-0.0125 .22057 0 6.40625 ]
[-0.0125 .28679 -51.25 -6.40625 ]
[-0.0125 .28679 0 6.40625 ]
[-0.0125 .44055 -51.25 -6.40625 ]
[-0.0125 .44055 0 6.40625 ]
[-0.0125 .50677 -51.25 -6.40625 ]
[-0.0125 .50677 0 6.40625 ]
[ -0.0005 -0.0005 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 0 m
.02381 .00625 L
s
gsave
.02381 -0.0125 -66 -16 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 16.000000 moveto
 558.000000 16.000000 lineto
 558.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 16.000000 lineto
closepath
clip newpath
63.000000 13.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 13.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(1) show
69.000000 13.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: font Courier
grestore
.20276 0 m
.20276 .00625 L
s
gsave
.20276 -0.0125 -66 -16 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 16.000000 moveto
 558.000000 16.000000 lineto
 558.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 16.000000 lineto
closepath
clip newpath
63.000000 13.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 13.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(2) show
69.000000 13.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: font Courier
grestore
.43933 0 m
.43933 .00625 L
s
gsave
.43933 -0.0125 -66 -16 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 16.000000 moveto
 558.000000 16.000000 lineto
 558.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 16.000000 lineto
closepath
clip newpath
63.000000 13.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 13.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(5) show
69.000000 13.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: font Courier
grestore
.61828 0 m
.61828 .00625 L
s
gsave
.61828 -0.0125 -69 -16 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 16.000000 moveto
 558.000000 16.000000 lineto
 558.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 16.000000 lineto
closepath
clip newpath
63.000000 13.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 13.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(10) show
75.000000 13.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: font Courier
grestore
.79724 0 m
.79724 .00625 L
s
gsave
.79724 -0.0125 -69 -16 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 16.000000 moveto
 558.000000 16.000000 lineto
 558.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 16.000000 lineto
closepath
clip newpath
63.000000 13.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 13.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(20) show
75.000000 13.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: font Courier
grestore
.001 w
.30745 0 m
.30745 .00375 L
s
.38172 0 m
.38172 .00375 L
s
.4864 0 m
.4864 .00375 L
s
.5262 0 m
.5262 .00375 L
s
.56067 0 m
.56067 .00375 L
s
.59108 0 m
.59108 .00375 L
s
.90192 0 m
.90192 .00375 L
s
.97619 0 m
.97619 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .0668 m
.00625 .0668 L
s
gsave
-0.0125 .0668 -112.25 -10.4062 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.8125 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 16.812500 moveto
 558.000000 16.812500 lineto
 558.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 16.812500 lineto
closepath
clip newpath
63.000000 13.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 13.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(1.) show
75.000000 13.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
76.812500 13.812500 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(\\264) show
84.625000 13.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(10) show
96.625000 9.437500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 7.125000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
96.625000 9.437500 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 7.125000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(-) show
100.812500 9.437500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 7.125000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(12) show
109.187500 9.437500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 7.125000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Math1Mono
%%+ font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Math1Mono
%%+ Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: font Math1Mono
%%+ font Courier
grestore
0 .22057 m
.00625 .22057 L
s
gsave
-0.0125 .22057 -112.25 -10.4062 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.8125 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 16.812500 moveto
 558.000000 16.812500 lineto
 558.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 16.812500 lineto
closepath
clip newpath
63.000000 13.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 13.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(5.) show
75.000000 13.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
76.812500 13.812500 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(\\264) show
84.625000 13.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(10) show
96.625000 9.437500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 7.125000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
96.625000 9.437500 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 7.125000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(-) show
100.812500 9.437500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 7.125000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(12) show
109.187500 9.437500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 7.125000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Math1Mono
%%+ font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Math1Mono
%%+ Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: font Math1Mono
%%+ font Courier
grestore
0 .28679 m
.00625 .28679 L
s
gsave
-0.0125 .28679 -112.25 -10.4062 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.8125 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 16.812500 moveto
 558.000000 16.812500 lineto
 558.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 16.812500 lineto
closepath
clip newpath
63.000000 13.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 13.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(1.) show
75.000000 13.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
76.812500 13.812500 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(\\264) show
84.625000 13.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(10) show
96.625000 9.437500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 7.125000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
96.625000 9.437500 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 7.125000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(-) show
100.812500 9.437500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 7.125000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(11) show
109.187500 9.437500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 7.125000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Math1Mono
%%+ font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Math1Mono
%%+ Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: font Math1Mono
%%+ font Courier
grestore
0 .44055 m
.00625 .44055 L
s
gsave
-0.0125 .44055 -112.25 -10.4062 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.8125 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 16.812500 moveto
 558.000000 16.812500 lineto
 558.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 16.812500 lineto
closepath
clip newpath
63.000000 13.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 13.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(5.) show
75.000000 13.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
76.812500 13.812500 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(\\264) show
84.625000 13.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(10) show
96.625000 9.437500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 7.125000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
96.625000 9.437500 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 7.125000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(-) show
100.812500 9.437500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 7.125000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(11) show
109.187500 9.437500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 7.125000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Math1Mono
%%+ font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Math1Mono
%%+ Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: font Math1Mono
%%+ font Courier
grestore
0 .50677 m
.00625 .50677 L
s
gsave
-0.0125 .50677 -112.25 -10.4062 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.8125 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 16.812500 moveto
 558.000000 16.812500 lineto
 558.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 16.812500 lineto
closepath
clip newpath
63.000000 13.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 13.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(1.) show
75.000000 13.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
76.812500 13.812500 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(\\264) show
84.625000 13.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(10) show
96.625000 9.437500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 7.125000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
96.625000 9.437500 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 7.125000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(-) show
100.812500 9.437500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 7.125000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(10) show
109.187500 9.437500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 7.125000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Math1Mono
%%+ font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Math1Mono
%%+ Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: font Math1Mono
%%+ font Courier
grestore
.001 w
0 .13303 m
.00375 .13303 L
s
0 .17176 m
.00375 .17176 L
s
0 .19925 m
.00375 .19925 L
s
0 .23799 m
.00375 .23799 L
s
0 .25271 m
.00375 .25271 L
s
0 .26547 m
.00375 .26547 L
s
0 .27672 m
.00375 .27672 L
s
0 .35301 m
.00375 .35301 L
s
0 .39175 m
.00375 .39175 L
s
0 .41923 m
.00375 .41923 L
s
0 .45797 m
.00375 .45797 L
s
0 .4727 m
.00375 .4727 L
s
0 .48545 m
.00375 .48545 L
s
0 .49671 m
.00375 .49671 L
s
0 .573 m
.00375 .573 L
s
0 .61173 m
.00375 .61173 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
0 0 0 r
.5 Mabswid
.21141 0 m
.26436 .15572 L
.33918 .33219 L
.39962 .4392 L
.44611 .50119 L
.48519 .54047 L
.51667 .56407 L
.54514 .57958 L
.56003 .58558 L
.57324 .58973 L
.57957 .59134 L
.58631 .59279 L
.5921 .59382 L
.59814 .59467 L
.60398 .5953 L
.60917 .5957 L
.61163 .59583 L
.61292 .59589 L
.61427 .59594 L
.61545 .59597 L
.61674 .596 L
.61791 .59602 L
.61899 .59602 L
.62035 .59603 L
.62104 .59603 L
.62179 .59602 L
.62311 .596 L
.62435 .59598 L
.6258 .59594 L
.62711 .59589 L
.63006 .59575 L
.63243 .59561 L
.635 .59541 L
.64011 .59493 L
.64952 .59367 L
.65797 .59215 L
.67633 .5876 L
.69194 .58243 L
.72263 .569 L
.74908 .55414 L
.77451 .53718 L
.79685 .52028 L
.81664 .50382 L
.83617 .4863 L
.85367 .46959 L
.87105 .45208 L
.88676 .43551 L
.90102 .4199 L
.91538 .40366 L
.92848 .38838 L
Mistroke
.94171 .37255 L
.95385 .35767 L
.96502 .3437 L
.97619 .32946 L
Mfstroke
0 g
[ .01 .01 ] 0 setdash
.21475 0 m
.26436 .14621 L
.33918 .32311 L
.39962 .43043 L
.44611 .49264 L
.48519 .53209 L
.51667 .55583 L
.54514 .57144 L
.56003 .5775 L
.57324 .58169 L
.57957 .58332 L
.58631 .58479 L
.5921 .58584 L
.59814 .58671 L
.60398 .58736 L
.60917 .58777 L
.61163 .58791 L
.61292 .58797 L
.61427 .58802 L
.61545 .58806 L
.61674 .58809 L
.61791 .58811 L
.61899 .58813 L
.62035 .58813 L
.62104 .58813 L
.62179 .58813 L
.62311 .58812 L
.62435 .58809 L
.62506 .58808 L
.6258 .58806 L
.62711 .58802 L
.63006 .58789 L
.63258 .58774 L
.63491 .58757 L
.64011 .58709 L
.6489 .58595 L
.65797 .58436 L
.67709 .57963 L
.69393 .57399 L
.72331 .56102 L
.75128 .54519 L
.77562 .52885 L
.79704 .51262 L
.81805 .49513 L
.83678 .4783 L
.8553 .46057 L
.87196 .44374 L
.88704 .42784 L
.90217 .41126 L
.91594 .39566 L
Mistroke
.92982 .37947 L
.94251 .36425 L
.95417 .34997 L
.96601 .33514 L
.97619 .32217 L
Mfstroke
.2088 0 m
.21106 .00787 L
.26436 .16437 L
.33918 .34048 L
.39962 .44723 L
.44611 .50903 L
.48519 .54816 L
.51667 .57166 L
.54514 .58708 L
.56003 .59303 L
.57324 .59715 L
.57957 .59874 L
.58631 .60017 L
.5921 .60118 L
.59814 .60202 L
.60117 .60236 L
.60398 .60264 L
.60669 .60285 L
.60917 .60302 L
.61149 .60314 L
.61393 .60323 L
.61519 .60327 L
.61636 .60329 L
.61763 .60331 L
.61899 .60332 L
.62031 .60332 L
.62105 .60331 L
.62175 .60331 L
.62315 .60329 L
.62393 .60327 L
.62465 .60325 L
.62715 .60316 L
.62977 .60303 L
.63259 .60286 L
.63519 .60265 L
.641 .60207 L
.65048 .60073 L
.66024 .59887 L
.6792 .59389 L
.69591 .58806 L
.72508 .57482 L
.75286 .5588 L
.77706 .54233 L
.79837 .52601 L
.81928 .50846 L
.83791 .49159 L
.85636 .47382 L
.87296 .45697 L
.88797 .44106 L
.90305 .42447 L
Mistroke
.91678 .40886 L
.93061 .39267 L
.94327 .37746 L
.95489 .36317 L
.9667 .34835 L
.97619 .33624 L
Mfstroke
1 0 0 r
[ ] 0 setdash
.21119 0 m
.26436 .15643 L
.33918 .33303 L
.39962 .44017 L
.44611 .50227 L
.48519 .54163 L
.51667 .56531 L
.54514 .58089 L
.56003 .58692 L
.57324 .5911 L
.57957 .59273 L
.58631 .59419 L
.5921 .59522 L
.59814 .5961 L
.60398 .59674 L
.60917 .59714 L
.61163 .59728 L
.61292 .59734 L
.61427 .59739 L
.61545 .59743 L
.61674 .59746 L
.61791 .59748 L
.61899 .59749 L
.62035 .59749 L
.62104 .59749 L
.62179 .59749 L
.62311 .59747 L
.62435 .59745 L
.6258 .59741 L
.62711 .59737 L
.63006 .59724 L
.63243 .5971 L
.635 .59691 L
.64011 .59643 L
.64952 .59519 L
.65797 .59368 L
.67633 .58917 L
.69194 .58403 L
.72263 .57065 L
.74908 .55583 L
.77451 .53891 L
.79685 .52203 L
.81664 .5056 L
.83617 .48811 L
.85367 .47141 L
.87105 .45392 L
.88676 .43737 L
.90102 .42177 L
.91538 .40554 L
.92848 .39028 L
Mistroke
.94171 .37445 L
.95385 .35959 L
.96502 .34563 L
.97619 .3314 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[172]:=",
  ImageSize->{520, 321.25},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`4000880001@A000`40O003h00Oogooogoo2Woo003o
OoooOol:Ool00?mooomoo`Yoo`00ogooogoo2Woo003oOoooOol:Ool00?mooomoo`Yoo`00ogooogoo
2Woo003oOoooOol:Ool00?mooomoo`Yoo`00ogooogoo2Woo003oOoooOol:Ool00?mooomoo`Yoo`00
ogooogoo2Woo0012Ool3001?Ool4001YOol3001=Ool30004Ool2001:Ool40003Ool2001KOol004=o
o`03001oogoo04moo`03001oogoo06aoo`03001oogoo04]oo`03001oogoo009oo`04001oogoo001:
Ool00`00Oomoo`02Ool01000Oomoo`00FWoo0013Ool00`00Oomoo`1@Ool00`00Oomoo`1[Ool00`00
Oomoo`1;Ool00`00Oomoo`02Ool01000Oomoo`00Bgoo00D007ooOomoo`00009oo`03001oogoo05Qo
o`00@goo00<007ooOol0DGoo00<007ooOol0Igoo0`00CWoo00<007ooOol00Woo00@007ooOol004ao
o`04001oogoo0002Ool00`00Oomoo`1HOol004=oo`03001oogoo04ioo`04001oogoo001YOol00`00
Oomoo`1>Ool00`00Oomoo`02Ool01000Oomoo`00BGoo00@007ooOol0009oo`04001oogoo001JOol0
049oo`80055oo`8006Yoo`@004aoo`8000Eoo`8004]oo`8000Aoo`8005]oo`00ogooogoo2Woo003o
OoooOol:Ool00?mooomoo`Yoo`00ogooogoo2Woo003oOoooOol:Ool00?mooomoo`Yoo`00ogooogoo
2Woo003oOoooOol:Ool003Uoof400003O00000000?l006/0005oo`00>Goo00<007ooOol027oo00<0
07ooOol0Cgoo00D007ooOomoog`002aoo`03001oogoo01moo`03001oogoo01Moo`03001oogoo01=o
o`03001oogoo011oo`03001oogoo00eoo`03001oogoo00]oo`03001oogoo00Uoo`03001oogoo051o
o`03001oogoo02eoo`03001oogoo021oo`03001oogoo00Uoo`00>Goo00<007ooOol027oo00<007oo
Ool0Cgoo00<007ooOol00Woo00=l0000Ool0IGoo00<007ooOol0D7oo00<007ooOol0D7oo00<007oo
Ool0G7oo000iOol00`00Oomoo`1NOol00`00O000003oOom/Ool003Uoo`03001oogoo05ioo`04001l
07oo003oOom[Ool003Uoo`03001oogoo05ioo`04001oog`0003oOom[Ool003Uoo`03001oogoo05mo
o`04001l07oo003oOomZOol003Uoo`03001oogoo05moo`03001l07oo0?moof]oo`00>Goo00<007oo
Ool0HGoo00=l07ooOol0ogooJGoo000iOol00`00Oomoo`1QOol00g`0Oomoo`3oOomYOol003Uoo`03
001oogoo065oo`03O01oo`000?moofUoo`00>Goo00<007ooOol0HGoo00<007`00000ogooJGoo000i
Ool00`00Oomoo`1QOol01000O01oo`00ogooJ7oo000iOol00`00Oomoo`1QOol01000O01oo`00ogoo
J7oo000iOol00`00Oomoo`1ROol00`00O000003oOomXOol003Uoo`03001oogoo069oo`04001l07oo
003oOomWOol003Uoo`03001oogoo069oo`03001l07oo0?moofQoo`00>Goo00<007ooOol0I7oo00=l
07ooOol0ogooIWoo000iOol00`00Oomoo`1TOol00g`0Oomoo`3oOomVOol003Uoo`03001oogoo06Ao
o`03O00000000?moofIoo`00>Goo00<007ooOol0I7oo00<007`00000ogooIWoo000iOol00`00Oomo
o`1TOol01000O01oo`00ogooIGoo000iOol00`00Oomoo`1TOol01000O0000000ogooIGoo000iOol0
0`00Oomoo`1UOol00`00O000003oOomUOol003Uoo`03001oogoo06Eoo`04001l07oo003oOomTOol0
03Uoo`03001oogoo06Eoo`03001oog`00?moofEoo`00>Goo00<007ooOol0Igoo00=l07ooOol0ogoo
Hgoo000iOol00`00Oomoo`1WOol00g`0Oomoo`3oOomSOol000=oo`<000Aoo`8000Aoo`05001oogoo
Ool00003Ool30004Ool2000HOol00`00Oomoo`1XOol00g`0001oo`3oOomROol000Aoo`03001oogoo
00=oo`8000Eoo`03001oo`0000Eoo`03001oogoo009oo`04001oogoo000GOol00`00Oomoo`1WOol0
0`00O000003oOomSOol000Aoo`03001oogoo00]oo`03001oogoo00Aoo`03001oogoo009oo`04001o
ogoo000GOol3001WOol01000O01oo`00ogooHWoo0004Ool00`00Oomoo`0:Ool00`00Ool00005Ool0
0`00Oomoo`02Ool01000Oomoo`005goo00<007ooOol0Igoo00@007ooO0000?moof9oo`0017oo00<0
07ooOol02Goo00D007ooOomoo`0000Aoo`03001oogoo009oo`04001oogoo0006Ool3000017oo0000
00002Woo00<007ooOol0J7oo00@007`0Ool00?moof5oo`000goo0P004goo0P001Goo0P000goo0`00
0Woo00D007ooOomoo`0000]oo`03001oogoo06Qoo`03001l07oo0?moof9oo`00:Goo00<007ooOol0
0Woo00<007ooOol027oo00<007ooOol0JWoo00=l07ooOol0ogooH7oo000XOol20002Ool3000:Ool0
0`00Oomoo`1ZOol00g`0Oomoo`3oOomPOol003Uoo`03001oogoo06Yoo`03O00007oo0?moof1oo`00
>Goo00<007ooOol0Jgoo00=l0000Ool0ogooGgoo000iOol00`00Oomoo`1ZOol00`00O000003oOomP
Ool003Uoo`03001oogoo06Yoo`04001l0000003oOomOOol003Uoo`03001oogoo06Yoo`04001oog`0
003oOomOOol003Uoo`03001oogoo06]oo`04001l07oo003oOomNOol003Uoo`03001oogoo06]oo`03
001l00000?mooemoo`00>Goo00<007ooOol0KGoo00=l07ooOol0ogooGGoo000iOol00`00Oomoo`1]
Ool00g`0Oomoo`3oOomMOol003Uoo`03001oogoo06eoo`03O00000000?mooeeoo`00>Goo00<007oo
Ool0KGoo00<007`00000ogooGGoo000iOol00`00Oomoo`1]Ool01000O01oo`00ogooG7oo000iOol0
0`00Oomoo`1]Ool01000O0000000ogooG7oo000iOol00`00Oomoo`1^Ool00`00O000003oOomLOol0
03Uoo`03001oogoo06ioo`04001l07oo003oOomKOol003Uoo`03001oogoo06ioo`03001oog`00?mo
oeaoo`00>Goo00<007ooOol0L7oo00=l07ooOol0ogooFWoo000iOol00`00Oomoo`1`Ool00g`0Oomo
o`3oOomJOol003Uoo`03001oogoo075oo`03O00007oo0?mooeUoo`00>Goo00<007ooOol0L7oo00<0
07`00000ogooFWoo000iOol00`00Oomoo`1`Ool01000O0000000ogooFGoo000iOol00`00Oomoo`1`
Ool01000Ooml0000ogooFGoo000iOol00`00Oomoo`1aOol00`00O000003oOomIOol003Uoo`03001o
ogoo075oo`04001l0000003oOomHOol003Uoo`03001oogoo07=oo`03O01oogoo0?mooeMoo`00>Goo
0P00M7oo00=l07ooOol0ogooEgoo000iOol00`00Oomoo`1cOol00g`0001oo`3oOomGOol003Uoo`03
001oogoo07Aoo`03O00007oo0?mooeIoo`00>Goo00<007ooOol0Lgoo00<007`00000ogooEgoo000i
Ool00`00Oomoo`1cOol01000O0000000ogooEWoo000iOol00`00Oomoo`1cOol01000Ooml0000ogoo
EWoo000iOol00`00Oomoo`1dOol01000O01oo`00ogooEGoo000iOol00`00Oomoo`1dOol00`00O000
003oOomFOol003Uoo`03001oogoo07Ioo`03O01oogoo0?mooeAoo`00>Goo00<007ooOol0MWoo00=l
07ooOol0ogooE7oo000iOol00`00Oomoo`1fOol00g`0001oo`3oOomDOol003Uoo`03001oogoo07Mo
o`03O01oo`000?mooe=oo`00>Goo00<007ooOol0MWoo00@007`000000?mooe=oo`00>Goo00<007oo
Ool0MWoo00@007ooO0000?mooe=oo`00>Goo00<007ooOol0Mgoo00@007`0Ool00?mooe9oo`00>Goo
00<007ooOol0Mgoo00@007`000000?mooe9oo`00>Goo00<007ooOol0Mgoo00<007ooO000ogooDgoo
000iOol00`00Oomoo`1iOol00g`0001oo`3oOomAOol003Uoo`8007]oo`03O01oogoo0?mooe1oo`00
>Goo00<007ooOol0NWoo00=l00000000ogooD7oo000iOol00`00Oomoo`1iOol01000Ooml0000ogoo
D7oo000iOol00`00Oomoo`1iOol01@00Ooml07oo0000ogooCgoo000iOol00`00Oomoo`1jOol01000
O0000000ogooCgoo000iOol00`00Oomoo`1jOol01@00Ooml07oo0000ogooCWoo000iOol00`00Oomo
o`1kOol00`00O000003oOom?Ool003Uoo`03001oogoo07eoo`03O01oogoo0?moodeoo`00>Goo00<0
07ooOol0OGoo00=l07ooOol0ogooCGoo000iOol00`00Oomoo`1nOol00g`0Oomoo`3oOom<Ool003Uo
o`03001oogoo07ioo`03O01oo`000?moodaoo`00>Goo00<007ooOol0OGoo00@007`000000?moodao
o`00>Goo00<007ooOol0OGoo00D007ooO01oo`000?mood]oo`00>Goo0P00OWoo00<007ooO0000P00
ogooBgoo000iOol00`00Oomoo`1nOol01@00Ooml07oo0000ogooBWoo000iOol00`00Oomoo`1nOol0
0`00Ooml003oOom<Ool003Uoo`03001oogoo081oo`03O00007oo0?moodYoo`00>Goo00<007ooOol0
PGoo00=l07ooOol0ogooBGoo000iOol00`00Oomoo`21Ool00g`00000003oOom9Ool003Uoo`03001o
ogoo081oo`04001oog`0003oOom9Ool000=oo`<000Aoo`8000Aoo`05001oogooOol00003Ool30004
Ool2000HOol00`00Oomoo`20Ool01@00Ooml07oo0000ogooB7oo0006Ool01000Oomoogoo0P001Goo
00<007oo00001Goo00<007ooOol00Woo00@007ooOol001Moo`03001oogoo085oo`04001oog`0003o
Oom8Ool000Ioo`03001oogoo00Uoo`03001oogoo00Aoo`03001oogoo009oo`04001oogoo000GOol3
0021Ool01@00Ooml07oo0000ogooAgoo0003Ool3000;Ool00`00Ool00005Ool00`00Oomoo`02Ool0
1000Oomoo`005goo00<007ooOol0PWoo00<007`00000ogooB7oo0003Ool00`00Oomoo`0:Ool01@00
Oomoogoo000017oo00<007ooOol00Woo00@007ooOol000Ioo`<00004Ool00000000:Ool00`00Oomo
o`24Ool00g`0Oomoo`3oOom6Ool000=oo`@0015oo`8000Eoo`8000=oo`<0009oo`05001oogooOol0
000;Ool00`00Oomoo`24Ool00g`0Oomoo`3oOom6Ool002Uoo`03001oogoo009oo`03001oogoo00Qo
o`03001oogoo08Eoo`03O01oogoo0?moodEoo`00:7oo0P000Woo0`002Woo00<007ooOol0QGoo00=l
07oo0000ogooAGoo000iOol00`00Oomoo`24Ool01000O0000000ogooAGoo000iOol00`00Oomoo`24
Ool01@00Ooml07oo0000ogooA7oo000iOol20026Ool01000O0000000ogooA7oo000iOol00`00Oomo
o`25Ool01@00Ooml07oo0000ogoo@goo000iOol00`00Oomoo`26Ool00`00O01oo`3oOom4Ool003Uo
o`03001oogoo08Qoo`03O01oogoo0?mood9oo`00>Goo00<007ooOol0R7oo00=l07ooOol0ogoo@Woo
000iOol00`00Oomoo`28Ool017`0001oo`00ogoo@Goo000iOol00`00Oomoo`28Ool01000O01oo`00
ogoo@Goo000iOol20029Ool01000O01oo`00ogoo@Goo000iOol00`00Oomoo`28Ool01@00Ooml07oo
0000ogoo@7oo000iOol00`00Oomoo`29Ool01000O01oo`00ogoo@7oo000iOol00`00Oomoo`29Ool0
0`00Ooml003oOom1Ool003Uoo`03001oogoo08]oo`03O01oogoo0?moocmoo`00>Goo00<007ooOol0
Rgoo00=l0000Ool0ogoo?goo000iOol2002=Ool00g`0Oomoo`3oOolnOol003Uoo`03001oogoo08ao
o`03O01oo`000?moocioo`00>Goo00<007ooOol0Rgoo00@007ooO0000?moocioo`00>Goo00<007oo
Ool0Rgoo00D007ooO01oo`000?mooceoo`00>Goo00<007ooOol0S7oo00@007`000000?mooceoo`00
>Goo0P00SGoo00D007ooO01oo`000?moocaoo`00>Goo00<007ooOol0SGoo00<007`0Ool0ogoo?Goo
000iOol00`00Oomoo`2?Ool00g`0Oomoo`3oOolkOol000=oo`<000Aoo`8000Aoo`05001oogooOol0
0003Ool30004Ool2000HOol00`00Oomoo`2?Ool00g`0Oomoo`3oOolkOol000Aoo`03001oogoo00=o
o`8000Eoo`03001oo`0000Eoo`03001oogoo009oo`04001oogoo000GOol00`00Oomoo`2@Ool00g`0
Ool0003oOoljOol000Aoo`03001oogoo00]oo`03001oogoo00Aoo`03001oogoo009oo`04001oogoo
000GOol3002?Ool01000O01oo`00ogoo>Woo0004Ool00`00Oomoo`0:Ool00`00Ool00005Ool00`00
Oomoo`02Ool01000Oomoo`005goo00<007ooOol0Sgoo00D007`0001oo`000?moocUoo`0017oo00<0
07ooOol02Goo00D007ooOomoo`0000Aoo`03001oogoo009oo`04001oogoo0006Ool3000017oo0000
00002Woo00<007ooOol0T7oo00@007`0Ool00?moocUoo`000goo0P004goo0P001Goo0P000goo0`00
0Woo00D007ooOomoo`0000]oo`03001oogoo091oo`05001l07ooOol0003oOolhOol002Uoo`05001o
ogooOol0000;Ool00`00Oomoo`2AOol00`00O01oo`3oOoliOol002Qoo`80009oo`8000]oo`03001o
ogoo099oo`03O01oogoo0?moocQoo`00>Goo00<007ooOol0TWoo00=l0000Ool0ogoo>7oo000iOol0
0`00Oomoo`2COol00g`0Oomoo`3oOolgOol003Uoo`03001oogoo09=oo`03O01oo`000?moocMoo`00
>Goo00<007ooOol0TWoo00@007ooO0000?moocMoo`00>Goo00<007ooOol0TWoo00D007ooO01oo`00
0?moocIoo`00>Goo00<007ooOol0Tgoo00@007ooO0000?moocIoo`00>Goo00<007ooOol0Tgoo00D0
07ooO01oo`000?moocEoo`00>Goo00<007ooOol0U7oo00<007`0Ool0ogoo=Woo000iOol00`00Oomo
o`2FOol00g`0Oomoo`3oOoldOol003Uoo`03001oogoo09Ioo`03O01oogoo0?moocAoo`00>Goo00<0
07ooOol0Ugoo00=l07oo0000ogoo9Woo00<007ooOol02Woo000iOol00`00Oomoo`2FOol01000O01o
o`00ogoo9Woo00<007ooOol02Woo000iOol00`00Oomoo`2FOol01000Ooml0000ogoo9Goo00<007oo
Ool02goo000iOol00`00Oomoo`2GOol01000O01oo`00ogoo97oo00<007ooOol02goo000iOol00`00
Oomoo`2GOol01@00O01oogoo0000ogoo8Woo00@007ooOol000]oo`00>Goo00<007ooOol0V7oo00<0
07`0Ool0ogoo9Goo00<007`0Ool02Woo000iOol00`00Oomoo`2IOol00g`0Oomoo`3oOolSOol00`00
O01oo`0;Ool003Uoo`03001oogoo09Yoo`03O01oogoo0?moob5oo`04001l07oo000;Ool003Uoo`03
001oogoo09Yoo`04O01oogoo003oOolMOol01P00Ool007`0Ool000aoo`00>Goo00<007ooOol0Vgoo
00=l07oo0000ogoo77oo00H007oo001l07oo000=Ool003Uoo`03001oogoo09Yoo`05001oog`0Ool0
003oOolJOol01P00Ool007`0Ool000ioo`00>Goo00<007ooOol0VWoo00<007ooO0000Woo00<007oo
Ool0ogoo5Woo00@007ooOoml015oo`00>Goo00<007ooOol0Vgoo00<007ooO0000Woo00<007ooOol0
ogoo5goo00<007`0Ool047oo000iOol00`00Oomoo`2KOol00`00Ooml003oOolKOol00`00O000000A
Ool003Uoo`03001oogoo09aoo`03001oog`00?mooaUoo`04001l07oo000AOol003Uoo`8009moo`03
O01oogoo0?mooaAoo`06001oogooO01oo`004Woo000iOol00`00Oomoo`2OOol017`0Oomoo`00ogoo
4Goo00L007ooOol007`0Ool0000BOol003Uoo`03001oogoo09moo`04O00007oo003oOol@Ool01`00
Oomoo`00O01oo`0001=oo`00>Goo00<007ooOol0WWoo00<007ooO0000Woo00<007ooOol0ogoo37oo
00D007ooOomoog`001Ioo`00>Goo00<007ooOol0WWoo00H007ooOoml07oo003oOolAOol00`00O01o
o`0EOol003Uoo`03001oogoo09moo`03001oog`0009oo`03001oogoo0?moo`eoo`03001l07oo01Io
o`00>Goo00<007ooOol0X7oo00<007ooO000ogoo47oo00@007`0Ool001Ioo`00>Goo00<007ooOol0
XGoo00<007`0Ool0ogoo2goo00L007ooOomoog`0Ool0000GOol003Uoo`03001oogoo0:=oo`03O01o
ogoo0?moo`Uoo`06001oogooO01oo`0067oo000iOol00`00Oomoo`2SOol017`0001oo`00ogoo1goo
00H007ooOoml07oo000IOol003Uoo`03001oogoo0:Aoo`03O01oo`000?moo`Ioo`05001oogoo001l
000KOol003Uoo`03001oogoo0:=oo`05001l0000Ool0003oOol4Ool01@00Oomoo`00O00077oo000i
Ool00`00Oomoo`2SOol00`00Ooml0002Ool00`00Oomoo`3oOol3Ool00`00O01oo`0LOol003Uoo`03
001oogoo0:Aoo`03001oog`0009oo`03001oogoo0?moo`5oo`04001l07oo000LOol003Uoo`03001o
ogoo0:Aoo`03001oog`00?moo`9oo`07001oogoo001l07oo00007Goo000iOol00`00Oomoo`2UOol0
0`00Ooml003oOol1Ool01P00Ool007`0Ool001ioo`00>Goo00<007ooOol0Ygoo00=l0000Ool0oGoo
00H007oo001l07oo000OOol003Uoo`800:Uoo`04O01oogoo003jOol01000Oomoog`08Woo000iOol0
0`00Oomoo`2XOol017`0001oo`00nGoo00D007ooOol007`0029oo`00>Goo00<007ooOol0Ygoo00<0
07ooO0000Woo00<007ooOol0mGoo00D007ooOol007`002=oo`00>Goo00<007ooOol0Ygoo00H007oo
Ooml07oo003fOol01`00Oomoo`00O01oo`00029oo`00>Goo00<007ooOol0Z7oo00<007ooO0000Woo
00<007ooOol0lWoo00L007ooOol007`0Ool0000SOol003Uoo`03001oogoo0:Uoo`03001oog`00?Eo
o`07001oogoo001l07oo000097oo000iOol00`00Oomoo`2ZOol00`00O000003cOol01`00Oomoo`00
O01oo`0002Eoo`00>Goo00<007ooOol0[7oo00=l07ooOol0m7oo00=l07ooOol09Woo000iOol00`00
Oomoo`2/Ool01G`0001oogoo0000lGoo00<007`0Ool09goo000iOol00`00Oomoo`2]Ool017`0Oomo
o`00k7oo00H007ooOomoo`00O00YOol003Uoo`03001oogoo0:aoo`03001l0000009oo`03001oogoo
0>Uoo`07001oogoo001l07oo0000:7oo000iOol00`00Oomoo`2/Ool00`00Ooml0002Ool00`00Oomo
o`3XOol01`00Oomoo`00O01oo`0002Uoo`00>Goo00<007ooOol0[Goo00<007ooO0000Woo00<007oo
Ool0iWoo00L007ooOol007`0Ool0000ZOol003Uoo`800:ioo`04001oog`0003YOol01`00Oomoo`00
O01oo`0002]oo`00>Goo00<007ooOol0[Woo00<007ooO000k7oo00=l07ooOol0;7oo000iOol00`00
Oomoo`2`Ool00g`0001oo`3YOol00`00O01oo`0]Ool003Uoo`03001oogoo0;5oo`04O01oogoo003R
Ool02000Oomoogoo001l07oo000]Ool003Uoo`03001oogoo0;5oo`04O00007oo003QOol02000Oomo
ogoo001l07oo000^Ool003Uoo`03001oogoo0;1oo`03001oog`0009oo`03001oogoo0=ioo`07001o
ogoo001l07oo0000;goo000iOol00`00Oomoo`2`Ool01000Ooml00000Woo00<007ooOol0g7oo00D0
07ooOol007`0039oo`00>Goo00<007ooOol0/Goo00@007ooO000009oo`03001oogoo0=Yoo`05001o
ogoo001l000cOol000=oo`<000Aoo`8000Aoo`05001oogooOol00003Ool30004Ool2000HOol00`00
Oomoo`2bOol00`00Ooml003QOol01000O01oo`00<Woo0006Ool01000Oomoogoo0P001Goo00<007oo
00001Goo00<007ooOol00Woo00@007ooOol001Moo`03001oogoo0;=oo`03001l00000=moo`04001l
07oo000cOol000Ioo`03001oogoo00Uoo`03001oogoo00Aoo`03001oogoo009oo`04001oogoo000G
Ool3002eOol00g`0Oomoo`3HOol20002Ool01000O01oo`00=7oo0003Ool3000;Ool00`00Ool00005
Ool00`00Oomoo`02Ool01000Oomoo`005goo00<007ooOol0]Goo00El0000Oomoo`000=Eoo`06001o
ogooOol007`00Woo00<007ooOol0<Woo0003Ool00`00Oomoo`0:Ool01@00Oomoogoo000017oo00<0
07ooOol00Woo00@007ooOol000Ioo`<00004Ool00000000:Ool00`00Oomoo`2fOol017`0001oo`00
eGoo00D007ooOol007`0009oo`03001oogoo03=oo`000goo10004Goo0P001Goo0P000goo0`000Woo
00D007ooOomoo`0000]oo`03001oogoo0;Eoo`06001oog`0001oo`00dgoo00D007ooOol007`003Uo
o`00:Goo00D007ooOomoo`0000]oo`03001oogoo0;Eoo`04001oogooO002Ool00`00Oomoo`3BOol0
0`00O01oo`0iOol002Qoo`80009oo`8000]oo`03001oogoo0;Ioo`04001oog`00002Ool00`00Oomo
o`3@Ool01000O01oo`00>Goo000iOol00`00Oomoo`2gOol01000Ooml0000cgoo00H007ooOomoo`00
O002Ool00`00Oomoo`0gOol003Uoo`03001oogoo0;Qoo`04001oog`0003>Ool01@00Oomoo`00O000
0Woo00<007ooOol0>7oo000iOol2002lOol01G`0Oomoogoo0000bGoo00H007ooOol007`0Ool2000k
Ool003Uoo`03001oogoo0;]oo`05O00007ooOol00038Ool01@00Oomoo`00O000?goo000iOol00`00
Oomoo`2kOol00`00O0000002Ool00`00Oomoo`34Ool01@00Oomoo`00O000@7oo000iOol00`00Oomo
o`2kOol01000Ooml00000Woo00<007ooOol0aGoo00<007`0Ool0@7oo000iOol00`00Oomoo`2lOol0
0`00Ooml0003Ool00`00Oomoo`33Ool01@00O01oogoo0000?goo000iOol00`00Oomoo`2lOol01000
Ooml0000`goo0P000Woo00D007`0Oomoo`00041oo`00>Goo00<007ooOol0_Goo00@007ooO0000<5o
o`06001oogooOol007`00Woo00<007ooOol0?goo000iOol20031Ool00g`0001oo`2nOol01P00Oomo
ogoo001l009oo`03001oogoo041oo`00>Goo00<007ooOol0`Goo00Al0000Ool00;]oo`06001oogoo
Ool007`0AWoo000iOol00`00Oomoo`32Ool00g`0Ool0002nOol00`00O01oo`16Ool003Uoo`03001o
ogoo0<1oo`06001oog`0001oo`00_7oo00@007`0Ool004Ioo`00>Goo00<007ooOol0`Goo00H007oo
O00007oo002fOol02000Oomoogoo001l07oo0017Ool003Uoo`03001oogoo0<9oo`06001oog`0001o
o`00]7oo00P007ooOomoo`00O01oo`00B7oo000iOol20034Ool00`00Ooml002eOol00`00Oomoo`02
00000g`0Ool00019Ool003Uoo`03001oogoo0<Eoo`03O00007oo0;9oo`04001oogoo0002O01<Ool0
03Uoo`03001oogoo0<Ioo`05O00007ooOol0002aOol00`00O01oo`1=Ool003Uoo`03001oogoo0<Mo
o`05O00007ooOol0002_Ool01@00O01oogoo0000C7oo000iOol00`00Oomoo`36Ool00`00Ooml0002
Ool00`00Oomoo`2XOol01P00Oomoogoo001l009oo`03001oogoo04]oo`00>Goo0P00agoo00@007oo
O000009oo`03001oogoo0:Ioo`06001oogooOol007`00Woo00<007ooOol0C7oo000iOol00`00Oomo
o`37Ool01000Ooml00000Woo00<007ooOol0Y7oo00H007ooOomoo`00O002Ool00`00Oomoo`1=Ool0
00=oo`<000Aoo`8000Aoo`05001oogooOol00003Ool30004Ool2000HOol00`00Oomoo`37Ool01@00
Oomoog`00000Ygoo00H007ooOomoo`00O002Ool00`00Oomoo`1>Ool000Aoo`03001oogoo00=oo`80
00Eoo`03001oo`0000Eoo`03001oogoo009oo`04001oogoo000GOol00`00Oomoo`38Ool01@00Oomo
og`00000Z7oo0P0000=l07ooOol0DWoo0004Ool00`00Oomoo`0;Ool00`00Oomoo`04Ool00`00Oomo
o`02Ool01000Oomoo`005goo00<007ooOol0c7oo00Al0000Oomoo`800:9oo`03001l07`005Eoo`00
17oo00<007ooOol02Woo00<007oo00001Goo00<007ooOol00Woo00@007ooOol001Moo`<00<eoo`03
O00007oo009oo`03001oogoo09Yoo`06001oogooOol007`00Woo0P00Dgoo0004Ool00`00Oomoo`09
Ool01@00Oomoogoo000017oo00<007ooOol00Woo00@007ooOol001Moo`03001oogoo0<]oo`05001o
ogooO0000003Ool00`00Oomoo`2HOol01P00Oomoogoo001l009oo`03001oogoo05=oo`000goo0P00
4goo0P001Goo0P001goo0`0000Aoo`00000000Yoo`03001oogoo0<aoo`05001oogooO0000003Ool0
0`00Oomoo`2FOol01P00Oomoogoo001l009oo`03001oogoo05Aoo`0097oo0`000Woo00H007ooOol0
07oo000:Ool00`00Oomoo`3=Ool01@00Oomoog`00000VWoo00H007ooOomoo`00O002Ool00`00Oomo
o`1EOol002Uoo`06001oogoo001oo`002Woo00<007ooOol0cWoo00D007ooOoml000009aoo`03001l
07oo05Yoo`00:7oo0P000Woo0`002Woo00<007ooOol0cgoo00D007ooOoml000000=oo`03001oogoo
09Aoo`03001l07oo05]oo`00>Goo00<007ooOol0dgoo00El0000Oomoo`0008moo`8000=oo`800004
O01oo`00001JOol003Uoo`03001oogoo0=Aoo`05O00007ooOol0002=Ool00`00Oomoo`02Ool01@00
O01l07oo0000G7oo000iOol00`00Oomoo`3BOol01@00Oomoog`000000Woo00<007ooOol0RGoo00<0
07ooOol00Woo00D007`0Oomoo`0005eoo`00>Goo00<007ooOol0dgoo00D007ooOoml0000009oo`03
001oogoo08Moo`05001oogooOol00002O002Ool00`00Oomoo`1LOol003Uoo`03001oogoo0=Aoo`05
001oogooO000002>Ool2O01SOol003Uoo`03001oogoo0=Eoo`05001oogooO0000026Ool00`00Oomo
o`02Ool01000O01oogoo0P00HGoo000iOol00`00Oomoo`3IOol017`0001oogoo0P00P7oo00<007oo
Ool00Woo0W`00Woo00<007ooOol0HGoo000iOol00`00Oomoo`3JOol00g`0001oo`02Ool00`00Oomo
o`1lOol00`00Oomoo`02Ool01G`0Oomoogoo0000I7oo000iOol00`00Oomoo`3HOol01@00Oomoog`0
00000goo00<007ooOol0NWoo00@007ooOomoo`9l00=oo`03001oogoo06=oo`00>Goo00<007ooOol0
fGoo00@007ooOoml0080009oo`03001oogoo07aoo`03O01oogoo06Uoo`00>Goo00<007ooOol0fWoo
00<007ooOol00W`000<007ooOol0OGoo00=l07ooOol0JWoo000iOol00`00Oomoo`3KOol01P00Oomo
ogooO00007Ioo`<000=oo`9l009oo`8006Uoo`00>Goo00<007ooOol0g7oo00H007ooOomoog`00003
Ool2001_Ool00`00Oomoo`03Ool01G`0Oomoogoo0000Jgoo000iOol00`00Oomoo`3QOol00g`00000
0003Ool00`00Oomoo`1[Ool00`00Oomoo`02Ool2O003Ool00`00Oomoo`1ZOol003Uoo`03001oogoo
0>9oo`9l0005001oogooOol0001`Ool00g`0Oomoo`02Ool00`00Oomoo`1[Ool003Uoo`03001oogoo
0=moo`8000=oo`03O00007oo06Uoo`8000Ioo`03O01oogoo075oo`00>Goo00<007ooOol0hGoo0P00
0Woo00=l00000000Igoo00<007ooOol017oo0W`00Woo0P00L7oo000iOol00`00Oomoo`3SOol00`00
Oomoo`02O0001000Oomoogoo0P00H7oo00<007ooOol00goo0W`00goo00<007ooOol0L7oo000iOol0
0`00Oomoo`3XOol00g`0001oo`03Ool2001MOol00`00Oomoo`02Ool2O004Ool00`00Oomoo`1aOol0
03Uoo`03001oogoo0>Uoo`03O00007oo00Aoo`03001oogoo05aoo`03001l07`000Eoo`03001oogoo
079oo`00>Goo00<007ooOol0igoo00@007ooOoml008005Yoo`<000=oo`800003O01oogoo07Yoo`00
>Goo00<007ooOol0j7oo00<007ooOol00W`00P001Goo0P00CWoo0`0017oo0P000W`00goo0P00N7oo
000iOol00`00Oomoo`3YOol01000Oomoogoo0W`00P001Goo0P00DGoo0P000W`00goo0P00NWoo000i
Ool00`00Oomoo`3ZOol00`00Oomoo`02Ool2O0020005Ool00`00Oomoo`14Ool20006Ool20002O004
Ool00`00Oomoo`1jOol003Uoo`800?9oo`9l0003001oogoo009oo`03001oogoo04=oo`03001oogoo
00Aoo`04001l07`0O023Ool003Uoo`03001oogoo0>ioo`8000=oo`03O000000000Moo`8003eoo`80
00Eoo`03001l07`000Aoo`80081oo`00>Goo00<007ooOol0l7oo0P000Woo0W`00P001goo0P00@7oo
00<007`0O0000goo0`00PWoo000iOol00`00Oomoo`3bOol01000Oomoogoo0W`00P001goo00<007oo
Ool0<7oo10001goo0g`017oo00<007ooOol0Pgoo000iOol00`00Oomoo`3hOol2O0030008Ool3000[
Ool00`00Oomoo`07Ool2O02=Ool003Uoo`03001oogoo0?Yoo`=l008000Uoo`<0021oo`D000Yoo`03
001l07`000Aoo`8008Uoo`00>Goo00<007ooOol0mWoo0P001Goo0W`00`0037oo0`006Goo00<007oo
Ool02Woo00@007`0O01l00Aoo`8008]oo`00>Goo00<007ooOol0n7oo0`0017oo0g`00`0037oo0`00
17oo1@0017oo1@003Goo0`000W`01Woo00<007ooOol0Rgoo000iOol00`00Oomoo`3kOol00`00Oomo
o`04Ool3O003000VOol50003O02FOol003Uoo`03001oogoo0?moo`8000Aoo`Il00<001eoo`<000El
00Eoo`<0095oo`00>Goo00<007ooOol0ogoo0Woo0P0027oo1W`00`003goo10001g`01goo0`00U7oo
000iOol00`00Oomoo`3oOol4Ool00`00Oomoo`0;Ool9O0040009O009Ool2002JOol003Uoo`03001o
ogoo0?moo`Uoo`<000ioo`El00ioo`@009aoo`00>Goo00<007ooOol0ogoo37oo0P006Woo0P00Xgoo
000iOol00`00Oomoo`3oOolBOol50004Ool60003Ool4002UOol003Uoo`03001oogoo0?mooleoo`00
>Goo00<007ooOol0ogoocGoo000iOol00`00Oomoo`3oOoo=Ool003Uoo`800?moolioo`00>Goo00<0
07ooOol0ogoocGoo000iOol00`00Oomoo`3oOoo=Ool003Uoo`03001oogoo0?mooleoo`00ogooogoo
2Woo003oOoooOol:Ool00?mooomoo`Yoo`00ogooogoo2Woo003oOoooOol:Ool00?mooomoo`Yoo`00
ogooogoo2Woo003oOoooOol:Ool00001\
\>"],
  ImageRangeCache->{{{0, 519}, {320.25, 0}} -> {-0.247702, -12.562, 
  0.00364127, 0.00983994}}]
}, Closed]],

Cell["\<\
The distribution is vaguely log. normal, but with a skew to small \
values.  The standard errors above are therefore misleading:\
\>", \
"MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(BarChart[
      BinCounts[Log[gt /. \[Theta] -> 1. ], {\(-55\), \(-15\), 0.5}], 
      BinCounts[Log[gt /. \[Theta] -> 10. ], {\(-55\), \(-15\), 0.5}], 
      PlotRange -> {{0, 80}, {0, 100}}]; \)\)], "Input",
  CellLabel->"In[235]:="],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 0.0125 0 0.00618034 [
[.015 -0.0125 -3 -9 ]
[.015 -0.0125 3 0 ]
[.0275 -0.0125 -3 -9 ]
[.0275 -0.0125 3 0 ]
[.04 -0.0125 -3 -9 ]
[.04 -0.0125 3 0 ]
[.0525 -0.0125 -3 -9 ]
[.0525 -0.0125 3 0 ]
[.065 -0.0125 -3 -9 ]
[.065 -0.0125 3 0 ]
[.0775 -0.0125 -3 -9 ]
[.0775 -0.0125 3 0 ]
[.09 -0.0125 -3 -9 ]
[.09 -0.0125 3 0 ]
[.1025 -0.0125 -3 -9 ]
[.1025 -0.0125 3 0 ]
[.115 -0.0125 -3 -9 ]
[.115 -0.0125 3 0 ]
[.1275 -0.0125 -6 -9 ]
[.1275 -0.0125 6 0 ]
[.14 -0.0125 -6 -9 ]
[.14 -0.0125 6 0 ]
[.1525 -0.0125 -6 -9 ]
[.1525 -0.0125 6 0 ]
[.165 -0.0125 -6 -9 ]
[.165 -0.0125 6 0 ]
[.1775 -0.0125 -6 -9 ]
[.1775 -0.0125 6 0 ]
[.19 -0.0125 -6 -9 ]
[.19 -0.0125 6 0 ]
[.2025 -0.0125 -6 -9 ]
[.2025 -0.0125 6 0 ]
[.215 -0.0125 -6 -9 ]
[.215 -0.0125 6 0 ]
[.2275 -0.0125 -6 -9 ]
[.2275 -0.0125 6 0 ]
[.24 -0.0125 -6 -9 ]
[.24 -0.0125 6 0 ]
[.2525 -0.0125 -6 -9 ]
[.2525 -0.0125 6 0 ]
[.265 -0.0125 -6 -9 ]
[.265 -0.0125 6 0 ]
[.2775 -0.0125 -6 -9 ]
[.2775 -0.0125 6 0 ]
[.29 -0.0125 -6 -9 ]
[.29 -0.0125 6 0 ]
[.3025 -0.0125 -6 -9 ]
[.3025 -0.0125 6 0 ]
[.315 -0.0125 -6 -9 ]
[.315 -0.0125 6 0 ]
[.3275 -0.0125 -6 -9 ]
[.3275 -0.0125 6 0 ]
[.34 -0.0125 -6 -9 ]
[.34 -0.0125 6 0 ]
[.3525 -0.0125 -6 -9 ]
[.3525 -0.0125 6 0 ]
[.365 -0.0125 -6 -9 ]
[.365 -0.0125 6 0 ]
[.3775 -0.0125 -6 -9 ]
[.3775 -0.0125 6 0 ]
[.39 -0.0125 -6 -9 ]
[.39 -0.0125 6 0 ]
[.4025 -0.0125 -6 -9 ]
[.4025 -0.0125 6 0 ]
[.415 -0.0125 -6 -9 ]
[.415 -0.0125 6 0 ]
[.4275 -0.0125 -6 -9 ]
[.4275 -0.0125 6 0 ]
[.44 -0.0125 -6 -9 ]
[.44 -0.0125 6 0 ]
[.4525 -0.0125 -6 -9 ]
[.4525 -0.0125 6 0 ]
[.465 -0.0125 -6 -9 ]
[.465 -0.0125 6 0 ]
[.4775 -0.0125 -6 -9 ]
[.4775 -0.0125 6 0 ]
[.49 -0.0125 -6 -9 ]
[.49 -0.0125 6 0 ]
[.5025 -0.0125 -6 -9 ]
[.5025 -0.0125 6 0 ]
[.515 -0.0125 -6 -9 ]
[.515 -0.0125 6 0 ]
[.5275 -0.0125 -6 -9 ]
[.5275 -0.0125 6 0 ]
[.54 -0.0125 -6 -9 ]
[.54 -0.0125 6 0 ]
[.5525 -0.0125 -6 -9 ]
[.5525 -0.0125 6 0 ]
[.565 -0.0125 -6 -9 ]
[.565 -0.0125 6 0 ]
[.5775 -0.0125 -6 -9 ]
[.5775 -0.0125 6 0 ]
[.59 -0.0125 -6 -9 ]
[.59 -0.0125 6 0 ]
[.6025 -0.0125 -6 -9 ]
[.6025 -0.0125 6 0 ]
[.615 -0.0125 -6 -9 ]
[.615 -0.0125 6 0 ]
[.6275 -0.0125 -6 -9 ]
[.6275 -0.0125 6 0 ]
[.64 -0.0125 -6 -9 ]
[.64 -0.0125 6 0 ]
[.6525 -0.0125 -6 -9 ]
[.6525 -0.0125 6 0 ]
[.665 -0.0125 -6 -9 ]
[.665 -0.0125 6 0 ]
[.6775 -0.0125 -6 -9 ]
[.6775 -0.0125 6 0 ]
[.69 -0.0125 -6 -9 ]
[.69 -0.0125 6 0 ]
[.7025 -0.0125 -6 -9 ]
[.7025 -0.0125 6 0 ]
[.715 -0.0125 -6 -9 ]
[.715 -0.0125 6 0 ]
[.7275 -0.0125 -6 -9 ]
[.7275 -0.0125 6 0 ]
[.74 -0.0125 -6 -9 ]
[.74 -0.0125 6 0 ]
[.7525 -0.0125 -6 -9 ]
[.7525 -0.0125 6 0 ]
[.765 -0.0125 -6 -9 ]
[.765 -0.0125 6 0 ]
[.7775 -0.0125 -6 -9 ]
[.7775 -0.0125 6 0 ]
[.79 -0.0125 -6 -9 ]
[.79 -0.0125 6 0 ]
[.8025 -0.0125 -6 -9 ]
[.8025 -0.0125 6 0 ]
[.815 -0.0125 -6 -9 ]
[.815 -0.0125 6 0 ]
[.8275 -0.0125 -6 -9 ]
[.8275 -0.0125 6 0 ]
[.84 -0.0125 -6 -9 ]
[.84 -0.0125 6 0 ]
[.8525 -0.0125 -6 -9 ]
[.8525 -0.0125 6 0 ]
[.865 -0.0125 -6 -9 ]
[.865 -0.0125 6 0 ]
[.8775 -0.0125 -6 -9 ]
[.8775 -0.0125 6 0 ]
[.89 -0.0125 -6 -9 ]
[.89 -0.0125 6 0 ]
[.9025 -0.0125 -6 -9 ]
[.9025 -0.0125 6 0 ]
[.915 -0.0125 -6 -9 ]
[.915 -0.0125 6 0 ]
[.9275 -0.0125 -6 -9 ]
[.9275 -0.0125 6 0 ]
[.94 -0.0125 -6 -9 ]
[.94 -0.0125 6 0 ]
[.9525 -0.0125 -6 -9 ]
[.9525 -0.0125 6 0 ]
[.965 -0.0125 -6 -9 ]
[.965 -0.0125 6 0 ]
[.9775 -0.0125 -6 -9 ]
[.9775 -0.0125 6 0 ]
[.99 -0.0125 -6 -9 ]
[.99 -0.0125 6 0 ]
[-0.005 .12361 -12 -4.5 ]
[-0.005 .12361 0 4.5 ]
[-0.005 .24721 -12 -4.5 ]
[-0.005 .24721 0 4.5 ]
[-0.005 .37082 -12 -4.5 ]
[-0.005 .37082 0 4.5 ]
[-0.005 .49443 -12 -4.5 ]
[-0.005 .49443 0 4.5 ]
[-0.005 .61803 -18 -4.5 ]
[-0.005 .61803 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.015 0 m
.015 .00625 L
s
[(1)] .015 -0.0125 0 1 Mshowa
.0275 0 m
.0275 .00625 L
s
[(2)] .0275 -0.0125 0 1 Mshowa
.04 0 m
.04 .00625 L
s
[(3)] .04 -0.0125 0 1 Mshowa
.0525 0 m
.0525 .00625 L
s
[(4)] .0525 -0.0125 0 1 Mshowa
.065 0 m
.065 .00625 L
s
[(5)] .065 -0.0125 0 1 Mshowa
.0775 0 m
.0775 .00625 L
s
[(6)] .0775 -0.0125 0 1 Mshowa
.09 0 m
.09 .00625 L
s
[(7)] .09 -0.0125 0 1 Mshowa
.1025 0 m
.1025 .00625 L
s
[(8)] .1025 -0.0125 0 1 Mshowa
.115 0 m
.115 .00625 L
s
[(9)] .115 -0.0125 0 1 Mshowa
.1275 0 m
.1275 .00625 L
s
[(10)] .1275 -0.0125 0 1 Mshowa
.14 0 m
.14 .00625 L
s
[(11)] .14 -0.0125 0 1 Mshowa
.1525 0 m
.1525 .00625 L
s
[(12)] .1525 -0.0125 0 1 Mshowa
.165 0 m
.165 .00625 L
s
[(13)] .165 -0.0125 0 1 Mshowa
.1775 0 m
.1775 .00625 L
s
[(14)] .1775 -0.0125 0 1 Mshowa
.19 0 m
.19 .00625 L
s
[(15)] .19 -0.0125 0 1 Mshowa
.2025 0 m
.2025 .00625 L
s
[(16)] .2025 -0.0125 0 1 Mshowa
.215 0 m
.215 .00625 L
s
[(17)] .215 -0.0125 0 1 Mshowa
.2275 0 m
.2275 .00625 L
s
[(18)] .2275 -0.0125 0 1 Mshowa
.24 0 m
.24 .00625 L
s
[(19)] .24 -0.0125 0 1 Mshowa
.2525 0 m
.2525 .00625 L
s
[(20)] .2525 -0.0125 0 1 Mshowa
.265 0 m
.265 .00625 L
s
[(21)] .265 -0.0125 0 1 Mshowa
.2775 0 m
.2775 .00625 L
s
[(22)] .2775 -0.0125 0 1 Mshowa
.29 0 m
.29 .00625 L
s
[(23)] .29 -0.0125 0 1 Mshowa
.3025 0 m
.3025 .00625 L
s
[(24)] .3025 -0.0125 0 1 Mshowa
.315 0 m
.315 .00625 L
s
[(25)] .315 -0.0125 0 1 Mshowa
.3275 0 m
.3275 .00625 L
s
[(26)] .3275 -0.0125 0 1 Mshowa
.34 0 m
.34 .00625 L
s
[(27)] .34 -0.0125 0 1 Mshowa
.3525 0 m
.3525 .00625 L
s
[(28)] .3525 -0.0125 0 1 Mshowa
.365 0 m
.365 .00625 L
s
[(29)] .365 -0.0125 0 1 Mshowa
.3775 0 m
.3775 .00625 L
s
[(30)] .3775 -0.0125 0 1 Mshowa
.39 0 m
.39 .00625 L
s
[(31)] .39 -0.0125 0 1 Mshowa
.4025 0 m
.4025 .00625 L
s
[(32)] .4025 -0.0125 0 1 Mshowa
.415 0 m
.415 .00625 L
s
[(33)] .415 -0.0125 0 1 Mshowa
.4275 0 m
.4275 .00625 L
s
[(34)] .4275 -0.0125 0 1 Mshowa
.44 0 m
.44 .00625 L
s
[(35)] .44 -0.0125 0 1 Mshowa
.4525 0 m
.4525 .00625 L
s
[(36)] .4525 -0.0125 0 1 Mshowa
.465 0 m
.465 .00625 L
s
[(37)] .465 -0.0125 0 1 Mshowa
.4775 0 m
.4775 .00625 L
s
[(38)] .4775 -0.0125 0 1 Mshowa
.49 0 m
.49 .00625 L
s
[(39)] .49 -0.0125 0 1 Mshowa
.5025 0 m
.5025 .00625 L
s
[(40)] .5025 -0.0125 0 1 Mshowa
.515 0 m
.515 .00625 L
s
[(41)] .515 -0.0125 0 1 Mshowa
.5275 0 m
.5275 .00625 L
s
[(42)] .5275 -0.0125 0 1 Mshowa
.54 0 m
.54 .00625 L
s
[(43)] .54 -0.0125 0 1 Mshowa
.5525 0 m
.5525 .00625 L
s
[(44)] .5525 -0.0125 0 1 Mshowa
.565 0 m
.565 .00625 L
s
[(45)] .565 -0.0125 0 1 Mshowa
.5775 0 m
.5775 .00625 L
s
[(46)] .5775 -0.0125 0 1 Mshowa
.59 0 m
.59 .00625 L
s
[(47)] .59 -0.0125 0 1 Mshowa
.6025 0 m
.6025 .00625 L
s
[(48)] .6025 -0.0125 0 1 Mshowa
.615 0 m
.615 .00625 L
s
[(49)] .615 -0.0125 0 1 Mshowa
.6275 0 m
.6275 .00625 L
s
[(50)] .6275 -0.0125 0 1 Mshowa
.64 0 m
.64 .00625 L
s
[(51)] .64 -0.0125 0 1 Mshowa
.6525 0 m
.6525 .00625 L
s
[(52)] .6525 -0.0125 0 1 Mshowa
.665 0 m
.665 .00625 L
s
[(53)] .665 -0.0125 0 1 Mshowa
.6775 0 m
.6775 .00625 L
s
[(54)] .6775 -0.0125 0 1 Mshowa
.69 0 m
.69 .00625 L
s
[(55)] .69 -0.0125 0 1 Mshowa
.7025 0 m
.7025 .00625 L
s
[(56)] .7025 -0.0125 0 1 Mshowa
.715 0 m
.715 .00625 L
s
[(57)] .715 -0.0125 0 1 Mshowa
.7275 0 m
.7275 .00625 L
s
[(58)] .7275 -0.0125 0 1 Mshowa
.74 0 m
.74 .00625 L
s
[(59)] .74 -0.0125 0 1 Mshowa
.7525 0 m
.7525 .00625 L
s
[(60)] .7525 -0.0125 0 1 Mshowa
.765 0 m
.765 .00625 L
s
[(61)] .765 -0.0125 0 1 Mshowa
.7775 0 m
.7775 .00625 L
s
[(62)] .7775 -0.0125 0 1 Mshowa
.79 0 m
.79 .00625 L
s
[(63)] .79 -0.0125 0 1 Mshowa
.8025 0 m
.8025 .00625 L
s
[(64)] .8025 -0.0125 0 1 Mshowa
.815 0 m
.815 .00625 L
s
[(65)] .815 -0.0125 0 1 Mshowa
.8275 0 m
.8275 .00625 L
s
[(66)] .8275 -0.0125 0 1 Mshowa
.84 0 m
.84 .00625 L
s
[(67)] .84 -0.0125 0 1 Mshowa
.8525 0 m
.8525 .00625 L
s
[(68)] .8525 -0.0125 0 1 Mshowa
.865 0 m
.865 .00625 L
s
[(69)] .865 -0.0125 0 1 Mshowa
.8775 0 m
.8775 .00625 L
s
[(70)] .8775 -0.0125 0 1 Mshowa
.89 0 m
.89 .00625 L
s
[(71)] .89 -0.0125 0 1 Mshowa
.9025 0 m
.9025 .00625 L
s
[(72)] .9025 -0.0125 0 1 Mshowa
.915 0 m
.915 .00625 L
s
[(73)] .915 -0.0125 0 1 Mshowa
.9275 0 m
.9275 .00625 L
s
[(74)] .9275 -0.0125 0 1 Mshowa
.94 0 m
.94 .00625 L
s
[(75)] .94 -0.0125 0 1 Mshowa
.9525 0 m
.9525 .00625 L
s
[(76)] .9525 -0.0125 0 1 Mshowa
.965 0 m
.965 .00625 L
s
[(77)] .965 -0.0125 0 1 Mshowa
.9775 0 m
.9775 .00625 L
s
[(78)] .9775 -0.0125 0 1 Mshowa
.99 0 m
.99 .00625 L
s
[(79)] .99 -0.0125 0 1 Mshowa
0 0 m
1 0 L
s
.0075 .12361 m
.01375 .12361 L
s
[(20)] -0.005 .12361 1 0 Mshowa
.0075 .24721 m
.01375 .24721 L
s
[(40)] -0.005 .24721 1 0 Mshowa
.0075 .37082 m
.01375 .37082 L
s
[(60)] -0.005 .37082 1 0 Mshowa
.0075 .49443 m
.01375 .49443 L
s
[(80)] -0.005 .49443 1 0 Mshowa
.0075 .61803 m
.01375 .61803 L
s
[(100)] -0.005 .61803 1 0 Mshowa
.125 Mabswid
.0075 .0309 m
.01125 .0309 L
s
.0075 .0618 m
.01125 .0618 L
s
.0075 .09271 m
.01125 .09271 L
s
.0075 .15451 m
.01125 .15451 L
s
.0075 .18541 m
.01125 .18541 L
s
.0075 .21631 m
.01125 .21631 L
s
.0075 .27812 m
.01125 .27812 L
s
.0075 .30902 m
.01125 .30902 L
s
.0075 .33992 m
.01125 .33992 L
s
.0075 .40172 m
.01125 .40172 L
s
.0075 .43262 m
.01125 .43262 L
s
.0075 .46353 m
.01125 .46353 L
s
.0075 .52533 m
.01125 .52533 L
s
.0075 .55623 m
.01125 .55623 L
s
.0075 .58713 m
.01125 .58713 L
s
.25 Mabswid
.0075 0 m
.0075 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
1 0 0 r
.01 0 m
.01 0 L
.015 0 L
.015 0 L
F
0 g
.5 Mabswid
.01 0 m
.01 0 L
.015 0 L
.015 0 L
.01 0 L
s
1 0 0 r
.0225 0 m
.0225 0 L
.0275 0 L
.0275 0 L
F
0 g
.0225 0 m
.0225 0 L
.0275 0 L
.0275 0 L
.0225 0 L
s
1 0 0 r
.035 0 m
.035 0 L
.04 0 L
.04 0 L
F
0 g
.035 0 m
.035 0 L
.04 0 L
.04 0 L
.035 0 L
s
1 0 0 r
.0475 0 m
.0475 0 L
.0525 0 L
.0525 0 L
F
0 g
.0475 0 m
.0475 0 L
.0525 0 L
.0525 0 L
.0475 0 L
s
1 0 0 r
.06 0 m
.06 0 L
.065 0 L
.065 0 L
F
0 g
.06 0 m
.06 0 L
.065 0 L
.065 0 L
.06 0 L
s
1 0 0 r
.0725 0 m
.0725 .00618 L
.0775 .00618 L
.0775 0 L
F
0 g
.0725 0 m
.0725 .00618 L
.0775 .00618 L
.0775 0 L
.0725 0 L
s
1 0 0 r
.085 0 m
.085 0 L
.09 0 L
.09 0 L
F
0 g
.085 0 m
.085 0 L
.09 0 L
.09 0 L
.085 0 L
s
1 0 0 r
.0975 0 m
.0975 0 L
.1025 0 L
.1025 0 L
F
0 g
.0975 0 m
.0975 0 L
.1025 0 L
.1025 0 L
.0975 0 L
s
1 0 0 r
.11 0 m
.11 0 L
.115 0 L
.115 0 L
F
0 g
.11 0 m
.11 0 L
.115 0 L
.115 0 L
.11 0 L
s
1 0 0 r
.1225 0 m
.1225 0 L
.1275 0 L
.1275 0 L
F
0 g
.1225 0 m
.1225 0 L
.1275 0 L
.1275 0 L
.1225 0 L
s
1 0 0 r
.135 0 m
.135 0 L
.14 0 L
.14 0 L
F
0 g
.135 0 m
.135 0 L
.14 0 L
.14 0 L
.135 0 L
s
1 0 0 r
.1475 0 m
.1475 0 L
.1525 0 L
.1525 0 L
F
0 g
.1475 0 m
.1475 0 L
.1525 0 L
.1525 0 L
.1475 0 L
s
1 0 0 r
.16 0 m
.16 .00618 L
.165 .00618 L
.165 0 L
F
0 g
.16 0 m
.16 .00618 L
.165 .00618 L
.165 0 L
.16 0 L
s
1 0 0 r
.1725 0 m
.1725 0 L
.1775 0 L
.1775 0 L
F
0 g
.1725 0 m
.1725 0 L
.1775 0 L
.1775 0 L
.1725 0 L
s
1 0 0 r
.185 0 m
.185 .00618 L
.19 .00618 L
.19 0 L
F
0 g
.185 0 m
.185 .00618 L
.19 .00618 L
.19 0 L
.185 0 L
s
1 0 0 r
.1975 0 m
.1975 .01854 L
.2025 .01854 L
.2025 0 L
F
0 g
.1975 0 m
.1975 .01854 L
.2025 .01854 L
.2025 0 L
.1975 0 L
s
1 0 0 r
.21 0 m
.21 .01854 L
.215 .01854 L
.215 0 L
F
0 g
.21 0 m
.21 .01854 L
.215 .01854 L
.215 0 L
.21 0 L
s
1 0 0 r
.2225 0 m
.2225 .0309 L
.2275 .0309 L
.2275 0 L
F
0 g
.2225 0 m
.2225 .0309 L
.2275 .0309 L
.2275 0 L
.2225 0 L
s
1 0 0 r
.235 0 m
.235 .0618 L
.24 .0618 L
.24 0 L
F
0 g
.235 0 m
.235 .0618 L
.24 .0618 L
.24 0 L
.235 0 L
s
1 0 0 r
.2475 0 m
.2475 .04326 L
.2525 .04326 L
.2525 0 L
F
0 g
.2475 0 m
.2475 .04326 L
.2525 .04326 L
.2525 0 L
.2475 0 L
s
1 0 0 r
.26 0 m
.26 .04326 L
.265 .04326 L
.265 0 L
F
0 g
.26 0 m
.26 .04326 L
.265 .04326 L
.265 0 L
.26 0 L
s
1 0 0 r
.2725 0 m
.2725 .0618 L
.2775 .0618 L
.2775 0 L
F
0 g
.2725 0 m
.2725 .0618 L
.2775 .0618 L
.2775 0 L
.2725 0 L
s
1 0 0 r
.285 0 m
.285 .11125 L
.29 .11125 L
.29 0 L
F
0 g
.285 0 m
.285 .11125 L
.29 .11125 L
.29 0 L
.285 0 L
s
1 0 0 r
.2975 0 m
.2975 .09271 L
.3025 .09271 L
.3025 0 L
F
0 g
.2975 0 m
.2975 .09271 L
.3025 .09271 L
.3025 0 L
.2975 0 L
s
1 0 0 r
.31 0 m
.31 .12361 L
.315 .12361 L
.315 0 L
F
0 g
.31 0 m
.31 .12361 L
.315 .12361 L
.315 0 L
.31 0 L
s
1 0 0 r
.3225 0 m
.3225 .09889 L
.3275 .09889 L
.3275 0 L
F
0 g
.3225 0 m
.3225 .09889 L
.3275 .09889 L
.3275 0 L
.3225 0 L
s
1 0 0 r
.335 0 m
.335 .18541 L
.34 .18541 L
.34 0 L
F
0 g
.335 0 m
.335 .18541 L
.34 .18541 L
.34 0 L
.335 0 L
s
1 0 0 r
.3475 0 m
.3475 .30284 L
.3525 .30284 L
.3525 0 L
F
0 g
.3475 0 m
.3475 .30284 L
.3525 .30284 L
.3525 0 L
.3475 0 L
s
1 0 0 r
.36 0 m
.36 .29048 L
.365 .29048 L
.365 0 L
F
0 g
.36 0 m
.36 .29048 L
.365 .29048 L
.365 0 L
.36 0 L
s
1 0 0 r
.3725 0 m
.3725 .27193 L
.3775 .27193 L
.3775 0 L
F
0 g
.3725 0 m
.3725 .27193 L
.3775 .27193 L
.3775 0 L
.3725 0 L
s
1 0 0 r
.385 0 m
.385 .40172 L
.39 .40172 L
.39 0 L
F
0 g
.385 0 m
.385 .40172 L
.39 .40172 L
.39 0 L
.385 0 L
s
1 0 0 r
.3975 0 m
.3975 .46971 L
.4025 .46971 L
.4025 0 L
F
0 g
.3975 0 m
.3975 .46971 L
.4025 .46971 L
.4025 0 L
.3975 0 L
s
1 0 0 r
.41 0 m
.41 .51297 L
.415 .51297 L
.415 0 L
F
0 g
.41 0 m
.41 .51297 L
.415 .51297 L
.415 0 L
.41 0 L
s
1 0 0 r
.4225 0 m
.4225 .42026 L
.4275 .42026 L
.4275 0 L
F
0 g
.4225 0 m
.4225 .42026 L
.4275 .42026 L
.4275 0 L
.4225 0 L
s
1 0 0 r
.435 0 m
.435 .50679 L
.44 .50679 L
.44 0 L
F
0 g
.435 0 m
.435 .50679 L
.44 .50679 L
.44 0 L
.435 0 L
s
1 0 0 r
.4475 0 m
.4475 .48207 L
.4525 .48207 L
.4525 0 L
F
0 g
.4475 0 m
.4475 .48207 L
.4525 .48207 L
.4525 0 L
.4475 0 L
s
1 0 0 r
.46 0 m
.46 .4388 L
.465 .4388 L
.465 0 L
F
0 g
.46 0 m
.46 .4388 L
.465 .4388 L
.465 0 L
.46 0 L
s
1 0 0 r
.4725 0 m
.4725 .33374 L
.4775 .33374 L
.4775 0 L
F
0 g
.4725 0 m
.4725 .33374 L
.4775 .33374 L
.4775 0 L
.4725 0 L
s
1 0 0 r
.485 0 m
.485 .22867 L
.49 .22867 L
.49 0 L
F
0 g
.485 0 m
.485 .22867 L
.49 .22867 L
.49 0 L
.485 0 L
s
1 0 0 r
.4975 0 m
.4975 .21013 L
.5025 .21013 L
.5025 0 L
F
0 g
.4975 0 m
.4975 .21013 L
.5025 .21013 L
.5025 0 L
.4975 0 L
s
1 0 0 r
.51 0 m
.51 .18541 L
.515 .18541 L
.515 0 L
F
0 g
.51 0 m
.51 .18541 L
.515 .18541 L
.515 0 L
.51 0 L
s
1 0 0 r
.5225 0 m
.5225 .09271 L
.5275 .09271 L
.5275 0 L
F
0 g
.5225 0 m
.5225 .09271 L
.5275 .09271 L
.5275 0 L
.5225 0 L
s
1 0 0 r
.535 0 m
.535 .06798 L
.54 .06798 L
.54 0 L
F
0 g
.535 0 m
.535 .06798 L
.54 .06798 L
.54 0 L
.535 0 L
s
1 0 0 r
.5475 0 m
.5475 .0309 L
.5525 .0309 L
.5525 0 L
F
0 g
.5475 0 m
.5475 .0309 L
.5525 .0309 L
.5525 0 L
.5475 0 L
s
1 0 0 r
.56 0 m
.56 .01854 L
.565 .01854 L
.565 0 L
F
0 g
.56 0 m
.56 .01854 L
.565 .01854 L
.565 0 L
.56 0 L
s
1 0 0 r
.5725 0 m
.5725 .00618 L
.5775 .00618 L
.5775 0 L
F
0 g
.5725 0 m
.5725 .00618 L
.5775 .00618 L
.5775 0 L
.5725 0 L
s
1 0 0 r
.585 0 m
.585 0 L
.59 0 L
.59 0 L
F
0 g
.585 0 m
.585 0 L
.59 0 L
.59 0 L
.585 0 L
s
1 0 0 r
.5975 0 m
.5975 0 L
.6025 0 L
.6025 0 L
F
0 g
.5975 0 m
.5975 0 L
.6025 0 L
.6025 0 L
.5975 0 L
s
1 0 0 r
.61 0 m
.61 0 L
.615 0 L
.615 0 L
F
0 g
.61 0 m
.61 0 L
.615 0 L
.615 0 L
.61 0 L
s
1 0 0 r
.6225 0 m
.6225 0 L
.6275 0 L
.6275 0 L
F
0 g
.6225 0 m
.6225 0 L
.6275 0 L
.6275 0 L
.6225 0 L
s
1 0 0 r
.635 0 m
.635 0 L
.64 0 L
.64 0 L
F
0 g
.635 0 m
.635 0 L
.64 0 L
.64 0 L
.635 0 L
s
1 0 0 r
.6475 0 m
.6475 0 L
.6525 0 L
.6525 0 L
F
0 g
.6475 0 m
.6475 0 L
.6525 0 L
.6525 0 L
.6475 0 L
s
1 0 0 r
.66 0 m
.66 0 L
.665 0 L
.665 0 L
F
0 g
.66 0 m
.66 0 L
.665 0 L
.665 0 L
.66 0 L
s
1 0 0 r
.6725 0 m
.6725 0 L
.6775 0 L
.6775 0 L
F
0 g
.6725 0 m
.6725 0 L
.6775 0 L
.6775 0 L
.6725 0 L
s
1 0 0 r
.685 0 m
.685 0 L
.69 0 L
.69 0 L
F
0 g
.685 0 m
.685 0 L
.69 0 L
.69 0 L
.685 0 L
s
1 0 0 r
.6975 0 m
.6975 0 L
.7025 0 L
.7025 0 L
F
0 g
.6975 0 m
.6975 0 L
.7025 0 L
.7025 0 L
.6975 0 L
s
1 0 0 r
.71 0 m
.71 0 L
.715 0 L
.715 0 L
F
0 g
.71 0 m
.71 0 L
.715 0 L
.715 0 L
.71 0 L
s
1 0 0 r
.7225 0 m
.7225 0 L
.7275 0 L
.7275 0 L
F
0 g
.7225 0 m
.7225 0 L
.7275 0 L
.7275 0 L
.7225 0 L
s
1 0 0 r
.735 0 m
.735 0 L
.74 0 L
.74 0 L
F
0 g
.735 0 m
.735 0 L
.74 0 L
.74 0 L
.735 0 L
s
1 0 0 r
.7475 0 m
.7475 0 L
.7525 0 L
.7525 0 L
F
0 g
.7475 0 m
.7475 0 L
.7525 0 L
.7525 0 L
.7475 0 L
s
1 0 0 r
.76 0 m
.76 0 L
.765 0 L
.765 0 L
F
0 g
.76 0 m
.76 0 L
.765 0 L
.765 0 L
.76 0 L
s
1 0 0 r
.7725 0 m
.7725 0 L
.7775 0 L
.7775 0 L
F
0 g
.7725 0 m
.7725 0 L
.7775 0 L
.7775 0 L
.7725 0 L
s
1 0 0 r
.785 0 m
.785 0 L
.79 0 L
.79 0 L
F
0 g
.785 0 m
.785 0 L
.79 0 L
.79 0 L
.785 0 L
s
1 0 0 r
.7975 0 m
.7975 0 L
.8025 0 L
.8025 0 L
F
0 g
.7975 0 m
.7975 0 L
.8025 0 L
.8025 0 L
.7975 0 L
s
1 0 0 r
.81 0 m
.81 0 L
.815 0 L
.815 0 L
F
0 g
.81 0 m
.81 0 L
.815 0 L
.815 0 L
.81 0 L
s
1 0 0 r
.8225 0 m
.8225 0 L
.8275 0 L
.8275 0 L
F
0 g
.8225 0 m
.8225 0 L
.8275 0 L
.8275 0 L
.8225 0 L
s
1 0 0 r
.835 0 m
.835 0 L
.84 0 L
.84 0 L
F
0 g
.835 0 m
.835 0 L
.84 0 L
.84 0 L
.835 0 L
s
1 0 0 r
.8475 0 m
.8475 0 L
.8525 0 L
.8525 0 L
F
0 g
.8475 0 m
.8475 0 L
.8525 0 L
.8525 0 L
.8475 0 L
s
1 0 0 r
.86 0 m
.86 0 L
.865 0 L
.865 0 L
F
0 g
.86 0 m
.86 0 L
.865 0 L
.865 0 L
.86 0 L
s
1 0 0 r
.8725 0 m
.8725 0 L
.8775 0 L
.8775 0 L
F
0 g
.8725 0 m
.8725 0 L
.8775 0 L
.8775 0 L
.8725 0 L
s
1 0 0 r
.885 0 m
.885 0 L
.89 0 L
.89 0 L
F
0 g
.885 0 m
.885 0 L
.89 0 L
.89 0 L
.885 0 L
s
1 0 0 r
.8975 0 m
.8975 0 L
.9025 0 L
.9025 0 L
F
0 g
.8975 0 m
.8975 0 L
.9025 0 L
.9025 0 L
.8975 0 L
s
1 0 0 r
.91 0 m
.91 0 L
.915 0 L
.915 0 L
F
0 g
.91 0 m
.91 0 L
.915 0 L
.915 0 L
.91 0 L
s
1 0 0 r
.9225 0 m
.9225 0 L
.9275 0 L
.9275 0 L
F
0 g
.9225 0 m
.9225 0 L
.9275 0 L
.9275 0 L
.9225 0 L
s
1 0 0 r
.935 0 m
.935 0 L
.94 0 L
.94 0 L
F
0 g
.935 0 m
.935 0 L
.94 0 L
.94 0 L
.935 0 L
s
1 0 0 r
.9475 0 m
.9475 0 L
.9525 0 L
.9525 0 L
F
0 g
.9475 0 m
.9475 0 L
.9525 0 L
.9525 0 L
.9475 0 L
s
1 0 0 r
.96 0 m
.96 0 L
.965 0 L
.965 0 L
F
0 g
.96 0 m
.96 0 L
.965 0 L
.965 0 L
.96 0 L
s
1 0 0 r
.9725 0 m
.9725 0 L
.9775 0 L
.9775 0 L
F
0 g
.9725 0 m
.9725 0 L
.9775 0 L
.9775 0 L
.9725 0 L
s
1 0 0 r
.985 0 m
.985 0 L
.99 0 L
.99 0 L
F
0 g
.985 0 m
.985 0 L
.99 0 L
.99 0 L
.985 0 L
s
1 0 0 r
.9975 0 m
.9975 0 L
1.0025 0 L
1.0025 0 L
F
0 g
.9975 0 m
.9975 0 L
s
.9975 0 m
0 0 rlineto s
0 .4 1 r
.015 0 m
.015 0 L
.02 0 L
.02 0 L
F
0 g
.015 0 m
.015 0 L
.02 0 L
.02 0 L
.015 0 L
s
0 .4 1 r
.0275 0 m
.0275 0 L
.0325 0 L
.0325 0 L
F
0 g
.0275 0 m
.0275 0 L
.0325 0 L
.0325 0 L
.0275 0 L
s
0 .4 1 r
.04 0 m
.04 0 L
.045 0 L
.045 0 L
F
0 g
.04 0 m
.04 0 L
.045 0 L
.045 0 L
.04 0 L
s
0 .4 1 r
.0525 0 m
.0525 0 L
.0575 0 L
.0575 0 L
F
0 g
.0525 0 m
.0525 0 L
.0575 0 L
.0575 0 L
.0525 0 L
s
0 .4 1 r
.065 0 m
.065 0 L
.07 0 L
.07 0 L
F
0 g
.065 0 m
.065 0 L
.07 0 L
.07 0 L
.065 0 L
s
0 .4 1 r
.0775 0 m
.0775 0 L
.0825 0 L
.0825 0 L
F
0 g
.0775 0 m
.0775 0 L
.0825 0 L
.0825 0 L
.0775 0 L
s
0 .4 1 r
.09 0 m
.09 0 L
.095 0 L
.095 0 L
F
0 g
.09 0 m
.09 0 L
.095 0 L
.095 0 L
.09 0 L
s
0 .4 1 r
.1025 0 m
.1025 0 L
.1075 0 L
.1075 0 L
F
0 g
.1025 0 m
.1025 0 L
.1075 0 L
.1075 0 L
.1025 0 L
s
0 .4 1 r
.115 0 m
.115 0 L
.12 0 L
.12 0 L
F
0 g
.115 0 m
.115 0 L
.12 0 L
.12 0 L
.115 0 L
s
0 .4 1 r
.1275 0 m
.1275 0 L
.1325 0 L
.1325 0 L
F
0 g
.1275 0 m
.1275 0 L
.1325 0 L
.1325 0 L
.1275 0 L
s
0 .4 1 r
.14 0 m
.14 0 L
.145 0 L
.145 0 L
F
0 g
.14 0 m
.14 0 L
.145 0 L
.145 0 L
.14 0 L
s
0 .4 1 r
.1525 0 m
.1525 0 L
.1575 0 L
.1575 0 L
F
0 g
.1525 0 m
.1525 0 L
.1575 0 L
.1575 0 L
.1525 0 L
s
0 .4 1 r
.165 0 m
.165 0 L
.17 0 L
.17 0 L
F
0 g
.165 0 m
.165 0 L
.17 0 L
.17 0 L
.165 0 L
s
0 .4 1 r
.1775 0 m
.1775 0 L
.1825 0 L
.1825 0 L
F
0 g
.1775 0 m
.1775 0 L
.1825 0 L
.1825 0 L
.1775 0 L
s
0 .4 1 r
.19 0 m
.19 0 L
.195 0 L
.195 0 L
F
0 g
.19 0 m
.19 0 L
.195 0 L
.195 0 L
.19 0 L
s
0 .4 1 r
.2025 0 m
.2025 0 L
.2075 0 L
.2075 0 L
F
0 g
.2025 0 m
.2025 0 L
.2075 0 L
.2075 0 L
.2025 0 L
s
0 .4 1 r
.215 0 m
.215 0 L
.22 0 L
.22 0 L
F
0 g
.215 0 m
.215 0 L
.22 0 L
.22 0 L
.215 0 L
s
0 .4 1 r
.2275 0 m
.2275 0 L
.2325 0 L
.2325 0 L
F
0 g
.2275 0 m
.2275 0 L
.2325 0 L
.2325 0 L
.2275 0 L
s
0 .4 1 r
.24 0 m
.24 0 L
.245 0 L
.245 0 L
F
0 g
.24 0 m
.24 0 L
.245 0 L
.245 0 L
.24 0 L
s
0 .4 1 r
.2525 0 m
.2525 0 L
.2575 0 L
.2575 0 L
F
0 g
.2525 0 m
.2525 0 L
.2575 0 L
.2575 0 L
.2525 0 L
s
0 .4 1 r
.265 0 m
.265 0 L
.27 0 L
.27 0 L
F
0 g
.265 0 m
.265 0 L
.27 0 L
.27 0 L
.265 0 L
s
0 .4 1 r
.2775 0 m
.2775 0 L
.2825 0 L
.2825 0 L
F
0 g
.2775 0 m
.2775 0 L
.2825 0 L
.2825 0 L
.2775 0 L
s
0 .4 1 r
.29 0 m
.29 0 L
.295 0 L
.295 0 L
F
0 g
.29 0 m
.29 0 L
.295 0 L
.295 0 L
.29 0 L
s
0 .4 1 r
.3025 0 m
.3025 0 L
.3075 0 L
.3075 0 L
F
0 g
.3025 0 m
.3025 0 L
.3075 0 L
.3075 0 L
.3025 0 L
s
0 .4 1 r
.315 0 m
.315 0 L
.32 0 L
.32 0 L
F
0 g
.315 0 m
.315 0 L
.32 0 L
.32 0 L
.315 0 L
s
0 .4 1 r
.3275 0 m
.3275 0 L
.3325 0 L
.3325 0 L
F
0 g
.3275 0 m
.3275 0 L
.3325 0 L
.3325 0 L
.3275 0 L
s
0 .4 1 r
.34 0 m
.34 0 L
.345 0 L
.345 0 L
F
0 g
.34 0 m
.34 0 L
.345 0 L
.345 0 L
.34 0 L
s
0 .4 1 r
.3525 0 m
.3525 0 L
.3575 0 L
.3575 0 L
F
0 g
.3525 0 m
.3525 0 L
.3575 0 L
.3575 0 L
.3525 0 L
s
0 .4 1 r
.365 0 m
.365 0 L
.37 0 L
.37 0 L
F
0 g
.365 0 m
.365 0 L
.37 0 L
.37 0 L
.365 0 L
s
0 .4 1 r
.3775 0 m
.3775 0 L
.3825 0 L
.3825 0 L
F
0 g
.3775 0 m
.3775 0 L
.3825 0 L
.3825 0 L
.3775 0 L
s
0 .4 1 r
.39 0 m
.39 0 L
.395 0 L
.395 0 L
F
0 g
.39 0 m
.39 0 L
.395 0 L
.395 0 L
.39 0 L
s
0 .4 1 r
.4025 0 m
.4025 0 L
.4075 0 L
.4075 0 L
F
0 g
.4025 0 m
.4025 0 L
.4075 0 L
.4075 0 L
.4025 0 L
s
0 .4 1 r
.415 0 m
.415 0 L
.42 0 L
.42 0 L
F
0 g
.415 0 m
.415 0 L
.42 0 L
.42 0 L
.415 0 L
s
0 .4 1 r
.4275 0 m
.4275 0 L
.4325 0 L
.4325 0 L
F
0 g
.4275 0 m
.4275 0 L
.4325 0 L
.4325 0 L
.4275 0 L
s
0 .4 1 r
.44 0 m
.44 0 L
.445 0 L
.445 0 L
F
0 g
.44 0 m
.44 0 L
.445 0 L
.445 0 L
.44 0 L
s
0 .4 1 r
.4525 0 m
.4525 0 L
.4575 0 L
.4575 0 L
F
0 g
.4525 0 m
.4525 0 L
.4575 0 L
.4575 0 L
.4525 0 L
s
0 .4 1 r
.465 0 m
.465 0 L
.47 0 L
.47 0 L
F
0 g
.465 0 m
.465 0 L
.47 0 L
.47 0 L
.465 0 L
s
0 .4 1 r
.4775 0 m
.4775 0 L
.4825 0 L
.4825 0 L
F
0 g
.4775 0 m
.4775 0 L
.4825 0 L
.4825 0 L
.4775 0 L
s
0 .4 1 r
.49 0 m
.49 0 L
.495 0 L
.495 0 L
F
0 g
.49 0 m
.49 0 L
.495 0 L
.495 0 L
.49 0 L
s
0 .4 1 r
.5025 0 m
.5025 0 L
.5075 0 L
.5075 0 L
F
0 g
.5025 0 m
.5025 0 L
.5075 0 L
.5075 0 L
.5025 0 L
s
0 .4 1 r
.515 0 m
.515 0 L
.52 0 L
.52 0 L
F
0 g
.515 0 m
.515 0 L
.52 0 L
.52 0 L
.515 0 L
s
0 .4 1 r
.5275 0 m
.5275 0 L
.5325 0 L
.5325 0 L
F
0 g
.5275 0 m
.5275 0 L
.5325 0 L
.5325 0 L
.5275 0 L
s
0 .4 1 r
.54 0 m
.54 0 L
.545 0 L
.545 0 L
F
0 g
.54 0 m
.54 0 L
.545 0 L
.545 0 L
.54 0 L
s
0 .4 1 r
.5525 0 m
.5525 .00618 L
.5575 .00618 L
.5575 0 L
F
0 g
.5525 0 m
.5525 .00618 L
.5575 .00618 L
.5575 0 L
.5525 0 L
s
0 .4 1 r
.565 0 m
.565 0 L
.57 0 L
.57 0 L
F
0 g
.565 0 m
.565 0 L
.57 0 L
.57 0 L
.565 0 L
s
0 .4 1 r
.5775 0 m
.5775 .00618 L
.5825 .00618 L
.5825 0 L
F
0 g
.5775 0 m
.5775 .00618 L
.5825 .00618 L
.5825 0 L
.5775 0 L
s
0 .4 1 r
.59 0 m
.59 0 L
.595 0 L
.595 0 L
F
0 g
.59 0 m
.59 0 L
.595 0 L
.595 0 L
.59 0 L
s
0 .4 1 r
.6025 0 m
.6025 .01854 L
.6075 .01854 L
.6075 0 L
F
0 g
.6025 0 m
.6025 .01854 L
.6075 .01854 L
.6075 0 L
.6025 0 L
s
0 .4 1 r
.615 0 m
.615 .00618 L
.62 .00618 L
.62 0 L
F
0 g
.615 0 m
.615 .00618 L
.62 .00618 L
.62 0 L
.615 0 L
s
0 .4 1 r
.6275 0 m
.6275 .03708 L
.6325 .03708 L
.6325 0 L
F
0 g
.6275 0 m
.6275 .03708 L
.6325 .03708 L
.6325 0 L
.6275 0 L
s
0 .4 1 r
.64 0 m
.64 .04326 L
.645 .04326 L
.645 0 L
F
0 g
.64 0 m
.64 .04326 L
.645 .04326 L
.645 0 L
.64 0 L
s
0 .4 1 r
.6525 0 m
.6525 .0309 L
.6575 .0309 L
.6575 0 L
F
0 g
.6525 0 m
.6525 .0309 L
.6575 .0309 L
.6575 0 L
.6525 0 L
s
0 .4 1 r
.665 0 m
.665 .04326 L
.67 .04326 L
.67 0 L
F
0 g
.665 0 m
.665 .04326 L
.67 .04326 L
.67 0 L
.665 0 L
s
0 .4 1 r
.6775 0 m
.6775 .09271 L
.6825 .09271 L
.6825 0 L
F
0 g
.6775 0 m
.6775 .09271 L
.6825 .09271 L
.6825 0 L
.6775 0 L
s
0 .4 1 r
.69 0 m
.69 .16687 L
.695 .16687 L
.695 0 L
F
0 g
.69 0 m
.69 .16687 L
.695 .16687 L
.695 0 L
.69 0 L
s
0 .4 1 r
.7025 0 m
.7025 .16069 L
.7075 .16069 L
.7075 0 L
F
0 g
.7025 0 m
.7025 .16069 L
.7075 .16069 L
.7075 0 L
.7025 0 L
s
0 .4 1 r
.715 0 m
.715 .14833 L
.72 .14833 L
.72 0 L
F
0 g
.715 0 m
.715 .14833 L
.72 .14833 L
.72 0 L
.715 0 L
s
0 .4 1 r
.7275 0 m
.7275 .30284 L
.7325 .30284 L
.7325 0 L
F
0 g
.7275 0 m
.7275 .30284 L
.7325 .30284 L
.7325 0 L
.7275 0 L
s
0 .4 1 r
.74 0 m
.74 .33992 L
.745 .33992 L
.745 0 L
F
0 g
.74 0 m
.74 .33992 L
.745 .33992 L
.745 0 L
.74 0 L
s
0 .4 1 r
.7525 0 m
.7525 .44498 L
.7575 .44498 L
.7575 0 L
F
0 g
.7525 0 m
.7525 .44498 L
.7575 .44498 L
.7575 0 L
.7525 0 L
s
0 .4 1 r
.765 0 m
.765 .40172 L
.77 .40172 L
.77 0 L
F
0 g
.765 0 m
.765 .40172 L
.77 .40172 L
.77 0 L
.765 0 L
s
0 .4 1 r
.7775 0 m
.7775 .58713 L
.7825 .58713 L
.7825 0 L
F
0 g
.7775 0 m
.7775 .58713 L
.7825 .58713 L
.7825 0 L
.7775 0 L
s
0 .4 1 r
.79 0 m
.79 .50061 L
.795 .50061 L
.795 0 L
F
0 g
.79 0 m
.79 .50061 L
.795 .50061 L
.795 0 L
.79 0 L
s
0 .4 1 r
.8025 0 m
.8025 .62421 L
.8075 .62421 L
.8075 0 L
F
0 g
.8025 0 m
0 0 rlineto s
.8025 0 m
.8025 .61803 L
s
.8075 .61803 m
.8075 0 L
.8025 0 L
s
0 .4 1 r
.815 0 m
.815 .52533 L
.82 .52533 L
.82 0 L
F
0 g
.815 0 m
.815 .52533 L
.82 .52533 L
.82 0 L
.815 0 L
s
0 .4 1 r
.8275 0 m
.8275 .54387 L
.8325 .54387 L
.8325 0 L
F
0 g
.8275 0 m
.8275 .54387 L
.8325 .54387 L
.8325 0 L
.8275 0 L
s
0 .4 1 r
.84 0 m
.84 .32138 L
.845 .32138 L
.845 0 L
F
0 g
.84 0 m
.84 .32138 L
.845 .32138 L
.845 0 L
.84 0 L
s
0 .4 1 r
.8525 0 m
.8525 .2843 L
.8575 .2843 L
.8575 0 L
F
0 g
.8525 0 m
.8525 .2843 L
.8575 .2843 L
.8575 0 L
.8525 0 L
s
0 .4 1 r
.865 0 m
.865 .24721 L
.87 .24721 L
.87 0 L
F
0 g
.865 0 m
.865 .24721 L
.87 .24721 L
.87 0 L
.865 0 L
s
0 .4 1 r
.8775 0 m
.8775 .16687 L
.8825 .16687 L
.8825 0 L
F
0 g
.8775 0 m
.8775 .16687 L
.8825 .16687 L
.8825 0 L
.8775 0 L
s
0 .4 1 r
.89 0 m
.89 .0618 L
.895 .0618 L
.895 0 L
F
0 g
.89 0 m
.89 .0618 L
.895 .0618 L
.895 0 L
.89 0 L
s
0 .4 1 r
.9025 0 m
.9025 .04944 L
.9075 .04944 L
.9075 0 L
F
0 g
.9025 0 m
.9025 .04944 L
.9075 .04944 L
.9075 0 L
.9025 0 L
s
0 .4 1 r
.915 0 m
.915 .01854 L
.92 .01854 L
.92 0 L
F
0 g
.915 0 m
.915 .01854 L
.92 .01854 L
.92 0 L
.915 0 L
s
0 .4 1 r
.9275 0 m
.9275 0 L
.9325 0 L
.9325 0 L
F
0 g
.9275 0 m
.9275 0 L
.9325 0 L
.9325 0 L
.9275 0 L
s
0 .4 1 r
.94 0 m
.94 0 L
.945 0 L
.945 0 L
F
0 g
.94 0 m
.94 0 L
.945 0 L
.945 0 L
.94 0 L
s
0 .4 1 r
.9525 0 m
.9525 0 L
.9575 0 L
.9575 0 L
F
0 g
.9525 0 m
.9525 0 L
.9575 0 L
.9575 0 L
.9525 0 L
s
0 .4 1 r
.965 0 m
.965 0 L
.97 0 L
.97 0 L
F
0 g
.965 0 m
.965 0 L
.97 0 L
.97 0 L
.965 0 L
s
0 .4 1 r
.9775 0 m
.9775 0 L
.9825 0 L
.9825 0 L
F
0 g
.9775 0 m
.9775 0 L
.9825 0 L
.9825 0 L
.9775 0 L
s
0 .4 1 r
.99 0 m
.99 0 L
.995 0 L
.995 0 L
F
0 g
.99 0 m
.99 0 L
.995 0 L
.995 0 L
.99 0 L
s
0 .4 1 r
1.0025 0 m
1.0025 0 L
1.0075 0 L
1.0075 0 L
F
0 g
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[235]:=",
  ImageSize->{546, 337.312},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40008R0001DA000`40O003h00Oogooogoo97oo003o
OoooOolTOol0021oo`<000=oo`@0009oo`<000Eoo`<0009oo`<000Eoo`8000Aoo`03001oogoo00=o
o`8000Aoo`H000Aoo`<000=oo`<000=oo`@0009oo`@000=oo`@0009oo`@000=oo`<000=oo`<000Ao
o`<000=oo`@000=oo`@0009oo`@0009oo`@0009oo`D0009oo`@0009oo`D0009oo`@0009oo`@000=o
o`@0009oo`<000Aoo`<000=oo`<000=oo`@0009oo`@000=oo`@0009oo`@000=oo`<000=oo`<000Ao
o`<000=oo`@000=oo`@0009oo`@0009oo`@0009oo`D000=oo`<0009oo`D000=oo`<000=oo`<000=o
o`@0009oo`<000Aoo`<000=oo`<000=oo`@0009oo`@000=oo`@0009oo`@000=oo`<000=oo`<000Ao
o`<000=oo`<000Aoo`<000=oo`<000=oo`@0009oo`@000Aoo`<0009oo`@000Aoo`8000Aoo`8000Ao
o`<000=oo`<000Aoo`8000Aoo`<000=oo`@0009oo`<000Eoo`<0009oo`<000Eoo`8000Aoo`03001o
ogoo00=oo`8000Aoo`<000Uoo`008Goo00<007ooOol00goo00<007ooOol01Goo00<007ooOol00goo
00<007ooOol017oo00D007ooOomoo`00009oo`05001oogooOol00004Ool01000Oomoo`001Woo0P00
17oo00@007oo000000Aoo`03001oogoo00=oo`03001oogoo00Aoo`8000Aoo`8000Eoo`8000=oo`80
0003Ool007oo009oo`03001oogoo009oo`04001oo`000004Ool00`00Ool00002Ool01000Ool00000
17oo00<007ooOol00goo00<007ooOol017oo0P0017oo0P001Goo0P000goo0P0000=oo`00Ool00Woo
00<007ooOol00Woo00@007oo000000Ioo`04001oogoo0002Ool20003Ool00`00Ool00003Ool00`00
Ool00005Ool20004Ool20005Ool20002Ool01000Oomoo`000goo00<007oo00000Woo00<007ooOol0
0P0017oo0P000Woo00@007ooOol000Aoo`8000Aoo`8000Ioo`03001oogoo00=oo`03001oogoo00Ao
o`06001oogooOol007oo0P000goo0P000goo00@007ooOol000Ioo`04001oogoo0002Ool20003Ool0
0`00Ool00003Ool00`00Ool00005Ool20004Ool20005Ool20002Ool01000Oomoo`000goo00<007oo
00000Woo00<007ooOol00P000Woo00@007ooOol0009oo`800003Ool00000009oo`800004Ool007oo
Ool200000goo001oo`02Ool01000Ool000000Woo00@007oo000000=oo`04001oo`000002Ool01000
Oomoo`000Woo0P0000Aoo`00Oomoo`800003Ool0000000=oo`03001oo`00009oo`04001oo`000004
Ool00`00Oomoo`03Ool00`00Oomoo`04Ool20004Ool20005Ool20003Ool200000goo001oo`02Ool0
0`00Oomoo`02Ool01000Ool000001Woo00<007ooOol01Woo000QOol00`00Oomoo`04Ool00`00Oomo
o`04Ool01000Oomoogoo10001Goo00D007ooOomoo`00009oo`03001oogoo009oo`05001oogooOol0
0002Ool00`00Oomoo`02Ool40004Ool01000Ool0000017oo00<007ooOol00goo0P001Goo0P000goo
100017oo0P000goo0P0000=oo`00Ool00Woo0P000goo00@007oo000000Aoo`<0009oo`04001oogoo
0004Ool20005Ool00`00Oomoo`04Ool01000Oomoogoo10001Goo00H007ooOomoo`00Ool20004Ool0
1@00Oomoogoo00000Woo00<007ooOol00Woo0`000Woo00<007ooOol00P000goo00<007oo000017oo
0P001Goo0P000Woo10001Goo0P000Woo00@007ooOol000Aoo`80009oo`03001oogoo0080009oo`@0
009oo`D0009oo`@0009oo`@000=oo`@0009oo`@000=oo`@0009oo`@0009oo`@0009oo`D000=oo`<0
009oo`03001oogoo008000=oo`03001oo`0000Aoo`8000Eoo`80009oo`@000Eoo`80009oo`04001o
ogoo0004Ool20002Ool00`00Oomoo`020002Ool40002Ool200000goo00000002Ool200001Woo001o
ogoo001oo`8000=oo`04001oo`000002Ool40003Ool01000Ool000000Woo00@007ooOol0009oo`04
001oo`000002Ool200000goo00000003Ool30002Ool01000Oomoo`0017oo0P001Goo00<007ooOol0
17oo00@007ooOomoo`@000Eoo`06001oogooOol007oo0P0017oo00D007ooOomoo`00009oo`03001o
ogoo009oo`<000Qoo`008Goo00<007ooOol01Goo00@007ooOomoo`8000Aoo`03001oo`0000=oo`<0
00Aoo`<000Eoo`03001oogoo009oo`8000Aoo`03001oogoo008000Aoo`04001oo`000004Ool00`00
Oomoo`03Ool00`00Ool00003Ool20004Ool30003Ool30004Ool30004Ool20004Ool20004Ool01000
Oomoo`000Woo00<007ooOol00P000goo00<007oo00001Goo00@007ooOomoo`800006Ool007ooOol0
07oo0P000Woo0`0000Aoo`00Oomoo`@000Aoo`8000=oo`800004Ool007ooOol40002Ool01000Ool0
000017oo0P0017oo0`000goo0`000goo0`000goo10000goo0`0017oo0P0017oo0`000goo00@007oo
0000009oo`800003Ool007oo009oo`<000=oo`04001oo`000003Ool30003Ool00`00Ool00003Ool4
0003Ool30003Ool00`00Ool00004Ool30003Ool40002Ool40003Ool30003Ool40003Ool30003Ool3
0003Ool40003Ool30003Ool30004Ool30003Ool40002Ool40003Ool30003Ool40003Ool30003Ool3
0003Ool40003Ool30003Ool30004Ool30003Ool01000Ool000000Woo00@007ooOol000Aoo`8000Eo
o`8000=oo`<000=oo`03001oo`0000=oo`@000=oo`<000Eoo`03001oogoo009oo`<000=oo`04001o
ogoo0008Ool0025oo`03001oogoo009oo`04001oogoo0005Ool01`00Oomoogoo001oo`0000=oo`03
001oogoo00Aoo`03001oogoo00Ioo`04001oogoo0002Ool01@00Oomoogoo00000Woo0P0017oo00@0
07oo000000Aoo`03001oogoo009oo`800003Ool007oo00=oo`8000=oo`<000=oo`03001oo`0000Ao
o`8000Eoo`03001oo`00009oo`04001oo`000003Ool01000Oomoo`000Woo0P0000=oo`0000000Woo
0P0000Eoo`00Oomoo`00009oo`06001oogooOol007oo0P000Woo00@007oo0000009oo`80009oo`04
001oogoo0002Ool01000Oomoo`000Woo00<007ooOol00P0000=oo`0000000Woo00@007ooOol0009o
o`03001oogoo008000=oo`03001oo`00009oo`04001oogoo0005Ool20002Ool01000Ool000000Woo
00D007ooOomoo`00009oo`04001oogoo0005Ool01000Oomoo`000Woo0P000Woo00@007oo0000009o
o`800003Ool007oo009oo`<000=oo`04001oo`000003Ool00`00Ool00003Ool00`00Ool00003Ool2
00000goo001oo`02Ool00`00Ool00003Ool01000Ool000000Woo0P0000=oo`00Ool00Woo00@007oo
Ool0009oo`800003Ool007oo009oo`8000Aoo`04001oogoo0003Ool00`00Ool00003Ool00`00Ool0
0003Ool20005Ool00`00Oomoo`03Ool01000Oomoo`000Woo0P0000=oo`00Ool00Woo00@007ooOol0
009oo`800003Ool007oo009oo`8000Aoo`04001oogoo0003Ool00`00Ool00003Ool00`00Ool00003
Ool20005Ool00`00Oomoo`03Ool01000Oomoo`000Woo0P0000=oo`00Ool00Woo00@007ooOol0009o
o`03001oogoo008000=oo`03001oo`00009oo`04001oogoo0005Ool20002Ool01000Ool000000Woo
00D007ooOomoo`00009oo`04001oogoo0005Ool01000Oomoo`000Woo0P000Woo00@007ooOol000Qo
o`0087oo0P001Goo0P000goo0`001Goo0P000goo100017oo0`000Woo10000goo0P001Goo10001Goo
0P0017oo0P0017oo0`000goo0`0017oo0`000goo10000goo10000Woo10000goo0P001Goo0P0017oo
0`000goo0`0017oo0P000goo100017oo0P000goo100017oo0`000Woo10000goo0`000goo0`0017oo
0`000goo0`000goo0`000goo10000goo0`000goo10000goo10000Woo10000goo0`0017oo0P0017oo
0`000goo0`0017oo0P000goo100017oo0P000goo100017oo0`000Woo10000goo0`000goo10000goo
10000Woo10000Woo10000Woo1@000Woo10000Woo1@000Woo10000Woo10000goo10000goo0`000goo
10000Woo10000goo0`000Woo1@000goo0`000Woo1@000goo0`000Woo10000goo10000Woo10000goo
10000Woo10000Woo10000Woo1@000Woo10000Woo1@000Woo10000Woo10000goo10000goo0P002Goo
003oOoooOolTOol00?mooomoobAoo`00ogooogoo97oo003oOoooOolTOol00?mooomoobAoo`00ogoo
ogoo97oo003oOoooOolTOol001moo`0:001oogoo001oo`00Ool007oo0002Ool20002Ool01000Ool0
00000Woo00<007ooOol00P0000Eoo`00Oomoo`0000=oo`07001oo`00Ool007oo00000Woo0P000Woo
00@007oo0000009oo`03001oogoo00800004Ool007ooOol20002Ool01`00Ool007oo001oo`00009o
o`06001oogooOol007oo0P000Woo00@007ooOol0009oo`04001oogoo0003Ool00`00Ool00003Ool0
1000Oomoo`000goo00<007oo00000goo00@007ooOol0009oo`04001oogoo0003Ool00`00Ool00003
Ool01000Oomoo`000goo00<007oo00000goo00@007ooOol0009oo`04001oogoo0003Ool00`00Ool0
0003Ool01000Oomoo`000goo00<007oo00000goo00@007ooOol0009oo`04001oogoo0003Ool00`00
Ool00003Ool01000Oomoo`000goo00<007oo00000goo00@007ooOol0009oo`04001oogoo0003Ool0
0`00Ool00003Ool01000Oomoo`000goo00<007oo00000goo00@007ooOol0009oo`04001oogoo0003
Ool00`00Ool00003Ool01000Oomoo`000goo00<007oo00002Goo00@007ooOol000Moo`03001oo`00
009oo`80009oo`04001oogoo0002Ool01`00Oomoogoo001oo`0000=oo`04001oogoo0003Ool00`00
Ool00003Ool01000Oomoo`000Woo00@007ooOol000=oo`03001oo`0000=oo`04001oogoo0003Ool0
0`00Ool00003Ool01000Oomoo`000Woo00@007ooOol000=oo`03001oo`0000=oo`04001oogoo0003
Ool00`00Ool00003Ool01000Oomoo`000Woo00@007ooOol000=oo`03001oo`0000=oo`04001oogoo
0003Ool00`00Ool00003Ool01000Oomoo`000Woo00@007ooOol000=oo`03001oo`0000=oo`04001o
ogoo0003Ool00`00Ool00003Ool01000Oomoo`000Woo00@007ooOol0009oo`800004Ool007ooOol2
0002Ool01`00Ool007oo001oo`00009oo`80009oo`04001oo`000002Ool00`00Oomoo`020008Ool0
01Yoool00?l000<000Moo`007Woo00D007ooOomoo`0000Eoo`03001oogoo00=oo`03001oogoo00Ao
o`03001oogoo00=oo`05001oogooOol00002O0000`00Oomoo`03Ool00`00Oomoo`03Ool00`00Oomo
o`04Ool00`00Oomoo`03Ool00`00Oomoo`04Ool00`00Oomoo`03Ool01`00Oomoogoo001l000000Io
o`07001oogooOol007`000000goo00@007`0O000009oo`04001l07`00003Ool00`00O0000003Ool0
1000O01l00000goo00<007`000000goo00@007`0O000009oo`04001l07`00003Ool00`00O0000003
Ool01000O01l00000goo00<007`000000goo00@007`0O000009oo`04001l07`00003Ool00`00O000
0003Ool01000O01l00000goo00<007`000000goo00@007`0O000009oo`04001l07`00003Ool00`00
O0000003Ool01000O01l00000goo00<007`000000goo00@007`0O000009oo`04001l07`00003Ool0
0`00O0000003Ool01000O01l00000goo00<007`000000goo00@007`0O000009oo`04001l07`00003
Ool00`00O0000003Ool02P00O01l00000Il007oo001l00000goo00H007`0O000006O0003Ool00`00
Oomoo`03Ool010000Il1W`000goo00<0006O00000goo00@0006O0Il000=oo`030001W`0000=oo`03
0001W`0000=oo`040001W`6O0003Ool00`000Il00003Ool010000Il1W`000goo00<0006O00000goo
00<0006O00000goo00@0006O0Il000=oo`030001W`0000=oo`040001W`6O0003Ool00`000Il00003
Ool00`000Il00003Ool010000Il1W`000goo00<0006O00000goo00@0006O0Il000=oo`030001W`00
00=oo`030001W`0000=oo`040001W`6O0003Ool00`000Il00003Ool010000Il1W`000goo00<0006O
00000goo00<0006O00000goo00@0006O0Il000=oo`03001oogoo00=oo`03001oogoo00Aoo`03001o
ogoo00=oo`03001oogoo00=oo`03001oogoo00Aoo`03001oogoo00Yoo`007Woo00D007ooOomoo`00
00Eoo`03001oogoo00=oo`03001oogoo00Aoo`03001oogoo00=oo`05001oogooOol00002O0000`00
Oomoo`03Ool00`00Oomoo`03Ool00`00Oomoo`04Ool00`00Oomoo`03Ool00`00Oomoo`04Ool00`00
Oomoo`03Ool01`00Oomoogoo001l000000Ioo`07001oogooOol007`000000goo00@007`0O000009o
o`04001l07`00003Ool00`00O0000003Ool01000O01l00000goo00<007`000000goo00@007`0O000
009oo`04001l07`00003Ool00`00O0000003Ool01000O01l00000goo00<007`000000goo00@007`0
O000009oo`04001l07`00003Ool00`00O0000003Ool01000O01l00000goo00<007`000000goo00@0
07`0O000009oo`04001l07`00003Ool00`00O0000003Ool01000O01l00000goo00<007`000000goo
00@007`0O000009oo`04001l07`00003Ool00`00O0000003Ool01000O01l00000goo00<007`00000
0goo00@007`0O000009oo`04001l07`00003Ool00`00O0000003Ool02P00O01l00000Il007oo001l
00000goo00H007`0O000006O0003Ool00`00Oomoo`03Ool010000Il1W`000goo00<0006O00000goo
00@0006O0Il000=oo`030001W`0000=oo`030001W`0000=oo`040001W`6O0003Ool00`000Il00003
Ool010000Il1W`000goo00<0006O00000goo00<0006O00000goo00@0006O0Il000=oo`030001W`00
00=oo`040001W`6O0003Ool00`000Il00003Ool00`000Il00003Ool010000Il1W`000goo00<0006O
00000goo00@0006O0Il000=oo`030001W`0000=oo`030001W`0000=oo`040001W`6O0003Ool00`00
0Il00003Ool010000Il1W`000goo00<0006O00000goo00<0006O00000goo00@0006O0Il000=oo`03
001oogoo00=oo`03001oogoo00Aoo`03001oogoo00=oo`03001oogoo00=oo`03001oogoo00Aoo`03
001oogoo00Yoo`007Woo00D007ooOomoo`0000Eoo`03001oogoo00=oo`03001oogoo00Aoo`03001o
ogoo00=oo`04001oogooOol40005Ool00`00Oomoo`03Ool00`00Oomoo`04Ool00`00Oomoo`03Ool0
0`00Oomoo`04Ool00`00Oomoo`03Ool01000Oomoogoo0`001Woo00@007ooOomoo`<000=oo`04001l
07`00002Ool01000O01l00000goo00<007`000000goo00@007`0O00000=oo`03001l000000=oo`04
001l07`00002Ool01000O01l00000goo00<007`000000goo00@007`0O00000=oo`03001l000000=o
o`04001l07`00002Ool01000O01l00000goo00<007`000000goo00@007`0O00000=oo`03001l0000
00=oo`04001l07`00002Ool01000O01l00000goo00<007`000000goo00@007`0O00000=oo`03001l
000000=oo`04001l07`00002Ool01000O01l00000goo00<007`000000goo00@007`0O00000=oo`03
001l000000=oo`04001l07`00002Ool01000O01l00000goo00<007`000000goo00<007`0O0000`00
00Aoo`00O00000=oo`H000=oo`03001oogoo00=oo`040001W`6O0003Ool30003Ool010000Il1W`00
0goo00<0006O00000goo00<0006O00000goo00@0006O0Il000=oo`030001W`0000=oo`040001W`6O
0003Ool00`000Il00003Ool00`000Il00003Ool010000Il1W`000goo00<0006O00000goo00@0006O
0Il000=oo`030001W`0000=oo`030001W`0000=oo`040001W`6O0003Ool00`000Il00003Ool01000
0Il1W`000goo00<0006O00000goo00<0006O00000goo00@0006O0Il000=oo`030001W`0000=oo`04
0001W`6O0003Ool00`000Il00003Ool00`000Il00003Ool010000Il1W`000goo00<007ooOol00goo
00<007ooOol017oo00<007ooOol00goo00<007ooOol00goo00<007ooOol017oo00<007ooOol02Woo
000NOol00`00Oomoo`1NOol01000O01l00000Woo00@007`0O00000=oo`03001l000000=oo`04001l
07`00003Ool00`00O0000003Ool01000O01l00000Woo00@007`0O00000=oo`03001l000000=oo`04
001l07`00003Ool00`00O0000003Ool01000O01l00000Woo00@007`0O00000=oo`03001l000000=o
o`04001l07`00003Ool00`00O0000003Ool01000O01l00000Woo00@007`0O00000=oo`03001l0000
00=oo`04001l07`00003Ool00`00O0000003Ool01000O01l00000Woo00@007`0O00000=oo`03001l
000000=oo`04001l07`00003Ool00`00O0000003Ool01000O01l00000Woo00@007`0O00000=oo`03
001l000000=oo`04001l07`00003Ool00`00O000000BOol010000Il1W`002Goo00@0006O0Il000=o
o`030001W`0000=oo`030001W`0000=oo`040001W`6O0003Ool00`000Il00003Ool010000Il1W`00
0goo00<0006O00000goo00<0006O00000goo00@0006O0Il000=oo`030001W`0000=oo`040001W`6O
0003Ool00`000Il00003Ool00`000Il00003Ool010000Il1W`000goo00<0006O00000goo00@0006O
0Il000=oo`030001W`0000=oo`030001W`0000=oo`040001W`6O0003Ool00`000Il00003Ool01000
0Il1W`000goo00<0006O00000goo00<0006O00000goo00@0006O0Il0031oo`007Woo00<007ooOol0
GWoo00@007`0O000009oo`04001l07`00003Ool00`00O0000003Ool01000O01l00000goo00<007`0
00000goo00@007`0O000009oo`04001l07`00003Ool00`00O0000003Ool01000O01l00000goo00<0
07`000000goo00@007`0O000009oo`04001l07`00003Ool00`00O0000003Ool01000O01l00000goo
00<007`000000goo00@007`0O000009oo`04001l07`00003Ool00`00O0000003Ool01000O01l0000
0goo00<007`000000goo00@007`0O000009oo`04001l07`00003Ool00`00O0000003Ool01000O01l
00000goo00<007`000000goo00@007`0O000009oo`04001l07`00003Ool00`00O0000003Ool01000
O01l00000goo00<007`000004Woo00@0006O0Il000Uoo`040001W`6O0003Ool00`000Il00003Ool0
0`000Il00003Ool010000Il1W`000goo00<0006O00000goo00@0006O0Il000=oo`030001W`0000=o
o`030001W`0000=oo`040001W`6O0003Ool00`000Il00003Ool010000Il1W`000goo00<0006O0000
0goo00<0006O00000goo00@0006O0Il000=oo`030001W`0000=oo`040001W`6O0003Ool00`000Il0
0003Ool00`000Il00003Ool010000Il1W`000goo00<0006O00000goo00@0006O0Il000=oo`030001
W`0000=oo`030001W`0000=oo`040001W`6O000`Ool001ioo`03001oogoo05ioo`04001l07`00002
Ool01000O01l00000goo00<007`000000goo00@007`0O00000=oo`03001l000000=oo`04001l07`0
0002Ool01000O01l00000goo00<007`000000goo00@007`0O00000=oo`03001l000000=oo`04001l
07`00002Ool01000O01l00000goo00<007`000000goo00@007`0O00000=oo`03001l000000=oo`04
001l07`00002Ool01000O01l00000goo00<007`000000goo00@007`0O00000=oo`03001l000000=o
o`04001l07`00002Ool01000O01l00000goo00<007`000000goo00@007`0O00000=oo`03001l0000
00=oo`04001l07`00002Ool01000O01l00000goo00<007`000000goo00@007`0O00000=oo`03001l
0000019oo`040001W`6O0009Ool010000Il1W`000goo00<0006O00000goo00<0006O00000goo00@0
006O0Il000=oo`030001W`0000=oo`040001W`6O0003Ool00`000Il00003Ool00`000Il00003Ool0
10000Il1W`000goo00<0006O00000goo00@0006O0Il000=oo`030001W`0000=oo`030001W`0000=o
o`040001W`6O0003Ool00`000Il00003Ool010000Il1W`000goo00<0006O00000goo00<0006O0000
0goo00@0006O0Il000=oo`030001W`0000=oo`040001W`6O0003Ool00`000Il00003Ool00`000Il0
0003Ool010000Il1W`00<7oo000NOol00`00Oomoo`1NOol01000O01l00000Woo00@007`0O00000=o
o`03001l000000=oo`04001l07`00003Ool00`00O0000003Ool01000O01l00000Woo00@007`0O000
00=oo`03001l000000=oo`04001l07`00003Ool00`00O0000003Ool01000O01l00000Woo00@007`0
O00000=oo`03001l000000=oo`04001l07`00003Ool00`00O0000003Ool01000O01l00000Woo00@0
07`0O00000=oo`03001l000000=oo`04001l07`00003Ool00`00O0000003Ool01000O01l00000Woo
00@007`0O00000=oo`03001l000000=oo`04001l07`00003Ool00`00O0000003Ool01000O01l0000
0Woo00@007`0O00000=oo`03001l000000=oo`04001l07`00003Ool00`00O000000BOol010000Il1
W`002Goo00@0006O0Il000=oo`030001W`0000=oo`030001W`0000=oo`040001W`6O0003Ool00`00
0Il00003Ool010000Il1W`000goo00<0006O00000goo00<0006O00000goo00@0006O0Il000=oo`03
0001W`0000=oo`040001W`6O0003Ool00`000Il00003Ool00`000Il00003Ool010000Il1W`000goo
00<0006O00000goo00@0006O0Il000=oo`030001W`0000=oo`030001W`0000=oo`040001W`6O0003
Ool00`000Il00003Ool010000Il1W`000goo00<0006O00000goo00<0006O00000goo00@0006O0Il0
031oo`007Woo00<007ooOol0GWoo00@007`0O000009oo`04001l07`00003Ool00`00O0000003Ool0
1000O01l00000goo00<007`000000goo00@007`0O000009oo`04001l07`00003Ool00`00O0000003
Ool01000O01l00000goo00<007`000000goo00@007`0O000009oo`04001l07`00003Ool00`00O000
0003Ool01000O01l00000goo00<007`000000goo00@007`0O000009oo`04001l07`00003Ool00`00
O0000003Ool01000O01l00000goo00<007`000000goo00@007`0O000009oo`04001l07`00003Ool0
0`00O0000003Ool01000O01l00000goo00<007`000000goo00@007`0O000009oo`04001l07`00003
Ool00`00O0000003Ool01000O01l00000goo00<007`000004Woo00@0006O0Il000Uoo`040001W`6O
0003Ool00`000Il00003Ool00`000Il00003Ool010000Il1W`000goo00<0006O00000goo00@0006O
0Il000=oo`030001W`0000=oo`030001W`0000=oo`040001W`6O0003Ool00`000Il00003Ool01000
0Il1W`000goo00<0006O00000goo00<0006O00000goo00@0006O0Il000=oo`030001W`0000=oo`04
0001W`6O0003Ool00`000Il00003Ool00`000Il00003Ool010000Il1W`000goo00<0006O00000goo
00@0006O0Il000=oo`030001W`0000=oo`030001W`0000=oo`040001W`6O000`Ool001ioo`03001o
ogoo05ioo`@0009oo`@000=oo`03001l000000=oo`04001l07`00003Ool00`00O0000003Ool01000
O01l00000Woo00@007`0O00000=oo`03001l000000=oo`04001l07`00003Ool00`00O0000003Ool0
1000O01l00000Woo00@007`0O00000=oo`03001l000000=oo`04001l07`00003Ool00`00O0000003
Ool01000O01l00000Woo00@007`0O00000=oo`03001l000000=oo`04001l07`00003Ool00`00O000
0003Ool01000O01l00000Woo00@007`0O00000=oo`03001l000000=oo`04001l07`00003Ool00`00
O0000003Ool01000O01l00000Woo00@007`0O00000=oo`03001l000000=oo`04001l07`00003Ool3
000BOol40009Ool010000Il1W`000goo00<0006O00000goo00<0006O00000goo00@0006O0Il000=o
o`030001W`0000=oo`040001W`6O0003Ool00`000Il00003Ool00`000Il00003Ool010000Il1W`00
0goo00<0006O00000goo00@0006O0Il000=oo`030001W`0000=oo`030001W`0000=oo`040001W`6O
0003Ool00`000Il00003Ool010000Il1W`000goo00<0006O00000goo00<0006O00000goo00@0006O
0Il000=oo`030001W`0000=oo`040001W`6O0003Ool00`000Il00003Ool00`000Il00003Ool4000`
Ool001ioo`03001oogoo06]oo`03001l000000=oo`04001l07`00003Ool00`00O0000003Ool01000
O01l00000Woo00@007`0O00000=oo`03001l000000=oo`04001l07`00003Ool00`00O0000003Ool0
1000O01l00000Woo00@007`0O00000=oo`03001l000000=oo`04001l07`00003Ool00`00O0000003
Ool01000O01l00000Woo00@007`0O00000=oo`03001l000000=oo`04001l07`00003Ool00`00O000
0003Ool01000O01l00000Woo00@007`0O00000=oo`03001l000000=oo`04001l07`00003Ool00`00
O0000003Ool01000O01l00000Woo00@007`0O00000=oo`03001l000000=oo`04001l07`0000UOol0
10000Il1W`000goo00<0006O00000goo00<0006O00000goo00@0006O0Il000=oo`030001W`0000=o
o`040001W`6O0003Ool00`000Il00003Ool00`000Il00003Ool010000Il1W`000goo00<0006O0000
0goo00@0006O0Il000=oo`030001W`0000=oo`030001W`0000=oo`040001W`6O0003Ool00`000Il0
0003Ool010000Il1W`000goo00<0006O00000goo00<0006O00000goo00@0006O0Il000=oo`030001
W`0000=oo`040001W`6O0003Ool00`000Il00003Ool00`000Il0000gOol001ioo`03001oogoo06]o
o`03001l000000=oo`04001l07`00003Ool00`00O0000003Ool01000O01l00000Woo00@007`0O000
00=oo`03001l000000=oo`04001l07`00003Ool00`00O0000003Ool01000O01l00000Woo00@007`0
O00000=oo`03001l000000=oo`04001l07`00003Ool00`00O0000003Ool01000O01l00000Woo00@0
07`0O00000=oo`03001l000000=oo`04001l07`00003Ool00`00O0000003Ool01000O01l00000Woo
00@007`0O00000=oo`03001l000000=oo`04001l07`00003Ool00`00O0000003Ool01000O01l0000
0Woo00@007`0O00000=oo`03001l000000=oo`04001l07`0000UOol010000Il1W`000goo00<0006O
00000goo00<0006O00000goo00@0006O0Il000=oo`030001W`0000=oo`040001W`6O0003Ool00`00
0Il00003Ool00`000Il00003Ool010000Il1W`000goo00<0006O00000goo00@0006O0Il000=oo`03
0001W`0000=oo`030001W`0000=oo`040001W`6O0003Ool00`000Il00003Ool010000Il1W`000goo
00<0006O00000goo00<0006O00000goo00@0006O0Il000=oo`030001W`0000=oo`040001W`6O0003
Ool00`000Il00003Ool00`000Il0000gOol001ioo`03001oogoo06]oo`03001l000000=oo`04001l
07`00003Ool00`00O0000003Ool01000O01l00000Woo00@007`0O00000=oo`03001l000000=oo`04
001l07`00003Ool00`00O0000003Ool01000O01l00000Woo00@007`0O00000=oo`03001l000000=o
o`04001l07`00003Ool00`00O0000003Ool01000O01l00000Woo00@007`0O00000=oo`03001l0000
00=oo`04001l07`00003Ool00`00O0000003Ool01000O01l00000Woo00@007`0O00000=oo`03001l
000000=oo`04001l07`00003Ool00`00O0000003Ool01000O01l00000Woo00@007`0O00000=oo`03
001l000000=oo`04001l07`0000UOol010000Il1W`000goo00<0006O00000goo00<0006O00000goo
00@0006O0Il000=oo`030001W`0000=oo`040001W`6O0003Ool00`000Il00003Ool00`000Il00003
Ool010000Il1W`000goo00<0006O00000goo00@0006O0Il000=oo`030001W`0000=oo`030001W`00
00=oo`040001W`6O0003Ool00`000Il00003Ool010000Il1W`000goo00<0006O00000goo00<0006O
00000goo00@0006O0Il000=oo`030001W`0000=oo`040001W`6O0003Ool00`000Il00003Ool00`00
0Il0000gOol001ioo`03001oogoo06]oo`03001l000000=oo`04001l07`00003Ool00`00O0000003
Ool01000O01l00000Woo00@007`0O00000=oo`03001l000000=oo`04001l07`00003Ool00`00O000
0003Ool01000O01l00000Woo00@007`0O00000=oo`03001l000000=oo`04001l07`00003Ool00`00
O0000003Ool01000O01l00000Woo00@007`0O00000=oo`03001l000000=oo`04001l07`00003Ool0
0`00O0000003Ool01000O01l00000Woo00@007`0O00000=oo`03001l000000=oo`04001l07`00003
Ool00`00O0000003Ool01000O01l00000Woo00@007`0O00000=oo`03001l000000=oo`04001l07`0
000UOol010000Il1W`000goo00<0006O00000goo00<0006O00000goo00@0006O0Il000=oo`030001
W`0000=oo`040001W`6O0003Ool00`000Il00003Ool00`000Il00003Ool010000Il1W`000goo00<0
006O00000goo00@0006O0Il000=oo`030001W`0000=oo`030001W`0000=oo`040001W`6O0003Ool0
0`000Il00003Ool010000Il1W`000goo00<0006O00000goo00<0006O00000goo00@0006O0Il000=o
o`030001W`0000=oo`040001W`6O0003Ool00`000Il00003Ool00`000Il0000gOol001ioo`03001o
ogoo06]oo`03001l000000=oo`04001l07`00003Ool00`00O0000003Ool01000O01l00000Woo00@0
07`0O00000=oo`03001l000000=oo`04001l07`00003Ool00`00O0000003Ool01000O01l00000Woo
00@007`0O00000=oo`03001l000000=oo`04001l07`00003Ool00`00O0000003Ool01000O01l0000
0Woo00@007`0O00000=oo`03001l000000=oo`04001l07`00003Ool00`00O0000003Ool01000O01l
00000Woo00@007`0O00000=oo`03001l000000=oo`04001l07`00003Ool00`00O0000003Ool01000
O01l00000Woo00@007`0O00000=oo`03001l000000=oo`04001l07`0000UOol010000Il1W`000goo
00<0006O00000goo00<0006O00000goo00@0006O0Il000=oo`030001W`0000=oo`040001W`6O0003
Ool00`000Il00003Ool00`000Il00003Ool010000Il1W`000goo00<0006O00000goo00@0006O0Il0
00=oo`030001W`0000=oo`030001W`0000=oo`040001W`6O0003Ool00`000Il00003Ool010000Il1
W`000goo00<0006O00000goo00<0006O00000goo00@0006O0Il000=oo`030001W`0000=oo`040001
W`6O0003Ool00`000Il00003Ool00`000Il0000gOol001ioo`<006]oo`<000=oo`04001l07`00003
Ool00`00O0000003Ool01000O01l00000Woo00@007`0O00000=oo`03001l000000=oo`04001l07`0
0003Ool00`00O0000003Ool01000O01l00000Woo00@007`0O00000=oo`03001l000000=oo`04001l
07`00003Ool00`00O0000003Ool01000O01l00000Woo00@007`0O00000=oo`03001l000000=oo`04
001l07`00003Ool00`00O0000003Ool01000O01l00000Woo00@007`0O00000=oo`03001l000000=o
o`04001l07`00003Ool00`00O0000003Ool01000O01l00000Woo00@007`0O00000=oo`03001l0000
00=oo`@002Eoo`040001W`6O0003Ool00`000Il00003Ool30003Ool010000Il1W`000goo00<0006O
00000goo00@0006O0Il000=oo`030001W`0000=oo`030001W`0000=oo`040001W`6O0003Ool00`00
0Il00003Ool010000Il1W`000goo00<0006O00000goo00<0006O00000goo00@0006O0Il000=oo`03
0001W`0000=oo`040001W`6O0003Ool00`000Il00003Ool00`000Il00003Ool010000Il1W`000goo
00<0006O00000goo00@0006O0Il000=oo`030001W`0000=oo`030001W`0003Moo`007Woo00<007oo
Ool0LGoo00@007`0O00000=oo`03001l000000=oo`04001l07`00002Ool01000O01l00000goo00<0
07`000000goo00@007`0O00000=oo`03001l000000=oo`04001l07`00002Ool01000O01l00000goo
00<007`000000goo00@007`0O00000=oo`03001l000000=oo`04001l07`00002Ool01000O01l0000
0goo00<007`000000goo00@007`0O00000=oo`03001l000000=oo`04001l07`00002Ool01000O01l
00000goo00<007`000000goo00@007`0O00000=oo`03001l000000=oo`04001l07`00002Ool01000
O01l00000goo00<007`00000;7oo00@0006O0Il000=oo`030001W`0000Uoo`040001W`6O0003Ool0
0`000Il00003Ool010000Il1W`000goo00<0006O00000goo00<0006O00000goo00@0006O0Il000=o
o`030001W`0000=oo`040001W`6O0003Ool00`000Il00003Ool00`000Il00003Ool010000Il1W`00
0goo00<0006O00000goo00@0006O0Il000=oo`030001W`0000=oo`030001W`0000=oo`040001W`6O
0003Ool00`000Il00003Ool010000Il1W`000goo00<0006O00000goo00<0006O0000=goo000NOol0
0`00Oomoo`1aOol01000O01l00000goo00<007`000000goo00@007`0O000009oo`04001l07`00003
Ool00`00O0000003Ool01000O01l00000goo00<007`000000goo00@007`0O000009oo`04001l07`0
0003Ool00`00O0000003Ool01000O01l00000goo00<007`000000goo00@007`0O000009oo`04001l
07`00003Ool00`00O0000003Ool01000O01l00000goo00<007`000000goo00@007`0O000009oo`04
001l07`00003Ool00`00O0000003Ool01000O01l00000goo00<007`000000goo00@007`0O000009o
o`04001l07`00003Ool00`00O000000/Ool010000Il1W`000goo00<0006O00002Goo00@0006O0Il0
00=oo`030001W`0000=oo`040001W`6O0003Ool00`000Il00003Ool00`000Il00003Ool010000Il1
W`000goo00<0006O00000goo00@0006O0Il000=oo`030001W`0000=oo`030001W`0000=oo`040001
W`6O0003Ool00`000Il00003Ool010000Il1W`000goo00<0006O00000goo00<0006O00000goo00@0
006O0Il000=oo`030001W`0000=oo`040001W`6O0003Ool00`000Il00003Ool00`000Il0000gOol0
01ioo`03001oogoo075oo`04001l07`00003Ool00`00O0000003Ool01000O01l00000Woo00@007`0
O00000=oo`03001l000000=oo`04001l07`00003Ool00`00O0000003Ool01000O01l00000Woo00@0
07`0O00000=oo`03001l000000=oo`04001l07`00003Ool00`00O0000003Ool01000O01l00000Woo
00@007`0O00000=oo`03001l000000=oo`04001l07`00003Ool00`00O0000003Ool01000O01l0000
0Woo00@007`0O00000=oo`03001l000000=oo`04001l07`00003Ool00`00O0000003Ool01000O01l
00000Woo00@007`0O00000=oo`03001l000002aoo`040001W`6O0003Ool00`000Il00009Ool01000
0Il1W`000goo00<0006O00000goo00@0006O0Il000=oo`030001W`0000=oo`030001W`0000=oo`04
0001W`6O0003Ool00`000Il00003Ool010000Il1W`000goo00<0006O00000goo00<0006O00000goo
00@0006O0Il000=oo`030001W`0000=oo`040001W`6O0003Ool00`000Il00003Ool00`000Il00003
Ool010000Il1W`000goo00<0006O00000goo00@0006O0Il000=oo`030001W`0000=oo`030001W`00
03Moo`007Woo00<007ooOol0LGoo00@007`0O00000=oo`03001l000000=oo`04001l07`00002Ool0
1000O01l00000goo00<007`000000goo00@007`0O00000=oo`03001l000000=oo`04001l07`00002
Ool01000O01l00000goo00<007`000000goo00@007`0O00000=oo`03001l000000=oo`04001l07`0
0002Ool01000O01l00000goo00<007`000000goo00@007`0O00000=oo`03001l000000=oo`04001l
07`00002Ool01000O01l00000goo00<007`000000goo00@007`0O00000=oo`03001l000000=oo`04
001l07`00002Ool01000O01l00000goo00<007`00000;7oo10000goo00<0006O00002Goo00@0006O
0Il000=oo`030001W`0000=oo`040001W`6O0003Ool00`000Il00003Ool00`000Il00003Ool01000
0Il1W`000goo00<0006O00000goo00@0006O0Il000=oo`030001W`0000=oo`030001W`0000=oo`04
0001W`6O0003Ool00`000Il00003Ool010000Il1W`000goo00<0006O00000goo00<0006O00000goo
00@0006O0Il000=oo`030001W`0000=oo`040001W`6O0003Ool00`000Il00003Ool00`000Il0000g
Ool001ioo`03001oogoo075oo`04001l07`00003Ool00`00O0000003Ool01000O01l00000Woo00@0
07`0O00000=oo`03001l000000=oo`04001l07`00003Ool00`00O0000003Ool01000O01l00000Woo
00@007`0O00000=oo`03001l000000=oo`04001l07`00003Ool00`00O0000003Ool01000O01l0000
0Woo00@007`0O00000=oo`03001l000000=oo`04001l07`00003Ool00`00O0000003Ool01000O01l
00000Woo00@007`0O00000=oo`03001l000000=oo`04001l07`00003Ool00`00O0000003Ool01000
O01l00000Woo00@007`0O00000=oo`03001l000003=oo`030001W`0000Uoo`040001W`6O0003Ool0
0`000Il00003Ool010000Il1W`000goo00<0006O00000goo00<0006O00000goo00@0006O0Il000=o
o`030001W`0000=oo`040001W`6O0003Ool00`000Il00003Ool00`000Il00003Ool010000Il1W`00
0goo00<0006O00000goo00@0006O0Il000=oo`030001W`0000=oo`030001W`0000=oo`040001W`6O
0003Ool00`000Il00003Ool010000Il1W`000goo00<0006O00000goo00<0006O0000=goo000NOol0
0`00Oomoo`1aOol01000O01l00000goo00<007`000000goo00@007`0O000009oo`04001l07`00003
Ool00`00O0000003Ool01000O01l00000goo00<007`000000goo00@007`0O000009oo`04001l07`0
0003Ool00`00O0000003Ool01000O01l00000goo00<007`000000goo00@007`0O000009oo`04001l
07`00003Ool00`00O0000003Ool01000O01l00000goo00<007`000000goo00@007`0O000009oo`04
001l07`00003Ool00`00O0000003Ool01000O01l00000goo00<007`000000goo00@007`0O000009o
o`04001l07`00003Ool00`00O000000cOol00`000Il00009Ool010000Il1W`000goo00<0006O0000
0goo00@0006O0Il000=oo`030001W`0000=oo`030001W`0000=oo`040001W`6O0003Ool00`000Il0
0003Ool010000Il1W`000goo00<0006O00000goo00<0006O00000goo00@0006O0Il000=oo`030001
W`0000=oo`040001W`6O0003Ool00`000Il00003Ool00`000Il00003Ool010000Il1W`000goo00<0
006O00000goo00@0006O0Il000=oo`030001W`0000=oo`030001W`0003Moo`007Woo00<007ooOol0
LGoo00@007`0O00000=oo`<000=oo`@0009oo`04001l07`00003Ool00`00O0000003Ool01000O01l
00000goo00<007`000000goo00@007`0O000009oo`04001l07`00003Ool00`00O0000003Ool01000
O01l00000goo00<007`000000goo00@007`0O000009oo`04001l07`00003Ool00`00O0000003Ool0
1000O01l00000goo00<007`000000goo00@007`0O000009oo`04001l07`00003Ool00`00O0000003
Ool01000O01l00000goo00<007`000000goo00@007`0O000009oo`04001l07`00003Ool00`00O000
000cOol30009Ool40003Ool00`000Il00003Ool010000Il1W`000goo00<0006O00000goo00<0006O
00000goo00@0006O0Il000=oo`030001W`0000=oo`040001W`6O0003Ool00`000Il00003Ool00`00
0Il00003Ool010000Il1W`000goo00<0006O00000goo00@0006O0Il000=oo`030001W`0000=oo`03
0001W`0000=oo`040001W`6O0003Ool00`000Il00003Ool010000Il1W`000goo00<0006O00000goo
00<0006O0000=goo000NOol00`00Oomoo`1aOol01000O01l00003goo00@007`0O00000=oo`03001l
000000=oo`04001l07`00003Ool00`00O0000003Ool01000O01l00000Woo00@007`0O00000=oo`03
001l000000=oo`04001l07`00003Ool00`00O0000003Ool01000O01l00000Woo00@007`0O00000=o
o`03001l000000=oo`04001l07`00003Ool00`00O0000003Ool01000O01l00000Woo00@007`0O000
00=oo`03001l000000=oo`04001l07`00003Ool00`00O0000003Ool01000O01l00000Woo00@007`0
O00000=oo`03001l000004Ioo`030001W`0000=oo`040001W`6O0003Ool00`000Il00003Ool00`00
0Il00003Ool010000Il1W`000goo00<0006O00000goo00@0006O0Il000=oo`030001W`0000=oo`03
0001W`0000=oo`040001W`6O0003Ool00`000Il00003Ool010000Il1W`000goo00<0006O00000goo
00<0006O00000goo00@0006O0Il000=oo`030001W`0000=oo`040001W`6O0003Ool00`000Il00003
Ool00`000Il0000gOol001ioo`03001oogoo075oo`04001l07`0000?Ool01000O01l00000goo00<0
07`000000goo00@007`0O00000=oo`03001l000000=oo`04001l07`00002Ool01000O01l00000goo
00<007`000000goo00@007`0O00000=oo`03001l000000=oo`04001l07`00002Ool01000O01l0000
0goo00<007`000000goo00@007`0O00000=oo`03001l000000=oo`04001l07`00002Ool01000O01l
00000goo00<007`000000goo00@007`0O00000=oo`03001l000000=oo`04001l07`00002Ool01000
O01l00000goo00<007`00000AWoo00<0006O00000goo00@0006O0Il000=oo`030001W`0000=oo`03
0001W`0000=oo`040001W`6O0003Ool00`000Il00003Ool010000Il1W`000goo00<0006O00000goo
00<0006O00000goo00@0006O0Il000=oo`030001W`0000=oo`040001W`6O0003Ool00`000Il00003
Ool00`000Il00003Ool010000Il1W`000goo00<0006O00000goo00@0006O0Il000=oo`030001W`00
00=oo`030001W`0003Moo`007Woo00<007ooOol0LGoo00@007`0O00000moo`04001l07`00003Ool0
0`00O0000003Ool01000O01l00000goo00<007`000000goo00@007`0O000009oo`04001l07`00003
Ool00`00O0000003Ool01000O01l00000goo00<007`000000goo00@007`0O000009oo`04001l07`0
0003Ool00`00O0000003Ool01000O01l00000goo00<007`000000goo00@007`0O000009oo`04001l
07`00003Ool00`00O0000003Ool01000O01l00000goo00<007`000000goo00@007`0O000009oo`04
001l07`00003Ool00`00O0000016Ool00`000Il00003Ool010000Il1W`000goo00<0006O00000goo
00<0006O00000goo00@0006O0Il000=oo`030001W`0000=oo`040001W`6O0003Ool00`000Il00003
Ool00`000Il00003Ool010000Il1W`000goo00<0006O00000goo00@0006O0Il000=oo`030001W`00
00=oo`030001W`0000=oo`040001W`6O0003Ool00`000Il00003Ool010000Il1W`000goo00<0006O
00000goo0`00=goo000NOol00`00Oomoo`1aOol01000O01l00003goo00@007`0O00000=oo`03001l
000000=oo`04001l07`00003Ool00`00O0000003Ool01000O01l00000Woo00@007`0O00000=oo`03
001l000000=oo`04001l07`00003Ool00`00O0000003Ool01000O01l00000Woo00@007`0O00000=o
o`03001l000000=oo`04001l07`00003Ool00`00O0000003Ool01000O01l00000Woo00@007`0O000
00=oo`03001l000000=oo`04001l07`00003Ool00`00O0000003Ool01000O01l00000Woo00@007`0
O00000=oo`03001l000004Ioo`030001W`0000=oo`040001W`6O0003Ool00`000Il00003Ool00`00
0Il00003Ool010000Il1W`000goo00<0006O00000goo00@0006O0Il000=oo`030001W`0000=oo`03
0001W`0000=oo`040001W`6O0003Ool00`000Il00003Ool010000Il1W`000goo00<0006O00000goo
00<0006O00000goo00@0006O0Il000=oo`030001W`0000=oo`040001W`6O0003Ool00`000Il0000m
Ool001ioo`03001oogoo075oo`04001l07`0000?Ool01000O01l00000goo00<007`000000goo00@0
07`0O00000=oo`03001l000000=oo`04001l07`00002Ool01000O01l00000goo00<007`000000goo
00@007`0O00000=oo`03001l000000=oo`04001l07`00002Ool01000O01l00000goo00<007`00000
0goo00@007`0O00000=oo`03001l000000=oo`04001l07`00002Ool01000O01l00000goo00<007`0
00000goo00@007`0O00000=oo`03001l000000=oo`04001l07`00002Ool01000O01l00000goo00<0
07`00000AWoo00<0006O00000goo00@0006O0Il000=oo`030001W`0000=oo`030001W`0000=oo`04
0001W`6O0003Ool00`000Il00003Ool010000Il1W`000goo00<0006O00000goo00<0006O00000goo
00@0006O0Il000=oo`030001W`0000=oo`040001W`6O0003Ool00`000Il00003Ool00`000Il00003
Ool010000Il1W`000goo00<0006O00000goo00@0006O0Il000=oo`030001W`0003eoo`007Woo00<0
07ooOol0LGoo00@007`0O00000moo`04001l07`00003Ool00`00O0000003Ool01000O01l00000goo
00<007`000000goo00@007`0O000009oo`04001l07`00003Ool00`00O0000003Ool01000O01l0000
0goo00<007`000000goo00@007`0O000009oo`04001l07`00003Ool00`00O0000003Ool01000O01l
00000goo00<007`000000goo00@007`0O000009oo`04001l07`00003Ool00`00O0000003Ool01000
O01l00000goo00<007`000000goo00@007`0O000009oo`04001l07`00003Ool00`00O0000016Ool0
0`000Il00003Ool010000Il1W`000goo00<0006O00000goo00<0006O00000goo00@0006O0Il000=o
o`030001W`0000=oo`040001W`6O0003Ool00`000Il00003Ool00`000Il00003Ool010000Il1W`00
0goo00<0006O00000goo00@0006O0Il000=oo`030001W`0000=oo`030001W`0000=oo`040001W`6O
0003Ool00`000Il00003Ool010000Il1W`000goo00<0006O0000?Goo000NOol00`00Oomoo`1aOol0
1000O01l00003goo00@007`0O00000=oo`03001l000000=oo`04001l07`00003Ool00`00O0000003
Ool01000O01l00000Woo00@007`0O00000=oo`03001l000000=oo`04001l07`00003Ool00`00O000
0003Ool01000O01l00000Woo00@007`0O00000=oo`03001l000000=oo`04001l07`00003Ool00`00
O0000003Ool01000O01l00000Woo00@007`0O00000=oo`03001l000000=oo`04001l07`00003Ool0
0`00O0000003Ool01000O01l00000Woo00@007`0O00000=oo`03001l000004Ioo`030001W`0000=o
o`040001W`6O0003Ool00`000Il00003Ool00`000Il00003Ool010000Il1W`000goo00<0006O0000
0goo00@0006O0Il000=oo`030001W`0000=oo`030001W`0000=oo`040001W`6O0003Ool00`000Il0
0003Ool010000Il1W`000goo00<0006O00000goo00<0006O00000goo00@0006O0Il000=oo`030001
W`0000=oo`040001W`6O0003Ool00`000Il0000mOol001ioo`03001oogoo075oo`04001l07`0000?
Ool01000O01l00000goo00<007`000000goo00@007`0O00000=oo`03001l000000=oo`04001l07`0
0002Ool01000O01l00000goo00<007`000000goo00@007`0O00000=oo`03001l000000=oo`04001l
07`00002Ool01000O01l00000goo00<007`000000goo00@007`0O00000=oo`03001l000000=oo`04
001l07`00002Ool01000O01l00000goo00<007`000000goo00@007`0O00000=oo`03001l000000=o
o`04001l07`00002Ool01000O01l00000goo00<007`00000AWoo00<0006O00000goo00@0006O0Il0
00=oo`030001W`0000=oo`030001W`0000=oo`040001W`6O0003Ool00`000Il00003Ool010000Il1
W`000goo00<0006O00000goo00<0006O00000goo00@0006O0Il000=oo`030001W`0000=oo`040001
W`6O0003Ool00`000Il00003Ool00`000Il00003Ool010000Il1W`000goo00<0006O00000goo00@0
006O0Il000=oo`030001W`0003eoo`007Woo0`00LGoo10003goo10000goo00<007`000000goo00@0
07`0O00000=oo`03001l000000=oo`04001l07`00002Ool01000O01l00000goo00<007`000000goo
00@007`0O00000=oo`03001l000000=oo`04001l07`00002Ool01000O01l00000goo00<007`00000
0goo00@007`0O00000=oo`03001l000000=oo`04001l07`00002Ool01000O01l00000goo00<007`0
00000goo00@007`0O00000=oo`03001l000000=oo`04001l07`00002Ool01000O01l00000goo00<0
07`00000AWoo00<0006O00000goo00@0006O0Il000=oo`030001W`0000=oo`030001W`0000=oo`04
0001W`6O0003Ool00`000Il00003Ool010000Il1W`000goo00<0006O00000goo00<0006O00000goo
00@0006O0Il000=oo`030001W`0000=oo`040001W`6O0003Ool00`000Il00003Ool00`000Il00003
Ool010000Il1W`000goo00<0006O00000goo00@0006O0Il000=oo`<003eoo`007Woo00<007ooOol0
Rgoo00<007`000000goo00@007`0O00000=oo`03001l000000=oo`04001l07`00002Ool01000O01l
00000goo00<007`000000goo00@007`0O00000=oo`03001l000000=oo`04001l07`00002Ool01000
O01l00000goo00<007`000000goo00@007`0O00000=oo`03001l000000=oo`04001l07`00002Ool0
1000O01l00000goo00<007`000000goo00@007`0O00000=oo`03001l000000=oo`04001l07`00002
Ool01000O01l00000goo00<007`00000AWoo00<0006O00000goo00@0006O0Il000=oo`030001W`00
00=oo`030001W`0000=oo`040001W`6O0003Ool00`000Il00003Ool010000Il1W`000goo00<0006O
00000goo00<0006O00000goo00@0006O0Il000=oo`030001W`0000=oo`040001W`6O0003Ool00`00
0Il00003Ool00`000Il00003Ool010000Il1W`000goo00<0006O00000goo00@0006O0Il004=oo`00
7Woo00<007ooOol0Rgoo00<007`000000goo00@007`0O00000=oo`03001l000000=oo`04001l07`0
0002Ool01000O01l00000goo00<007`000000goo00@007`0O00000=oo`03001l000000=oo`04001l
07`00002Ool01000O01l00000goo00<007`000000goo00@007`0O00000=oo`03001l000000=oo`04
001l07`00002Ool01000O01l00000goo00<007`000000goo00@007`0O00000=oo`03001l000000=o
o`04001l07`00002Ool01000O01l00000goo00<007`00000AWoo00<0006O00000goo00@0006O0Il0
00=oo`030001W`0000=oo`030001W`0000=oo`040001W`6O0003Ool00`000Il00003Ool010000Il1
W`000goo00<0006O00000goo00<0006O00000goo00@0006O0Il000=oo`030001W`0000=oo`040001
W`6O0003Ool00`000Il00003Ool00`000Il00003Ool010000Il1W`000goo00<0006O00000goo00@0
006O0Il004=oo`007Woo00<007ooOol0Rgoo00<007`000000goo00@007`0O00000=oo`03001l0000
00=oo`04001l07`00002Ool01000O01l00000goo00<007`000000goo00@007`0O00000=oo`03001l
000000=oo`04001l07`00002Ool01000O01l00000goo00<007`000000goo00@007`0O00000=oo`03
001l000000=oo`04001l07`00002Ool01000O01l00000goo00<007`000000goo00@007`0O00000=o
o`03001l000000=oo`04001l07`00002Ool01000O01l00000goo0`00AWoo00<0006O00000goo00@0
006O0Il000=oo`030001W`0000=oo`030001W`0000=oo`040001W`6O0003Ool00`000Il00003Ool0
10000Il1W`000goo00<0006O00000goo00<0006O00000goo00@0006O0Il000=oo`030001W`0000=o
o`040001W`6O0003Ool00`000Il00003Ool00`000Il00003Ool010000Il1W`000goo00<0006O0000
0goo00@0006O0Il004=oo`007Woo00<007ooOol0Rgoo00<007`000000goo00@007`0O00000=oo`03
001l000000=oo`04001l07`00002Ool01000O01l00000goo00<007`000000goo00@007`0O00000=o
o`03001l000000=oo`04001l07`00002Ool01000O01l00000goo00<007`000000goo00@007`0O000
00=oo`03001l000000=oo`04001l07`00002Ool01000O01l00000goo00<007`000000goo00@007`0
O00000=oo`03001l000000=oo`04001l07`00002Ool01000O01l0000C7oo00<0006O00000goo00@0
006O0Il000=oo`030001W`0000=oo`030001W`0000=oo`040001W`6O0003Ool00`000Il00003Ool0
10000Il1W`000goo00<0006O00000goo00<0006O00000goo00@0006O0Il000=oo`030001W`0000=o
o`040001W`6O0003Ool00`000Il00003Ool00`000Il00003Ool010000Il1W`000goo00<0006O0000
0goo00@0006O0Il004=oo`007Woo00<007ooOol0Rgoo00<007`000000goo00@007`0O00000=oo`03
001l000000=oo`04001l07`00002Ool01000O01l00000goo00<007`000000goo00@007`0O00000=o
o`03001l000000=oo`04001l07`00002Ool01000O01l00000goo00<007`000000goo00@007`0O000
00=oo`03001l000000=oo`04001l07`00002Ool01000O01l00000goo00<007`000000goo00@007`0
O00000=oo`03001l000000=oo`04001l07`00002Ool01000O01l0000C7oo00<0006O00000goo00@0
006O0Il000=oo`030001W`0000=oo`030001W`0000=oo`040001W`6O0003Ool00`000Il00003Ool0
10000Il1W`000goo00<0006O00000goo00<0006O00000goo00@0006O0Il000=oo`030001W`0000=o
o`040001W`6O0003Ool00`000Il00003Ool00`000Il00003Ool010000Il1W`000goo00<0006O0000
0goo00@0006O0Il004=oo`007Woo00<007ooOol0Rgoo00<007`000000goo00@007`0O00000=oo`03
001l000000=oo`04001l07`00002Ool01000O01l00000goo00<007`000000goo00@007`0O00000=o
o`03001l000000=oo`04001l07`00002Ool01000O01l00000goo00<007`000000goo00@007`0O000
00=oo`03001l000000=oo`04001l07`00002Ool01000O01l00000goo00<007`000000goo00@007`0
O00000=oo`03001l000000=oo`04001l07`00002Ool01000O01l0000C7oo00<0006O00000goo00@0
006O0Il000=oo`030001W`0000=oo`030001W`0000=oo`040001W`6O0003Ool00`000Il00003Ool0
10000Il1W`000goo00<0006O00000goo00<0006O00000goo00@0006O0Il000=oo`030001W`0000=o
o`040001W`6O0003Ool00`000Il00003Ool00`000Il00003Ool010000Il1W`000goo00<0006O0000
0goo00@0006O0Il004=oo`007Woo00<007ooOol0Rgoo00<007`000000goo00@007`0O00000=oo`03
001l000000=oo`04001l07`00002Ool01000O01l00000goo00<007`000000goo00@007`0O00000=o
o`03001l000000=oo`04001l07`00002Ool01000O01l00000goo00<007`000000goo00@007`0O000
00=oo`03001l000000=oo`04001l07`00002Ool01000O01l00000goo00<007`000000goo00@007`0
O00000=oo`03001l000000=oo`04001l07`00002Ool01000O01l0000C7oo00<0006O00000goo00@0
006O0Il000=oo`030001W`0000=oo`030001W`0000=oo`040001W`6O0003Ool00`000Il00003Ool0
10000Il1W`000goo00<0006O00000goo00<0006O00000goo00@0006O0Il000=oo`030001W`0000=o
o`040001W`6O0003Ool00`000Il00003Ool00`000Il00003Ool010000Il1W`000goo00<0006O0000
0goo00@0006O0Il004=oo`007Woo00<007ooOol0Rgoo00<007`000000goo00@007`0O00000=oo`03
001l000000=oo`04001l07`00002Ool01000O01l00000goo00<007`000000goo00@007`0O00000=o
o`03001l000000=oo`04001l07`00002Ool01000O01l00000goo00<007`000000goo00@007`0O000
00=oo`03001l000000=oo`04001l07`00002Ool01000O01l00000goo00<007`000000goo00@007`0
O00000=oo`03001l000000=oo`04001l07`00002Ool01000O01l0000C7oo00<0006O00000goo00@0
006O0Il000=oo`030001W`0000=oo`030001W`0000=oo`040001W`6O0003Ool00`000Il00003Ool0
10000Il1W`000goo00<0006O00000goo00<0006O00000goo00@0006O0Il000=oo`030001W`0000=o
o`040001W`6O0003Ool00`000Il00003Ool00`000Il00003Ool010000Il1W`000goo00<0006O0000
0goo00@0006O0Il004=oo`007Woo00<007ooOol0Rgoo00<007`000000goo00@007`0O00000=oo`03
001l000000=oo`04001l07`00002Ool01000O01l00000goo00<007`000000goo00@007`0O00000=o
o`03001l000000=oo`04001l07`00002Ool01000O01l00000goo00<007`000000goo00@007`0O000
00=oo`03001l000000=oo`04001l07`00002Ool01000O01l00000goo00<007`000000goo00@007`0
O00000=oo`03001l000000=oo`04001l07`00002Ool01000O01l0000C7oo00<0006O00000goo00@0
006O0Il000=oo`030001W`0000=oo`030001W`0000=oo`040001W`6O0003Ool00`000Il00003Ool0
10000Il1W`000goo00<0006O00000goo00<0006O00000goo00@0006O0Il000=oo`030001W`0000=o
o`040001W`6O0003Ool00`000Il00003Ool00`000Il00003Ool010000Il1W`000goo00<0006O0000
0goo00@0006O0Il004=oo`007Woo00<007ooOol0Rgoo00<007`000000goo00@007`0O00000=oo`03
001l000000=oo`04001l07`00002Ool01000O01l00000goo00<007`000000goo00@007`0O00000=o
o`03001l000000=oo`04001l07`00002Ool01000O01l00000goo00<007`000000goo00@007`0O000
00=oo`03001l000000=oo`04001l07`00002Ool01000O01l00000goo00<007`000000goo00@007`0
O00000=oo`03001l000000=oo`04001l07`00002Ool01000O01l0000C7oo00<0006O00000goo00@0
006O0Il000=oo`030001W`0000=oo`030001W`0000=oo`040001W`6O0003Ool00`000Il00003Ool0
10000Il1W`000goo00<0006O00000goo00<0006O00000goo00@0006O0Il000=oo`030001W`0000=o
o`040001W`6O0003Ool00`000Il00003Ool00`000Il00003Ool010000Il1W`000goo00<0006O0000
0goo00@0006O0Il004=oo`007Woo00<007ooOol0Rgoo00<007`000000goo00@007`0O00000=oo`03
001l000000=oo`04001l07`00002Ool01000O01l00000goo00<007`000000goo00@007`0O00000=o
o`03001l000000=oo`04001l07`00002Ool01000O01l00000goo00<007`000000goo00@007`0O000
00=oo`03001l000000=oo`04001l07`00002Ool01000O01l00000goo00<007`000000goo00@007`0
O00000=oo`03001l000000=oo`04001l07`00002Ool01000O01l0000C7oo00<0006O00000goo00@0
006O0Il000=oo`030001W`0000=oo`030001W`0000=oo`040001W`6O0003Ool00`000Il00003Ool0
10000Il1W`000goo00<0006O00000goo00<0006O00000goo00@0006O0Il000=oo`030001W`0000=o
o`040001W`6O0003Ool00`000Il00003Ool00`000Il00003Ool010000Il1W`000goo00<0006O0000
0goo00@0006O0Il004=oo`007Woo00<007ooOol0Rgoo00<007`000000goo00@007`0O00000=oo`03
001l000000=oo`04001l07`00002Ool01000O01l00000goo00<007`000000goo00@007`0O00000=o
o`03001l000000=oo`04001l07`00002Ool01000O01l00000goo00<007`000000goo00@007`0O000
00=oo`03001l000000=oo`04001l07`00002Ool01000O01l00000goo00<007`000000goo00@007`0
O00000=oo`03001l000000=oo`04001l07`00002Ool01000O01l0000C7oo00<0006O00000goo00@0
006O0Il000=oo`030001W`0000=oo`030001W`0000=oo`040001W`6O0003Ool00`000Il00003Ool0
10000Il1W`000goo00<0006O00000goo00<0006O00000goo00@0006O0Il000=oo`030001W`0000=o
o`040001W`6O0003Ool00`000Il00003Ool00`000Il00003Ool010000Il1W`000goo00<0006O0000
0goo00@0006O0Il004=oo`007Woo00<007ooOol0Rgoo00<007`000000goo00@007`0O00000=oo`03
001l000000=oo`04001l07`00002Ool01000O01l00000goo00<007`000000goo00@007`0O00000=o
o`03001l000000=oo`04001l07`00002Ool01000O01l00000goo00<007`000000goo00@007`0O000
00=oo`03001l000000=oo`04001l07`00002Ool01000O01l00000goo00<007`000000goo00@007`0
O00000=oo`03001l000000=oo`04001l07`00002Ool01000O01l0000C7oo00<0006O00000goo00@0
006O0Il000=oo`030001W`0000=oo`030001W`0000=oo`040001W`6O0003Ool00`000Il00003Ool0
10000Il1W`000goo00<0006O00000goo00<0006O00000goo00@0006O0Il000=oo`030001W`0000=o
o`040001W`6O0003Ool00`000Il00003Ool00`000Il00003Ool010000Il1W`000goo00<0006O0000
0goo00@0006O0Il004=oo`007Woo00<007ooOol0Rgoo00<007`000000goo00@007`0O00000=oo`03
001l000000=oo`04001l07`00002Ool01000O01l00000goo00<007`000000goo00@007`0O00000=o
o`03001l000000=oo`04001l07`00002Ool01000O01l00000goo00<007`000000goo00@007`0O000
00=oo`03001l000000=oo`04001l07`00002Ool01000O01l00000goo00<007`000000goo00@007`0
O00000=oo`03001l000000=oo`04001l07`00002Ool01000O01l0000C7oo00<0006O00000goo00@0
006O0Il000=oo`030001W`0000=oo`030001W`0000=oo`040001W`6O0003Ool00`000Il00003Ool0
10000Il1W`000goo00<0006O00000goo00<0006O00000goo00@0006O0Il000=oo`030001W`0000=o
o`040001W`6O0003Ool00`000Il00003Ool00`000Il00003Ool010000Il1W`000goo00<0006O0000
0goo00@0006O0Il004=oo`007Woo00<007ooOol0Rgoo00<007`000000goo00@007`0O00000=oo`03
001l000000=oo`04001l07`00002Ool01000O01l00000goo00<007`000000goo00@007`0O00000=o
o`03001l000000=oo`04001l07`00002Ool01000O01l00000goo00<007`000000goo00@007`0O000
00=oo`03001l000000=oo`04001l07`00002Ool01000O01l00000goo00<007`000000goo00@007`0
O00000=oo`03001l000000=oo`04001l07`00002Ool01000O01l0000C7oo00<0006O00000goo00@0
006O0Il000=oo`030001W`0000=oo`030001W`0000=oo`040001W`6O0003Ool00`000Il00003Ool0
10000Il1W`000goo00<0006O00000goo00<0006O00000goo00@0006O0Il000=oo`030001W`0000=o
o`040001W`6O0003Ool00`000Il00003Ool00`000Il00003Ool010000Il1W`000goo00<0006O0000
0goo00@0006O0Il004=oo`007Woo0`00Rgoo00<007`000000goo10000goo00<007`000000goo00@0
07`0O000009oo`04001l07`00003Ool00`00O0000003Ool01000O01l00000goo00<007`000000goo
00@007`0O000009oo`04001l07`00003Ool00`00O0000003Ool01000O01l00000goo00<007`00000
0goo00@007`0O000009oo`04001l07`00003Ool00`00O0000003Ool01000O01l00000goo00<007`0
00000goo00@007`0O000009oo`@004aoo`<000=oo`040001W`6O0003Ool00`000Il00003Ool00`00
0Il00003Ool010000Il1W`000goo00<0006O00000goo00@0006O0Il000=oo`030001W`0000=oo`03
0001W`0000=oo`040001W`6O0003Ool00`000Il00003Ool010000Il1W`000goo00<0006O00000goo
00<0006O00000goo00@0006O0Il000=oo`030001W`0000=oo`040001W`6O0013Ool001ioo`03001o
ogoo08]oo`03001l000000Yoo`03001l000000=oo`04001l07`00002Ool01000O01l00000goo00<0
07`000000goo00@007`0O00000=oo`03001l000000=oo`04001l07`00002Ool01000O01l00000goo
00<007`000000goo00@007`0O00000=oo`03001l000000=oo`04001l07`00002Ool01000O01l0000
0goo00<007`000000goo00@007`0O00000=oo`03001l000000=oo`04001l07`0001HOol010000Il1
W`000goo00<0006O00000goo00<0006O00000goo00@0006O0Il000=oo`030001W`0000=oo`040001
W`6O0003Ool00`000Il00003Ool00`000Il00003Ool010000Il1W`000goo00<0006O00000goo00@0
006O0Il000=oo`030001W`0000=oo`030001W`0000=oo`040001W`6O0003Ool00`000Il00003Ool0
10000Il1W`00@goo000NOol00`00Oomoo`2;Ool00`00O000000:Ool00`00O0000003Ool01000O01l
00000Woo00@007`0O00000=oo`03001l000000=oo`04001l07`00003Ool00`00O0000003Ool01000
O01l00000Woo00@007`0O00000=oo`03001l000000=oo`04001l07`00003Ool00`00O0000003Ool0
1000O01l00000Woo00@007`0O00000=oo`03001l000000=oo`04001l07`00003Ool00`00O0000003
Ool01000O01l0000F7oo00@0006O0Il000=oo`030001W`0000=oo`030001W`0000=oo`040001W`6O
0003Ool00`000Il00003Ool010000Il1W`000goo00<0006O00000goo00<0006O00000goo00@0006O
0Il000=oo`030001W`0000=oo`040001W`6O0003Ool00`000Il00003Ool00`000Il00003Ool01000
0Il1W`000goo00<0006O00000goo00@0006O0Il004=oo`007Woo00<007ooOol0Rgoo00<007`00000
2Woo00<007`000000goo10000Woo00@007`0O00000=oo`03001l000000=oo`04001l07`00003Ool0
0`00O0000003Ool01000O01l00000Woo00@007`0O00000=oo`03001l000000=oo`04001l07`00003
Ool00`00O0000003Ool01000O01l00000Woo00@007`0O00000=oo`03001l000000=oo`04001l07`0
0003Ool00`00O0000003Ool01000O01l0000F7oo00@0006O0Il000=oo`030001W`0000=oo`030001
W`0000=oo`040001W`6O0003Ool00`000Il00003Ool010000Il1W`000goo00<0006O00000goo00<0
006O00000goo00@0006O0Il000=oo`030001W`0000=oo`040001W`6O0003Ool00`000Il00003Ool0
0`000Il00003Ool010000Il1W`000goo00<0006O00000goo00@0006O0Il004=oo`007Woo00<007oo
Ool0Rgoo00<007`000002Woo00<007`000002Goo00@007`0O00000=oo`03001l000000=oo`04001l
07`00003Ool00`00O0000003Ool01000O01l00000Woo00@007`0O00000=oo`03001l000000=oo`04
001l07`00003Ool00`00O0000003Ool01000O01l00000Woo00@007`0O00000=oo`03001l000000=o
o`04001l07`00003Ool00`00O0000003Ool01000O01l0000F7oo00@0006O0Il000=oo`030001W`00
00=oo`030001W`0000=oo`040001W`6O0003Ool00`000Il00003Ool010000Il1W`000goo00<0006O
00000goo00<0006O00000goo00@0006O0Il000=oo`030001W`0000=oo`040001W`6O0003Ool00`00
0Il00003Ool00`000Il00003Ool010000Il1W`000goo00<0006O00000goo00@0006O0Il004=oo`00
7Woo00<007ooOol0Rgoo00<007`000002Woo00<007`000002Goo00@007`0O00000=oo`03001l0000
00=oo`04001l07`00003Ool00`00O0000003Ool01000O01l00000Woo00@007`0O00000=oo`03001l
000000=oo`04001l07`00003Ool00`00O0000003Ool01000O01l00000Woo00@007`0O00000=oo`03
001l000000=oo`04001l07`00003Ool00`00O0000003Ool01000O01l0000F7oo00@0006O0Il000=o
o`030001W`0000=oo`030001W`0000=oo`040001W`6O0003Ool00`000Il00003Ool010000Il1W`00
0goo00<0006O00000goo00<0006O00000goo00@0006O0Il000=oo`030001W`0000=oo`040001W`6O
0003Ool00`000Il00003Ool00`000Il00003Ool010000Il1W`000goo00<0006O00000goo00@0006O
0Il004=oo`007Woo00<007ooOol0Rgoo00<007`000002Woo00<007`000002Goo00@007`0O00000=o
o`03001l000000=oo`04001l07`00003Ool00`00O0000003Ool01000O01l00000Woo00@007`0O000
00=oo`03001l000000=oo`04001l07`00003Ool00`00O0000003Ool01000O01l00000Woo00@007`0
O00000=oo`03001l000000=oo`04001l07`00003Ool00`00O0000003Ool01000O01l0000F7oo00@0
006O0Il000=oo`030001W`0000=oo`030001W`0000=oo`040001W`6O0003Ool00`000Il00003Ool0
10000Il1W`000goo00<0006O00000goo00<0006O00000goo00@0006O0Il000=oo`030001W`0000=o
o`040001W`6O0003Ool00`000Il00003Ool00`000Il00003Ool010000Il1W`000goo00<0006O0000
0goo00@0006O0Il004=oo`007Woo00<007ooOol0Rgoo00<007`000002Woo00<007`000002Goo00@0
07`0O00000=oo`03001l000000=oo`04001l07`00003Ool00`00O0000003Ool01000O01l00000Woo
00@007`0O00000=oo`03001l000000=oo`04001l07`00003Ool00`00O0000003Ool01000O01l0000
0Woo00@007`0O00000=oo`03001l000000=oo`04001l07`00003Ool00`00O0000003Ool01000O01l
0000F7oo00@0006O0Il000=oo`030001W`0000=oo`030001W`0000=oo`040001W`6O0003Ool00`00
0Il00003Ool010000Il1W`000goo00<0006O00000goo00<0006O00000goo00@0006O0Il000=oo`03
0001W`0000=oo`040001W`6O0003Ool00`000Il00003Ool00`000Il00003Ool010000Il1W`000goo
00<0006O00000goo00@0006O0Il004=oo`007Woo00<007ooOol0Rgoo00<007`000002Woo00<007`0
00002Goo00@007`0O00000=oo`03001l000000=oo`04001l07`00003Ool00`00O0000003Ool01000
O01l00000Woo00@007`0O00000=oo`03001l000000=oo`04001l07`00003Ool00`00O0000003Ool0
1000O01l00000Woo00@007`0O00000=oo`03001l000000=oo`04001l07`00003Ool00`00O0000003
Ool01000O01l0000F7oo00@0006O0Il000=oo`030001W`0000=oo`030001W`0000=oo`040001W`6O
0003Ool00`000Il00003Ool010000Il1W`000goo00<0006O00000goo00<0006O00000goo00@0006O
0Il000=oo`030001W`0000=oo`040001W`6O0003Ool00`000Il00003Ool00`000Il00003Ool01000
0Il1W`000goo00<0006O00000goo00@0006O0Il004=oo`007Woo00<007ooOol0Rgoo00<007`00000
2Woo00<007`000002Goo00@007`0O00000=oo`03001l000000=oo`04001l07`00003Ool00`00O000
0003Ool01000O01l00000Woo00@007`0O00000=oo`03001l000000=oo`04001l07`00003Ool00`00
O0000003Ool01000O01l00000Woo00@007`0O00000=oo`03001l000000=oo`04001l07`00003Ool0
0`00O0000003Ool01000O01l0000F7oo00@0006O0Il000=oo`030001W`0000=oo`030001W`0000=o
o`040001W`6O0003Ool00`000Il00003Ool010000Il1W`000goo00<0006O00000goo00<0006O0000
0goo00@0006O0Il000=oo`030001W`0000=oo`040001W`6O0003Ool00`000Il00003Ool00`000Il0
0003Ool010000Il1W`000goo00<0006O00000goo00@0006O0Il004=oo`007Woo00<007ooOol0Rgoo
0`002Woo00<007`000002Goo00@007`0O00000=oo`03001l000000=oo`04001l07`00003Ool00`00
O0000003Ool01000O01l00000Woo00@007`0O00000=oo`03001l000000=oo`04001l07`00003Ool0
0`00O0000003Ool01000O01l00000Woo00@007`0O00000=oo`03001l000000=oo`04001l07`00003
Ool00`00O0000003Ool01000O01l0000F7oo00@0006O0Il000=oo`030001W`0000=oo`030001W`00
00=oo`040001W`6O0003Ool00`000Il00003Ool010000Il1W`000goo00<0006O00000goo00<0006O
00000goo00@0006O0Il000=oo`030001W`0000=oo`040001W`6O0003Ool00`000Il00003Ool00`00
0Il00003Ool010000Il1W`000goo00<0006O00000goo00@0006O0Il004=oo`007Woo00<007ooOol0
V7oo00<007`000002Goo00@007`0O00000=oo`03001l000000=oo`04001l07`00003Ool00`00O000
0003Ool01000O01l00000Woo00@007`0O00000=oo`03001l000000=oo`04001l07`00003Ool00`00
O0000003Ool01000O01l00000Woo00@007`0O00000=oo`03001l000000=oo`04001l07`00003Ool0
0`00O0000003Ool01000O01l0000F7oo00@0006O0Il000=oo`030001W`0000=oo`030001W`0000=o
o`040001W`6O0003Ool00`000Il00003Ool010000Il1W`000goo00<0006O00000goo00<0006O0000
0goo00@0006O0Il000=oo`030001W`0000=oo`040001W`6O0003Ool00`000Il00003Ool00`000Il0
0003Ool010000Il1W`000goo00<0006O00000goo00@0006O0Il004=oo`007Woo00<007ooOol0V7oo
00<007`000002Goo00@007`0O00000=oo`03001l000000=oo`04001l07`00003Ool00`00O0000003
Ool01000O01l00000Woo00@007`0O00000=oo`03001l000000=oo`04001l07`00003Ool00`00O000
0003Ool01000O01l00000Woo00@007`0O00000=oo`03001l000000=oo`04001l07`00003Ool00`00
O0000003Ool01000O01l0000F7oo00@0006O0Il000=oo`030001W`0000=oo`030001W`0000=oo`04
0001W`6O0003Ool00`000Il00003Ool010000Il1W`000goo00<0006O00000goo00<0006O00000goo
00@0006O0Il000=oo`030001W`0000=oo`040001W`6O0003Ool00`000Il00003Ool00`000Il00003
Ool010000Il1W`000goo00<0006O00000goo00@0006O0Il004=oo`007Woo00<007ooOol0V7oo00<0
07`000002Goo00@007`0O00000=oo`03001l000000=oo`04001l07`00003Ool00`00O0000003Ool0
1000O01l00000Woo00@007`0O00000=oo`03001l000000=oo`04001l07`00003Ool00`00O0000003
Ool01000O01l00000Woo00@007`0O00000=oo`03001l000000=oo`04001l07`00003Ool00`00O000
0003Ool01000O01l0000F7oo00@0006O0Il000=oo`030001W`0000=oo`030001W`0000=oo`040001
W`6O0003Ool00`000Il00003Ool010000Il1W`000goo00<0006O00000goo00<0006O00000goo00@0
006O0Il000=oo`030001W`0000=oo`040001W`6O0003Ool00`000Il00003Ool00`000Il00003Ool0
10000Il1W`000goo00<0006O00000goo00@0006O0Il004=oo`0037oo10000goo0P002Goo00<007oo
Ool0V7oo00<007`000002Goo00@007`0O00000=oo`03001l000000=oo`04001l07`00003Ool00`00
O0000003Ool01000O01l00000Woo00@007`0O00000=oo`03001l000000=oo`04001l07`00003Ool0
0`00O0000003Ool01000O01l00000Woo00@007`0O00000=oo`03001l000000=oo`04001l07`00003
Ool00`00O0000003Ool01000O01l0000F7oo00@0006O0Il000=oo`030001W`0000=oo`030001W`00
00=oo`040001W`6O0003Ool00`000Il00003Ool010000Il1W`000goo00<0006O00000goo00<0006O
00000goo00@0006O0Il000=oo`030001W`0000=oo`040001W`6O0003Ool00`000Il00003Ool00`00
0Il00003Ool010000Il1W`000goo00<0006O00000goo00@0006O0Il004=oo`003Goo00<007ooOol0
0Woo00@007ooOol000Qoo`03001oogoo09Qoo`03001l000000Uoo`04001l07`00003Ool00`00O000
0003Ool01000O01l00000goo00<007`000000goo00@007`0O000009oo`04001l07`00003Ool00`00
O0000003Ool01000O01l00000goo00<007`000000goo00@007`0O000009oo`04001l07`00003Ool0
0`00O0000003Ool01000O01l00000goo00<007`000000goo00@007`0O00005Qoo`040001W`6O0003
Ool00`000Il00003Ool00`000Il00003Ool010000Il1W`000goo00<0006O00000goo00@0006O0Il0
00=oo`030001W`0000=oo`030001W`0000=oo`040001W`6O0003Ool00`000Il00003Ool010000Il1
W`000goo00<0006O00000goo00<0006O00000goo00@0006O0Il000=oo`030001W`0000=oo`040001
W`6O0013Ool000ioo`05001oogooOol00002Ool00`00Oomoo`06Ool4002GOol30009Ool01000O01l
00000goo00<007`000000goo00@007`0O00000=oo`03001l000000=oo`04001l07`00002Ool01000
O01l00000goo00<007`000000goo00@007`0O00000=oo`03001l000000=oo`04001l07`00002Ool0
1000O01l00000goo00<007`000000goo00@007`0O00000=oo`03001l000000=oo`04001l07`0001H
Ool010000Il1W`000goo00<0006O00000goo00<0006O00000goo00@0006O0Il000=oo`030001W`00
00=oo`040001W`6O0003Ool00`000Il00003Ool00`000Il00003Ool010000Il1W`000goo00<0006O
00000goo00@0006O0Il000=oo`030001W`0000=oo`030001W`0000=oo`040001W`6O0003Ool00`00
0Il00003Ool010000Il1W`00@goo000?Ool01000Oomoo`000Woo00<007ooOol01Woo00<007ooOol0
Y7oo00@007`0O00000=oo`03001l000000=oo`04001l07`00003Ool00`00O0000003Ool01000O01l
00000Woo00@007`0O00000=oo`03001l000000=oo`04001l07`00003Ool00`00O0000003Ool01000
O01l00000Woo00@007`0O00000=oo`03001l000000=oo`04001l07`00003Ool00`00O0000003Ool0
1000O01l0000F7oo00@0006O0Il000=oo`030001W`0000=oo`030001W`0000=oo`040001W`6O0003
Ool00`000Il00003Ool010000Il1W`000goo00<0006O00000goo00<0006O00000goo00@0006O0Il0
00=oo`030001W`0000=oo`040001W`6O0003Ool00`000Il00003Ool00`000Il00003Ool010000Il1
W`000goo00<0006O00000goo00@0006O0Il004=oo`0037oo00@007ooOol0009oo`04001oogoo0008
Ool00`00Oomoo`2TOol01000O01l00000goo00<007`000000goo00@007`0O00000=oo`03001l0000
00=oo`04001l07`00002Ool01000O01l00000goo00<007`000000goo00@007`0O00000=oo`03001l
000000=oo`04001l07`00002Ool01000O01l00000goo00<007`000000goo00@007`0O00000=oo`03
001l000000=oo`04001l07`0001HOol010000Il1W`000goo00<0006O00000goo00<0006O00000goo
00@0006O0Il000=oo`030001W`0000=oo`040001W`6O0003Ool00`000Il00003Ool00`000Il00003
Ool010000Il1W`000goo00<0006O00000goo00@0006O0Il000=oo`030001W`0000=oo`030001W`00
00=oo`040001W`6O0003Ool00`000Il00003Ool010000Il1W`00@goo000=Ool20004Ool20009Ool0
0`00Oomoo`2TOol01000O01l00000goo00<007`000000goo00@007`0O00000=oo`03001l000000=o
o`04001l07`00002Ool01000O01l00000goo00<007`000000goo00@007`0O00000=oo`03001l0000
00=oo`04001l07`00002Ool01000O01l00000goo00<007`000000goo00@007`0O00000=oo`03001l
000000=oo`04001l07`0001HOol010000Il1W`000goo00<0006O00000goo00<0006O00000goo00@0
006O0Il000=oo`030001W`0000=oo`040001W`6O0003Ool00`000Il00003Ool00`000Il00003Ool0
10000Il1W`000goo00<0006O00000goo00@0006O0Il000=oo`030001W`0000=oo`030001W`0000=o
o`040001W`6O0003Ool00`000Il00003Ool010000Il1W`00@goo000NOol00`00Oomoo`2TOol01000
O01l00000goo00<007`000000goo00@007`0O00000=oo`03001l000000=oo`04001l07`00002Ool0
1000O01l00000goo00<007`000000goo00@007`0O00000=oo`03001l000000=oo`04001l07`00002
Ool01000O01l00000goo00<007`000000goo00@007`0O00000=oo`03001l000000=oo`04001l07`0
001HOol010000Il1W`000goo00<0006O00000goo00<0006O00000goo00@0006O0Il000=oo`030001
W`0000=oo`040001W`6O0003Ool00`000Il00003Ool00`000Il00003Ool010000Il1W`000goo00<0
006O00000goo00@0006O0Il000=oo`030001W`0000=oo`030001W`0000=oo`040001W`6O0003Ool0
0`000Il00003Ool010000Il1W`00@goo000NOol00`00Oomoo`2TOol01000O01l00000goo00<007`0
00000goo00@007`0O00000=oo`03001l000000=oo`04001l07`00002Ool01000O01l00000goo00<0
07`000000goo00@007`0O00000=oo`03001l000000=oo`04001l07`00002Ool01000O01l00000goo
00<007`000000goo00@007`0O00000=oo`03001l000000=oo`04001l07`0001HOol010000Il1W`00
0goo00<0006O00000goo00<0006O00000goo00@0006O0Il000=oo`030001W`0000=oo`040001W`6O
0003Ool00`000Il00003Ool00`000Il00003Ool010000Il1W`000goo00<0006O00000goo00@0006O
0Il000=oo`030001W`0000=oo`030001W`0000=oo`040001W`6O0003Ool00`000Il00003Ool01000
0Il1W`00@goo000NOol00`00Oomoo`2TOol01000O01l00000goo00<007`000000goo00@007`0O000
00=oo`03001l000000=oo`04001l07`00002Ool01000O01l00000goo00<007`000000goo00@007`0
O00000=oo`03001l000000=oo`04001l07`00002Ool01000O01l00000goo00<007`000000goo00@0
07`0O00000=oo`03001l000000=oo`04001l07`0001HOol010000Il1W`000goo00<0006O00000goo
00<0006O00000goo00@0006O0Il000=oo`030001W`0000=oo`040001W`6O0003Ool00`000Il00003
Ool00`000Il00003Ool010000Il1W`000goo00<0006O00000goo00@0006O0Il000=oo`030001W`00
00=oo`030001W`0000=oo`040001W`6O0003Ool00`000Il00003Ool010000Il1W`00@goo000NOol0
0`00Oomoo`2TOol01000O01l00000goo00<007`000000goo00@007`0O00000=oo`03001l000000=o
o`04001l07`00002Ool01000O01l00000goo00<007`000000goo00@007`0O00000=oo`03001l0000
00=oo`04001l07`00002Ool01000O01l00000goo00<007`000000goo00@007`0O00000=oo`03001l
000000=oo`04001l07`0001HOol010000Il1W`000goo00<0006O00000goo00<0006O00000goo00@0
006O0Il000=oo`030001W`0000=oo`040001W`6O0003Ool00`000Il00003Ool00`000Il00003Ool0
10000Il1W`000goo00<0006O00000goo00@0006O0Il000=oo`030001W`0000=oo`030001W`0000=o
o`040001W`6O0003Ool00`000Il00003Ool010000Il1W`00@goo000NOol00`00Oomoo`2TOol01000
O01l00000goo00<007`000000goo00@007`0O00000=oo`03001l000000=oo`04001l07`00002Ool0
1000O01l00000goo00<007`000000goo00@007`0O00000=oo`03001l000000=oo`04001l07`00002
Ool01000O01l00000goo00<007`000000goo00@007`0O00000=oo`03001l000000=oo`04001l07`0
001HOol010000Il1W`000goo00<0006O00000goo00<0006O00000goo00@0006O0Il000=oo`030001
W`0000=oo`040001W`6O0003Ool00`000Il00003Ool00`000Il00003Ool010000Il1W`000goo00<0
006O00000goo00@0006O0Il000=oo`030001W`0000=oo`030001W`0000=oo`040001W`6O0003Ool0
0`000Il00003Ool010000Il1W`00@goo000NOol00`00Oomoo`2TOol01000O01l00000goo00<007`0
00000goo00@007`0O00000=oo`03001l000000=oo`04001l07`00002Ool01000O01l00000goo00<0
07`000000goo00@007`0O00000=oo`03001l000000=oo`04001l07`00002Ool01000O01l00000goo
00<007`000000goo00@007`0O00000=oo`03001l000000=oo`04001l07`0001HOol010000Il1W`00
0goo00<0006O00000goo00<0006O00000goo00@0006O0Il000=oo`030001W`0000=oo`040001W`6O
0003Ool00`000Il00003Ool00`000Il00003Ool010000Il1W`000goo00<0006O00000goo00@0006O
0Il000=oo`030001W`0000=oo`030001W`0000=oo`040001W`6O0003Ool00`000Il00003Ool01000
0Il1W`00@goo000NOol00`00Oomoo`2TOol01000O01l00000goo00<007`000000goo00@007`0O000
00=oo`03001l000000=oo`04001l07`00002Ool01000O01l00000goo00<007`000000goo00@007`0
O00000=oo`03001l000000=oo`04001l07`00002Ool01000O01l00000goo00<007`000000goo00@0
07`0O00000=oo`03001l000000=oo`04001l07`0001HOol010000Il1W`000goo00<0006O00000goo
00<0006O00000goo00@0006O0Il000=oo`030001W`0000=oo`040001W`6O0003Ool00`000Il00003
Ool00`000Il00003Ool010000Il1W`000goo00<0006O00000goo00@0006O0Il000=oo`030001W`00
00=oo`030001W`0000=oo`040001W`6O0003Ool00`000Il00003Ool010000Il1W`00@goo000NOol0
0`00Oomoo`2TOol01000O01l00000goo00<007`000000goo00@007`0O00000=oo`03001l000000=o
o`04001l07`00002Ool01000O01l00000goo00<007`000000goo00@007`0O00000=oo`03001l0000
00=oo`04001l07`00002Ool01000O01l00000goo00<007`000000goo00@007`0O00000=oo`03001l
000000=oo`04001l07`0001HOol010000Il1W`000goo00<0006O00000goo00<0006O00000goo00@0
006O0Il000=oo`030001W`0000=oo`040001W`6O0003Ool00`000Il00003Ool00`000Il00003Ool0
10000Il1W`000goo00<0006O00000goo00@0006O0Il000=oo`030001W`0000=oo`030001W`0000=o
o`040001W`6O0003Ool00`000Il00003Ool010000Il1W`00@goo000NOol00`00Oomoo`2TOol01000
O01l00000goo00<007`000000goo00@007`0O00000=oo`03001l000000=oo`04001l07`00002Ool0
1000O01l00000goo00<007`000000goo00@007`0O00000=oo`03001l000000=oo`04001l07`00002
Ool01000O01l00000goo00<007`000000goo00@007`0O00000=oo`03001l000000=oo`04001l07`0
001HOol010000Il1W`000goo00<0006O00000goo00<0006O00000goo00@0006O0Il000=oo`030001
W`0000=oo`040001W`6O0003Ool00`000Il00003Ool00`000Il00003Ool010000Il1W`000goo00<0
006O00000goo00@0006O0Il000=oo`030001W`0000=oo`030001W`0000=oo`040001W`6O0003Ool0
0`000Il00003Ool010000Il1W`00@goo000NOol00`00Oomoo`2TOol01000O01l00000goo00<007`0
00000goo00@007`0O00000=oo`03001l000000=oo`04001l07`00002Ool01000O01l00000goo00<0
07`000000goo00@007`0O00000=oo`03001l000000=oo`04001l07`00002Ool01000O01l00000goo
00<007`000000goo00@007`0O00000=oo`03001l000000=oo`04001l07`0001HOol010000Il1W`00
0goo00<0006O00000goo0`000goo00@0006O0Il000=oo`030001W`0000=oo`040001W`6O0003Ool0
0`000Il00003Ool00`000Il00003Ool010000Il1W`000goo00<0006O00000goo00@0006O0Il000=o
o`030001W`0000=oo`030001W`0000=oo`040001W`6O0003Ool00`000Il00003Ool010000Il1W`00
@goo000NOol00`00Oomoo`2TOol01000O01l00000goo00<007`000000goo00@007`0O00000=oo`03
001l000000=oo`04001l07`00002Ool01000O01l00000goo00<007`000000goo00@007`0O00000=o
o`03001l000000=oo`04001l07`00002Ool01000O01l00000goo00<007`000000goo00@007`0O000
00=oo`03001l000000=oo`04001l07`0001HOol010000Il1W`000goo00<0006O00002Goo00@0006O
0Il000=oo`030001W`0000=oo`040001W`6O0003Ool00`000Il00003Ool00`000Il00003Ool01000
0Il1W`000goo00<0006O00000goo00@0006O0Il000=oo`030001W`0000=oo`030001W`0000=oo`04
0001W`6O0003Ool00`000Il00003Ool010000Il1W`00@goo000NOol00`00Oomoo`2TOol01000O01l
00000goo00<007`000000goo00@007`0O00000=oo`03001l000000=oo`04001l07`00002Ool01000
O01l00000goo00<007`000000goo00@007`0O00000=oo`03001l000000=oo`04001l07`00002Ool0
1000O01l00000goo00<007`000000goo00@007`0O00000=oo`03001l000000=oo`04001l07`0001H
Ool010000Il1W`000goo00<0006O00002Goo00@0006O0Il000=oo`030001W`0000=oo`040001W`6O
0003Ool00`000Il00003Ool00`000Il00003Ool010000Il1W`000goo00<0006O00000goo00@0006O
0Il000=oo`030001W`0000=oo`030001W`0000=oo`040001W`6O0003Ool00`000Il00003Ool01000
0Il1W`00@goo000NOol3002TOol01000O01l00000goo00<007`000000goo00@007`0O00000=oo`03
001l000000=oo`04001l07`00002Ool01000O01l00000goo00<007`000000goo00@007`0O00000=o
o`03001l000000=oo`04001l07`00002Ool01000O01l00000goo00<007`000000goo00@007`0O000
00=oo`03001l000000=oo`04001l07`0001HOol010000Il1W`000goo00<0006O00002Goo00@0006O
0Il000=oo`030001W`0000=oo`040001W`6O0003Ool00`000Il00003Ool00`000Il00003Ool01000
0Il1W`000goo00<0006O00000goo00@0006O0Il000=oo`030001W`0000=oo`030001W`0000=oo`04
0001W`6O0003Ool00`000Il00003Ool010000Il1W`00@goo000NOol00`00Oomoo`2TOol01000O01l
00000goo00<007`000000goo00@007`0O00000=oo`03001l000000=oo`04001l07`00002Ool01000
O01l00000goo00<007`000000goo00@007`0O00000=oo`03001l000000=oo`04001l07`00002Ool0
1000O01l00000goo00<007`000000goo00@007`0O00000=oo`03001l000000=oo`04001l07`0001H
Ool010000Il1W`000goo00<0006O00002Goo00@0006O0Il000=oo`030001W`0000=oo`040001W`6O
0003Ool00`000Il00003Ool00`000Il00003Ool010000Il1W`000goo00<0006O00000goo00@0006O
0Il000=oo`030001W`0000=oo`030001W`0000=oo`040001W`6O0003Ool00`000Il00003Ool01000
0Il1W`00@goo000NOol00`00Oomoo`2TOol01000O01l00000goo00<007`000000goo00@007`0O000
00=oo`03001l000000=oo`04001l07`00002Ool01000O01l00000goo00<007`000000goo00@007`0
O00000=oo`03001l000000=oo`04001l07`00002Ool01000O01l00000goo00<007`000000goo00@0
07`0O00000=oo`03001l000000=oo`04001l07`0001HOol010000Il1W`000goo00<0006O00002Goo
00@0006O0Il000=oo`030001W`0000=oo`040001W`6O0003Ool00`000Il00003Ool00`000Il00003
Ool010000Il1W`000goo00<0006O00000goo00@0006O0Il000=oo`030001W`0000=oo`030001W`00
00=oo`040001W`6O0003Ool00`000Il00003Ool010000Il1W`00@goo000NOol00`00Oomoo`2TOol0
1000O01l00000goo00<007`000000goo00@007`0O00000=oo`03001l000000=oo`04001l07`00002
Ool01000O01l00000goo00<007`000000goo00@007`0O00000=oo`03001l000000=oo`04001l07`0
0002Ool01000O01l00000goo00<007`000000goo00@007`0O00000=oo`03001l000000=oo`04001l
07`0001HOol010000Il1W`000goo0`002Goo00@0006O0Il000=oo`030001W`0000=oo`040001W`6O
0003Ool00`000Il00003Ool00`000Il00003Ool010000Il1W`000goo00<0006O00000goo00@0006O
0Il000=oo`030001W`0000=oo`030001W`0000=oo`040001W`6O0003Ool00`000Il00003Ool01000
0Il1W`00@goo000NOol00`00Oomoo`2TOol01000O01l00000goo00<007`000000goo00@007`0O000
00=oo`03001l000000=oo`04001l07`00002Ool01000O01l00000goo00<007`000000goo00@007`0
O00000=oo`03001l000000=oo`04001l07`00002Ool01000O01l00000goo00<007`000000goo00@0
07`0O00000=oo`03001l000000=oo`04001l07`0001HOol010000Il1W`003goo00@0006O0Il000=o
o`030001W`0000=oo`040001W`6O0003Ool00`000Il00003Ool00`000Il00003Ool010000Il1W`00
0goo00<0006O00000goo00@0006O0Il000=oo`030001W`0000=oo`030001W`0000=oo`040001W`6O
0003Ool00`000Il00003Ool010000Il1W`00@goo000NOol00`00Oomoo`2TOol01000O01l00000goo
00<007`000000goo00@007`0O00000=oo`03001l000000=oo`04001l07`00002Ool01000O01l0000
0goo00<007`000000goo00@007`0O00000=oo`03001l000000=oo`04001l07`00002Ool01000O01l
00000goo00<007`000000goo00@007`0O00000=oo`03001l000000=oo`04001l07`0001HOol01000
0Il1W`003goo00@0006O0Il000=oo`030001W`0000=oo`040001W`6O0003Ool00`000Il00003Ool0
0`000Il00003Ool010000Il1W`000goo00<0006O00000goo00@0006O0Il000=oo`030001W`0000=o
o`030001W`0000=oo`040001W`6O0003Ool00`000Il00003Ool010000Il1W`00@goo000NOol00`00
Oomoo`2TOol01000O01l00000goo00<007`000000goo00@007`0O00000=oo`03001l000000=oo`04
001l07`00002Ool01000O01l00000goo00<007`000000goo00@007`0O00000=oo`03001l000000=o
o`04001l07`00002Ool01000O01l00000goo00<007`000000goo00@007`0O00000=oo`03001l0000
00=oo`04001l07`0001HOol4000?Ool010000Il1W`000goo00<0006O00000goo00@0006O0Il000=o
o`030001W`0000=oo`030001W`0000=oo`040001W`6O0003Ool00`000Il00003Ool010000Il1W`00
0goo00<0006O00000goo00<0006O00000goo00@0006O0Il000=oo`030001W`0000=oo`@004=oo`00
7Woo00<007ooOol0Y7oo00@007`0O00000=oo`03001l000000=oo`04001l07`00003Ool00`00O000
0003Ool01000O01l00000Woo00@007`0O00000=oo`03001l000000=oo`04001l07`00003Ool00`00
O0000003Ool01000O01l00000Woo00@007`0O00000=oo`03001l000000=oo`04001l07`00003Ool0
0`00O0000003Ool01000O01l0000Jgoo00@0006O0Il000=oo`030001W`0000=oo`040001W`6O0003
Ool00`000Il00003Ool00`000Il00003Ool010000Il1W`000goo00<0006O00000goo00@0006O0Il0
00=oo`030001W`0000=oo`030001W`0000=oo`040001W`6O0003Ool00`000Il0001:Ool001ioo`03
001oogoo0:Aoo`04001l07`00003Ool00`00O0000003Ool01000O01l00000goo00<007`000000goo
00@007`0O000009oo`04001l07`00003Ool00`00O0000003Ool01000O01l00000goo00<007`00000
0goo00@007`0O000009oo`04001l07`00003Ool00`00O0000003Ool01000O01l00000goo00<007`0
00000goo00@007`0O00006]oo`040001W`6O0003Ool00`000Il00003Ool010000Il1W`000goo00<0
006O00000goo00<0006O00000goo00@0006O0Il000=oo`030001W`0000=oo`040001W`6O0003Ool0
0`000Il00003Ool00`000Il00003Ool010000Il1W`000goo00<0006O0000BWoo000NOol00`00Oomo
o`2TOol01000O01l00000goo00<007`000000goo00@007`0O00000=oo`03001l000000=oo`04001l
07`00002Ool01000O01l00000goo00<007`000000goo00@007`0O00000=oo`03001l000000=oo`04
001l07`00002Ool01000O01l00000goo00<007`000000goo00@007`0O00000=oo`03001l000000=o
o`04001l07`0001[Ool010000Il1W`000goo00<0006O00000goo00@0006O0Il000=oo`030001W`00
00=oo`030001W`0000=oo`040001W`6O0003Ool00`000Il00003Ool010000Il1W`000goo00<0006O
00000goo00<0006O00000goo00@0006O0Il000=oo`030001W`0004Yoo`007Woo00<007ooOol0Y7oo
00@007`0O00000=oo`03001l000000=oo`04001l07`00003Ool00`00O0000003Ool01000O01l0000
0Woo00@007`0O00000=oo`03001l000000=oo`04001l07`00003Ool00`00O0000003Ool01000O01l
00000Woo00@007`0O00000=oo`03001l000000=oo`04001l07`00003Ool00`00O0000003Ool01000
O01l0000Jgoo00@0006O0Il000=oo`030001W`0000=oo`040001W`6O0003Ool00`000Il00003Ool0
0`000Il00003Ool010000Il1W`000goo00<0006O00000goo00@0006O0Il000=oo`030001W`0000=o
o`030001W`0000=oo`040001W`6O0003Ool00`000Il0001:Ool001ioo`03001oogoo0:Aoo`04001l
07`00003Ool00`00O0000003Ool01000O01l00000goo00<007`000000goo00@007`0O000009oo`04
001l07`00003Ool00`00O0000003Ool01000O01l00000goo00<007`000000goo00@007`0O000009o
o`04001l07`00003Ool00`00O0000003Ool01000O01l00000goo00<007`000000goo00@007`0O000
06]oo`040001W`6O0003Ool00`000Il00003Ool010000Il1W`000goo00<0006O00000goo00<0006O
00000goo00@0006O0Il000=oo`030001W`0000=oo`040001W`6O0003Ool00`000Il00003Ool00`00
0Il00003Ool010000Il1W`000goo00<0006O0000BWoo000NOol00`00Oomoo`2TOol01000O01l0000
0goo00<007`000000goo00@007`0O00000=oo`03001l000000=oo`04001l07`00002Ool01000O01l
00000goo00<007`000000goo00@007`0O00000=oo`03001l000000=oo`04001l07`00002Ool01000
O01l00000goo00<007`000000goo00@007`0O00000=oo`03001l000000=oo`04001l07`0001[Ool0
10000Il1W`000goo00<0006O00000goo00@0006O0Il000=oo`030001W`0000=oo`030001W`0000=o
o`040001W`6O0003Ool00`000Il00003Ool010000Il1W`000goo00<0006O00000goo00<0006O0000
0goo00@0006O0Il000=oo`030001W`0004Yoo`007Woo00<007ooOol0Y7oo00@007`0O00000=oo`03
001l000000=oo`04001l07`00003Ool00`00O0000003Ool01000O01l00000Woo00@007`0O00000=o
o`03001l000000=oo`04001l07`00003Ool00`00O0000003Ool01000O01l00000Woo00@007`0O000
00=oo`03001l000000=oo`04001l07`00003Ool00`00O0000003Ool01000O01l0000Jgoo00@0006O
0Il000=oo`030001W`0000=oo`040001W`6O0003Ool00`000Il00003Ool00`000Il00003Ool01000
0Il1W`000goo00<0006O00000goo00@0006O0Il000=oo`030001W`0000=oo`030001W`0000=oo`04
0001W`6O0003Ool00`000Il0001:Ool001ioo`03001oogoo0:Aoo`04001l07`00003Ool00`00O000
0003Ool01000O01l00000goo00<007`000000goo00@007`0O000009oo`04001l07`00003Ool00`00
O0000003Ool01000O01l00000goo00<007`000000goo00@007`0O000009oo`04001l07`00003Ool0
0`00O0000003Ool01000O01l00000goo00<007`000000goo00@007`0O00006]oo`040001W`6O0003
Ool00`000Il00003Ool010000Il1W`000goo00<0006O00000goo00<0006O00000goo00@0006O0Il0
00=oo`030001W`0000=oo`040001W`6O0003Ool00`000Il00003Ool00`000Il00003Ool010000Il1
W`000goo00<0006O0000BWoo000NOol00`00Oomoo`2TOol01000O01l00000goo00<007`000000goo
00@007`0O00000=oo`03001l000000=oo`04001l07`00002Ool01000O01l00000goo00<007`00000
0goo00@007`0O00000=oo`03001l000000=oo`04001l07`00002Ool01000O01l00000goo00<007`0
00000goo00@007`0O00000=oo`03001l000000=oo`04001l07`0001[Ool010000Il1W`000goo00<0
006O00000goo00@0006O0Il000=oo`030001W`0000=oo`030001W`0000=oo`040001W`6O0003Ool0
0`000Il00003Ool010000Il1W`000goo00<0006O00000goo00<0006O00000goo00@0006O0Il000=o
o`030001W`0004Yoo`007Woo0`00Y7oo10000goo00<007`000000goo00@007`0O00000=oo`03001l
000000=oo`04001l07`00002Ool01000O01l00000goo00<007`000000goo00@007`0O00000=oo`03
001l000000=oo`04001l07`00002Ool01000O01l00000goo00<007`000000goo00@007`0O00000=o
o`03001l000000=oo`@006]oo`040001W`6O0003Ool00`000Il00003Ool010000Il1W`000goo00<0
006O00000goo00<0006O00000goo00@0006O0Il000=oo`030001W`0000=oo`040001W`6O0003Ool0
0`000Il00003Ool00`000Il00003Ool010000Il1W`000goo00<0006O0000BWoo000NOol00`00Oomo
o`2[Ool00`00O0000003Ool01000O01l00000goo00<007`000000goo00@007`0O000009oo`04001l
07`00003Ool00`00O0000003Ool01000O01l00000goo00<007`000000goo00@007`0O000009oo`04
001l07`00003Ool00`00O0000003Ool01000O01l00000goo00<007`00000LWoo00@0006O0Il000=o
o`030001W`0000=oo`040001W`6O0003Ool00`000Il00003Ool00`000Il00003Ool010000Il1W`00
0goo00<0006O00000goo00@0006O0Il000=oo`030001W`0000=oo`030001W`0000=oo`040001W`6O
0003Ool00`000Il0001:Ool001ioo`03001oogoo0:]oo`03001l000000=oo`04001l07`00003Ool0
0`00O0000003Ool01000O01l00000Woo00@007`0O00000=oo`03001l000000=oo`04001l07`00003
Ool00`00O0000003Ool01000O01l00000Woo00@007`0O00000=oo`03001l000000=oo`04001l07`0
0003Ool00`00O000001bOol010000Il1W`000goo00<0006O00000goo00@0006O0Il000=oo`030001
W`0000=oo`030001W`0000=oo`040001W`6O0003Ool00`000Il00003Ool010000Il1W`000goo00<0
006O00000goo00<0006O00000goo00@0006O0Il000=oo`030001W`0004Yoo`007Woo00<007ooOol0
Zgoo00<007`000000goo00@007`0O00000=oo`03001l000000=oo`04001l07`00002Ool01000O01l
00000goo00<007`000000goo00@007`0O00000=oo`03001l000000=oo`04001l07`00002Ool01000
O01l00000goo00<007`000000goo00@007`0O00000=oo`03001l0000079oo`040001W`6O0003Ool0
0`000Il00003Ool010000Il1W`000goo00<0006O00000goo00<0006O00000goo00@0006O0Il000=o
o`030001W`0000=oo`040001W`6O0003Ool00`000Il00003Ool00`000Il00003Ool010000Il1W`00
0goo00<0006O0000BWoo000NOol00`00Oomoo`2[Ool00`00O0000003Ool01000O01l00000goo00<0
07`000000goo00@007`0O000009oo`04001l07`00003Ool00`00O0000003Ool01000O01l00000goo
00<007`000000goo00@007`0O000009oo`04001l07`00003Ool00`00O0000003Ool01000O01l0000
0goo00<007`00000LWoo00@0006O0Il000=oo`030001W`0000=oo`040001W`6O0003Ool00`000Il0
0003Ool00`000Il00003Ool010000Il1W`000goo00<0006O00000goo00@0006O0Il000=oo`030001
W`0000=oo`030001W`0000=oo`040001W`6O0003Ool00`000Il0001:Ool001ioo`03001oogoo0:]o
o`03001l000000=oo`04001l07`00003Ool00`00O0000003Ool01000O01l00000Woo00@007`0O000
00=oo`03001l000000=oo`04001l07`00003Ool00`00O0000003Ool01000O01l00000Woo00@007`0
O00000=oo`03001l000000=oo`04001l07`00003Ool00`00O000001bOol010000Il1W`000goo00<0
006O00000goo00@0006O0Il000=oo`030001W`0000=oo`030001W`0000=oo`040001W`6O0003Ool0
0`000Il00003Ool010000Il1W`000goo00<0006O00000goo00<0006O00000goo00@0006O0Il000=o
o`030001W`0004Yoo`007Woo00<007ooOol0Zgoo00<007`000000goo00@007`0O00000=oo`03001l
000000=oo`04001l07`00002Ool01000O01l00000goo00<007`000000goo00@007`0O00000=oo`03
001l000000=oo`04001l07`00002Ool01000O01l00000goo00<007`000000goo00@007`0O00000=o
o`03001l0000079oo`040001W`6O0003Ool00`000Il00003Ool010000Il1W`000goo00<0006O0000
0goo00<0006O00000goo00@0006O0Il000=oo`030001W`0000=oo`040001W`6O0003Ool00`000Il0
0003Ool00`000Il00003Ool010000Il1W`000goo00<0006O0000BWoo000NOol00`00Oomoo`2[Ool0
0`00O0000003Ool01000O01l00000goo00<007`000000goo00@007`0O000009oo`04001l07`00003
Ool00`00O0000003Ool01000O01l00000goo00<007`000000goo00@007`0O000009oo`04001l07`0
0003Ool00`00O0000003Ool01000O01l00000goo00<007`00000LWoo00@0006O0Il000=oo`030001
W`0000=oo`040001W`6O0003Ool00`000Il00003Ool00`000Il00003Ool010000Il1W`000goo00<0
006O00000goo00@0006O0Il000=oo`030001W`0000=oo`030001W`0000=oo`040001W`6O0003Ool0
0`000Il0001:Ool001ioo`03001oogoo0:]oo`03001l000000=oo`04001l07`00003Ool00`00O000
0003Ool01000O01l00000Woo00@007`0O00000=oo`03001l000000=oo`04001l07`00003Ool00`00
O0000003Ool01000O01l00000Woo00@007`0O00000=oo`03001l000000=oo`04001l07`00003Ool0
0`00O000001bOol010000Il1W`000goo00<0006O00000goo00@0006O0Il000=oo`030001W`0000=o
o`030001W`0000=oo`040001W`6O0003Ool00`000Il00003Ool010000Il1W`000goo00<0006O0000
0goo00<0006O00000goo00@0006O0Il000=oo`030001W`0004Yoo`007Woo00<007ooOol0Zgoo00<0
07`000000goo00@007`0O00000=oo`03001l000000=oo`04001l07`00002Ool01000O01l00000goo
00<007`000000goo00@007`0O00000=oo`03001l000000=oo`04001l07`00002Ool01000O01l0000
0goo00<007`000000goo00@007`0O00000=oo`03001l0000079oo`040001W`6O0003Ool00`000Il0
0003Ool010000Il1W`000goo00<0006O00000goo00<0006O00000goo00@0006O0Il000=oo`030001
W`0000=oo`040001W`6O0003Ool00`000Il00003Ool00`000Il00003Ool010000Il1W`000goo00<0
006O0000BWoo000NOol00`00Oomoo`2[Ool00`00O0000003Ool01000O01l00000goo00<007`00000
0goo00@007`0O000009oo`04001l07`00003Ool00`00O0000003Ool01000O01l00000goo00<007`0
00000goo00@007`0O000009oo`04001l07`00003Ool00`00O0000003Ool01000O01l00000goo00<0
07`00000LWoo00@0006O0Il000=oo`030001W`0000=oo`040001W`6O0003Ool00`000Il00003Ool0
0`000Il00003Ool010000Il1W`000goo00<0006O00000goo00@0006O0Il000=oo`030001W`0000=o
o`030001W`0000=oo`040001W`6O0003Ool00`000Il0001:Ool001ioo`03001oogoo0:]oo`03001l
000000=oo`04001l07`00003Ool00`00O0000003Ool01000O01l00000Woo00@007`0O00000=oo`03
001l000000=oo`04001l07`00003Ool00`00O0000003Ool01000O01l00000Woo00@007`0O00000=o
o`03001l000000=oo`04001l07`00003Ool00`00O000001bOol010000Il1W`000goo00<0006O0000
0goo00@0006O0Il000=oo`030001W`0000=oo`030001W`0000=oo`040001W`6O0003Ool00`000Il0
0003Ool010000Il1W`000goo00<0006O00000goo00<0006O00000goo00@0006O0Il000=oo`030001
W`0004Yoo`007Woo00<007ooOol0Zgoo00<007`000000goo00@007`0O00000=oo`03001l000000=o
o`04001l07`00002Ool01000O01l00000goo00<007`000000goo00@007`0O00000=oo`03001l0000
00=oo`04001l07`00002Ool01000O01l00000goo00<007`000000goo00@007`0O00000=oo`<0079o
o`040001W`6O0003Ool00`000Il00003Ool010000Il1W`000goo00<0006O00000goo00<0006O0000
0goo00@0006O0Il000=oo`030001W`0000=oo`040001W`6O0003Ool00`000Il00003Ool00`000Il0
0003Ool010000Il1W`000goo00<0006O0000BWoo000NOol00`00Oomoo`2[Ool00`00O0000003Ool0
1000O01l00000goo00<007`000000goo00@007`0O000009oo`04001l07`00003Ool00`00O0000003
Ool01000O01l00000goo00<007`000000goo00@007`0O000009oo`04001l07`00003Ool00`00O000
0003Ool01000O01l0000N7oo00@0006O0Il000=oo`030001W`0000=oo`040001W`6O0003Ool00`00
0Il00003Ool00`000Il00003Ool010000Il1W`000goo00<0006O00000goo00@0006O0Il000=oo`03
0001W`0000=oo`030001W`0000=oo`040001W`6O0003Ool00`000Il0001:Ool001ioo`03001oogoo
0:]oo`03001l000000=oo`04001l07`00003Ool00`00O0000003Ool01000O01l00000Woo00@007`0
O00000=oo`03001l000000=oo`04001l07`00003Ool00`00O0000003Ool01000O01l00000Woo00@0
07`0O00000=oo`03001l000000=oo`04001l07`0001hOol010000Il1W`000goo00<0006O00000goo
00@0006O0Il000=oo`030001W`0000=oo`030001W`0000=oo`040001W`6O0003Ool00`000Il00003
Ool010000Il1W`000goo00<0006O00000goo00<0006O00000goo00@0006O0Il000=oo`030001W`00
04Yoo`007Woo0`00Zgoo00<007`000000goo00@007`0O00000=oo`03001l000000=oo`04001l07`0
0002Ool01000O01l00000goo00<007`000000goo00@007`0O00000=oo`03001l000000=oo`04001l
07`00002Ool01000O01l00000goo00<007`000000goo00@007`0O00007Qoo`040001W`6O0003Ool0
0`000Il00003Ool010000Il1W`000goo00<0006O00000goo00<0006O00000goo00@0006O0Il000=o
o`030001W`0000=oo`040001W`6O0003Ool00`000Il00003Ool00`000Il00003Ool010000Il1W`00
0goo00<0006O0000BWoo000NOol00`00Oomoo`2[Ool00`00O0000003Ool01000O01l00000goo00<0
07`000000goo00@007`0O000009oo`04001l07`00003Ool00`00O0000003Ool01000O01l00000goo
00<007`000000goo00@007`0O000009oo`04001l07`00003Ool00`00O0000003Ool01000O01l0000
N7oo00@0006O0Il000=oo`030001W`0000=oo`040001W`6O0003Ool00`000Il00003Ool00`000Il0
0003Ool010000Il1W`000goo00<0006O00000goo00@0006O0Il000=oo`030001W`0000=oo`030001
W`0000=oo`040001W`6O0003Ool00`000Il0001:Ool001ioo`03001oogoo0:]oo`03001l000000=o
o`04001l07`00003Ool00`00O0000003Ool01000O01l00000Woo00@007`0O00000=oo`03001l0000
00=oo`04001l07`00003Ool00`00O0000003Ool01000O01l00000Woo00@007`0O00000=oo`03001l
000000=oo`04001l07`0001hOol010000Il1W`000goo00<0006O00000goo00@0006O0Il000=oo`03
0001W`0000=oo`030001W`0000=oo`040001W`6O0003Ool00`000Il00003Ool010000Il1W`000goo
00<0006O00000goo00<0006O00000goo00@0006O0Il000=oo`030001W`0004Yoo`007Woo00<007oo
Ool0Zgoo00<007`000000goo00@007`0O00000=oo`03001l000000=oo`04001l07`00002Ool01000
O01l00000goo00<007`000000goo00@007`0O00000=oo`03001l000000=oo`04001l07`00002Ool0
1000O01l00000goo00<007`000000goo00@007`0O00007Qoo`040001W`6O0003Ool00`000Il00003
Ool010000Il1W`000goo00<0006O00000goo00<0006O00000goo00@0006O0Il000=oo`030001W`00
00=oo`040001W`6O0003Ool00`000Il00003Ool00`000Il00003Ool010000Il1W`000goo00<0006O
0000BWoo000NOol00`00Oomoo`2[Ool00`00O0000003Ool01000O01l00000goo00<007`000000goo
00@007`0O000009oo`04001l07`00003Ool00`00O0000003Ool01000O01l00000goo00<007`00000
0goo00@007`0O000009oo`04001l07`00003Ool00`00O0000003Ool01000O01l0000N7oo00@0006O
0Il000=oo`030001W`0000=oo`040001W`6O0003Ool00`000Il00003Ool00`000Il00003Ool01000
0Il1W`000goo00<0006O00000goo00@0006O0Il000=oo`030001W`0000=oo`030001W`0000=oo`04
0001W`6O0003Ool00`000Il0001:Ool001ioo`03001oogoo0:]oo`03001l000000=oo`04001l07`0
0003Ool00`00O0000003Ool01000O01l00000Woo00@007`0O00000=oo`03001l000000=oo`04001l
07`00003Ool00`00O0000003Ool01000O01l00000Woo00@007`0O00000=oo`03001l000000=oo`04
001l07`0001hOol010000Il1W`000goo00<0006O00000goo00@0006O0Il000=oo`030001W`0000=o
o`030001W`0000=oo`040001W`6O0003Ool00`000Il00003Ool010000Il1W`000goo00<0006O0000
0goo00<0006O00000goo00@0006O0Il000=oo`030001W`0004Yoo`007Woo00<007ooOol0Zgoo00<0
07`000000goo00@007`0O00000=oo`03001l000000=oo`04001l07`00002Ool01000O01l00000goo
00<007`000000goo00@007`0O00000=oo`03001l000000=oo`04001l07`00002Ool01000O01l0000
0goo00<007`000000goo00@007`0O00007Qoo`040001W`6O0003Ool00`000Il00003Ool010000Il1
W`000goo00<0006O00000goo00<0006O00000goo00@0006O0Il000=oo`030001W`0000=oo`040001
W`6O0003Ool00`000Il00003Ool00`000Il00003Ool010000Il1W`000goo00<0006O0000BWoo000N
Ool00`00Oomoo`2[Ool00`00O0000003Ool01000O01l00000goo00<007`000000goo00@007`0O000
009oo`04001l07`00003Ool00`00O0000003Ool01000O01l00000goo00<007`000000goo00@007`0
O000009oo`04001l07`00003Ool00`00O0000003Ool4001hOol010000Il1W`000goo00<0006O0000
0goo00@0006O0Il000=oo`030001W`0000=oo`030001W`0000=oo`040001W`6O0003Ool00`000Il0
0003Ool010000Il1W`000goo00<0006O00000goo00<0006O00000goo00@0006O0Il000=oo`030001
W`0004Yoo`007Woo00<007ooOol0Zgoo00<007`000000goo00@007`0O00000=oo`03001l000000=o
o`04001l07`00002Ool01000O01l00000goo00<007`000000goo00@007`0O00000=oo`03001l0000
00=oo`04001l07`00002Ool01000O01l00000goo00<007`00000Ogoo00@0006O0Il000=oo`030001
W`0000=oo`040001W`6O0003Ool00`000Il00003Ool00`000Il00003Ool010000Il1W`000goo00<0
006O00000goo00@0006O0Il000=oo`030001W`0000=oo`030001W`0000=oo`040001W`6O0003Ool0
0`000Il0001:Ool001ioo`03001oogoo0:]oo`03001l000000=oo`04001l07`00003Ool00`00O000
0003Ool01000O01l00000Woo00@007`0O00000=oo`03001l000000=oo`04001l07`00003Ool00`00
O0000003Ool01000O01l00000Woo00@007`0O00000=oo`03001l000007moo`040001W`6O0003Ool0
0`000Il00003Ool010000Il1W`000goo00<0006O00000goo00<0006O00000goo00@0006O0Il000=o
o`030001W`0000=oo`040001W`6O0003Ool00`000Il00003Ool00`000Il00003Ool010000Il1W`00
0goo00<0006O0000BWoo000NOol00`00Oomoo`2[Ool00`00O0000003Ool01000O01l00000goo00<0
07`000000goo00@007`0O000009oo`04001l07`00003Ool00`00O0000003Ool01000O01l00000goo
00<007`000000goo00@007`0O000009oo`04001l07`00003Ool00`00O000001oOol010000Il1W`00
0goo00<0006O00000goo00@0006O0Il000=oo`030001W`0000=oo`030001W`0000=oo`040001W`6O
0003Ool00`000Il00003Ool010000Il1W`000goo00<0006O00000goo00<0006O00000goo00@0006O
0Il000=oo`030001W`0004Yoo`007Woo00<007ooOol0Zgoo00<007`000000goo00@007`0O00000=o
o`03001l000000=oo`04001l07`00002Ool01000O01l00000goo00<007`000000goo00@007`0O000
00=oo`03001l000000=oo`04001l07`00002Ool01000O01l00000goo00<007`00000Ogoo00@0006O
0Il000=oo`030001W`0000=oo`040001W`6O0003Ool00`000Il00003Ool00`000Il00003Ool01000
0Il1W`000goo00<0006O00000goo00@0006O0Il000=oo`030001W`0000=oo`030001W`0000=oo`04
0001W`6O0003Ool00`000Il0001:Ool001ioo`03001oogoo0:]oo`03001l000000=oo`04001l07`0
0003Ool00`00O0000003Ool01000O01l00000Woo00@007`0O00000=oo`03001l000000=oo`04001l
07`00003Ool00`00O0000003Ool01000O01l00000Woo00@007`0O00000=oo`03001l000007moo`04
0001W`6O0003Ool00`000Il00003Ool010000Il1W`000goo00<0006O00000goo00<0006O00000goo
00@0006O0Il000=oo`030001W`0000=oo`040001W`6O0003Ool00`000Il00003Ool00`000Il00003
Ool010000Il1W`000goo00<0006O0000BWoo000NOol00`00Oomoo`2[Ool00`00O0000003Ool01000
O01l00000goo00<007`000000goo00@007`0O000009oo`04001l07`00003Ool00`00O0000003Ool0
1000O01l00000goo00<007`000000goo00@007`0O000009oo`04001l07`00003Ool00`00O000001o
Ool010000Il1W`000goo00<0006O00000goo00@0006O0Il000=oo`030001W`0000=oo`030001W`00
00=oo`040001W`6O0003Ool00`000Il00003Ool010000Il1W`000goo00<0006O00000goo00<0006O
00000goo00@0006O0Il000=oo`030001W`0004Yoo`003Goo0`000goo0P002Goo00<007ooOol0Zgoo
00<007`000000goo00@007`0O00000=oo`03001l000000=oo`04001l07`00002Ool01000O01l0000
0goo00<007`000000goo00@007`0O00000=oo`03001l000000=oo`04001l07`00002Ool01000O01l
00000goo00<007`00000Ogoo00@0006O0Il000=oo`030001W`0000=oo`040001W`6O0003Ool00`00
0Il00003Ool00`000Il00003Ool010000Il1W`000goo00<0006O00000goo00@0006O0Il000=oo`03
0001W`0000=oo`030001W`0000=oo`040001W`6O0003Ool00`000Il0001:Ool000ioo`05001oogoo
Ool00002Ool00`00Oomoo`06Ool00`00Oomoo`2[Ool00`00O0000003Ool01000O01l00000goo00<0
07`000000goo00@007`0O000009oo`04001l07`00003Ool00`00O0000003Ool01000O01l00000goo
00<007`000000goo00@007`0O000009oo`04001l07`00003Ool00`00O000001oOol010000Il1W`00
0goo00<0006O00000goo00@0006O0Il000=oo`030001W`0000=oo`030001W`0000=oo`040001W`6O
0003Ool00`000Il00003Ool010000Il1W`000goo00<0006O00000goo00<0006O00000goo00@0006O
0Il000=oo`030001W`0004Yoo`0037oo10000Woo00@007ooOol000Qoo`@00:Yoo`03001l000000=o
o`04001l07`00003Ool00`00O0000003Ool01000O01l00000Woo00@007`0O00000=oo`03001l0000
00=oo`04001l07`00003Ool00`00O0000003Ool01000O01l00000Woo00@007`0O00000=oo`03001l
000007moo`040001W`6O0003Ool00`000Il00003Ool010000Il1W`000goo00<0006O00000goo00<0
006O00000goo00@0006O0Il000=oo`030001W`0000=oo`040001W`6O0003Ool00`000Il00003Ool0
0`000Il00003Ool010000Il1W`000goo0`00BWoo000<Ool00`00Ool00003Ool01000Oomoo`0027oo
00<007ooOol0Zgoo00<007`000000goo00@007`0O00000=oo`03001l000000=oo`04001l07`00002
Ool01000O01l00000goo00<007`000000goo00@007`0O00000=oo`03001l000000=oo`04001l07`0
0002Ool01000O01l00000goo00<007`00000Ogoo00@0006O0Il000=oo`030001W`0000=oo`040001
W`6O0003Ool00`000Il00003Ool00`000Il00003Ool010000Il1W`000goo00<0006O00000goo00@0
006O0Il000=oo`030001W`0000=oo`030001W`0000=oo`040001W`6O001@Ool000aoo`03001oo`00
00=oo`04001oogoo0008Ool00`00Oomoo`2[Ool00`00O0000003Ool01000O01l00000goo00<007`0
00000goo00@007`0O000009oo`04001l07`00003Ool00`00O0000003Ool01000O01l00000goo00<0
07`000000goo00@007`0O000009oo`04001l07`00003Ool00`00O000001oOol010000Il1W`000goo
00<0006O00000goo00@0006O0Il000=oo`030001W`0000=oo`030001W`0000=oo`040001W`6O0003
Ool00`000Il00003Ool010000Il1W`000goo00<0006O00000goo00<0006O00000goo00@0006O0Il0
051oo`003Goo0P0017oo0P002Goo00<007ooOol0Zgoo00<007`000000goo00@007`0O00000=oo`03
001l000000=oo`04001l07`00002Ool01000O01l00000goo00<007`000000goo00@007`0O00000=o
o`03001l000000=oo`04001l07`00002Ool01000O01l00000goo00<007`00000Ogoo00@0006O0Il0
00=oo`030001W`0000=oo`040001W`6O0003Ool00`000Il00003Ool00`000Il00003Ool010000Il1
W`000goo00<0006O00000goo00@0006O0Il000=oo`030001W`0000=oo`030001W`0000=oo`040001
W`6O001@Ool001ioo`03001oogoo0:]oo`03001l000000=oo`04001l07`00003Ool00`00O0000003
Ool01000O01l00000Woo00@007`0O00000=oo`03001l000000=oo`04001l07`00003Ool00`00O000
0003Ool01000O01l00000Woo00@007`0O00000=oo`03001l000007moo`040001W`6O0003Ool00`00
0Il00003Ool010000Il1W`000goo00<0006O00000goo00<0006O00000goo00@0006O0Il000=oo`03
0001W`0000=oo`040001W`6O0003Ool00`000Il00003Ool00`000Il00003Ool010000Il1W`00D7oo
000NOol00`00Oomoo`2[Ool00`00O0000003Ool01000O01l00000goo00<007`000000goo00@007`0
O000009oo`04001l07`00003Ool00`00O0000003Ool01000O01l00000goo00<007`000000goo00@0
07`0O000009oo`04001l07`00003Ool00`00O000001oOol010000Il1W`000goo00<0006O00000goo
00@0006O0Il000=oo`030001W`0000=oo`030001W`0000=oo`040001W`6O0003Ool00`000Il00003
Ool010000Il1W`000goo00<0006O00000goo00<0006O00000goo00@0006O0Il0051oo`007Woo00<0
07ooOol0Zgoo00<007`000000goo00@007`0O00000=oo`03001l000000=oo`04001l07`00002Ool0
1000O01l00000goo00<007`000000goo00@007`0O00000=oo`03001l000000=oo`04001l07`00002
Ool01000O01l00000goo00<007`00000Ogoo00@0006O0Il000=oo`030001W`0000=oo`040001W`6O
0003Ool00`000Il00003Ool00`000Il00003Ool010000Il1W`000goo00<0006O00000goo00@0006O
0Il000=oo`030001W`0000=oo`030001W`0000=oo`040001W`6O001@Ool001ioo`03001oogoo0:]o
o`03001l000000=oo`04001l07`00003Ool00`00O0000003Ool01000O01l00000Woo00@007`0O000
00=oo`03001l000000=oo`04001l07`00003Ool00`00O0000003Ool01000O01l00000Woo00@007`0
O00000=oo`03001l000007moo`040001W`6O0003Ool00`000Il00003Ool010000Il1W`000goo00<0
006O00000goo00<0006O00000goo00@0006O0Il000=oo`030001W`0000=oo`040001W`6O0003Ool0
0`000Il00003Ool00`000Il00003Ool010000Il1W`00D7oo000NOol00`00Oomoo`2[Ool00`00O000
0003Ool01000O01l00000goo00<007`000000goo00@007`0O000009oo`04001l07`00003Ool00`00
O0000003Ool01000O01l00000goo00<007`000000goo00@007`0O000009oo`04001l07`00003Ool0
0`00O000001oOol010000Il1W`000goo00<0006O00000goo00@0006O0Il000=oo`030001W`0000=o
o`030001W`0000=oo`040001W`6O0003Ool00`000Il00003Ool010000Il1W`000goo00<0006O0000
0goo00<0006O00000goo00@0006O0Il0051oo`007Woo00<007ooOol0Zgoo00<007`000000goo00@0
07`0O00000=oo`03001l000000=oo`04001l07`00002Ool01000O01l00000goo00<007`000000goo
00@007`0O00000=oo`03001l000000=oo`04001l07`00002Ool01000O01l00000goo00<007`00000
Ogoo00@0006O0Il000=oo`030001W`0000=oo`040001W`6O0003Ool00`000Il00003Ool00`000Il0
0003Ool010000Il1W`000goo00<0006O00000goo00@0006O0Il000=oo`030001W`0000=oo`030001
W`0000=oo`040001W`6O001@Ool001ioo`03001oogoo0:]oo`03001l000000=oo`04001l07`00003
Ool00`00O0000003Ool01000O01l00000Woo00@007`0O00000=oo`03001l000000=oo`04001l07`0
0003Ool00`00O0000003Ool01000O01l00000Woo00@007`0O00000=oo`03001l000007moo`040001
W`6O0003Ool00`000Il00003Ool010000Il1W`000goo00<0006O00000goo00<0006O00000goo00@0
006O0Il000=oo`030001W`0000=oo`040001W`6O0003Ool00`000Il00003Ool00`000Il00003Ool0
10000Il1W`00D7oo000NOol00`00Oomoo`2[Ool00`00O0000003Ool01000O01l00000goo00<007`0
00000goo00@007`0O000009oo`04001l07`00003Ool00`00O0000003Ool01000O01l00000goo00<0
07`000000goo00@007`0O000009oo`04001l07`00003Ool00`00O000001oOol010000Il1W`000goo
00<0006O00000goo00@0006O0Il000=oo`030001W`0000=oo`030001W`0000=oo`040001W`6O0003
Ool00`000Il00003Ool010000Il1W`000goo00<0006O00000goo00<0006O00000goo00@0006O0Il0
051oo`007Woo00<007ooOol0Zgoo00<007`000000goo00@007`0O00000=oo`03001l000000=oo`04
001l07`00002Ool01000O01l00000goo00<007`000000goo00@007`0O00000=oo`03001l000000=o
o`04001l07`00002Ool01000O01l00000goo00<007`00000Ogoo00@0006O0Il000=oo`030001W`00
00=oo`040001W`6O0003Ool00`000Il00003Ool00`000Il00003Ool010000Il1W`000goo00<0006O
00000goo00@0006O0Il000=oo`030001W`0000=oo`030001W`0000=oo`040001W`6O001@Ool001io
o`03001oogoo0:]oo`03001l000000=oo`04001l07`00003Ool30003Ool01000O01l00000Woo00@0
07`0O00000=oo`03001l000000=oo`04001l07`00003Ool00`00O0000003Ool01000O01l00000Woo
00@007`0O00000=oo`03001l000007moo`040001W`6O0003Ool00`000Il00003Ool010000Il1W`00
0goo00<0006O00000goo00<0006O00000goo00@0006O0Il000=oo`030001W`0000=oo`040001W`6O
0003Ool00`000Il00003Ool00`000Il00003Ool010000Il1W`00D7oo000NOol00`00Oomoo`2[Ool0
0`00O0000003Ool01000O01l00002Goo00@007`0O000009oo`04001l07`00003Ool00`00O0000003
Ool01000O01l00000goo00<007`000000goo00@007`0O000009oo`04001l07`00003Ool00`00O000
001oOol010000Il1W`000goo00<0006O00000goo00@0006O0Il000=oo`030001W`0000=oo`030001
W`0000=oo`040001W`6O0003Ool00`000Il00003Ool010000Il1W`000goo00<0006O00000goo00<0
006O00000goo00@0006O0Il0051oo`007Woo00<007ooOol0Zgoo00<007`000000goo00@007`0O000
00Uoo`04001l07`00002Ool01000O01l00000goo00<007`000000goo00@007`0O00000=oo`03001l
000000=oo`04001l07`00002Ool01000O01l00000goo00<007`00000Ogoo00@0006O0Il000=oo`03
0001W`0000=oo`040001W`6O0003Ool00`000Il00003Ool00`000Il00003Ool010000Il1W`000goo
00<0006O00000goo00@0006O0Il000=oo`030001W`0000=oo`030001W`0000=oo`040001W`6O001@
Ool001ioo`<00:]oo`03001l000000=oo`04001l07`00009Ool01000O01l00000Woo00@007`0O000
00=oo`03001l000000=oo`04001l07`00003Ool00`00O0000003Ool01000O01l00000Woo00@007`0
O00000=oo`03001l000007moo`040001W`6O0003Ool00`000Il00003Ool010000Il1W`000goo00<0
006O00000goo00<0006O00000goo00@0006O0Il000=oo`030001W`0000=oo`040001W`6O0003Ool0
0`000Il00003Ool00`000Il00003Ool010000Il1W`00D7oo000NOol00`00Oomoo`2[Ool00`00O000
0003Ool01000O01l00002Goo00@007`0O000009oo`04001l07`00003Ool00`00O0000003Ool01000
O01l00000goo00<007`000000goo00@007`0O000009oo`04001l07`00003Ool00`00O000001oOol0
10000Il1W`000goo00<0006O00000goo00@0006O0Il000=oo`030001W`0000=oo`030001W`0000=o
o`040001W`6O0003Ool00`000Il00003Ool010000Il1W`000goo00<0006O00000goo00<0006O0000
0goo00@0006O0Il0051oo`007Woo00<007ooOol0Zgoo00<007`000000goo00@007`0O00000Uoo`04
001l07`00002Ool01000O01l00000goo00<007`000000goo00@007`0O00000=oo`03001l000000=o
o`04001l07`00002Ool01000O01l00000goo00<007`00000Ogoo00@0006O0Il000=oo`030001W`00
00=oo`040001W`6O0003Ool00`000Il00003Ool00`000Il00003Ool010000Il1W`000goo00<0006O
00000goo00@0006O0Il000=oo`030001W`0000=oo`030001W`0000=oo`040001W`6O001@Ool001io
o`03001oogoo0:]oo`03001l000000=oo`04001l07`00009Ool01000O01l00000Woo00@007`0O000
00=oo`03001l000000=oo`04001l07`00003Ool00`00O0000003Ool01000O01l00000Woo00@007`0
O00000=oo`03001l000007moo`040001W`6O0003Ool00`000Il00003Ool010000Il1W`000goo00<0
006O00000goo00<0006O00000goo00@0006O0Il000=oo`030001W`0000=oo`040001W`6O0003Ool0
0`000Il00003Ool00`000Il00003Ool4001@Ool001ioo`03001oogoo0:]oo`03001l000000=oo`04
001l07`00009Ool01000O01l00000Woo00@007`0O00000=oo`03001l000000=oo`04001l07`00003
Ool00`00O0000003Ool01000O01l00000Woo00@007`0O00000=oo`03001l000007moo`040001W`6O
0003Ool00`000Il00003Ool010000Il1W`000goo00<0006O00000goo00<0006O00000goo00@0006O
0Il000=oo`030001W`0000=oo`040001W`6O0003Ool00`000Il00003Ool00`000Il0001GOol001io
o`03001oogoo0:]oo`03001l000000=oo`04001l07`00009Ool01000O01l00000Woo00@007`0O000
00=oo`03001l000000=oo`04001l07`00003Ool00`00O0000003Ool01000O01l00000Woo00@007`0
O00000=oo`03001l000007moo`040001W`6O0003Ool00`000Il00003Ool010000Il1W`000goo00<0
006O00000goo00<0006O00000goo00@0006O0Il000=oo`030001W`0000=oo`040001W`6O0003Ool0
0`000Il00003Ool00`000Il0001GOol001ioo`03001oogoo0:]oo`03001l000000=oo`@000Uoo`04
001l07`00002Ool01000O01l00000goo00<007`000000goo00@007`0O00000=oo`03001l000000=o
o`04001l07`00002Ool01000O01l00000goo00<007`00000Ogoo00@0006O0Il000=oo`030001W`00
00=oo`040001W`6O0003Ool00`000Il00003Ool00`000Il00003Ool010000Il1W`000goo00<0006O
00000goo00@0006O0Il000=oo`030001W`0000=oo`030001W`0005Moo`007Woo00<007ooOol0Zgoo
00<007`0000047oo00@007`0O000009oo`04001l07`00003Ool00`00O0000003Ool01000O01l0000
0goo00<007`000000goo00@007`0O000009oo`04001l07`00003Ool00`00O000001oOol010000Il1
W`000goo00<0006O00000goo00@0006O0Il000=oo`030001W`0000=oo`030001W`0000=oo`040001
W`6O0003Ool00`000Il00003Ool010000Il1W`000goo00<0006O00000goo00<0006O0000Egoo000N
Ool00`00Oomoo`2[Ool00`00O000000@Ool01000O01l00000Woo00@007`0O00000=oo`03001l0000
00=oo`04001l07`00003Ool00`00O0000003Ool01000O01l00000Woo00@007`0O00000=oo`03001l
000007moo`040001W`6O0003Ool00`000Il00003Ool010000Il1W`000goo00<0006O00000goo00<0
006O00000goo00@0006O0Il000=oo`030001W`0000=oo`040001W`6O0003Ool00`000Il00003Ool0
0`000Il0001GOol001ioo`03001oogoo0:]oo`03001l0000011oo`04001l07`00002Ool01000O01l
00000goo00<007`000000goo00@007`0O00000=oo`03001l000000=oo`04001l07`00002Ool01000
O01l00000goo00<007`00000Ogoo00@0006O0Il000=oo`030001W`0000=oo`040001W`6O0003Ool0
0`000Il00003Ool00`000Il00003Ool010000Il1W`000goo00<0006O00000goo00@0006O0Il000=o
o`030001W`0000=oo`030001W`0005Moo`007Woo00<007ooOol0Zgoo00<007`0000047oo00@007`0
O000009oo`04001l07`00003Ool00`00O0000003Ool01000O01l00000goo00<007`000000goo00@0
07`0O000009oo`04001l07`00003Ool00`00O000001oOol010000Il1W`000goo00<0006O00000goo
00@0006O0Il000=oo`030001W`0000=oo`030001W`0000=oo`040001W`6O0003Ool00`000Il00003
Ool010000Il1W`000goo00<0006O00000goo00<0006O0000Egoo000NOol00`00Oomoo`2[Ool00`00
O000000@Ool01000O01l00000Woo00@007`0O00000=oo`03001l000000=oo`04001l07`00003Ool0
0`00O0000003Ool01000O01l00000Woo00@007`0O00000=oo`03001l000007moo`040001W`6O0003
Ool00`000Il00003Ool010000Il1W`000goo00<0006O00000goo00<0006O00000goo00@0006O0Il0
00=oo`030001W`0000=oo`040001W`6O0003Ool00`000Il00003Ool00`000Il0001GOol001ioo`03
001oogoo0:]oo`03001l0000011oo`04001l07`00002Ool01000O01l00000goo00<007`000000goo
00@007`0O00000=oo`03001l000000=oo`04001l07`00002Ool01000O01l00000goo00<007`00000
Ogoo00@0006O0Il000=oo`030001W`0000=oo`040001W`6O0003Ool00`000Il00003Ool00`000Il0
0003Ool010000Il1W`000goo00<0006O00000goo00@0006O0Il000=oo`030001W`0000=oo`030001
W`0005Moo`007Woo00<007ooOol0Zgoo0`0047oo00@007`0O000009oo`04001l07`00003Ool00`00
O0000003Ool01000O01l00000goo00<007`000000goo00@007`0O000009oo`04001l07`00003Ool0
0`00O000001oOol40003Ool00`000Il00003Ool010000Il1W`000goo00<0006O00000goo00<0006O
00000goo00@0006O0Il000=oo`030001W`0000=oo`040001W`6O0003Ool00`000Il00003Ool00`00
0Il0001GOol001ioo`03001oogoo0;ioo`04001l07`00002Ool01000O01l00000goo00<007`00000
0goo00@007`0O00000=oo`03001l000000=oo`04001l07`00002Ool01000O01l00000goo00<007`0
0000QWoo00<0006O00000goo00@0006O0Il000=oo`030001W`0000=oo`030001W`0000=oo`040001
W`6O0003Ool00`000Il00003Ool010000Il1W`000goo00<0006O00000goo00<0006O0000Egoo000N
Ool00`00Oomoo`2nOol01000O01l00000Woo00@007`0O00000=oo`03001l000000=oo`04001l07`0
0003Ool00`00O0000003Ool01000O01l00000Woo00@007`0O00000=oo`03001l000008Ioo`030001
W`0000=oo`040001W`6O0003Ool00`000Il00003Ool00`000Il00003Ool010000Il1W`000goo00<0
006O00000goo00@0006O0Il000=oo`030001W`0000=oo`030001W`0005Moo`007Woo0`00_Woo00@0
07`0O000009oo`04001l07`00003Ool00`00O0000003Ool01000O01l00000goo00<007`000000goo
00@007`0O000009oo`04001l07`00003Ool00`00O0000026Ool00`000Il00003Ool010000Il1W`00
0goo00<0006O00000goo00<0006O00000goo00@0006O0Il000=oo`030001W`0000=oo`040001W`6O
0003Ool00`000Il00003Ool00`000Il0001GOol001ioo`03001oogoo0;ioo`04001l07`00002Ool0
1000O01l00000goo00<007`000000goo00@007`0O00000=oo`03001l000000=oo`04001l07`00002
Ool01000O01l00000goo00<007`00000QWoo00<0006O00000goo00@0006O0Il000=oo`030001W`00
00=oo`030001W`0000=oo`040001W`6O0003Ool00`000Il00003Ool010000Il1W`000goo00<0006O
00000goo00<0006O0000Egoo000NOol00`00Oomoo`2nOol01000O01l00000Woo00@007`0O00000=o
o`03001l000000=oo`04001l07`00003Ool00`00O0000003Ool01000O01l00000Woo00@007`0O000
00=oo`03001l000008Ioo`030001W`0000=oo`040001W`6O0003Ool00`000Il00003Ool00`000Il0
0003Ool010000Il1W`000goo00<0006O00000goo00@0006O0Il000=oo`030001W`0000=oo`030001
W`0005Moo`007Woo00<007ooOol0_Woo00@007`0O000009oo`04001l07`00003Ool00`00O0000003
Ool01000O01l00000goo00<007`000000goo00@007`0O000009oo`04001l07`00003Ool00`00O000
0026Ool00`000Il00003Ool010000Il1W`000goo00<0006O00000goo00<0006O00000goo00@0006O
0Il000=oo`030001W`0000=oo`040001W`6O0003Ool00`000Il00003Ool00`000Il0001GOol001io
o`03001oogoo0;ioo`04001l07`00002Ool01000O01l00000goo00<007`000000goo00@007`0O000
00=oo`03001l000000=oo`04001l07`00002Ool01000O01l00000goo00<007`00000QWoo00<0006O
00000goo00@0006O0Il000=oo`030001W`0000=oo`030001W`0000=oo`040001W`6O0003Ool00`00
0Il00003Ool010000Il1W`000goo00<0006O00000goo00<0006O0000Egoo000NOol00`00Oomoo`2n
Ool01000O01l00000Woo00@007`0O00000=oo`03001l000000=oo`04001l07`00003Ool00`00O000
0003Ool01000O01l00000Woo00@007`0O00000=oo`03001l000008Ioo`030001W`0000=oo`040001
W`6O0003Ool00`000Il00003Ool00`000Il00003Ool010000Il1W`000goo00<0006O00000goo00@0
006O0Il000=oo`030001W`0000=oo`030001W`0005Moo`007Woo00<007ooOol0_Woo00@007`0O000
009oo`04001l07`00003Ool00`00O0000003Ool01000O01l00000goo00<007`000000goo00@007`0
O000009oo`04001l07`00003Ool00`00O0000026Ool00`000Il00003Ool010000Il1W`000goo00<0
006O00000goo00<0006O00000goo00@0006O0Il000=oo`030001W`0000=oo`040001W`6O0003Ool0
0`000Il00003Ool3001GOol001ioo`03001oogoo0;ioo`04001l07`00002Ool01000O01l00000goo
00<007`000000goo00@007`0O00000=oo`03001l000000=oo`04001l07`00002Ool01000O01l0000
0goo00<007`00000QWoo00<0006O00000goo00@0006O0Il000=oo`030001W`0000=oo`030001W`00
00=oo`040001W`6O0003Ool00`000Il00003Ool010000Il1W`000goo00<0006O0000GGoo000NOol0
0`00Oomoo`2nOol01000O01l00000Woo00@007`0O00000=oo`03001l000000=oo`04001l07`00003
Ool00`00O0000003Ool01000O01l00000Woo00@007`0O00000=oo`03001l000008Ioo`030001W`00
00=oo`040001W`6O0003Ool00`000Il00003Ool00`000Il00003Ool010000Il1W`000goo00<0006O
00000goo00@0006O0Il000=oo`030001W`0005eoo`007Woo00<007ooOol0_Woo00@007`0O000009o
o`04001l07`00003Ool00`00O0000003Ool01000O01l00000goo00<007`000000goo00@007`0O000
009oo`04001l07`00003Ool00`00O0000026Ool00`000Il00003Ool010000Il1W`000goo00<0006O
00000goo00<0006O00000goo00@0006O0Il000=oo`030001W`0000=oo`040001W`6O0003Ool00`00
0Il0001MOol001ioo`03001oogoo0;ioo`04001l07`00002Ool01000O01l00000goo00<007`00000
0goo00@007`0O00000=oo`03001l000000=oo`04001l07`00002Ool01000O01l00000goo00<007`0
0000QWoo00<0006O00000goo00@0006O0Il000=oo`030001W`0000=oo`030001W`0000=oo`040001
W`6O0003Ool00`000Il00003Ool010000Il1W`000goo00<0006O0000GGoo000NOol00`00Oomoo`2n
Ool01000O01l00000Woo00@007`0O00000=oo`03001l000000=oo`04001l07`00003Ool00`00O000
0003Ool01000O01l00000Woo00@007`0O00000=oo`03001l000008Ioo`030001W`0000=oo`040001
W`6O0003Ool00`000Il00003Ool00`000Il00003Ool010000Il1W`000goo00<0006O00000goo00@0
006O0Il000=oo`030001W`0005eoo`007Woo00<007ooOol0_Woo00@007`0O000009oo`04001l07`0
0003Ool00`00O0000003Ool01000O01l00000goo00<007`000000goo00@007`0O000009oo`04001l
07`00003Ool30026Ool00`000Il00003Ool010000Il1W`000goo00<0006O00000goo00<0006O0000
0goo00@0006O0Il000=oo`030001W`0000=oo`040001W`6O0003Ool00`000Il0001MOol001ioo`03
001oogoo0;ioo`04001l07`00002Ool01000O01l00000goo00<007`000000goo00@007`0O00000=o
o`03001l000000=oo`04001l07`00002Ool01000O01l0000S7oo00<0006O00000goo00@0006O0Il0
00=oo`030001W`0000=oo`030001W`0000=oo`040001W`6O0003Ool00`000Il00003Ool010000Il1
W`000goo00<0006O0000GGoo000NOol00`00Oomoo`2nOol01000O01l00000Woo00@007`0O00000=o
o`03001l000000=oo`04001l07`00003Ool00`00O0000003Ool01000O01l00000Woo00@007`0O000
08aoo`030001W`0000=oo`040001W`6O0003Ool00`000Il00003Ool00`000Il00003Ool010000Il1
W`000goo00<0006O00000goo00@0006O0Il000=oo`030001W`0005eoo`007Woo00<007ooOol0_Woo
00@007`0O000009oo`04001l07`00003Ool00`00O0000003Ool01000O01l00000goo00<007`00000
0goo00@007`0O000009oo`04001l07`0002<Ool00`000Il00003Ool010000Il1W`000goo00<0006O
00000goo00<0006O00000goo00@0006O0Il000=oo`030001W`0000=oo`040001W`6O0003Ool00`00
0Il0001MOol001ioo`<00;ioo`04001l07`00002Ool01000O01l00000goo00<007`000000goo00@0
07`0O00000=oo`03001l000000=oo`04001l07`00002Ool01000O01l0000S7oo0`000goo00@0006O
0Il000=oo`030001W`0000=oo`030001W`0000=oo`040001W`6O0003Ool00`000Il00003Ool01000
0Il1W`000goo00<0006O0000GGoo000NOol00`00Oomoo`2nOol01000O01l00000Woo00@007`0O000
00=oo`03001l000000=oo`04001l07`00003Ool00`00O0000003Ool01000O01l00000Woo00@007`0
O000099oo`040001W`6O0003Ool00`000Il00003Ool00`000Il00003Ool010000Il1W`000goo00<0
006O00000goo00@0006O0Il000=oo`030001W`0005eoo`007Woo00<007ooOol0_Woo00@007`0O000
009oo`04001l07`00003Ool00`00O0000003Ool01000O01l00000goo00<007`000000goo00@007`0
O000009oo`04001l07`0002BOol010000Il1W`000goo00<0006O00000goo00<0006O00000goo00@0
006O0Il000=oo`030001W`0000=oo`040001W`6O0003Ool00`000Il0001MOol001ioo`03001oogoo
0;ioo`04001l07`00002Ool01000O01l00000goo00<007`000000goo00@007`0O00000=oo`03001l
000000=oo`04001l07`00002Ool01000O01l0000TWoo00@0006O0Il000=oo`030001W`0000=oo`03
0001W`0000=oo`040001W`6O0003Ool00`000Il00003Ool010000Il1W`000goo00<0006O0000GGoo
000NOol00`00Oomoo`2nOol01000O01l00000Woo00@007`0O00000=oo`03001l000000=oo`04001l
07`00003Ool00`00O0000003Ool01000O01l00000Woo00@007`0O000099oo`040001W`6O0003Ool0
0`000Il00003Ool00`000Il00003Ool010000Il1W`000goo00<0006O00000goo00@0006O0Il000=o
o`030001W`0005eoo`007Woo00<007ooOol0_Woo00@007`0O000009oo`04001l07`00003Ool00`00
O0000003Ool01000O01l00000goo00<007`000000goo00@007`0O000009oo`04001l07`0002BOol0
10000Il1W`000goo00<0006O00000goo00<0006O00000goo00@0006O0Il000=oo`030001W`0000=o
o`040001W`6O0003Ool00`000Il0001MOol001ioo`03001oogoo0;ioo`04001l07`00002Ool01000
O01l00000goo00<007`000000goo00@007`0O00000=oo`03001l000000=oo`04001l07`00002Ool0
1000O01l0000TWoo00@0006O0Il000=oo`030001W`0000=oo`030001W`0000=oo`040001W`6O0003
Ool00`000Il00003Ool010000Il1W`000goo00<0006O0000GGoo000NOol00`00Oomoo`2nOol01000
O01l00000Woo00@007`0O00000=oo`03001l000000=oo`04001l07`00003Ool00`00O0000003Ool0
1000O01l00000Woo00@007`0O000099oo`040001W`6O0003Ool00`000Il00003Ool00`000Il00003
Ool010000Il1W`000goo00<0006O00000goo00@0006O0Il000=oo`030001W`0005eoo`007Woo00<0
07ooOol0_Woo00@007`0O000009oo`04001l07`00003Ool00`00O0000003Ool01000O01l00000goo
00<007`000000goo00@007`0O000009oo`04001l07`0002BOol010000Il1W`000goo00<0006O0000
0goo00<0006O00000goo00@0006O0Il000=oo`030001W`0000=oo`040001W`6O0003Ool00`000Il0
001MOol001ioo`03001oogoo0;ioo`04001l07`00002Ool01000O01l00000goo00<007`000000goo
00@007`0O00000=oo`03001l000000=oo`04001l07`00002Ool01000O01l0000TWoo00@0006O0Il0
00=oo`030001W`0000=oo`030001W`0000=oo`040001W`6O0003Ool00`000Il00003Ool010000Il1
W`000goo00<0006O0000GGoo000NOol00`00Oomoo`2nOol01000O01l00000Woo00@007`0O00000=o
o`03001l000000=oo`04001l07`00003Ool00`00O0000003Ool01000O01l00000Woo00@007`0O000
099oo`040001W`6O0003Ool00`000Il00003Ool00`000Il00003Ool010000Il1W`000goo00<0006O
00000goo00@0006O0Il000=oo`030001W`0005eoo`007Woo00<007ooOol0_Woo00@007`0O000009o
o`04001l07`00003Ool00`00O0000003Ool01000O01l00000goo00<007`000000goo00@007`0O000
009oo`04001l07`0002BOol010000Il1W`000goo00<0006O00000goo00<0006O00000goo00@0006O
0Il000=oo`030001W`0000=oo`040001W`6O0003Ool00`000Il0001MOol001ioo`03001oogoo0;io
o`04001l07`00002Ool01000O01l00000goo00<007`000000goo00@007`0O00000=oo`03001l0000
00=oo`04001l07`00002Ool01000O01l0000TWoo00@0006O0Il000=oo`030001W`0000=oo`030001
W`0000=oo`040001W`6O0003Ool00`000Il00003Ool010000Il1W`000goo00<0006O0000GGoo000=
Ool20004Ool20009Ool00`00Oomoo`2nOol01000O01l00000Woo00@007`0O00000=oo`03001l0000
00=oo`04001l07`00003Ool00`00O0000003Ool01000O01l00000Woo00@007`0O000099oo`040001
W`6O0003Ool00`000Il00003Ool00`000Il00003Ool010000Il1W`000goo00<0006O00000goo00@0
006O0Il000=oo`030001W`0005eoo`0037oo00@007ooOol0009oo`04001oogoo0008Ool00`00Oomo
o`2nOol01000O01l00000Woo00@007`0O00000=oo`03001l000000=oo`04001l07`00003Ool00`00
O0000003Ool01000O01l00000Woo00@007`0O000099oo`040001W`6O0003Ool00`000Il00003Ool0
0`000Il00003Ool010000Il1W`000goo00<0006O00000goo00@0006O0Il000=oo`030001W`0005eo
o`0037oo00@007ooOol0009oo`04001oogoo0008Ool4002mOol01000O01l00000Woo00@007`0O000
00=oo`03001l000000=oo`04001l07`00003Ool00`00O0000003Ool01000O01l00000Woo00@007`0
O000099oo`040001W`6O0003Ool00`000Il00003Ool00`000Il00003Ool010000Il1W`000goo00<0
006O00000goo00@0006O0Il000=oo`030001W`0005eoo`0037oo0`000goo00@007ooOol000Qoo`03
001oogoo0;ioo`04001l07`00002Ool01000O01l00000goo00<007`000000goo00@007`0O00000=o
o`03001l000000=oo`04001l07`00002Ool01000O01l0000TWoo00@0006O0Il000=oo`030001W`00
00=oo`030001W`0000=oo`040001W`6O0003Ool00`000Il00003Ool010000Il1W`000goo00<0006O
0000GGoo000<Ool00`00Oomoo`03Ool01000Oomoo`0027oo00<007ooOol0_Woo00@007`0O000009o
o`04001l07`00003Ool00`00O0000003Ool01000O01l00000goo00<007`000000goo00@007`0O000
009oo`04001l07`0002BOol010000Il1W`000goo00<0006O00000goo00<0006O00000goo00@0006O
0Il000=oo`030001W`0000=oo`040001W`6O0003Ool00`000Il0001MOol000eoo`<000=oo`8000Uo
o`03001oogoo0;ioo`04001l07`00002Ool01000O01l00000goo00<007`000000goo00@007`0O000
00=oo`03001l000000=oo`04001l07`00002Ool01000O01l0000TWoo00@0006O0Il000=oo`030001
W`0000=oo`030001W`0000=oo`040001W`6O0003Ool00`000Il00003Ool010000Il1W`000goo00<0
006O0000GGoo000NOol00`00Oomoo`2nOol01000O01l00000Woo00@007`0O00000=oo`03001l0000
00=oo`04001l07`00003Ool00`00O0000003Ool01000O01l00000Woo00@007`0O000099oo`040001
W`6O0003Ool00`000Il00003Ool00`000Il00003Ool010000Il1W`000goo00<0006O00000goo00@0
006O0Il000=oo`030001W`0005eoo`007Woo00<007ooOol0_Woo00@007`0O000009oo`04001l07`0
0003Ool00`00O0000003Ool01000O01l00000goo00<007`000000goo00@007`0O000009oo`04001l
07`0002BOol010000Il1W`000goo00<0006O00000goo00<0006O00000goo00@0006O0Il000=oo`03
0001W`0000=oo`040001W`6O0003Ool00`000Il0001MOol001ioo`03001oogoo0;ioo`04001l07`0
0002Ool01000O01l00000goo00<007`000000goo00@007`0O00000=oo`03001l000000=oo`04001l
07`00002Ool01000O01l0000TWoo00@0006O0Il000=oo`030001W`0000=oo`030001W`0000=oo`04
0001W`6O0003Ool00`000Il00003Ool010000Il1W`000goo00<0006O0000GGoo000NOol00`00Oomo
o`2nOol01000O01l00000Woo00@007`0O00000=oo`03001l000000=oo`04001l07`00003Ool00`00
O0000003Ool01000O01l00000Woo00@007`0O000099oo`040001W`6O0003Ool00`000Il00003Ool0
0`000Il00003Ool010000Il1W`000goo00<0006O00000goo00@0006O0Il000=oo`030001W`0005eo
o`007Woo00<007ooOol0_Woo00@007`0O000009oo`04001l07`00003Ool00`00O0000003Ool01000
O01l00000goo00<007`000000goo00@007`0O000009oo`04001l07`0002BOol010000Il1W`000goo
00<0006O00000goo00<0006O00000goo00@0006O0Il000=oo`030001W`0000=oo`040001W`6O0003
Ool00`000Il0001MOol001ioo`03001oogoo0;ioo`04001l07`00002Ool01000O01l00000goo00<0
07`000000goo00@007`0O00000=oo`03001l000000=oo`04001l07`00002Ool01000O01l0000TWoo
00@0006O0Il000=oo`030001W`0000=oo`030001W`0000=oo`040001W`6O0003Ool00`000Il00003
Ool010000Il1W`000goo00<0006O0000GGoo000NOol00`00Oomoo`2nOol01000O01l00000Woo00@0
07`0O00000=oo`03001l000000=oo`04001l07`00003Ool00`00O0000003Ool01000O01l00000Woo
00@007`0O000099oo`040001W`6O0003Ool00`000Il00003Ool00`000Il00003Ool010000Il1W`00
0goo00<0006O00000goo00@0006O0Il000=oo`030001W`0005eoo`007Woo00<007ooOol0_Woo00@0
07`0O000009oo`04001l07`00003Ool00`00O0000003Ool01000O01l00000goo00<007`000000goo
00@007`0O000009oo`04001l07`0002BOol010000Il1W`000goo00<0006O00000goo00<0006O0000
0goo00@0006O0Il000=oo`030001W`0000=oo`040001W`6O0003Ool00`000Il0001MOol001ioo`03
001oogoo0;ioo`04001l07`00002Ool01000O01l00000goo00<007`000000goo00@007`0O00000=o
o`03001l000000=oo`04001l07`00002Ool01000O01l0000TWoo00@0006O0Il000=oo`030001W`00
00=oo`030001W`0000=oo`040001W`6O0003Ool00`000Il00003Ool010000Il1W`000goo00<0006O
0000GGoo000NOol00`00Oomoo`2nOol01000O01l00000Woo00@007`0O00000=oo`03001l000000=o
o`04001l07`00003Ool00`00O0000003Ool01000O01l00000Woo00@007`0O000099oo`040001W`6O
0003Ool00`000Il00003Ool00`000Il00003Ool010000Il1W`000goo00<0006O00000goo00@0006O
0Il000=oo`030001W`0005eoo`007Woo00<007ooOol0_Woo00@007`0O000009oo`04001l07`00003
Ool00`00O0000003Ool01000O01l00000goo00<007`000000goo00@007`0O000009oo`04001l07`0
002BOol010000Il1W`000goo00<0006O00000goo00<0006O00000goo00@0006O0Il000=oo`030001
W`0000=oo`040001W`6O0003Ool00`000Il0001MOol001ioo`03001oogoo0;ioo`04001l07`00002
Ool01000O01l00000goo00<007`000000goo00@007`0O00000=oo`03001l000000=oo`04001l07`0
0002Ool01000O01l0000TWoo00@0006O0Il000=oo`030001W`0000=oo`030001W`0000=oo`040001
W`6O0003Ool00`000Il00003Ool010000Il1W`000goo00<0006O0000GGoo000NOol3002nOol40002
Ool01000O01l00000goo00<007`000000goo00@007`0O00000=oo`03001l000000=oo`04001l07`0
0002Ool01000O01l0000TWoo00@0006O0Il000=oo`<000=oo`030001W`0000=oo`040001W`6O0003
Ool00`000Il00003Ool010000Il1W`000goo00<0006O0000GGoo000NOol00`00Oomoo`34Ool01000
O01l00000goo00<007`000000goo00@007`0O00000=oo`03001l000000=oo`04001l07`00002Ool0
1000O01l0000TWoo00@0006O0Il000Uoo`030001W`0000=oo`040001W`6O0003Ool00`000Il00003
Ool010000Il1W`000goo00<0006O0000GGoo000NOol00`00Oomoo`34Ool01000O01l00000goo00<0
07`000000goo00@007`0O00000=oo`03001l000000=oo`04001l07`00002Ool01000O01l0000TWoo
00@0006O0Il000Uoo`030001W`0000=oo`040001W`6O0003Ool00`000Il00003Ool010000Il1W`00
0goo00<0006O0000GGoo000NOol00`00Oomoo`34Ool01000O01l00000goo00<007`000000goo00@0
07`0O00000=oo`03001l000000=oo`04001l07`00002Ool01000O01l0000TWoo00@0006O0Il000Uo
o`030001W`0000=oo`040001W`6O0003Ool00`000Il00003Ool010000Il1W`000goo00<0006O0000
GGoo000NOol00`00Oomoo`34Ool01000O01l00000goo00<007`000000goo00@007`0O00000=oo`03
001l000000=oo`04001l07`00002Ool01000O01l0000TWoo00@0006O0Il000Uoo`030001W`0000=o
o`040001W`6O0003Ool00`000Il00003Ool010000Il1W`000goo00<0006O0000GGoo000NOol00`00
Oomoo`34Ool01000O01l00000goo00<007`000000goo00@007`0O00000=oo`03001l000000=oo`04
001l07`00002Ool01000O01l0000TWoo00@0006O0Il000Uoo`030001W`0000=oo`040001W`6O0003
Ool00`000Il00003Ool010000Il1W`000goo00<0006O0000GGoo000NOol00`00Oomoo`34Ool01000
O01l00000goo00<007`000000goo00@007`0O00000=oo`03001l000000=oo`04001l07`00002Ool0
1000O01l0000TWoo00@0006O0Il000Uoo`030001W`0000=oo`040001W`6O0003Ool00`000Il00003
Ool010000Il1W`000goo00<0006O0000GGoo000NOol00`00Oomoo`34Ool01000O01l00000goo00<0
07`000000goo00@007`0O00000=oo`03001l000000=oo`04001l07`00002Ool01000O01l0000TWoo
00@0006O0Il000Uoo`030001W`0000=oo`040001W`6O0003Ool00`000Il00003Ool010000Il1W`00
0goo00<0006O0000GGoo000NOol00`00Oomoo`34Ool01000O01l00000goo00<007`000000goo00@0
07`0O00000=oo`03001l000000=oo`04001l07`00002Ool01000O01l0000TWoo00@0006O0Il000Uo
o`030001W`0000=oo`040001W`6O0003Ool00`000Il00003Ool010000Il1W`000goo00<0006O0000
GGoo000NOol00`00Oomoo`34Ool01000O01l00000goo00<007`000000goo00@007`0O00000=oo`03
001l000000=oo`04001l07`00002Ool01000O01l0000TWoo00@0006O0Il000Uoo`030001W`0000=o
o`040001W`6O0003Ool00`000Il00003Ool010000Il1W`000goo00<0006O0000GGoo000NOol00`00
Oomoo`34Ool01000O01l00000goo00<007`000000goo10000goo00<007`000000goo00@007`0O000
009oo`04001l07`0002BOol010000Il1W`002Goo00<0006O00000goo00@0006O0Il000=oo`030001
W`0000=oo`040001W`6O0003Ool00`000Il0001MOol001ioo`03001oogoo0<Aoo`04001l07`00003
Ool00`00O000000:Ool00`00O0000003Ool01000O01l00000Woo00@007`0O000099oo`040001W`6O
0009Ool00`000Il00003Ool010000Il1W`000goo00<0006O00000goo00@0006O0Il000=oo`030001
W`0005eoo`007Woo00<007ooOol0a7oo00@007`0O00000=oo`03001l000000Yoo`03001l000000=o
o`04001l07`00002Ool01000O01l0000TWoo00@0006O0Il000Uoo`030001W`0000=oo`040001W`6O
0003Ool00`000Il00003Ool010000Il1W`000goo00<0006O0000GGoo000NOol00`00Oomoo`34Ool0
1000O01l00000goo00<007`000002Woo00<007`000000goo00@007`0O000009oo`04001l07`0002B
Ool010000Il1W`002Goo00<0006O00000goo00@0006O0Il000=oo`030001W`0000=oo`040001W`6O
0003Ool00`000Il0001MOol001ioo`03001oogoo0<Aoo`04001l07`00003Ool00`00O000000:Ool0
0`00O0000003Ool01000O01l00000Woo00@007`0O000099oo`040001W`6O0009Ool00`000Il00003
Ool010000Il1W`000goo00<0006O00000goo00@0006O0Il000=oo`030001W`0005eoo`007Woo00<0
07ooOol0a7oo00@007`0O00000=oo`03001l000000Yoo`03001l000000=oo`04001l07`00002Ool0
1000O01l0000TWoo00@0006O0Il000Uoo`030001W`0000=oo`040001W`6O0003Ool00`000Il00003
Ool010000Il1W`000goo00<0006O0000GGoo000NOol30034Ool01000O01l00000goo00<007`00000
2Woo00<007`000000goo00@007`0O000009oo`04001l07`0002BOol010000Il1W`002Goo00<0006O
00000goo00@0006O0Il000=oo`030001W`0000=oo`040001W`6O0003Ool00`000Il0001MOol001io
o`03001oogoo0<Aoo`04001l07`00003Ool00`00O000000:Ool00`00O0000003Ool01000O01l0000
0Woo00@007`0O000099oo`040001W`6O0009Ool00`000Il00003Ool010000Il1W`000goo00<0006O
00000goo00@0006O0Il000=oo`030001W`0005eoo`007Woo00<007ooOol0a7oo00@007`0O00000=o
o`03001l000000Yoo`03001l000000=oo`04001l07`00002Ool01000O01l0000TWoo00@0006O0Il0
00Uoo`030001W`0000=oo`040001W`6O0003Ool00`000Il00003Ool010000Il1W`000goo00<0006O
0000GGoo000NOol00`00Oomoo`34Ool01000O01l00000goo00<007`000002Woo00<007`000000goo
00@007`0O000009oo`@0099oo`040001W`6O0009Ool00`000Il00003Ool010000Il1W`000goo00<0
006O00000goo00@0006O0Il000=oo`030001W`0005eoo`007Woo00<007ooOol0a7oo00@007`0O000
00=oo`03001l000000Yoo`03001l000000=oo`04001l07`0002HOol010000Il1W`002Goo00<0006O
00000goo00@0006O0Il000=oo`030001W`0000=oo`040001W`6O0003Ool00`000Il0001MOol001io
o`03001oogoo0<Aoo`04001l07`00003Ool00`00O000000:Ool00`00O0000003Ool01000O01l0000
V7oo00@0006O0Il000Uoo`030001W`0000=oo`040001W`6O0003Ool00`000Il00003Ool010000Il1
W`000goo00<0006O0000GGoo000NOol00`00Oomoo`34Ool01000O01l00000goo00<007`000002Woo
00<007`000000goo00@007`0O00009Qoo`@000Uoo`030001W`0000=oo`040001W`6O0003Ool00`00
0Il00003Ool010000Il1W`000goo00<0006O0000GGoo000NOol00`00Oomoo`34Ool01000O01l0000
0goo00<007`000002Woo00<007`000000goo00@007`0O0000:Eoo`030001W`0000=oo`040001W`6O
0003Ool00`000Il00003Ool010000Il1W`000goo00<0006O0000GGoo000NOol00`00Oomoo`34Ool0
1000O01l00000goo00<007`000002Woo00<007`000000goo00@007`0O0000:Eoo`030001W`0000=o
o`040001W`6O0003Ool00`000Il00003Ool010000Il1W`000goo00<0006O0000GGoo000NOol00`00
Oomoo`34Ool01000O01l00000goo00<007`000002Woo00<007`000000goo00@007`0O0000:Eoo`03
0001W`0000=oo`040001W`6O0003Ool00`000Il00003Ool010000Il1W`000goo00<0006O0000GGoo
000NOol00`00Oomoo`34Ool01000O01l00000goo00<007`000002Woo00<007`000000goo00@007`0
O0000:Eoo`030001W`0000=oo`040001W`6O0003Ool00`000Il00003Ool010000Il1W`000goo00<0
006O0000GGoo000NOol00`00Oomoo`34Ool01000O01l00000goo00<007`000002Woo00<007`00000
0goo00@007`0O0000:Eoo`030001W`0000=oo`040001W`6O0003Ool00`000Il00003Ool010000Il1
W`000goo00<0006O0000GGoo000NOol00`00Oomoo`34Ool01000O01l00000goo00<007`000002Woo
00<007`000000goo00@007`0O0000:Eoo`030001W`0000=oo`040001W`6O0003Ool00`000Il00003
Ool010000Il1W`000goo00<0006O0000GGoo000NOol00`00Oomoo`34Ool01000O01l00000goo00<0
07`000002Woo00<007`000000goo00@007`0O0000:Eoo`030001W`0000=oo`040001W`6O0003Ool0
0`000Il00003Ool010000Il1W`000goo00<0006O0000GGoo000NOol00`00Oomoo`34Ool01000O01l
00000goo00<007`000002Woo00<007`000000goo00@007`0O0000:Eoo`030001W`0000=oo`040001
W`6O0003Ool00`000Il00003Ool010000Il1W`000goo00<0006O0000GGoo000NOol00`00Oomoo`34
Ool01000O01l00000goo00<007`000002Woo00<007`000000goo00@007`0O0000:Eoo`030001W`00
00=oo`040001W`6O0003Ool00`000Il00003Ool010000Il1W`000goo00<0006O0000GGoo000NOol3
0034Ool01000O01l00000goo00<007`000002Woo00<007`000000goo00@007`0O0000:Eoo`030001
W`0000=oo`040001W`6O0003Ool00`000Il00003Ool010000Il1W`000goo00<0006O0000GGoo000N
Ool00`00Oomoo`34Ool01000O01l00000goo00<007`000002Woo00<007`000000goo00@007`0O000
0:Eoo`030001W`0000=oo`040001W`6O0003Ool00`000Il00003Ool010000Il1W`000goo00<0006O
0000GGoo000NOol00`00Oomoo`34Ool01000O01l00000goo00<007`000002Woo00<007`000000goo
00@007`0O0000:Eoo`030001W`0000=oo`040001W`6O0003Ool00`000Il00003Ool010000Il1W`00
0goo00<0006O0000GGoo000NOol00`00Oomoo`34Ool40003Ool00`00O000000:Ool00`00O0000003
Ool01000O01l0000YGoo00<0006O00000goo00@0006O0Il000=oo`030001W`0000=oo`040001W`6O
0003Ool00`000Il0001MOol001ioo`03001oogoo0<]oo`03001l000000Yoo`03001l000000=oo`04
001l07`0002UOol00`000Il00003Ool010000Il1W`000goo00<0006O00000goo00@0006O0Il000=o
o`030001W`0005eoo`007Woo00<007ooOol0bgoo00<007`000002Woo00<007`000000goo00@007`0
O0000:Eoo`030001W`0000=oo`040001W`6O0003Ool00`000Il00003Ool010000Il1W`000goo00<0
006O0000GGoo000NOol00`00Oomoo`3;Ool00`00O000000:Ool00`00O0000003Ool01000O01l0000
YGoo00<0006O00000goo00@0006O0Il000=oo`030001W`0000=oo`040001W`6O0003Ool00`000Il0
001MOol001ioo`03001oogoo0<]oo`03001l000000Yoo`03001l000000=oo`04001l07`0002UOol0
0`000Il00003Ool010000Il1W`000goo00<0006O00000goo00@0006O0Il000=oo`030001W`0005eo
o`007Woo00<007ooOol0bgoo00<007`000002Woo00<007`000000goo00@007`0O0000:Eoo`030001
W`0000=oo`040001W`6O0003Ool00`000Il00003Ool010000Il1W`000goo00<0006O0000GGoo000N
Ool00`00Oomoo`3;Ool00`00O000000:Ool00`00O0000003Ool4002UOol00`000Il00003Ool01000
0Il1W`000goo00<0006O00000goo00@0006O0Il000=oo`030001W`0005eoo`007Woo00<007ooOol0
bgoo00<007`000002Woo00<007`00000[7oo00<0006O00000goo00@0006O0Il000=oo`030001W`00
00=oo`040001W`6O0003Ool00`000Il0001MOol001ioo`03001oogoo0<]oo`03001l000000Yoo`03
001l00000:aoo`030001W`0000=oo`040001W`6O0003Ool00`000Il00003Ool010000Il1W`000goo
00<0006O0000GGoo000NOol00`00Oomoo`3;Ool00`00O000000:Ool00`00O000002/Ool00`000Il0
0003Ool010000Il1W`000goo00<0006O00000goo00@0006O0Il000=oo`030001W`0005eoo`007Woo
00<007ooOol0bgoo00<007`000002Woo00<007`00000[7oo00<0006O00000goo00@0006O0Il000=o
o`030001W`0000=oo`040001W`6O0003Ool00`000Il0001MOol000eoo`8000Aoo`8000Uoo`03001o
ogoo0<]oo`03001l000000Yoo`03001l00000:aoo`030001W`0000=oo`040001W`6O0003Ool00`00
0Il00003Ool010000Il1W`000goo00<0006O0000GGoo000<Ool01000Oomoo`000Woo00@007ooOol0
00Qoo`03001oogoo0<]oo`03001l000000Yoo`03001l00000:aoo`030001W`0000=oo`040001W`6O
0003Ool00`000Il00003Ool010000Il1W`000goo00<0006O0000GGoo000<Ool01000Oomoo`000Woo
00@007ooOol000Qoo`@00<Yoo`03001l000000Yoo`03001l00000:aoo`030001W`0000=oo`040001
W`6O0003Ool00`000Il00003Ool010000Il1W`000goo00<0006O0000GGoo000=Ool20003Ool01000
Oomoo`0027oo00<007ooOol0bgoo00<007`000002Woo00<007`00000[7oo00<0006O00000goo00@0
006O0Il000=oo`030001W`0000=oo`040001W`6O0003Ool00`000Il0001MOol000aoo`04001oogoo
0002Ool01000Oomoo`0027oo00<007ooOol0bgoo00<007`000002Woo00<007`00000[7oo00<0006O
00000goo00@0006O0Il000=oo`030001W`0000=oo`040001W`6O0003Ool00`000Il0001MOol000eo
o`8000Aoo`8000Uoo`03001oogoo0<]oo`03001l000000Yoo`03001l00000:aoo`030001W`0000=o
o`@000=oo`030001W`0000=oo`040001W`6O0003Ool00`000Il0001MOol001ioo`03001oogoo0<]o
o`03001l000000Yoo`03001l00000:aoo`030001W`0000Yoo`030001W`0000=oo`040001W`6O0003
Ool00`000Il0001MOol001ioo`03001oogoo0<]oo`03001l000000Yoo`03001l00000:aoo`030001
W`0000Yoo`030001W`0000=oo`040001W`6O0003Ool00`000Il0001MOol001ioo`03001oogoo0<]o
o`03001l000000Yoo`<00:aoo`030001W`0000Yoo`030001W`0000=oo`040001W`6O0003Ool00`00
0Il0001MOol001ioo`03001oogoo0<]oo`03001l00000;Uoo`030001W`0000Yoo`030001W`0000=o
o`040001W`6O0003Ool00`000Il0001MOol001ioo`03001oogoo0<]oo`03001l00000;Uoo`030001
W`0000Yoo`030001W`0000=oo`040001W`6O0003Ool00`000Il0001MOol001ioo`03001oogoo0<]o
o`<00;Uoo`030001W`0000Yoo`030001W`0000=oo`040001W`6O0003Ool00`000Il0001MOol001io
o`03001oogoo0?moohQoo`030001W`0000Yoo`030001W`0000=oo`040001W`6O0003Ool00`000Il0
001MOol001ioo`03001oogoo0?moohQoo`030001W`0000Yoo`030001W`0000=oo`040001W`6O0003
Ool00`000Il0001MOol001ioo`03001oogoo0?moohQoo`030001W`0000Yoo`030001W`0000=oo`04
0001W`6O0003Ool00`000Il0001MOol001ioo`03001oogoo0?moohQoo`030001W`0000Yoo`030001
W`0000=oo`040001W`6O0003Ool00`000Il0001MOol001ioo`03001oogoo0?moohQoo`030001W`00
00Yoo`030001W`0000=oo`040001W`6O0003Ool00`000Il0001MOol001ioo`03001oogoo0?moohQo
o`030001W`0000Yoo`030001W`0000=oo`040001W`6O0003Ool00`000Il0001MOol001ioo`<00?mo
ohQoo`030001W`0000Yoo`030001W`0000=oo`@000=oo`030001W`0005eoo`007Woo00<007ooOol0
ogooR7oo00<0006O00002Woo00<0006O00002Woo00<0006O0000GGoo000NOol00`00Oomoo`3oOon8
Ool00`000Il0000:Ool00`000Il0000:Ool00`000Il0001MOol001ioo`03001oogoo0?moohQoo`03
0001W`0000Yoo`030001W`0000Yoo`030001W`0005eoo`007Woo00<007ooOol0ogooR7oo00<0006O
00002Woo00<0006O00002Woo00<0006O0000GGoo000NOol00`00Oomoo`3oOon8Ool00`000Il0000:
Ool00`000Il0000:Ool00`000Il0001MOol001ioo`03001oogoo0?moohQoo`030001W`0000Yoo`03
0001W`0000Yoo`030001W`0005eoo`007Woo00<007ooOol0ogooR7oo00<0006O00002Woo00<0006O
00002Woo00<0006O0000GGoo000NOol00`00Oomoo`3oOon8Ool00`000Il0000:Ool00`000Il0000:
Ool00`000Il0001MOol001ioo`03001oogoo0?moohQoo`030001W`0000Yoo`030001W`0000Yoo`<0
05eoo`007Woo00<007ooOol0ogooR7oo00<0006O00002Woo00<0006O0000JWoo000NOol00`00Oomo
o`3oOon8Ool00`000Il0000:Ool00`000Il0001ZOol001ioo`03001oogoo0?moohQoo`030001W`00
00Yoo`030001W`0006Yoo`007Woo00<007ooOol0ogooR7oo00<0006O00002Woo00<0006O0000JWoo
000NOol00`00Oomoo`3oOon8Ool00`000Il0000:Ool00`000Il0001ZOol001ioo`<00?moohQoo`03
0001W`0000Yoo`030001W`0006Yoo`007Woo00<007ooOol0ogooR7oo00<0006O00002Woo00<0006O
0000JWoo000NOol00`00Oomoo`3oOon8Ool00`000Il0000:Ool00`000Il0001ZOol001ioo`03001o
ogoo0?moohQoo`030001W`0000Yoo`030001W`0006Yoo`007Woo00<007ooOol0ogooR7oo00<0006O
00002Woo00<0006O0000JWoo000NOol00`00Oomoo`3oOon8Ool00`000Il0000:Ool00`000Il0001Z
Ool001ioo`03001oogoo0?moohQoo`030001W`0000Yoo`030001W`0006Yoo`007Woo00<007ooOol0
ogooR7oo00<0006O00002Woo00<0006O0000JWoo000NOol00`00Oomoo`3oOon8Ool00`000Il0000:
Ool00`000Il0001ZOol001ioo`03001oogoo0?moohQoo`030001W`0000Yoo`030001W`0006Yoo`00
7Woo00<007ooOol0ogooR7oo00<0006O00002Woo00<0006O0000JWoo000NOol00`00Oomoo`3oOon8
Ool00`000Il0000:Ool00`000Il0001ZOol001ioo`03001oogoo0?moohQoo`030001W`0000Yoo`03
0001W`0006Yoo`007Woo00<007ooOol0ogooR7oo00<0006O00002Woo00<0006O0000JWoo000NOol0
0`00Oomoo`3oOon8Ool00`000Il0000:Ool00`000Il0001ZOol001ioo`03001oogoo0?moohQoo`03
0001W`0000Yoo`030001W`0006Yoo`007Woo0`00ogooR7oo0`002Woo00<0006O0000JWoo000NOol0
0`00Oomoo`3oOonEOol00`000Il0001ZOol001ioo`03001oogoo0?mooiEoo`030001W`0006Yoo`00
7Woo00<007ooOol0ogooUGoo00<0006O0000JWoo000NOol00`00Oomoo`3oOonEOol00`000Il0001Z
Ool001ioo`03001oogoo0?mooiEoo`030001W`0006Yoo`007Woo00<007ooOol0ogooUGoo00<0006O
0000JWoo000NOol00`00Oomoo`3oOonEOol00`000Il0001ZOol001ioo`03001oogoo0?mooiEoo`03
0001W`0006Yoo`007Woo00<007ooOol0ogooUGoo00<0006O0000JWoo000NOol00`00Oomoo`3oOonE
Ool00`000Il0001ZOol001ioo`03001oogoo0?mooiEoo`030001W`0006Yoo`007Woo00<007ooOol0
ogooUGoo00<0006O0000JWoo000NOol00`00Oomoo`3oOonEOol00`000Il0001ZOol000Ioo`<000Ao
o`8000Aoo`8000Uoo`03001oogoo0?mooiEoo`030001W`0006Yoo`001goo00<007ooOol00Woo00@0
07ooOol0009oo`04001oogoo0008Ool00`00Oomoo`3oOonEOol00`000Il0001ZOol000Moo`03001o
ogoo009oo`04001oogoo0002Ool01000Oomoo`0027oo1000ogooU7oo00<0006O0000JWoo0007Ool0
0`00Oomoo`02Ool01000Oomoo`000Woo00@007ooOol00?mooj1oo`81Wf]oo`001goo00<007ooOol0
0Woo00@007ooOol0009oo`04001oogoo003oOonPOol20Im[Ool000Ioo`8000Eoo`8000Aoo`800?mo
oj5oo`81Wf]oo`00ogooogoo97oo0000\
\>"],
  ImageRangeCache->{{{0, 545}, {336.312, 0}} -> {-4.1186, -4.86745, 0.156261, 
  0.316044}}]
}, Closed]],

Cell["\<\
On the original scale, the distribution is highly skewed, with rare \
high values:\
\>", "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(BarChart[
      BinCounts[gt /. \[Theta] -> 1. , {0, 10\^\(-14\), 10\^\(-16\)}], 
      PlotRange -> {{0, 100}, {0, 100}}]; \)\)], "Input",
  CellLabel->"In[236]:="],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 0.01 0 0.00618034 [
[.01 -0.0125 -3 -9 ]
[.01 -0.0125 3 0 ]
[.02 -0.0125 -3 -9 ]
[.02 -0.0125 3 0 ]
[.03 -0.0125 -3 -9 ]
[.03 -0.0125 3 0 ]
[.04 -0.0125 -3 -9 ]
[.04 -0.0125 3 0 ]
[.05 -0.0125 -3 -9 ]
[.05 -0.0125 3 0 ]
[.06 -0.0125 -3 -9 ]
[.06 -0.0125 3 0 ]
[.07 -0.0125 -3 -9 ]
[.07 -0.0125 3 0 ]
[.08 -0.0125 -3 -9 ]
[.08 -0.0125 3 0 ]
[.09 -0.0125 -3 -9 ]
[.09 -0.0125 3 0 ]
[.1 -0.0125 -6 -9 ]
[.1 -0.0125 6 0 ]
[.11 -0.0125 -6 -9 ]
[.11 -0.0125 6 0 ]
[.12 -0.0125 -6 -9 ]
[.12 -0.0125 6 0 ]
[.13 -0.0125 -6 -9 ]
[.13 -0.0125 6 0 ]
[.14 -0.0125 -6 -9 ]
[.14 -0.0125 6 0 ]
[.15 -0.0125 -6 -9 ]
[.15 -0.0125 6 0 ]
[.16 -0.0125 -6 -9 ]
[.16 -0.0125 6 0 ]
[.17 -0.0125 -6 -9 ]
[.17 -0.0125 6 0 ]
[.18 -0.0125 -6 -9 ]
[.18 -0.0125 6 0 ]
[.19 -0.0125 -6 -9 ]
[.19 -0.0125 6 0 ]
[.2 -0.0125 -6 -9 ]
[.2 -0.0125 6 0 ]
[.21 -0.0125 -6 -9 ]
[.21 -0.0125 6 0 ]
[.22 -0.0125 -6 -9 ]
[.22 -0.0125 6 0 ]
[.23 -0.0125 -6 -9 ]
[.23 -0.0125 6 0 ]
[.24 -0.0125 -6 -9 ]
[.24 -0.0125 6 0 ]
[.25 -0.0125 -6 -9 ]
[.25 -0.0125 6 0 ]
[.26 -0.0125 -6 -9 ]
[.26 -0.0125 6 0 ]
[.27 -0.0125 -6 -9 ]
[.27 -0.0125 6 0 ]
[.28 -0.0125 -6 -9 ]
[.28 -0.0125 6 0 ]
[.29 -0.0125 -6 -9 ]
[.29 -0.0125 6 0 ]
[.3 -0.0125 -6 -9 ]
[.3 -0.0125 6 0 ]
[.31 -0.0125 -6 -9 ]
[.31 -0.0125 6 0 ]
[.32 -0.0125 -6 -9 ]
[.32 -0.0125 6 0 ]
[.33 -0.0125 -6 -9 ]
[.33 -0.0125 6 0 ]
[.34 -0.0125 -6 -9 ]
[.34 -0.0125 6 0 ]
[.35 -0.0125 -6 -9 ]
[.35 -0.0125 6 0 ]
[.36 -0.0125 -6 -9 ]
[.36 -0.0125 6 0 ]
[.37 -0.0125 -6 -9 ]
[.37 -0.0125 6 0 ]
[.38 -0.0125 -6 -9 ]
[.38 -0.0125 6 0 ]
[.39 -0.0125 -6 -9 ]
[.39 -0.0125 6 0 ]
[.4 -0.0125 -6 -9 ]
[.4 -0.0125 6 0 ]
[.41 -0.0125 -6 -9 ]
[.41 -0.0125 6 0 ]
[.42 -0.0125 -6 -9 ]
[.42 -0.0125 6 0 ]
[.43 -0.0125 -6 -9 ]
[.43 -0.0125 6 0 ]
[.44 -0.0125 -6 -9 ]
[.44 -0.0125 6 0 ]
[.45 -0.0125 -6 -9 ]
[.45 -0.0125 6 0 ]
[.46 -0.0125 -6 -9 ]
[.46 -0.0125 6 0 ]
[.47 -0.0125 -6 -9 ]
[.47 -0.0125 6 0 ]
[.48 -0.0125 -6 -9 ]
[.48 -0.0125 6 0 ]
[.49 -0.0125 -6 -9 ]
[.49 -0.0125 6 0 ]
[.5 -0.0125 -6 -9 ]
[.5 -0.0125 6 0 ]
[.51 -0.0125 -6 -9 ]
[.51 -0.0125 6 0 ]
[.52 -0.0125 -6 -9 ]
[.52 -0.0125 6 0 ]
[.53 -0.0125 -6 -9 ]
[.53 -0.0125 6 0 ]
[.54 -0.0125 -6 -9 ]
[.54 -0.0125 6 0 ]
[.55 -0.0125 -6 -9 ]
[.55 -0.0125 6 0 ]
[.56 -0.0125 -6 -9 ]
[.56 -0.0125 6 0 ]
[.57 -0.0125 -6 -9 ]
[.57 -0.0125 6 0 ]
[.58 -0.0125 -6 -9 ]
[.58 -0.0125 6 0 ]
[.59 -0.0125 -6 -9 ]
[.59 -0.0125 6 0 ]
[.6 -0.0125 -6 -9 ]
[.6 -0.0125 6 0 ]
[.61 -0.0125 -6 -9 ]
[.61 -0.0125 6 0 ]
[.62 -0.0125 -6 -9 ]
[.62 -0.0125 6 0 ]
[.63 -0.0125 -6 -9 ]
[.63 -0.0125 6 0 ]
[.64 -0.0125 -6 -9 ]
[.64 -0.0125 6 0 ]
[.65 -0.0125 -6 -9 ]
[.65 -0.0125 6 0 ]
[.66 -0.0125 -6 -9 ]
[.66 -0.0125 6 0 ]
[.67 -0.0125 -6 -9 ]
[.67 -0.0125 6 0 ]
[.68 -0.0125 -6 -9 ]
[.68 -0.0125 6 0 ]
[.69 -0.0125 -6 -9 ]
[.69 -0.0125 6 0 ]
[.7 -0.0125 -6 -9 ]
[.7 -0.0125 6 0 ]
[.71 -0.0125 -6 -9 ]
[.71 -0.0125 6 0 ]
[.72 -0.0125 -6 -9 ]
[.72 -0.0125 6 0 ]
[.73 -0.0125 -6 -9 ]
[.73 -0.0125 6 0 ]
[.74 -0.0125 -6 -9 ]
[.74 -0.0125 6 0 ]
[.75 -0.0125 -6 -9 ]
[.75 -0.0125 6 0 ]
[.76 -0.0125 -6 -9 ]
[.76 -0.0125 6 0 ]
[.77 -0.0125 -6 -9 ]
[.77 -0.0125 6 0 ]
[.78 -0.0125 -6 -9 ]
[.78 -0.0125 6 0 ]
[.79 -0.0125 -6 -9 ]
[.79 -0.0125 6 0 ]
[.8 -0.0125 -6 -9 ]
[.8 -0.0125 6 0 ]
[.81 -0.0125 -6 -9 ]
[.81 -0.0125 6 0 ]
[.82 -0.0125 -6 -9 ]
[.82 -0.0125 6 0 ]
[.83 -0.0125 -6 -9 ]
[.83 -0.0125 6 0 ]
[.84 -0.0125 -6 -9 ]
[.84 -0.0125 6 0 ]
[.85 -0.0125 -6 -9 ]
[.85 -0.0125 6 0 ]
[.86 -0.0125 -6 -9 ]
[.86 -0.0125 6 0 ]
[.87 -0.0125 -6 -9 ]
[.87 -0.0125 6 0 ]
[.88 -0.0125 -6 -9 ]
[.88 -0.0125 6 0 ]
[.89 -0.0125 -6 -9 ]
[.89 -0.0125 6 0 ]
[.9 -0.0125 -6 -9 ]
[.9 -0.0125 6 0 ]
[.91 -0.0125 -6 -9 ]
[.91 -0.0125 6 0 ]
[.92 -0.0125 -6 -9 ]
[.92 -0.0125 6 0 ]
[.93 -0.0125 -6 -9 ]
[.93 -0.0125 6 0 ]
[.94 -0.0125 -6 -9 ]
[.94 -0.0125 6 0 ]
[.95 -0.0125 -6 -9 ]
[.95 -0.0125 6 0 ]
[.96 -0.0125 -6 -9 ]
[.96 -0.0125 6 0 ]
[.97 -0.0125 -6 -9 ]
[.97 -0.0125 6 0 ]
[.98 -0.0125 -6 -9 ]
[.98 -0.0125 6 0 ]
[.99 -0.0125 -6 -9 ]
[.99 -0.0125 6 0 ]
[1 -0.0125 -9 -9 ]
[1 -0.0125 9 0 ]
[-0.0085 .12361 -12 -4.5 ]
[-0.0085 .12361 0 4.5 ]
[-0.0085 .24721 -12 -4.5 ]
[-0.0085 .24721 0 4.5 ]
[-0.0085 .37082 -12 -4.5 ]
[-0.0085 .37082 0 4.5 ]
[-0.0085 .49443 -12 -4.5 ]
[-0.0085 .49443 0 4.5 ]
[-0.0085 .61803 -18 -4.5 ]
[-0.0085 .61803 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.01 0 m
.01 .00625 L
s
[(1)] .01 -0.0125 0 1 Mshowa
.02 0 m
.02 .00625 L
s
[(2)] .02 -0.0125 0 1 Mshowa
.03 0 m
.03 .00625 L
s
[(3)] .03 -0.0125 0 1 Mshowa
.04 0 m
.04 .00625 L
s
[(4)] .04 -0.0125 0 1 Mshowa
.05 0 m
.05 .00625 L
s
[(5)] .05 -0.0125 0 1 Mshowa
.06 0 m
.06 .00625 L
s
[(6)] .06 -0.0125 0 1 Mshowa
.07 0 m
.07 .00625 L
s
[(7)] .07 -0.0125 0 1 Mshowa
.08 0 m
.08 .00625 L
s
[(8)] .08 -0.0125 0 1 Mshowa
.09 0 m
.09 .00625 L
s
[(9)] .09 -0.0125 0 1 Mshowa
.1 0 m
.1 .00625 L
s
[(10)] .1 -0.0125 0 1 Mshowa
.11 0 m
.11 .00625 L
s
[(11)] .11 -0.0125 0 1 Mshowa
.12 0 m
.12 .00625 L
s
[(12)] .12 -0.0125 0 1 Mshowa
.13 0 m
.13 .00625 L
s
[(13)] .13 -0.0125 0 1 Mshowa
.14 0 m
.14 .00625 L
s
[(14)] .14 -0.0125 0 1 Mshowa
.15 0 m
.15 .00625 L
s
[(15)] .15 -0.0125 0 1 Mshowa
.16 0 m
.16 .00625 L
s
[(16)] .16 -0.0125 0 1 Mshowa
.17 0 m
.17 .00625 L
s
[(17)] .17 -0.0125 0 1 Mshowa
.18 0 m
.18 .00625 L
s
[(18)] .18 -0.0125 0 1 Mshowa
.19 0 m
.19 .00625 L
s
[(19)] .19 -0.0125 0 1 Mshowa
.2 0 m
.2 .00625 L
s
[(20)] .2 -0.0125 0 1 Mshowa
.21 0 m
.21 .00625 L
s
[(21)] .21 -0.0125 0 1 Mshowa
.22 0 m
.22 .00625 L
s
[(22)] .22 -0.0125 0 1 Mshowa
.23 0 m
.23 .00625 L
s
[(23)] .23 -0.0125 0 1 Mshowa
.24 0 m
.24 .00625 L
s
[(24)] .24 -0.0125 0 1 Mshowa
.25 0 m
.25 .00625 L
s
[(25)] .25 -0.0125 0 1 Mshowa
.26 0 m
.26 .00625 L
s
[(26)] .26 -0.0125 0 1 Mshowa
.27 0 m
.27 .00625 L
s
[(27)] .27 -0.0125 0 1 Mshowa
.28 0 m
.28 .00625 L
s
[(28)] .28 -0.0125 0 1 Mshowa
.29 0 m
.29 .00625 L
s
[(29)] .29 -0.0125 0 1 Mshowa
.3 0 m
.3 .00625 L
s
[(30)] .3 -0.0125 0 1 Mshowa
.31 0 m
.31 .00625 L
s
[(31)] .31 -0.0125 0 1 Mshowa
.32 0 m
.32 .00625 L
s
[(32)] .32 -0.0125 0 1 Mshowa
.33 0 m
.33 .00625 L
s
[(33)] .33 -0.0125 0 1 Mshowa
.34 0 m
.34 .00625 L
s
[(34)] .34 -0.0125 0 1 Mshowa
.35 0 m
.35 .00625 L
s
[(35)] .35 -0.0125 0 1 Mshowa
.36 0 m
.36 .00625 L
s
[(36)] .36 -0.0125 0 1 Mshowa
.37 0 m
.37 .00625 L
s
[(37)] .37 -0.0125 0 1 Mshowa
.38 0 m
.38 .00625 L
s
[(38)] .38 -0.0125 0 1 Mshowa
.39 0 m
.39 .00625 L
s
[(39)] .39 -0.0125 0 1 Mshowa
.4 0 m
.4 .00625 L
s
[(40)] .4 -0.0125 0 1 Mshowa
.41 0 m
.41 .00625 L
s
[(41)] .41 -0.0125 0 1 Mshowa
.42 0 m
.42 .00625 L
s
[(42)] .42 -0.0125 0 1 Mshowa
.43 0 m
.43 .00625 L
s
[(43)] .43 -0.0125 0 1 Mshowa
.44 0 m
.44 .00625 L
s
[(44)] .44 -0.0125 0 1 Mshowa
.45 0 m
.45 .00625 L
s
[(45)] .45 -0.0125 0 1 Mshowa
.46 0 m
.46 .00625 L
s
[(46)] .46 -0.0125 0 1 Mshowa
.47 0 m
.47 .00625 L
s
[(47)] .47 -0.0125 0 1 Mshowa
.48 0 m
.48 .00625 L
s
[(48)] .48 -0.0125 0 1 Mshowa
.49 0 m
.49 .00625 L
s
[(49)] .49 -0.0125 0 1 Mshowa
.5 0 m
.5 .00625 L
s
[(50)] .5 -0.0125 0 1 Mshowa
.51 0 m
.51 .00625 L
s
[(51)] .51 -0.0125 0 1 Mshowa
.52 0 m
.52 .00625 L
s
[(52)] .52 -0.0125 0 1 Mshowa
.53 0 m
.53 .00625 L
s
[(53)] .53 -0.0125 0 1 Mshowa
.54 0 m
.54 .00625 L
s
[(54)] .54 -0.0125 0 1 Mshowa
.55 0 m
.55 .00625 L
s
[(55)] .55 -0.0125 0 1 Mshowa
.56 0 m
.56 .00625 L
s
[(56)] .56 -0.0125 0 1 Mshowa
.57 0 m
.57 .00625 L
s
[(57)] .57 -0.0125 0 1 Mshowa
.58 0 m
.58 .00625 L
s
[(58)] .58 -0.0125 0 1 Mshowa
.59 0 m
.59 .00625 L
s
[(59)] .59 -0.0125 0 1 Mshowa
.6 0 m
.6 .00625 L
s
[(60)] .6 -0.0125 0 1 Mshowa
.61 0 m
.61 .00625 L
s
[(61)] .61 -0.0125 0 1 Mshowa
.62 0 m
.62 .00625 L
s
[(62)] .62 -0.0125 0 1 Mshowa
.63 0 m
.63 .00625 L
s
[(63)] .63 -0.0125 0 1 Mshowa
.64 0 m
.64 .00625 L
s
[(64)] .64 -0.0125 0 1 Mshowa
.65 0 m
.65 .00625 L
s
[(65)] .65 -0.0125 0 1 Mshowa
.66 0 m
.66 .00625 L
s
[(66)] .66 -0.0125 0 1 Mshowa
.67 0 m
.67 .00625 L
s
[(67)] .67 -0.0125 0 1 Mshowa
.68 0 m
.68 .00625 L
s
[(68)] .68 -0.0125 0 1 Mshowa
.69 0 m
.69 .00625 L
s
[(69)] .69 -0.0125 0 1 Mshowa
.7 0 m
.7 .00625 L
s
[(70)] .7 -0.0125 0 1 Mshowa
.71 0 m
.71 .00625 L
s
[(71)] .71 -0.0125 0 1 Mshowa
.72 0 m
.72 .00625 L
s
[(72)] .72 -0.0125 0 1 Mshowa
.73 0 m
.73 .00625 L
s
[(73)] .73 -0.0125 0 1 Mshowa
.74 0 m
.74 .00625 L
s
[(74)] .74 -0.0125 0 1 Mshowa
.75 0 m
.75 .00625 L
s
[(75)] .75 -0.0125 0 1 Mshowa
.76 0 m
.76 .00625 L
s
[(76)] .76 -0.0125 0 1 Mshowa
.77 0 m
.77 .00625 L
s
[(77)] .77 -0.0125 0 1 Mshowa
.78 0 m
.78 .00625 L
s
[(78)] .78 -0.0125 0 1 Mshowa
.79 0 m
.79 .00625 L
s
[(79)] .79 -0.0125 0 1 Mshowa
.8 0 m
.8 .00625 L
s
[(80)] .8 -0.0125 0 1 Mshowa
.81 0 m
.81 .00625 L
s
[(81)] .81 -0.0125 0 1 Mshowa
.82 0 m
.82 .00625 L
s
[(82)] .82 -0.0125 0 1 Mshowa
.83 0 m
.83 .00625 L
s
[(83)] .83 -0.0125 0 1 Mshowa
.84 0 m
.84 .00625 L
s
[(84)] .84 -0.0125 0 1 Mshowa
.85 0 m
.85 .00625 L
s
[(85)] .85 -0.0125 0 1 Mshowa
.86 0 m
.86 .00625 L
s
[(86)] .86 -0.0125 0 1 Mshowa
.87 0 m
.87 .00625 L
s
[(87)] .87 -0.0125 0 1 Mshowa
.88 0 m
.88 .00625 L
s
[(88)] .88 -0.0125 0 1 Mshowa
.89 0 m
.89 .00625 L
s
[(89)] .89 -0.0125 0 1 Mshowa
.9 0 m
.9 .00625 L
s
[(90)] .9 -0.0125 0 1 Mshowa
.91 0 m
.91 .00625 L
s
[(91)] .91 -0.0125 0 1 Mshowa
.92 0 m
.92 .00625 L
s
[(92)] .92 -0.0125 0 1 Mshowa
.93 0 m
.93 .00625 L
s
[(93)] .93 -0.0125 0 1 Mshowa
.94 0 m
.94 .00625 L
s
[(94)] .94 -0.0125 0 1 Mshowa
.95 0 m
.95 .00625 L
s
[(95)] .95 -0.0125 0 1 Mshowa
.96 0 m
.96 .00625 L
s
[(96)] .96 -0.0125 0 1 Mshowa
.97 0 m
.97 .00625 L
s
[(97)] .97 -0.0125 0 1 Mshowa
.98 0 m
.98 .00625 L
s
[(98)] .98 -0.0125 0 1 Mshowa
.99 0 m
.99 .00625 L
s
[(99)] .99 -0.0125 0 1 Mshowa
1 0 m
1 .00625 L
s
[(100)] 1 -0.0125 0 1 Mshowa
0 0 m
1 0 L
s
.004 .12361 m
.01025 .12361 L
s
[(20)] -0.0085 .12361 1 0 Mshowa
.004 .24721 m
.01025 .24721 L
s
[(40)] -0.0085 .24721 1 0 Mshowa
.004 .37082 m
.01025 .37082 L
s
[(60)] -0.0085 .37082 1 0 Mshowa
.004 .49443 m
.01025 .49443 L
s
[(80)] -0.0085 .49443 1 0 Mshowa
.004 .61803 m
.01025 .61803 L
s
[(100)] -0.0085 .61803 1 0 Mshowa
.125 Mabswid
.004 .0309 m
.00775 .0309 L
s
.004 .0618 m
.00775 .0618 L
s
.004 .09271 m
.00775 .09271 L
s
.004 .15451 m
.00775 .15451 L
s
.004 .18541 m
.00775 .18541 L
s
.004 .21631 m
.00775 .21631 L
s
.004 .27812 m
.00775 .27812 L
s
.004 .30902 m
.00775 .30902 L
s
.004 .33992 m
.00775 .33992 L
s
.004 .40172 m
.00775 .40172 L
s
.004 .43262 m
.00775 .43262 L
s
.004 .46353 m
.00775 .46353 L
s
.004 .52533 m
.00775 .52533 L
s
.004 .55623 m
.00775 .55623 L
s
.004 .58713 m
.00775 .58713 L
s
.25 Mabswid
.004 0 m
.004 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
1 0 0 r
.006 0 m
.006 4.7156 L
.014 4.7156 L
.014 0 L
F
0 g
.5 Mabswid
.006 0 m
0 0 rlineto s
.006 0 m
.006 .61803 L
s
.014 .61803 m
.014 0 L
.006 0 L
s
1 0 0 r
.016 0 m
.016 .50679 L
.024 .50679 L
.024 0 L
F
0 g
.016 0 m
.016 .50679 L
.024 .50679 L
.024 0 L
.016 0 L
s
1 0 0 r
.026 0 m
.026 .25339 L
.034 .25339 L
.034 0 L
F
0 g
.026 0 m
.026 .25339 L
.034 .25339 L
.034 0 L
.026 0 L
s
1 0 0 r
.036 0 m
.036 .10507 L
.044 .10507 L
.044 0 L
F
0 g
.036 0 m
.036 .10507 L
.044 .10507 L
.044 0 L
.036 0 L
s
1 0 0 r
.046 0 m
.046 .09271 L
.054 .09271 L
.054 0 L
F
0 g
.046 0 m
.046 .09271 L
.054 .09271 L
.054 0 L
.046 0 L
s
1 0 0 r
.056 0 m
.056 .09271 L
.064 .09271 L
.064 0 L
F
0 g
.056 0 m
.056 .09271 L
.064 .09271 L
.064 0 L
.056 0 L
s
1 0 0 r
.066 0 m
.066 .06798 L
.074 .06798 L
.074 0 L
F
0 g
.066 0 m
.066 .06798 L
.074 .06798 L
.074 0 L
.066 0 L
s
1 0 0 r
.076 0 m
.076 .0618 L
.084 .0618 L
.084 0 L
F
0 g
.076 0 m
.076 .0618 L
.084 .0618 L
.084 0 L
.076 0 L
s
1 0 0 r
.086 0 m
.086 .01236 L
.094 .01236 L
.094 0 L
F
0 g
.086 0 m
.086 .01236 L
.094 .01236 L
.094 0 L
.086 0 L
s
1 0 0 r
.096 0 m
.096 .04326 L
.104 .04326 L
.104 0 L
F
0 g
.096 0 m
.096 .04326 L
.104 .04326 L
.104 0 L
.096 0 L
s
1 0 0 r
.106 0 m
.106 .02472 L
.114 .02472 L
.114 0 L
F
0 g
.106 0 m
.106 .02472 L
.114 .02472 L
.114 0 L
.106 0 L
s
1 0 0 r
.116 0 m
.116 .01854 L
.124 .01854 L
.124 0 L
F
0 g
.116 0 m
.116 .01854 L
.124 .01854 L
.124 0 L
.116 0 L
s
1 0 0 r
.126 0 m
.126 .01236 L
.134 .01236 L
.134 0 L
F
0 g
.126 0 m
.126 .01236 L
.134 .01236 L
.134 0 L
.126 0 L
s
1 0 0 r
.136 0 m
.136 .02472 L
.144 .02472 L
.144 0 L
F
0 g
.136 0 m
.136 .02472 L
.144 .02472 L
.144 0 L
.136 0 L
s
1 0 0 r
.146 0 m
.146 .01854 L
.154 .01854 L
.154 0 L
F
0 g
.146 0 m
.146 .01854 L
.154 .01854 L
.154 0 L
.146 0 L
s
1 0 0 r
.156 0 m
.156 0 L
.164 0 L
.164 0 L
F
0 g
.156 0 m
.156 0 L
.164 0 L
.164 0 L
.156 0 L
s
1 0 0 r
.166 0 m
.166 .00618 L
.174 .00618 L
.174 0 L
F
0 g
.166 0 m
.166 .00618 L
.174 .00618 L
.174 0 L
.166 0 L
s
1 0 0 r
.176 0 m
.176 .00618 L
.184 .00618 L
.184 0 L
F
0 g
.176 0 m
.176 .00618 L
.184 .00618 L
.184 0 L
.176 0 L
s
1 0 0 r
.186 0 m
.186 .00618 L
.194 .00618 L
.194 0 L
F
0 g
.186 0 m
.186 .00618 L
.194 .00618 L
.194 0 L
.186 0 L
s
1 0 0 r
.196 0 m
.196 0 L
.204 0 L
.204 0 L
F
0 g
.196 0 m
.196 0 L
.204 0 L
.204 0 L
.196 0 L
s
1 0 0 r
.206 0 m
.206 0 L
.214 0 L
.214 0 L
F
0 g
.206 0 m
.206 0 L
.214 0 L
.214 0 L
.206 0 L
s
1 0 0 r
.216 0 m
.216 .01236 L
.224 .01236 L
.224 0 L
F
0 g
.216 0 m
.216 .01236 L
.224 .01236 L
.224 0 L
.216 0 L
s
1 0 0 r
.226 0 m
.226 .01236 L
.234 .01236 L
.234 0 L
F
0 g
.226 0 m
.226 .01236 L
.234 .01236 L
.234 0 L
.226 0 L
s
1 0 0 r
.236 0 m
.236 .00618 L
.244 .00618 L
.244 0 L
F
0 g
.236 0 m
.236 .00618 L
.244 .00618 L
.244 0 L
.236 0 L
s
1 0 0 r
.246 0 m
.246 .00618 L
.254 .00618 L
.254 0 L
F
0 g
.246 0 m
.246 .00618 L
.254 .00618 L
.254 0 L
.246 0 L
s
1 0 0 r
.256 0 m
.256 .00618 L
.264 .00618 L
.264 0 L
F
0 g
.256 0 m
.256 .00618 L
.264 .00618 L
.264 0 L
.256 0 L
s
1 0 0 r
.266 0 m
.266 .01236 L
.274 .01236 L
.274 0 L
F
0 g
.266 0 m
.266 .01236 L
.274 .01236 L
.274 0 L
.266 0 L
s
1 0 0 r
.276 0 m
.276 0 L
.284 0 L
.284 0 L
F
0 g
.276 0 m
.276 0 L
.284 0 L
.284 0 L
.276 0 L
s
1 0 0 r
.286 0 m
.286 0 L
.294 0 L
.294 0 L
F
0 g
.286 0 m
.286 0 L
.294 0 L
.294 0 L
.286 0 L
s
1 0 0 r
.296 0 m
.296 0 L
.304 0 L
.304 0 L
F
0 g
.296 0 m
.296 0 L
.304 0 L
.304 0 L
.296 0 L
s
1 0 0 r
.306 0 m
.306 .00618 L
.314 .00618 L
.314 0 L
F
0 g
.306 0 m
.306 .00618 L
.314 .00618 L
.314 0 L
.306 0 L
s
1 0 0 r
.316 0 m
.316 0 L
.324 0 L
.324 0 L
F
0 g
.316 0 m
.316 0 L
.324 0 L
.324 0 L
.316 0 L
s
1 0 0 r
.326 0 m
.326 .00618 L
.334 .00618 L
.334 0 L
F
0 g
.326 0 m
.326 .00618 L
.334 .00618 L
.334 0 L
.326 0 L
s
1 0 0 r
.336 0 m
.336 0 L
.344 0 L
.344 0 L
F
0 g
.336 0 m
.336 0 L
.344 0 L
.344 0 L
.336 0 L
s
1 0 0 r
.346 0 m
.346 .01236 L
.354 .01236 L
.354 0 L
F
0 g
.346 0 m
.346 .01236 L
.354 .01236 L
.354 0 L
.346 0 L
s
1 0 0 r
.356 0 m
.356 0 L
.364 0 L
.364 0 L
F
0 g
.356 0 m
.356 0 L
.364 0 L
.364 0 L
.356 0 L
s
1 0 0 r
.366 0 m
.366 0 L
.374 0 L
.374 0 L
F
0 g
.366 0 m
.366 0 L
.374 0 L
.374 0 L
.366 0 L
s
1 0 0 r
.376 0 m
.376 0 L
.384 0 L
.384 0 L
F
0 g
.376 0 m
.376 0 L
.384 0 L
.384 0 L
.376 0 L
s
1 0 0 r
.386 0 m
.386 0 L
.394 0 L
.394 0 L
F
0 g
.386 0 m
.386 0 L
.394 0 L
.394 0 L
.386 0 L
s
1 0 0 r
.396 0 m
.396 0 L
.404 0 L
.404 0 L
F
0 g
.396 0 m
.396 0 L
.404 0 L
.404 0 L
.396 0 L
s
1 0 0 r
.406 0 m
.406 0 L
.414 0 L
.414 0 L
F
0 g
.406 0 m
.406 0 L
.414 0 L
.414 0 L
.406 0 L
s
1 0 0 r
.416 0 m
.416 .00618 L
.424 .00618 L
.424 0 L
F
0 g
.416 0 m
.416 .00618 L
.424 .00618 L
.424 0 L
.416 0 L
s
1 0 0 r
.426 0 m
.426 0 L
.434 0 L
.434 0 L
F
0 g
.426 0 m
.426 0 L
.434 0 L
.434 0 L
.426 0 L
s
1 0 0 r
.436 0 m
.436 0 L
.444 0 L
.444 0 L
F
0 g
.436 0 m
.436 0 L
.444 0 L
.444 0 L
.436 0 L
s
1 0 0 r
.446 0 m
.446 0 L
.454 0 L
.454 0 L
F
0 g
.446 0 m
.446 0 L
.454 0 L
.454 0 L
.446 0 L
s
1 0 0 r
.456 0 m
.456 0 L
.464 0 L
.464 0 L
F
0 g
.456 0 m
.456 0 L
.464 0 L
.464 0 L
.456 0 L
s
1 0 0 r
.466 0 m
.466 0 L
.474 0 L
.474 0 L
F
0 g
.466 0 m
.466 0 L
.474 0 L
.474 0 L
.466 0 L
s
1 0 0 r
.476 0 m
.476 0 L
.484 0 L
.484 0 L
F
0 g
.476 0 m
.476 0 L
.484 0 L
.484 0 L
.476 0 L
s
1 0 0 r
.486 0 m
.486 0 L
.494 0 L
.494 0 L
F
0 g
.486 0 m
.486 0 L
.494 0 L
.494 0 L
.486 0 L
s
1 0 0 r
.496 0 m
.496 .00618 L
.504 .00618 L
.504 0 L
F
0 g
.496 0 m
.496 .00618 L
.504 .00618 L
.504 0 L
.496 0 L
s
1 0 0 r
.506 0 m
.506 0 L
.514 0 L
.514 0 L
F
0 g
.506 0 m
.506 0 L
.514 0 L
.514 0 L
.506 0 L
s
1 0 0 r
.516 0 m
.516 0 L
.524 0 L
.524 0 L
F
0 g
.516 0 m
.516 0 L
.524 0 L
.524 0 L
.516 0 L
s
1 0 0 r
.526 0 m
.526 0 L
.534 0 L
.534 0 L
F
0 g
.526 0 m
.526 0 L
.534 0 L
.534 0 L
.526 0 L
s
1 0 0 r
.536 0 m
.536 0 L
.544 0 L
.544 0 L
F
0 g
.536 0 m
.536 0 L
.544 0 L
.544 0 L
.536 0 L
s
1 0 0 r
.546 0 m
.546 0 L
.554 0 L
.554 0 L
F
0 g
.546 0 m
.546 0 L
.554 0 L
.554 0 L
.546 0 L
s
1 0 0 r
.556 0 m
.556 0 L
.564 0 L
.564 0 L
F
0 g
.556 0 m
.556 0 L
.564 0 L
.564 0 L
.556 0 L
s
1 0 0 r
.566 0 m
.566 0 L
.574 0 L
.574 0 L
F
0 g
.566 0 m
.566 0 L
.574 0 L
.574 0 L
.566 0 L
s
1 0 0 r
.576 0 m
.576 0 L
.584 0 L
.584 0 L
F
0 g
.576 0 m
.576 0 L
.584 0 L
.584 0 L
.576 0 L
s
1 0 0 r
.586 0 m
.586 .00618 L
.594 .00618 L
.594 0 L
F
0 g
.586 0 m
.586 .00618 L
.594 .00618 L
.594 0 L
.586 0 L
s
1 0 0 r
.596 0 m
.596 0 L
.604 0 L
.604 0 L
F
0 g
.596 0 m
.596 0 L
.604 0 L
.604 0 L
.596 0 L
s
1 0 0 r
.606 0 m
.606 0 L
.614 0 L
.614 0 L
F
0 g
.606 0 m
.606 0 L
.614 0 L
.614 0 L
.606 0 L
s
1 0 0 r
.616 0 m
.616 .00618 L
.624 .00618 L
.624 0 L
F
0 g
.616 0 m
.616 .00618 L
.624 .00618 L
.624 0 L
.616 0 L
s
1 0 0 r
.626 0 m
.626 0 L
.634 0 L
.634 0 L
F
0 g
.626 0 m
.626 0 L
.634 0 L
.634 0 L
.626 0 L
s
1 0 0 r
.636 0 m
.636 0 L
.644 0 L
.644 0 L
F
0 g
.636 0 m
.636 0 L
.644 0 L
.644 0 L
.636 0 L
s
1 0 0 r
.646 0 m
.646 0 L
.654 0 L
.654 0 L
F
0 g
.646 0 m
.646 0 L
.654 0 L
.654 0 L
.646 0 L
s
1 0 0 r
.656 0 m
.656 0 L
.664 0 L
.664 0 L
F
0 g
.656 0 m
.656 0 L
.664 0 L
.664 0 L
.656 0 L
s
1 0 0 r
.666 0 m
.666 0 L
.674 0 L
.674 0 L
F
0 g
.666 0 m
.666 0 L
.674 0 L
.674 0 L
.666 0 L
s
1 0 0 r
.676 0 m
.676 0 L
.684 0 L
.684 0 L
F
0 g
.676 0 m
.676 0 L
.684 0 L
.684 0 L
.676 0 L
s
1 0 0 r
.686 0 m
.686 0 L
.694 0 L
.694 0 L
F
0 g
.686 0 m
.686 0 L
.694 0 L
.694 0 L
.686 0 L
s
1 0 0 r
.696 0 m
.696 0 L
.704 0 L
.704 0 L
F
0 g
.696 0 m
.696 0 L
.704 0 L
.704 0 L
.696 0 L
s
1 0 0 r
.706 0 m
.706 0 L
.714 0 L
.714 0 L
F
0 g
.706 0 m
.706 0 L
.714 0 L
.714 0 L
.706 0 L
s
1 0 0 r
.716 0 m
.716 0 L
.724 0 L
.724 0 L
F
0 g
.716 0 m
.716 0 L
.724 0 L
.724 0 L
.716 0 L
s
1 0 0 r
.726 0 m
.726 0 L
.734 0 L
.734 0 L
F
0 g
.726 0 m
.726 0 L
.734 0 L
.734 0 L
.726 0 L
s
1 0 0 r
.736 0 m
.736 0 L
.744 0 L
.744 0 L
F
0 g
.736 0 m
.736 0 L
.744 0 L
.744 0 L
.736 0 L
s
1 0 0 r
.746 0 m
.746 0 L
.754 0 L
.754 0 L
F
0 g
.746 0 m
.746 0 L
.754 0 L
.754 0 L
.746 0 L
s
1 0 0 r
.756 0 m
.756 0 L
.764 0 L
.764 0 L
F
0 g
.756 0 m
.756 0 L
.764 0 L
.764 0 L
.756 0 L
s
1 0 0 r
.766 0 m
.766 0 L
.774 0 L
.774 0 L
F
0 g
.766 0 m
.766 0 L
.774 0 L
.774 0 L
.766 0 L
s
1 0 0 r
.776 0 m
.776 0 L
.784 0 L
.784 0 L
F
0 g
.776 0 m
.776 0 L
.784 0 L
.784 0 L
.776 0 L
s
1 0 0 r
.786 0 m
.786 0 L
.794 0 L
.794 0 L
F
0 g
.786 0 m
.786 0 L
.794 0 L
.794 0 L
.786 0 L
s
1 0 0 r
.796 0 m
.796 0 L
.804 0 L
.804 0 L
F
0 g
.796 0 m
.796 0 L
.804 0 L
.804 0 L
.796 0 L
s
1 0 0 r
.806 0 m
.806 0 L
.814 0 L
.814 0 L
F
0 g
.806 0 m
.806 0 L
.814 0 L
.814 0 L
.806 0 L
s
1 0 0 r
.816 0 m
.816 0 L
.824 0 L
.824 0 L
F
0 g
.816 0 m
.816 0 L
.824 0 L
.824 0 L
.816 0 L
s
1 0 0 r
.826 0 m
.826 0 L
.834 0 L
.834 0 L
F
0 g
.826 0 m
.826 0 L
.834 0 L
.834 0 L
.826 0 L
s
1 0 0 r
.836 0 m
.836 0 L
.844 0 L
.844 0 L
F
0 g
.836 0 m
.836 0 L
.844 0 L
.844 0 L
.836 0 L
s
1 0 0 r
.846 0 m
.846 0 L
.854 0 L
.854 0 L
F
0 g
.846 0 m
.846 0 L
.854 0 L
.854 0 L
.846 0 L
s
1 0 0 r
.856 0 m
.856 0 L
.864 0 L
.864 0 L
F
0 g
.856 0 m
.856 0 L
.864 0 L
.864 0 L
.856 0 L
s
1 0 0 r
.866 0 m
.866 0 L
.874 0 L
.874 0 L
F
0 g
.866 0 m
.866 0 L
.874 0 L
.874 0 L
.866 0 L
s
1 0 0 r
.876 0 m
.876 0 L
.884 0 L
.884 0 L
F
0 g
.876 0 m
.876 0 L
.884 0 L
.884 0 L
.876 0 L
s
1 0 0 r
.886 0 m
.886 0 L
.894 0 L
.894 0 L
F
0 g
.886 0 m
.886 0 L
.894 0 L
.894 0 L
.886 0 L
s
1 0 0 r
.896 0 m
.896 0 L
.904 0 L
.904 0 L
F
0 g
.896 0 m
.896 0 L
.904 0 L
.904 0 L
.896 0 L
s
1 0 0 r
.906 0 m
.906 0 L
.914 0 L
.914 0 L
F
0 g
.906 0 m
.906 0 L
.914 0 L
.914 0 L
.906 0 L
s
1 0 0 r
.916 0 m
.916 0 L
.924 0 L
.924 0 L
F
0 g
.916 0 m
.916 0 L
.924 0 L
.924 0 L
.916 0 L
s
1 0 0 r
.926 0 m
.926 0 L
.934 0 L
.934 0 L
F
0 g
.926 0 m
.926 0 L
.934 0 L
.934 0 L
.926 0 L
s
1 0 0 r
.936 0 m
.936 0 L
.944 0 L
.944 0 L
F
0 g
.936 0 m
.936 0 L
.944 0 L
.944 0 L
.936 0 L
s
1 0 0 r
.946 0 m
.946 0 L
.954 0 L
.954 0 L
F
0 g
.946 0 m
.946 0 L
.954 0 L
.954 0 L
.946 0 L
s
1 0 0 r
.956 0 m
.956 0 L
.964 0 L
.964 0 L
F
0 g
.956 0 m
.956 0 L
.964 0 L
.964 0 L
.956 0 L
s
1 0 0 r
.966 0 m
.966 0 L
.974 0 L
.974 0 L
F
0 g
.966 0 m
.966 0 L
.974 0 L
.974 0 L
.966 0 L
s
1 0 0 r
.976 0 m
.976 0 L
.984 0 L
.984 0 L
F
0 g
.976 0 m
.976 0 L
.984 0 L
.984 0 L
.976 0 L
s
1 0 0 r
.986 0 m
.986 .00618 L
.994 .00618 L
.994 0 L
F
0 g
.986 0 m
.986 .00618 L
.994 .00618 L
.994 0 L
.986 0 L
s
1 0 0 r
.996 0 m
.996 0 L
1.004 0 L
1.004 0 L
F
0 g
.996 0 m
.996 0 L
s
.996 0 m
0 0 rlineto s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[236]:=",
  ImageSize->{594, 366.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40009B0001KQ000`40O003h00OogooogooE7oo003o
OoooOomDOol001]oo`<000=oo`@00004Ool000000004Ool3000017oo0000000017oo0P0017oo00<0
07ooOol00Woo0P000goo1@000goo0`000Woo10000Woo10000Woo0`000Woo1@0000Aoo`000000009o
o`@0009oo`<000=oo`<0009oo`@0009oo`@00003Ool000000080009oo`@0009oo`@00003Ool00000
00<00003Ool0000000800003Ool000000080009oo`@00003Ool000000080009oo`<000=oo`<0009o
o`@0009oo`@00003Ool000000080009oo`@0009oo`<0009oo`@0009oo`<0009oo`@0009oo`@000=o
o`<0009oo`<0009oo`@0009oo`<000=oo`<0009oo`@0009oo`<000=oo`<0009oo`<0009oo`<0009o
o`@0009oo`<000=oo`@00003Ool000000080009oo`@00003Ool000000080009oo`<000=oo`<0009o
o`@0009oo`<000=oo`<0009oo`<000=oo`@0009oo`<000=oo`<0009oo`<000=oo`8000=oo`8000Ao
o`8000=oo`<000=oo`<0009oo`<000=oo`@00004Ool000000004Ool30002Ool30003Ool20003Ool2
0004Ool20003Ool30003Ool30002Ool30003Ool4000017oo0000000017oo0`000Woo0`000goo0P00
0goo0P0017oo0P000Woo10000Woo0`000goo0`000Woo1@0000Aoo`000000009oo`D00004Ool00000
0003Ool30002Ool30003Ool500000goo000000030004Ool20005Ool001aoo`03001oogoo00=oo`03
001oogoo00Aoo`03001oogoo009oo`03001oogoo00=oo`04001oogoo0002Ool01@00Oomoogoo0000
0goo00@007ooOol000Eoo`03001oogoo009oo`800004Ool007ooOol20004Ool00`00Oomoo`03Ool0
0`00Ool00002Ool00`00Ool00003Ool00`00Ool00002Ool01000Oomoo`000Woo00<007ooOol00Woo
0P0000Eoo`00Oomoo`00009oo`06001oo`00001oo`000Woo0P0017oo00<007ooOol00goo00<007oo
00000Woo00<007oo00000goo00<007oo00000Woo00@007ooOol0009oo`03001oogoo009oo`04001o
ogoo0004Ool01000Oomoo`000Woo00@007ooOomoo`8000=oo`03001oo`0000Aoo`8000=oo`8000Eo
o`05001oogoo001oo`020002Ool00`00Ool00002Ool01000Ool000000goo0P000Woo00@007oo0000
00=oo`03001oogoo009oo`8000Aoo`03001oo`0000=oo`03001oogoo00=oo`80009oo`800004Ool0
07ooOol20003Ool200000goo001oo`03Ool01@00Oomoo`00Ool00P000Woo00<007oo00000goo00<0
07oo000017oo0P000goo0P0017oo0P0000Eoo`00Oomoo`0000=oo`03001oo`00009oo`06001oo`00
001oo`000Woo00D007oo000007oo00800005Ool00000Ool00002Ool2000017oo001oo`000Woo0P00
00=oo`00Ool00P0000Aoo`00Oomoo`800008Ool007ooOol007oo001oo`80009oo`04001oogoo0003
Ool00`00Ool00002Ool01000Oomoo`000Woo00<007ooOol00Woo0P0017oo00<007oo00000goo0P00
0goo00D007ooOol007oo00800004Ool007ooOol20003Ool200001Goo001oogoo00000Woo00D007oo
000007oo00800008Ool00000Ool007oo001oo`80009oo`04001oogoo0002Ool01P00Ool00000Ool0
009oo`800008Ool007ooOol007oo001oo`80009oo`04001oogoo0004Ool200001Goo001oogoo0000
0goo00<007oo00000goo0P001Goo00<007ooOol00Woo00<007ooOol00goo00@007ooOol0009oo`04
001oogooOol20002Ool01000Oomoo`0017oo0P0000Eoo`00Oomoo`00009oo`03001oogoo009oo`00
77oo00<007ooOol017oo00<007ooOol00goo00<007ooOol0100017oo00@007ooOol0009oo`03001o
ogoo009oo`04001oogoo0002Ool01000Oomoogoo0`0017oo0P0000Aoo`00Oomoo`8000Aoo`8000Ao
o`03001oo`00009oo`@0009oo`03001oo`00009oo`04001oogoo0002Ool20003Ool200000goo001o
o`02Ool300000goo001oo`020003Ool00`00Oomoo`03Ool00`00Oomoo`03Ool20002Ool40003Ool2
0002Ool200000goo001oo`02Ool01000Oomoogoo0P0000Aoo`00Oomoo`<0009oo`04001oogoo0003
Ool20004Ool20004Ool200000goo000000020005Ool01@00Oomoo`00Ool00P000goo0P000Woo00D0
07oo000007oo00@0009oo`@00003Ool000000080009oo`@00003Ool0000000<00003Ool000000080
009oo`@00003Ool0000000<00003Ool0000000800003Ool0000000<0009oo`<0009oo`04001oo`00
0002Ool00`00Ool00004Ool20004Ool200000goo000000020004Ool200001Goo001oogoo000017oo
0P000Woo00D007oo000007oo00@00004Ool00000Ool200001Goo000007oo00000Woo00H007oo0000
07oo0002Ool200000goo00000002000017oo001oogoo0P0000Moo`00Oomoo`00Ool00002Ool01000
Oomoo`000Woo00@007ooOomoo`<0009oo`800004Ool007ooOol20004Ool20004Ool20002Ool40003
Ool01P00Ool007oo001oo`8000=oo`80009oo`04001oo`000002Ool4000017oo000007oo0P0000Mo
o`00001oo`00Ool00002Ool01000Oomoo`000Woo00<007ooOol0100000Aoo`00Oomoo`800007Ool0
07ooOol007oo00000Woo00@007ooOol0009oo`03001oogoo00@00003Ool00000008000=oo`<0009o
o`<000=oo`<0009oo`@0009oo`<0009oo`@0009oo`<0009oo`@000=oo`<00005Ool007ooOol00002
Ool00`00Oomoo`02Ool001aoo`03001oogoo00Eoo`03001oogoo008000=oo`03001oo`00009oo`<0
00=oo`<000Eoo`04001oogooOol20003Ool01000Oomoo`0017oo0P0000Aoo`00Oomoo`8000Aoo`03
001oo`0000=oo`8000=oo`03001oo`00009oo`<000=oo`<000=oo`8000Aoo`8000=oo`06001oo`00
001oo`000Woo00@007ooOomoo`8000Eoo`04001oogooOol30002Ool00`00Ool00002Ool40002Ool3
0004Ool20003Ool20002Ool40002Ool40002Ool20004Ool30002Ool30002Ool30003Ool30003Ool3
0003Ool20003Ool30002Ool01000Ool000000Woo00P007oo000007oo001oo`000goo00L007oo0000
07oo001oo`020002Ool00`00Ool00003Ool30002Ool40002Ool00`00Ool00002Ool01000Ool00000
0Woo100000Moo`00000007oo001oo`030003Ool400000goo000000020002Ool30002Ool40002Ool3
0003Ool30002Ool40002Ool400001goo00000000Ool007oo00<000=oo`@00003Ool000000080009o
o`<0009oo`@0009oo`<0009oo`@0009oo`<000=oo`04001oo`000002Ool2000017oo001oogoo0P00
17oo00<007oo00000Woo0P000goo00<007oo00000goo0`000Woo0`0017oo0P000goo0P000goo1000
0Woo0P0000Aoo`00Oomoo`8000=oo`800004Ool007ooOol20003Ool30003Ool30002Ool30003Ool3
0003Ool20002Ool200001Goo000007oo00000Woo00<007ooOol00P0000Aoo`00Ool0009oo`800003
Ool0000000800005Ool00000Ool00002Ool40002Ool400001Goo001oogoo00000Woo10000Woo00H0
07oo000007oo0002Ool01000Oomoo`0017oo000LOol00`00Oomoo`02Ool01000Oomoo`0017oo00H0
07ooOol007oo0002Ool00`00Oomoo`03Ool00`00Oomoo`06Ool00`00Ool00002Ool01000Oomoo`00
0Woo00<007ooOol00Woo0P0000Aoo`00Oomoo`8000=oo`800003Ool007oo009oo`03001oo`00009o
o`03001oo`00009oo`8000Aoo`03001oogoo00=oo`03001oo`00009oo`800003Ool007oo00800005
Ool00000Ool00002Ool01000Ool007oo0P000Woo00@007ooOol0009oo`05001oogoo001oo`020000
1Goo001oogoo00000Woo00H007oo000007oo0002Ool01@00Oomoo`00Ool00P0000Eoo`00001oo`00
009oo`04001oogoo0002Ool01000Oomoogoo0P000Woo00@007ooOol000Aoo`800003Ool007oo0080
009oo`04001oogoo0002Ool00`00Ool00005Ool01@00Oomoo`00Ool00P0000=oo`00Ool00P000Woo
00P007oo000007oo001oo`000goo00h007oo000007oo001oo`00Ool007oo001oo`000goo00<007oo
00000Woo0`000goo00D007oo000007oo00<00004Ool007oo0002Ool01000Ool000000Woo00@007oo
000000Aoo`06001oogoo001oo`000goo00D007oo001oo`00009oo`8000Aoo`03001oogoo00=oo`05
001oogoo001oo`020002Ool00`00Ool00002Ool01000Ool000000Woo00@007oo000000Aoo`06001o
ogoo001oo`000goo00D007oo001oo`00009oo`8000Aoo`03001oogoo009oo`07001oogooOol007oo
00000Woo00@007ooOol0009oo`05001oogoo001oo`020002Ool00`00Ool00002Ool01000Ool00000
17oo00D007ooOol007oo0080009oo`03001oo`00009oo`04001oogoo0004Ool200001Goo001oogoo
00000Woo00D007ooOol007oo00800004Ool00000Ool200000goo001oo`0200001Goo000007oo0000
0Woo00D007ooOol007oo00800005Ool00000Ool00002Ool01P00Oomoo`00Ool0009oo`800006Ool0
07ooOol007oo0P0000Eoo`00001oo`00009oo`03001oogoo00800003Ool007oo00800005Ool00000
Ool00002Ool01P00Ool00000Ool0009oo`04001oogoo0002Ool01P00Oomoo`00Ool0009oo`800005
Ool007ooOol00002Ool01P00Ool00000Ool0009oo`04001oogoo0004Ool001]oo`8000Eoo`80009o
o`<000Aoo`80009oo`@000=oo`<0009oo`@0009oo`8000Aoo`<000Aoo`<0009oo`<000=oo`<000=o
o`<0009oo`@0009oo`@00003Ool0000000<00003Ool000000080009oo`<000=oo`<000=oo`8000=o
o`8000Aoo`8000=oo`<000=oo`<0009oo`@0009oo`@00003Ool000000080009oo`<0009oo`<000=o
o`<0009oo`<000=oo`<0009oo`@0009oo`<000=oo`@00003Ool0000000<00003Ool0000000800003
Ool00000008000=oo`8000Aoo`8000=oo`8000Aoo`8000=oo`<000=oo`8000=oo`@0009oo`@00003
Ool000000080009oo`<0009oo`@00003Ool000000080009oo`@0009oo`@00003Ool000000080009o
o`@00003Ool0000000<00003Ool000000080009oo`@00003Ool00000008000=oo`<0009oo`<0009o
o`@000=oo`<0009oo`<000=oo`<0009oo`@0009oo`<0009oo`@0009oo`<0009oo`@00003Ool00000
0080009oo`@00003Ool000000080009oo`@0009oo`@00003Ool0000000<00003Ool0000000800003
Ool0000000<00003Ool00000008000=oo`8000=oo`<0009oo`<000=oo`<0009oo`<000Aoo`8000=o
o`@0009oo`<0009oo`@0009oo`8000=oo`<000=oo`8000=oo`<000=oo`<0009oo`<000=oo`<0009o
o`@000=oo`<0009oo`@0009oo`<000=oo`@000Aoo`8000Eoo`00ogooogooE7oo003oOoooOomDOol0
0?mooomooeAoo`00ogooogooE7oo003oOoooOomDOol00?mooomooeAoo`00ogooogooE7oo000KOol0
0`00Oomoo`1AOol01@00Oomoogoo00004Goo00<007ooOol00Woo0P000goo00<007ooOol087oo00L0
07ooOomoo`00Ool00003Ool20004Ool00`00Oomoo`03Ool00`00Oomoo`02Ool00`00Oomoo`03Ool0
0`00Oomoo`02Ool00`00Oomoo`04Ool01000Oomoogoo0P0017oo0P000goo0P0017oo0P000goo00<0
07oo00000goo00<007ooOol017oo00@007ooOomoo`8000Aoo`8000=oo`03001oo`0000=oo`8000Ao
o`8000=oo`8000Aoo`03001oogoo00=oo`03001oogoo009oo`8000Aoo`8000=oo`8000Aoo`8000=o
o`8000Aoo`8000=oo`03001oo`0000=oo`03001oogoo00Aoo`04001oogooOol20004Ool00`00Oomo
o`04Ool01000Oomoogoo0P0017oo0P000goo0P0017oo0P000goo00<007oo00000goo0P0017oo0P00
0goo0P0017oo0P000goo0P0017oo0P0017oo0P000goo0P0017oo0P000goo0P0017oo0P000goo00<0
07oo00000goo0P0017oo0P000goo0P0017oo0P000goo00<007oo00000goo0P0017oo0P000goo0P00
17oo0P000goo0P0017oo0P0017oo0P000goo0P0017oo0P000goo0P0017oo0P000goo00<007oo0000
0goo0P0017oo00<007ooOol00goo00<007ooOol02goo000GOooo003o000b000;Ool001Yoo`8000=l
008000Al008000=l0003001oo`0000=l008000Al008000=l008000Al008000=l008000Al008000Al
008000=l008000Al008000=l008000Al008000=l0005001oogooOol00002Ool00`00O01l0002O002
0003O0020004O0001000Oomoo`001Goo00@007ooOol000Al008000=l008000Al008000=l008000Al
008000Al0004001oogoo0004Ool00`00Oomoo`03Ool01000Oomoo`0017`000@007ooOol000=oo`05
001l07`0O0000002Ool01@00Oomoogoo00000g`000D007ooOomoo`0000Aoo`03001oogoo00=oo`03
001oogoo009oo`03001oogoo00=oo`03001oogoo00=oo`04001oogoo0003O0001@00Oomoogoo0000
17oo00<007ooOol00goo00<007ooOol00goo00<007ooOol00Woo00<007ooOol00goo00<007ooOol0
0Woo00D007ooOomoo`0000=l0004001oogoo0005Ool00`00Oomoo`03Ool00`00Oomoo`02Ool00`00
Oomoo`03Ool00`00Oomoo`02Ool00`00Oomoo`03Ool00`00Oomoo`03Ool01000Oomoo`000g`000D0
07ooOomoo`0000Aoo`05001oogooOol00003O0001@00Oomoogoo000017oo00<007ooOol00goo00<0
07ooOol00Woo00<007ooOol00goo00<007ooOol00Woo00<007ooOol00goo00<007ooOol00goo00<0
07ooOol00Woo00<007ooOol00goo00<007ooOol00Woo00<007ooOol00goo00<007ooOol00goo00<0
07ooOol00Woo00<007ooOol00goo00<007ooOol00Woo00<007ooOol00goo00<007ooOol00goo00<0
07ooOol00Woo00<007ooOol00goo00<007ooOol00Woo00<007ooOol00goo00<007ooOol00goo00<0
07ooOol00Woo00<007ooOol00goo00<007ooOol00Woo00<007ooOol00goo00<007ooOol00Woo00<0
07ooOol00goo00<007ooOol00goo00<007ooOol00Woo00<007ooOol00goo00<007ooOol00Woo00<0
07ooOol00goo00<007ooOol00goo00<007ooOol00Woo00D007ooOomoo`0000=l0004001oogoo000;
Ool001Yoo`8000=l008000Al008000=l0003001oo`0000=l008000Al008000=l008000Al008000=l
008000Al008000Al008000=l008000Al008000=l008000Al008000=l0005001oogooOol00002Ool0
0`00O01l0002O0020003O0020004O0001000Oomoo`001Goo00@007ooOol000Al008000=l008000Al
008000=l008000Al008000Al0004001oogoo0004Ool00`00Oomoo`03Ool01000Oomoo`0017`000@0
07ooOol000=oo`05001l07`0O0000002Ool01@00Oomoogoo00000g`000D007ooOomoo`0000Aoo`03
001oogoo00=oo`03001oogoo009oo`03001oogoo00=oo`03001oogoo00=oo`04001oogoo0003O000
1@00Oomoogoo000017oo00<007ooOol00goo00<007ooOol00goo00<007ooOol00Woo00<007ooOol0
0goo00<007ooOol00Woo00D007ooOomoo`0000=l0004001oogoo0005Ool00`00Oomoo`03Ool00`00
Oomoo`02Ool00`00Oomoo`03Ool00`00Oomoo`02Ool00`00Oomoo`03Ool00`00Oomoo`03Ool01000
Oomoo`000g`000D007ooOomoo`0000Aoo`05001oogooOol00003O0001@00Oomoogoo000017oo00<0
07ooOol00goo00<007ooOol00Woo00<007ooOol00goo00<007ooOol00Woo00<007ooOol00goo00<0
07ooOol00goo00<007ooOol00Woo00<007ooOol00goo00<007ooOol00Woo00<007ooOol00goo00<0
07ooOol00goo00<007ooOol00Woo00<007ooOol00goo00<007ooOol00Woo00<007ooOol00goo00<0
07ooOol00goo00<007ooOol00Woo00<007ooOol00goo00<007ooOol00Woo00<007ooOol00goo00<0
07ooOol00goo00<007ooOol00Woo00<007ooOol00goo00<007ooOol00Woo00<007ooOol00goo00<0
07ooOol00Woo00<007ooOol00goo00<007ooOol00goo00<007ooOol00Woo00<007ooOol00goo00<0
07ooOol00Woo00<007ooOol00goo00<007ooOol00goo00<007ooOol00Woo00D007ooOomoo`0000=l
0004001oogoo000;Ool001Yoo`8000=l008000Al008000=l0003001oo`0000=l008000Al008000=l
008000Al008000=l008000Al008000Al008000=l008000Al008000=l008000Al008000=l0005001o
ogooOol00002OolA0002Ool00`00Oomoo`03Ool01000Oomoo`0017`00P000g`04`0017`000@007oo
Ool000Aoo`03001oogoo00=oo`03001oogoo00H0009oo`04001oogooOol50002Ool01@00Oomoogoo
00000g`000D007ooOomoo`0000Aoo`03001oogoo00=oo`03001oogoo009oo`03001oogoo00=oo`03
001oogoo00=oo`03001oogoo00D000=oo`03001oogoo009oo`03001oogoo00=oo`03001oogoo00=o
o`03001oogoo009oo`03001oogoo00=oo`03001oogoo009oo`04001oogooOol50002Ool00`00Oomo
o`03Ool00`00Oomoo`03Ool00`00Oomoo`02Ool00`00Oomoo`03Ool00`00Oomoo`02Ool00`00Oomo
o`03Ool00`00Oomoo`03Ool00`00Oomoo`050003Ool00`00Oomoo`02Ool01000Oomoogoo1@000goo
00<007ooOol00Woo00<007ooOol00goo00<007ooOol00Woo00<007ooOol00goo00<007ooOol00Woo
00<007ooOol00goo00<007ooOol00goo00<007ooOol00Woo00<007ooOol00goo00<007ooOol00Woo
00<007ooOol00goo00<007ooOol00goo00<007ooOol00Woo00<007ooOol00goo00<007ooOol00Woo
00<007ooOol00goo00<007ooOol00goo00<007ooOol00Woo00<007ooOol00goo00<007ooOol00Woo
00<007ooOol00goo00<007ooOol00goo00<007ooOol00Woo00<007ooOol00goo00<007ooOol00Woo
00<007ooOol00goo00<007ooOol00Woo00<007ooOol00goo00<007ooOol00goo00<007ooOol00Woo
00<007ooOol00goo00<007ooOol00Woo00<007ooOol00goo00<007ooOol00goo00<007ooOol00Woo
00@007ooOomoo`D0009oo`03001oogoo00Uoo`006Woo0P000g`00P0017`00P000g`000<007oo0000
0g`00P0017`00P000g`00P0017`00P000g`00P0017`00P0017`00P000g`00P0017`00P000g`00P00
17`00P000g`000<007ooOol087oo00<007`0O0000W`00P000g`000<007ooOol03goo00<007`0O000
0W`000<007ooOol09Goo00D007`0O01l00000?moogEoo`006Woo0P000g`00P0017`00P000g`000<0
07oo00000g`00P0017`00P000g`00P0017`00P000g`00P0017`00P0017`00P000g`00P0017`00P00
0g`00P0017`00P000g`000<007ooOol087oo00<007`0O0000W`00P000g`000<007ooOol03goo00<0
07`0O0000W`000<007ooOol09Goo00D007`0O01l00000?moogEoo`006Woo0P000g`00P0017`00P00
0g`000<007oo00000g`00P0017`00P000g`00P0017`00P000g`0200017`00P000g`00P0017`01`00
17`00P000g`000<007ooOol087oo2`004Goo1P009goo1@00ogooMGoo000JOol20003O0020004O002
0003O0000`00Ool00003O0020004O0020003O0020004O0020003O0000`00Oomoo`04Ool00`00O01l
0002O0020003O0020004O0000`00Oomoo`03Ool00`00O01l0002O0020003O0000`00Oomoo`3oOooS
Ool001Yoo`8000=l008000Al008000=l0003001oo`0000=l008000Al008000=l008000Al008000=l
0003001oogoo00Aoo`03001l07`0009l008000=l008000Al0003001oogoo00=oo`03001l07`0009l
008000=l0003001oogoo0?moon=oo`006Woo0P000g`00P0017`00P000g`000<007oo00000g`00P00
17`00P000g`00P0017`00P000g`000<007ooOol017oo00<007`0O0000W`00P000g`00P0017`000<0
07ooOol00goo00<007`0O0000W`00P000g`000<007ooOol0ogoohgoo000JOol20003O0020004O002
0003O0000`00Ool00003O0020004O0020003O0020004O0020003O0000`00Oomoo`04Ool00`00O01l
0002O0020003O0070005Ool00`00O01l0002O006003oOooUOol001Yoo`8000=l008000Al008000=l
0003001oo`0000=l008000Al008000=l008000Al008000=l0003001oogoo00Aoo`03001l07`0009l
008000=l0003001oogoo00Uoo`03001l07`0009l0003001oogoo0?moonQoo`006Woo0P000g`00P00
17`00P000g`000<007oo00000g`00P0017`00P000g`00P0017`00P000g`000<007ooOol017oo00<0
07`0O0000W`00P000g`000<007ooOol02Goo00<007`0O0000W`000<007ooOol0ogooj7oo000JOol2
0003O0020004O0020003O0000`00Ool00003O0020004O0020003O0020004O0020003O0000`00Oomo
o`04Ool00`00O01l0002O006000;Ool6003oOooZOol001Yoo`8000=l008000Al008000=l0003001o
o`0000=l008000Al008000=l008000Al008000=l0003001oogoo00Aoo`03001l07`0009l0003001o
ogoo0?moooioo`006Woo0P000g`00P0017`00P000g`000<007oo00000g`00P0017`00P000g`00P00
17`00P000g`000<007ooOol017oo00<007`0O0000W`000<007ooOol0ogoooWoo000JOol20003O002
0004O0020003O0000`00Ool00003O0020004O0020003O0020004O0020003O0000`00Oomoo`04Ool0
0`00O01l0002O0000`00Oomoo`3oOoonOol001Yoo`8000=l008000Al008000=l0003001oo`0000=l
008000Al008000=l008000Al008000=l0003001oogoo00Aoo`03001l07`0009l0003001oogoo0?mo
ooioo`006Woo0P000g`00P0017`00P000g`000<007oo00000g`00P0017`00P000g`00P0017`00P00
0g`000<007ooOol017oo00<007`0O0000W`000<007ooOol0ogoooWoo000JOol20003O0020004O002
0003O0000`00Ool00003O0020004O0020003O0020004O0020003O0000`00Oomoo`04Ool00`00O01l
0002O0000`00Oomoo`3oOoonOol001Yoo`8000=l008000Al008000=l0003001oo`0000=l008000Al
008000=l008000Al008000=l0003001oogoo00Aoo`03001l07`0009l0003001oogoo0?moooioo`00
6Woo0P000g`00P0017`00P000g`000<007oo00000g`00P0017`00P000g`00P0017`00P000g`000<0
07ooOol017oo00<007`0O0000W`000<007ooOol0ogoooWoo000JOol20003O0020004O0020003O000
0`00Ool00003O0020004O0020003O0020004O0020003O0000`00Oomoo`04Ool00`00O01l0002O000
0`00Oomoo`3oOoonOol001Yoo`8000=l008000Al008000=l0003001oo`0000=l008000Al008000=l
008000Al008000=l0003001oogoo00Aoo`03001l07`0009l0003001oogoo0?moooioo`006Woo0P00
0g`00P0017`00P000g`000<007oo00000g`00P0017`00P000g`00P0017`00P000g`000<007ooOol0
17oo1P00ogooogoo0Goo000JOol20003O0020004O0020003O0000`00Ool00003O0020004O0020003
O0020004O0020003O0000`00Oomoo`3oOoooOol;Ool001Yoo`8000=l008000Al008000=l0003001o
o`0000=l008000Al008000=l008000Al008000=l0003001oogoo0?mooomoo`]oo`006Woo0P000g`0
0P0017`00P000g`000<007oo00000g`00P0017`00P000g`00P0017`00P000g`000<007ooOol0ogoo
ogoo2goo000JOol20003O0020004O0020003O0000`00Ool00003O0020004O0020003O0020004O002
0003O0000`00Oomoo`3oOoooOol;Ool001Yoo`8000=l008000Al008000=l0003001oo`0000=l0080
00Al008000=l008000Al008000=l0003001oogoo0?mooomoo`]oo`006Woo0P000g`00P0017`00P00
0g`000<007oo00000g`00P0017`00P000g`00P0017`00P000g`000<007ooOol0ogooogoo2goo000J
Ool20003O0020004O0020003O0000`00Ool00003O0020004O0020003O0020004O0020003O0000`00
Oomoo`3oOoooOol;Ool001Yoo`8000=l008000Al008000=l0003001oo`0000=l008000Al008000=l
008000Al008000=l0003001oogoo0?mooomoo`]oo`006Woo0P000g`00P0017`00P000g`000<007oo
00000g`00P0017`00P000g`00P0017`00P000g`000<007ooOol0ogooogoo2goo000JOol20003O002
0004O0020003O0000`00Ool00003O0020004O0020003O0020004O006003oOoooOol=Ool001Yoo`80
00=l008000Al008000=l0003001oo`0000=l008000Al008000=l008000Al0003001oogoo0?mooomo
oa1oo`006Woo0P000g`00P0017`00P000g`000<007oo00000g`00P0017`00P000g`00P0017`000<0
07ooOol0ogooogoo47oo000JOol20003O0020004O0020003O0000`00Ool00003O0020004O0020003
O0020004O0000`00Oomoo`3oOoooOol@Ool001Yoo`8000=l008000Al008000=l0003001oo`0000=l
008000Al008000=l00L00?mooomooa9oo`006Woo0P000g`00P0017`00P000g`000<007oo00000g`0
0P0017`00P000g`000<007ooOol0ogooogoo5Woo000JOol20003O0020004O0020003O0000`00Ool0
0003O0020004O0020003O0000`00Oomoo`3oOoooOolFOol001Yoo`8000=l008000Al008000=l0003
001oo`0000=l008000Al008000=l0003001oogoo0?mooomooaIoo`006Woo0P000g`00P0017`00P00
0g`000<007oo00000g`00P0017`00P000g`000<007ooOol0ogooogoo5Woo000JOol20003O0020004
O0020003O0000`00Ool00003O0020004O0020003O0000`00Oomoo`3oOoooOolFOol001Yoo`8000=l
008000Al008000=l0003001oo`0000=l008000Al008000=l0003001oogoo0?mooomooaIoo`006Woo
0P000g`00P0017`00P000g`000<007oo00000g`00P0017`00P000g`000<007ooOol0ogooogoo5Woo
000JOol20003O0020004O0020003O0000`00Ool00003O0020004O0020003O0000`00Oomoo`3oOooo
OolFOol001Yoo`8000=l008000Al008000=l0003001oo`0000=l008000Al008000=l0003001oogoo
0?mooomooaIoo`006Woo0P000g`00P0017`00P000g`000<007oo00000g`00P0017`00P000g`000<0
07ooOol0ogooogoo5Woo000JOol20003O0020004O0020003O0000`00Ool00003O0020004O0020003
O0000`00Oomoo`3oOoooOolFOol001Yoo`8000=l008000Al008000=l0003001oo`0000=l008000Al
008000=l0003001oogoo0?mooomooaIoo`006Woo0P000g`00P0017`00P000g`000<007oo00000g`0
3000ogooogoo67oo000JOol20003O0020004O0020003O0000`00Ool00003O0000`00Oomoo`3oOooo
OolQOol001Yoo`8000=l008000Al008000=l0003001oo`0000=l0003001oogoo0?mooomoob5oo`00
6Woo0P000g`00P0017`00P000g`000<007oo00000g`000<007ooOol0ogooogoo8Goo000JOol20003
O0020004O0020003O0000`00Ool00003O0000`00Oomoo`3oOoooOolQOol001Yoo`8000=l008000Al
008000=l0003001oo`0000=l0003001oogoo0?mooomoob5oo`006Woo0P000g`00P0017`00P000g`0
00<007oo00000g`000<007ooOol0ogooogoo8Goo000JOol20003O0020004O0020003O0000`00Ool0
0004003oOoooOolSOol001Yoo`8000=l008000Al008000=l0003001oogoo0?mooomoobMoo`006Woo
0P000g`00P0017`00P000g`000<007ooOol0ogooogoo9goo000JOol20003O0020004O0020003O000
0`00Oomoo`3oOoooOolWOol001Yoo`8000=l008000Al008000=l0003001oogoo0?mooomoobMoo`00
6Woo0P000g`00P0017`00P000g`000<007ooOol0ogooogoo9goo000JOol20003O0020004O0020003
O0000`00Oomoo`3oOoooOolWOol001Yoo`8000=l008000Al008000=l0003001oogoo0?mooomoobMo
o`006Woo0P000g`00P0017`00P000g`000<007ooOol0ogooogoo9goo0008Ool40003Ool20009Ool2
0003O0020004O0020003O0000`00Oomoo`3oOoooOolWOol000Uoo`03001oogoo009oo`04001oogoo
0008Ool20003O0020004O0020003O0000`00Oomoo`3oOoooOolWOol000Yoo`05001oogooOol00002
Ool00`00Oomoo`06Ool20003O0020004O0020003O0000`00Oomoo`3oOoooOolWOol000]oo`04001o
ogoo0002Ool00`00Oomoo`06Ool20003O0020004O0020003O0000`00Oomoo`3oOoooOolWOol000Qo
o`04001oogoo0002Ool01000Oomoo`0027oo0P000g`00P0017`00P000g`000<007ooOol0ogooogoo
9goo0009Ool20004Ool20009Ool20003O0020004O0020003O0000`00Oomoo`3oOoooOolWOol001Yo
o`8000=l008000Al008000=l0003001oogoo0?mooomoobMoo`006Woo0P000g`00P0017`00P000g`0
00<007ooOol0ogooogoo9goo000JOol20003O0020004O0020003O0000`00Oomoo`3oOoooOolWOol0
01Yoo`8000=l008000Al008000=l0003001oogoo0?mooomoobMoo`006Woo0P000g`00P0017`00P00
0g`000<007ooOol0ogooogoo9goo000JOol20003O0020004O0020003O0000`00Oomoo`3oOoooOolW
Ool001Yoo`8000=l008000Al008000=l0003001oogoo0?mooomoobMoo`006Woo0P000g`00P0017`0
0P000g`000<007ooOol0ogooogoo9goo000JOol20003O0020004O0020003O0000`00Oomoo`3oOooo
OolWOol001Yoo`8000=l008000Al008000=l0003001oogoo0?mooomoobMoo`006Woo0P000g`00P00
17`00P000g`000<007ooOol0ogooogoo9goo000JOol20003O0020004O0020003O0000`00Oomoo`3o
OoooOolWOol001Yoo`8000=l008000Al008000=l0003001oogoo0?mooomoobMoo`006Woo0P000g`0
0P0017`00P000g`000<007ooOol0ogooogoo9goo000JOol20003O0020004O0020003O0000`00Oomo
o`3oOoooOolWOol001Yoo`8000=l008000Al008000=l0003001oogoo0?mooomoobMoo`006Woo0P00
0g`00P0017`00P000g`000<007ooOol0ogooogoo9goo000JOol20003O0020004O0020003O0000`00
Oomoo`3oOoooOolWOol001Yoo`8000=l008000Al008000=l0003001oogoo0?mooomoobMoo`006Woo
0P000g`00P0017`00P000g`000<007ooOol0ogooogoo9goo000JOol20003O0020004O0020003O000
0`00Oomoo`3oOoooOolWOol001Yoo`8000=l008000Al008000=l0003001oogoo0?mooomoobMoo`00
6Woo0P000g`00P0017`00P000g`000<007ooOol0ogooogoo9goo000JOol20003O0020004O0020003
O0000`00Oomoo`3oOoooOolWOol001Yoo`8000=l008000Al008000=l0003001oogoo0?mooomoobMo
o`006Woo0P000g`00P0017`00P000g`000<007ooOol0ogooogoo9goo000JOol20003O0020004O002
0003O0000`00Oomoo`3oOoooOolWOol001Yoo`8000=l008000Al008000=l0003001oogoo0?mooomo
obMoo`006Woo0P000g`00P0017`00P000g`000<007ooOol0ogooogoo9goo000JOol20003O0020004
O0020003O0000`00Oomoo`3oOoooOolWOol001Yoo`8000=l008000Al008000=l0003001oogoo0?mo
oomoobMoo`006Woo0P000g`00P0017`00P000g`000<007ooOol0ogooogoo9goo000JOol20003O002
0004O0020003O0000`00Oomoo`3oOoooOolWOol001Yoo`8000=l008000Al008000=l0003001oogoo
0?mooomoobMoo`006Woo0P000g`00P0017`00P000g`000<007ooOol0ogooogoo9goo000JOol20003
O0020004O0020003O0000`00Oomoo`3oOoooOolWOol001Yoo`8000=l008000Al008000=l0003001o
ogoo0?mooomoobMoo`006Woo0P000g`00P0017`00P000g`000<007ooOol0ogooogoo9goo000JOol2
0003O0020004O0020003O0000`00Oomoo`3oOoooOolWOol001Yoo`8000=l008000Al008000=l0003
001oogoo0?mooomoobMoo`006Woo0P000g`00P0017`00P000g`000<007ooOol0ogooogoo9goo000J
Ool20003O0020004O0020003O0000`00Oomoo`3oOoooOolWOol001Yoo`8000=l008000Al008000=l
0003001oogoo0?mooomoobMoo`006Woo0P000g`00P0017`00P000g`000<007ooOol0ogooogoo9goo
000JOol20003O0020004O0020003O0000`00Oomoo`3oOoooOolWOol001Yoo`8000=l008000Al0080
00=l0003001oogoo0?mooomoobMoo`006Woo0P000g`00P0017`00P000g`000<007ooOol0ogooogoo
9goo000JOol20003O0020004O0020003O0000`00Oomoo`3oOoooOolWOol001Yoo`8000=l008000Al
008000=l0003001oogoo0?mooomoobMoo`006Woo0P000g`00P0017`00P000g`000<007ooOol0ogoo
ogoo9goo000JOol20003O0020004O0020003O0000`00Oomoo`3oOoooOolWOol001Yoo`8000=l0080
00Al008000=l0003001oogoo0?mooomoobMoo`006Woo0P000g`00P0017`00P000g`000<007ooOol0
ogooogoo9goo000JOol20003O0020004O0020003O0000`00Oomoo`3oOoooOolWOol001Yoo`8000=l
008000Al008000=l0003001oogoo0?mooomoobMoo`006Woo0P000g`00P0017`00P000g`000<007oo
Ool0ogooogoo9goo000JOol20003O0020004O0020003O0000`00Oomoo`3oOoooOolWOol001Yoo`80
00=l008000Al008000=l0003001oogoo0?mooomoobMoo`006Woo0P000g`00P0017`00P000g`000<0
07ooOol0ogooogoo9goo000JOol20003O0020004O0020003O0000`00Oomoo`3oOoooOolWOol001Yo
o`8000=l008000Al008000=l0003001oogoo0?mooomoobMoo`006Woo0P000g`00P0017`00P000g`0
00<007ooOol0ogooogoo9goo000JOol20003O0020004O0020003O0000`00Oomoo`3oOoooOolWOol0
00Uoo`<000=oo`8000Uoo`8000=l008000Al008000=l0003001oogoo0?mooomoobMoo`002Woo00D0
07ooOomoo`00009oo`03001oogoo00Ioo`8000=l008000Al008000=l0003001oogoo0?mooomoobMo
o`0027oo10000Woo00@007ooOol000Qoo`8000=l008000Al008000=l0003001oogoo0?mooomoobMo
o`0027oo00<007oo00000goo00@007ooOol000Qoo`8000=l008000Al008000=l0003001oogoo0?mo
oomoobMoo`0027oo00<007oo00000goo00@007ooOol000Qoo`8000=l008000Al008000=l0003001o
ogoo0?mooomoobMoo`002Goo0P0017oo0P002Goo0P000g`00P0017`01P00ogooogoo:Goo000JOol2
0003O0020004O0000`00Oomoo`3oOoooOol/Ool001Yoo`8000=l008000Al0003001oogoo0?mooomo
obaoo`006Woo0P000g`00P0017`000<007ooOol0ogooogoo;7oo000JOol20003O0020004O0000`00
Oomoo`3oOoooOol/Ool001Yoo`8000=l008000Al0003001oogoo0?mooomoobaoo`006Woo0P000g`0
0P0017`000<007ooOol0ogooogoo;7oo000JOol20003O0020004O0000`00Oomoo`3oOoooOol/Ool0
01Yoo`8000=l008000Al0003001oogoo0?mooomoobaoo`006Woo0P000g`00P0017`000<007ooOol0
ogooogoo;7oo000JOol20003O0020004O0000`00Oomoo`3oOoooOol/Ool001Yoo`8000=l008000Al
0003001oogoo0?mooomoobaoo`006Woo0P000g`00P0017`000<007ooOol0ogooogoo;7oo000JOol2
0003O0020004O0000`00Oomoo`3oOoooOol/Ool001Yoo`8000=l008000Al0003001oogoo0?mooomo
obaoo`006Woo0P000g`00P0017`000<007ooOol0ogooogoo;7oo000JOol20003O0020004O0000`00
Oomoo`3oOoooOol/Ool001Yoo`8000=l008000Al0003001oogoo0?mooomoobaoo`006Woo0P000g`0
0P0017`000<007ooOol0ogooogoo;7oo000JOol20003O0020004O0000`00Oomoo`3oOoooOol/Ool0
01Yoo`8000=l008000Al0003001oogoo0?mooomoobaoo`006Woo0P000g`00P0017`000<007ooOol0
ogooogoo;7oo000JOol20003O0020004O0000`00Oomoo`3oOoooOol/Ool001Yoo`8000=l008000Al
0003001oogoo0?mooomoobaoo`006Woo0P000g`00P0017`000<007ooOol0ogooogoo;7oo000JOol2
0003O0020004O0000`00Oomoo`3oOoooOol/Ool001Yoo`8000=l008000Al0003001oogoo0?mooomo
obaoo`006Woo0P000g`00P0017`000<007ooOol0ogooogoo;7oo000JOol20003O0020004O0000`00
Oomoo`3oOoooOol/Ool001Yoo`8000=l008000Al0003001oogoo0?mooomoobaoo`006Woo0P000g`0
0P0017`000<007ooOol0ogooogoo;7oo000JOol20003O0020004O0000`00Oomoo`3oOoooOol/Ool0
01Yoo`8000=l008000Al0003001oogoo0?mooomoobaoo`006Woo0P000g`00P0017`000<007ooOol0
ogooogoo;7oo000JOol20003O0020004O0000`00Oomoo`3oOoooOol/Ool001Yoo`8000=l008000Al
0003001oogoo0?mooomoobaoo`006Woo0P000g`00P0017`000<007ooOol0ogooogoo;7oo000JOol2
0003O0020004O0000`00Oomoo`3oOoooOol/Ool001Yoo`8000=l008000Al0003001oogoo0?mooomo
obaoo`006Woo0P000g`00P0017`000<007ooOol0ogooogoo;7oo000JOol20003O0020004O0000`00
Oomoo`3oOoooOol/Ool001Yoo`8000=l008000Al0003001oogoo0?mooomoobaoo`006Woo0P000g`0
0P0017`000<007ooOol0ogooogoo;7oo000JOol20003O0020004O0000`00Oomoo`3oOoooOol/Ool0
01Yoo`8000=l008000Al0003001oogoo0?mooomoobaoo`006Woo0P000g`00P0017`000<007ooOol0
ogooogoo;7oo000JOol20003O0020004O0000`00Oomoo`3oOoooOol/Ool001Yoo`8000=l008000Al
0003001oogoo0?mooomoobaoo`006Woo0P000g`00P0017`000<007ooOol0ogooogoo;7oo000JOol2
0003O0020004O0000`00Oomoo`3oOoooOol/Ool001Yoo`8000=l008000Al0003001oogoo0?mooomo
obaoo`006Woo0P000g`00P0017`000<007ooOol0ogooogoo;7oo000JOol20003O0020004O0000`00
Oomoo`3oOoooOol/Ool001Yoo`8000=l008000Al0003001oogoo0?mooomoobaoo`006Woo0P000g`0
0P0017`000<007ooOol0ogooogoo;7oo000JOol20003O0020004O0000`00Oomoo`3oOoooOol/Ool0
01Yoo`8000=l008000Al0003001oogoo0?mooomoobaoo`006Woo0P000g`00P0017`000<007ooOol0
ogooogoo;7oo000JOol20003O0020004O0000`00Oomoo`3oOoooOol/Ool001Yoo`8000=l008000Al
0003001oogoo0?mooomoobaoo`006Woo0P000g`00P0017`000<007ooOol0ogooogoo;7oo000JOol2
0003O0020004O0000`00Oomoo`3oOoooOol/Ool001Yoo`8000=l008000Al0003001oogoo0?mooomo
obaoo`006Woo0P000g`00P0017`000<007ooOol0ogooogoo;7oo0009Ool20004Ool20009Ool20003
O0020004O0000`00Oomoo`3oOoooOol/Ool000Qoo`04001oogoo0002Ool01000Oomoo`0027oo0P00
0g`00P0017`000<007ooOol0ogooogoo;7oo0008Ool01000Oomoo`000Woo00@007ooOol000Qoo`80
00=l008000Al0003001oogoo0?mooomoobaoo`0027oo0`000goo00@007ooOol000Qoo`8000=l0080
00Al0003001oogoo0?mooomoobaoo`0027oo00<007ooOol00goo00@007ooOol000Qoo`8000=l0080
00Al0003001oogoo0?mooomoobaoo`002Goo0`000goo0P002Goo0P000g`00P0017`000<007ooOol0
ogooogoo;7oo000JOol20003O0020004O0000`00Oomoo`3oOoooOol/Ool001Yoo`8000=l008000Al
0003001oogoo0?mooomoobaoo`006Woo0P000g`00P0017`000<007ooOol0ogooogoo;7oo000JOol2
0003O0020004O0000`00Oomoo`3oOoooOol/Ool001Yoo`8000=l008000Al0003001oogoo0?mooomo
obaoo`006Woo0P000g`00P0017`000<007ooOol0ogooogoo;7oo000JOol20003O0020004O0000`00
Oomoo`3oOoooOol/Ool001Yoo`8000=l008000Al0003001oogoo0?mooomoobaoo`006Woo0P000g`0
0P0017`000<007ooOol0ogooogoo;7oo000JOol20003O0020004O0000`00Oomoo`3oOoooOol/Ool0
01Yoo`8000=l008000Al0003001oogoo0?mooomoobaoo`006Woo0P000g`00P0017`000<007ooOol0
ogooogoo;7oo000JOol20003O0020004O0000`00Oomoo`3oOoooOol/Ool001Yoo`8000=l008000Al
0003001oogoo0?mooomoobaoo`006Woo0P000g`00P0017`000<007ooOol0ogooogoo;7oo000JOol2
0003O0020004O0000`00Oomoo`3oOoooOol/Ool001Yoo`8000=l008000Al0003001oogoo0?mooomo
obaoo`006Woo0P000g`00P0017`000<007ooOol0ogooogoo;7oo000JOol20003O0020004O0000`00
Oomoo`3oOoooOol/Ool001Yoo`8000=l008000Al0003001oogoo0?mooomoobaoo`006Woo0P000g`0
0P0017`000<007ooOol0ogooogoo;7oo000JOol20003O0020004O0000`00Oomoo`3oOoooOol/Ool0
01Yoo`8000=l008000Al0003001oogoo0?mooomoobaoo`006Woo0P000g`00P0017`000<007ooOol0
ogooogoo;7oo000JOol20003O0020004O0000`00Oomoo`3oOoooOol/Ool001Yoo`8000=l008000Al
0003001oogoo0?mooomoobaoo`006Woo0P000g`00P0017`000<007ooOol0ogooogoo;7oo000JOol2
0003O0020004O0000`00Oomoo`3oOoooOol/Ool001Yoo`8000=l008000Al0003001oogoo0?mooomo
obaoo`006Woo0P000g`00P0017`000<007ooOol0ogooogoo;7oo000JOol20003O0020004O0000`00
Oomoo`3oOoooOol/Ool001Yoo`8000=l008000Al0003001oogoo0?mooomoobaoo`006Woo0P000g`0
0P0017`000<007ooOol0ogooogoo;7oo000JOol20003O0020004O0000`00Oomoo`3oOoooOol/Ool0
01Yoo`8000=l008000Al0003001oogoo0?mooomoobaoo`006Woo0P000g`00P0017`000<007ooOol0
ogooogoo;7oo000JOol20003O0020004O0000`00Oomoo`3oOoooOol/Ool001Yoo`8000=l008000Al
0003001oogoo0?mooomoobaoo`006Woo0P000g`00P0017`000<007ooOol0ogooogoo;7oo000JOol2
0003O0020004O0000`00Oomoo`3oOoooOol/Ool001Yoo`8000=l008000Al0003001oogoo0?mooomo
obaoo`006Woo0P000g`00P0017`000<007ooOol0ogooogoo;7oo000JOol20003O0020004O0000`00
Oomoo`3oOoooOol/Ool001Yoo`8000=l008000Al0003001oogoo0?mooomoobaoo`006Woo0P000g`0
0P0017`000<007ooOol0ogooogoo;7oo000JOol20003O0020004O0000`00Oomoo`3oOoooOol/Ool0
01Yoo`8000=l008000Al0003001oogoo0?mooomoobaoo`006Woo0P000g`00P0017`000<007ooOol0
ogooogoo;7oo000JOol20003O0020004O0000`00Oomoo`3oOoooOol/Ool001Yoo`8000=l008000Al
0003001oogoo0?mooomoobaoo`006Woo0P000g`00P0017`000<007ooOol0ogooogoo;7oo000JOol2
0003O0020004O0000`00Oomoo`3oOoooOol/Ool001Yoo`8000=l008000Al0003001oogoo0?mooomo
obaoo`006Woo0P000g`00P0017`000<007ooOol0ogooogoo;7oo000JOol20003O0020004O0000`00
Oomoo`3oOoooOol/Ool001Yoo`8000=l008000Al0003001oogoo0?mooomoobaoo`006Woo0P000g`0
0P0017`000<007ooOol0ogooogoo;7oo000JOol20003O0020004O0000`00Oomoo`3oOoooOol/Ool0
01Yoo`8000=l008000Al0003001oogoo0?mooomoobaoo`006Woo0P000g`00P0017`000<007ooOol0
ogooogoo;7oo000JOol20003O0020004O0000`00Oomoo`3oOoooOol/Ool001Yoo`8000=l008000Al
0003001oogoo0?mooomoobaoo`006Woo0P000g`00P0017`000<007ooOol0ogooogoo;7oo0009Ool2
0004Ool20009Ool20003O0020004O0000`00Oomoo`3oOoooOol/Ool000Qoo`04001oogoo0002Ool0
1000Oomoo`0027oo0P000g`00P0017`000<007ooOol0ogooogoo;7oo0008Ool01000Oomoo`000Woo
00@007ooOol000Qoo`8000=l008000Al0003001oogoo0?mooomoobaoo`002Goo0P000goo00@007oo
Ool000Qoo`8000=l008000Al0003001oogoo0?mooomoobaoo`0027oo00@007ooOol0009oo`04001o
ogoo0008Ool20003O0020004O0000`00Oomoo`3oOoooOol/Ool000Uoo`8000Aoo`8000Uoo`8000=l
008000Al0003001oogoo0?mooomoobaoo`006Woo0P000g`00P0017`000<007ooOol0ogooogoo;7oo
000JOol20003O0020004O0000`00Oomoo`3oOoooOol/Ool001Yoo`8000=l008000Al0003001oogoo
0?mooomoobaoo`006Woo0P000g`01`00ogooogoo;Woo000JOol20003O0000`00Oomoo`3oOoooOolb
Ool001Yoo`8000=l0003001oogoo0?mooomooc9oo`006Woo0P000g`000<007ooOol0ogooogoo<Woo
000JOol20003O0000`00Oomoo`3oOoooOolbOol001Yoo`8000=l0003001oogoo0?mooomooc9oo`00
6Woo0P000g`000<007ooOol0ogooogoo<Woo000JOol20003O0000`00Oomoo`3oOoooOolbOol001Yo
o`8000=l0003001oogoo0?mooomooc9oo`006Woo0P000g`000<007ooOol0ogooogoo<Woo000JOol2
0003O0000`00Oomoo`3oOoooOolbOol001Yoo`8000=l0003001oogoo0?mooomooc9oo`006Woo0P00
0g`000<007ooOol0ogooogoo<Woo000JOol20003O0000`00Oomoo`3oOoooOolbOol001Yoo`8000=l
0003001oogoo0?mooomooc9oo`006Woo0P000g`000<007ooOol0ogooogoo<Woo000JOol20003O000
0`00Oomoo`3oOoooOolbOol001Yoo`8000=l0003001oogoo0?mooomooc9oo`006Woo0P000g`000<0
07ooOol0ogooogoo<Woo000JOol20003O0000`00Oomoo`3oOoooOolbOol001Yoo`8000=l0003001o
ogoo0?mooomooc9oo`006Woo0P000g`000<007ooOol0ogooogoo<Woo000JOol20003O0000`00Oomo
o`3oOoooOolbOol001Yoo`8000=l0003001oogoo0?mooomooc9oo`006Woo0P000g`000<007ooOol0
ogooogoo<Woo000JOol20003O0000`00Oomoo`3oOoooOolbOol001Yoo`8000=l0003001oogoo0?mo
oomooc9oo`006Woo0P000g`000<007ooOol0ogooogoo<Woo000JOol20003O0000`00Oomoo`3oOooo
OolbOol001Yoo`8000=l0003001oogoo0?mooomooc9oo`006Woo0P000g`000<007ooOol0ogooogoo
<Woo000JOol20003O0000`00Oomoo`3oOoooOolbOol001Yoo`8000=l0003001oogoo0?mooomooc9o
o`006Woo0P000g`000<007ooOol0ogooogoo<Woo000JOol20003O0000`00Oomoo`3oOoooOolbOol0
01Yoo`8000=l0003001oogoo0?mooomooc9oo`006Woo0P000g`000<007ooOol0ogooogoo<Woo000J
Ool20003O0000`00Oomoo`3oOoooOolbOol001Yoo`8000=l0003001oogoo0?mooomooc9oo`006Woo
0P000g`000<007ooOol0ogooogoo<Woo000JOol20003O0000`00Oomoo`3oOoooOolbOol001Yoo`80
00=l0003001oogoo0?mooomooc9oo`006Woo0P000g`000<007ooOol0ogooogoo<Woo000JOol20003
O0000`00Oomoo`3oOoooOolbOol001Yoo`8000=l0003001oogoo0?mooomooc9oo`006Woo0P000g`0
00<007ooOol0ogooogoo<Woo000JOol20003O0000`00Oomoo`3oOoooOolbOol001Yoo`8000=l0003
001oogoo0?mooomooc9oo`006Woo0P000g`000<007ooOol0ogooogoo<Woo000JOol20003O0000`00
Oomoo`3oOoooOolbOol001Yoo`8000=l0003001oogoo0?mooomooc9oo`006Woo0P000g`000<007oo
Ool0ogooogoo<Woo000JOol20003O0000`00Oomoo`3oOoooOolbOol001Yoo`8000=l0003001oogoo
0?mooomooc9oo`006Woo0P000g`000<007ooOol0ogooogoo<Woo000JOol20003O0000`00Oomoo`3o
OoooOolbOol001Yoo`8000=l0003001oogoo0?mooomooc9oo`006Woo0P000g`000<007ooOol0ogoo
ogoo<Woo000JOol20003O0000`00Oomoo`3oOoooOolbOol001Yoo`8000=l0003001oogoo0?mooomo
oc9oo`000Woo0`0017oo0P0017oo0P002Goo0P000g`000<007ooOol0ogooogoo<Woo0003Ool00`00
Oomoo`02Ool01000Oomoo`000Woo00@007ooOol000Qoo`8000=l0003001oogoo0?mooomooc9oo`00
0goo00<007ooOol00Woo00@007ooOol0009oo`04001oogoo0008Ool20003O0000`00Oomoo`3oOooo
OolbOol000=oo`03001oogoo009oo`04001oogoo0002Ool01000Oomoo`002Goo17`0ogooogoo=Goo
0003Ool00`00Oomoo`02Ool01000Oomoo`000Woo00@007ooOol000Uoo`Al0?mooomoocEoo`000Woo
0P001Goo0P0017oo0P002Woo17`0ogooogoo=Goo000KOol4O03oOoooOoleOol00001\
\>"],
  ImageRangeCache->{{{0, 593}, {365.938, 0}} -> {-4.27609, -4.62836, 
  0.178907, 0.289478}}]
}, Closed]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Comparison with MonteCarloProbability[]", "SubsectionIcon",
  CellTags->"Comparison with MonteCarloProbability"],

Cell["\<\
It may be more efficient to use the alternative Monte Carlo method \
given above, which traces back to successive coalescences, rather than to \
succssive mutations or coalescences. One could either calculate the \
probability separately for each ordering, or choose random orderings; the \
former is more efficient where there is a moderate number of orders.\
\>", 
  "Text"],

Cell[" In this example, there are 4 possible orderings:", "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[
    \(orders = PossibleCoalescenceOrder[g]; orders // TableForm\)], "Input",
  CellLabel->"In[173]:="],

Cell[BoxData[
    TagBox[GridBox[{
          {"a", "b", "c", "d", "e", "f", "4", "1", "2", "3", "5", "6"},
          {"a", "b", "c", "d", "e", "f", "1", "4", "2", "3", "5", "6"},
          {"a", "b", "c", "d", "e", "f", "1", "2", "4", "3", "5", "6"},
          {"a", "b", "c", "d", "e", "f", "1", "2", "3", "4", "5", "6"}
          },
        RowSpacings->1,
        ColumnSpacings->3,
        RowAlignments->Baseline,
        ColumnAlignments->{Left}],
      (TableForm[ #]&)]], "Output",
  CellLabel->"Out[173]//TableForm="]
}, Closed]],

Cell["\<\
ss[] calculates a table of MonteCarloProbability[] for a given \
order:\
\>", "MathCaption"],

Cell[BoxData[
    \(\(ss[o_, \[Phi]_, seed_] := 
      \(ss[o, \[Phi], seed] = 
        MonteCarloProbability[g, o, \(NumberOfMutations[g, #]&\)/@o, 
          \[Theta], \[Phi], 1000]\); \)\)], "Input",
  CellLabel->"In[190]:="],

Cell["\<\
mn[], se[] calculate numerical values for the mean and standard \
errors, for given orders and given \[Theta].  (Symbolic expressions would be \
unwieldy):\
\>", "MathCaption"],

Cell[BoxData[
    \(mn[o_, \[Theta]1_, \[Phi]_, seed_] := 
      \(mn[o, \[Theta]1, \[Phi], seed] = 
        Mean[ss[o, \[Phi], seed] /. \[Theta] \[Rule] \[Theta]1]\); \n
    se[o_, \[Theta]1_, \[Phi]_, seed_] := 
      \(se[o, \[Theta]1, \[Phi], seed] = 
        StandardErrorOfSampleMean[
          ss[o, \[Phi], seed] /. \[Theta] \[Rule] \[Theta]1]\); \)], "Input",
  CellLabel->"In[191]:="],

Cell[BoxData[
    \(mnO[\[Theta]_, \[Phi]_, seed_] := 
      \(mnO[\[Theta], \[Phi], seed] = 
        \(mn[#, \[Theta], \[Phi], seed]&\)/@orders\); \n
    seO[\[Theta]_, \[Phi]_, seed_] := 
      \(seO[\[Theta], \[Phi], seed] = 
        \(se[#, \[Theta], \[Phi], seed]&\)/@orders\); \)], "Input",
  CellLabel->"In[192]:="],

Cell[BoxData[
    \(\(tt[\[Theta]1_, \[Phi]_, j_] := 
      \(tt[\[Theta]1, \[Phi], j] = 
        Module[{ttt, ex = ExactProbability[g, \[Theta]1]}, \n\t\t\t
          ttt = \({Drop[Drop[#, 6], \(-2\)], mn[#, \[Theta]1, \[Phi], j], 
                  se[#, \[Theta]1, \[Phi], j], ex}&\)/@orders; \n
          Append[ttt, {Total, Plus@@mnO[\[Theta]1, \[Phi], j], 
                \@Plus@@\(\((seO[\[Theta]1, \[Phi], j])\)\^2\), ex}] // 
            TableForm]\); \)\)], "Input",
  CellLabel->"In[193]:="],

Cell[CellGroupData[{

Cell[BoxData[
    \(tt[1. , 1. , 1]\)], "Input",
  CellLabel->"In[182]:="],

Cell[BoxData[
    InterpretationBox[GridBox[{
          {GridBox[{
                {"4"},
                {"1"},
                {"2"},
                {"3"}
                },
              RowSpacings->0.25,
              ColumnSpacings->1,
              RowAlignments->Baseline,
              ColumnAlignments->{Left}], "1.87015633614935907`*^-19", 
            "2.44170896788019886`*^-20", "1.72735923801524471`*^-16"},
          {GridBox[{
                {"1"},
                {"4"},
                {"2"},
                {"3"}
                },
              RowSpacings->0.25,
              ColumnSpacings->1,
              RowAlignments->Baseline,
              ColumnAlignments->{Left}], "1.37610228120432576`*^-17", 
            "3.41982677821049918`*^-18", "1.72735923801524471`*^-16"},
          {GridBox[{
                {"1"},
                {"2"},
                {"4"},
                {"3"}
                },
              RowSpacings->0.25,
              ColumnSpacings->1,
              RowAlignments->Baseline,
              ColumnAlignments->{Left}], "5.41736280009157589`*^-17", 
            "6.5859711126311069`*^-18", "1.72735923801524471`*^-16"},
          {GridBox[{
                {"1"},
                {"2"},
                {"3"},
                {"4"}
                },
              RowSpacings->0.25,
              ColumnSpacings->1,
              RowAlignments->Baseline,
              ColumnAlignments->{Left}], "7.08048158374666147`*^-17", 
            "4.01937852946252682`*^-18", "1.72735923801524471`*^-16"},
          {"Total", "1.38926482284040609`*^-16", "8.43956341564833323`*^-18", 
            "1.72735923801524471`*^-16"}
          },
        RowSpacings->1,
        ColumnSpacings->3,
        RowAlignments->Baseline,
        ColumnAlignments->{Left}],
      TableForm[ {{{4, 1, 2, 3}, 1.8701563361493595*^-19, 
        2.4417089678801987*^-20, 1.7273592380152449*^-16}, {{1, 4, 2, 3}, 
        1.3761022812043259*^-17, 3.4198267782104993*^-18, 
        1.7273592380152449*^-16}, {{1, 2, 4, 3}, 5.4173628000915761*^-17, 
        6.5859711126311069*^-18, 1.7273592380152449*^-16}, {{1, 2, 3, 4}, 
        7.0804815837466627*^-17, 4.0193785294625274*^-18, 
        1.7273592380152449*^-16}, {Total, 1.3892648228404059*^-16, 
        8.4395634156483339*^-18, 1.7273592380152449*^-16}}]]], "Output",
  CellLabel->"Out[182]//TableForm="]
}, Closed]],

Cell["\<\
There is poor agreement with the exact calculation from \
ExactProbability[] (last column): the t-statistic is significant.  \
\>", 
  "Text"],

Cell["\<\
Running another 1000 replicates gives a substantially different \
answer:\
\>", "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[
    \(tt[1. , 1. , 3]\)], "Input",
  CellLabel->"In[183]:="],

Cell[BoxData[
    InterpretationBox[GridBox[{
          {GridBox[{
                {"4"},
                {"1"},
                {"2"},
                {"3"}
                },
              RowSpacings->0.25,
              ColumnSpacings->1,
              RowAlignments->Baseline,
              ColumnAlignments->{Left}], "1.74527796708352322`*^-19", 
            "2.38414866589452989`*^-20", "1.72735923801524471`*^-16"},
          {GridBox[{
                {"1"},
                {"4"},
                {"2"},
                {"3"}
                },
              RowSpacings->0.25,
              ColumnSpacings->1,
              RowAlignments->Baseline,
              ColumnAlignments->{Left}], "1.26795987546595601`*^-17", 
            "2.79615899649928412`*^-18", "1.72735923801524471`*^-16"},
          {GridBox[{
                {"1"},
                {"2"},
                {"4"},
                {"3"}
                },
              RowSpacings->0.25,
              ColumnSpacings->1,
              RowAlignments->Baseline,
              ColumnAlignments->{Left}], "5.88346292199325127`*^-17", 
            "1.7479334724652511`*^-17", "1.72735923801524471`*^-16"},
          {GridBox[{
                {"1"},
                {"2"},
                {"3"},
                {"4"}
                },
              RowSpacings->0.25,
              ColumnSpacings->1,
              RowAlignments->Baseline,
              ColumnAlignments->{Left}], "1.08544045699418312`*^-16", 
            "1.28195718544707325`*^-17", "1.72735923801524471`*^-16"},
          {"Total", "1.80232801470718744`*^-16", "2.18560664003971982`*^-17", 
            "1.72735923801524471`*^-16"}
          },
        RowSpacings->1,
        ColumnSpacings->3,
        RowAlignments->Baseline,
        ColumnAlignments->{Left}],
      TableForm[ {{{4, 1, 2, 3}, 1.7452779670835231*^-19, 
        2.3841486658945298*^-20, 1.7273592380152449*^-16}, {{1, 4, 2, 3}, 
        1.2679598754659561*^-17, 2.7961589964992839*^-18, 
        1.7273592380152449*^-16}, {{1, 2, 4, 3}, 5.8834629219932518*^-17, 
        1.7479334724652513*^-17, 1.7273592380152449*^-16}, {{1, 2, 3, 4}, 
        1.0854404569941831*^-16, 1.2819571854470733*^-17, 
        1.7273592380152449*^-16}, {Total, 1.8023280147071876*^-16, 
        2.1856066400397199*^-17, 1.7273592380152449*^-16}}]]], "Output",
  CellLabel->"Out[183]//TableForm="]
}, Closed]],

Cell["There are two related difficulties:", "Text"],

Cell[TextData[{
  " i) The values are (roughly) log normally distributed, and so have a very \
wide distribution - wider than would be indicated by taking the standard \
error of the raw values, as was done above.  In this example, values span a \
range of ",
  Cell[BoxData[
      \(TraditionalForm\`\( \[Tilde] \[ExponentialE]\)\^10\)]],
  ".  The t-statistic from the first (misleading) runs was significant, while \
that from the second was not:"
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \({\(1.389 - 1.727\)\/0.0844, \(1.802 - 1.727\)\/0.219}\)], "Input",
  CellLabel->"In[188]:="],

Cell[BoxData[
    \({\(-4.00473933649289204`\), 0.342465753424657348`}\)], "Output",
  CellLabel->"Out[188]="]
}, Closed]],

Cell["\<\
It would be better to base results on the log-normal \
distribution.\
\>", "Text"],

Cell["\<\
ii)  Even with 1000 replicates, there is an appreciable chance of \
missing rare paths with high weight.  Hence, there is  a risk of making a \
gross underestimate of the probability, but rarely, a gross overestimate.  \
The bar chart shows the distribution of estimates for the most likely order, \
for two replicates:\
\>", "Text"],

Cell[BoxData[
    \(\(bc[o_, \[Theta]1_, \[Phi]_, j_, rng_] := 
      \(bc[o, \[Theta]1, \[Phi], j, rng] = 
        BinCounts[Log[ss[o, \[Phi], j] /. \[Theta] -> \[Theta]1], rng]\); 
    \)\)], "Input",
  CellLabel->"In[125]:="],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(BarChart[bc[Last[orders], 1. , 1. , 1, {\(-42\), \(-28\), 0.5}\ ], 
      bc[Last[orders], 1. , 1. , 3, {\(-42\), \(-28\), 0.5}], 
      PlotRange -> {{0, 28}, {0, 200}}]; \)\)], "Input",
  CellLabel->"In[185]:="],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 0.0357143 0 0.00309017 [
[.04286 -0.0125 -3 -9 ]
[.04286 -0.0125 3 0 ]
[.07857 -0.0125 -3 -9 ]
[.07857 -0.0125 3 0 ]
[.11429 -0.0125 -3 -9 ]
[.11429 -0.0125 3 0 ]
[.15 -0.0125 -3 -9 ]
[.15 -0.0125 3 0 ]
[.18571 -0.0125 -3 -9 ]
[.18571 -0.0125 3 0 ]
[.22143 -0.0125 -3 -9 ]
[.22143 -0.0125 3 0 ]
[.25714 -0.0125 -3 -9 ]
[.25714 -0.0125 3 0 ]
[.29286 -0.0125 -3 -9 ]
[.29286 -0.0125 3 0 ]
[.32857 -0.0125 -3 -9 ]
[.32857 -0.0125 3 0 ]
[.36429 -0.0125 -6 -9 ]
[.36429 -0.0125 6 0 ]
[.4 -0.0125 -6 -9 ]
[.4 -0.0125 6 0 ]
[.43571 -0.0125 -6 -9 ]
[.43571 -0.0125 6 0 ]
[.47143 -0.0125 -6 -9 ]
[.47143 -0.0125 6 0 ]
[.50714 -0.0125 -6 -9 ]
[.50714 -0.0125 6 0 ]
[.54286 -0.0125 -6 -9 ]
[.54286 -0.0125 6 0 ]
[.57857 -0.0125 -6 -9 ]
[.57857 -0.0125 6 0 ]
[.61429 -0.0125 -6 -9 ]
[.61429 -0.0125 6 0 ]
[.65 -0.0125 -6 -9 ]
[.65 -0.0125 6 0 ]
[.68571 -0.0125 -6 -9 ]
[.68571 -0.0125 6 0 ]
[.72143 -0.0125 -6 -9 ]
[.72143 -0.0125 6 0 ]
[.75714 -0.0125 -6 -9 ]
[.75714 -0.0125 6 0 ]
[.79286 -0.0125 -6 -9 ]
[.79286 -0.0125 6 0 ]
[.82857 -0.0125 -6 -9 ]
[.82857 -0.0125 6 0 ]
[.86429 -0.0125 -6 -9 ]
[.86429 -0.0125 6 0 ]
[.9 -0.0125 -6 -9 ]
[.9 -0.0125 6 0 ]
[.93571 -0.0125 -6 -9 ]
[.93571 -0.0125 6 0 ]
[.97143 -0.0125 -6 -9 ]
[.97143 -0.0125 6 0 ]
[.00893 .07725 -12 -4.5 ]
[.00893 .07725 0 4.5 ]
[.00893 .15451 -12 -4.5 ]
[.00893 .15451 0 4.5 ]
[.00893 .23176 -12 -4.5 ]
[.00893 .23176 0 4.5 ]
[.00893 .30902 -18 -4.5 ]
[.00893 .30902 0 4.5 ]
[.00893 .38627 -18 -4.5 ]
[.00893 .38627 0 4.5 ]
[.00893 .46353 -18 -4.5 ]
[.00893 .46353 0 4.5 ]
[.00893 .54078 -18 -4.5 ]
[.00893 .54078 0 4.5 ]
[.00893 .61803 -18 -4.5 ]
[.00893 .61803 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.04286 0 m
.04286 .00625 L
s
[(1)] .04286 -0.0125 0 1 Mshowa
.07857 0 m
.07857 .00625 L
s
[(2)] .07857 -0.0125 0 1 Mshowa
.11429 0 m
.11429 .00625 L
s
[(3)] .11429 -0.0125 0 1 Mshowa
.15 0 m
.15 .00625 L
s
[(4)] .15 -0.0125 0 1 Mshowa
.18571 0 m
.18571 .00625 L
s
[(5)] .18571 -0.0125 0 1 Mshowa
.22143 0 m
.22143 .00625 L
s
[(6)] .22143 -0.0125 0 1 Mshowa
.25714 0 m
.25714 .00625 L
s
[(7)] .25714 -0.0125 0 1 Mshowa
.29286 0 m
.29286 .00625 L
s
[(8)] .29286 -0.0125 0 1 Mshowa
.32857 0 m
.32857 .00625 L
s
[(9)] .32857 -0.0125 0 1 Mshowa
.36429 0 m
.36429 .00625 L
s
[(10)] .36429 -0.0125 0 1 Mshowa
.4 0 m
.4 .00625 L
s
[(11)] .4 -0.0125 0 1 Mshowa
.43571 0 m
.43571 .00625 L
s
[(12)] .43571 -0.0125 0 1 Mshowa
.47143 0 m
.47143 .00625 L
s
[(13)] .47143 -0.0125 0 1 Mshowa
.50714 0 m
.50714 .00625 L
s
[(14)] .50714 -0.0125 0 1 Mshowa
.54286 0 m
.54286 .00625 L
s
[(15)] .54286 -0.0125 0 1 Mshowa
.57857 0 m
.57857 .00625 L
s
[(16)] .57857 -0.0125 0 1 Mshowa
.61429 0 m
.61429 .00625 L
s
[(17)] .61429 -0.0125 0 1 Mshowa
.65 0 m
.65 .00625 L
s
[(18)] .65 -0.0125 0 1 Mshowa
.68571 0 m
.68571 .00625 L
s
[(19)] .68571 -0.0125 0 1 Mshowa
.72143 0 m
.72143 .00625 L
s
[(20)] .72143 -0.0125 0 1 Mshowa
.75714 0 m
.75714 .00625 L
s
[(21)] .75714 -0.0125 0 1 Mshowa
.79286 0 m
.79286 .00625 L
s
[(22)] .79286 -0.0125 0 1 Mshowa
.82857 0 m
.82857 .00625 L
s
[(23)] .82857 -0.0125 0 1 Mshowa
.86429 0 m
.86429 .00625 L
s
[(24)] .86429 -0.0125 0 1 Mshowa
.9 0 m
.9 .00625 L
s
[(25)] .9 -0.0125 0 1 Mshowa
.93571 0 m
.93571 .00625 L
s
[(26)] .93571 -0.0125 0 1 Mshowa
.97143 0 m
.97143 .00625 L
s
[(27)] .97143 -0.0125 0 1 Mshowa
0 0 m
1 0 L
s
.02143 .07725 m
.02768 .07725 L
s
[(25)] .00893 .07725 1 0 Mshowa
.02143 .15451 m
.02768 .15451 L
s
[(50)] .00893 .15451 1 0 Mshowa
.02143 .23176 m
.02768 .23176 L
s
[(75)] .00893 .23176 1 0 Mshowa
.02143 .30902 m
.02768 .30902 L
s
[(100)] .00893 .30902 1 0 Mshowa
.02143 .38627 m
.02768 .38627 L
s
[(125)] .00893 .38627 1 0 Mshowa
.02143 .46353 m
.02768 .46353 L
s
[(150)] .00893 .46353 1 0 Mshowa
.02143 .54078 m
.02768 .54078 L
s
[(175)] .00893 .54078 1 0 Mshowa
.02143 .61803 m
.02768 .61803 L
s
[(200)] .00893 .61803 1 0 Mshowa
.125 Mabswid
.02143 .01545 m
.02518 .01545 L
s
.02143 .0309 m
.02518 .0309 L
s
.02143 .04635 m
.02518 .04635 L
s
.02143 .0618 m
.02518 .0618 L
s
.02143 .09271 m
.02518 .09271 L
s
.02143 .10816 m
.02518 .10816 L
s
.02143 .12361 m
.02518 .12361 L
s
.02143 .13906 m
.02518 .13906 L
s
.02143 .16996 m
.02518 .16996 L
s
.02143 .18541 m
.02518 .18541 L
s
.02143 .20086 m
.02518 .20086 L
s
.02143 .21631 m
.02518 .21631 L
s
.02143 .24721 m
.02518 .24721 L
s
.02143 .26266 m
.02518 .26266 L
s
.02143 .27812 m
.02518 .27812 L
s
.02143 .29357 m
.02518 .29357 L
s
.02143 .32447 m
.02518 .32447 L
s
.02143 .33992 m
.02518 .33992 L
s
.02143 .35537 m
.02518 .35537 L
s
.02143 .37082 m
.02518 .37082 L
s
.02143 .40172 m
.02518 .40172 L
s
.02143 .41717 m
.02518 .41717 L
s
.02143 .43262 m
.02518 .43262 L
s
.02143 .44807 m
.02518 .44807 L
s
.02143 .47898 m
.02518 .47898 L
s
.02143 .49443 m
.02518 .49443 L
s
.02143 .50988 m
.02518 .50988 L
s
.02143 .52533 m
.02518 .52533 L
s
.02143 .55623 m
.02518 .55623 L
s
.02143 .57168 m
.02518 .57168 L
s
.02143 .58713 m
.02518 .58713 L
s
.02143 .60258 m
.02518 .60258 L
s
.25 Mabswid
.02143 0 m
.02143 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
1 0 0 r
.02857 0 m
.02857 0 L
.04286 0 L
.04286 0 L
F
0 g
.5 Mabswid
.02857 0 m
.02857 0 L
.04286 0 L
.04286 0 L
.02857 0 L
s
1 0 0 r
.06429 0 m
.06429 0 L
.07857 0 L
.07857 0 L
F
0 g
.06429 0 m
.06429 0 L
.07857 0 L
.07857 0 L
.06429 0 L
s
1 0 0 r
.1 0 m
.1 0 L
.11429 0 L
.11429 0 L
F
0 g
.1 0 m
.1 0 L
.11429 0 L
.11429 0 L
.1 0 L
s
1 0 0 r
.13571 0 m
.13571 0 L
.15 0 L
.15 0 L
F
0 g
.13571 0 m
.13571 0 L
.15 0 L
.15 0 L
.13571 0 L
s
1 0 0 r
.17143 0 m
.17143 0 L
.18571 0 L
.18571 0 L
F
0 g
.17143 0 m
.17143 0 L
.18571 0 L
.18571 0 L
.17143 0 L
s
1 0 0 r
.20714 0 m
.20714 0 L
.22143 0 L
.22143 0 L
F
0 g
.20714 0 m
.20714 0 L
.22143 0 L
.22143 0 L
.20714 0 L
s
1 0 0 r
.24286 0 m
.24286 0 L
.25714 0 L
.25714 0 L
F
0 g
.24286 0 m
.24286 0 L
.25714 0 L
.25714 0 L
.24286 0 L
s
1 0 0 r
.27857 0 m
.27857 .00618 L
.29286 .00618 L
.29286 0 L
F
0 g
.27857 0 m
.27857 .00618 L
.29286 .00618 L
.29286 0 L
.27857 0 L
s
1 0 0 r
.31429 0 m
.31429 .03399 L
.32857 .03399 L
.32857 0 L
F
0 g
.31429 0 m
.31429 .03399 L
.32857 .03399 L
.32857 0 L
.31429 0 L
s
1 0 0 r
.35 0 m
.35 .07416 L
.36429 .07416 L
.36429 0 L
F
0 g
.35 0 m
.35 .07416 L
.36429 .07416 L
.36429 0 L
.35 0 L
s
1 0 0 r
.38571 0 m
.38571 .13597 L
.4 .13597 L
.4 0 L
F
0 g
.38571 0 m
.38571 .13597 L
.4 .13597 L
.4 0 L
.38571 0 L
s
1 0 0 r
.42143 0 m
.42143 .19777 L
.43571 .19777 L
.43571 0 L
F
0 g
.42143 0 m
.42143 .19777 L
.43571 .19777 L
.43571 0 L
.42143 0 L
s
1 0 0 r
.45714 0 m
.45714 .22249 L
.47143 .22249 L
.47143 0 L
F
0 g
.45714 0 m
.45714 .22249 L
.47143 .22249 L
.47143 0 L
.45714 0 L
s
1 0 0 r
.49286 0 m
.49286 .3152 L
.50714 .3152 L
.50714 0 L
F
0 g
.49286 0 m
.49286 .3152 L
.50714 .3152 L
.50714 0 L
.49286 0 L
s
1 0 0 r
.52857 0 m
.52857 .42026 L
.54286 .42026 L
.54286 0 L
F
0 g
.52857 0 m
.52857 .42026 L
.54286 .42026 L
.54286 0 L
.52857 0 L
s
1 0 0 r
.56429 0 m
.56429 .5346 L
.57857 .5346 L
.57857 0 L
F
0 g
.56429 0 m
.56429 .5346 L
.57857 .5346 L
.57857 0 L
.56429 0 L
s
1 0 0 r
.6 0 m
.6 .32447 L
.61429 .32447 L
.61429 0 L
F
0 g
.6 0 m
.6 .32447 L
.61429 .32447 L
.61429 0 L
.6 0 L
s
1 0 0 r
.63571 0 m
.63571 .21013 L
.65 .21013 L
.65 0 L
F
0 g
.63571 0 m
.63571 .21013 L
.65 .21013 L
.65 0 L
.63571 0 L
s
1 0 0 r
.67143 0 m
.67143 .23485 L
.68571 .23485 L
.68571 0 L
F
0 g
.67143 0 m
.67143 .23485 L
.68571 .23485 L
.68571 0 L
.67143 0 L
s
1 0 0 r
.70714 0 m
.70714 .16996 L
.72143 .16996 L
.72143 0 L
F
0 g
.70714 0 m
.70714 .16996 L
.72143 .16996 L
.72143 0 L
.70714 0 L
s
1 0 0 r
.74286 0 m
.74286 .0958 L
.75714 .0958 L
.75714 0 L
F
0 g
.74286 0 m
.74286 .0958 L
.75714 .0958 L
.75714 0 L
.74286 0 L
s
1 0 0 r
.77857 0 m
.77857 .05562 L
.79286 .05562 L
.79286 0 L
F
0 g
.77857 0 m
.77857 .05562 L
.79286 .05562 L
.79286 0 L
.77857 0 L
s
1 0 0 r
.81429 0 m
.81429 .02781 L
.82857 .02781 L
.82857 0 L
F
0 g
.81429 0 m
.81429 .02781 L
.82857 .02781 L
.82857 0 L
.81429 0 L
s
1 0 0 r
.85 0 m
.85 .01545 L
.86429 .01545 L
.86429 0 L
F
0 g
.85 0 m
.85 .01545 L
.86429 .01545 L
.86429 0 L
.85 0 L
s
1 0 0 r
.88571 0 m
.88571 .00309 L
.9 .00309 L
.9 0 L
F
0 g
.88571 0 m
.88571 .00309 L
.9 .00309 L
.9 0 L
.88571 0 L
s
1 0 0 r
.92143 0 m
.92143 .00618 L
.93571 .00618 L
.93571 0 L
F
0 g
.92143 0 m
.92143 .00618 L
.93571 .00618 L
.93571 0 L
.92143 0 L
s
1 0 0 r
.95714 0 m
.95714 .00618 L
.97143 .00618 L
.97143 0 L
F
0 g
.95714 0 m
.95714 .00618 L
.97143 .00618 L
.97143 0 L
.95714 0 L
s
1 0 0 r
.99286 0 m
.99286 0 L
1.00714 0 L
1.00714 0 L
F
0 g
.99286 0 m
.99286 0 L
s
.99286 0 m
0 0 rlineto s
0 .4 1 r
.04286 0 m
.04286 0 L
.05714 0 L
.05714 0 L
F
0 g
.04286 0 m
.04286 0 L
.05714 0 L
.05714 0 L
.04286 0 L
s
0 .4 1 r
.07857 0 m
.07857 0 L
.09286 0 L
.09286 0 L
F
0 g
.07857 0 m
.07857 0 L
.09286 0 L
.09286 0 L
.07857 0 L
s
0 .4 1 r
.11429 0 m
.11429 0 L
.12857 0 L
.12857 0 L
F
0 g
.11429 0 m
.11429 0 L
.12857 0 L
.12857 0 L
.11429 0 L
s
0 .4 1 r
.15 0 m
.15 0 L
.16429 0 L
.16429 0 L
F
0 g
.15 0 m
.15 0 L
.16429 0 L
.16429 0 L
.15 0 L
s
0 .4 1 r
.18571 0 m
.18571 0 L
.2 0 L
.2 0 L
F
0 g
.18571 0 m
.18571 0 L
.2 0 L
.2 0 L
.18571 0 L
s
0 .4 1 r
.22143 0 m
.22143 0 L
.23571 0 L
.23571 0 L
F
0 g
.22143 0 m
.22143 0 L
.23571 0 L
.23571 0 L
.22143 0 L
s
0 .4 1 r
.25714 0 m
.25714 .00309 L
.27143 .00309 L
.27143 0 L
F
0 g
.25714 0 m
.25714 .00309 L
.27143 .00309 L
.27143 0 L
.25714 0 L
s
0 .4 1 r
.29286 0 m
.29286 .01236 L
.30714 .01236 L
.30714 0 L
F
0 g
.29286 0 m
.29286 .01236 L
.30714 .01236 L
.30714 0 L
.29286 0 L
s
0 .4 1 r
.32857 0 m
.32857 .02163 L
.34286 .02163 L
.34286 0 L
F
0 g
.32857 0 m
.32857 .02163 L
.34286 .02163 L
.34286 0 L
.32857 0 L
s
0 .4 1 r
.36429 0 m
.36429 .04017 L
.37857 .04017 L
.37857 0 L
F
0 g
.36429 0 m
.36429 .04017 L
.37857 .04017 L
.37857 0 L
.36429 0 L
s
0 .4 1 r
.4 0 m
.4 .12052 L
.41429 .12052 L
.41429 0 L
F
0 g
.4 0 m
.4 .12052 L
.41429 .12052 L
.41429 0 L
.4 0 L
s
0 .4 1 r
.43571 0 m
.43571 .17923 L
.45 .17923 L
.45 0 L
F
0 g
.43571 0 m
.43571 .17923 L
.45 .17923 L
.45 0 L
.43571 0 L
s
0 .4 1 r
.47143 0 m
.47143 .24721 L
.48571 .24721 L
.48571 0 L
F
0 g
.47143 0 m
.47143 .24721 L
.48571 .24721 L
.48571 0 L
.47143 0 L
s
0 .4 1 r
.50714 0 m
.50714 .34301 L
.52143 .34301 L
.52143 0 L
F
0 g
.50714 0 m
.50714 .34301 L
.52143 .34301 L
.52143 0 L
.50714 0 L
s
0 .4 1 r
.54286 0 m
.54286 .35537 L
.55714 .35537 L
.55714 0 L
F
0 g
.54286 0 m
.54286 .35537 L
.55714 .35537 L
.55714 0 L
.54286 0 L
s
0 .4 1 r
.57857 0 m
.57857 .48207 L
.59286 .48207 L
.59286 0 L
F
0 g
.57857 0 m
.57857 .48207 L
.59286 .48207 L
.59286 0 L
.57857 0 L
s
0 .4 1 r
.61429 0 m
.61429 .37391 L
.62857 .37391 L
.62857 0 L
F
0 g
.61429 0 m
.61429 .37391 L
.62857 .37391 L
.62857 0 L
.61429 0 L
s
0 .4 1 r
.65 0 m
.65 .23176 L
.66429 .23176 L
.66429 0 L
F
0 g
.65 0 m
.65 .23176 L
.66429 .23176 L
.66429 0 L
.65 0 L
s
0 .4 1 r
.68571 0 m
.68571 .28739 L
.7 .28739 L
.7 0 L
F
0 g
.68571 0 m
.68571 .28739 L
.7 .28739 L
.7 0 L
.68571 0 L
s
0 .4 1 r
.72143 0 m
.72143 .17305 L
.73571 .17305 L
.73571 0 L
F
0 g
.72143 0 m
.72143 .17305 L
.73571 .17305 L
.73571 0 L
.72143 0 L
s
0 .4 1 r
.75714 0 m
.75714 .0958 L
.77143 .0958 L
.77143 0 L
F
0 g
.75714 0 m
.75714 .0958 L
.77143 .0958 L
.77143 0 L
.75714 0 L
s
0 .4 1 r
.79286 0 m
.79286 .04326 L
.80714 .04326 L
.80714 0 L
F
0 g
.79286 0 m
.79286 .04326 L
.80714 .04326 L
.80714 0 L
.79286 0 L
s
0 .4 1 r
.82857 0 m
.82857 .04635 L
.84286 .04635 L
.84286 0 L
F
0 g
.82857 0 m
.82857 .04635 L
.84286 .04635 L
.84286 0 L
.82857 0 L
s
0 .4 1 r
.86429 0 m
.86429 .02163 L
.87857 .02163 L
.87857 0 L
F
0 g
.86429 0 m
.86429 .02163 L
.87857 .02163 L
.87857 0 L
.86429 0 L
s
0 .4 1 r
.9 0 m
.9 0 L
.91429 0 L
.91429 0 L
F
0 g
.9 0 m
.9 0 L
.91429 0 L
.91429 0 L
.9 0 L
s
0 .4 1 r
.93571 0 m
.93571 .00927 L
.95 .00927 L
.95 0 L
F
0 g
.93571 0 m
.93571 .00927 L
.95 .00927 L
.95 0 L
.93571 0 L
s
0 .4 1 r
.97143 0 m
.97143 .00309 L
.98571 .00309 L
.98571 0 L
F
0 g
.97143 0 m
.97143 .00309 L
.98571 .00309 L
.98571 0 L
.97143 0 L
s
0 .4 1 r
1.00714 0 m
1.00714 0 L
1.02143 0 L
1.02143 0 L
F
0 g
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[185]:=",
  ImageSize->{498, 307.625},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40007b0001<a000`40O003h00Oogoolgoo003oOooc
Ool002Qoo`<000ioo`@000eoo`<000ioo`<000eoo`<000ioo`8000moo`03001oogoo00ioo`8000eo
o`<000]oo`<000Aoo`8000Moo`<000=oo`<000Qoo`<000=oo`@000Moo`<000=oo`<000Moo`<000Ao
o`<000Moo`<000=oo`<000Moo`<000Aoo`8000Qoo`<000Aoo`03001oogoo00Moo`<000Aoo`8000Mo
o`<000=oo`<000Qoo`@000=oo`8000Moo`@0009oo`<000Qoo`@0009oo`@000Moo`@0009oo`<000Mo
o`@000=oo`<000Moo`@0009oo`<000Moo`@000=oo`8000Qoo`@000=oo`03001oogoo01=oo`00:Goo
00<007ooOol03Woo00<007ooOol047oo00<007ooOol037oo00<007ooOol03goo00<007ooOol02Woo
00@007ooOol000ioo`03001oogoo00eoo`04001oogoo000?Ool00`00Oomoo`09Ool00`00Oomoo`02
Ool01000Oomoo`001goo00<007ooOol00goo00<007ooOol027oo00<007ooOol00goo00<007ooOol0
27oo00<007ooOol01Goo00<007ooOol01Goo00<007ooOol017oo00<007ooOol01goo00<007ooOol0
1Goo00<007ooOol01Goo00<007ooOol00Woo00@007ooOol000Qoo`03001oogoo00=oo`03001oogoo
00Qoo`03001oogoo009oo`04001oogoo0007Ool00`00Oomoo`05Ool00`00Oomoo`06Ool00`00Oomo
o`02Ool01000Oomoo`001goo00<007ooOol00goo00<007ooOol027oo00<007ooOol00goo00<007oo
Ool027oo00<007ooOol01Goo00<007ooOol01Goo00<007ooOol017oo00<007ooOol01goo00<007oo
Ool01Goo00<007ooOol01Goo00<007ooOol00Woo00@007ooOol000Qoo`03001oogoo00=oo`03001o
ogoo01=oo`00:Goo00<007ooOol03goo00<007ooOol03goo00<007ooOol02Woo100047oo00<007oo
Ool02Woo00@007ooOol000moo`03001oogoo00aoo`04001oogoo000=Ool3000;Ool00`00Oomoo`02
Ool01000Oomoo`001goo00<007ooOol00goo00<007ooOol027oo00<007ooOol017oo00<007ooOol0
1goo00<007ooOol01Goo00<007ooOol01Goo00<007ooOol00Woo100027oo00<007ooOol01Goo00<0
07ooOol01Goo00<007ooOol00Woo00@007ooOol000Qoo`03001oogoo00Aoo`03001oogoo00Moo`03
001oogoo009oo`04001oogoo0007Ool00`00Oomoo`03Ool30009Ool01@00Oomoogoo00000Woo00<0
07ooOol01Woo00<007ooOol00Woo00<007ooOol02Goo00<007ooOol00goo00<007ooOol027oo00<0
07ooOol017oo00<007ooOol01Woo00@007ooOomoo`@000Uoo`03001oogoo00Aoo`03001oogoo00Io
o`05001oogooOol00002Ool00`00Oomoo`07Ool00`00Oomoo`03Ool00`00Oomoo`0BOol002Uoo`03
001oogoo011oo`03001oogoo00aoo`8000eoo`03001oo`0000ioo`<000eoo`<0011oo`03001oogoo
00eoo`8000eoo`04001oogoo000;Ool00`00Oomoo`02Ool01000Oomoo`001goo00<007ooOol00goo
00<007ooOol027oo00<007ooOol01Goo00<007ooOol01Woo00<007ooOol00goo0P0027oo00<007oo
Ool00Woo00<007oo00002Goo00<007ooOol00Woo0`0027oo00<007ooOol00Woo0`002Goo00<007oo
Ool017oo00<007ooOol01goo00<007ooOol00goo0P0027oo00<007ooOol00Woo00@007ooOol000Yo
o`04001oogoo0002Ool00`00Oomoo`07Ool01@00Oomoogoo000037oo00<007ooOol00goo00<007oo
Ool027oo00@007ooOomoo`8000Yoo`06001oogoo001oo`002goo00<007ooOol00`002Woo00<007oo
Ool00`002goo00<007ooOol00Woo00<007ooOol04Woo000YOol00`00Oomoo`0=Ool01000Oomoo`00
47oo00<007ooOol02Woo00<007oo00003Woo00<007ooOol03Goo00<007ooOol04Goo00<007ooOol0
2goo00@007ooOol000aoo`04001oogoo000;Ool00`00Oomoo`02Ool01000Oomoo`001goo00<007oo
Ool00goo00<007ooOol027oo00<007ooOol00Woo00@007ooOol000Qoo`03001oogoo00Eoo`03001o
ogoo00Eoo`03001oogoo009oo`03001oo`0000Uoo`03001oogoo009oo`03001oogoo00Qoo`03001o
ogoo009oo`03001oogoo00Uoo`03001oogoo00Eoo`03001oogoo00Ioo`03001oogoo009oo`04001o
ogoo0007Ool00`00Oomoo`02Ool01000Oomoo`001goo00@007ooOol0009oo`04001oogoo0006Ool0
1000Oomoo`000goo00<007ooOol01goo00@007ooOol0009oo`04001oogoo0007Ool01000Oomoo`00
1Goo00<007ooOol017oo00@007ooOol0009oo`03001oo`0000Qoo`04001oogoo0002Ool00`00Oomo
o`07Ool01000Oomoo`000Woo00<007ooOol027oo00@007ooOol000Eoo`03001oogoo015oo`00:7oo
0P0047oo0P003Woo0`003Woo0P003Woo10003Goo0`003Goo10003Woo0P003Woo0P002goo0P001Goo
0P001goo0P0017oo0P002Goo0P001Goo0P0027oo0P0017oo0`001goo0P001Goo0P0027oo0P0017oo
10001Woo0P001Goo0`001goo0P0017oo10001goo0P001Goo0P001goo0P001Goo0P002Goo0P0017oo
0P0027oo0P000goo0P002Woo0P0017oo0P002Goo0P000goo0`0027oo0P0017oo0P002Goo0P000goo
10001goo0P0017oo0`0027oo0P000goo10004goo003oOoocOol00?mooo=oo`00ogoolgoo003oOooc
Ool00?mooo=oo`00ogoolgoo000TOol00`00Oomoo`04Ool00`00Oomoo`03Ool01@00Oomoogoo0000
1Goo00<007ooOol017oo00@007ooOol000Ioo`03001oogoo00Aoo`04001oogoo0005Ool00`00Oomo
o`04Ool01000Oomoo`001Woo00<007ooOol017oo00@007ooOol000Ioo`03001oogoo00=oo`05001o
ogooOol00005Ool00`00Oomoo`3oOolYOol00`00Oomoo`04Ool00`00Oomoo`0QOol00`00Oomoo`0;
Ool001Ioool00=<000Yoo`0087oo00<007ooOol01goo00<007ooOol03Woo00<007ooOol03Woo00<0
07ooOol03Goo00<007ooOol03Woo00<007ooOol03Goo00<007ooOol03Woo20000Woo00<007`0O000
17`000<0006O0Il00`6O00D007ooOomoo`0000El00030001W`6O00@1W`04001oogoo0006O0000`00
0Il1W`030Il01@00Oomoogoo00001G`000<0006O0Il0106O00@007ooOol000Il00030001W`6O00@1
W`04001oogoo0006O0000`000Il1W`030Il01@00Oomoogoo00001G`000<0006O0Il0106O00@007oo
Ool000Il00030001W`6O00<1W`05001oogooOol00005O0000`000Il1W`040Il01000Oomoo`001W`0
00<0006O0Il0106O00@007ooOol000Il00030001W`6O00<1W`05001oogooOol00005O0000`000Il1
W`040Il01000Oomoo`001W`000<0006O0Il0106O00@007ooOol000El00030001W`6O00@1W`04001o
ogoo0006O0000`000Il1W`040Il01000Oomoo`001W`000<0006O0Il00`6O00D007ooOomoo`0000El
00030001W`6O00@1W`03001oogoo00P000Uoo`03001l07`000=l00030001W`6O00@1W`04001oogoo
0006O008000@Ool0021oo`03001oogoo00Moo`03001oogoo00ioo`03001oogoo00ioo`03001oogoo
00eoo`03001oogoo00ioo`03001oogoo00eoo`03001oogoo00ioo`03001oogoo00Moo`03001l07`0
00Al00030001W`6O00<1W`05001oogooOol00005O0000`000Il1W`040Il01000Oomoo`001W`000<0
006O0Il00`6O00D007ooOomoo`0000El00030001W`6O00@1W`04001oogoo0006O0000`000Il1W`04
0Il01000Oomoo`001W`000<0006O0Il00`6O00D007ooOomoo`0000El00030001W`6O00@1W`04001o
ogoo0006O0000`000Il1W`030Il01@00Oomoogoo00001G`000<0006O0Il0106O00@007ooOol000Il
00030001W`6O00@1W`04001oogoo0006O0000`000Il1W`030Il01@00Oomoogoo00001G`000<0006O
0Il0106O00@007ooOol000Il00030001W`6O00@1W`04001oogoo0005O0000`000Il1W`040Il01000
Oomoo`001W`000<0006O0Il0106O00@007ooOol000Il00030001W`6O00<1W`05001oogooOol00005
O0000`000Il1W`040Il00`00Oomoo`07Ool00`00Oomoo`07Ool00`00O01l0003O0000`000Il1W`04
0Il01000Oomoo`001W`000<007ooOol05Goo000POol00`00Oomoo`07Ool00`00Oomoo`0>Ool00`00
Oomoo`0>Ool00`00Oomoo`0=Ool00`00Oomoo`0>Ool00`00Oomoo`0=Ool00`00Oomoo`0>Ool00`00
Oomoo`07Ool800050Il01@00Oomoogoo00001G`000<0006O0Il0106O00@007ooOol000Il00030001
W`6O00<1W`05001oogooOol00005O0000`000Il1W`040Il01000Oomoo`001W`000<0006O0Il0106O
00@007ooOol000Il00030001W`6O00<1W`05001oogooOol00005O0000`000Il1W`040Il01000Oomo
o`001W`000<0006O0Il00`6O00D007ooOomoo`0000El00030001W`6O00@1W`04001oogoo0006O000
0`000Il1W`040Il01000Oomoo`001W`000<0006O0Il00`6O00D007ooOomoo`0000El00030001W`6O
00@1W`04001oogoo0006O0000`000Il1W`040Il01000Oomoo`001G`000<0006O0Il0106O00@007oo
Ool000Il00030001W`6O00@1W`04001oogoo0006O0000`000Il1W`030Il01@00Oomoogoo00001G`0
00<0006O0Il0106O00<007ooOol01goo00<007ooOol01goo1`001P6O00<007ooOol020005goo000P
Ool00`00Oomoo`1lOol00`000Il1W`030Il01@00Oomoogoo00001G`000<0006O0Il0106O00@007oo
Ool000Il00030001W`6O00<1W`05001oogooOol00005O0000`000Il1W`040Il01000Oomoo`001W`0
00<0006O0Il0106O00@007ooOol000Il00030001W`6O00<1W`05001oogooOol00005O0000`000Il1
W`040Il01000Oomoo`001W`000<0006O0Il00`6O00D007ooOomoo`0000El00030001W`6O00@1W`04
001oogoo0006O0000`000Il1W`040Il01000Oomoo`001W`000<0006O0Il00`6O00D007ooOomoo`00
00El00030001W`6O00@1W`04001oogoo0006O0000`000Il1W`040Il01000Oomoo`001G`000<0006O
0Il0106O00@007ooOol000Il00030001W`6O00@1W`04001oogoo0006O0000`000Il1W`030Il01@00
Oomoogoo00001G`000<0006O0Il0106O00<007ooOol05goo20008Goo000POol00`00Oomoo`1lOol7
0003Ool00`00O01l0003O0000`000Il1W`040Il01000Oomoo`001W`000<0006O0Il00`6O00D007oo
Oomoo`0000El00030001W`6O00@1W`04001oogoo0006O0000`000Il1W`040Il01000Oomoo`001W`0
00<0006O0Il00`6O00D007ooOomoo`0000El00030001W`6O00@1W`04001oogoo0006O0000`000Il1
W`030Il01@00Oomoogoo00001G`000<0006O0Il0106O00@007ooOol000Il00030001W`6O00@1W`04
001oogoo0006O0000`000Il1W`030Il01@00Oomoogoo00001G`000<0006O0Il0106O00@007ooOol0
00Il00030001W`6O00@1W`04001oogoo0005O0000`000Il1W`040Il01000Oomoo`001W`000<0006O
0Il0106O00@007ooOol000Il00030001W`6O00<1W`05001oogooOol00005O0000`000Il1W`040Il0
0`00Oomoo`10Ool0021oo`03001oogoo08Ioo`03001l07`000=l00030001W`6O00@1W`04001oogoo
0006O0000`000Il1W`030Il01@00Oomoogoo00001G`000<0006O0Il0106O00@007ooOol000Il0003
0001W`6O00@1W`04001oogoo0006O0000`000Il1W`030Il01@00Oomoogoo00001G`000<0006O0Il0
106O00@007ooOol000Il00030001W`6O00<1W`05001oogooOol00005O0000`000Il1W`040Il01000
Oomoo`001W`000<0006O0Il0106O00@007ooOol000Il00030001W`6O00<1W`05001oogooOol00005
O0000`000Il1W`040Il01000Oomoo`001W`000<0006O0Il0106O00@007ooOol000El00030001W`6O
00@1W`04001oogoo0006O0000`000Il1W`040Il01000Oomoo`001W`000<0006O0Il00`6O00D007oo
Oomoo`0000El00030001W`6O00@1W`03001oogoo041oo`0087oo0`00QWoo00<007`0O0000g`000<0
006O0Il0106O00@007ooOol000Il00030001W`6O00<1W`05001oogooOol00005O0000`000Il1W`04
0Il01000Oomoo`001W`000<0006O0Il0106O00@007ooOol000Il00030001W`6O00<1W`05001oogoo
Ool00005O0000`000Il1W`040Il01000Oomoo`001W`000<0006O0Il00`6O00D007ooOomoo`0000El
00030001W`6O00@1W`04001oogoo0006O0000`000Il1W`040Il01000Oomoo`001W`000<0006O0Il0
0`6O00D007ooOomoo`0000El00030001W`6O00@1W`04001oogoo0006O0000`000Il1W`040Il01000
Oomoo`001G`000<0006O0Il0106O00@007ooOol000Il00030001W`6O00@1W`04001oogoo0006O000
0`000Il1W`030Il01000Oomoogoo1`001P6O00<007ooOol0@7oo000POol00`00Oomoo`26Ool00`00
O01l0003O0000`000Il1W`040Il01000Oomoo`001W`000<0006O0Il00`6O00D007ooOomoo`0000El
00030001W`6O00@1W`04001oogoo0006O0000`000Il1W`040Il01000Oomoo`001W`000<0006O0Il0
0`6O00D007ooOomoo`0000El00030001W`6O00@1W`04001oogoo0006O0000`000Il1W`030Il01@00
Oomoogoo00001G`000<0006O0Il0106O00@007ooOol000Il00030001W`6O00@1W`04001oogoo0006
O0000`000Il1W`030Il01@00Oomoogoo00001G`000<0006O0Il0106O00@007ooOol000Il00030001
W`6O00@1W`04001oogoo0005O0000`000Il1W`040Il01000Oomoo`001W`000<0006O0Il0106O00@0
07ooOol000Il00030001W`6O00<1W`03001oogoo00Moo`030001W`6O00@1W`03001oogoo041oo`00
87oo00<007ooOol0QWoo00<007`0O0000g`000<0006O0Il0106O00@007ooOol000Il00030001W`6O
00<1W`05001oogooOol00005O0000`000Il1W`040Il01000Oomoo`001W`000<0006O0Il0106O00@0
07ooOol000Il00030001W`6O00<1W`05001oogooOol00005O0000`000Il1W`040Il01000Oomoo`00
1W`000<0006O0Il00`6O00D007ooOomoo`0000El00030001W`6O00@1W`04001oogoo0006O0000`00
0Il1W`040Il01000Oomoo`001W`000<0006O0Il00`6O00D007ooOomoo`0000El00030001W`6O00@1
W`04001oogoo0006O0000`000Il1W`040Il01000Oomoo`001G`000<0006O0Il0106O00@007ooOol0
00Il00030001W`6O00@1W`04001oogoo0006O0000`000Il1W`030Il00`00Oomoo`07Ool00`000Il1
W`040Il00`00Oomoo`10Ool0021oo`03001oogoo08Ioo`03001l07`000=l00P0009oo`03001l07`0
00Al00030001W`6O00<1W`05001oogooOol00005O0000`000Il1W`040Il01000Oomoo`001W`000<0
006O0Il0106O00@007ooOol000Il00030001W`6O00<1W`05001oogooOol00005O0000`000Il1W`04
0Il01000Oomoo`001W`000<0006O0Il00`6O00D007ooOomoo`0000El00030001W`6O00@1W`04001o
ogoo0006O0000`000Il1W`040Il01000Oomoo`001W`000<0006O0Il00`6O00D007ooOomoo`0000El
00030001W`6O00@1W`04001oogoo0006O0000`000Il1W`040Il01000Oomoo`001G`000<0006O0Il0
106O00@007ooOol000Il00030001W`6O00@1W`04001oogoo0006O0000`000Il1W`030Il00`00Oomo
o`07Ool80012Ool0021oo`03001oogoo08Ioo`03001l07`000=l0003001oogoo00Moo`03001l07`0
00Al00030001W`6O00<1W`05001oogooOol00005O0000`000Il1W`040Il01000Oomoo`001W`000<0
006O0Il0106O00@007ooOol000Il00030001W`6O00<1W`05001oogooOol00005O0000`000Il1W`04
0Il01000Oomoo`001W`000<0006O0Il00`6O00D007ooOomoo`0000El00030001W`6O00@1W`04001o
ogoo0006O0000`000Il1W`040Il01000Oomoo`001W`000<0006O0Il00`6O00D007ooOomoo`0000El
00030001W`6O00@1W`04001oogoo0006O0000`000Il1W`040Il01000Oomoo`001G`000<0006O0Il0
106O00@007ooOol000Il00030001W`6O00@1W`04001oogoo0006O0000`000Il1W`030Il00`00Oomo
o`1AOol0021oo`03001oogoo08Ioo`03001l07`000=l0003001oogoo00Moo`03001l07`000Al0003
0001W`6O00<1W`05001oogooOol00005O0000`000Il1W`040Il01000Oomoo`001W`000<0006O0Il0
106O00@007ooOol000Il00030001W`6O00<1W`05001oogooOol00005O0000`000Il1W`040Il01000
Oomoo`001W`000<0006O0Il00`6O00D007ooOomoo`0000El00030001W`6O00@1W`04001oogoo0006
O0000`000Il1W`040Il01000Oomoo`001W`000<0006O0Il00`6O00D007ooOomoo`0000El00030001
W`6O00@1W`04001oogoo0006O0000`000Il1W`040Il01000Oomoo`001G`000<0006O0Il0106O00@0
07ooOol000Il00030001W`6O00@1W`04001oogoo0006O0000`000Il1W`030Il00`00Oomoo`1AOol0
021oo`03001oogoo08Ioo`03001l07`000=l0003001oogoo00Moo`03001l07`000Al00030001W`6O
00<1W`05001oogooOol00005O0000`000Il1W`040Il01000Oomoo`001W`000<0006O0Il0106O00@0
07ooOol000Il00030001W`6O00<1W`05001oogooOol00005O0000`000Il1W`040Il01000Oomoo`00
1W`000<0006O0Il00`6O00D007ooOomoo`0000El00030001W`6O00@1W`04001oogoo0006O0000`00
0Il1W`040Il01000Oomoo`001W`000<0006O0Il00`6O00D007ooOomoo`0000El00030001W`6O00@1
W`04001oogoo0006O0000`000Il1W`040Il01000Oomoo`001G`000<0006O0Il0106O00@007ooOol0
00Il00030001W`6O00@1W`03001oogoo00P000D1W`03001oogoo055oo`0087oo0`00QWoo00<007`0
O0000g`000<007ooOol01goo00<007`0O00017`000<0006O0Il00`6O00D007ooOomoo`0000El0003
0001W`6O00@1W`04001oogoo0006O0000`000Il1W`040Il01000Oomoo`001W`000<0006O0Il00`6O
00D007ooOomoo`0000El00030001W`6O00@1W`04001oogoo0006O0000`000Il1W`030Il01@00Oomo
ogoo00001G`000<0006O0Il0106O00@007ooOol000Il00030001W`6O00@1W`04001oogoo0006O000
0`000Il1W`030Il01@00Oomoogoo00001G`000<0006O0Il0106O00@007ooOol000Il00030001W`6O
00@1W`04001oogoo0005O0000`000Il1W`040Il01000Oomoo`001W`000<0006O0Il0106O00<007oo
Ool01goo00<0006O0Il00`6O00<007ooOol0DGoo000POol00`00Oomoo`26Ool70009Ool00`00O01l
0004O0000`000Il1W`030Il01@00Oomoogoo00001G`000<0006O0Il0106O00@007ooOol000Il0003
0001W`6O00@1W`04001oogoo0006O0000`000Il1W`030Il01@00Oomoogoo00001G`000<0006O0Il0
106O00@007ooOol000Il00030001W`6O00<1W`05001oogooOol00005O0000`000Il1W`040Il01000
Oomoo`001W`000<0006O0Il0106O00@007ooOol000Il00030001W`6O00<1W`05001oogooOol00005
O0000`000Il1W`040Il01000Oomoo`001W`000<0006O0Il0106O00@007ooOol000El00030001W`6O
00@1W`04001oogoo0006O0000`000Il1W`040Il00`00Oomoo`07Ool00`000Il1W`030Il00`00Oomo
o`1AOol0021oo`03001oogoo09Ioo`03001l07`000Al00030001W`6O00<1W`05001oogooOol00005
O0000`000Il1W`040Il01000Oomoo`001W`000<0006O0Il0106O00@007ooOol000Il00030001W`6O
00<1W`05001oogooOol00005O0000`000Il1W`040Il01000Oomoo`001W`000<0006O0Il00`6O00D0
07ooOomoo`0000El00030001W`6O00@1W`04001oogoo0006O0000`000Il1W`040Il01000Oomoo`00
1W`000<0006O0Il00`6O00D007ooOomoo`0000El00030001W`6O00@1W`04001oogoo0006O0000`00
0Il1W`040Il01000Oomoo`001G`000<0006O0Il0106O00@007ooOol000Il00030001W`6O00@1W`03
001oogoo00Moo`030001W`6O00<1W`03001oogoo055oo`0087oo00<007ooOol0UWoo00<007`0O000
17`000<0006O0Il00`6O00D007ooOomoo`0000El00030001W`6O00@1W`04001oogoo0006O0000`00
0Il1W`040Il01000Oomoo`001W`000<0006O0Il00`6O00D007ooOomoo`0000El00030001W`6O00@1
W`04001oogoo0006O0000`000Il1W`030Il01@00Oomoogoo00001G`000<0006O0Il0106O00@007oo
Ool000Il00030001W`6O00@1W`04001oogoo0006O0000`000Il1W`030Il01@00Oomoogoo00001G`0
00<0006O0Il0106O00@007ooOol000Il00030001W`6O00@1W`04001oogoo0005O0000`000Il1W`04
0Il01000Oomoo`001W`000<0006O0Il0106O00<007ooOol01goo00<0006O0Il00`6O00<007ooOol0
DGoo000POol00`00Oomoo`2FOol00`00O01l0004O0070003Ool00`00O01l0003O0000`000Il1W`04
0Il01000Oomoo`001W`000<0006O0Il0106O00@007ooOol000Il00030001W`6O00<1W`05001oogoo
Ool00005O0000`000Il1W`040Il01000Oomoo`001W`000<0006O0Il00`6O00D007ooOomoo`0000El
00030001W`6O00@1W`04001oogoo0006O0000`000Il1W`040Il01000Oomoo`001W`000<0006O0Il0
0`6O00D007ooOomoo`0000El00030001W`6O00@1W`04001oogoo0006O0000`000Il1W`040Il01000
Oomoo`001G`000<0006O0Il0106O00@007ooOol000Il00030001W`6O00@1W`03001oogoo00Moo`03
0001W`6O00<1W`03001oogoo055oo`0087oo00<007ooOol0UWoo00<007`0O00017`000<007ooOol0
1goo00<007`0O0000g`000<0006O0Il0106O00@007ooOol000Il00030001W`6O00@1W`04001oogoo
0006O0000`000Il1W`030Il01@00Oomoogoo00001G`000<0006O0Il0106O00@007ooOol000Il0003
0001W`6O00<1W`05001oogooOol00005O0000`000Il1W`040Il01000Oomoo`001W`000<0006O0Il0
106O00@007ooOol000Il00030001W`6O00<1W`05001oogooOol00005O0000`000Il1W`040Il01000
Oomoo`001W`000<0006O0Il0106O00@007ooOol000El00030001W`6O00@1W`04001oogoo0006O000
0`000Il1W`040Il00`00Oomoo`07Ool00`000Il1W`030Il00`00Oomoo`1AOol0021oo`03001oogoo
09Ioo`03001l07`000Al0003001oogoo00Moo`03001l07`000=l00030001W`6O00@1W`04001oogoo
0006O0000`000Il1W`040Il01000Oomoo`001W`000<0006O0Il00`6O00D007ooOomoo`0000El0003
0001W`6O00@1W`04001oogoo0006O0000`000Il1W`030Il01@00Oomoogoo00001G`000<0006O0Il0
106O00@007ooOol000Il00030001W`6O00@1W`04001oogoo0006O0000`000Il1W`030Il01@00Oomo
ogoo00001G`000<0006O0Il0106O00@007ooOol000Il00030001W`6O00@1W`04001oogoo0005O000
0`000Il1W`040Il01000Oomoo`001W`020002Goo00<0006O0Il00`6O00<007ooOol0DGoo000POol3
002FOol00`00O01l0004O0000`00Oomoo`07Ool00`00O01l0003O0000`000Il1W`040Il01000Oomo
o`001W`000<0006O0Il0106O00@007ooOol000Il00030001W`6O00<1W`05001oogooOol00005O000
0`000Il1W`040Il01000Oomoo`001W`000<0006O0Il00`6O00D007ooOomoo`0000El00030001W`6O
00@1W`04001oogoo0006O0000`000Il1W`040Il01000Oomoo`001W`000<0006O0Il00`6O00D007oo
Oomoo`0000El00030001W`6O00@1W`04001oogoo0006O0000`000Il1W`040Il01000Oomoo`001G`0
00<0006O0Il0106O00@007ooOol000Il0003001oogoo00ioo`L005=oo`0087oo00<007ooOol0UWoo
00<007`0O00017`000<007ooOol01goo00<007`0O0000g`000<0006O0Il0106O00@007ooOol000Il
00030001W`6O00@1W`04001oogoo0006O0000`000Il1W`030Il01@00Oomoogoo00001G`000<0006O
0Il0106O00@007ooOol000Il00030001W`6O00<1W`05001oogooOol00005O0000`000Il1W`040Il0
1000Oomoo`001W`000<0006O0Il0106O00@007ooOol000Il00030001W`6O00<1W`05001oogooOol0
0005O0000`000Il1W`040Il01000Oomoo`001W`000<0006O0Il0106O00@007ooOol000El00030001
W`6O00@1W`04001oogoo0006O0000`00Oomoo`1XOol0021oo`03001oogoo09Ioo`03001l07`000Al
0003001oogoo00Moo`03001l07`000=l00030001W`6O00@1W`04001oogoo0006O0000`000Il1W`04
0Il01000Oomoo`001W`000<0006O0Il00`6O00D007ooOomoo`0000El00030001W`6O00@1W`04001o
ogoo0006O0000`000Il1W`030Il01@00Oomoogoo00001G`000<0006O0Il0106O00@007ooOol000Il
00030001W`6O00@1W`04001oogoo0006O0000`000Il1W`030Il01@00Oomoogoo00001G`000<0006O
0Il0106O00@007ooOol000Il00030001W`6O00@1W`04001oogoo0005O0000`000Il1W`040Il01000
Oomoo`001W`000<007ooOol0J7oo000POol00`00Oomoo`2FOol00`00O01l0004O0000`00Oomoo`07
Ool00`00O01l0003O0000`000Il1W`040Il01000Oomoo`001W`000<0006O0Il0106O00@007ooOol0
00Il00030001W`6O00<1W`05001oogooOol00005O0000`000Il1W`040Il01000Oomoo`001W`000<0
006O0Il00`6O00D007ooOomoo`0000El00030001W`6O00@1W`04001oogoo0006O0000`000Il1W`04
0Il01000Oomoo`001W`000<0006O0Il00`6O00D007ooOomoo`0000El00030001W`6O00@1W`04001o
ogoo0006O0000`000Il1W`040Il01000Oomoo`001G`000<0006O0Il0106O00@007ooOol000Il0003
001oogoo06Qoo`0087oo00<007ooOol0UWoo00<007`0O00017`000<007ooOol01goo00<007`0O000
0g`000<0006O0Il0106O00@007ooOol000Il00030001W`6O00@1W`04001oogoo0006O0000`000Il1
W`030Il01@00Oomoogoo00001G`000<0006O0Il0106O00@007ooOol000Il00030001W`6O00<1W`05
001oogooOol00005O0000`000Il1W`040Il01000Oomoo`001W`000<0006O0Il0106O00@007ooOol0
00Il00030001W`6O00<1W`05001oogooOol00005O0000`000Il1W`040Il01000Oomoo`001W`000<0
006O0Il0106O00@007ooOol000El00030001W`6O00@1W`04001oogoo0006O0000`00Oomoo`1XOol0
021oo`03001oogoo09Ioo`03001l07`000Al0003001oogoo00Moo`03001l07`000=l00030001W`6O
00@1W`04001oogoo0006O0000`000Il1W`040Il01000Oomoo`001W`000<0006O0Il00`6O00D007oo
Oomoo`0000El00030001W`6O00@1W`04001oogoo0006O0000`000Il1W`030Il01@00Oomoogoo0000
1G`000<0006O0Il0106O00@007ooOol000Il00030001W`6O00@1W`04001oogoo0006O0000`000Il1
W`030Il01@00Oomoogoo00001G`000<0006O0Il0106O00@007ooOol000Il00030001W`6O00@1W`04
001oogoo0005O0000`000Il1W`040Il00`00Oomoo`08001ZOol0021oo`03001oogoo09Ioo`03001l
07`000Al0003001oogoo00Moo`03001l07`000=l00030001W`6O00@1W`04001oogoo0006O0000`00
0Il1W`040Il01000Oomoo`001W`000<0006O0Il00`6O00D007ooOomoo`0000El00030001W`6O00@1
W`04001oogoo0006O0000`000Il1W`030Il01@00Oomoogoo00001G`000<0006O0Il0106O00@007oo
Ool000Il00030001W`6O00@1W`04001oogoo0006O0000`000Il1W`030Il01@00Oomoogoo00001G`0
00<0006O0Il0106O00@007ooOol000Il00030001W`6O00@1W`04001oogoo0005O0000`000Il1W`04
0Il00`00Oomoo`1bOol0021oo`<009Ioo`03001l07`000Al0003001oogoo00Moo`03001l07`000=l
00030001W`6O00@1W`04001oogoo0006O0000`000Il1W`040Il01000Oomoo`001W`000<0006O0Il0
0`6O00D007ooOomoo`0000El00030001W`6O00@1W`04001oogoo0006O0000`000Il1W`030Il01@00
Oomoogoo00001G`000<0006O0Il0106O00@007ooOol000Il00030001W`6O00@1W`04001oogoo0006
O0000`000Il1W`030Il01@00Oomoogoo00001G`000<0006O0Il0106O00@007ooOol000Il00030001
W`6O00@1W`04001oogoo0005O0000`000Il1W`040Il00`00Oomoo`1bOol0021oo`03001oogoo09Io
o`03001l07`000Al0003001oogoo00Moo`03001l07`000=l00030001W`6O00@1W`04001oogoo0006
O0000`000Il1W`040Il01000Oomoo`001W`000<0006O0Il00`6O00D007ooOomoo`0000El00030001
W`6O00@1W`04001oogoo0006O0000`000Il1W`030Il01@00Oomoogoo00001G`000<0006O0Il0106O
00@007ooOol000Il00030001W`6O00@1W`04001oogoo0006O0000`000Il1W`030Il01@00Oomoogoo
00001G`000<0006O0Il0106O00@007ooOol000Il00030001W`6O00@1W`04001oogoo0005O0000`00
0Il1W`040Il00`00Oomoo`1bOol0021oo`03001oogoo09Ioo`03001l07`000Al0003001oogoo00Mo
o`03001l07`000=l00030001W`6O00@1W`04001oogoo0006O0000`000Il1W`040Il01000Oomoo`00
1W`000<0006O0Il00`6O00D007ooOomoo`0000El00030001W`6O00@1W`04001oogoo0006O0000`00
0Il1W`030Il01@00Oomoogoo00001G`000<0006O0Il0106O00@007ooOol000Il00030001W`6O00@1
W`04001oogoo0006O0000`000Il1W`030Il01@00Oomoogoo00001G`000<0006O0Il0106O00@007oo
Ool000Il00030001W`6O00@1W`04001oogoo0005O0000`000Il1W`040Il00`00Oomoo`1bOol0021o
o`03001oogoo09Ioo`03001l07`000Al0003001oogoo00Moo`03001l07`000=l00030001W`6O00@1
W`04001oogoo0006O0000`000Il1W`040Il01000Oomoo`001W`000<0006O0Il00`6O00D007ooOomo
o`0000El00030001W`6O00@1W`04001oogoo0006O0000`000Il1W`030Il01@00Oomoogoo00001G`0
00<0006O0Il0106O00@007ooOol000Il00030001W`6O00@1W`04001oogoo0006O0000`000Il1W`03
0Il01@00Oomoogoo00001G`000<0006O0Il0106O00@007ooOol000Il00030001W`6O00@1W`04001o
ogoo0005O0000`000Il1W`040Il00`00Oomoo`1bOol0021oo`03001oogoo09Ioo`03001l07`000Al
0003001oogoo00Moo`03001l07`000=l00030001W`6O00@1W`04001oogoo0006O0000`000Il1W`04
0Il01000Oomoo`001W`000<0006O0Il00`6O00D007ooOomoo`0000El00030001W`6O00@1W`04001o
ogoo0006O0000`000Il1W`030Il01@00Oomoogoo00001G`000<0006O0Il0106O00@007ooOol000Il
00030001W`6O00@1W`04001oogoo0006O0000`000Il1W`030Il01@00Oomoogoo00001G`000<0006O
0Il0106O00@007ooOol000Il00030001W`6O00@1W`04001oogoo0005O0000`000Il1W`040Il00`00
Oomoo`1bOol0021oo`03001oogoo09Ioo`03001l07`000Al0003001oogoo00Moo`03001l07`000=l
00030001W`6O00@1W`04001oogoo0006O0000`000Il1W`040Il01000Oomoo`001W`000<0006O0Il0
0`6O00D007ooOomoo`0000El00030001W`6O00@1W`04001oogoo0006O0000`000Il1W`030Il01@00
Oomoogoo00001G`000<0006O0Il0106O00@007ooOol000Il00030001W`6O00@1W`04001oogoo0006
O0000`000Il1W`030Il01@00Oomoogoo00001G`000<0006O0Il0106O00@007ooOol000Il00030001
W`6O00@1W`04001oogoo0005O0000`000Il1W`040Il00`00Oomoo`1bOol0011oo`@0009oo`<000Mo
o`03001oogoo09Ioo`P000Uoo`03001l07`000=l00030001W`6O00@1W`04001oogoo0006O0000`00
0Il1W`040Il01000Oomoo`001W`000<0006O0Il00`6O00D007ooOomoo`0000El00030001W`6O00@1
W`04001oogoo0006O0000`000Il1W`030Il01@00Oomoogoo00001G`000<0006O0Il0106O00@007oo
Ool000Il00030001W`6O00@1W`04001oogoo0006O0000`000Il1W`030Il01@00Oomoogoo00001G`0
00<0006O0Il0106O00@007ooOol000Il00030001W`6O00@1W`04001oogoo0005O0000`000Il1W`04
0Il00`00Oomoo`1bOol0015oo`03001oogoo00Eoo`03001oogoo00Aoo`03001oogoo0:Moo`03001l
07`000=l00030001W`6O00@1W`04001oogoo0006O0000`000Il1W`040Il01000Oomoo`001W`000<0
006O0Il00`6O00D007ooOomoo`0000El00030001W`6O00@1W`04001oogoo0006O0000`000Il1W`03
0Il01@00Oomoogoo00001G`000<0006O0Il0106O00@007ooOol000Il00030001W`6O00@1W`04001o
ogoo0006O0000`000Il1W`030Il01@00Oomoogoo00001G`000<0006O0Il0106O00@007ooOol000Il
00030001W`6O00@1W`04001oogoo0005O0000`000Il1W`040Il00`00Oomoo`1bOol0019oo`03001o
ogoo00Aoo`03001oogoo00Aoo`@00:Ioo`03001l07`000=l00030001W`6O00@1W`04001oogoo0006
O0000`000Il1W`040Il01000Oomoo`001W`000<0006O0Il00`6O00D007ooOomoo`0000El00030001
W`6O00@1W`04001oogoo0006O0000`000Il1W`030Il01@00Oomoogoo00001G`000<0006O0Il0106O
00@007ooOol000Il00030001W`6O00@1W`04001oogoo0006O0000`000Il1W`030Il01@00Oomoogoo
00001G`000<0006O0Il0106O00@007ooOol000Il00030001W`6O00@1W`04001oogoo0005O0000`00
0Il1W`040Il00`00Oomoo`1bOol001=oo`03001oogoo00<000Moo`03001oogoo0:Moo`03001l07`0
00=l00030001W`6O00@1W`04001oogoo0006O0000`000Il1W`040Il01000Oomoo`001W`000<0006O
0Il00`6O00D007ooOomoo`0000El00030001W`6O00@1W`04001oogoo0006O0000`000Il1W`030Il0
1@00Oomoogoo00001G`000<0006O0Il0106O00@007ooOol000Il00030001W`6O00@1W`04001oogoo
0006O0000`000Il1W`030Il01@00Oomoogoo00001G`000<0006O0Il0106O00@007ooOol000Il0003
0001W`6O00@1W`04001oogoo0005O0000`000Il1W`040Il00`00Oomoo`1bOol0011oo`04001oogoo
0002Ool00`00Oomoo`07Ool00`00Oomoo`2WOol00`00O01l0003O0000`000Il1W`040Il01000Oomo
o`001W`000<0006O0Il0106O00@007ooOol000Il00030001W`6O00<1W`05001oogooOol00005O000
0`000Il1W`040Il01000Oomoo`001W`000<0006O0Il00`6O00D007ooOomoo`0000El00030001W`6O
00@1W`04001oogoo0006O0000`000Il1W`040Il01000Oomoo`001W`000<0006O0Il00`6O00D007oo
Oomoo`0000El00030001W`6O00@1W`04001oogoo0006O0000`000Il1W`040Il01000Oomoo`001G`0
00<0006O0Il0106O00<007ooOol0LWoo000AOol20003Ool40006Ool00`00Oomoo`2WOol00`00O01l
0003O0000`000Il1W`040Il01000Oomoo`001W`000<0006O0Il0106O00@007ooOol000Il00030001
W`6O00<1W`05001oogooOol00005O0000`000Il1W`040Il01000Oomoo`001W`000<0006O0Il00`6O
00D007ooOomoo`0000El00030001W`6O00@1W`04001oogoo0006O0000`000Il1W`040Il01000Oomo
o`001W`000<0006O0Il00`6O00D007ooOomoo`0000El00030001W`6O00@1W`04001oogoo0006O000
0`000Il1W`040Il01000Oomoo`001G`000<0006O0Il0106O00<007ooOol0LWoo000POol00`00Oomo
o`2WOol00`00O01l0003O0000`000Il1W`040Il01000Oomoo`001W`000<0006O0Il0106O00@007oo
Ool000Il00030001W`6O00<1W`05001oogooOol00005O0000`000Il1W`040Il01000Oomoo`001W`0
00<0006O0Il00`6O00D007ooOomoo`0000El00030001W`6O00@1W`04001oogoo0006O0000`000Il1
W`040Il01000Oomoo`001W`000<0006O0Il00`6O00D007ooOomoo`0000El00030001W`6O00@1W`04
001oogoo0006O0000`000Il1W`040Il01000Oomoo`001G`000<0006O0Il0106O00<007ooOol0LWoo
000POol00`00Oomoo`2WOol00`00O01l0003O0000`000Il1W`040Il01000Oomoo`001W`000<0006O
0Il0106O00@007ooOol000Il00030001W`6O00<1W`05001oogooOol00005O0000`000Il1W`040Il0
1000Oomoo`001W`000<0006O0Il00`6O00D007ooOomoo`0000El00030001W`6O00@1W`04001oogoo
0006O0000`000Il1W`040Il01000Oomoo`001W`000<0006O0Il00`6O00D007ooOomoo`0000El0003
0001W`6O00@1W`04001oogoo0006O0000`000Il1W`040Il01000Oomoo`001G`000<0006O0Il0106O
00<007ooOol0LWoo000POol00`00Oomoo`2WOol00`00O01l0003O0000`000Il1W`040Il01000Oomo
o`001W`000<0006O0Il0106O00@007ooOol000Il00030001W`6O00<1W`05001oogooOol00005O000
0`000Il1W`040Il01000Oomoo`001W`000<0006O0Il00`6O00D007ooOomoo`0000El00030001W`6O
00@1W`04001oogoo0006O0000`000Il1W`040Il01000Oomoo`001W`000<0006O0Il00`6O00D007oo
Oomoo`0000El00030001W`6O00@1W`04001oogoo0006O0000`000Il1W`040Il01000Oomoo`001G`0
00<0006O0Il0106O00<007ooOol0LWoo000POol3002WOol00`00O01l0003O0000`000Il1W`040Il0
1000Oomoo`001W`000<0006O0Il0106O00@007ooOol000Il00030001W`6O00<1W`05001oogooOol0
0005O0000`000Il1W`040Il01000Oomoo`001W`000<0006O0Il00`6O00D007ooOomoo`0000El0003
0001W`6O00@1W`04001oogoo0006O0000`000Il1W`040Il01000Oomoo`001W`000<0006O0Il00`6O
00D007ooOomoo`0000El00030001W`6O00@1W`04001oogoo0006O0000`000Il1W`040Il01000Oomo
o`001G`000<0006O0Il0106O00<007ooOol0LWoo000POol00`00Oomoo`2WOol00`00O01l0003O000
0`000Il1W`040Il01000Oomoo`001W`000<0006O0Il0106O00@007ooOol000Il00030001W`6O00<1
W`05001oogooOol00005O0000`000Il1W`040Il01000Oomoo`001W`000<0006O0Il00`6O00D007oo
Oomoo`0000El00030001W`6O00@1W`04001oogoo0006O0000`000Il1W`040Il01000Oomoo`001W`0
00<0006O0Il00`6O00D007ooOomoo`0000El00030001W`6O00@1W`04001oogoo0006O0000`000Il1
W`040Il00`00Oomoo`0>001dOol0021oo`03001oogoo0:Moo`03001l07`000=l00030001W`6O00@1
W`04001oogoo0006O0000`000Il1W`040Il01000Oomoo`001W`000<0006O0Il00`6O00D007ooOomo
o`0000El00030001W`6O00@1W`04001oogoo0006O0000`000Il1W`030Il01@00Oomoogoo00001G`0
00<0006O0Il0106O00@007ooOol000Il00030001W`6O00@1W`04001oogoo0006O0000`000Il1W`03
0Il01@00Oomoogoo00001G`000<0006O0Il0106O00@007ooOol000Il00030001W`6O00@1W`03001o
ogoo089oo`0087oo00<007ooOol0Ygoo00<007`0O0000g`000<0006O0Il0106O00@007ooOol000Il
00030001W`6O00@1W`04001oogoo0006O0000`000Il1W`030Il01@00Oomoogoo00001G`000<0006O
0Il0106O00@007ooOol000Il00030001W`6O00<1W`05001oogooOol00005O0000`000Il1W`040Il0
1000Oomoo`001W`000<0006O0Il0106O00@007ooOol000Il00030001W`6O00<1W`05001oogooOol0
0005O0000`000Il1W`040Il01000Oomoo`001W`000<0006O0Il0106O00<007ooOol0PWoo000POol0
0`00Oomoo`2WOol00`00O01l0003O0000`000Il1W`040Il01000Oomoo`001W`000<0006O0Il0106O
00@007ooOol000Il00030001W`6O00<1W`05001oogooOol00005O0000`000Il1W`040Il01000Oomo
o`001W`000<0006O0Il00`6O00D007ooOomoo`0000El00030001W`6O00@1W`04001oogoo0006O000
0`000Il1W`040Il01000Oomoo`001W`000<0006O0Il00`6O00D007ooOomoo`0000El00030001W`6O
00@1W`04001oogoo0006O0000`000Il1W`040Il00`00Oomoo`22Ool0021oo`03001oogoo0:Moo`03
001l07`000=l00030001W`6O00@1W`04001oogoo0006O0000`000Il1W`040Il01000Oomoo`001W`0
00<0006O0Il00`6O00D007ooOomoo`0000El00030001W`6O00@1W`04001oogoo0006O0000`000Il1
W`030Il01@00Oomoogoo00001G`000<0006O0Il0106O00@007ooOol000Il00030001W`6O00@1W`04
001oogoo0006O0000`000Il1W`030Il01@00Oomoogoo00001G`000<0006O0Il0106O00@007ooOol0
00Il00030001W`6O00@1W`03001oogoo089oo`0087oo00<007ooOol0Ygoo00<007`0O0000g`000<0
006O0Il0106O00@007ooOol000Il00030001W`6O00@1W`04001oogoo0006O0000`000Il1W`030Il0
1@00Oomoogoo00001G`000<0006O0Il0106O00@007ooOol000Il00030001W`6O00<1W`05001oogoo
Ool00005O0000`000Il1W`040Il01000Oomoo`001W`000<0006O0Il0106O00@007ooOol000Il0003
0001W`6O00<1W`05001oogooOol00005O0000`000Il1W`040Il01000Oomoo`001W`000<0006O0Il0
106O00<007ooOol0PWoo000POol3002WOol00`00O01l0003O0000`000Il1W`040Il01000Oomoo`00
1W`000<0006O0Il0106O00@007ooOol000Il00030001W`6O00<1W`05001oogooOol00005O0000`00
0Il1W`040Il01000Oomoo`001W`000<0006O0Il00`6O00D007ooOomoo`0000El00030001W`6O00@1
W`04001oogoo0006O0000`000Il1W`040Il01000Oomoo`001W`000<0006O0Il00`6O00D007ooOomo
o`0000El00030001W`6O00@1W`04001oogoo0006O0000`000Il1W`040Il00`00Oomoo`22Ool0021o
o`03001oogoo0:Moo`03001l07`000=l00030001W`6O00@1W`04001oogoo0006O0000`000Il1W`04
0Il01000Oomoo`001W`000<0006O0Il00`6O00D007ooOomoo`0000El00030001W`6O00@1W`04001o
ogoo0006O0000`000Il1W`030Il01@00Oomoogoo00001G`000<0006O0Il0106O00@007ooOol000Il
00030001W`6O00@1W`04001oogoo0006O0000`000Il1W`030Il01@00Oomoogoo00001G`000<0006O
0Il0106O00@007ooOol000Il00030001W`6O00@1W`03001oogoo089oo`0087oo00<007ooOol0Ygoo
00<007`0O0000g`000<0006O0Il0106O00@007ooOol000Il00030001W`6O00@1W`04001oogoo0006
O0000`000Il1W`030Il01@00Oomoogoo00001G`000<0006O0Il0106O00@007ooOol000Il00030001
W`6O00<1W`05001oogooOol00005O0000`000Il1W`040Il01000Oomoo`001W`000<0006O0Il0106O
00@007ooOol000Il00030001W`6O00<1W`05001oogooOol00005O0000`000Il1W`040Il01000Oomo
o`001W`000<0006O0Il0106O00<007ooOol0PWoo000POol00`00Oomoo`2WOol00`00O01l0003O000
0`000Il1W`040Il01000Oomoo`001W`000<0006O0Il0106O00@007ooOol000Il00030001W`6O00<1
W`05001oogooOol00005O0000`000Il1W`040Il01000Oomoo`001W`000<0006O0Il00`6O00D007oo
Oomoo`0000El00030001W`6O00@1W`04001oogoo0006O0000`000Il1W`040Il01000Oomoo`001W`0
00<0006O0Il00`6O00D007ooOomoo`0000El00030001W`6O00@1W`04001oogoo0006O0000`000Il1
W`040Il00`00Oomoo`22Ool0021oo`03001oogoo0:Moo`03001l07`000=l00030001W`6O00@1W`04
001oogoo0006O0000`000Il1W`040Il01000Oomoo`001W`000<0006O0Il00`6O00D007ooOomoo`00
00El00030001W`6O00@1W`04001oogoo0006O0000`000Il1W`030Il01@00Oomoogoo00001G`000<0
006O0Il0106O00@007ooOol000Il00030001W`6O00@1W`04001oogoo0006O0000`000Il1W`030Il0
1@00Oomoogoo00001G`000<0006O0Il0106O00@007ooOol000Il00030001W`6O00@1W`03001oogoo
089oo`0087oo00<007ooOol0Ygoo00<007`0O0000g`000<0006O0Il0106O00@007ooOol000Il0003
0001W`6O00@1W`04001oogoo0006O0000`000Il1W`030Il01@00Oomoogoo00001G`000<0006O0Il0
106O00@007ooOol000Il00030001W`6O00<1W`05001oogooOol00005O0000`000Il1W`040Il01000
Oomoo`001W`000<0006O0Il0106O00@007ooOol000Il00030001W`6O00<1W`05001oogooOol00005
O0000`000Il1W`040Il01000Oomoo`001W`000<0006O0Il0106O00<007ooOol0PWoo000POol00`00
Oomoo`2WOol00`00O01l0003O0080002Ool00`00O01l0004O0000`000Il1W`040Il01000Oomoo`00
1W`000<0006O0Il00`6O00D007ooOomoo`0000El00030001W`6O00@1W`04001oogoo0006O0000`00
0Il1W`030Il01@00Oomoogoo00001G`000<0006O0Il0106O00@007ooOol000Il00030001W`6O00@1
W`04001oogoo0006O0000`000Il1W`030Il01@00Oomoogoo00001G`000<0006O0Il0106O00@007oo
Ool000Il00030001W`6O00@1W`03001oogoo089oo`0087oo0`00Ygoo00<007`0O0000g`000<007oo
Ool01goo00<007`0O00017`000<0006O0Il0106O00@007ooOol000Il00030001W`6O00<1W`05001o
ogooOol00005O0000`000Il1W`040Il01000Oomoo`001W`000<0006O0Il00`6O00D007ooOomoo`00
00El00030001W`6O00@1W`04001oogoo0006O0000`000Il1W`040Il01000Oomoo`001W`000<0006O
0Il00`6O00D007ooOomoo`0000El00030001W`6O00@1W`04001oogoo0006O0000`000Il1W`040Il0
0`00Oomoo`22Ool0021oo`03001oogoo0:Moo`03001l07`000=l0003001oogoo00Moo`03001l07`0
00Al00030001W`6O00@1W`04001oogoo0006O0000`000Il1W`030Il01@00Oomoogoo00001G`000<0
006O0Il0106O00@007ooOol000Il00030001W`6O00<1W`05001oogooOol00005O0000`000Il1W`04
0Il01000Oomoo`001W`000<0006O0Il0106O00@007ooOol000Il00030001W`6O00<1W`05001oogoo
Ool00005O0000`000Il1W`040Il01000Oomoo`001W`000<0006O0Il0106O00<007ooOol0PWoo000P
Ool00`00Oomoo`2WOol00`00O01l0003O0000`00Oomoo`07Ool00`00O01l0004O0000`000Il1W`04
0Il01000Oomoo`001W`000<0006O0Il00`6O00D007ooOomoo`0000El00030001W`6O00@1W`04001o
ogoo0006O0000`000Il1W`030Il01@00Oomoogoo00001G`000<0006O0Il0106O00@007ooOol000Il
00030001W`6O00@1W`04001oogoo0006O0000`000Il1W`030Il01@00Oomoogoo00001G`000<0006O
0Il0106O00@007ooOol000Il00030001W`6O00@1W`03001oogoo089oo`0087oo00<007ooOol0Ygoo
00<007`0O0000g`000<007ooOol01goo00<007`0O00017`000<0006O0Il0106O00@007ooOol000Il
00030001W`6O00<1W`05001oogooOol00005O0000`000Il1W`040Il01000Oomoo`001W`000<0006O
0Il00`6O00D007ooOomoo`0000El00030001W`6O00@1W`04001oogoo0006O0000`000Il1W`040Il0
1000Oomoo`001W`000<0006O0Il00`6O00D007ooOomoo`0000El00030001W`6O00@1W`04001oogoo
0006O0000`000Il1W`040Il00`00Oomoo`22Ool0021oo`03001oogoo0:Moo`03001l07`000=l0003
001oogoo00Moo`03001l07`000Al00030001W`6O00@1W`04001oogoo0006O0000`000Il1W`030Il0
1@00Oomoogoo00001G`000<0006O0Il0106O00@007ooOol000Il00030001W`6O00<1W`05001oogoo
Ool00005O0000`000Il1W`040Il01000Oomoo`001W`000<0006O0Il0106O00@007ooOol000Il0003
0001W`6O00<1W`05001oogooOol00005O0000`000Il1W`040Il01000Oomoo`001W`000<0006O0Il0
106O00<007ooOol0PWoo000POol00`00Oomoo`2WOol00`00O01l0003O0000`00Oomoo`07Ool00`00
O01l0004O0000`000Il1W`040Il01000Oomoo`001W`000<0006O0Il00`6O00D007ooOomoo`0000El
00030001W`6O00@1W`04001oogoo0006O0000`000Il1W`030Il01@00Oomoogoo00001G`000<0006O
0Il0106O00@007ooOol000Il00030001W`6O00@1W`04001oogoo0006O0000`000Il1W`030Il01@00
Oomoogoo00001G`000<0006O0Il0106O00@007ooOol000Il00030001W`6O00@1W`03001oogoo089o
o`0087oo00<007ooOol0Ygoo1`002Goo00<007`0O00017`000<0006O0Il0106O00@007ooOol000Il
00030001W`6O00<1W`05001oogooOol00005O0000`000Il1W`040Il01000Oomoo`001W`000<0006O
0Il00`6O00D007ooOomoo`0000El00030001W`6O00@1W`04001oogoo0006O0000`000Il1W`040Il0
1000Oomoo`001W`000<0006O0Il00`6O00D007ooOomoo`0000El00030001W`6O00@1W`04001oogoo
0006O0000`000Il1W`040Il00`00Oomoo`22Ool0021oo`<00;Moo`03001l07`000Al00030001W`6O
00@1W`04001oogoo0006O0000`000Il1W`030Il01@00Oomoogoo00001G`000<0006O0Il0106O00@0
07ooOol000Il00030001W`6O00<1W`05001oogooOol00005O0000`000Il1W`040Il01000Oomoo`00
1W`000<0006O0Il0106O00@007ooOol000Il00030001W`6O00<1W`05001oogooOol00005O0000`00
0Il1W`040Il01000Oomoo`001W`000<0006O0Il0106O00<007ooOol0PWoo000POol00`00Oomoo`2g
Ool00`00O01l0004O0000`000Il1W`040Il01000Oomoo`001W`000<0006O0Il00`6O00D007ooOomo
o`0000El00030001W`6O00@1W`04001oogoo0006O0000`000Il1W`030Il01@00Oomoogoo00001G`0
00<0006O0Il0106O00@007ooOol000Il00030001W`6O00@1W`04001oogoo0006O0000`000Il1W`03
0Il01@00Oomoogoo00001G`000<0006O0Il0106O00@007ooOol000Il00030001W`6O00@1W`03001o
ogoo089oo`0087oo00<007ooOol0]goo00<007`0O00017`000<0006O0Il0106O00@007ooOol000Il
00030001W`6O00<1W`05001oogooOol00005O0000`000Il1W`040Il01000Oomoo`001W`000<0006O
0Il00`6O00D007ooOomoo`0000El00030001W`6O00@1W`04001oogoo0006O0000`000Il1W`040Il0
1000Oomoo`001W`000<0006O0Il00`6O00D007ooOomoo`0000El00030001W`6O00@1W`04001oogoo
0006O0000`000Il1W`040Il00`00Oomoo`22Ool0021oo`03001oogoo0;Moo`03001l07`000Al0003
0001W`6O00@1W`04001oogoo0006O0000`000Il1W`030Il01@00Oomoogoo00001G`000<0006O0Il0
106O00@007ooOol000Il00030001W`6O00<1W`05001oogooOol00005O0000`000Il1W`040Il01000
Oomoo`001W`000<0006O0Il0106O00@007ooOol000Il00030001W`6O00<1W`05001oogooOol00005
O0000`000Il1W`040Il01000Oomoo`001W`000<0006O0Il0106O00<007ooOol0PWoo000POol00`00
Oomoo`2gOol00`00O01l0004O0000`000Il1W`040Il01000Oomoo`001W`000<0006O0Il00`6O00D0
07ooOomoo`0000El00030001W`6O00@1W`04001oogoo0006O0000`000Il1W`030Il01@00Oomoogoo
00001G`000<0006O0Il0106O00@007ooOol000Il00030001W`6O00@1W`04001oogoo0006O0000`00
0Il1W`030Il01@00Oomoogoo00001G`000<0006O0Il0106O00@007ooOol000Il00030001W`6O00@1
W`03001oogoo089oo`0087oo00<007ooOol0]goo00<007`0O00017`000<0006O0Il0106O00@007oo
Ool000Il00030001W`6O00<1W`05001oogooOol00005O0000`000Il1W`040Il01000Oomoo`001W`0
00<0006O0Il00`6O00D007ooOomoo`0000El00030001W`6O00@1W`04001oogoo0006O0000`000Il1
W`040Il01000Oomoo`001W`000<0006O0Il00`6O00D007ooOomoo`0000El00030001W`6O00@1W`04
001oogoo0006O0000`000Il1W`040Il00`00Oomoo`22Ool0011oo`<000Aoo`8000Moo`03001oogoo
0;Moo`03001l07`000Al00030001W`6O00@1W`04001oogoo0006O0000`000Il1W`030Il01@00Oomo
ogoo00001G`000<0006O0Il0106O00@007ooOol000Il00030001W`6O00<1W`05001oogooOol00005
O0000`000Il1W`040Il01000Oomoo`001W`000<0006O0Il0106O00@007ooOol000Il00030001W`6O
00<1W`05001oogooOol00005O0000`000Il1W`040Il01000Oomoo`001W`000<0006O0Il0106O00<0
07ooOol0PWoo000COol01000Oomoo`000Woo00<007ooOol017oo00<007ooOol0]goo00<007`0O000
17`000<0006O0Il0106O00@007ooOol000Il00030001W`6O00<1W`05001oogooOol00005O0000`00
0Il1W`040Il01000Oomoo`001W`000<0006O0Il00`6O00D007ooOomoo`0000El00030001W`6O00@1
W`04001oogoo0006O0000`000Il1W`040Il01000Oomoo`001W`000<0006O0Il00`6O00D007ooOomo
o`0000El00030001W`6O00@1W`04001oogoo0006O0000`000Il1W`040Il00`00Oomoo`22Ool001=o
o`04001oogoo0002Ool00`00Oomoo`04Ool4002fOol00`00O01l0004O0000`000Il1W`040Il01000
Oomoo`001W`000<0006O0Il00`6O00D007ooOomoo`0000El00030001W`6O00@1W`04001oogoo0006
O0000`000Il1W`030Il01@00Oomoogoo00001G`000<0006O0Il0106O00@007ooOol000Il00030001
W`6O00@1W`04001oogoo0006O0000`000Il1W`030Il01@00Oomoogoo00001G`000<0006O0Il0106O
00@007ooOol000Il00030001W`6O00@1W`03001oogoo089oo`0047oo0`000goo00@007ooOol000Io
o`03001oogoo0;Moo`03001l07`000Al00030001W`6O00@1W`04001oogoo0006O0000`000Il1W`03
0Il01@00Oomoogoo00001G`000<0006O0Il0106O00@007ooOol000Il00030001W`6O00<1W`05001o
ogooOol00005O0000`000Il1W`040Il01000Oomoo`001W`000<0006O0Il0106O00@007ooOol000Il
00030001W`6O00<1W`05001oogooOol00005O0000`000Il1W`040Il01000Oomoo`001W`000<0006O
0Il0106O00<007ooOol0PWoo000@Ool00`00Oomoo`03Ool01000Oomoo`001Woo00<007ooOol0]goo
00<007`0O00017`000<0006O0Il0106O00@007ooOol000Il00030001W`6O00<1W`05001oogooOol0
0005O0000`000Il1W`040Il01000Oomoo`001W`000<0006O0Il00`6O00D007ooOomoo`0000El0003
0001W`6O00@1W`04001oogoo0006O0000`000Il1W`040Il01000Oomoo`001W`000<0006O0Il00`6O
00D007ooOomoo`0000El00030001W`6O00@1W`04001oogoo0006O0000`000Il1W`040Il00`00Oomo
o`22Ool0011oo`@000=oo`8000Moo`03001oogoo0;Moo`03001l07`000Al00030001W`6O00@1W`04
001oogoo0006O0000`000Il1W`030Il01@00Oomoogoo00001G`000<0006O0Il0106O00@007ooOol0
00Il00030001W`6O00<1W`05001oogooOol00005O0000`000Il1W`040Il01000Oomoo`001W`000<0
006O0Il0106O00@007ooOol000Il00030001W`6O00<1W`05001oogooOol00005O0000`000Il1W`04
0Il01000Oomoo`001W`000<0006O0Il0106O00<007ooOol0PWoo000POol00`00Oomoo`2gOol00`00
O01l0004O0000`000Il1W`040Il01000Oomoo`001W`000<0006O0Il00`6O00D007ooOomoo`0000El
00030001W`6O00@1W`04001oogoo0006O0000`000Il1W`030Il01@00Oomoogoo00001G`000<0006O
0Il0106O00@007ooOol000Il00030001W`6O00@1W`04001oogoo0006O0000`000Il1W`030Il01@00
Oomoogoo00001G`000<0006O0Il0106O00@007ooOol000Il00030001W`6O00@1W`03001oogoo089o
o`0087oo00<007ooOol0]goo00<007`0O00017`000<0006O0Il0106O00@007ooOol000Il00030001
W`6O00<1W`05001oogooOol00005O0000`000Il1W`040Il01000Oomoo`001W`000<0006O0Il00`6O
00D007ooOomoo`0000El00030001W`6O00@1W`04001oogoo0006O0000`000Il1W`040Il01000Oomo
o`001W`000<0006O0Il00`6O00D007ooOomoo`0000El00030001W`6O00@1W`04001oogoo0006O000
0`000Il1W`040Il00`00Oomoo`22Ool0021oo`03001oogoo0;Moo`03001l07`000Al00030001W`6O
00@1W`04001oogoo0006O0000`000Il1W`030Il01@00Oomoogoo00001G`000<0006O0Il0106O00@0
07ooOol000Il00030001W`6O00<1W`05001oogooOol00005O0000`000Il1W`040Il01000Oomoo`00
1W`000<0006O0Il0106O00@007ooOol000Il00030001W`6O00<1W`05001oogooOol00005O0000`00
0Il1W`040Il01000Oomoo`001W`000<0006O0Il0106O00<007ooOol0PWoo000POol3002gOol00`00
O01l0004O0000`000Il1W`040Il01000Oomoo`001W`000<0006O0Il00`6O00D007ooOomoo`0000El
00030001W`6O00@1W`04001oogoo0006O0000`000Il1W`030Il01@00Oomoogoo00001G`000<0006O
0Il0106O00@007ooOol000Il00030001W`6O00@1W`04001oogoo0006O0000`000Il1W`030Il01@00
Oomoogoo00001G`000<0006O0Il0106O00<007ooOol020001P6O00<007ooOol0PWoo000POol00`00
Oomoo`2gOol00`00O01l0004O0000`000Il1W`040Il01000Oomoo`001W`000<0006O0Il00`6O00D0
07ooOomoo`0000El00030001W`6O00@1W`04001oogoo0006O0000`000Il1W`030Il01@00Oomoogoo
00001G`000<0006O0Il0106O00@007ooOol000Il00030001W`6O00@1W`04001oogoo0006O0000`00
0Il1W`030Il01@00Oomoogoo00001G`000<0006O0Il0106O00<007ooOol01goo2000Q7oo000POol0
0`00Oomoo`2gOol00`00O01l0004O0000`000Il1W`040Il01000Oomoo`001W`000<0006O0Il00`6O
00D007ooOomoo`0000El00030001W`6O00@1W`04001oogoo0006O0000`000Il1W`030Il01@00Oomo
ogoo00001G`000<0006O0Il0106O00@007ooOol000Il00030001W`6O00@1W`04001oogoo0006O000
0`000Il1W`030Il01@00Oomoogoo00001G`000<0006O0Il0106O00<007ooOol0Tgoo000POol00`00
Oomoo`2gOol00`00O01l0004O0000`000Il1W`040Il01000Oomoo`001W`000<0006O0Il00`6O00D0
07ooOomoo`0000El00030001W`6O00@1W`04001oogoo0006O0000`000Il1W`030Il01@00Oomoogoo
00001G`000<0006O0Il0106O00@007ooOol000Il00030001W`6O00@1W`04001oogoo0006O0000`00
0Il1W`030Il01@00Oomoogoo00001G`000<0006O0Il0106O00<007ooOol0Tgoo000POol00`00Oomo
o`2gOol00`00O01l0004O0080002Ool00`00O01l0004O0000`000Il1W`030Il01@00Oomoogoo0000
1G`000<0006O0Il0106O00@007ooOol000Il00030001W`6O00<1W`05001oogooOol00005O0000`00
0Il1W`040Il01000Oomoo`001W`000<0006O0Il0106O00@007ooOol000Il00030001W`6O00<1W`05
001oogooOol00005O0000`000Il1W`040Il00`00Oomoo`2COol0021oo`03001oogoo0;Moo`03001l
07`000Al0003001oogoo00Moo`03001l07`000Al00030001W`6O00<1W`05001oogooOol00005O000
0`000Il1W`040Il01000Oomoo`001W`000<0006O0Il00`6O00D007ooOomoo`0000El00030001W`6O
00@1W`04001oogoo0006O0000`000Il1W`040Il01000Oomoo`001W`000<0006O0Il00`6O00D007oo
Oomoo`0000El00030001W`6O00@1W`03001oogoo09=oo`0087oo00<007ooOol0]goo00<007`0O000
17`000<007ooOol01goo00<007`0O00017`000<0006O0Il00`6O00D007ooOomoo`0000El00030001
W`6O00@1W`04001oogoo0006O0000`000Il1W`030Il01@00Oomoogoo00001G`000<0006O0Il0106O
00@007ooOol000Il00030001W`6O00@1W`04001oogoo0006O0000`000Il1W`030Il01@00Oomoogoo
00001G`000<0006O0Il0106O00<007ooOol0Tgoo000POol3002gOol00`00O01l0004O0000`00Oomo
o`07Ool00`00O01l0004O0000`000Il1W`030Il01@00Oomoogoo00001G`000<0006O0Il0106O00@0
07ooOol000Il00030001W`6O00<1W`05001oogooOol00005O0000`000Il1W`040Il01000Oomoo`00
1W`000<0006O0Il0106O00@007ooOol000Il00030001W`6O00<1W`05001oogooOol00005O0000`00
0Il1W`040Il00`00Oomoo`2COol0021oo`03001oogoo0;Moo`03001l07`000Al0003001oogoo00Mo
o`03001l07`000Al00030001W`6O00<1W`05001oogooOol00005O0000`000Il1W`040Il01000Oomo
o`001W`000<0006O0Il00`6O00D007ooOomoo`0000El00030001W`6O00@1W`04001oogoo0006O000
0`000Il1W`040Il01000Oomoo`001W`000<0006O0Il00`6O00D007ooOomoo`0000El00030001W`6O
00@1W`03001oogoo09=oo`0087oo00<007ooOol0]goo00<007`0O00017`000<007ooOol01goo00<0
07`0O00017`000<0006O0Il00`6O00D007ooOomoo`0000El00030001W`6O00@1W`04001oogoo0006
O0000`000Il1W`030Il01@00Oomoogoo00001G`000<0006O0Il0106O00@007ooOol000Il00030001
W`6O00@1W`04001oogoo0006O0000`000Il1W`030Il01@00Oomoogoo00001G`000<0006O0Il0106O
00<007ooOol0Tgoo000POol00`00Oomoo`2gOol00`00O01l0004O0000`00Oomoo`07Ool00`00O01l
0004O0000`000Il1W`030Il01@00Oomoogoo00001G`000<0006O0Il0106O00@007ooOol000Il0003
0001W`6O00<1W`05001oogooOol00005O0000`000Il1W`040Il01000Oomoo`001W`000<0006O0Il0
106O00@007ooOol000Il00030001W`6O00<1W`05001oogooOol00005O0000`000Il1W`040Il00`00
Oomoo`2COol0021oo`03001oogoo0;Moo`03001l07`000Al0003001oogoo00Moo`03001l07`000Al
00030001W`6O00<1W`05001oogooOol00005O0000`000Il1W`040Il01000Oomoo`001W`000<0006O
0Il00`6O00D007ooOomoo`0000El00030001W`6O00@1W`04001oogoo0006O0000`000Il1W`040Il0
1000Oomoo`001W`000<0006O0Il00`6O00D007ooOomoo`0000El00030001W`6O00@1W`03001oogoo
09=oo`0087oo00<007ooOol0]goo00<007`0O00017`000<007ooOol01goo00<007`0O00017`000<0
006O0Il00`6O00D007ooOomoo`0000El00030001W`6O00@1W`04001oogoo0006O0000`000Il1W`03
0Il01@00Oomoogoo00001G`000<0006O0Il0106O00@007ooOol000Il00030001W`6O00@1W`04001o
ogoo0006O0000`000Il1W`030Il01@00Oomoogoo00001G`000<0006O0Il0106O00<007ooOol0Tgoo
000POol00`00Oomoo`2gOol80009Ool00`00O01l0004O0000`000Il1W`030Il01@00Oomoogoo0000
1G`000<0006O0Il0106O00@007ooOol000Il00030001W`6O00<1W`05001oogooOol00005O0000`00
0Il1W`040Il01000Oomoo`001W`000<0006O0Il0106O00@007ooOol000Il00030001W`6O00<1W`05
001oogooOol00005O0000`000Il1W`040Il00`00Oomoo`2COol0021oo`<00<Qoo`03001l07`000Al
00030001W`6O00<1W`05001oogooOol00005O0000`000Il1W`040Il01000Oomoo`001W`000<0006O
0Il00`6O00D007ooOomoo`0000El00030001W`6O00@1W`04001oogoo0006O0000`000Il1W`040Il0
1000Oomoo`001W`000<0006O0Il00`6O00D007ooOomoo`0000El00030001W`6O00@1W`03001oogoo
09=oo`0087oo00<007ooOol0b7oo00<007`0O00017`000<0006O0Il00`6O00D007ooOomoo`0000El
00030001W`6O00@1W`04001oogoo0006O0000`000Il1W`030Il01@00Oomoogoo00001G`000<0006O
0Il0106O00@007ooOol000Il00030001W`6O00@1W`04001oogoo0006O0000`000Il1W`030Il01@00
Oomoogoo00001G`000<0006O0Il0106O00<007ooOol0Tgoo000POol00`00Oomoo`38Ool00`00O01l
0004O0000`000Il1W`030Il01@00Oomoogoo00001G`000<0006O0Il0106O00@007ooOol000Il0003
0001W`6O00<1W`05001oogooOol00005O0000`000Il1W`040Il01000Oomoo`001W`000<0006O0Il0
106O00@007ooOol000Il00030001W`6O00<1W`05001oogooOol00005O0000`000Il1W`040Il00`00
Oomoo`2COol0021oo`03001oogoo0<Qoo`03001l07`000Al00030001W`6O00<1W`05001oogooOol0
0005O0000`000Il1W`040Il01000Oomoo`001W`000<0006O0Il00`6O00D007ooOomoo`0000El0003
0001W`6O00@1W`04001oogoo0006O0000`000Il1W`040Il01000Oomoo`001W`000<0006O0Il00`6O
00D007ooOomoo`0000El00030001W`6O00@1W`03001oogoo09=oo`0087oo00<007ooOol0b7oo00<0
07`0O00017`000<0006O0Il00`6O00D007ooOomoo`0000El00030001W`6O00@1W`04001oogoo0006
O0000`000Il1W`030Il01@00Oomoogoo00001G`000<0006O0Il0106O00@007ooOol000Il00030001
W`6O00@1W`03001oogoo00P000D1W`05001oogooOol00005O0000`000Il1W`040Il00`00Oomoo`2C
Ool0021oo`03001oogoo0<Qoo`03001l07`000Al00030001W`6O00<1W`05001oogooOol00005O000
0`000Il1W`040Il01000Oomoo`001W`000<0006O0Il00`6O00D007ooOomoo`0000El00030001W`6O
00@1W`04001oogoo0006O0000`000Il1W`040Il00`00Oomoo`07Ool00`000Il1W`030Il01@00Oomo
ogoo00001G`000<0006O0Il0106O00<007ooOol0Tgoo000POol00`00Oomoo`38Ool00`00O01l0004
O0000`000Il1W`030Il01@00Oomoogoo00001G`000<0006O0Il0106O00@007ooOol000Il00030001
W`6O00<1W`05001oogooOol00005O0000`000Il1W`040Il01000Oomoo`001W`000<0006O0Il0106O
00<007ooOol01goo00<0006O0Il00`6O00D007ooOomoo`0000El00030001W`6O00@1W`03001oogoo
09=oo`0087oo0`00b7oo00<007`0O00017`000<0006O0Il00`6O00D007ooOomoo`0000El00030001
W`6O00@1W`04001oogoo0006O0000`000Il1W`030Il01@00Oomoogoo00001G`000<0006O0Il0106O
00@007ooOol000Il00030001W`6O00@1W`03001oogoo00Moo`030001W`6O00<1W`05001oogooOol0
0005O0000`000Il1W`040Il00`00Oomoo`2COol0021oo`03001oogoo0<Qoo`03001l07`000Al0003
0001W`6O00<1W`05001oogooOol00005O0000`000Il1W`040Il01000Oomoo`001W`000<0006O0Il0
0`6O00D007ooOomoo`0000El00030001W`6O00@1W`04001oogoo0006O0000`000Il1W`040Il00`00
Oomoo`07Ool00`000Il1W`030Il01@00Oomoogoo00001G`000<0006O0Il0106O00<007ooOol0Tgoo
000POol00`00Oomoo`38Ool00`00O01l0004O0000`000Il1W`030Il01@00Oomoogoo00001G`000<0
006O0Il0106O00@007ooOol000Il00030001W`6O00<1W`05001oogooOol00005O0000`000Il1W`04
0Il01000Oomoo`001W`000<0006O0Il0106O00<007ooOol01goo00<0006O0Il00`6O00D007ooOomo
o`0000El00030001W`6O00@1W`03001oogoo09=oo`0087oo00<007ooOol0b7oo20001@6O00D007oo
Oomoo`0000El00030001W`6O00@1W`04001oogoo0006O0000`000Il1W`030Il01@00Oomoogoo0000
1G`000<0006O0Il0106O00@007ooOol000Il00030001W`6O00@1W`03001oogoo00Moo`030001W`6O
00<1W`05001oogooOol00005O0000`000Il1W`040Il00`00Oomoo`2COol0021oo`03001oogoo0<mo
o`030001W`6O00<1W`05001oogooOol00005O0000`000Il1W`040Il01000Oomoo`001W`000<0006O
0Il00`6O00D007ooOomoo`0000El00030001W`6O00@1W`04001oogoo0006O0000`000Il1W`040Il0
0`00Oomoo`07Ool00`000Il1W`030Il01@00Oomoogoo00001G`000<0006O0Il0106O00<007ooOol0
Tgoo000AOol00`00Oomoo`02Ool30007Ool00`00Oomoo`3?Ool00`000Il1W`030Il01@00Oomoogoo
00001G`000<0006O0Il0106O00@007ooOol000Il00030001W`6O00<1W`05001oogooOol00005O000
0`000Il1W`040Il01000Oomoo`001W`000<0006O0Il0106O00<007ooOol01goo00<0006O0Il00`6O
00D007ooOomoo`0000El00030001W`6O00@1W`03001oogoo09=oo`004Goo00<007ooOol01Goo00<0
07ooOol017oo00<007ooOol0cgoo00<0006O0Il00`6O00D007ooOomoo`0000El00030001W`6O00@1
W`04001oogoo0006O0000`000Il1W`030Il01@00Oomoogoo00001G`000<0006O0Il0106O00@007oo
Ool000Il00030001W`6O00@1W`03001oogoo00Moo`030001W`6O00<1W`05001oogooOol00005O000
0`000Il1W`040Il00`00Oomoo`2COol0019oo`03001oogoo00Aoo`03001oogoo00Aoo`@00<ioo`03
0001W`6O00<1W`05001oogooOol00005O0000`000Il1W`040Il01000Oomoo`001W`000<0006O0Il0
0`6O00D007ooOomoo`0000El00030001W`6O00@1W`04001oogoo0006O0000`000Il1W`040Il00`00
Oomoo`07Ool70003Ool00`00O01l0003O0000`000Il1W`040Il00`00Oomoo`2COol0019oo`04001o
ogooOol30007Ool00`00Oomoo`3?Ool00`000Il1W`030Il01@00Oomoogoo00001G`000<0006O0Il0
106O00@007ooOol000Il00030001W`6O00<1W`05001oogooOol00005O0000`000Il1W`040Il01000
Oomoo`001W`000<0006O0Il0106O00<007ooOol04Goo00<007`0O0000g`000<0006O0Il0106O00<0
07ooOol0Tgoo000COol01000Oomoo`002Goo00<007ooOol0cgoo00<0006O0Il00`6O00D007ooOomo
o`0000El00030001W`6O00@1W`04001oogoo0006O0000`000Il1W`030Il01@00Oomoogoo00001G`0
00<0006O0Il0106O00@007ooOol000Il00030001W`6O00@1W`03001oogoo015oo`L000H1W`03001o
ogoo09=oo`0047oo10000Woo10001Woo00<007ooOol0cgoo00<0006O0Il00`6O00D007ooOomoo`00
00El00030001W`6O00@1W`04001oogoo0006O0000`000Il1W`030Il01@00Oomoogoo00001G`000<0
006O0Il0106O00@007ooOol000Il00030001W`6O00@1W`03001oogoo01Moo`030001W`6O00@1W`03
001oogoo09=oo`0087oo00<007ooOol0cgoo00<0006O0Il00`6O00D007ooOomoo`0000El00030001
W`6O00@1W`04001oogoo0006O0000`000Il1W`030Il01@00Oomoogoo00001G`000<0006O0Il0106O
00@007ooOol000Il00030001W`6O00@1W`03001oogoo01Moo`030001W`6O00@1W`03001oogoo09=o
o`0087oo00<007ooOol0cgoo00<0006O0Il00`6O00D007ooOomoo`0000El00030001W`6O00@1W`04
001oogoo0006O0000`000Il1W`030Il01@00Oomoogoo00001G`000<0006O0Il0106O00@007ooOol0
00Il00030001W`6O00@1W`03001oogoo01Moo`030001W`6O00@1W`03001oogoo09=oo`0087oo00<0
07ooOol0cgoo00<0006O0Il00`6O00D007ooOomoo`0000El00030001W`6O00@1W`04001oogoo0006
O0000`000Il1W`030Il01@00Oomoogoo00001G`000<0006O0Il0106O00@007ooOol000Il00030001
W`6O00@1W`03001oogoo01Moo`030001W`6O00@1W`03001oogoo09=oo`0087oo00<007ooOol0cgoo
00<0006O0Il00`6O00D007ooOomoo`0000El00030001W`6O00@1W`04001oogoo0006O0000`000Il1
W`030Il01@00Oomoogoo00001G`000<0006O0Il0106O00@007ooOol000Il00030001W`6O00@1W`03
001oogoo01Moo`030001W`6O00@1W`03001oogoo09=oo`0087oo0`00cgoo1`000goo00<007`0O000
0g`000<0006O0Il0106O00@007ooOol000Il00030001W`6O00<1W`05001oogooOol00005O0000`00
0Il1W`040Il01000Oomoo`001W`000<0006O0Il0106O00<007ooOol05goo00<0006O0Il0106O00<0
07ooOol0Tgoo000POol00`00Oomoo`3IOol00`00O01l0003O0000`000Il1W`040Il01000Oomoo`00
1W`000<0006O0Il00`6O00D007ooOomoo`0000El00030001W`6O00@1W`04001oogoo0006O0000`00
0Il1W`040Il00`00Oomoo`0GOol00`000Il1W`040Il00`00Oomoo`2COol0021oo`03001oogoo0=Uo
o`03001l07`000=l00030001W`6O00@1W`04001oogoo0006O0000`000Il1W`030Il01@00Oomoogoo
00001G`000<0006O0Il0106O00@007ooOol000Il00030001W`6O00@1W`03001oogoo01Moo`030001
W`6O00@1W`03001oogoo09=oo`0087oo00<007ooOol0fGoo00<007`0O0000g`000<0006O0Il0106O
00@007ooOol000Il00030001W`6O00<1W`05001oogooOol00005O0000`000Il1W`040Il01000Oomo
o`001W`000<0006O0Il0106O00<007ooOol05goo00<0006O0Il0106O00<007ooOol0Tgoo000POol0
0`00Oomoo`3IOol00`00O01l0003O0000`000Il1W`040Il01000Oomoo`001W`000<0006O0Il00`6O
00D007ooOomoo`0000El00030001W`6O00@1W`04001oogoo0006O0000`000Il1W`040Il00`00Oomo
o`0GOol00`000Il1W`040Il00`00Oomoo`2COol0021oo`03001oogoo0=Uoo`03001l07`000=l0003
0001W`6O00@1W`04001oogoo0006O0000`000Il1W`030Il01@00Oomoogoo00001G`000<0006O0Il0
106O00@007ooOol000Il00030001W`6O00@1W`03001oogoo01Moo`030001W`6O00@1W`03001oogoo
09=oo`0087oo00<007ooOol0fGoo00<007`0O0000g`000<0006O0Il0106O00@007ooOol000Il0003
0001W`6O00<1W`05001oogooOol00005O0000`000Il1W`040Il01000Oomoo`001W`000<0006O0Il0
106O00<007ooOol05goo00<0006O0Il0106O00<007ooOol0Tgoo000POol3003IOol00`00O01l0003
O0000`000Il1W`040Il01000Oomoo`001W`000<0006O0Il00`6O00D007ooOomoo`0000El00030001
W`6O00@1W`04001oogoo0006O0000`000Il1W`040Il00`00Oomoo`0GOol00`000Il1W`040Il00`00
Oomoo`2COol0021oo`03001oogoo0=Uoo`03001l07`000=l00030001W`6O00@1W`04001oogoo0006
O0000`000Il1W`030Il01@00Oomoogoo00001G`000<0006O0Il0106O00@007ooOol000Il00030001
W`6O00@1W`03001oogoo01Moo`030001W`6O00@1W`03001oogoo09=oo`0087oo00<007ooOol0fGoo
00<007`0O0000g`000<0006O0Il0106O00@007ooOol000Il00030001W`6O00<1W`05001oogooOol0
0005O0000`000Il1W`040Il01000Oomoo`001W`000<0006O0Il0106O00<007ooOol05goo00<0006O
0Il0106O00<007ooOol0Tgoo000POol00`00Oomoo`3IOol00`00O01l0003O0000`000Il1W`040Il0
1000Oomoo`001W`000<0006O0Il00`6O00D007ooOomoo`0000El00030001W`6O00@1W`04001oogoo
0006O0000`000Il1W`040Il00`00Oomoo`0GOol00`000Il1W`040Il00`00Oomoo`2COol0021oo`03
001oogoo0=Uoo`03001l07`000=l00030001W`6O00@1W`04001oogoo0006O0000`000Il1W`030Il0
1@00Oomoogoo00001G`000<0006O0Il0106O00@007ooOol000Il00030001W`6O00@1W`03001oogoo
01Moo`030001W`6O00@1W`03001oogoo09=oo`0087oo00<007ooOol0fGoo00<007`0O0000g`000<0
006O0Il0106O00@007ooOol000Il00030001W`6O00<1W`05001oogooOol00005O0000`000Il1W`04
0Il01000Oomoo`001W`000<0006O0Il0106O00<007ooOol05goo00<0006O0Il0106O00<007ooOol0
Tgoo000POol00`00Oomoo`3IOol00`00O01l0003O0000`000Il1W`040Il01000Oomoo`001W`000<0
006O0Il00`6O00D007ooOomoo`0000El00030001W`6O00@1W`04001oogoo0006O0000`000Il1W`04
0Il00`00Oomoo`0GOol00`000Il1W`040Il00`00Oomoo`2COol0021oo`<00=Uoo`03001l07`000=l
00030001W`6O00@1W`04001oogoo0006O0000`000Il1W`030Il01@00Oomoogoo00001G`000<0006O
0Il0106O00@007ooOol000Il00030001W`6O00@1W`03001oogoo01Moo`030001W`6O00@1W`03001o
ogoo09=oo`0087oo00<007ooOol0fGoo00<007`0O0000g`000<0006O0Il0106O00@007ooOol000Il
00030001W`6O00<1W`05001oogooOol00005O0000`000Il1W`040Il01000Oomoo`001W`000<0006O
0Il0106O00<007ooOol05goo00<0006O0Il0106O00<007ooOol0Tgoo000POol00`00Oomoo`3IOol0
0`00O01l0003O0000`000Il1W`040Il01000Oomoo`001W`000<0006O0Il00`6O00D007ooOomoo`00
00El00030001W`6O00@1W`04001oogoo0006O0000`000Il1W`040Il00`00Oomoo`0GOol00`000Il1
W`040Il00`00Oomoo`2COol0021oo`03001oogoo0=Uoo`03001l07`000=l00030001W`6O00@1W`04
001oogoo0006O0000`000Il1W`030Il01@00Oomoogoo00001G`000<0006O0Il0106O00@007ooOol0
00Il00030001W`6O00@1W`03001oogoo01Moo`030001W`6O00@1W`03001oogoo09=oo`0087oo00<0
07ooOol0fGoo00<007`0O0000g`000<0006O0Il0106O00@007ooOol000Il00030001W`6O00<1W`05
001oogooOol00005O0000`000Il1W`040Il01000Oomoo`001W`000<0006O0Il0106O00<007ooOol0
5goo2000UGoo000POol00`00Oomoo`3IOol00`00O01l0003O0000`000Il1W`040Il01000Oomoo`00
1W`000<0006O0Il00`6O00D007ooOomoo`0000El00030001W`6O00@1W`04001oogoo0006O0000`00
0Il1W`040Il00`00Oomoo`2dOol0021oo`03001oogoo0=Uoo`03001l07`000=l00030001W`6O00@1
W`04001oogoo0006O0000`000Il1W`030Il01@00Oomoogoo00001G`000<0006O0Il0106O00@007oo
Ool000Il00030001W`6O00@1W`03001oogoo0;Aoo`0087oo0`00fGoo00<007`0O0000g`000<0006O
0Il0106O00@007ooOol000Il00030001W`6O00<1W`05001oogooOol00005O0000`000Il1W`040Il0
1000Oomoo`001W`000<0006O0Il0106O00<007ooOol0]7oo000POol00`00Oomoo`3IOol00`00O01l
0003O0000`000Il1W`040Il01000Oomoo`001W`000<0006O0Il00`6O00D007ooOomoo`0000El0003
0001W`6O00@1W`04001oogoo0006O0000`000Il1W`040Il00`00Oomoo`2dOol0021oo`03001oogoo
0=Uoo`03001l07`000=l00030001W`6O00@1W`04001oogoo0006O0000`000Il1W`030Il01@00Oomo
ogoo00001G`000<0006O0Il0106O00@007ooOol000Il00030001W`6O00@1W`03001oogoo0;Aoo`00
87oo00<007ooOol0fGoo00<007`0O0000g`000<0006O0Il0106O00@007ooOol000Il00030001W`6O
00<1W`05001oogooOol00005O0000`000Il1W`040Il01000Oomoo`001W`000<0006O0Il0106O00<0
07ooOol0]7oo000POol00`00Oomoo`3IOol00`00O01l0003O0000`000Il1W`040Il01000Oomoo`00
1W`000<0006O0Il00`6O00D007ooOomoo`0000El00030001W`6O00@1W`04001oogoo0006O0000`00
0Il1W`040Il00`00Oomoo`2dOol000Yoo`<000Aoo`8000Aoo`8000Moo`03001oogoo0=Uoo`03001l
07`000=l00030001W`6O00@1W`04001oogoo0006O0000`000Il1W`030Il01@00Oomoogoo00001G`0
00<0006O0Il0106O00@007ooOol000Il00030001W`6O00@1W`03001oogoo0;Aoo`002goo00<007oo
Ool00Woo00@007ooOol0009oo`04001oogoo0006Ool00`00Oomoo`3IOol00`00O01l0003O0000`00
0Il1W`040Il01000Oomoo`001W`000<0006O0Il00`6O00D007ooOomoo`0000El00030001W`6O00@1
W`04001oogoo0006O0000`000Il1W`040Il00`00Oomoo`2dOol000]oo`03001oogoo009oo`04001o
ogoo0002Ool01000Oomoo`001Woo1000f7oo00<007`0O0000g`000<0006O0Il0106O00@007ooOol0
00Il00030001W`6O00<1W`05001oogooOol00005O0000`000Il1W`040Il01000Oomoo`001W`000<0
006O0Il0106O00<007ooOol0]7oo000;Ool00`00Oomoo`02Ool01000Oomoo`000Woo00@007ooOol0
00Ioo`03001oogoo0=Uoo`03001l07`000=l00030001W`6O00@1W`04001oogoo0006O0000`000Il1
W`030Il01@00Oomoogoo00001G`000<0006O0Il0106O00@007ooOol000Il00030001W`6O00@1W`03
001oogoo0;Aoo`002goo00<007ooOol00Woo00@007ooOol0009oo`04001oogoo0006Ool00`00Oomo
o`3IOol00`00O01l0003O0000`000Il1W`040Il01000Oomoo`001W`000<0006O0Il00`6O00D007oo
Oomoo`0000El00030001W`6O00@1W`04001oogoo0006O0000`000Il1W`040Il00`00Oomoo`2dOol0
00Yoo`8000Eoo`8000Aoo`8000Moo`03001oogoo0=Uoo`L000H1W`04001oogoo0006O0000`000Il1
W`030Il01@00Oomoogoo00001G`000<0006O0Il0106O00@007ooOol000Il00030001W`6O00@1W`03
001oogoo0;Aoo`0087oo00<007ooOol0ggoo00<0006O0Il0106O00@007ooOol000Il00030001W`6O
00<1W`05001oogooOol00005O0000`000Il1W`040Il01000Oomoo`001W`000<0006O0Il0106O00<0
07ooOol0]7oo000POol00`00Oomoo`3OOol00`000Il1W`040Il01000Oomoo`001W`000<0006O0Il0
0`6O00D007ooOomoo`0000El00030001W`6O00@1W`04001oogoo0006O0000`000Il1W`040Il00`00
Oomoo`2dOol0021oo`03001oogoo0=moo`030001W`6O00@1W`04001oogoo0006O0000`000Il1W`03
0Il01@00Oomoogoo00001G`000<0006O0Il0106O00@007ooOol000Il00030001W`6O00@1W`03001o
ogoo0;Aoo`0087oo00<007ooOol0ggoo00<0006O0Il0106O00@007ooOol000Il00030001W`6O00<1
W`05001oogooOol00005O0000`000Il1W`040Il01000Oomoo`001W`000<0006O0Il0106O00<007oo
Ool0]7oo000POol3003OOol00`000Il1W`040Il01000Oomoo`001W`000<0006O0Il00`6O00D007oo
Oomoo`0000El00030001W`6O00@1W`03001oogoo00P000H1W`03001oogoo0;Aoo`0087oo00<007oo
Ool0ggoo00<0006O0Il0106O00@007ooOol000Il00030001W`6O00<1W`05001oogooOol00005O000
0`000Il1W`040Il00`00Oomoo`07Ool00`000Il1W`040Il00`00Oomoo`2dOol0021oo`03001oogoo
0=moo`030001W`6O00@1W`04001oogoo0006O0000`000Il1W`030Il01@00Oomoogoo00001G`000<0
006O0Il0106O00<007ooOol01goo00<0006O0Il0106O00<007ooOol0]7oo000POol00`00Oomoo`3O
Ool00`000Il1W`040Il01000Oomoo`001W`000<0006O0Il00`6O00D007ooOomoo`0000El00030001
W`6O00@1W`03001oogoo00Moo`030001W`6O00@1W`03001oogoo0;Aoo`0087oo00<007ooOol0ggoo
00<0006O0Il0106O00@007ooOol000Il00030001W`6O00<1W`05001oogooOol00005O0000`000Il1
W`040Il00`00Oomoo`07Ool00`000Il1W`040Il00`00Oomoo`2dOol0021oo`03001oogoo0=moo`03
0001W`6O00@1W`04001oogoo0006O0000`000Il1W`030Il01@00Oomoogoo00001G`000<0006O0Il0
106O00<007ooOol01goo00<0006O0Il0106O00<007ooOol0]7oo000POol00`00Oomoo`3OOol00`00
0Il1W`040Il01000Oomoo`001W`000<0006O0Il00`6O00D007ooOomoo`0000El00030001W`6O00@1
W`03001oogoo00Moo`030001W`6O00@1W`03001oogoo0;Aoo`0087oo0`00ggoo00<0006O0Il0106O
00@007ooOol000Il00030001W`6O00<1W`05001oogooOol00005O0000`000Il1W`040Il00`00Oomo
o`07Ool00`000Il1W`040Il00`00Oomoo`2dOol0021oo`03001oogoo0=moo`P0009oo`03001l07`0
00Al00030001W`6O00<1W`05001oogooOol00005O0000`000Il1W`040Il00`00Oomoo`07Ool00`00
0Il1W`040Il00`00Oomoo`2dOol0021oo`03001oogoo0>Uoo`03001l07`000Al00030001W`6O00<1
W`05001oogooOol00005O0000`000Il1W`040Il00`00Oomoo`07Ool00`000Il1W`040Il00`00Oomo
o`2dOol0021oo`03001oogoo0>Uoo`03001l07`000Al00030001W`6O00<1W`05001oogooOol00005
O0000`000Il1W`040Il00`00Oomoo`07Ool00`000Il1W`040Il00`00Oomoo`2dOol0021oo`03001o
ogoo0>Uoo`03001l07`000Al00030001W`6O00<1W`05001oogooOol00005O0000`000Il1W`040Il0
0`00Oomoo`07Ool00`000Il1W`040Il00`00Oomoo`2dOol0021oo`03001oogoo0>Uoo`03001l07`0
00Al00030001W`6O00<1W`05001oogooOol00005O0000`000Il1W`040Il00`00Oomoo`07Ool00`00
0Il1W`040Il00`00Oomoo`2dOol0021oo`03001oogoo0>Uoo`03001l07`000Al00030001W`6O00<1
W`05001oogooOol00005O0000`000Il1W`040Il00`00Oomoo`07Ool00`000Il1W`040Il00`00Oomo
o`2dOol0021oo`<00>Uoo`03001l07`000Al00L000=oo`03001l07`000=l00030001W`6O00@1W`03
001oogoo00Moo`030001W`6O00@1W`03001oogoo0;Aoo`0087oo00<007ooOol0jGoo00<007`0O000
17`000<007ooOol01goo00<007`0O0000g`000<0006O0Il0106O00<007ooOol01goo00<0006O0Il0
106O00<007ooOol0]7oo000POol00`00Oomoo`3YOol00`00O01l0004O0000`00Oomoo`07Ool00`00
O01l0003O0000`000Il1W`040Il00`00Oomoo`07Ool00`000Il1W`040Il00`00Oomoo`2dOol0021o
o`03001oogoo0>Uoo`03001l07`000Al0003001oogoo00Moo`03001l07`000=l00030001W`6O00@1
W`03001oogoo00Moo`030001W`6O00@1W`03001oogoo0;Aoo`0087oo00<007ooOol0jGoo00<007`0
O00017`000<007ooOol01goo00<007`0O0000g`000<0006O0Il0106O00<007ooOol01goo00<0006O
0Il0106O00<007ooOol0]7oo000POol00`00Oomoo`3YOol00`00O01l0004O0000`00Oomoo`07Ool0
0`00O01l0003O0000`000Il1W`040Il00`00Oomoo`07Ool00`000Il1W`040Il00`00Oomoo`2dOol0
021oo`03001oogoo0>Uoo`03001l07`000Al0003001oogoo00Moo`03001l07`000=l00030001W`6O
00@1W`03001oogoo00Moo`030001W`6O00@1W`03001oogoo0;Aoo`0087oo0`00jGoo00<007`0O000
17`000<007ooOol01goo00<007`0O0000g`000<0006O0Il0106O00<007ooOol01goo00<0006O0Il0
106O00<007ooOol0]7oo000POol00`00Oomoo`3YOol00`00O01l0004O0000`00Oomoo`07Ool00`00
O01l0003O0000`000Il1W`040Il00`00Oomoo`07Ool00`000Il1W`040Il00`00Oomoo`2dOol0021o
o`03001oogoo0>Uoo`03001l07`000Al0003001oogoo00Moo`03001l07`000=l00030001W`6O00@1
W`03001oogoo00Moo`P00;Ioo`0087oo00<007ooOol0jGoo00<007`0O00017`000<007ooOol01goo
00<007`0O0000g`000<0006O0Il0106O00<007ooOol0aGoo000POol00`00Oomoo`3YOol00`00O01l
0004O0000`00Oomoo`07Ool00`00O01l0003O0000`000Il1W`040Il00`00Oomoo`35Ool000Yoo`<0
00=oo`@0009oo`<000Moo`03001oogoo0>Uoo`03001l07`000Al0003001oogoo00Moo`03001l07`0
00=l00030001W`6O00@1W`03001oogoo0<Eoo`002goo00<007ooOol00goo00<007ooOol01Goo00<0
07ooOol017oo00<007ooOol0jGoo00<007`0O00017`000<007ooOol01goo00<007`0O0000g`000<0
006O0Il0106O00<007ooOol0aGoo000;Ool00`00Oomoo`04Ool00`00Oomoo`04Ool00`00Oomoo`04
Ool4003XOol00`00O01l0004O0000`00Oomoo`07Ool00`00O01l0003O0000`000Il1W`040Il00`00
Oomoo`35Ool000]oo`03001oogoo00Eoo`03001oogoo00<000Moo`03001oogoo0>Uoo`03001l07`0
00Al0003001oogoo00Moo`03001l07`000=l00030001W`6O00@1W`03001oogoo0<Eoo`002goo00<0
07ooOol00Woo00@007ooOol0009oo`03001oogoo00Moo`03001oogoo0>Uoo`03001l07`000Al0003
001oogoo00Moo`03001l07`000=l00030001W`6O00@1W`03001oogoo0<Eoo`002Woo0P001Goo0P00
0goo10001Woo00<007ooOol0jGoo00<007`0O00017`000<007ooOol01goo00<007`0O0000g`000<0
006O0Il0106O00<007ooOol0aGoo000POol00`00Oomoo`3YOol00`00O01l0004O0000`00Oomoo`07
Ool00`00O01l0003O0000`000Il1W`040Il00`00Oomoo`35Ool0021oo`03001oogoo0>Uoo`03001l
07`000Al0003001oogoo00Moo`03001l07`000=l00030001W`6O00@1W`03001oogoo0<Eoo`0087oo
00<007ooOol0jGoo00<007`0O00017`000<007ooOol01goo00<007`0O0000g`000<0006O0Il0106O
00<007ooOol0aGoo000POol3003YOol00`00O01l0004O0000`00Oomoo`07Ool00`00O01l0003O000
0`000Il1W`040Il00`00Oomoo`35Ool0021oo`03001oogoo0>Uoo`03001l07`000Al0003001oogoo
00Moo`03001l07`000=l00030001W`6O00@1W`03001oogoo0<Eoo`0087oo00<007ooOol0jGoo00<0
07`0O00017`000<007ooOol01goo00<007`0O0000g`000<0006O0Il0106O00<007ooOol0aGoo000P
Ool00`00Oomoo`3YOol00`00O01l0004O0000`00Oomoo`07Ool00`00O01l0003O0000`000Il1W`04
0Il00`00Oomoo`35Ool0021oo`03001oogoo0>Uoo`03001l07`000Al0003001oogoo00Moo`03001l
07`000=l00030001W`6O00@1W`03001oogoo0<Eoo`0087oo00<007ooOol0jGoo00<007`0O00017`0
00<007ooOol01goo00<007`0O0000g`000<0006O0Il0106O00<007ooOol0aGoo000POol00`00Oomo
o`3YOol00`00O01l0004O0000`00Oomoo`07Ool00`00O01l0003O0000`000Il1W`040Il00`00Oomo
o`35Ool0021oo`03001oogoo0>Uoo`03001l07`000Al0003001oogoo00Moo`03001l07`000=l0003
0001W`6O00@1W`03001oogoo0<Eoo`0087oo0`00jGoo00<007`0O00017`000<007ooOol01goo00<0
07`0O0000g`000<0006O0Il0106O00<007ooOol0aGoo000POol00`00Oomoo`3YOol80009Ool00`00
O01l0003O0000`000Il1W`040Il00`00Oomoo`35Ool0021oo`03001oogoo0?Yoo`03001l07`000=l
00030001W`6O00@1W`03001oogoo0<Eoo`0087oo00<007ooOol0nWoo00<007`0O0000g`000<0006O
0Il0106O00<007ooOol0aGoo000POol00`00Oomoo`3jOol00`00O01l0003O0000`000Il1W`040Il0
0`00Oomoo`35Ool0021oo`03001oogoo0?Yoo`03001l07`000=l00030001W`6O00@1W`03001oogoo
0<Eoo`0087oo00<007ooOol0nWoo00<007`0O0000g`000<0006O0Il0106O00<007ooOol0aGoo000P
Ool3003jOol00`00O01l0003O0000`000Il1W`040Il00`00Oomoo`35Ool0021oo`03001oogoo0?Yo
o`03001l07`000=l00030001W`6O00@1W`03001oogoo0<Eoo`0087oo00<007ooOol0nWoo00<007`0
O0000g`000<0006O0Il0106O00<007ooOol0aGoo000POol00`00Oomoo`3jOol00`00O01l0003O000
0`000Il1W`040Il00`00Oomoo`35Ool0021oo`03001oogoo0?Yoo`03001l07`000=l00030001W`6O
00@1W`03001oogoo0<Eoo`0087oo00<007ooOol0nWoo00<007`0O0000g`000<0006O0Il0106O00<0
07ooOol0aGoo000POol00`00Oomoo`3jOol00`00O01l0003O0000`000Il1W`040Il00`00Oomoo`35
Ool0021oo`<00?Yoo`03001l07`000=l00030001W`6O00@1W`03001oogoo0<Eoo`0087oo00<007oo
Ool0nWoo00<007`0O0000g`000<0006O0Il0106O00<007ooOol0aGoo000POol00`00Oomoo`3jOol0
0`00O01l0003O0000`000Il1W`040Il00`00Oomoo`35Ool0021oo`03001oogoo0?Yoo`03001l07`0
00=l00030001W`6O00@1W`03001oogoo0<Eoo`0087oo00<007ooOol0nWoo00<007`0O0000g`000<0
006O0Il0106O00<007ooOol0aGoo000:Ool30003Ool30004Ool20007Ool00`00Oomoo`3jOol00`00
O01l0003O0000`000Il1W`040Il00`00Oomoo`35Ool000]oo`03001oogoo00Eoo`04001oogoo0002
Ool00`00Oomoo`04Ool00`00Oomoo`3jOol00`00O01l0003O0000`000Il1W`040Il00`00Oomoo`35
Ool000]oo`03001oogoo00Eoo`04001oogoo0002Ool00`00Oomoo`04Ool4003iOol00`00O01l0003
O0000`000Il1W`040Il00`00Oomoo`35Ool000]oo`03001oogoo009oo`<000=oo`04001oogoo0006
Ool00`00Oomoo`3jOol00`00O01l0003O0000`000Il1W`040Il00`00Oomoo`35Ool000]oo`03001o
ogoo009oo`03001oogoo00=oo`04001oogoo0006Ool00`00Oomoo`3jOol00`00O01l0003O0000`00
0Il1W`040Il00`00Oomoo`35Ool000Yoo`8000Aoo`@000=oo`8000Moo`03001oogoo0?Yoo`03001l
07`000=l00030001W`6O00@1W`03001oogoo0<Eoo`0087oo00<007ooOol0nWoo00<007`0O0000g`0
00<0006O0Il0106O00<007ooOol0aGoo000POol00`00Oomoo`3jOol00`00O01l0003O0000`000Il1
W`040Il00`00Oomoo`35Ool0021oo`03001oogoo0?Yoo`03001l07`000=l00030001W`6O00@1W`03
001oogoo0<Eoo`0087oo0`00nWoo00<007`0O0000g`000<0006O0Il0106O00<007ooOol0aGoo000P
Ool00`00Oomoo`3jOol00`00O01l0003O0000`000Il1W`040Il00`00Oomoo`35Ool0021oo`03001o
ogoo0?Yoo`03001l07`000=l00P00<Moo`0087oo00<007ooOol0nWoo00<007`0O0000g`000<007oo
Ool0c7oo000POol00`00Oomoo`3jOol00`00O01l0003O0000`00Oomoo`3<Ool0021oo`03001oogoo
0?Yoo`03001l07`000=l0003001oogoo0<aoo`0087oo00<007ooOol0nWoo00<007`0O0000g`000<0
07ooOol0c7oo000POol00`00Oomoo`3jOol00`00O01l0003O0000`00Oomoo`3<Ool0021oo`<00?Yo
o`03001l07`000=l0003001oogoo0<aoo`0087oo00<007ooOol0nWoo00<007`0O0000g`000<007oo
Ool0c7oo000POol00`00Oomoo`3jOol00`00O01l0003O0000`00Oomoo`3<Ool0021oo`03001oogoo
0?Yoo`03001l07`000=l0003001oogoo0<aoo`0087oo00<007ooOol0nWoo00<007`0O0000g`000<0
07ooOol0c7oo000POol00`00Oomoo`3jOol00`00O01l0003O0000`00Oomoo`3<Ool0021oo`03001o
ogoo0?Yoo`03001l07`000=l0003001oogoo0<aoo`0087oo0`00nWoo00<007`0O0000g`000<007oo
Ool0c7oo000POol00`00Oomoo`3jOol00`00O01l0003O0000`00Oomoo`3<Ool0021oo`03001oogoo
0?Yoo`03001l07`000=l0003001oogoo0<aoo`0087oo00<007ooOol0nWoo00<007`0O0000g`000<0
07ooOol0c7oo000POol00`00Oomoo`3jOol00`00O01l0003O0000`00Oomoo`3<Ool0021oo`03001o
ogoo0?Yoo`03001l07`000=l0003001oogoo0<aoo`0087oo00<007ooOol0nWoo00<007`0O0000g`0
00<007ooOol0c7oo000POol3003jOol00`00O01l0003O0000`00Oomoo`3<Ool0021oo`03001oogoo
0?Yoo`03001l07`000=l0003001oogoo0<aoo`0087oo00<007ooOol0nWoo00<007`0O0000g`000<0
07ooOol0c7oo000POol00`00Oomoo`3jOol00`00O01l0003O0000`00Oomoo`3<Ool0021oo`03001o
ogoo0?Yoo`L00<ioo`002Woo0`0017oo00<007ooOol00Woo0`001goo00<007ooOol0ogood7oo000;
Ool00`00Oomoo`03Ool00`00Oomoo`05Ool00`00Oomoo`04Ool00`00Oomoo`3oOoo@Ool000]oo`03
001oogoo00Aoo`03001oogoo00Aoo`03001oogoo00Aoo`@00?moolmoo`002goo00<007ooOol017oo
00@007ooOomoo`<000Moo`03001oogoo0?moom1oo`002goo00<007ooOol01Goo00@007ooOol000Uo
o`03001oogoo0?moom1oo`002Woo0P0017oo10000Woo10001Woo00<007ooOol0ogood7oo000POol0
0`00Oomoo`3oOoo@Ool0021oo`03001oogoo0?moom1oo`0087oo00<007ooOol0ogood7oo000POol3
003oOoo@Ool0021oo`03001oogoo0?moom1oo`0087oo00<007ooOol0ogood7oo000POol00`00Oomo
o`3oOoo@Ool0021oo`03001oogoo0?moom1oo`0087oo00<007ooOol0ogood7oo000POol00`00Oomo
o`3oOoo@Ool0021oo`<00?moom1oo`0087oo00<007ooOol0ogood7oo000POol00`00Oomoo`3oOoo@
Ool0021oo`03001oogoo0?moom1oo`0087oo00<007ooOol0ogood7oo000POol00`00Oomoo`3oOoo@
Ool0021oo`03001oogoo0?moom1oo`0087oo00<007ooOol0ogood7oo000POol3003oOoo@Ool0021o
o`03001oogoo0?moom1oo`0087oo00<007ooOol0ogood7oo000POol00`00Oomoo`3oOoo@Ool0021o
o`03001oogoo0?moom1oo`0087oo00<007ooOol0ogood7oo000POol00`00Oomoo`3oOoo@Ool0021o
o`<00?moom1oo`0087oo00<007ooOol0ogood7oo000POol00`00Oomoo`3oOoo@Ool0021oo`03001o
ogoo0?moom1oo`0087oo00<007ooOol0ogood7oo000:Ool40003Ool20004Ool20007Ool00`00Oomo
o`3oOoo@Ool000]oo`03001oogoo009oo`04001oogoo0002Ool01000Oomoo`001Woo00<007ooOol0
ogood7oo000<Ool01@00Oomoogoo00000Woo00@007ooOol0009oo`03001oogoo00Aoo`@00?moolmo
o`003Goo00@007ooOol0009oo`04001oogoo0002Ool00`00Oomoo`3oOooGOol000Yoo`04001oogoo
0002Ool01000Oomoo`000Woo00@007ooOol00?moomUoo`002goo0P0017oo0P0017oo0P00ogoofWoo
003oOoocOol00001\
\>"],
  ImageRangeCache->{{{0, 497}, {306.625, 0}} -> {-1.38429, -10.3111, 
  0.0602303, 0.696105}}]
}, Closed]],

Cell[TextData[
"One could try a different value of \[Phi].  Here, \[Phi]=10, which equals \
the value of \[Theta] that actually generated the genealogy:"], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(tt[1. , 10. , 1]\)], "Input",
  CellLabel->"In[215]:="],

Cell[BoxData[
    InterpretationBox[GridBox[{
          {GridBox[{
                {"4"},
                {"1"},
                {"2"},
                {"3"}
                },
              RowSpacings->0.25,
              ColumnSpacings->1,
              RowAlignments->Baseline,
              ColumnAlignments->{Left}], "3.35715291577426144`*^-19", 
            "1.62820567966983187`*^-19", "1.72735923801524471`*^-16"},
          {GridBox[{
                {"1"},
                {"4"},
                {"2"},
                {"3"}
                },
              RowSpacings->0.25,
              ColumnSpacings->1,
              RowAlignments->Baseline,
              ColumnAlignments->{Left}], "2.57910184548960907`*^-17", 
            "1.51240945142313165`*^-17", "1.72735923801524471`*^-16"},
          {GridBox[{
                {"1"},
                {"2"},
                {"4"},
                {"3"}
                },
              RowSpacings->0.25,
              ColumnSpacings->1,
              RowAlignments->Baseline,
              ColumnAlignments->{Left}], "7.05931301211298212`*^-17", 
            "1.91874202968952545`*^-17", "1.72735923801524471`*^-16"},
          {GridBox[{
                {"1"},
                {"2"},
                {"3"},
                {"4"}
                },
              RowSpacings->0.25,
              ColumnSpacings->1,
              RowAlignments->Baseline,
              ColumnAlignments->{Left}], "8.10569420459951395`*^-17", 
            "8.8450509638874486`*^-18", "1.72735923801524471`*^-16"},
          {"Total", "1.77776805913598483`*^-16", "2.59837789710470845`*^-17", 
            "1.72735923801524471`*^-16"}
          },
        RowSpacings->1,
        ColumnSpacings->3,
        RowAlignments->Baseline,
        ColumnAlignments->{Left}],
      TableForm[ {{{4, 1, 2, 3}, 3.3571529157742611*^-19, 
        1.6282056796698317*^-19, 1.7273592380152449*^-16}, {{1, 4, 2, 3}, 
        2.5791018454896094*^-17, 1.5124094514231317*^-17, 
        1.7273592380152449*^-16}, {{1, 2, 4, 3}, 7.0593130121129809*^-17, 
        1.9187420296895255*^-17, 1.7273592380152449*^-16}, {{1, 2, 3, 4}, 
        8.1056942045995142*^-17, 8.8450509638874485*^-18, 
        1.7273592380152449*^-16}, {Total, 1.7777680591359849*^-16, 
        2.598377897104709*^-17, 1.7273592380152449*^-16}}]]], "Output",
  CellLabel->"Out[215]//TableForm="]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    \(tt[1. , 10. , 2]\)], "Input",
  CellLabel->"In[216]:="],

Cell[BoxData[
    InterpretationBox[GridBox[{
          {GridBox[{
                {"4"},
                {"1"},
                {"2"},
                {"3"}
                },
              RowSpacings->0.25,
              ColumnSpacings->1,
              RowAlignments->Baseline,
              ColumnAlignments->{Left}], "3.65725629499166826`*^-19", 
            "1.07405964163264355`*^-19", "1.72735923801524471`*^-16"},
          {GridBox[{
                {"1"},
                {"4"},
                {"2"},
                {"3"}
                },
              RowSpacings->0.25,
              ColumnSpacings->1,
              RowAlignments->Baseline,
              ColumnAlignments->{Left}], "4.71359940486912343`*^-17", 
            "3.84613126698780138`*^-17", "1.72735923801524471`*^-16"},
          {GridBox[{
                {"1"},
                {"2"},
                {"4"},
                {"3"}
                },
              RowSpacings->0.25,
              ColumnSpacings->1,
              RowAlignments->Baseline,
              ColumnAlignments->{Left}], "7.55365008298918194`*^-17", 
            "3.21011158802765272`*^-17", "1.72735923801524471`*^-16"},
          {GridBox[{
                {"1"},
                {"2"},
                {"3"},
                {"4"}
                },
              RowSpacings->0.25,
              ColumnSpacings->1,
              RowAlignments->Baseline,
              ColumnAlignments->{Left}], "9.44904733190216283`*^-17", 
            "1.04562684162239394`*^-17", "1.72735923801524471`*^-16"},
          {"Total", "2.17528693827103891`*^-16", "5.11771364799001027`*^-17", 
            "1.72735923801524471`*^-16"}
          },
        RowSpacings->1,
        ColumnSpacings->3,
        RowAlignments->Baseline,
        ColumnAlignments->{Left}],
      TableForm[ {{{4, 1, 2, 3}, 3.6572562949916684*^-19, 
        1.0740596416326437*^-19, 1.7273592380152449*^-16}, {{1, 4, 2, 3}, 
        4.7135994048691237*^-17, 3.8461312669878014*^-17, 
        1.7273592380152449*^-16}, {{1, 2, 4, 3}, 7.5536500829891821*^-17, 
        3.2101115880276526*^-17, 1.7273592380152449*^-16}, {{1, 2, 3, 4}, 
        9.4490473319021643*^-17, 1.0456268416223941*^-17, 
        1.7273592380152449*^-16}, {Total, 2.1752869382710388*^-16, 
        5.1177136479900098*^-17, 1.7273592380152449*^-16}}]]], "Output",
  CellLabel->"Out[216]//TableForm="]
}, Closed]],

Cell["The distribution is just as wide:", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(BarChart[bc[Last[orders], 1. , 10. , 1, {\(-46\), \(-32\), 0.5}\ ], 
      bc[Last[orders], 1. , 10. , 3, {\(-46\), \(-32\), 0.5}], 
      PlotRange -> {{0, 28}, {0, 100}}]; \)\)], "Input",
  CellLabel->"In[221]:="],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 0.0357143 0 0.00618034 [
[.04286 -0.0125 -3 -9 ]
[.04286 -0.0125 3 0 ]
[.07857 -0.0125 -3 -9 ]
[.07857 -0.0125 3 0 ]
[.11429 -0.0125 -3 -9 ]
[.11429 -0.0125 3 0 ]
[.15 -0.0125 -3 -9 ]
[.15 -0.0125 3 0 ]
[.18571 -0.0125 -3 -9 ]
[.18571 -0.0125 3 0 ]
[.22143 -0.0125 -3 -9 ]
[.22143 -0.0125 3 0 ]
[.25714 -0.0125 -3 -9 ]
[.25714 -0.0125 3 0 ]
[.29286 -0.0125 -3 -9 ]
[.29286 -0.0125 3 0 ]
[.32857 -0.0125 -3 -9 ]
[.32857 -0.0125 3 0 ]
[.36429 -0.0125 -6 -9 ]
[.36429 -0.0125 6 0 ]
[.4 -0.0125 -6 -9 ]
[.4 -0.0125 6 0 ]
[.43571 -0.0125 -6 -9 ]
[.43571 -0.0125 6 0 ]
[.47143 -0.0125 -6 -9 ]
[.47143 -0.0125 6 0 ]
[.50714 -0.0125 -6 -9 ]
[.50714 -0.0125 6 0 ]
[.54286 -0.0125 -6 -9 ]
[.54286 -0.0125 6 0 ]
[.57857 -0.0125 -6 -9 ]
[.57857 -0.0125 6 0 ]
[.61429 -0.0125 -6 -9 ]
[.61429 -0.0125 6 0 ]
[.65 -0.0125 -6 -9 ]
[.65 -0.0125 6 0 ]
[.68571 -0.0125 -6 -9 ]
[.68571 -0.0125 6 0 ]
[.72143 -0.0125 -6 -9 ]
[.72143 -0.0125 6 0 ]
[.75714 -0.0125 -6 -9 ]
[.75714 -0.0125 6 0 ]
[.79286 -0.0125 -6 -9 ]
[.79286 -0.0125 6 0 ]
[.82857 -0.0125 -6 -9 ]
[.82857 -0.0125 6 0 ]
[.86429 -0.0125 -6 -9 ]
[.86429 -0.0125 6 0 ]
[.9 -0.0125 -6 -9 ]
[.9 -0.0125 6 0 ]
[.93571 -0.0125 -6 -9 ]
[.93571 -0.0125 6 0 ]
[.97143 -0.0125 -6 -9 ]
[.97143 -0.0125 6 0 ]
[.00893 .12361 -12 -4.5 ]
[.00893 .12361 0 4.5 ]
[.00893 .24721 -12 -4.5 ]
[.00893 .24721 0 4.5 ]
[.00893 .37082 -12 -4.5 ]
[.00893 .37082 0 4.5 ]
[.00893 .49443 -12 -4.5 ]
[.00893 .49443 0 4.5 ]
[.00893 .61803 -18 -4.5 ]
[.00893 .61803 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.04286 0 m
.04286 .00625 L
s
[(1)] .04286 -0.0125 0 1 Mshowa
.07857 0 m
.07857 .00625 L
s
[(2)] .07857 -0.0125 0 1 Mshowa
.11429 0 m
.11429 .00625 L
s
[(3)] .11429 -0.0125 0 1 Mshowa
.15 0 m
.15 .00625 L
s
[(4)] .15 -0.0125 0 1 Mshowa
.18571 0 m
.18571 .00625 L
s
[(5)] .18571 -0.0125 0 1 Mshowa
.22143 0 m
.22143 .00625 L
s
[(6)] .22143 -0.0125 0 1 Mshowa
.25714 0 m
.25714 .00625 L
s
[(7)] .25714 -0.0125 0 1 Mshowa
.29286 0 m
.29286 .00625 L
s
[(8)] .29286 -0.0125 0 1 Mshowa
.32857 0 m
.32857 .00625 L
s
[(9)] .32857 -0.0125 0 1 Mshowa
.36429 0 m
.36429 .00625 L
s
[(10)] .36429 -0.0125 0 1 Mshowa
.4 0 m
.4 .00625 L
s
[(11)] .4 -0.0125 0 1 Mshowa
.43571 0 m
.43571 .00625 L
s
[(12)] .43571 -0.0125 0 1 Mshowa
.47143 0 m
.47143 .00625 L
s
[(13)] .47143 -0.0125 0 1 Mshowa
.50714 0 m
.50714 .00625 L
s
[(14)] .50714 -0.0125 0 1 Mshowa
.54286 0 m
.54286 .00625 L
s
[(15)] .54286 -0.0125 0 1 Mshowa
.57857 0 m
.57857 .00625 L
s
[(16)] .57857 -0.0125 0 1 Mshowa
.61429 0 m
.61429 .00625 L
s
[(17)] .61429 -0.0125 0 1 Mshowa
.65 0 m
.65 .00625 L
s
[(18)] .65 -0.0125 0 1 Mshowa
.68571 0 m
.68571 .00625 L
s
[(19)] .68571 -0.0125 0 1 Mshowa
.72143 0 m
.72143 .00625 L
s
[(20)] .72143 -0.0125 0 1 Mshowa
.75714 0 m
.75714 .00625 L
s
[(21)] .75714 -0.0125 0 1 Mshowa
.79286 0 m
.79286 .00625 L
s
[(22)] .79286 -0.0125 0 1 Mshowa
.82857 0 m
.82857 .00625 L
s
[(23)] .82857 -0.0125 0 1 Mshowa
.86429 0 m
.86429 .00625 L
s
[(24)] .86429 -0.0125 0 1 Mshowa
.9 0 m
.9 .00625 L
s
[(25)] .9 -0.0125 0 1 Mshowa
.93571 0 m
.93571 .00625 L
s
[(26)] .93571 -0.0125 0 1 Mshowa
.97143 0 m
.97143 .00625 L
s
[(27)] .97143 -0.0125 0 1 Mshowa
0 0 m
1 0 L
s
.02143 .12361 m
.02768 .12361 L
s
[(20)] .00893 .12361 1 0 Mshowa
.02143 .24721 m
.02768 .24721 L
s
[(40)] .00893 .24721 1 0 Mshowa
.02143 .37082 m
.02768 .37082 L
s
[(60)] .00893 .37082 1 0 Mshowa
.02143 .49443 m
.02768 .49443 L
s
[(80)] .00893 .49443 1 0 Mshowa
.02143 .61803 m
.02768 .61803 L
s
[(100)] .00893 .61803 1 0 Mshowa
.125 Mabswid
.02143 .0309 m
.02518 .0309 L
s
.02143 .0618 m
.02518 .0618 L
s
.02143 .09271 m
.02518 .09271 L
s
.02143 .15451 m
.02518 .15451 L
s
.02143 .18541 m
.02518 .18541 L
s
.02143 .21631 m
.02518 .21631 L
s
.02143 .27812 m
.02518 .27812 L
s
.02143 .30902 m
.02518 .30902 L
s
.02143 .33992 m
.02518 .33992 L
s
.02143 .40172 m
.02518 .40172 L
s
.02143 .43262 m
.02518 .43262 L
s
.02143 .46353 m
.02518 .46353 L
s
.02143 .52533 m
.02518 .52533 L
s
.02143 .55623 m
.02518 .55623 L
s
.02143 .58713 m
.02518 .58713 L
s
.25 Mabswid
.02143 0 m
.02143 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
1 0 0 r
.02857 0 m
.02857 0 L
.04286 0 L
.04286 0 L
F
0 g
.5 Mabswid
.02857 0 m
.02857 0 L
.04286 0 L
.04286 0 L
.02857 0 L
s
1 0 0 r
.06429 0 m
.06429 0 L
.07857 0 L
.07857 0 L
F
0 g
.06429 0 m
.06429 0 L
.07857 0 L
.07857 0 L
.06429 0 L
s
1 0 0 r
.1 0 m
.1 0 L
.11429 0 L
.11429 0 L
F
0 g
.1 0 m
.1 0 L
.11429 0 L
.11429 0 L
.1 0 L
s
1 0 0 r
.13571 0 m
.13571 0 L
.15 0 L
.15 0 L
F
0 g
.13571 0 m
.13571 0 L
.15 0 L
.15 0 L
.13571 0 L
s
1 0 0 r
.17143 0 m
.17143 .01854 L
.18571 .01854 L
.18571 0 L
F
0 g
.17143 0 m
.17143 .01854 L
.18571 .01854 L
.18571 0 L
.17143 0 L
s
1 0 0 r
.20714 0 m
.20714 .10507 L
.22143 .10507 L
.22143 0 L
F
0 g
.20714 0 m
.20714 .10507 L
.22143 .10507 L
.22143 0 L
.20714 0 L
s
1 0 0 r
.24286 0 m
.24286 .07416 L
.25714 .07416 L
.25714 0 L
F
0 g
.24286 0 m
.24286 .07416 L
.25714 .07416 L
.25714 0 L
.24286 0 L
s
1 0 0 r
.27857 0 m
.27857 .11743 L
.29286 .11743 L
.29286 0 L
F
0 g
.27857 0 m
.27857 .11743 L
.29286 .11743 L
.29286 0 L
.27857 0 L
s
1 0 0 r
.31429 0 m
.31429 .35846 L
.32857 .35846 L
.32857 0 L
F
0 g
.31429 0 m
.31429 .35846 L
.32857 .35846 L
.32857 0 L
.31429 0 L
s
1 0 0 r
.35 0 m
.35 .2843 L
.36429 .2843 L
.36429 0 L
F
0 g
.35 0 m
.35 .2843 L
.36429 .2843 L
.36429 0 L
.35 0 L
s
1 0 0 r
.38571 0 m
.38571 .49443 L
.4 .49443 L
.4 0 L
F
0 g
.38571 0 m
.38571 .49443 L
.4 .49443 L
.4 0 L
.38571 0 L
s
1 0 0 r
.42143 0 m
.42143 .56241 L
.43571 .56241 L
.43571 0 L
F
0 g
.42143 0 m
.42143 .56241 L
.43571 .56241 L
.43571 0 L
.42143 0 L
s
1 0 0 r
.45714 0 m
.45714 .55623 L
.47143 .55623 L
.47143 0 L
F
0 g
.45714 0 m
.45714 .55623 L
.47143 .55623 L
.47143 0 L
.45714 0 L
s
1 0 0 r
.49286 0 m
.49286 .48825 L
.50714 .48825 L
.50714 0 L
F
0 g
.49286 0 m
.49286 .48825 L
.50714 .48825 L
.50714 0 L
.49286 0 L
s
1 0 0 r
.52857 0 m
.52857 .56241 L
.54286 .56241 L
.54286 0 L
F
0 g
.52857 0 m
.52857 .56241 L
.54286 .56241 L
.54286 0 L
.52857 0 L
s
1 0 0 r
.56429 0 m
.56429 .57477 L
.57857 .57477 L
.57857 0 L
F
0 g
.56429 0 m
.56429 .57477 L
.57857 .57477 L
.57857 0 L
.56429 0 L
s
1 0 0 r
.6 0 m
.6 .37082 L
.61429 .37082 L
.61429 0 L
F
0 g
.6 0 m
.6 .37082 L
.61429 .37082 L
.61429 0 L
.6 0 L
s
1 0 0 r
.63571 0 m
.63571 .53769 L
.65 .53769 L
.65 0 L
F
0 g
.63571 0 m
.63571 .53769 L
.65 .53769 L
.65 0 L
.63571 0 L
s
1 0 0 r
.67143 0 m
.67143 .35846 L
.68571 .35846 L
.68571 0 L
F
0 g
.67143 0 m
.67143 .35846 L
.68571 .35846 L
.68571 0 L
.67143 0 L
s
1 0 0 r
.70714 0 m
.70714 .25339 L
.72143 .25339 L
.72143 0 L
F
0 g
.70714 0 m
.70714 .25339 L
.72143 .25339 L
.72143 0 L
.70714 0 L
s
1 0 0 r
.74286 0 m
.74286 .17305 L
.75714 .17305 L
.75714 0 L
F
0 g
.74286 0 m
.74286 .17305 L
.75714 .17305 L
.75714 0 L
.74286 0 L
s
1 0 0 r
.77857 0 m
.77857 .17923 L
.79286 .17923 L
.79286 0 L
F
0 g
.77857 0 m
.77857 .17923 L
.79286 .17923 L
.79286 0 L
.77857 0 L
s
1 0 0 r
.81429 0 m
.81429 .04326 L
.82857 .04326 L
.82857 0 L
F
0 g
.81429 0 m
.81429 .04326 L
.82857 .04326 L
.82857 0 L
.81429 0 L
s
1 0 0 r
.85 0 m
.85 .00618 L
.86429 .00618 L
.86429 0 L
F
0 g
.85 0 m
.85 .00618 L
.86429 .00618 L
.86429 0 L
.85 0 L
s
1 0 0 r
.88571 0 m
.88571 .04326 L
.9 .04326 L
.9 0 L
F
0 g
.88571 0 m
.88571 .04326 L
.9 .04326 L
.9 0 L
.88571 0 L
s
1 0 0 r
.92143 0 m
.92143 .01854 L
.93571 .01854 L
.93571 0 L
F
0 g
.92143 0 m
.92143 .01854 L
.93571 .01854 L
.93571 0 L
.92143 0 L
s
1 0 0 r
.95714 0 m
.95714 0 L
.97143 0 L
.97143 0 L
F
0 g
.95714 0 m
.95714 0 L
.97143 0 L
.97143 0 L
.95714 0 L
s
1 0 0 r
.99286 0 m
.99286 0 L
1.00714 0 L
1.00714 0 L
F
0 g
.99286 0 m
.99286 0 L
s
.99286 0 m
0 0 rlineto s
0 .4 1 r
.04286 0 m
.04286 0 L
.05714 0 L
.05714 0 L
F
0 g
.04286 0 m
.04286 0 L
.05714 0 L
.05714 0 L
.04286 0 L
s
0 .4 1 r
.07857 0 m
.07857 0 L
.09286 0 L
.09286 0 L
F
0 g
.07857 0 m
.07857 0 L
.09286 0 L
.09286 0 L
.07857 0 L
s
0 .4 1 r
.11429 0 m
.11429 0 L
.12857 0 L
.12857 0 L
F
0 g
.11429 0 m
.11429 0 L
.12857 0 L
.12857 0 L
.11429 0 L
s
0 .4 1 r
.15 0 m
.15 .00618 L
.16429 .00618 L
.16429 0 L
F
0 g
.15 0 m
.15 .00618 L
.16429 .00618 L
.16429 0 L
.15 0 L
s
0 .4 1 r
.18571 0 m
.18571 .05562 L
.2 .05562 L
.2 0 L
F
0 g
.18571 0 m
.18571 .05562 L
.2 .05562 L
.2 0 L
.18571 0 L
s
0 .4 1 r
.22143 0 m
.22143 .04326 L
.23571 .04326 L
.23571 0 L
F
0 g
.22143 0 m
.22143 .04326 L
.23571 .04326 L
.23571 0 L
.22143 0 L
s
0 .4 1 r
.25714 0 m
.25714 .11743 L
.27143 .11743 L
.27143 0 L
F
0 g
.25714 0 m
.25714 .11743 L
.27143 .11743 L
.27143 0 L
.25714 0 L
s
0 .4 1 r
.29286 0 m
.29286 .12979 L
.30714 .12979 L
.30714 0 L
F
0 g
.29286 0 m
.29286 .12979 L
.30714 .12979 L
.30714 0 L
.29286 0 L
s
0 .4 1 r
.32857 0 m
.32857 .3461 L
.34286 .3461 L
.34286 0 L
F
0 g
.32857 0 m
.32857 .3461 L
.34286 .3461 L
.34286 0 L
.32857 0 L
s
0 .4 1 r
.36429 0 m
.36429 .25957 L
.37857 .25957 L
.37857 0 L
F
0 g
.36429 0 m
.36429 .25957 L
.37857 .25957 L
.37857 0 L
.36429 0 L
s
0 .4 1 r
.4 0 m
.4 .53769 L
.41429 .53769 L
.41429 0 L
F
0 g
.4 0 m
.4 .53769 L
.41429 .53769 L
.41429 0 L
.4 0 L
s
0 .4 1 r
.43571 0 m
.43571 .57477 L
.45 .57477 L
.45 0 L
F
0 g
.43571 0 m
.43571 .57477 L
.45 .57477 L
.45 0 L
.43571 0 L
s
0 .4 1 r
.47143 0 m
.47143 .50061 L
.48571 .50061 L
.48571 0 L
F
0 g
.47143 0 m
.47143 .50061 L
.48571 .50061 L
.48571 0 L
.47143 0 L
s
0 .4 1 r
.50714 0 m
.50714 .61185 L
.52143 .61185 L
.52143 0 L
F
0 g
.50714 0 m
.50714 .61185 L
.52143 .61185 L
.52143 0 L
.50714 0 L
s
0 .4 1 r
.54286 0 m
.54286 .59949 L
.55714 .59949 L
.55714 0 L
F
0 g
.54286 0 m
.54286 .59949 L
.55714 .59949 L
.55714 0 L
.54286 0 L
s
0 .4 1 r
.57857 0 m
.57857 .60567 L
.59286 .60567 L
.59286 0 L
F
0 g
.57857 0 m
.57857 .60567 L
.59286 .60567 L
.59286 0 L
.57857 0 L
s
0 .4 1 r
.61429 0 m
.61429 .36464 L
.62857 .36464 L
.62857 0 L
F
0 g
.61429 0 m
.61429 .36464 L
.62857 .36464 L
.62857 0 L
.61429 0 L
s
0 .4 1 r
.65 0 m
.65 .4388 L
.66429 .4388 L
.66429 0 L
F
0 g
.65 0 m
.65 .4388 L
.66429 .4388 L
.66429 0 L
.65 0 L
s
0 .4 1 r
.68571 0 m
.68571 .35846 L
.7 .35846 L
.7 0 L
F
0 g
.68571 0 m
.68571 .35846 L
.7 .35846 L
.7 0 L
.68571 0 L
s
0 .4 1 r
.72143 0 m
.72143 .19777 L
.73571 .19777 L
.73571 0 L
F
0 g
.72143 0 m
.72143 .19777 L
.73571 .19777 L
.73571 0 L
.72143 0 L
s
0 .4 1 r
.75714 0 m
.75714 .16069 L
.77143 .16069 L
.77143 0 L
F
0 g
.75714 0 m
.75714 .16069 L
.77143 .16069 L
.77143 0 L
.75714 0 L
s
0 .4 1 r
.79286 0 m
.79286 .12979 L
.80714 .12979 L
.80714 0 L
F
0 g
.79286 0 m
.79286 .12979 L
.80714 .12979 L
.80714 0 L
.79286 0 L
s
0 .4 1 r
.82857 0 m
.82857 .05562 L
.84286 .05562 L
.84286 0 L
F
0 g
.82857 0 m
.82857 .05562 L
.84286 .05562 L
.84286 0 L
.82857 0 L
s
0 .4 1 r
.86429 0 m
.86429 .01236 L
.87857 .01236 L
.87857 0 L
F
0 g
.86429 0 m
.86429 .01236 L
.87857 .01236 L
.87857 0 L
.86429 0 L
s
0 .4 1 r
.9 0 m
.9 .04944 L
.91429 .04944 L
.91429 0 L
F
0 g
.9 0 m
.9 .04944 L
.91429 .04944 L
.91429 0 L
.9 0 L
s
0 .4 1 r
.93571 0 m
.93571 .00618 L
.95 .00618 L
.95 0 L
F
0 g
.93571 0 m
.93571 .00618 L
.95 .00618 L
.95 0 L
.93571 0 L
s
0 .4 1 r
.97143 0 m
.97143 0 L
.98571 0 L
.98571 0 L
F
0 g
.97143 0 m
.97143 0 L
.98571 0 L
.98571 0 L
.97143 0 L
s
0 .4 1 r
1.00714 0 m
1.00714 .00618 L
1.02143 .00618 L
1.02143 0 L
F
0 g
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[221]:=",
  ImageSize->{454, 280.438},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`400076000161000`40O003h00Oogooagoo003oOoo7
Ool002Ioo`<000aoo`@000]oo`<000ioo`<000]oo`<000eoo`8000eoo`03001oogoo00aoo`8000ao
o`<000Uoo`<000Aoo`8000Ioo`<000=oo`<000Ioo`<000=oo`@000Eoo`<000=oo`<000Ioo`<000Ao
o`<000Eoo`<000=oo`<000Ioo`<000Aoo`8000Ioo`<000Aoo`03001oogoo00Eoo`<000Aoo`8000Io
o`<000=oo`<000Moo`@000=oo`8000Ioo`@0009oo`<000Ioo`@0009oo`@000Eoo`@0009oo`<000Io
o`@000=oo`<000Eoo`@0009oo`<000Ioo`@000=oo`8000Ioo`@000=oo`03001oogoo015oo`009goo
00<007ooOol037oo00<007ooOol03Woo00<007ooOol037oo00<007ooOol03Goo00<007ooOol02Goo
00@007ooOol000aoo`03001oogoo00]oo`04001oogoo000>Ool00`00Oomoo`07Ool00`00Oomoo`02
Ool01000Oomoo`001Woo00<007ooOol00goo00<007ooOol01Woo00<007ooOol00goo00<007ooOol0
1Woo00<007ooOol01Goo00<007ooOol017oo00<007ooOol017oo00<007ooOol01Goo00<007ooOol0
1Goo00<007ooOol017oo00<007ooOol00Woo00@007ooOol000Ioo`03001oogoo00=oo`03001oogoo
00Ioo`03001oogoo009oo`04001oogoo0006Ool00`00Oomoo`05Ool00`00Oomoo`05Ool00`00Oomo
o`02Ool01000Oomoo`001Woo00<007ooOol00goo00<007ooOol01Woo00<007ooOol00goo00<007oo
Ool01Woo00<007ooOol01Goo00<007ooOol017oo00<007ooOol017oo00<007ooOol01Goo00<007oo
Ool01Goo00<007ooOol017oo00<007ooOol00Woo00@007ooOol000Ioo`03001oogoo00=oo`03001o
ogoo015oo`009goo00<007ooOol03Goo00<007ooOol03Goo00<007ooOol02Woo10003Woo00<007oo
Ool02Goo00@007ooOol000eoo`03001oogoo00Yoo`04001oogoo000<Ool30009Ool00`00Oomoo`02
Ool01000Oomoo`001Woo00<007ooOol00goo00<007ooOol01Woo00<007ooOol017oo00<007ooOol0
1Goo00<007ooOol01Goo00<007ooOol017oo00<007ooOol00Woo10001Woo00<007ooOol01Goo00<0
07ooOol017oo00<007ooOol00Woo00@007ooOol000Ioo`03001oogoo00Aoo`03001oogoo00Eoo`03
001oogoo009oo`04001oogoo0006Ool00`00Oomoo`03Ool30008Ool01@00Oomoogoo00000Woo00<0
07ooOol01Goo00<007ooOol00Woo00<007ooOol01goo00<007ooOol00goo00<007ooOol01Woo00<0
07ooOol017oo00<007ooOol01Goo00@007ooOomoo`@000Moo`03001oogoo00Aoo`03001oogoo00Eo
o`05001oogooOol00002Ool00`00Oomoo`05Ool00`00Oomoo`03Ool00`00Oomoo`0@Ool002Moo`03
001oogoo00ioo`03001oogoo00Yoo`8000eoo`03001oo`0000aoo`<000aoo`<000ioo`03001oogoo
00]oo`8000aoo`04001oogoo0009Ool00`00Oomoo`02Ool01000Oomoo`001Woo00<007ooOol00goo
00<007ooOol01Woo00<007ooOol01Goo00<007ooOol017oo00<007ooOol00goo0P001goo00<007oo
Ool00Woo00<007oo00001goo00<007ooOol00Woo0`001goo00<007ooOol00Woo0`001goo00<007oo
Ool017oo00<007ooOol01Goo00<007ooOol00goo0P001goo00<007ooOol00Woo00@007ooOol000Uo
o`04001oogoo0002Ool00`00Oomoo`06Ool01@00Oomoogoo00002Woo00<007ooOol00goo00<007oo
Ool01Woo00@007ooOomoo`8000Uoo`06001oogoo001oo`002Goo00<007ooOol00`002Goo00<007oo
Ool00`002Goo00<007ooOol00Woo00<007ooOol047oo000WOol00`00Oomoo`0;Ool01000Oomoo`00
3Woo00<007ooOol02Woo00<007oo000037oo00<007ooOol037oo00<007ooOol03goo00<007ooOol0
2Goo00@007ooOol000]oo`04001oogoo0009Ool00`00Oomoo`02Ool01000Oomoo`001Woo00<007oo
Ool00goo00<007ooOol01Woo00<007ooOol00Woo00@007ooOol000Ioo`03001oogoo00Eoo`03001o
ogoo00Aoo`03001oogoo009oo`03001oo`0000Moo`03001oogoo009oo`03001oogoo00Moo`03001o
ogoo009oo`03001oogoo00Moo`03001oogoo00Eoo`03001oogoo00Aoo`03001oogoo009oo`04001o
ogoo0006Ool00`00Oomoo`02Ool01000Oomoo`001Woo00@007ooOol0009oo`04001oogoo0005Ool0
1000Oomoo`000goo00<007ooOol01Goo00@007ooOol0009oo`04001oogoo0005Ool01000Oomoo`00
1Goo00<007ooOol00goo00@007ooOol0009oo`03001oo`0000Ioo`04001oogoo0002Ool00`00Oomo
o`06Ool01000Oomoo`000Woo00<007ooOol01Woo00@007ooOol000Eoo`03001oogoo00moo`009Woo
0P003Woo0P0037oo0`003Woo0P0037oo100037oo0`002goo100037oo0P003Goo0P002Goo0P001Goo
0P001Woo0P0017oo0P001goo0P001Goo0P001Woo0P0017oo0`001Woo0P001Goo0P001Woo0P0017oo
10001Goo0P001Goo0`001Goo0P0017oo10001Goo0P001Goo0P001Woo0P001Goo0P0027oo0P0017oo
0P001goo0P000goo0P0027oo0P0017oo0P001goo0P000goo0`001goo0P0017oo0P001goo0P000goo
10001Woo0P0017oo0`001Woo0P000goo10004Goo003oOoo7Ool00?moolMoo`00ogooagoo003oOoo7
Ool00?moolMoo`00ogooagoo000FOooo002X0009Ool001moo`03001oogoo00Ioo`03001oogoo00ao
o`03001oogoo00aoo`03001oogoo00eoo`030001W`6O00<1W`04001oogoo0005O0000`000Il1W`03
0Il01000Oomoo`001G`000<0006O0Il00`6O00@007ooOol000El00030001W`6O00<1W`04001oogoo
0005O0000`000Il1W`030Il01000Oomoo`001G`000<0006O0Il00`6O00@007ooOol000El00030001
W`6O00<1W`04001oogoo0005O0000`000Il1W`030Il01000Oomoo`001G`000<0006O0Il00`6O00@0
07ooOol000El00030001W`6O00<1W`04001oogoo0005O0000`000Il1W`030Il01000Oomoo`001G`0
00<0006O0Il00`6O00@007ooOol000El00030001W`6O00<1W`04001oogoo0005O0000`000Il1W`03
0Il01000Oomoo`001G`000<0006O0Il00`6O00@007ooOol000El00030001W`6O00<1W`04001oogoo
0006O0000`000Il1W`030Il01000Oomoo`001G`000<0006O0Il00`6O00@007ooOol000El00030001
W`6O00<1W`04001oogoo0005O0000`000Il1W`030Il01000Oomoo`001G`000<0006O0Il00`6O00@0
07ooOol000El00030001W`6O00<1W`04001oogoo0005O0000`000Il1W`030Il00`00Oomoo`06Ool0
0`00Oomoo`0<Ool60Il1Ool001moo`03001oogoo00Ioo`03001oogoo00aoo`03001oogoo00aoo`03
001oogoo00eoo`030001W`6O00<1W`04001oogoo0005O0000`000Il1W`030Il01000Oomoo`001G`0
00<0006O0Il00`6O00@007ooOol000El00030001W`6O00<1W`04001oogoo0005O0000`000Il1W`03
0Il01000Oomoo`001G`000<0006O0Il00`6O00@007ooOol000El00030001W`6O00<1W`04001oogoo
0005O0000`000Il1W`030Il01000Oomoo`001G`000<0006O0Il00`6O00@007ooOol000El00030001
W`6O00<1W`04001oogoo0005O0000`000Il1W`030Il01000Oomoo`001G`000<0006O0Il00`6O00@0
07ooOol000El00030001W`6O00<1W`04001oogoo0005O0000`000Il1W`030Il01000Oomoo`001G`0
00<0006O0Il00`6O00@007ooOol000El00030001W`6O00<1W`04001oogoo0006O0000`000Il1W`03
0Il01000Oomoo`001G`000<0006O0Il00`6O00@007ooOol000El00030001W`6O00<1W`04001oogoo
0005O0000`000Il1W`030Il01000Oomoo`001G`000<0006O0Il00`6O00@007ooOol000El00030001
W`6O00<1W`04001oogoo0005O0000`000Il1W`030Il00`00Oomoo`06Ool00`00Oomoo`0<Ool60Il1
Ool001moo`03001oogoo00Ioo`03001oogoo00aoo`03001oogoo00aoo`03001oogoo00eoo`L0009o
o`03001l07`000=l00030001W`6O00<1W`04001oogoo0005O0000`000Il1W`030Il01000Oomoo`00
1G`000<0006O0Il00`6O00@007ooOol000El00030001W`6O00<1W`04001oogoo0005O0000`000Il1
W`030Il01000Oomoo`001G`000<0006O0Il00`6O00@007ooOol000El00030001W`6O00<1W`04001o
ogoo0005O0000`000Il1W`030Il01000Oomoo`001G`000<0006O0Il00`6O00@007ooOol000El0003
0001W`6O00<1W`04001oogoo0005O0000`000Il1W`030Il01000Oomoo`001G`000<0006O0Il00`6O
00@007ooOol000El00030001W`6O00<1W`04001oogoo0005O0000`000Il1W`030Il01000Oomoo`00
1G`000<0006O0Il00`6O00@007ooOol000Il00030001W`6O00<1W`04001oogoo0005O0000`000Il1
W`030Il01000Oomoo`001G`000<0006O0Il00`6O00@007ooOol000El00030001W`6O00<1W`03001o
ogoo00L000D1W`04001oogoo0005O0000`000Il1W`030Il01000Oomoo`001G`01`0027oo00<007oo
Ool037oo1P6O0Goo000OOol00`00Oomoo`0mOol00`00O01l0003O0000`000Il1W`030Il01000Oomo
o`001G`000<0006O0Il00`6O00@007ooOol000El00030001W`6O00<1W`04001oogoo0005O0000`00
0Il1W`030Il01000Oomoo`001G`000<0006O0Il00`6O00@007ooOol000El00030001W`6O00<1W`04
001oogoo0005O0000`000Il1W`030Il01000Oomoo`001G`000<0006O0Il00`6O00@007ooOol000El
00030001W`6O00<1W`04001oogoo0005O0000`000Il1W`030Il01000Oomoo`001G`000<0006O0Il0
0`6O00@007ooOol000El00030001W`6O00<1W`04001oogoo0005O0000`000Il1W`030Il01000Oomo
o`001G`000<0006O0Il00`6O00@007ooOol000El00030001W`6O00<1W`04001oogoo0006O0000`00
0Il1W`030Il01000Oomoo`001G`000<0006O0Il00`6O00@007ooOol000El00030001W`6O00<1W`04
001oogoo0005O0000`000Il1W`030Il00`00Oomoo`06Ool00`000Il1W`030Il01000Oomoo`001G`0
00<0006O0Il00`6O00@007ooOol000El0003001oogoo029oo`007goo00<007ooOol0?Goo00<007`0
O0000g`000<0006O0Il00`6O00@007ooOol000El00030001W`6O00<1W`04001oogoo0005O0000`00
0Il1W`030Il01000Oomoo`001G`000<0006O0Il00`6O00@007ooOol000El00030001W`6O00<1W`04
001oogoo0005O0000`000Il1W`030Il01000Oomoo`001G`000<0006O0Il00`6O00@007ooOol000El
00030001W`6O00<1W`04001oogoo0005O0000`000Il1W`030Il01000Oomoo`001G`000<0006O0Il0
0`6O00@007ooOol000El00030001W`6O00<1W`04001oogoo0005O0000`000Il1W`030Il01000Oomo
o`001G`000<0006O0Il00`6O00@007ooOol000El00030001W`6O00<1W`04001oogoo0005O0000`00
0Il1W`030Il01000Oomoo`001W`000<0006O0Il00`6O00@007ooOol000El00030001W`6O00<1W`04
001oogoo0005O0000`000Il1W`030Il01000Oomoo`001G`000<0006O0Il00`6O00<007ooOol01Woo
00<0006O0Il00`6O00@007ooOol000El00030001W`6O00<1W`04001oogoo0005O0000`00Oomoo`0R
Ool001moo`03001oogoo03eoo`03001l07`000=l00030001W`6O00<1W`04001oogoo0005O0000`00
0Il1W`030Il01000Oomoo`001G`000<0006O0Il00`6O00@007ooOol000El00030001W`6O00<1W`04
001oogoo0005O0000`000Il1W`030Il01000Oomoo`001G`000<0006O0Il00`6O00@007ooOol000El
00030001W`6O00<1W`04001oogoo0005O0000`000Il1W`030Il01000Oomoo`001G`000<0006O0Il0
0`6O00@007ooOol000El00030001W`6O00<1W`04001oogoo0005O0000`000Il1W`030Il01000Oomo
o`001G`000<0006O0Il00`6O00@007ooOol000El00030001W`6O00<1W`04001oogoo0005O0000`00
0Il1W`030Il01000Oomoo`001G`000<0006O0Il00`6O00@007ooOol000Il00030001W`6O00<1W`04
001oogoo0005O0000`000Il1W`030Il01000Oomoo`001G`000<0006O0Il00`6O00@007ooOol000El
00030001W`6O00<1W`03001oogoo00Ioo`L0009oo`03001l07`000=l00030001W`6O00<1W`04001o
ogoo0005O0000`00Oomoo`0ROol001moo`03001oogoo03eoo`03001l07`000=l00030001W`6O00<1
W`04001oogoo0005O0000`000Il1W`030Il01000Oomoo`001G`000<0006O0Il00`6O00@007ooOol0
00El00030001W`6O00<1W`04001oogoo0005O0000`000Il1W`030Il01000Oomoo`001G`000<0006O
0Il00`6O00@007ooOol000El00030001W`6O00<1W`04001oogoo0005O0000`000Il1W`030Il01000
Oomoo`001G`000<0006O0Il00`6O00@007ooOol000El00030001W`6O00<1W`04001oogoo0005O000
0`000Il1W`030Il01000Oomoo`001G`000<0006O0Il00`6O00@007ooOol000El00030001W`6O00<1
W`04001oogoo0005O0000`000Il1W`030Il01000Oomoo`001G`000<0006O0Il00`6O00@007ooOol0
00Il00030001W`6O00<1W`04001oogoo0005O0000`000Il1W`030Il01000Oomoo`001G`000<0006O
0Il00`6O00@007ooOol000El00030001W`6O00<1W`03001oogoo00moo`03001l07`000=l00030001
W`6O00<1W`04001oogoo0005O0000`00Oomoo`0ROol001moo`03001oogoo03eoo`L000D1W`04001o
ogoo0005O0000`000Il1W`030Il01000Oomoo`001G`000<0006O0Il00`6O00@007ooOol000El0003
0001W`6O00<1W`04001oogoo0005O0000`000Il1W`030Il01000Oomoo`001G`000<0006O0Il00`6O
00@007ooOol000El00030001W`6O00<1W`04001oogoo0005O0000`000Il1W`030Il01000Oomoo`00
1G`000<0006O0Il00`6O00@007ooOol000El00030001W`6O00<1W`04001oogoo0005O0000`000Il1
W`030Il01000Oomoo`001G`000<0006O0Il00`6O00@007ooOol000El00030001W`6O00<1W`04001o
ogoo0005O0000`000Il1W`030Il01000Oomoo`001G`000<0006O0Il00`6O00@007ooOol000Il0003
0001W`6O00<1W`04001oogoo0005O0000`000Il1W`030Il01000Oomoo`001G`000<0006O0Il00`6O
00@007ooOol000El00030001W`6O00<1W`03001oogoo00moo`03001l07`000=l00030001W`6O00<1
W`03001oogoo00L002Aoo`007goo00<007ooOol0@goo00<0006O0Il00`6O00@007ooOol000El0003
0001W`6O00<1W`04001oogoo0005O0000`000Il1W`030Il01000Oomoo`001G`000<0006O0Il00`6O
00@007ooOol000El00030001W`6O00<1W`04001oogoo0005O0000`000Il1W`030Il01000Oomoo`00
1G`000<0006O0Il00`6O00@007ooOol000El00030001W`6O00<1W`04001oogoo0005O0000`000Il1
W`030Il01000Oomoo`001G`000<0006O0Il00`6O00@007ooOol000El00030001W`6O00<1W`04001o
ogoo0005O0000`000Il1W`030Il01000Oomoo`001G`000<0006O0Il00`6O00@007ooOol000El0003
0001W`6O00<1W`04001oogoo0005O0000`000Il1W`030Il01000Oomoo`001W`000<0006O0Il00`6O
00@007ooOol000El00030001W`6O00<1W`04001oogoo0005O0000`000Il1W`030Il01000Oomoo`00
1G`000<0006O0Il00`6O00<007ooOol03goo00<007`0O0000g`000<0006O0Il00`6O00<007ooOol0
:goo000OOol00`00Oomoo`13Ool00`000Il1W`030Il01000Oomoo`001G`000<0006O0Il00`6O00@0
07ooOol000El00030001W`6O00<1W`04001oogoo0005O0000`000Il1W`030Il01000Oomoo`001G`0
00<0006O0Il00`6O00@007ooOol000El00030001W`6O00<1W`04001oogoo0005O0000`000Il1W`03
0Il01000Oomoo`001G`000<0006O0Il00`6O00@007ooOol000El00030001W`6O00<1W`04001oogoo
0005O0000`000Il1W`030Il01000Oomoo`001G`000<0006O0Il00`6O00@007ooOol000El00030001
W`6O00<1W`04001oogoo0005O0000`000Il1W`030Il01000Oomoo`001G`000<0006O0Il00`6O00@0
07ooOol000El00030001W`6O00<1W`04001oogoo0006O0000`000Il1W`030Il01000Oomoo`001G`0
00<0006O0Il00`6O00@007ooOol000El00030001W`6O00<1W`04001oogoo0005O0000`000Il1W`03
0Il00`00Oomoo`0?Ool00`00O01l0003O0000`000Il1W`030Il00`00Oomoo`0[Ool001moo`03001o
ogoo04=oo`030001W`6O00<1W`04001oogoo0005O0000`000Il1W`030Il01000Oomoo`001G`000<0
006O0Il00`6O00@007ooOol000El00030001W`6O00<1W`04001oogoo0005O0000`000Il1W`030Il0
1000Oomoo`001G`000<0006O0Il00`6O00@007ooOol000El00030001W`6O00<1W`04001oogoo0005
O0000`000Il1W`030Il01000Oomoo`001G`000<0006O0Il00`6O00@007ooOol000El00030001W`6O
00<1W`04001oogoo0005O0000`000Il1W`030Il01000Oomoo`001G`000<0006O0Il00`6O00@007oo
Ool000El00030001W`6O00<1W`04001oogoo0005O0000`000Il1W`030Il01000Oomoo`001G`000<0
006O0Il00`6O00@007ooOol000Il00030001W`6O00<1W`04001oogoo0005O0000`000Il1W`030Il0
1000Oomoo`001G`000<0006O0Il00`6O00@007ooOol000El00030001W`6O00<1W`03001oogoo00mo
o`03001l07`000=l00030001W`6O00<1W`03001oogoo02]oo`007goo00<007ooOol0@goo00<0006O
0Il00`6O00@007ooOol000El00030001W`6O00<1W`04001oogoo0005O0000`000Il1W`030Il01000
Oomoo`001G`000<0006O0Il00`6O00@007ooOol000El00030001W`6O00<1W`04001oogoo0005O000
0`000Il1W`030Il01000Oomoo`001G`000<0006O0Il00`6O00@007ooOol000El00030001W`6O00<1
W`04001oogoo0005O0000`000Il1W`030Il01000Oomoo`001G`000<0006O0Il00`6O00@007ooOol0
00El00030001W`6O00<1W`04001oogoo0005O0000`000Il1W`030Il01000Oomoo`001G`000<0006O
0Il00`6O00@007ooOol000El00030001W`6O00<1W`04001oogoo0005O0000`000Il1W`030Il01000
Oomoo`001W`000<0006O0Il00`6O00@007ooOol000El00030001W`6O00<1W`04001oogoo0005O000
0`000Il1W`030Il01000Oomoo`001G`000<0006O0Il00`6O00<007ooOol03goo00<007`0O0000g`0
00<0006O0Il00`6O00<007ooOol0:goo000OOol30013Ool00`000Il1W`030Il01000Oomoo`001G`0
00<0006O0Il00`6O00@007ooOol000El00030001W`6O00<1W`04001oogoo0005O0000`000Il1W`03
0Il01000Oomoo`001G`000<0006O0Il00`6O00@007ooOol000El00030001W`6O00<1W`04001oogoo
0005O0000`000Il1W`030Il01000Oomoo`001G`000<0006O0Il00`6O00@007ooOol000El00030001
W`6O00<1W`04001oogoo0005O0000`000Il1W`030Il01000Oomoo`001G`000<0006O0Il00`6O00@0
07ooOol000El00030001W`6O00<1W`04001oogoo0005O0000`000Il1W`030Il01000Oomoo`001G`0
00<0006O0Il00`6O00@007ooOol000El00030001W`6O00<1W`04001oogoo0006O0000`000Il1W`03
0Il01000Oomoo`001G`000<0006O0Il00`6O00@007ooOol000El00030001W`6O00<1W`04001oogoo
0005O0000`000Il1W`030Il00`00Oomoo`0?Ool00`00O01l0003O0000`000Il1W`030Il00`00Oomo
o`0[Ool001moo`03001oogoo04=oo`030001W`6O00<1W`04001oogoo0005O0000`000Il1W`030Il0
1000Oomoo`001G`000<0006O0Il00`6O00@007ooOol000El00030001W`6O00<1W`04001oogoo0005
O0000`000Il1W`030Il01000Oomoo`001G`000<0006O0Il00`6O00@007ooOol000El00030001W`6O
00<1W`04001oogoo0005O0000`000Il1W`030Il01000Oomoo`001G`000<0006O0Il00`6O00@007oo
Ool000El00030001W`6O00<1W`04001oogoo0005O0000`000Il1W`030Il01000Oomoo`001G`000<0
006O0Il00`6O00@007ooOol000El00030001W`6O00<1W`04001oogoo0005O0000`000Il1W`030Il0
1000Oomoo`001G`000<0006O0Il00`6O00@007ooOol000Il00030001W`6O00<1W`04001oogoo0005
O0000`000Il1W`030Il01000Oomoo`001G`000<0006O0Il00`6O00@007ooOol000El00030001W`6O
00<1W`03001oogoo00moo`03001l07`000=l00030001W`6O00<1W`03001oogoo02]oo`007goo00<0
07ooOol0@goo00<0006O0Il00`6O00@007ooOol000El00030001W`6O00<1W`04001oogoo0005O000
0`000Il1W`030Il01000Oomoo`001G`000<0006O0Il00`6O00@007ooOol000El00030001W`6O00<1
W`04001oogoo0005O0000`000Il1W`030Il01000Oomoo`001G`000<0006O0Il00`6O00@007ooOol0
00El00030001W`6O00<1W`04001oogoo0005O0000`000Il1W`030Il01000Oomoo`001G`000<0006O
0Il00`6O00@007ooOol000El00030001W`6O00<1W`04001oogoo0005O0000`000Il1W`030Il01000
Oomoo`001G`000<0006O0Il00`6O00@007ooOol000El00030001W`6O00<1W`04001oogoo0005O000
0`000Il1W`030Il01000Oomoo`001W`000<0006O0Il00`6O00@007ooOol000El00030001W`6O00<1
W`04001oogoo0005O0000`000Il1W`030Il01000Oomoo`001G`000<0006O0Il00`6O00<007ooOol0
3goo00<007`0O0000g`000<0006O0Il00`6O00<007ooOol0:goo000OOol00`00Oomoo`13Ool00`00
0Il1W`030Il01000Oomoo`001G`000<0006O0Il00`6O00@007ooOol000El00030001W`6O00<1W`04
001oogoo0005O0000`000Il1W`030Il01000Oomoo`001G`000<0006O0Il00`6O00@007ooOol000El
00030001W`6O00<1W`04001oogoo0005O0000`000Il1W`030Il01000Oomoo`001G`000<0006O0Il0
0`6O00@007ooOol000El00030001W`6O00<1W`04001oogoo0005O0000`000Il1W`030Il01000Oomo
o`001G`000<0006O0Il00`6O00@007ooOol000El00030001W`6O00<1W`04001oogoo0005O0000`00
0Il1W`030Il01000Oomoo`001G`000<0006O0Il00`6O00@007ooOol000El00030001W`6O00<1W`04
001oogoo0006O0000`000Il1W`030Il01000Oomoo`001G`000<0006O0Il00`6O00@007ooOol000El
00030001W`6O00<1W`04001oogoo0005O0000`000Il1W`030Il00`00Oomoo`0?Ool00`00O01l0003
O0000`000Il1W`030Il00`00Oomoo`0[Ool001moo`03001oogoo04=oo`030001W`6O00<1W`04001o
ogoo0005O0000`000Il1W`030Il01000Oomoo`001G`000<0006O0Il00`6O00@007ooOol000El0003
0001W`6O00<1W`04001oogoo0005O0000`000Il1W`030Il01000Oomoo`001G`000<0006O0Il00`6O
00@007ooOol000El00030001W`6O00<1W`04001oogoo0005O0000`000Il1W`030Il01000Oomoo`00
1G`000<0006O0Il00`6O00@007ooOol000El00030001W`6O00<1W`04001oogoo0005O0000`000Il1
W`030Il01000Oomoo`001G`000<0006O0Il00`6O00@007ooOol000El00030001W`6O00<1W`04001o
ogoo0005O0000`000Il1W`030Il01000Oomoo`001G`000<0006O0Il00`6O00@007ooOol000Il0003
0001W`6O00<1W`04001oogoo0005O0000`000Il1W`030Il01000Oomoo`001G`000<0006O0Il00`6O
00@007ooOol000El00030001W`6O00<1W`03001oogoo00moo`03001l07`000=l00030001W`6O00<1
W`03001oogoo02]oo`007goo00<007ooOol0@goo00<0006O0Il00`6O00@007ooOol000El00030001
W`6O00<1W`04001oogoo0005O0000`000Il1W`030Il01000Oomoo`001G`000<0006O0Il00`6O00@0
07ooOol000El00030001W`6O00<1W`04001oogoo0005O0000`000Il1W`030Il01000Oomoo`001G`0
00<0006O0Il00`6O00@007ooOol000El00030001W`6O00<1W`04001oogoo0005O0000`000Il1W`03
0Il01000Oomoo`001G`000<0006O0Il00`6O00@007ooOol000El00030001W`6O00<1W`04001oogoo
0005O0000`000Il1W`030Il01000Oomoo`001G`000<0006O0Il00`6O00@007ooOol000El00030001
W`6O00<1W`04001oogoo0005O0000`000Il1W`030Il01000Oomoo`001W`000<0006O0Il00`6O00@0
07ooOol000El00030001W`6O00<1W`04001oogoo0005O0000`000Il1W`030Il01000Oomoo`001G`0
00<0006O0Il00`6O00<007ooOol03goo00<007`0O0000g`000<0006O0Il00`6O00<007ooOol0:goo
000OOol00`00Oomoo`13Ool00`000Il1W`030Il01000Oomoo`001G`01`000Woo00<007`0O0000g`0
00<0006O0Il00`6O00@007ooOol000El00030001W`6O00<1W`04001oogoo0005O0000`000Il1W`03
0Il01000Oomoo`001G`000<0006O0Il00`6O00@007ooOol000El00030001W`6O00<1W`04001oogoo
0005O0000`000Il1W`030Il01000Oomoo`001G`000<0006O0Il00`6O00@007ooOol000El00030001
W`6O00<1W`04001oogoo0005O0000`000Il1W`030Il01000Oomoo`001G`000<0006O0Il00`6O00@0
07ooOol000El00030001W`6O00<1W`04001oogoo0005O0000`000Il1W`030Il01000Oomoo`001G`0
00<0006O0Il00`6O00@007ooOol000Il00030001W`6O00<1W`04001oogoo0005O0000`000Il1W`03
0Il01000Oomoo`001G`000<0006O0Il00`6O00<007ooOol01`001@6O00<007ooOol03goo1`001@6O
00<007ooOol0:goo000OOol00`00Oomoo`13Ool00`000Il1W`030Il01000Oomoo`001G`000<007oo
Ool01Woo00<007`0O0000g`000<0006O0Il00`6O00@007ooOol000El00030001W`6O00<1W`04001o
ogoo0005O0000`000Il1W`030Il01000Oomoo`001G`000<0006O0Il00`6O00@007ooOol000El0003
0001W`6O00<1W`04001oogoo0005O0000`000Il1W`030Il01000Oomoo`001G`000<0006O0Il00`6O
00@007ooOol000El00030001W`6O00<1W`04001oogoo0005O0000`000Il1W`030Il01000Oomoo`00
1G`000<0006O0Il00`6O00@007ooOol000El00030001W`6O00<1W`04001oogoo0005O0000`000Il1
W`030Il01000Oomoo`001G`000<0006O0Il00`6O00@007ooOol000Il00030001W`6O00<1W`04001o
ogoo0005O0000`000Il1W`030Il01000Oomoo`001G`000<0006O0Il00`6O00<007ooOol01Woo00<0
006O0Il00`6O00<007ooOol05Goo00<0006O0Il00`6O00<007ooOol0:goo000OOol00`00Oomoo`13
Ool00`000Il1W`030Il01000Oomoo`001G`000<007ooOol01Woo00<007`0O0000g`000<0006O0Il0
0`6O00@007ooOol000El00030001W`6O00<1W`04001oogoo0005O0000`000Il1W`030Il01000Oomo
o`001G`000<0006O0Il00`6O00@007ooOol000El00030001W`6O00<1W`04001oogoo0005O0000`00
0Il1W`030Il01000Oomoo`001G`000<0006O0Il00`6O00@007ooOol000El00030001W`6O00<1W`04
001oogoo0005O0000`000Il1W`030Il01000Oomoo`001G`000<0006O0Il00`6O00@007ooOol000El
00030001W`6O00<1W`04001oogoo0005O0000`000Il1W`030Il01000Oomoo`001G`000<0006O0Il0
0`6O00@007ooOol000Il00030001W`6O00<1W`04001oogoo0005O0000`000Il1W`030Il01000Oomo
o`001G`000<0006O0Il00`6O00<007ooOol01Woo00<0006O0Il00`6O00<007ooOol05Goo1`00;Goo
000OOol00`00Oomoo`13Ool00`000Il1W`030Il01000Oomoo`001G`000<007ooOol01Woo00<007`0
O0000g`000<0006O0Il00`6O00@007ooOol000El00030001W`6O00<1W`04001oogoo0005O0000`00
0Il1W`030Il01000Oomoo`001G`000<0006O0Il00`6O00@007ooOol000El00030001W`6O00<1W`04
001oogoo0005O0000`000Il1W`030Il01000Oomoo`001G`000<0006O0Il00`6O00@007ooOol000El
00030001W`6O00<1W`04001oogoo0005O0000`000Il1W`030Il01000Oomoo`001G`000<0006O0Il0
0`6O00@007ooOol000El00030001W`6O00<1W`04001oogoo0005O0000`000Il1W`030Il01000Oomo
o`001G`000<0006O0Il00`6O00@007ooOol000Il00030001W`6O00<1W`04001oogoo0005O0000`00
0Il1W`030Il01000Oomoo`001G`000<0006O0Il00`6O00<007ooOol01Woo00<0006O0Il00`6O00<0
07ooOol0BGoo000OOol00`00Oomoo`13Ool00`000Il1W`030Il01000Oomoo`001G`000<007ooOol0
1Woo00<007`0O0000g`000<0006O0Il00`6O00@007ooOol000El00030001W`6O00<1W`04001oogoo
0005O0000`000Il1W`030Il01000Oomoo`001G`000<0006O0Il00`6O00@007ooOol000El00030001
W`6O00<1W`04001oogoo0005O0000`000Il1W`030Il01000Oomoo`001G`000<0006O0Il00`6O00@0
07ooOol000El00030001W`6O00<1W`04001oogoo0005O0000`000Il1W`030Il01000Oomoo`001G`0
00<0006O0Il00`6O00@007ooOol000El00030001W`6O00<1W`04001oogoo0005O0000`000Il1W`03
0Il01000Oomoo`001G`000<0006O0Il00`6O00@007ooOol000Il00030001W`6O00<1W`04001oogoo
0005O0000`000Il1W`030Il01000Oomoo`001G`000<0006O0Il00`6O00<007ooOol01Woo00<0006O
0Il00`6O00<007ooOol0BGoo000OOol00`00Oomoo`13Ool70002Ool00`00O01l0003O0000`00Oomo
o`06Ool00`00O01l0003O0000`000Il1W`030Il01000Oomoo`001G`000<0006O0Il00`6O00@007oo
Ool000El00030001W`6O00<1W`04001oogoo0005O0000`000Il1W`030Il01000Oomoo`001G`000<0
006O0Il00`6O00@007ooOol000El00030001W`6O00<1W`04001oogoo0005O0000`000Il1W`030Il0
1000Oomoo`001G`000<0006O0Il00`6O00@007ooOol000El00030001W`6O00<1W`04001oogoo0005
O0000`000Il1W`030Il01000Oomoo`001G`000<0006O0Il00`6O00@007ooOol000El00030001W`6O
00<1W`04001oogoo0005O0000`000Il1W`030Il01000Oomoo`001W`000<0006O0Il00`6O00@007oo
Ool000El00030001W`6O00<1W`04001oogoo0005O0000`000Il1W`030Il00`00Oomoo`06Ool7001;
Ool001moo`03001oogoo04aoo`03001l07`000=l0003001oogoo00Ioo`03001l07`000=l00030001
W`6O00<1W`04001oogoo0005O0000`000Il1W`030Il01000Oomoo`001G`000<0006O0Il00`6O00@0
07ooOol000El00030001W`6O00<1W`04001oogoo0005O0000`000Il1W`030Il01000Oomoo`001G`0
00<0006O0Il00`6O00@007ooOol000El00030001W`6O00<1W`04001oogoo0005O0000`000Il1W`03
0Il01000Oomoo`001G`000<0006O0Il00`6O00@007ooOol000El00030001W`6O00<1W`04001oogoo
0005O0000`000Il1W`030Il01000Oomoo`001G`000<0006O0Il00`6O00@007ooOol000El00030001
W`6O00<1W`04001oogoo0006O0000`000Il1W`030Il01000Oomoo`001G`000<0006O0Il00`6O00@0
07ooOol000El00030001W`6O00<1W`03001oogoo05Qoo`007goo0`00C7oo00<007`0O0000g`000<0
07ooOol01Woo00<007`0O0000g`000<0006O0Il00`6O00@007ooOol000El00030001W`6O00<1W`04
001oogoo0005O0000`000Il1W`030Il01000Oomoo`001G`000<0006O0Il00`6O00@007ooOol000El
00030001W`6O00<1W`04001oogoo0005O0000`000Il1W`030Il01000Oomoo`001G`000<0006O0Il0
0`6O00@007ooOol000El00030001W`6O00<1W`04001oogoo0005O0000`000Il1W`030Il01000Oomo
o`001G`000<0006O0Il00`6O00@007ooOol000El00030001W`6O00<1W`04001oogoo0005O0000`00
0Il1W`030Il01000Oomoo`001G`000<0006O0Il00`6O00@007ooOol000Il00030001W`6O00<1W`04
001oogoo0005O0000`000Il1W`030Il01000Oomoo`001G`000<0006O0Il00`6O00<007ooOol0F7oo
000OOol00`00Oomoo`1<Ool00`00O01l0003O0000`00Oomoo`06Ool00`00O01l0003O0000`000Il1
W`030Il01000Oomoo`001G`000<0006O0Il00`6O00@007ooOol000El00030001W`6O00<1W`04001o
ogoo0005O0000`000Il1W`030Il01000Oomoo`001G`000<0006O0Il00`6O00@007ooOol000El0003
0001W`6O00<1W`04001oogoo0005O0000`000Il1W`030Il01000Oomoo`001G`000<0006O0Il00`6O
00@007ooOol000El00030001W`6O00<1W`04001oogoo0005O0000`000Il1W`030Il01000Oomoo`00
1G`000<0006O0Il00`6O00@007ooOol000El00030001W`6O00<1W`04001oogoo0005O0000`000Il1
W`030Il01000Oomoo`001W`000<0006O0Il00`6O00@007ooOol000El00030001W`6O00<1W`04001o
ogoo0005O0000`000Il1W`030Il00`00Oomoo`1HOol001moo`03001oogoo04aoo`03001l07`000=l
0003001oogoo00Ioo`03001l07`000=l00030001W`6O00<1W`04001oogoo0005O0000`000Il1W`03
0Il01000Oomoo`001G`000<0006O0Il00`6O00@007ooOol000El00030001W`6O00<1W`04001oogoo
0005O0000`000Il1W`030Il01000Oomoo`001G`000<0006O0Il00`6O00@007ooOol000El00030001
W`6O00<1W`04001oogoo0005O0000`000Il1W`030Il01000Oomoo`001G`000<0006O0Il00`6O00@0
07ooOol000El00030001W`6O00<1W`04001oogoo0005O0000`000Il1W`030Il01000Oomoo`001G`0
00<0006O0Il00`6O00@007ooOol000El00030001W`6O00<1W`04001oogoo0006O0000`000Il1W`03
0Il01000Oomoo`001G`000<0006O0Il00`6O00@007ooOol000El00030001W`6O00<1W`03001oogoo
05Qoo`007goo00<007ooOol0C7oo00<007`0O0000g`000<007ooOol01Woo00<007`0O0000g`000<0
006O0Il00`6O00@007ooOol000El00030001W`6O00<1W`04001oogoo0005O0000`000Il1W`030Il0
1000Oomoo`001G`000<0006O0Il00`6O00@007ooOol000El00030001W`6O00<1W`04001oogoo0005
O0000`000Il1W`030Il01000Oomoo`001G`000<0006O0Il00`6O00@007ooOol000El00030001W`6O
00<1W`04001oogoo0005O0000`000Il1W`030Il01000Oomoo`001G`000<0006O0Il00`6O00@007oo
Ool000El00030001W`6O00<1W`04001oogoo0005O0000`000Il1W`030Il01000Oomoo`001G`000<0
006O0Il00`6O00@007ooOol000Il00030001W`6O00<1W`04001oogoo0005O0000`000Il1W`030Il0
1000Oomoo`001G`000<0006O0Il00`6O00<007ooOol0F7oo000OOol00`00Oomoo`1<Ool00`00O01l
0003O0000`00Oomoo`06Ool00`00O01l0003O0000`000Il1W`030Il01000Oomoo`001G`000<0006O
0Il00`6O00@007ooOol000El00030001W`6O00<1W`04001oogoo0005O0000`000Il1W`030Il01000
Oomoo`001G`000<0006O0Il00`6O00@007ooOol000El00030001W`6O00<1W`04001oogoo0005O000
0`000Il1W`030Il01000Oomoo`001G`000<0006O0Il00`6O00@007ooOol000El00030001W`6O00<1
W`04001oogoo0005O0000`000Il1W`030Il01000Oomoo`001G`000<0006O0Il00`6O00@007ooOol0
00El00030001W`6O00<1W`04001oogoo0005O0000`000Il1W`030Il01000Oomoo`001W`000<0006O
0Il00`6O00@007ooOol000El00030001W`6O00<1W`04001oogoo0005O0000`000Il1W`030Il00`00
Oomoo`1HOol001moo`03001oogoo04aoo`03001l07`000=l0003001oogoo00Ioo`03001l07`000=l
00030001W`6O00<1W`04001oogoo0005O0000`000Il1W`030Il01000Oomoo`001G`000<0006O0Il0
0`6O00@007ooOol000El00030001W`6O00<1W`04001oogoo0005O0000`000Il1W`030Il01000Oomo
o`001G`000<0006O0Il00`6O00@007ooOol000El00030001W`6O00<1W`04001oogoo0005O0000`00
0Il1W`030Il01000Oomoo`001G`000<0006O0Il00`6O00@007ooOol000El00030001W`6O00<1W`04
001oogoo0005O0000`000Il1W`030Il01000Oomoo`001G`000<0006O0Il00`6O00@007ooOol000El
00030001W`6O00<1W`04001oogoo0006O0000`000Il1W`030Il01000Oomoo`001G`000<0006O0Il0
0`6O00@007ooOol000El00030001W`6O00<1W`03001oogoo05Qoo`007goo00<007ooOol0C7oo00<0
07`0O0000g`000<007ooOol01Woo1`001@6O00@007ooOol000El00030001W`6O00<1W`04001oogoo
0005O0000`000Il1W`030Il01000Oomoo`001G`000<0006O0Il00`6O00@007ooOol000El00030001
W`6O00<1W`04001oogoo0005O0000`000Il1W`030Il01000Oomoo`001G`000<0006O0Il00`6O00@0
07ooOol000El00030001W`6O00<1W`04001oogoo0005O0000`000Il1W`030Il01000Oomoo`001G`0
00<0006O0Il00`6O00@007ooOol000El00030001W`6O00<1W`04001oogoo0005O0000`000Il1W`03
0Il01000Oomoo`001G`000<0006O0Il00`6O00@007ooOol000Il00030001W`6O00<1W`04001oogoo
0005O0000`000Il1W`030Il01000Oomoo`001G`000<0006O0Il00`6O00<007ooOol0F7oo000OOol0
0`00Oomoo`1<Ool00`00O01l0003O0000`00Oomoo`0<Ool00`000Il1W`030Il01000Oomoo`001G`0
00<0006O0Il00`6O00@007ooOol000El00030001W`6O00<1W`04001oogoo0005O0000`000Il1W`03
0Il01000Oomoo`001G`000<0006O0Il00`6O00@007ooOol000El00030001W`6O00<1W`04001oogoo
0005O0000`000Il1W`030Il01000Oomoo`001G`000<0006O0Il00`6O00@007ooOol000El00030001
W`6O00<1W`04001oogoo0005O0000`000Il1W`030Il01000Oomoo`001G`000<0006O0Il00`6O00@0
07ooOol000El00030001W`6O00<1W`04001oogoo0005O0000`000Il1W`030Il01000Oomoo`001W`0
00<0006O0Il00`6O00@007ooOol000El00030001W`6O00<1W`04001oogoo0005O0000`000Il1W`03
0Il00`00Oomoo`1HOol001moo`03001oogoo04aoo`03001l07`000=l0003001oogoo00aoo`030001
W`6O00<1W`04001oogoo0005O0000`000Il1W`030Il01000Oomoo`001G`000<0006O0Il00`6O00@0
07ooOol000El00030001W`6O00<1W`04001oogoo0005O0000`000Il1W`030Il01000Oomoo`001G`0
00<0006O0Il00`6O00@007ooOol000El00030001W`6O00<1W`04001oogoo0005O0000`000Il1W`03
0Il01000Oomoo`001G`000<0006O0Il00`6O00@007ooOol000El00030001W`6O00<1W`04001oogoo
0005O0000`000Il1W`030Il01000Oomoo`001G`000<0006O0Il00`6O00@007ooOol000El00030001
W`6O00<1W`04001oogoo0006O0000`000Il1W`030Il01000Oomoo`001G`000<0006O0Il00`6O00@0
07ooOol000El00030001W`6O00<1W`03001oogoo05Qoo`007goo00<007ooOol0C7oo00<007`0O000
0g`000<007ooOol037oo00<0006O0Il00`6O00@007ooOol000El00030001W`6O00<1W`04001oogoo
0005O0000`000Il1W`030Il01000Oomoo`001G`000<0006O0Il00`6O00@007ooOol000El00030001
W`6O00<1W`04001oogoo0005O0000`000Il1W`030Il01000Oomoo`001G`000<0006O0Il00`6O00@0
07ooOol000El00030001W`6O00<1W`04001oogoo0005O0000`000Il1W`030Il01000Oomoo`001G`0
00<0006O0Il00`6O00@007ooOol000El00030001W`6O00<1W`04001oogoo0005O0000`000Il1W`03
0Il01000Oomoo`001G`000<0006O0Il00`6O00@007ooOol000Il00030001W`6O00<1W`04001oogoo
0005O0000`000Il1W`030Il01000Oomoo`001G`000<0006O0Il00`6O00<007ooOol0F7oo000OOol0
0`00Oomoo`1<Ool00`00O01l0003O0000`00Oomoo`0<Ool00`000Il1W`030Il01000Oomoo`001G`0
00<0006O0Il00`6O00@007ooOol000El00030001W`6O00<1W`04001oogoo0005O0000`000Il1W`03
0Il01000Oomoo`001G`000<0006O0Il00`6O00@007ooOol000El00030001W`6O00<1W`04001oogoo
0005O0000`000Il1W`030Il01000Oomoo`001G`000<0006O0Il00`6O00@007ooOol000El00030001
W`6O00<1W`04001oogoo0005O0000`000Il1W`030Il01000Oomoo`001G`000<0006O0Il00`6O00@0
07ooOol000El00030001W`6O00<1W`04001oogoo0005O0000`000Il1W`030Il01000Oomoo`001W`0
00<0006O0Il00`6O00@007ooOol000El00030001W`6O00<1W`04001oogoo0005O0000`000Il1W`03
0Il00`00Oomoo`1HOol001moo`03001oogoo04aoo`03001l07`000=l0003001oogoo00aoo`030001
W`6O00<1W`04001oogoo0005O0000`000Il1W`030Il01000Oomoo`001G`000<0006O0Il00`6O00@0
07ooOol000El00030001W`6O00<1W`04001oogoo0005O0000`000Il1W`030Il01000Oomoo`001G`0
00<0006O0Il00`6O00@007ooOol000El00030001W`6O00<1W`04001oogoo0005O0000`000Il1W`03
0Il01000Oomoo`001G`000<0006O0Il00`6O00@007ooOol000El00030001W`6O00<1W`04001oogoo
0005O0000`000Il1W`030Il01000Oomoo`001G`000<0006O0Il00`6O00@007ooOol000El00030001
W`6O00<1W`04001oogoo0006O0000`000Il1W`030Il01000Oomoo`001G`000<0006O0Il00`6O00@0
07ooOol000El00030001W`6O00<1W`03001oogoo05Qoo`007goo00<007ooOol0C7oo00<007`0O000
0g`000<007ooOol037oo00<0006O0Il00`6O00@007ooOol000El00030001W`6O00<1W`04001oogoo
0005O0000`000Il1W`030Il01000Oomoo`001G`000<0006O0Il00`6O00@007ooOol000El00030001
W`6O00<1W`04001oogoo0005O0000`000Il1W`030Il01000Oomoo`001G`000<0006O0Il00`6O00@0
07ooOol000El00030001W`6O00<1W`04001oogoo0005O0000`000Il1W`030Il01000Oomoo`001G`0
00<0006O0Il00`6O00@007ooOol000El00030001W`6O00<1W`04001oogoo0005O0000`000Il1W`03
0Il01000Oomoo`001G`000<0006O0Il00`6O00@007ooOol000Il00030001W`6O00<1W`04001oogoo
0005O0000`000Il1W`030Il01000Oomoo`001G`000<0006O0Il00`6O00<007ooOol0F7oo000OOol3
001<Ool00`00O01l0003O0000`00Oomoo`0<Ool00`000Il1W`030Il01000Oomoo`001G`000<0006O
0Il00`6O00@007ooOol000El00030001W`6O00<1W`04001oogoo0005O0000`000Il1W`030Il01000
Oomoo`001G`000<0006O0Il00`6O00@007ooOol000El00030001W`6O00<1W`04001oogoo0005O000
0`000Il1W`030Il01000Oomoo`001G`000<0006O0Il00`6O00@007ooOol000El00030001W`6O00<1
W`04001oogoo0005O0000`000Il1W`030Il01000Oomoo`001G`000<0006O0Il00`6O00@007ooOol0
00El00030001W`6O00<1W`04001oogoo0005O0000`000Il1W`030Il01000Oomoo`001W`000<0006O
0Il00`6O00@007ooOol000El00030001W`6O00<1W`04001oogoo0005O0000`000Il1W`030Il00`00
Oomoo`1HOol001moo`03001oogoo04aoo`03001l07`000=l0003001oogoo00aoo`030001W`6O00<1
W`04001oogoo0005O0000`000Il1W`030Il01000Oomoo`001G`000<0006O0Il00`6O00@007ooOol0
00El00030001W`6O00<1W`04001oogoo0005O0000`000Il1W`030Il01000Oomoo`001G`000<0006O
0Il00`6O00@007ooOol000El00030001W`6O00<1W`04001oogoo0005O0000`000Il1W`030Il01000
Oomoo`001G`000<0006O0Il00`6O00@007ooOol000El00030001W`6O00<1W`04001oogoo0005O000
0`000Il1W`030Il01000Oomoo`001G`000<0006O0Il00`6O00@007ooOol000El00030001W`6O00<1
W`04001oogoo0006O0000`000Il1W`030Il01000Oomoo`001G`000<0006O0Il00`6O00@007ooOol0
00El00030001W`6O00<1W`03001oogoo05Qoo`007goo00<007ooOol0C7oo00<007`0O0000g`000<0
07ooOol037oo00<0006O0Il00`6O00@007ooOol000El00030001W`6O00<1W`04001oogoo0005O000
0`000Il1W`030Il01000Oomoo`001G`000<0006O0Il00`6O00@007ooOol000El00030001W`6O00<1
W`04001oogoo0005O0000`000Il1W`030Il01000Oomoo`001G`000<0006O0Il00`6O00@007ooOol0
00El00030001W`6O00<1W`04001oogoo0005O0000`000Il1W`030Il01000Oomoo`001G`000<0006O
0Il00`6O00@007ooOol000El00030001W`6O00<1W`04001oogoo0005O0000`000Il1W`030Il01000
Oomoo`001G`000<0006O0Il00`6O00@007ooOol000Il00030001W`6O00<1W`04001oogoo0005O000
0`000Il1W`030Il01000Oomoo`001G`000<0006O0Il00`6O00<007ooOol0F7oo000OOol00`00Oomo
o`1<Ool00`00O01l0003O0000`00Oomoo`0<Ool00`000Il1W`030Il01000Oomoo`001G`000<0006O
0Il00`6O00@007ooOol000El00030001W`6O00<1W`04001oogoo0005O0000`000Il1W`030Il01000
Oomoo`001G`000<0006O0Il00`6O00@007ooOol000El00030001W`6O00<1W`04001oogoo0005O000
0`000Il1W`030Il01000Oomoo`001G`000<0006O0Il00`6O00@007ooOol000El00030001W`6O00<1
W`04001oogoo0005O0000`000Il1W`030Il01000Oomoo`001G`000<0006O0Il00`6O00@007ooOol0
00El00030001W`6O00<1W`04001oogoo0005O0000`000Il1W`030Il01000Oomoo`001W`000<0006O
0Il00`6O00@007ooOol000El00030001W`6O00<1W`04001oogoo0005O0000`000Il1W`030Il00`00
Oomoo`1HOol001moo`03001oogoo04aoo`03001l07`000=l0003001oogoo00aoo`030001W`6O00<1
W`04001oogoo0005O0000`000Il1W`030Il01000Oomoo`001G`000<0006O0Il00`6O00@007ooOol0
00El00030001W`6O00<1W`04001oogoo0005O0000`000Il1W`030Il01000Oomoo`001G`000<0006O
0Il00`6O00@007ooOol000El00030001W`6O00<1W`04001oogoo0005O0000`000Il1W`030Il01000
Oomoo`001G`000<0006O0Il00`6O00@007ooOol000El00030001W`6O00<1W`04001oogoo0005O000
0`000Il1W`030Il01000Oomoo`001G`000<0006O0Il00`6O00@007ooOol000El00030001W`6O00<1
W`04001oogoo0006O0000`000Il1W`030Il01000Oomoo`001G`000<0006O0Il00`6O00@007ooOol0
00El00030001W`6O00<1W`03001oogoo05Qoo`007goo00<007ooOol0C7oo00<007`0O0000g`000<0
07ooOol037oo00<0006O0Il00`6O00@007ooOol000El00030001W`6O00<1W`04001oogoo0005O000
0`000Il1W`030Il01000Oomoo`001G`000<0006O0Il00`6O00@007ooOol000El00030001W`6O00<1
W`04001oogoo0005O0000`000Il1W`030Il01000Oomoo`001G`000<0006O0Il00`6O00@007ooOol0
00El00030001W`6O00<1W`04001oogoo0005O0000`000Il1W`030Il01000Oomoo`001G`000<0006O
0Il00`6O00@007ooOol000El00030001W`6O00<1W`04001oogoo0005O0000`000Il1W`030Il01000
Oomoo`001G`000<0006O0Il00`6O00@007ooOol000Il00030001W`6O00<1W`04001oogoo0005O000
0`000Il1W`030Il01000Oomoo`001G`000<0006O0Il00`6O00<007ooOol0F7oo000OOol00`00Oomo
o`1<Ool7000>Ool00`000Il1W`030Il01000Oomoo`001G`000<0006O0Il00`6O00@007ooOol000El
00030001W`6O00<1W`04001oogoo0005O0000`000Il1W`030Il01000Oomoo`001G`000<0006O0Il0
0`6O00@007ooOol000El00030001W`6O00<1W`04001oogoo0005O0000`000Il1W`030Il01000Oomo
o`001G`000<0006O0Il00`6O00@007ooOol000El00030001W`6O00<1W`04001oogoo0005O0000`00
0Il1W`030Il01000Oomoo`001G`000<0006O0Il00`6O00@007ooOol000El00030001W`6O00<1W`04
001oogoo0005O0000`000Il1W`030Il01000Oomoo`001W`000<0006O0Il00`6O00@007ooOol000El
00030001W`6O00<1W`04001oogoo0005O0000`000Il1W`030Il00`00Oomoo`1HOol001moo`03001o
ogoo065oo`030001W`6O00<1W`04001oogoo0005O0000`000Il1W`030Il01000Oomoo`001G`000<0
006O0Il00`6O00@007ooOol000El00030001W`6O00<1W`04001oogoo0005O0000`000Il1W`030Il0
1000Oomoo`001G`000<0006O0Il00`6O00@007ooOol000El00030001W`6O00<1W`04001oogoo0005
O0000`000Il1W`030Il01000Oomoo`001G`000<0006O0Il00`6O00@007ooOol000El00030001W`6O
00<1W`04001oogoo0005O0000`000Il1W`030Il01000Oomoo`001G`000<0006O0Il00`6O00@007oo
Ool000El00030001W`6O00<1W`04001oogoo0006O0000`000Il1W`030Il01000Oomoo`001G`000<0
006O0Il00`6O00@007ooOol000El00030001W`6O00<1W`03001oogoo05Qoo`007goo00<007ooOol0
HGoo00<0006O0Il00`6O00@007ooOol000El00030001W`6O00<1W`04001oogoo0005O0000`000Il1
W`030Il01000Oomoo`001G`000<0006O0Il00`6O00@007ooOol000El00030001W`6O00<1W`04001o
ogoo0005O0000`000Il1W`030Il01000Oomoo`001G`000<0006O0Il00`6O00@007ooOol000El0003
0001W`6O00<1W`04001oogoo0005O0000`000Il1W`030Il01000Oomoo`001G`000<0006O0Il00`6O
00@007ooOol000El00030001W`6O00<1W`04001oogoo0005O0000`000Il1W`030Il01000Oomoo`00
1G`000<0006O0Il00`6O00@007ooOol000Il00030001W`6O00<1W`04001oogoo0005O0000`000Il1
W`030Il01000Oomoo`001G`000<0006O0Il00`6O00<007ooOol0F7oo000OOol00`00Oomoo`1QOol0
0`000Il1W`030Il01000Oomoo`001G`000<0006O0Il00`6O00@007ooOol000El00030001W`6O00<1
W`04001oogoo0005O0000`000Il1W`030Il01000Oomoo`001G`000<0006O0Il00`6O00@007ooOol0
00El00030001W`6O00<1W`04001oogoo0005O0000`000Il1W`030Il01000Oomoo`001G`000<0006O
0Il00`6O00@007ooOol000El00030001W`6O00<1W`04001oogoo0005O0000`000Il1W`030Il01000
Oomoo`001G`000<0006O0Il00`6O00@007ooOol000El00030001W`6O00<1W`04001oogoo0005O000
0`000Il1W`030Il01000Oomoo`001W`000<0006O0Il00`6O00@007ooOol000El00030001W`6O00<1
W`04001oogoo0005O0000`000Il1W`030Il00`00Oomoo`1HOol001moo`03001oogoo065oo`030001
W`6O00<1W`04001oogoo0005O0000`000Il1W`030Il01000Oomoo`001G`000<0006O0Il00`6O00@0
07ooOol000El00030001W`6O00<1W`04001oogoo0005O0000`000Il1W`030Il01000Oomoo`001G`0
00<0006O0Il00`6O00@007ooOol000El00030001W`6O00<1W`04001oogoo0005O0000`000Il1W`03
0Il01000Oomoo`001G`000<0006O0Il00`6O00@007ooOol000El00030001W`6O00<1W`04001oogoo
0005O0000`000Il1W`030Il01000Oomoo`001G`000<0006O0Il00`6O00@007ooOol000El00030001
W`6O00<1W`04001oogoo0006O0000`000Il1W`030Il01000Oomoo`001G`000<0006O0Il00`6O00@0
07ooOol000El00030001W`6O00<1W`03001oogoo05Qoo`003goo10000goo0P001goo00<007ooOol0
HGoo1`000Woo1`001@6O00@007ooOol000El00030001W`6O00<1W`04001oogoo0005O0000`000Il1
W`030Il01000Oomoo`001G`000<0006O0Il00`6O00@007ooOol000El00030001W`6O00<1W`04001o
ogoo0005O0000`000Il1W`030Il01000Oomoo`001G`000<0006O0Il00`6O00@007ooOol000El0003
0001W`6O00<1W`04001oogoo0005O0000`000Il1W`030Il01000Oomoo`001G`000<0006O0Il00`6O
00@007ooOol000El00030001W`6O00<1W`04001oogoo0005O0000`000Il1W`030Il01000Oomoo`00
1W`000<0006O0Il00`6O00@007ooOol000El00030001W`6O00<1W`04001oogoo0005O0000`000Il1
W`030Il00`00Oomoo`1HOol0011oo`03001oogoo009oo`04001oogoo0006Ool00`00Oomoo`1`Ool0
0`000Il1W`030Il01000Oomoo`001G`000<0006O0Il00`6O00@007ooOol000El00030001W`6O00<1
W`04001oogoo0005O0000`000Il1W`030Il01000Oomoo`001G`000<0006O0Il00`6O00@007ooOol0
00El00030001W`6O00<1W`04001oogoo0005O0000`000Il1W`030Il01000Oomoo`001G`000<0006O
0Il00`6O00@007ooOol000El00030001W`6O00<1W`04001oogoo0005O0000`000Il1W`030Il01000
Oomoo`001G`000<0006O0Il00`6O00@007ooOol000El00030001W`6O00<1W`04001oogoo0006O000
0`000Il1W`030Il01000Oomoo`001G`000<0006O0Il00`6O00@007ooOol000El00030001W`6O00<1
W`03001oogoo05Qoo`004Goo00D007ooOomoo`00009oo`03001oogoo00Aoo`@006moo`030001W`6O
00<1W`04001oogoo0005O0000`000Il1W`030Il01000Oomoo`001G`000<0006O0Il00`6O00@007oo
Ool000El00030001W`6O00<1W`04001oogoo0005O0000`000Il1W`030Il01000Oomoo`001G`000<0
006O0Il00`6O00@007ooOol000El00030001W`6O00<1W`04001oogoo0005O0000`000Il1W`030Il0
1000Oomoo`001G`000<0006O0Il00`6O00@007ooOol000El00030001W`6O00<1W`04001oogoo0005
O0000`000Il1W`030Il01000Oomoo`001G`000<0006O0Il00`6O00@007ooOol000Il00030001W`6O
00<1W`04001oogoo0005O0000`000Il1W`030Il01000Oomoo`001G`000<0006O0Il00`6O00<007oo
Ool0F7oo000BOol01000Oomoo`000Woo00<007ooOol017oo00<007ooOol0L7oo00<0006O0Il00`6O
00@007ooOol000El00030001W`6O00<1W`04001oogoo0005O0000`000Il1W`030Il01000Oomoo`00
1G`000<0006O0Il00`6O00@007ooOol000El00030001W`6O00<1W`04001oogoo0005O0000`000Il1
W`030Il01000Oomoo`001G`000<0006O0Il00`6O00@007ooOol000El00030001W`6O00<1W`04001o
ogoo0005O0000`000Il1W`030Il01000Oomoo`001G`000<0006O0Il00`6O00@007ooOol000El0003
0001W`6O00<1W`04001oogoo0005O0000`000Il1W`030Il01000Oomoo`001W`000<0006O0Il00`6O
00@007ooOol000El00030001W`6O00<1W`04001oogoo0005O0000`000Il1W`030Il00`00Oomoo`1H
Ool000moo`04001oogoo0002Ool01000Oomoo`001Woo00<007ooOol0L7oo00<0006O0Il00`6O00@0
07ooOol000El00030001W`6O00<1W`04001oogoo0005O0000`000Il1W`030Il01000Oomoo`001G`0
00<0006O0Il00`6O00@007ooOol000El00030001W`6O00<1W`04001oogoo0005O0000`000Il1W`03
0Il01000Oomoo`001G`000<0006O0Il00`6O00@007ooOol000El00030001W`6O00<1W`04001oogoo
0005O0000`000Il1W`030Il01000Oomoo`001G`000<0006O0Il00`6O00@007ooOol000El00030001
W`6O00<1W`04001oogoo0005O0000`000Il1W`030Il01000Oomoo`001W`000<0006O0Il00`6O00@0
07ooOol000El00030001W`6O00<1W`04001oogoo0005O0000`000Il1W`030Il00`00Oomoo`1HOol0
011oo`8000Aoo`8000Moo`03001oogoo071oo`L0009oo`03001l07`000=l00030001W`6O00<1W`04
001oogoo0005O0000`000Il1W`030Il01000Oomoo`001G`000<0006O0Il00`6O00@007ooOol000El
00030001W`6O00<1W`04001oogoo0005O0000`000Il1W`030Il01000Oomoo`001G`000<0006O0Il0
0`6O00@007ooOol000El00030001W`6O00<1W`04001oogoo0005O0000`000Il1W`030Il01000Oomo
o`001G`000<0006O0Il00`6O00@007ooOol000El00030001W`6O00<1W`04001oogoo0005O0000`00
0Il1W`030Il01000Oomoo`001W`000<0006O0Il00`6O00@007ooOol000El00030001W`6O00<1W`04
001oogoo0005O007001JOol001moo`03001oogoo07Uoo`03001l07`000=l00030001W`6O00<1W`04
001oogoo0005O0000`000Il1W`030Il01000Oomoo`001G`000<0006O0Il00`6O00@007ooOol000El
00030001W`6O00<1W`04001oogoo0005O0000`000Il1W`030Il01000Oomoo`001G`000<0006O0Il0
0`6O00@007ooOol000El00030001W`6O00<1W`04001oogoo0005O0000`000Il1W`030Il01000Oomo
o`001G`000<0006O0Il00`6O00@007ooOol000El00030001W`6O00<1W`04001oogoo0005O0000`00
0Il1W`030Il01000Oomoo`001W`000<0006O0Il00`6O00@007ooOol000El00030001W`6O00<1W`04
001oogoo0005O0000`00Oomoo`1NOol001moo`03001oogoo07Uoo`03001l07`000=l00030001W`6O
00<1W`04001oogoo0005O0000`000Il1W`030Il01000Oomoo`001G`000<0006O0Il00`6O00@007oo
Ool000El00030001W`6O00<1W`04001oogoo0005O0000`000Il1W`030Il01000Oomoo`001G`000<0
006O0Il00`6O00@007ooOol000El00030001W`6O00<1W`04001oogoo0005O0000`000Il1W`030Il0
1000Oomoo`001G`000<0006O0Il00`6O00@007ooOol000El00030001W`6O00<1W`04001oogoo0005
O0000`000Il1W`030Il01000Oomoo`001W`000<0006O0Il00`6O00@007ooOol000El00030001W`6O
00<1W`04001oogoo0005O0000`00Oomoo`1NOol001moo`03001oogoo07Uoo`03001l07`000=l0003
0001W`6O00<1W`04001oogoo0005O0000`000Il1W`030Il01000Oomoo`001G`000<0006O0Il00`6O
00@007ooOol000El00030001W`6O00<1W`04001oogoo0005O0000`000Il1W`030Il01000Oomoo`00
1G`000<0006O0Il00`6O00@007ooOol000El00030001W`6O00<1W`04001oogoo0005O0000`000Il1
W`030Il01000Oomoo`001G`000<0006O0Il00`6O00@007ooOol000El00030001W`6O00<1W`04001o
ogoo0005O0000`000Il1W`030Il01000Oomoo`001W`000<0006O0Il00`6O00@007ooOol000El0003
0001W`6O00<1W`04001oogoo0005O0000`00Oomoo`1NOol001moo`03001oogoo07Uoo`03001l07`0
00=l00030001W`6O00<1W`04001oogoo0005O0000`000Il1W`030Il01000Oomoo`001G`000<0006O
0Il00`6O00@007ooOol000El00030001W`6O00<1W`04001oogoo0005O0000`000Il1W`030Il01000
Oomoo`001G`000<0006O0Il00`6O00@007ooOol000El00030001W`6O00<1W`04001oogoo0005O000
0`000Il1W`030Il01000Oomoo`001G`000<0006O0Il00`6O00@007ooOol000El00030001W`6O00<1
W`04001oogoo0005O0000`000Il1W`030Il01000Oomoo`001W`000<0006O0Il00`6O00@007ooOol0
00El00030001W`6O00<1W`04001oogoo0005O0000`00Oomoo`1NOol001moo`03001oogoo07Uoo`03
001l07`000=l00030001W`6O00<1W`04001oogoo0005O0000`000Il1W`030Il01000Oomoo`001G`0
00<0006O0Il00`6O00@007ooOol000El00030001W`6O00<1W`04001oogoo0005O0000`000Il1W`03
0Il01000Oomoo`001G`000<0006O0Il00`6O00@007ooOol000El00030001W`6O00<1W`04001oogoo
0005O0000`000Il1W`030Il01000Oomoo`001G`000<0006O0Il00`6O00@007ooOol000El00030001
W`6O00<1W`04001oogoo0005O0000`000Il1W`030Il01000Oomoo`001W`000<0006O0Il00`6O00@0
07ooOol000El00030001W`6O00<1W`04001oogoo0005O0000`00Oomoo`1NOol001moo`03001oogoo
07Uoo`03001l07`000=l00030001W`6O00<1W`04001oogoo0005O0000`000Il1W`030Il01000Oomo
o`001G`000<0006O0Il00`6O00@007ooOol000El00030001W`6O00<1W`04001oogoo0005O0000`00
0Il1W`030Il01000Oomoo`001G`000<0006O0Il00`6O00@007ooOol000El00030001W`6O00<1W`04
001oogoo0005O0000`000Il1W`030Il01000Oomoo`001G`000<0006O0Il00`6O00@007ooOol000El
00030001W`6O00<1W`04001oogoo0005O0000`000Il1W`030Il01000Oomoo`001W`000<0006O0Il0
0`6O00@007ooOol000El00030001W`6O00<1W`04001oogoo0005O0000`00Oomoo`1NOol001moo`03
001oogoo07Uoo`03001l07`000=l00030001W`6O00<1W`04001oogoo0005O0000`000Il1W`030Il0
1000Oomoo`001G`000<0006O0Il00`6O00@007ooOol000El00030001W`6O00<1W`04001oogoo0005
O0000`000Il1W`030Il01000Oomoo`001G`000<0006O0Il00`6O00@007ooOol000El00030001W`6O
00<1W`04001oogoo0005O0000`000Il1W`030Il01000Oomoo`001G`000<0006O0Il00`6O00@007oo
Ool000El00030001W`6O00<1W`04001oogoo0005O0000`000Il1W`030Il01000Oomoo`001W`000<0
006O0Il00`6O00@007ooOol000El00030001W`6O00<1W`04001oogoo0005O0000`00Oomoo`1NOol0
01moo`03001oogoo07Uoo`03001l07`000=l00030001W`6O00<1W`04001oogoo0005O0000`000Il1
W`030Il01000Oomoo`001G`000<0006O0Il00`6O00@007ooOol000El00030001W`6O00<1W`04001o
ogoo0005O0000`000Il1W`030Il01000Oomoo`001G`000<0006O0Il00`6O00@007ooOol000El0003
0001W`6O00<1W`04001oogoo0005O0000`000Il1W`030Il01000Oomoo`001G`000<0006O0Il00`6O
00@007ooOol000El00030001W`6O00<1W`04001oogoo0005O0000`000Il1W`030Il01000Oomoo`00
1W`000<0006O0Il00`6O00@007ooOol000El00030001W`6O00<1W`04001oogoo0005O0000`00Oomo
o`1NOol001moo`03001oogoo07Uoo`03001l07`000=l00030001W`6O00<1W`04001oogoo0005O000
0`000Il1W`030Il01000Oomoo`001G`000<0006O0Il00`6O00@007ooOol000El00030001W`6O00<1
W`04001oogoo0005O0000`000Il1W`030Il01000Oomoo`001G`000<0006O0Il00`6O00@007ooOol0
00El00030001W`6O00<1W`04001oogoo0005O0000`000Il1W`030Il01000Oomoo`001G`000<0006O
0Il00`6O00@007ooOol000El00030001W`6O00<1W`04001oogoo0005O0000`000Il1W`030Il01000
Oomoo`001W`000<0006O0Il00`6O00@007ooOol000El00030001W`6O00<1W`04001oogoo0005O000
0`00Oomoo`1NOol001moo`03001oogoo07Uoo`03001l07`000=l00030001W`6O00<1W`04001oogoo
0005O0000`000Il1W`030Il01000Oomoo`001G`000<0006O0Il00`6O00@007ooOol000El00030001
W`6O00<1W`04001oogoo0005O0000`000Il1W`030Il01000Oomoo`001G`000<0006O0Il00`6O00@0
07ooOol000El00030001W`6O00<1W`04001oogoo0005O0000`000Il1W`030Il01000Oomoo`001G`0
00<0006O0Il00`6O00@007ooOol000El00030001W`6O00<1W`04001oogoo0005O0000`000Il1W`03
0Il01000Oomoo`001W`000<0006O0Il00`6O00@007ooOol000El00030001W`6O00<1W`04001oogoo
0005O0000`00Oomoo`1NOol001moo`<007Uoo`03001l07`000=l00030001W`6O00<1W`04001oogoo
0005O0000`000Il1W`030Il01000Oomoo`001G`000<0006O0Il00`6O00@007ooOol000El00030001
W`6O00<1W`04001oogoo0005O0000`000Il1W`030Il01000Oomoo`001G`000<0006O0Il00`6O00@0
07ooOol000El00030001W`6O00<1W`04001oogoo0005O0000`000Il1W`030Il01000Oomoo`001G`0
00<0006O0Il00`6O00@007ooOol000El00030001W`6O00<1W`04001oogoo0005O0000`000Il1W`03
0Il01000Oomoo`001W`000<0006O0Il00`6O00@007ooOol000El00030001W`6O00<1W`04001oogoo
0005O0000`00Oomoo`1NOol001moo`03001oogoo07Uoo`03001l07`000=l00030001W`6O00<1W`04
001oogoo0005O0000`000Il1W`030Il01000Oomoo`001G`000<0006O0Il00`6O00@007ooOol000El
00030001W`6O00<1W`04001oogoo0005O0000`000Il1W`030Il01000Oomoo`001G`000<0006O0Il0
0`6O00@007ooOol000El00030001W`6O00<1W`04001oogoo0005O0000`000Il1W`030Il01000Oomo
o`001G`000<0006O0Il00`6O00@007ooOol000El00030001W`6O00<1W`04001oogoo0005O0000`00
0Il1W`030Il01000Oomoo`001W`000<0006O0Il00`6O00@007ooOol000El00030001W`6O00<1W`04
001oogoo0005O0000`00Oomoo`1NOol001moo`03001oogoo07Uoo`03001l07`000=l00030001W`6O
00<1W`04001oogoo0005O0000`000Il1W`030Il01000Oomoo`001G`000<0006O0Il00`6O00@007oo
Ool000El00030001W`6O00<1W`04001oogoo0005O0000`000Il1W`030Il01000Oomoo`001G`000<0
006O0Il00`6O00@007ooOol000El00030001W`6O00<1W`04001oogoo0005O0000`000Il1W`030Il0
1000Oomoo`001G`000<0006O0Il00`6O00@007ooOol000El00030001W`6O00<1W`04001oogoo0005
O0000`000Il1W`030Il01000Oomoo`001W`000<0006O0Il00`6O00@007ooOol000El00L0009oo`03
001l07`000=l0003001oogoo05ioo`007goo00<007ooOol0NGoo00<007`0O0000g`000<0006O0Il0
0`6O00@007ooOol000El00030001W`6O00<1W`04001oogoo0005O0000`000Il1W`030Il01000Oomo
o`001G`000<0006O0Il00`6O00@007ooOol000El00030001W`6O00<1W`04001oogoo0005O0000`00
0Il1W`030Il01000Oomoo`001G`000<0006O0Il00`6O00@007ooOol000El00030001W`6O00<1W`04
001oogoo0005O0000`000Il1W`030Il01000Oomoo`001G`000<0006O0Il00`6O00@007ooOol000El
00030001W`6O00<1W`04001oogoo0006O0000`000Il1W`030Il01000Oomoo`001G`000<007ooOol0
1Woo00<007`0O0000g`000<007ooOol0GWoo000OOol00`00Oomoo`1iOol00`00O01l0003O0000`00
0Il1W`030Il01000Oomoo`001G`000<0006O0Il00`6O00@007ooOol000El00030001W`6O00<1W`04
001oogoo0005O0000`000Il1W`030Il01000Oomoo`001G`000<0006O0Il00`6O00@007ooOol000El
00030001W`6O00<1W`04001oogoo0005O0000`000Il1W`030Il01000Oomoo`001G`000<0006O0Il0
0`6O00@007ooOol000El00030001W`6O00<1W`04001oogoo0005O0000`000Il1W`030Il01000Oomo
o`001G`000<0006O0Il00`6O00@007ooOol000Il00030001W`6O00<1W`04001oogoo0005O0000`00
Oomoo`06Ool00`00O01l0003O0000`00Oomoo`1NOol001moo`03001oogoo07Uoo`03001l07`000=l
00030001W`6O00<1W`04001oogoo0005O0000`000Il1W`030Il01000Oomoo`001G`000<0006O0Il0
0`6O00@007ooOol000El00030001W`6O00<1W`04001oogoo0005O0000`000Il1W`030Il01000Oomo
o`001G`000<0006O0Il00`6O00@007ooOol000El00030001W`6O00<1W`04001oogoo0005O0000`00
0Il1W`030Il01000Oomoo`001G`000<0006O0Il00`6O00@007ooOol000El00030001W`6O00<1W`04
001oogoo0005O0000`000Il1W`030Il01000Oomoo`001W`000<0006O0Il00`6O00@007ooOol000El
0003001oogoo00Ioo`03001l07`000=l0003001oogoo05ioo`007goo00<007ooOol0NGoo00<007`0
O0000g`000<0006O0Il00`6O00@007ooOol000El00030001W`6O00<1W`04001oogoo0005O0000`00
0Il1W`030Il01000Oomoo`001G`000<0006O0Il00`6O00@007ooOol000El00030001W`6O00<1W`04
001oogoo0005O0000`000Il1W`030Il01000Oomoo`001G`000<0006O0Il00`6O00@007ooOol000El
00030001W`6O00<1W`04001oogoo0005O0000`000Il1W`030Il01000Oomoo`001G`000<0006O0Il0
0`6O00@007ooOol000El00030001W`6O00<1W`04001oogoo0006O0000`000Il1W`030Il01000Oomo
o`001G`000<007ooOol01Woo00<007`0O0000g`000<007ooOol0GWoo000OOol00`00Oomoo`1iOol0
0`00O01l0003O0000`000Il1W`030Il01000Oomoo`001G`000<0006O0Il00`6O00@007ooOol000El
00030001W`6O00<1W`04001oogoo0005O0000`000Il1W`030Il01000Oomoo`001G`000<0006O0Il0
0`6O00@007ooOol000El00030001W`6O00<1W`04001oogoo0005O0000`000Il1W`030Il01000Oomo
o`001G`000<0006O0Il00`6O00@007ooOol000El00030001W`6O00<1W`04001oogoo0005O0000`00
0Il1W`030Il01000Oomoo`001G`000<0006O0Il00`6O00@007ooOol000Il00030001W`6O00<1W`03
001oogoo00L000Qoo`03001l07`000=l0003001oogoo05ioo`007goo00<007ooOol0NGoo00<007`0
O0000g`000<0006O0Il00`6O00@007ooOol000El00030001W`6O00<1W`04001oogoo0005O0000`00
0Il1W`030Il01000Oomoo`001G`000<0006O0Il00`6O00@007ooOol000El00030001W`6O00<1W`04
001oogoo0005O0000`000Il1W`030Il01000Oomoo`001G`000<0006O0Il00`6O00@007ooOol000El
00030001W`6O00<1W`04001oogoo0005O0000`000Il1W`030Il01000Oomoo`001G`000<0006O0Il0
0`6O00@007ooOol000El00030001W`6O00<1W`04001oogoo0006O0000`000Il1W`030Il00`00Oomo
o`0?Ool00`00O01l0003O0000`00Oomoo`1NOol001moo`03001oogoo07Uoo`03001l07`000=l0003
0001W`6O00<1W`04001oogoo0005O0000`000Il1W`030Il01000Oomoo`001G`000<0006O0Il00`6O
00@007ooOol000El00030001W`6O00<1W`04001oogoo0005O0000`000Il1W`030Il01000Oomoo`00
1G`000<0006O0Il00`6O00@007ooOol000El00030001W`6O00<1W`04001oogoo0005O0000`000Il1
W`030Il01000Oomoo`001G`000<0006O0Il00`6O00@007ooOol000El00030001W`6O00<1W`04001o
ogoo0005O0000`000Il1W`030Il01000Oomoo`001W`000<0006O0Il00`6O00<007ooOol03goo00<0
07`0O0000g`000<007ooOol0GWoo000OOol00`00Oomoo`1iOol00`00O01l0003O0000`000Il1W`03
0Il01000Oomoo`001G`000<0006O0Il00`6O00@007ooOol000El00030001W`6O00<1W`04001oogoo
0005O0000`000Il1W`030Il01000Oomoo`001G`000<0006O0Il00`6O00@007ooOol000El00030001
W`6O00<1W`04001oogoo0005O0000`000Il1W`030Il01000Oomoo`001G`000<0006O0Il00`6O00@0
07ooOol000El00030001W`6O00<1W`04001oogoo0005O0000`000Il1W`030Il01000Oomoo`001G`0
00<0006O0Il00`6O00@007ooOol000Il00030001W`6O00<1W`03001oogoo00moo`L0061oo`007goo
00<007ooOol0NGoo00<007`0O0000g`000<0006O0Il00`6O00@007ooOol000El00030001W`6O00<1
W`04001oogoo0005O0000`000Il1W`030Il01000Oomoo`001G`000<0006O0Il00`6O00@007ooOol0
00El00030001W`6O00<1W`04001oogoo0005O0000`000Il1W`030Il01000Oomoo`001G`000<0006O
0Il00`6O00@007ooOol000El00030001W`6O00<1W`04001oogoo0005O0000`000Il1W`030Il01000
Oomoo`001G`000<0006O0Il00`6O00@007ooOol000El00030001W`6O00<1W`04001oogoo0006O000
0`000Il1W`030Il00`00Oomoo`1fOol001moo`03001oogoo07Uoo`03001l07`000=l00030001W`6O
00<1W`04001oogoo0005O0000`000Il1W`030Il01000Oomoo`001G`000<0006O0Il00`6O00@007oo
Ool000El00030001W`6O00<1W`04001oogoo0005O0000`000Il1W`030Il01000Oomoo`001G`000<0
006O0Il00`6O00@007ooOol000El00030001W`6O00<1W`04001oogoo0005O0000`000Il1W`030Il0
1000Oomoo`001G`000<0006O0Il00`6O00@007ooOol000El00030001W`6O00<1W`04001oogoo0005
O0000`000Il1W`030Il01000Oomoo`001W`000<0006O0Il00`6O00<007ooOol0MWoo000OOol3001i
Ool00`00O01l0003O0000`000Il1W`030Il01000Oomoo`001G`000<0006O0Il00`6O00@007ooOol0
00El00030001W`6O00<1W`04001oogoo0005O0000`000Il1W`030Il01000Oomoo`001G`000<0006O
0Il00`6O00@007ooOol000El00030001W`6O00<1W`04001oogoo0005O0000`000Il1W`030Il01000
Oomoo`001G`000<0006O0Il00`6O00@007ooOol000El00030001W`6O00<1W`04001oogoo0005O000
0`000Il1W`030Il01000Oomoo`001G`000<0006O0Il00`6O00@007ooOol000Il00030001W`6O00<1
W`03001oogoo07Ioo`007goo00<007ooOol0NGoo00<007`0O0000g`000<0006O0Il00`6O00@007oo
Ool000El00030001W`6O00<1W`04001oogoo0005O0000`000Il1W`030Il01000Oomoo`001G`000<0
006O0Il00`6O00@007ooOol000El00030001W`6O00<1W`04001oogoo0005O0000`000Il1W`030Il0
1000Oomoo`001G`000<0006O0Il00`6O00@007ooOol000El00030001W`6O00<1W`04001oogoo0005
O0000`000Il1W`030Il01000Oomoo`001G`000<0006O0Il00`6O00@007ooOol000El00030001W`6O
00<1W`04001oogoo0006O0000`000Il1W`030Il00`00Oomoo`1fOol001moo`03001oogoo07Uoo`03
001l07`000=l00030001W`6O00<1W`04001oogoo0005O0000`000Il1W`030Il01000Oomoo`001G`0
00<0006O0Il00`6O00@007ooOol000El00030001W`6O00<1W`04001oogoo0005O0000`000Il1W`03
0Il01000Oomoo`001G`000<0006O0Il00`6O00@007ooOol000El00030001W`6O00<1W`04001oogoo
0005O0000`000Il1W`030Il01000Oomoo`001G`000<0006O0Il00`6O00@007ooOol000El00030001
W`6O00<1W`04001oogoo0005O0000`000Il1W`030Il01000Oomoo`001W`000<0006O0Il00`6O00<0
07ooOol0MWoo000OOol00`00Oomoo`1iOol00`00O01l0003O0000`000Il1W`030Il01000Oomoo`00
1G`000<0006O0Il00`6O00@007ooOol000El00030001W`6O00<1W`04001oogoo0005O0000`000Il1
W`030Il01000Oomoo`001G`000<0006O0Il00`6O00@007ooOol000El00030001W`6O00<1W`04001o
ogoo0005O0000`000Il1W`030Il01000Oomoo`001G`000<0006O0Il00`6O00@007ooOol000El0003
0001W`6O00<1W`04001oogoo0005O0000`000Il1W`030Il01000Oomoo`001G`000<0006O0Il00`6O
00@007ooOol000Il00030001W`6O00<1W`03001oogoo07Ioo`007goo00<007ooOol0NGoo00<007`0
O0000g`000<0006O0Il00`6O00@007ooOol000El00030001W`6O00<1W`04001oogoo0005O0000`00
0Il1W`030Il01000Oomoo`001G`000<0006O0Il00`6O00@007ooOol000El00030001W`6O00<1W`04
001oogoo0005O0000`000Il1W`030Il01000Oomoo`001G`000<0006O0Il00`6O00@007ooOol000El
00030001W`6O00<1W`04001oogoo0005O0000`000Il1W`030Il01000Oomoo`001G`000<0006O0Il0
0`6O00@007ooOol000El00030001W`6O00<1W`04001oogoo0006O0000`000Il1W`030Il00`00Oomo
o`1fOol001moo`03001oogoo07Uoo`03001l07`000=l00030001W`6O00<1W`04001oogoo0005O000
0`000Il1W`030Il01000Oomoo`001G`000<0006O0Il00`6O00@007ooOol000El00030001W`6O00<1
W`04001oogoo0005O0000`000Il1W`030Il01000Oomoo`001G`000<0006O0Il00`6O00@007ooOol0
00El00030001W`6O00<1W`04001oogoo0005O0000`000Il1W`030Il01000Oomoo`001G`000<0006O
0Il00`6O00@007ooOol000El00030001W`6O00<1W`04001oogoo0005O0000`000Il1W`030Il01000
Oomoo`001W`01`00N7oo000OOol00`00Oomoo`1iOol00`00O01l0003O0000`000Il1W`030Il01000
Oomoo`001G`000<0006O0Il00`6O00@007ooOol000El00030001W`6O00<1W`04001oogoo0005O000
0`000Il1W`030Il01000Oomoo`001G`000<0006O0Il00`6O00@007ooOol000El00030001W`6O00<1
W`04001oogoo0005O0000`000Il1W`030Il01000Oomoo`001G`000<0006O0Il00`6O00@007ooOol0
00El00030001W`6O00<1W`04001oogoo0005O0000`000Il1W`030Il01000Oomoo`001G`000<0006O
0Il00`6O00@007ooOol000Il0003001oogoo07aoo`007goo00<007ooOol0NGoo00<007`0O0000g`0
00<0006O0Il00`6O00@007ooOol000El00030001W`6O00<1W`04001oogoo0005O0000`000Il1W`03
0Il01000Oomoo`001G`000<0006O0Il00`6O00@007ooOol000El00030001W`6O00<1W`04001oogoo
0005O0000`000Il1W`030Il01000Oomoo`001G`000<0006O0Il00`6O00@007ooOol000El00030001
W`6O00<1W`04001oogoo0005O0000`000Il1W`030Il01000Oomoo`001G`000<0006O0Il00`6O00@0
07ooOol000El00030001W`6O00<1W`04001oogoo0006O0000`00Oomoo`1lOol001moo`03001oogoo
07Uoo`03001l07`000=l00030001W`6O00<1W`04001oogoo0005O0000`000Il1W`030Il01000Oomo
o`001G`000<0006O0Il00`6O00@007ooOol000El00030001W`6O00<1W`04001oogoo0005O0000`00
0Il1W`030Il01000Oomoo`001G`000<0006O0Il00`6O00@007ooOol000El00030001W`6O00<1W`04
001oogoo0005O0000`000Il1W`030Il01000Oomoo`001G`000<0006O0Il00`6O00@007ooOol000El
00030001W`6O00<1W`04001oogoo0005O0000`000Il1W`030Il01000Oomoo`001W`000<007ooOol0
O7oo000OOol00`00Oomoo`1iOol00`00O01l0003O0000`000Il1W`030Il01000Oomoo`001G`000<0
006O0Il00`6O00@007ooOol000El00030001W`6O00<1W`04001oogoo0005O0000`000Il1W`030Il0
1000Oomoo`001G`000<0006O0Il00`6O00@007ooOol000El00030001W`6O00<1W`04001oogoo0005
O0000`000Il1W`030Il01000Oomoo`001G`000<0006O0Il00`6O00@007ooOol000El00030001W`6O
00<1W`04001oogoo0005O0000`000Il1W`030Il01000Oomoo`001G`000<0006O0Il00`6O00@007oo
Ool000Il0003001oogoo07aoo`007goo00<007ooOol0NGoo00<007`0O0000g`000<0006O0Il00`6O
00@007ooOol000El00030001W`6O00<1W`04001oogoo0005O0000`000Il1W`030Il01000Oomoo`00
1G`000<0006O0Il00`6O00@007ooOol000El00030001W`6O00<1W`04001oogoo0005O0000`000Il1
W`030Il01000Oomoo`001G`000<0006O0Il00`6O00@007ooOol000El00030001W`6O00<1W`04001o
ogoo0005O0000`000Il1W`030Il01000Oomoo`001G`000<0006O0Il00`6O00@007ooOol000El0003
0001W`6O00<1W`04001oogoo0006O0000`00Oomoo`1lOol001moo`03001oogoo07Uoo`03001l07`0
00=l00030001W`6O00<1W`04001oogoo0005O0000`000Il1W`030Il01000Oomoo`001G`000<0006O
0Il00`6O00@007ooOol000El00030001W`6O00<1W`04001oogoo0005O0000`000Il1W`030Il01000
Oomoo`001G`000<0006O0Il00`6O00@007ooOol000El00030001W`6O00<1W`04001oogoo0005O000
0`000Il1W`030Il01000Oomoo`001G`000<0006O0Il00`6O00@007ooOol000El00030001W`6O00<1
W`04001oogoo0005O0000`000Il1W`030Il01000Oomoo`001W`000<007ooOol0O7oo000OOol00`00
Oomoo`1iOol00`00O01l0003O0000`000Il1W`030Il01000Oomoo`001G`000<0006O0Il00`6O00@0
07ooOol000El00030001W`6O00<1W`04001oogoo0005O0000`000Il1W`030Il01000Oomoo`001G`0
00<0006O0Il00`6O00@007ooOol000El00030001W`6O00<1W`04001oogoo0005O0000`000Il1W`03
0Il01000Oomoo`001G`000<0006O0Il00`6O00@007ooOol000El00030001W`6O00<1W`04001oogoo
0005O0000`000Il1W`030Il01000Oomoo`001G`000<0006O0Il00`6O00@007ooOol000Il0003001o
ogoo07aoo`007goo0`00NGoo00<007`0O0000g`000<0006O0Il00`6O00@007ooOol000El00030001
W`6O00<1W`04001oogoo0005O0000`000Il1W`030Il01000Oomoo`001G`000<0006O0Il00`6O00@0
07ooOol000El00030001W`6O00<1W`04001oogoo0005O0000`000Il1W`030Il01000Oomoo`001G`0
00<0006O0Il00`6O00@007ooOol000El00030001W`6O00<1W`04001oogoo0005O0000`000Il1W`03
0Il01000Oomoo`001G`000<0006O0Il00`6O00@007ooOol000El00030001W`6O00<1W`04001oogoo
0006O0000`00Oomoo`1lOol001moo`03001oogoo07Uoo`03001l07`000=l00030001W`6O00<1W`04
001oogoo0005O0000`000Il1W`030Il01000Oomoo`001G`000<0006O0Il00`6O00@007ooOol000El
00030001W`6O00<1W`04001oogoo0005O0000`000Il1W`030Il01000Oomoo`001G`000<0006O0Il0
0`6O00@007ooOol000El00030001W`6O00<1W`04001oogoo0005O0000`000Il1W`030Il01000Oomo
o`001G`000<0006O0Il00`6O00@007ooOol000El00030001W`6O00<1W`04001oogoo0005O0000`00
0Il1W`030Il01000Oomoo`001W`000<007ooOol0O7oo000OOol00`00Oomoo`1iOol00`00O01l0003
O0000`000Il1W`030Il01000Oomoo`001G`000<0006O0Il00`6O00@007ooOol000El00030001W`6O
00<1W`04001oogoo0005O0000`000Il1W`030Il01000Oomoo`001G`000<0006O0Il00`6O00@007oo
Ool000El00030001W`6O00<1W`04001oogoo0005O0000`000Il1W`030Il01000Oomoo`001G`000<0
006O0Il00`6O00@007ooOol000El00030001W`6O00<1W`04001oogoo0005O0000`000Il1W`030Il0
1000Oomoo`001G`000<0006O0Il00`6O00@007ooOol000Il0003001oogoo07aoo`007goo00<007oo
Ool0NGoo00<007`0O0000g`000<0006O0Il00`6O00@007ooOol000El00030001W`6O00<1W`04001o
ogoo0005O0000`000Il1W`030Il01000Oomoo`001G`000<0006O0Il00`6O00@007ooOol000El0003
0001W`6O00<1W`04001oogoo0005O0000`000Il1W`030Il01000Oomoo`001G`000<0006O0Il00`6O
00@007ooOol000El00030001W`6O00<1W`04001oogoo0005O0000`000Il1W`030Il01000Oomoo`00
1G`000<0006O0Il00`6O00@007ooOol000El00030001W`6O00<1W`04001oogoo0006O0000`00Oomo
o`1lOol001moo`03001oogoo07Uoo`03001l07`000=l00030001W`6O00<1W`04001oogoo0005O000
0`000Il1W`030Il01000Oomoo`001G`000<0006O0Il00`6O00@007ooOol000El00030001W`6O00<1
W`04001oogoo0005O0000`000Il1W`030Il01000Oomoo`001G`000<0006O0Il00`6O00@007ooOol0
00El00030001W`6O00<1W`04001oogoo0005O0000`000Il1W`030Il01000Oomoo`001G`000<0006O
0Il00`6O00@007ooOol000El00030001W`6O00<1W`04001oogoo0005O0000`000Il1W`030Il01000
Oomoo`001W`000<007ooOol0O7oo000OOol00`00Oomoo`1iOol00`00O01l0003O0000`000Il1W`03
0Il01000Oomoo`001G`000<0006O0Il00`6O00@007ooOol000El00030001W`6O00<1W`04001oogoo
0005O0000`000Il1W`030Il01000Oomoo`001G`000<0006O0Il00`6O00@007ooOol000El00030001
W`6O00<1W`04001oogoo0005O0000`000Il1W`030Il01000Oomoo`001G`000<0006O0Il00`6O00@0
07ooOol000El00030001W`6O00<1W`04001oogoo0005O0000`000Il1W`030Il01000Oomoo`001G`0
00<0006O0Il00`6O00@007ooOol000Il0003001oogoo07aoo`007goo00<007ooOol0NGoo00<007`0
O0000g`000<0006O0Il00`6O00@007ooOol000El00030001W`6O00<1W`04001oogoo0005O0000`00
0Il1W`030Il01000Oomoo`001G`000<0006O0Il00`6O00@007ooOol000El00030001W`6O00<1W`04
001oogoo0005O0000`000Il1W`030Il01000Oomoo`001G`000<0006O0Il00`6O00@007ooOol000El
00030001W`6O00<1W`04001oogoo0005O0000`000Il1W`030Il01000Oomoo`001G`000<0006O0Il0
0`6O00@007ooOol000El00030001W`6O00<1W`04001oogoo0006O0000`00Oomoo`1lOol001moo`03
001oogoo07Uoo`03001l07`000=l00030001W`6O00<1W`04001oogoo0005O0000`000Il1W`030Il0
1000Oomoo`001G`000<0006O0Il00`6O00@007ooOol000El00030001W`6O00<1W`04001oogoo0005
O0000`000Il1W`030Il01000Oomoo`001G`000<0006O0Il00`6O00@007ooOol000El00030001W`6O
00<1W`04001oogoo0005O0000`000Il1W`030Il01000Oomoo`001G`000<0006O0Il00`6O00@007oo
Ool000El00030001W`6O00<1W`04001oogoo0005O0000`000Il1W`030Il01000Oomoo`001W`000<0
07ooOol0O7oo000OOol00`00Oomoo`1iOol00`00O01l0003O0000`000Il1W`030Il01000Oomoo`00
1G`000<0006O0Il00`6O00@007ooOol000El00030001W`6O00<1W`04001oogoo0005O0000`000Il1
W`030Il01000Oomoo`001G`000<0006O0Il00`6O00@007ooOol000El00030001W`6O00<1W`04001o
ogoo0005O0000`000Il1W`030Il01000Oomoo`001G`000<0006O0Il00`6O00@007ooOol000El0003
0001W`6O00<1W`04001oogoo0005O0000`000Il1W`030Il01000Oomoo`001G`000<0006O0Il00`6O
00@007ooOol000Il0003001oogoo07aoo`007goo00<007ooOol0NGoo00<007`0O0000g`000<0006O
0Il00`6O00@007ooOol000El00030001W`6O00<1W`04001oogoo0005O0000`000Il1W`030Il01000
Oomoo`001G`000<0006O0Il00`6O00@007ooOol000El00030001W`6O00<1W`04001oogoo0005O000
0`000Il1W`030Il01000Oomoo`001G`000<0006O0Il00`6O00@007ooOol000El00030001W`6O00<1
W`04001oogoo0005O0000`000Il1W`030Il01000Oomoo`001G`000<0006O0Il00`6O00@007ooOol0
00El00030001W`6O00<1W`04001oogoo0006O0000`00Oomoo`1lOol001moo`03001oogoo07Uoo`03
001l07`000=l00030001W`6O00<1W`04001oogoo0005O0000`000Il1W`030Il01000Oomoo`001G`0
00<0006O0Il00`6O00@007ooOol000El00030001W`6O00<1W`04001oogoo0005O0000`000Il1W`03
0Il01000Oomoo`001G`000<0006O0Il00`6O00@007ooOol000El00030001W`6O00<1W`04001oogoo
0005O0000`000Il1W`030Il01000Oomoo`001G`000<0006O0Il00`6O00@007ooOol000El00030001
W`6O00<1W`04001oogoo0005O0000`000Il1W`030Il01000Oomoo`001W`000<007ooOol0O7oo000@
Ool30003Ool20007Ool00`00Oomoo`1iOol00`00O01l0003O0000`000Il1W`030Il01000Oomoo`00
1G`000<0006O0Il00`6O00@007ooOol000El00030001W`6O00<1W`04001oogoo0005O0000`000Il1
W`030Il01000Oomoo`001G`000<0006O0Il00`6O00@007ooOol000El00030001W`6O00<1W`04001o
ogoo0005O0000`000Il1W`030Il01000Oomoo`001G`000<0006O0Il00`6O00@007ooOol000El0003
0001W`6O00<1W`04001oogoo0005O0000`000Il1W`030Il01000Oomoo`001G`000<0006O0Il00`6O
00@007ooOol000Il0003001oogoo07aoo`004Goo00D007ooOomoo`00009oo`03001oogoo00Aoo`03
001oogoo07Uoo`03001l07`000=l00030001W`6O00<1W`04001oogoo0005O0000`000Il1W`030Il0
1000Oomoo`001G`000<0006O0Il00`6O00@007ooOol000El00030001W`6O00<1W`04001oogoo0005
O0000`000Il1W`030Il01000Oomoo`001G`000<0006O0Il00`6O00@007ooOol000El00030001W`6O
00<1W`04001oogoo0005O0000`000Il1W`030Il01000Oomoo`001G`000<0006O0Il00`6O00@007oo
Ool000El00030001W`6O00<1W`04001oogoo0005O0000`000Il1W`030Il01000Oomoo`001W`000<0
07ooOol0O7oo000?Ool40002Ool01000Oomoo`001Woo1000N7oo00<007`0O0000g`000<0006O0Il0
0`6O00@007ooOol000El00030001W`6O00<1W`04001oogoo0005O0000`000Il1W`030Il01000Oomo
o`001G`000<0006O0Il00`6O00@007ooOol000El00030001W`6O00<1W`04001oogoo0005O0000`00
0Il1W`030Il01000Oomoo`001G`000<0006O0Il00`6O00@007ooOol000El00030001W`6O00<1W`04
001oogoo0005O0000`000Il1W`030Il01000Oomoo`001G`000<0006O0Il00`6O00@007ooOol000El
00030001W`6O00<1W`04001oogoo0006O0000`00Oomoo`1lOol000moo`03001oo`0000=oo`04001o
ogoo0006Ool00`00Oomoo`1iOol00`00O01l0003O0000`000Il1W`030Il01000Oomoo`001G`000<0
006O0Il00`6O00@007ooOol000El00030001W`6O00<1W`04001oogoo0005O0000`000Il1W`030Il0
1000Oomoo`001G`000<0006O0Il00`6O00@007ooOol000El00030001W`6O00<1W`04001oogoo0005
O0000`000Il1W`030Il01000Oomoo`001G`000<0006O0Il00`6O00@007ooOol000El00030001W`6O
00<1W`04001oogoo0005O0000`000Il1W`030Il01000Oomoo`001G`000<0006O0Il00`6O00@007oo
Ool000Il0003001oogoo07aoo`003goo00<007oo00000goo00@007ooOol000Ioo`03001oogoo07Uo
o`03001l07`000=l00030001W`6O00<1W`04001oogoo0005O0000`000Il1W`030Il01000Oomoo`00
1G`000<0006O0Il00`6O00@007ooOol000El00030001W`6O00<1W`04001oogoo0005O0000`000Il1
W`030Il01000Oomoo`001G`000<0006O0Il00`6O00@007ooOol000El00030001W`6O00<1W`04001o
ogoo0005O0000`000Il1W`030Il01000Oomoo`001G`000<0006O0Il00`6O00@007ooOol000El0003
0001W`6O00<1W`04001oogoo0005O0000`000Il1W`030Il00`00Oomoo`08001nOol0011oo`8000Ao
o`8000Moo`03001oogoo07Uoo`03001l07`000=l00030001W`6O00<1W`04001oogoo0005O0000`00
0Il1W`030Il01000Oomoo`001G`000<0006O0Il00`6O00@007ooOol000El00030001W`6O00<1W`04
001oogoo0005O0000`000Il1W`030Il01000Oomoo`001G`000<0006O0Il00`6O00@007ooOol000El
00030001W`6O00<1W`04001oogoo0005O0000`000Il1W`030Il01000Oomoo`001G`000<0006O0Il0
0`6O00@007ooOol000El00030001W`6O00<1W`04001oogoo0005O0000`000Il1W`030Il00`00Oomo
o`26Ool001moo`03001oogoo07Uoo`03001l07`000=l00030001W`6O00<1W`04001oogoo0005O000
0`000Il1W`030Il01000Oomoo`001G`000<0006O0Il00`6O00@007ooOol000El00030001W`6O00<1
W`04001oogoo0005O0000`000Il1W`030Il01000Oomoo`001G`000<0006O0Il00`6O00@007ooOol0
00El00030001W`6O00<1W`04001oogoo0005O0000`000Il1W`030Il01000Oomoo`001G`000<0006O
0Il00`6O00@007ooOol000El00030001W`6O00<1W`04001oogoo0005O0000`000Il1W`030Il00`00
Oomoo`26Ool001moo`03001oogoo07Uoo`03001l07`000=l00030001W`6O00<1W`04001oogoo0005
O0070002Ool00`00O01l0003O0000`000Il1W`030Il01000Oomoo`001G`000<0006O0Il00`6O00@0
07ooOol000El00030001W`6O00<1W`04001oogoo0005O0000`000Il1W`030Il01000Oomoo`001G`0
00<0006O0Il00`6O00@007ooOol000El00030001W`6O00<1W`04001oogoo0005O0000`000Il1W`03
0Il01000Oomoo`001G`000<0006O0Il00`6O00@007ooOol000El00030001W`6O00<1W`03001oogoo
08Ioo`007goo00<007ooOol0NGoo00<007`0O0000g`000<0006O0Il00`6O00@007ooOol000El0003
001oogoo00Ioo`03001l07`000=l00030001W`6O00<1W`04001oogoo0005O0000`000Il1W`030Il0
1000Oomoo`001G`000<0006O0Il00`6O00@007ooOol000El00030001W`6O00<1W`04001oogoo0005
O0000`000Il1W`030Il01000Oomoo`001G`000<0006O0Il00`6O00@007ooOol000El00030001W`6O
00<1W`04001oogoo0005O0000`000Il1W`030Il01000Oomoo`001G`000<0006O0Il00`6O00<007oo
Ool0QWoo000OOol00`00Oomoo`1iOol00`00O01l0003O0000`000Il1W`030Il01000Oomoo`001G`0
00<007ooOol01Woo00<007`0O0000g`000<0006O0Il00`6O00@007ooOol000El00030001W`6O00<1
W`04001oogoo0005O0000`000Il1W`030Il01000Oomoo`001G`000<0006O0Il00`6O00@007ooOol0
00El00030001W`6O00<1W`04001oogoo0005O0000`000Il1W`030Il01000Oomoo`001G`000<0006O
0Il00`6O00@007ooOol000El00030001W`6O00<1W`04001oogoo0005O0000`000Il1W`030Il00`00
Oomoo`26Ool001moo`03001oogoo07Uoo`03001l07`000=l00030001W`6O00<1W`04001oogoo0005
O0000`00Oomoo`06Ool00`00O01l0003O0000`000Il1W`030Il01000Oomoo`001G`000<0006O0Il0
0`6O00@007ooOol000El00030001W`6O00<1W`04001oogoo0005O0000`000Il1W`030Il01000Oomo
o`001G`000<0006O0Il00`6O00@007ooOol000El00030001W`6O00<1W`04001oogoo0005O0000`00
0Il1W`030Il01000Oomoo`001G`000<0006O0Il00`6O00@007ooOol000El00030001W`6O00<1W`03
001oogoo08Ioo`007goo00<007ooOol0NGoo00<007`0O0000g`000<0006O0Il00`6O00@007ooOol0
00El0003001oogoo00Ioo`03001l07`000=l00030001W`6O00<1W`04001oogoo0005O0000`000Il1
W`030Il01000Oomoo`001G`000<0006O0Il00`6O00@007ooOol000El00030001W`6O00<1W`04001o
ogoo0005O0000`000Il1W`030Il01000Oomoo`001G`000<0006O0Il00`6O00@007ooOol000El0003
0001W`6O00<1W`04001oogoo0005O0000`000Il1W`030Il01000Oomoo`001G`000<0006O0Il00`6O
00<007ooOol0QWoo000OOol00`00Oomoo`1iOol00`00O01l0003O0000`000Il1W`030Il01000Oomo
o`001G`000<007ooOol01Woo00<007`0O0000g`000<0006O0Il00`6O00@007ooOol000El00030001
W`6O00<1W`04001oogoo0005O0000`000Il1W`030Il01000Oomoo`001G`000<0006O0Il00`6O00@0
07ooOol000El00030001W`6O00<1W`04001oogoo0005O0000`000Il1W`030Il01000Oomoo`001G`0
00<0006O0Il00`6O00@007ooOol000El00030001W`6O00<1W`04001oogoo0005O0000`000Il1W`03
0Il00`00Oomoo`26Ool001moo`03001oogoo07Uoo`03001l07`000=l00030001W`6O00<1W`04001o
ogoo0005O0000`00Oomoo`06Ool00`00O01l0003O0000`000Il1W`030Il01000Oomoo`001G`000<0
006O0Il00`6O00@007ooOol000El00030001W`6O00<1W`04001oogoo0005O0000`000Il1W`030Il0
1000Oomoo`001G`000<0006O0Il00`6O00@007ooOol000El00030001W`6O00<1W`04001oogoo0005
O0000`000Il1W`030Il01000Oomoo`001G`000<0006O0Il00`6O00@007ooOol000El00030001W`6O
00<1W`03001oogoo08Ioo`007goo00<007ooOol0NGoo00<007`0O0000g`000<0006O0Il00`6O00@0
07ooOol000El0003001oogoo00Ioo`03001l07`000=l00030001W`6O00<1W`04001oogoo0005O000
0`000Il1W`030Il01000Oomoo`001G`000<0006O0Il00`6O00@007ooOol000El00030001W`6O00<1
W`04001oogoo0005O0000`000Il1W`030Il01000Oomoo`001G`000<0006O0Il00`6O00@007ooOol0
00El00030001W`6O00<1W`04001oogoo0005O0000`000Il1W`030Il01000Oomoo`001G`000<0006O
0Il00`6O00<007ooOol0QWoo000OOol3001iOol00`00O01l0003O0000`000Il1W`030Il01000Oomo
o`001G`000<007ooOol01Woo00<007`0O0000g`000<0006O0Il00`6O00@007ooOol000El00030001
W`6O00<1W`04001oogoo0005O0000`000Il1W`030Il01000Oomoo`001G`000<0006O0Il00`6O00@0
07ooOol000El00030001W`6O00<1W`04001oogoo0005O0000`000Il1W`030Il01000Oomoo`001G`0
00<0006O0Il00`6O00@007ooOol000El00030001W`6O00<1W`04001oogoo0005O0000`000Il1W`03
0Il00`00Oomoo`26Ool001moo`03001oogoo07Uoo`03001l07`000=l00030001W`6O00<1W`04001o
ogoo0005O0000`00Oomoo`06Ool00`00O01l0003O0000`000Il1W`030Il01000Oomoo`001G`000<0
006O0Il00`6O00@007ooOol000El00030001W`6O00<1W`04001oogoo0005O0000`000Il1W`030Il0
1000Oomoo`001G`000<0006O0Il00`6O00@007ooOol000El00030001W`6O00<1W`04001oogoo0005
O0000`000Il1W`030Il01000Oomoo`001G`000<0006O0Il00`6O00@007ooOol000El00030001W`6O
00<1W`03001oogoo08Ioo`007goo00<007ooOol0NGoo00<007`0O0000g`000<0006O0Il00`6O00<0
07ooOol01`0027oo00<007`0O0000g`000<0006O0Il00`6O00@007ooOol000El00030001W`6O00<1
W`04001oogoo0005O0000`000Il1W`030Il01000Oomoo`001G`000<0006O0Il00`6O00@007ooOol0
00El00030001W`6O00<1W`04001oogoo0005O0000`000Il1W`030Il01000Oomoo`001G`000<0006O
0Il00`6O00@007ooOol000El00030001W`6O00<1W`04001oogoo0005O0000`000Il1W`030Il00`00
Oomoo`26Ool001moo`03001oogoo07Uoo`03001l07`000=l00030001W`6O00<1W`03001oogoo00mo
o`03001l07`000=l00030001W`6O00<1W`04001oogoo0005O0000`000Il1W`030Il01000Oomoo`00
1G`000<0006O0Il00`6O00@007ooOol000El00030001W`6O00<1W`04001oogoo0005O0000`000Il1
W`030Il01000Oomoo`001G`000<0006O0Il00`6O00@007ooOol000El00030001W`6O00<1W`04001o
ogoo0005O0000`000Il1W`030Il01000Oomoo`001G`000<0006O0Il00`6O00<007ooOol0QWoo000O
Ool00`00Oomoo`1iOol00`00O01l0003O0000`000Il1W`030Il00`00Oomoo`0?Ool00`00O01l0003
O0000`000Il1W`030Il01000Oomoo`001G`000<0006O0Il00`6O00@007ooOol000El00030001W`6O
00<1W`04001oogoo0005O0000`000Il1W`030Il01000Oomoo`001G`000<0006O0Il00`6O00@007oo
Ool000El00030001W`6O00<1W`04001oogoo0005O0000`000Il1W`030Il01000Oomoo`001G`000<0
006O0Il00`6O00@007ooOol000El00030001W`6O00<1W`03001oogoo08Ioo`007goo00<007ooOol0
NGoo00<007`0O0000g`000<0006O0Il00`6O00<007ooOol03goo00<007`0O0000g`000<0006O0Il0
0`6O00@007ooOol000El00030001W`6O00<1W`04001oogoo0005O0000`000Il1W`030Il01000Oomo
o`001G`000<0006O0Il00`6O00@007ooOol000El00030001W`6O00<1W`04001oogoo0005O0000`00
0Il1W`030Il01000Oomoo`001G`000<0006O0Il00`6O00@007ooOol000El00030001W`6O00<1W`04
001oogoo0005O0000`000Il1W`030Il00`00Oomoo`26Ool001moo`03001oogoo07Uoo`03001l07`0
00=l00030001W`6O00<1W`03001oogoo00moo`03001l07`000=l00030001W`6O00<1W`04001oogoo
0005O0000`000Il1W`030Il01000Oomoo`001G`000<0006O0Il00`6O00@007ooOol000El00030001
W`6O00<1W`04001oogoo0005O0000`000Il1W`030Il01000Oomoo`001G`000<0006O0Il00`6O00@0
07ooOol000El00030001W`6O00<1W`04001oogoo0005O0000`000Il1W`030Il01000Oomoo`001G`0
00<0006O0Il00`6O00<007ooOol0QWoo000OOol00`00Oomoo`1iOol00`00O01l0003O0000`000Il1
W`030Il00`00Oomoo`0?Ool00`00O01l0003O0000`000Il1W`030Il01000Oomoo`001G`000<0006O
0Il00`6O00@007ooOol000El00030001W`6O00<1W`04001oogoo0005O0000`000Il1W`030Il01000
Oomoo`001G`000<0006O0Il00`6O00@007ooOol000El00030001W`6O00<1W`04001oogoo0005O000
0`000Il1W`030Il01000Oomoo`001G`000<0006O0Il00`6O00@007ooOol000El00030001W`6O00<1
W`03001oogoo08Ioo`007goo00<007ooOol0NGoo00<007`0O0000g`000<0006O0Il00`6O00<007oo
Ool03goo00<007`0O0000g`000<0006O0Il00`6O00@007ooOol000El00030001W`6O00<1W`04001o
ogoo0005O0000`000Il1W`030Il01000Oomoo`001G`000<0006O0Il00`6O00@007ooOol000El0003
0001W`6O00<1W`04001oogoo0005O0000`000Il1W`030Il01000Oomoo`001G`000<0006O0Il00`6O
00@007ooOol000El00030001W`6O00<1W`04001oogoo0005O0000`000Il1W`030Il00`00Oomoo`26
Ool001moo`03001oogoo07Uoo`03001l07`000=l00030001W`6O00<1W`03001oogoo00moo`03001l
07`000=l00030001W`6O00<1W`04001oogoo0005O0000`000Il1W`030Il01000Oomoo`001G`000<0
006O0Il00`6O00@007ooOol000El00030001W`6O00<1W`04001oogoo0005O0000`000Il1W`030Il0
1000Oomoo`001G`000<0006O0Il00`6O00@007ooOol000El00030001W`6O00<1W`04001oogoo0005
O0000`000Il1W`030Il01000Oomoo`001G`000<0006O0Il00`6O00<007ooOol0QWoo000OOol00`00
Oomoo`1iOol00`00O01l0003O0000`000Il1W`030Il00`00Oomoo`0?Ool00`00O01l0003O0000`00
0Il1W`030Il01000Oomoo`001G`000<0006O0Il00`6O00@007ooOol000El00030001W`6O00<1W`04
001oogoo0005O0000`000Il1W`030Il01000Oomoo`001G`000<0006O0Il00`6O00@007ooOol000El
00030001W`6O00<1W`04001oogoo0005O0000`000Il1W`030Il01000Oomoo`001G`000<0006O0Il0
0`6O00@007ooOol000El00030001W`6O00<1W`03001oogoo08Ioo`007goo00<007ooOol0NGoo00<0
07`0O0000g`000<0006O0Il00`6O00<007ooOol03goo00<007`0O0000g`000<0006O0Il00`6O00@0
07ooOol000El00030001W`6O00<1W`04001oogoo0005O0000`000Il1W`030Il01000Oomoo`001G`0
00<0006O0Il00`6O00@007ooOol000El00030001W`6O00<1W`04001oogoo0005O0000`000Il1W`03
0Il01000Oomoo`001G`000<0006O0Il00`6O00@007ooOol000El00030001W`6O00<1W`04001oogoo
0005O0000`000Il1W`030Il00`00Oomoo`26Ool001moo`03001oogoo07Uoo`03001l07`000=l0003
0001W`6O00<1W`03001oogoo00moo`03001l07`000=l00030001W`6O00<1W`04001oogoo0005O000
0`000Il1W`030Il01000Oomoo`001G`000<0006O0Il00`6O00@007ooOol000El00030001W`6O00<1
W`04001oogoo0005O0000`000Il1W`030Il01000Oomoo`001G`000<0006O0Il00`6O00@007ooOol0
00El00030001W`6O00<1W`04001oogoo0005O0000`000Il1W`030Il01000Oomoo`001G`000<0006O
0Il00`6O00<007ooOol0QWoo000OOol3001iOol00`00O01l0003O0000`000Il1W`030Il00`00Oomo
o`0?Ool00`00O01l0003O0000`000Il1W`030Il01000Oomoo`001G`000<0006O0Il00`6O00@007oo
Ool000El00030001W`6O00<1W`04001oogoo0005O0000`000Il1W`030Il01000Oomoo`001G`000<0
006O0Il00`6O00@007ooOol000El00030001W`6O00<1W`04001oogoo0005O0000`000Il1W`030Il0
1000Oomoo`001G`000<0006O0Il00`6O00@007ooOol000El00030001W`6O00<1W`03001oogoo08Io
o`007goo00<007ooOol0NGoo00<007`0O0000g`000<0006O0Il00`6O00<007ooOol03goo00<007`0
O0000g`000<0006O0Il00`6O00@007ooOol000El00030001W`6O00<1W`04001oogoo0005O0000`00
0Il1W`030Il01000Oomoo`001G`000<0006O0Il00`6O00@007ooOol000El00030001W`6O00<1W`04
001oogoo0005O0000`000Il1W`030Il01000Oomoo`001G`000<0006O0Il00`6O00@007ooOol000El
00030001W`6O00<1W`04001oogoo0005O0000`000Il1W`030Il00`00Oomoo`26Ool001moo`03001o
ogoo07Uoo`03001l07`000=l00030001W`6O00<1W`03001oogoo00moo`03001l07`000=l00030001
W`6O00<1W`04001oogoo0005O0000`000Il1W`030Il01000Oomoo`001G`000<0006O0Il00`6O00@0
07ooOol000El00030001W`6O00<1W`04001oogoo0005O0000`000Il1W`030Il01000Oomoo`001G`0
00<0006O0Il00`6O00@007ooOol000El00030001W`6O00<1W`04001oogoo0005O0000`000Il1W`03
0Il01000Oomoo`001G`000<0006O0Il00`6O00<007ooOol0QWoo000OOol00`00Oomoo`1iOol00`00
O01l0003O0000`000Il1W`030Il00`00Oomoo`0?Ool00`00O01l0003O0000`000Il1W`030Il01000
Oomoo`001G`000<0006O0Il00`6O00@007ooOol000El00030001W`6O00<1W`04001oogoo0005O000
0`000Il1W`030Il01000Oomoo`001G`000<0006O0Il00`6O00@007ooOol000El00030001W`6O00<1
W`04001oogoo0005O0000`000Il1W`030Il01000Oomoo`001G`000<0006O0Il00`6O00@007ooOol0
00El00030001W`6O00<1W`03001oogoo08Ioo`007goo00<007ooOol0NGoo00<007`0O0000g`000<0
006O0Il00`6O00<007ooOol03goo00<007`0O0000g`000<0006O0Il00`6O00@007ooOol000El0003
0001W`6O00<1W`04001oogoo0005O0000`000Il1W`030Il01000Oomoo`001G`000<0006O0Il00`6O
00@007ooOol000El00030001W`6O00<1W`04001oogoo0005O0000`000Il1W`030Il01000Oomoo`00
1G`000<0006O0Il00`6O00@007ooOol000El00030001W`6O00<1W`04001oogoo0005O0000`000Il1
W`030Il00`00Oomoo`26Ool001moo`03001oogoo07Uoo`03001l07`000=l00030001W`6O00<1W`03
001oogoo00moo`03001l07`000=l00030001W`6O00<1W`04001oogoo0005O0000`000Il1W`030Il0
1000Oomoo`001G`000<0006O0Il00`6O00@007ooOol000El00030001W`6O00<1W`04001oogoo0005
O0000`000Il1W`030Il01000Oomoo`001G`000<0006O0Il00`6O00@007ooOol000El00030001W`6O
00<1W`04001oogoo0005O0000`000Il1W`030Il01000Oomoo`001G`000<0006O0Il00`6O00<007oo
Ool0QWoo000OOol00`00Oomoo`1iOol00`00O01l0003O0000`000Il1W`030Il00`00Oomoo`0?Ool0
0`00O01l0003O0000`000Il1W`030Il01000Oomoo`001G`000<0006O0Il00`6O00@007ooOol000El
00030001W`6O00<1W`04001oogoo0005O0000`000Il1W`030Il01000Oomoo`001G`000<0006O0Il0
0`6O00@007ooOol000El00030001W`6O00<1W`04001oogoo0005O0000`000Il1W`030Il01000Oomo
o`001G`000<0006O0Il00`6O00@007ooOol000El00030001W`6O00<1W`03001oogoo08Ioo`007goo
00<007ooOol0NGoo00<007`0O0000g`000<0006O0Il00`6O00<007ooOol03goo00<007`0O0000g`0
00<0006O0Il00`6O00@007ooOol000El00030001W`6O00<1W`04001oogoo0005O0000`000Il1W`03
0Il01000Oomoo`001G`000<0006O0Il00`6O00@007ooOol000El00030001W`6O00<1W`04001oogoo
0005O0000`000Il1W`030Il01000Oomoo`001G`000<0006O0Il00`6O00@007ooOol000El00030001
W`6O00<1W`04001oogoo0005O0000`000Il1W`030Il00`00Oomoo`26Ool001moo`03001oogoo07Uo
o`03001l07`000=l00030001W`6O00<1W`03001oogoo00moo`03001l07`000=l00030001W`6O00<1
W`04001oogoo0005O0000`000Il1W`030Il01000Oomoo`001G`000<0006O0Il00`6O00@007ooOol0
00El00030001W`6O00<1W`04001oogoo0005O0000`000Il1W`030Il01000Oomoo`001G`000<0006O
0Il00`6O00@007ooOol000El00030001W`6O00<1W`04001oogoo0005O0000`000Il1W`030Il01000
Oomoo`001G`000<0006O0Il00`6O00<007ooOol0QWoo000OOol00`00Oomoo`1iOol00`00O01l0003
O0000`000Il1W`030Il00`00Oomoo`0?Ool00`00O01l0003O0000`000Il1W`030Il01000Oomoo`00
1G`000<0006O0Il00`6O00@007ooOol000El00030001W`6O00<1W`04001oogoo0005O0000`000Il1
W`030Il01000Oomoo`001G`000<0006O0Il00`6O00@007ooOol000El00030001W`6O00<1W`04001o
ogoo0005O0000`000Il1W`030Il01000Oomoo`001G`000<0006O0Il00`6O00@007ooOol000El0003
0001W`6O00<1W`03001oogoo08Ioo`007goo00<007ooOol0NGoo00<007`0O0000g`000<0006O0Il0
0`6O00<007ooOol03goo00<007`0O0000g`000<0006O0Il00`6O00@007ooOol000El00030001W`6O
00<1W`04001oogoo0005O0000`000Il1W`030Il01000Oomoo`001G`000<0006O0Il00`6O00@007oo
Ool000El00030001W`6O00<1W`04001oogoo0005O0000`000Il1W`030Il01000Oomoo`001G`000<0
006O0Il00`6O00@007ooOol000El00030001W`6O00<1W`04001oogoo0005O0000`000Il1W`030Il0
0`00Oomoo`26Ool001moo`03001oogoo07Uoo`03001l07`000=l00030001W`6O00<1W`03001oogoo
00moo`03001l07`000=l00030001W`6O00<1W`04001oogoo0005O0000`000Il1W`030Il01000Oomo
o`001G`000<0006O0Il00`6O00@007ooOol000El00030001W`6O00<1W`04001oogoo0005O0000`00
0Il1W`030Il01000Oomoo`001G`000<0006O0Il00`6O00@007ooOol000El00030001W`6O00<1W`04
001oogoo0005O0000`000Il1W`030Il01000Oomoo`001G`000<0006O0Il00`6O00<007ooOol0QWoo
000OOol00`00Oomoo`1iOol00`00O01l0003O0000`000Il1W`030Il00`00Oomoo`0?Ool00`00O01l
0003O0000`000Il1W`030Il01000Oomoo`001G`000<0006O0Il00`6O00@007ooOol000El00030001
W`6O00<1W`04001oogoo0005O0000`000Il1W`030Il01000Oomoo`001G`000<0006O0Il00`6O00@0
07ooOol000El00030001W`6O00<1W`04001oogoo0005O0000`000Il1W`030Il01000Oomoo`001G`0
00<0006O0Il00`6O00@007ooOol000El00030001W`6O00<1W`03001oogoo08Ioo`007goo0`00NGoo
00<007`0O0000g`000<0006O0Il00`6O00<007ooOol03goo00<007`0O0000g`000<0006O0Il00`6O
00@007ooOol000El00030001W`6O00<1W`04001oogoo0005O0000`000Il1W`030Il01000Oomoo`00
1G`000<0006O0Il00`6O00@007ooOol000El00030001W`6O00<1W`04001oogoo0005O0000`000Il1
W`030Il01000Oomoo`001G`000<0006O0Il00`6O00@007ooOol000El00030001W`6O00<1W`04001o
ogoo0005O0000`000Il1W`030Il00`00Oomoo`26Ool001moo`03001oogoo07Uoo`03001l07`000=l
00030001W`6O00<1W`03001oogoo00moo`03001l07`000=l00030001W`6O00<1W`04001oogoo0005
O0000`000Il1W`030Il01000Oomoo`001G`000<0006O0Il00`6O00@007ooOol000El00030001W`6O
00<1W`04001oogoo0005O0000`000Il1W`030Il01000Oomoo`001G`000<0006O0Il00`6O00@007oo
Ool000El00030001W`6O00<1W`04001oogoo0005O0000`000Il1W`030Il01000Oomoo`001G`000<0
006O0Il00`6O00<007ooOol0QWoo000OOol00`00Oomoo`1iOol00`00O01l0003O007000AOol00`00
O01l0003O0000`000Il1W`030Il01000Oomoo`001G`000<0006O0Il00`6O00@007ooOol000El0003
0001W`6O00<1W`04001oogoo0005O0000`000Il1W`030Il01000Oomoo`001G`000<0006O0Il00`6O
00@007ooOol000El00030001W`6O00<1W`04001oogoo0005O0000`000Il1W`030Il01000Oomoo`00
1G`000<0006O0Il00`6O00@007ooOol000El00030001W`6O00<1W`03001oogoo08Ioo`007goo00<0
07ooOol0NGoo00<007`0O0000g`000<007ooOol05Goo00<007`0O0000g`000<0006O0Il00`6O00@0
07ooOol000El00030001W`6O00<1W`04001oogoo0005O0000`000Il1W`030Il01000Oomoo`001G`0
00<0006O0Il00`6O00@007ooOol000El00030001W`6O00<1W`04001oogoo0005O0000`000Il1W`03
0Il01000Oomoo`001G`000<0006O0Il00`6O00@007ooOol000El00030001W`6O00<1W`04001oogoo
0005O0000`000Il1W`030Il00`00Oomoo`26Ool001moo`03001oogoo07Uoo`03001l07`000=l0003
001oogoo01Eoo`03001l07`000=l00030001W`6O00<1W`04001oogoo0005O0000`000Il1W`030Il0
1000Oomoo`001G`000<0006O0Il00`6O00@007ooOol000El00030001W`6O00<1W`04001oogoo0005
O0000`000Il1W`030Il01000Oomoo`001G`000<0006O0Il00`6O00@007ooOol000El00030001W`6O
00<1W`04001oogoo0005O0000`000Il1W`030Il01000Oomoo`001G`000<0006O0Il00`6O00<007oo
Ool0QWoo000OOol00`00Oomoo`1iOol00`00O01l0003O0000`00Oomoo`0EOol00`00O01l0003O000
0`000Il1W`030Il01000Oomoo`001G`000<0006O0Il00`6O00@007ooOol000El00030001W`6O00<1
W`04001oogoo0005O0000`000Il1W`030Il01000Oomoo`001G`000<0006O0Il00`6O00@007ooOol0
00El00030001W`6O00<1W`04001oogoo0005O0000`000Il1W`030Il01000Oomoo`001G`000<0006O
0Il00`6O00@007ooOol000El00030001W`6O00<1W`03001oogoo08Ioo`007goo00<007ooOol0NGoo
00<007`0O0000g`000<007ooOol05Goo00<007`0O0000g`000<0006O0Il00`6O00@007ooOol000El
00030001W`6O00<1W`04001oogoo0005O0000`000Il1W`030Il01000Oomoo`001G`000<0006O0Il0
0`6O00@007ooOol000El00030001W`6O00<1W`04001oogoo0005O0000`000Il1W`030Il01000Oomo
o`001G`000<0006O0Il00`6O00@007ooOol000El00030001W`6O00<1W`04001oogoo0005O0000`00
0Il1W`030Il00`00Oomoo`26Ool001moo`03001oogoo07Uoo`03001l07`000=l0003001oogoo01Eo
o`03001l07`000=l00030001W`6O00<1W`04001oogoo0005O0000`000Il1W`030Il01000Oomoo`00
1G`000<0006O0Il00`6O00@007ooOol000El00030001W`6O00<1W`04001oogoo0005O0000`000Il1
W`030Il01000Oomoo`001G`000<0006O0Il00`6O00@007ooOol000El00030001W`6O00<1W`04001o
ogoo0005O0000`000Il1W`030Il01000Oomoo`001G`000<0006O0Il00`6O00<007ooOol0QWoo000O
Ool00`00Oomoo`1iOol7000GOol00`00O01l0003O0000`000Il1W`030Il01000Oomoo`001G`000<0
006O0Il00`6O00@007ooOol000El00030001W`6O00<1W`04001oogoo0005O0000`000Il1W`030Il0
1000Oomoo`001G`000<0006O0Il00`6O00@007ooOol000El00030001W`6O00<1W`04001oogoo0005
O0000`000Il1W`030Il01000Oomoo`001G`000<0006O0Il00`6O00<007ooOol03@00R7oo000OOol0
0`00Oomoo`2GOol00`00O01l0003O0000`000Il1W`030Il01000Oomoo`001G`000<0006O0Il00`6O
00@007ooOol000El00030001W`6O00<1W`04001oogoo0005O0000`000Il1W`030Il01000Oomoo`00
1G`000<0006O0Il00`6O00@007ooOol000El00030001W`6O00<1W`04001oogoo0005O0000`000Il1
W`030Il01000Oomoo`001G`000<0006O0Il00`6O00<007ooOol0UGoo000OOol00`00Oomoo`2GOol0
0`00O01l0003O0000`000Il1W`030Il01000Oomoo`001G`000<0006O0Il00`6O00@007ooOol000El
00030001W`6O00<1W`04001oogoo0005O0000`000Il1W`030Il01000Oomoo`001G`000<0006O0Il0
0`6O00@007ooOol000El00030001W`6O00<1W`04001oogoo0005O0070002Ool00`00O01l0003O000
0`000Il1W`030Il00`00Oomoo`2EOol0011oo`8000Aoo`8000Moo`03001oogoo09Moo`03001l07`0
00=l00030001W`6O00<1W`04001oogoo0005O0000`000Il1W`030Il01000Oomoo`001G`000<0006O
0Il00`6O00@007ooOol000El00030001W`6O00<1W`04001oogoo0005O0000`000Il1W`030Il01000
Oomoo`001G`000<0006O0Il00`6O00@007ooOol000El0003001oogoo00Ioo`03001l07`000=l0003
0001W`6O00<1W`03001oogoo09Eoo`003goo00@007ooOol0009oo`04001oogoo0006Ool00`00Oomo
o`2GOol00`00O01l0003O0000`000Il1W`030Il01000Oomoo`001G`000<0006O0Il00`6O00@007oo
Ool000El00030001W`6O00<1W`04001oogoo0005O0000`000Il1W`030Il01000Oomoo`001G`000<0
006O0Il00`6O00@007ooOol000El00030001W`6O00<1W`04001oogoo0005O0000`00Oomoo`06Ool0
0`00O01l0003O0000`000Il1W`030Il00`00Oomoo`2EOol000moo`04001oogoo0002Ool01000Oomo
o`001Woo1000UWoo00<007`0O0000g`000<0006O0Il00`6O00@007ooOol000El00030001W`6O00<1
W`04001oogoo0005O0000`000Il1W`030Il01000Oomoo`001G`000<0006O0Il00`6O00@007ooOol0
00El00030001W`6O00<1W`04001oogoo0005O0000`000Il1W`030Il00`00Oomoo`070008Ool00`00
O01l0003O0000`000Il1W`030Il00`00Oomoo`2EOol000moo`<000=oo`04001oogoo0006Ool00`00
Oomoo`2GOol00`00O01l0003O0000`000Il1W`030Il01000Oomoo`001G`000<0006O0Il00`6O00@0
07ooOol000El00030001W`6O00<1W`04001oogoo0005O0000`000Il1W`030Il01000Oomoo`001G`0
00<0006O0Il00`6O00@007ooOol000El00030001W`6O00<1W`03001oogoo00moo`03001l07`000=l
00030001W`6O00<1W`03001oogoo09Eoo`003goo00<007ooOol00goo00@007ooOol000Ioo`03001o
ogoo09Moo`03001l07`000=l00030001W`6O00<1W`04001oogoo0005O0000`000Il1W`030Il01000
Oomoo`001G`000<0006O0Il00`6O00@007ooOol000El00030001W`6O00<1W`04001oogoo0005O000
0`000Il1W`030Il01000Oomoo`001G`000<0006O0Il00`6O00<007ooOol03goo00<007`0O0000g`0
00<0006O0Il00`6O00<007ooOol0UGoo000@Ool30003Ool20007Ool00`00Oomoo`2GOol00`00O01l
0003O0000`000Il1W`030Il01000Oomoo`001G`000<0006O0Il00`6O00@007ooOol000El00030001
W`6O00<1W`04001oogoo0005O0000`000Il1W`030Il01000Oomoo`001G`000<0006O0Il00`6O00@0
07ooOol000El00030001W`6O00<1W`03001oogoo00moo`03001l07`000=l00030001W`6O00<1W`03
001oogoo09Eoo`007goo00<007ooOol0Ugoo00<007`0O0000g`000<0006O0Il00`6O00@007ooOol0
00El00030001W`6O00<1W`04001oogoo0005O0000`000Il1W`030Il01000Oomoo`001G`000<0006O
0Il00`6O00@007ooOol000El00030001W`6O00<1W`04001oogoo0005O0000`000Il1W`030Il00`00
Oomoo`0?Ool00`00O01l0003O0000`000Il1W`030Il00`00Oomoo`2EOol001moo`03001oogoo09Mo
o`03001l07`000=l00030001W`6O00<1W`04001oogoo0005O0000`000Il1W`030Il01000Oomoo`00
1G`000<0006O0Il00`6O00@007ooOol000El00030001W`6O00<1W`04001oogoo0005O0000`000Il1
W`030Il01000Oomoo`001G`000<0006O0Il00`6O00<007ooOol03goo00<007`0O0000g`000<0006O
0Il00`6O00<007ooOol0UGoo000OOol00`00Oomoo`2GOol00`00O01l0003O0000`000Il1W`030Il0
1000Oomoo`001G`000<0006O0Il00`6O00@007ooOol000El00030001W`6O00<1W`04001oogoo0005
O0000`000Il1W`030Il01000Oomoo`001G`000<0006O0Il00`6O00@007ooOol000El00030001W`6O
00<1W`03001oogoo00moo`03001l07`000=l00030001W`6O00<1W`03001oogoo09Eoo`007goo00<0
07ooOol0Ugoo00<007`0O0000g`000<0006O0Il00`6O00@007ooOol000El00030001W`6O00<1W`04
001oogoo0005O0000`000Il1W`030Il01000Oomoo`001G`000<0006O0Il00`6O00@007ooOol000El
00030001W`6O00<1W`04001oogoo0005O0000`000Il1W`030Il00`00Oomoo`0?Ool00`00O01l0003
O0000`000Il1W`030Il00`00Oomoo`2EOol001moo`03001oogoo09Moo`03001l07`000=l00030001
W`6O00<1W`04001oogoo0005O0000`000Il1W`030Il01000Oomoo`001G`000<0006O0Il00`6O00@0
07ooOol000El00030001W`6O00<1W`04001oogoo0005O0000`000Il1W`030Il01000Oomoo`001G`0
00<0006O0Il00`6O00<007ooOol03goo00<007`0O0000g`000<0006O0Il00`6O00<007ooOol0UGoo
000OOol00`00Oomoo`2GOol00`00O01l0003O0000`000Il1W`030Il01000Oomoo`001G`000<0006O
0Il00`6O00@007ooOol000El00030001W`6O00<1W`04001oogoo0005O0000`000Il1W`030Il01000
Oomoo`001G`000<0006O0Il00`6O00@007ooOol000El00030001W`6O00<1W`03001oogoo00moo`03
001l07`000=l00030001W`6O00<1W`03001oogoo09Eoo`007goo00<007ooOol0Ugoo00<007`0O000
0g`000<0006O0Il00`6O00@007ooOol000El00030001W`6O00<1W`04001oogoo0005O0000`000Il1
W`030Il01000Oomoo`001G`000<0006O0Il00`6O00@007ooOol000El00030001W`6O00<1W`04001o
ogoo0005O0000`000Il1W`030Il00`00Oomoo`0?Ool00`00O01l0003O0000`000Il1W`030Il00`00
Oomoo`2EOol001moo`03001oogoo09Moo`03001l07`000=l00030001W`6O00<1W`04001oogoo0005
O0000`000Il1W`030Il01000Oomoo`001G`000<0006O0Il00`6O00@007ooOol000El00030001W`6O
00<1W`04001oogoo0005O0000`000Il1W`030Il01000Oomoo`001G`000<0006O0Il00`6O00<007oo
Ool03goo00<007`0O0000g`000<0006O0Il00`6O00<007ooOol0UGoo000OOol00`00Oomoo`2GOol0
0`00O01l0003O0000`000Il1W`030Il01000Oomoo`001G`000<0006O0Il00`6O00@007ooOol000El
00030001W`6O00<1W`04001oogoo0005O0000`000Il1W`030Il01000Oomoo`001G`000<0006O0Il0
0`6O00@007ooOol000El00030001W`6O00<1W`03001oogoo00moo`03001l07`000=l00030001W`6O
00<1W`03001oogoo09Eoo`007goo0`00Ugoo00<007`0O0000g`000<0006O0Il00`6O00@007ooOol0
00El00030001W`6O00<1W`04001oogoo0005O0000`000Il1W`030Il01000Oomoo`001G`000<0006O
0Il00`6O00@007ooOol000El00030001W`6O00<1W`04001oogoo0005O0000`000Il1W`030Il00`00
Oomoo`0?Ool00`00O01l0003O0000`000Il1W`030Il00`00Oomoo`2EOol001moo`03001oogoo09Mo
o`03001l07`000=l00030001W`6O00<1W`04001oogoo0005O0000`000Il1W`030Il01000Oomoo`00
1G`000<0006O0Il00`6O00@007ooOol000El00030001W`6O00<1W`04001oogoo0005O0000`000Il1
W`030Il01000Oomoo`001G`000<0006O0Il00`6O00<007ooOol03goo00<007`0O0000g`000<0006O
0Il00`6O00<007ooOol0UGoo000OOol00`00Oomoo`2GOol00`00O01l0003O0000`000Il1W`030Il0
1000Oomoo`001G`000<0006O0Il00`6O00@007ooOol000El00030001W`6O00<1W`04001oogoo0005
O0000`000Il1W`030Il01000Oomoo`001G`000<0006O0Il00`6O00@007ooOol000El00030001W`6O
00<1W`03001oogoo00moo`03001l07`000=l00030001W`6O00<1W`03001oogoo09Eoo`007goo00<0
07ooOol0Ugoo00<007`0O0000g`000<0006O0Il00`6O00@007ooOol000El00030001W`6O00<1W`04
001oogoo0005O0000`000Il1W`030Il01000Oomoo`001G`000<0006O0Il00`6O00@007ooOol000El
00030001W`6O00<1W`04001oogoo0005O0000`000Il1W`030Il00`00Oomoo`0?Ool00`00O01l0003
O0000`000Il1W`030Il00`00Oomoo`2EOol001moo`03001oogoo09Moo`03001l07`000=l00030001
W`6O00<1W`04001oogoo0005O0000`000Il1W`030Il01000Oomoo`001G`000<0006O0Il00`6O00@0
07ooOol000El00030001W`6O00<1W`04001oogoo0005O0000`000Il1W`030Il01000Oomoo`001G`0
00<0006O0Il00`6O00<007ooOol03goo00<007`0O0000g`000<0006O0Il00`6O00<007ooOol0UGoo
000OOol00`00Oomoo`2GOol00`00O01l0003O0000`000Il1W`030Il01000Oomoo`001G`000<0006O
0Il00`6O00@007ooOol000El00030001W`6O00<1W`04001oogoo0005O0000`000Il1W`030Il01000
Oomoo`001G`000<0006O0Il00`6O00@007ooOol000El00030001W`6O00<1W`03001oogoo00moo`03
001l07`000=l00030001W`6O00<1W`03001oogoo09Eoo`007goo00<007ooOol0Ugoo00<007`0O000
0g`000<0006O0Il00`6O00@007ooOol000El00030001W`6O00<1W`04001oogoo0005O0000`000Il1
W`030Il01000Oomoo`001G`000<0006O0Il00`6O00@007ooOol000El00030001W`6O00<1W`04001o
ogoo0005O0000`000Il1W`030Il00`00Oomoo`0?Ool00`00O01l0003O0000`000Il1W`030Il00`00
Oomoo`2EOol001moo`03001oogoo09Moo`03001l07`000=l00030001W`6O00<1W`04001oogoo0005
O0000`000Il1W`030Il01000Oomoo`001G`000<0006O0Il00`6O00@007ooOol000El00030001W`6O
00<1W`04001oogoo0005O0000`000Il1W`030Il01000Oomoo`001G`000<0006O0Il00`6O00<007oo
Ool03goo00<007`0O0000g`000<0006O0Il00`6O00<007ooOol0UGoo000OOol00`00Oomoo`2GOol0
0`00O01l0003O0000`000Il1W`030Il01000Oomoo`001G`000<0006O0Il00`6O00@007ooOol000El
00030001W`6O00<1W`04001oogoo0005O0000`000Il1W`030Il01000Oomoo`001G`000<0006O0Il0
0`6O00@007ooOol000El00030001W`6O00<1W`03001oogoo00moo`03001l07`000=l00030001W`6O
00<1W`03001oogoo09Eoo`007goo00<007ooOol0Ugoo00<007`0O0000g`000<0006O0Il00`6O00@0
07ooOol000El00030001W`6O00<1W`04001oogoo0005O0000`000Il1W`030Il01000Oomoo`001G`0
00<0006O0Il00`6O00@007ooOol000El00030001W`6O00<1W`04001oogoo0005O0000`000Il1W`03
0Il00`00Oomoo`0?Ool00`00O01l0003O0000`000Il1W`030Il00`00Oomoo`2EOol001moo`03001o
ogoo09Moo`03001l07`000=l00030001W`6O00<1W`04001oogoo0005O0000`000Il1W`030Il01000
Oomoo`001G`000<0006O0Il00`6O00@007ooOol000El00030001W`6O00<1W`04001oogoo0005O000
0`000Il1W`030Il01000Oomoo`001G`000<0006O0Il00`6O00<007ooOol03goo00<007`0O0000g`0
00<0006O0Il00`6O00<007ooOol0UGoo000OOol00`00Oomoo`2GOol00`00O01l0003O0000`000Il1
W`030Il01000Oomoo`001G`000<0006O0Il00`6O00@007ooOol000El00030001W`6O00<1W`04001o
ogoo0005O0000`000Il1W`030Il01000Oomoo`001G`000<0006O0Il00`6O00@007ooOol000El0003
0001W`6O00<1W`03001oogoo00moo`03001l07`000=l00030001W`6O00<1W`03001oogoo09Eoo`00
7goo00<007ooOol0Ugoo00<007`0O0000g`000<0006O0Il00`6O00@007ooOol000El00030001W`6O
00<1W`04001oogoo0005O0000`000Il1W`030Il01000Oomoo`001G`000<0006O0Il00`6O00@007oo
Ool000El00030001W`6O00<1W`04001oogoo0005O0000`000Il1W`030Il00`00Oomoo`0?Ool00`00
O01l0003O0000`000Il1W`030Il00`00Oomoo`2EOol001moo`<009Moo`03001l07`000=l00030001
W`6O00<1W`04001oogoo0005O0000`000Il1W`030Il01000Oomoo`001G`000<0006O0Il00`6O00@0
07ooOol000El00030001W`6O00<1W`04001oogoo0005O0000`000Il1W`030Il01000Oomoo`001G`0
00<0006O0Il00`6O00<007ooOol03goo00<007`0O0000g`000<0006O0Il00`6O00<007ooOol0UGoo
000OOol00`00Oomoo`2GOol00`00O01l0003O0000`000Il1W`030Il01000Oomoo`001G`000<0006O
0Il00`6O00@007ooOol000El00030001W`6O00<1W`04001oogoo0005O0000`000Il1W`030Il01000
Oomoo`001G`000<0006O0Il00`6O00@007ooOol000El00030001W`6O00<1W`03001oogoo00moo`03
001l07`000=l00030001W`6O00<1W`03001oogoo09Eoo`007goo00<007ooOol0Ugoo00<007`0O000
0g`000<0006O0Il00`6O00@007ooOol000El00030001W`6O00<1W`04001oogoo0005O0000`000Il1
W`030Il01000Oomoo`001G`000<0006O0Il00`6O00@007ooOol000El00030001W`6O00<1W`04001o
ogoo0005O0000`000Il1W`030Il00`00Oomoo`0?Ool00`00O01l0003O007002GOol001moo`03001o
ogoo09Moo`03001l07`000=l00030001W`6O00<1W`04001oogoo0005O0000`000Il1W`030Il01000
Oomoo`001G`000<0006O0Il00`6O00@007ooOol000El00030001W`6O00<1W`04001oogoo0005O000
0`000Il1W`030Il01000Oomoo`001G`000<0006O0Il00`6O00<007ooOol03goo00<007`0O0000g`0
00<007ooOol0Vgoo000OOol00`00Oomoo`2GOol00`00O01l0003O0000`000Il1W`030Il01000Oomo
o`001G`000<0006O0Il00`6O00@007ooOol000El00030001W`6O00<1W`04001oogoo0005O0000`00
0Il1W`030Il01000Oomoo`001G`000<0006O0Il00`6O00@007ooOol000El00030001W`6O00<1W`03
001oogoo00moo`03001l07`000=l0003001oogoo09]oo`007goo00<007ooOol0Ugoo00<007`0O000
0g`000<0006O0Il00`6O00@007ooOol000El00030001W`6O00<1W`04001oogoo0005O0000`000Il1
W`030Il01000Oomoo`001G`000<0006O0Il00`6O00@007ooOol000El00030001W`6O00<1W`04001o
ogoo0005O0000`000Il1W`030Il00`00Oomoo`0?Ool00`00O01l0003O0000`00Oomoo`2KOol001mo
o`03001oogoo09Moo`03001l07`000=l00030001W`6O00<1W`04001oogoo0005O0000`000Il1W`03
0Il01000Oomoo`001G`000<0006O0Il00`6O00@007ooOol000El00030001W`6O00<1W`04001oogoo
0005O0000`000Il1W`030Il01000Oomoo`001G`000<0006O0Il00`6O00<007ooOol03goo00<007`0
O0000g`000<007ooOol0Vgoo000OOol00`00Oomoo`2GOol00`00O01l0003O0000`000Il1W`030Il0
1000Oomoo`001G`000<0006O0Il00`6O00@007ooOol000El00030001W`6O00<1W`04001oogoo0005
O0000`000Il1W`030Il01000Oomoo`001G`000<0006O0Il00`6O00@007ooOol000El00030001W`6O
00<1W`03001oogoo00moo`03001l07`000=l0003001oogoo09]oo`007goo00<007ooOol0Ugoo00<0
07`0O0000g`000<0006O0Il00`6O00@007ooOol000El00030001W`6O00<1W`04001oogoo0005O000
0`000Il1W`030Il01000Oomoo`001G`000<0006O0Il00`6O00@007ooOol000El00030001W`6O00<1
W`04001oogoo0005O0000`000Il1W`030Il00`00Oomoo`0?Ool00`00O01l0003O0000`00Oomoo`2K
Ool001moo`03001oogoo09Moo`03001l07`000=l00030001W`6O00<1W`04001oogoo0005O0000`00
0Il1W`030Il01000Oomoo`001G`000<0006O0Il00`6O00@007ooOol000El00030001W`6O00<1W`04
001oogoo0005O0000`000Il1W`030Il01000Oomoo`001G`000<0006O0Il00`6O00<007ooOol03goo
00<007`0O0000g`000<007ooOol0Vgoo000OOol00`00Oomoo`2GOol00`00O01l0003O0000`000Il1
W`030Il01000Oomoo`001G`000<0006O0Il00`6O00@007ooOol000El00030001W`6O00<1W`04001o
ogoo0005O0000`000Il1W`030Il01000Oomoo`001G`000<0006O0Il00`6O00@007ooOol000El0003
0001W`6O00<1W`03001oogoo00moo`03001l07`000=l0003001oogoo09]oo`007goo00<007ooOol0
Ugoo00<007`0O0000g`000<0006O0Il00`6O00@007ooOol000El00030001W`6O00<1W`04001oogoo
0005O0000`000Il1W`030Il01000Oomoo`001G`000<0006O0Il00`6O00@007ooOol000El00030001
W`6O00<1W`04001oogoo0005O0000`000Il1W`030Il00`00Oomoo`0?Ool00`00O01l0003O0000`00
Oomoo`2KOol001moo`03001oogoo09Moo`03001l07`000=l00030001W`6O00<1W`04001oogoo0005
O0000`000Il1W`030Il01000Oomoo`001G`000<0006O0Il00`6O00@007ooOol000El00030001W`6O
00<1W`04001oogoo0005O0000`000Il1W`030Il01000Oomoo`001G`000<0006O0Il00`6O00<007oo
Ool03goo00<007`0O0000g`000<007ooOol0Vgoo000OOol3002GOol00`00O01l0003O0000`000Il1
W`030Il01000Oomoo`001G`000<0006O0Il00`6O00@007ooOol000El00030001W`6O00<1W`04001o
ogoo0005O0000`000Il1W`030Il01000Oomoo`001G`000<0006O0Il00`6O00@007ooOol000El0003
0001W`6O00<1W`03001oogoo00moo`03001l07`000=l0003001oogoo09]oo`007goo00<007ooOol0
Ugoo00<007`0O0000g`000<0006O0Il00`6O00@007ooOol000El00030001W`6O00<1W`04001oogoo
0005O0000`000Il1W`030Il01000Oomoo`001G`000<0006O0Il00`6O00@007ooOol000El00030001
W`6O00<1W`04001oogoo0005O0000`000Il1W`030Il00`00Oomoo`0?Ool00`00O01l0003O0000`00
Oomoo`2KOol001moo`03001oogoo09Moo`03001l07`000=l00030001W`6O00<1W`04001oogoo0005
O0000`000Il1W`030Il01000Oomoo`001G`000<0006O0Il00`6O00@007ooOol000El00030001W`6O
00<1W`04001oogoo0005O0000`000Il1W`030Il01000Oomoo`001G`000<0006O0Il00`6O00<007oo
Ool03goo00<007`0O0000g`000<007ooOol0Vgoo000OOol00`00Oomoo`2GOol00`00O01l0003O000
0`000Il1W`030Il01000Oomoo`001G`000<0006O0Il00`6O00@007ooOol000El00030001W`6O00<1
W`04001oogoo0005O0000`000Il1W`030Il01000Oomoo`001G`000<0006O0Il00`6O00@007ooOol0
00El00030001W`6O00<1W`03001oogoo00moo`03001l07`000=l0003001oogoo09]oo`007goo00<0
07ooOol0Ugoo00<007`0O0000g`000<0006O0Il00`6O00@007ooOol000El00030001W`6O00<1W`04
001oogoo0005O0000`000Il1W`030Il01000Oomoo`001G`000<0006O0Il00`6O00@007ooOol000El
00030001W`6O00<1W`04001oogoo0005O0000`000Il1W`030Il00`00Oomoo`0?Ool00`00O01l0003
O0000`00Oomoo`2KOol001moo`03001oogoo09Moo`03001l07`000=l00030001W`6O00<1W`04001o
ogoo0005O0000`000Il1W`030Il01000Oomoo`001G`000<0006O0Il00`6O00@007ooOol000El0003
0001W`6O00<1W`04001oogoo0005O0000`000Il1W`030Il01000Oomoo`001G`000<0006O0Il00`6O
00<007ooOol03goo00<007`0O0000g`000<007ooOol0Vgoo000OOol00`00Oomoo`2GOol00`00O01l
0003O0000`000Il1W`030Il01000Oomoo`001G`000<0006O0Il00`6O00@007ooOol000El00030001
W`6O00<1W`04001oogoo0005O0000`000Il1W`030Il01000Oomoo`001G`000<0006O0Il00`6O00@0
07ooOol000El00030001W`6O00<1W`03001oogoo00moo`03001l07`000=l0003001oogoo09]oo`00
7goo00<007ooOol0Ugoo00<007`0O0000g`000<0006O0Il00`6O00@007ooOol000El00030001W`6O
00<1W`04001oogoo0005O0000`000Il1W`030Il01000Oomoo`001G`000<0006O0Il00`6O00@007oo
Ool000El00030001W`6O00<1W`04001oogoo0005O0000`000Il1W`030Il00`00Oomoo`0?Ool00`00
O01l0003O0000`00Oomoo`2KOol001moo`03001oogoo09Moo`03001l07`000=l00030001W`6O00<1
W`04001oogoo0005O0000`000Il1W`030Il01000Oomoo`001G`000<0006O0Il00`6O00@007ooOol0
00El00030001W`6O00<1W`04001oogoo0005O0000`000Il1W`030Il01000Oomoo`001G`000<0006O
0Il00`6O00<007ooOol03goo00<007`0O0000g`000<007ooOol0Vgoo000OOol00`00Oomoo`2GOol0
0`00O01l0003O0000`000Il1W`030Il01000Oomoo`001G`000<0006O0Il00`6O00@007ooOol000El
00030001W`6O00<1W`04001oogoo0005O0000`000Il1W`030Il01000Oomoo`001G`000<0006O0Il0
0`6O00@007ooOol000El00030001W`6O00<1W`03001oogoo00moo`03001l07`000=l0003001oogoo
09]oo`007goo00<007ooOol0Ugoo00<007`0O0000g`000<0006O0Il00`6O00@007ooOol000El0003
0001W`6O00<1W`04001oogoo0005O0000`000Il1W`030Il00`00Oomoo`0700050Il01000Oomoo`00
1G`000<0006O0Il00`6O00@007ooOol000El00030001W`6O00<1W`03001oogoo00moo`03001l07`0
00=l0003001oogoo09]oo`0047oo0P0017oo0P001goo00<007ooOol0Ugoo00<007`0O0000g`000<0
006O0Il00`6O00@007ooOol000El00030001W`6O00<1W`04001oogoo0005O0000`000Il1W`030Il0
0`00Oomoo`06Ool00`000Il1W`030Il01000Oomoo`001G`000<0006O0Il00`6O00@007ooOol000El
00030001W`6O00<1W`03001oogoo00moo`03001l07`000=l0003001oogoo09]oo`003goo00@007oo
Ool0009oo`04001oogoo0006Ool00`00Oomoo`2GOol00`00O01l0003O0000`000Il1W`030Il01000
Oomoo`001G`000<0006O0Il00`6O00@007ooOol000El00030001W`6O00<1W`03001oogoo00Ioo`03
0001W`6O00<1W`04001oogoo0005O0000`000Il1W`030Il01000Oomoo`001G`000<0006O0Il00`6O
00<007ooOol03goo00<007`0O0000g`000<007ooOol0Vgoo000?Ool01000Oomoo`000Woo00@007oo
Ool000Ioo`@009Ioo`L000D1W`04001oogoo0005O0000`000Il1W`030Il01000Oomoo`001G`000<0
006O0Il00`6O00<007ooOol01Woo00<0006O0Il00`6O00@007ooOol000El00030001W`6O00<1W`04
001oogoo0005O0000`000Il1W`030Il00`00Oomoo`0?Ool00`00O01l0003O0000`00Oomoo`2KOol0
011oo`8000=oo`04001oogoo0006Ool00`00Oomoo`2MOol00`000Il1W`030Il01000Oomoo`001G`0
00<0006O0Il00`6O00@007ooOol000El00030001W`6O00<1W`03001oogoo00Ioo`030001W`6O00<1
W`04001oogoo0005O0000`000Il1W`030Il01000Oomoo`001G`000<0006O0Il00`6O00<007ooOol0
3goo00<007`0O0000g`000<007ooOol0Vgoo000?Ool01000Oomoo`000Woo00@007ooOol000Ioo`03
001oogoo09eoo`030001W`6O00<1W`04001oogoo0005O0000`000Il1W`030Il01000Oomoo`001G`0
1`0027oo00<0006O0Il00`6O00@007ooOol000El00030001W`6O00<1W`04001oogoo0005O0000`00
0Il1W`030Il00`00Oomoo`0?Ool00`00O01l0003O0000`00Oomoo`2KOol0011oo`8000Aoo`8000Mo
o`03001oogoo09eoo`030001W`6O00<1W`04001oogoo0005O0000`000Il1W`030Il01000Oomoo`00
1G`000<007ooOol037oo00<0006O0Il00`6O00@007ooOol000El00030001W`6O00<1W`04001oogoo
0005O0000`000Il1W`030Il00`00Oomoo`0?Ool00`00O01l0003O0000`00Oomoo`2KOol001moo`03
001oogoo09eoo`030001W`6O00<1W`04001oogoo0005O0000`000Il1W`030Il01000Oomoo`001G`0
00<007ooOol037oo00<0006O0Il00`6O00@007ooOol000El00030001W`6O00<1W`04001oogoo0005
O0000`000Il1W`030Il00`00Oomoo`0?Ool00`00O01l0003O0000`00Oomoo`2KOol001moo`03001o
ogoo09eoo`030001W`6O00<1W`04001oogoo0005O0000`000Il1W`030Il01000Oomoo`001G`000<0
07ooOol037oo00<0006O0Il00`6O00@007ooOol000El00030001W`6O00<1W`04001oogoo0005O000
0`000Il1W`030Il00`00Oomoo`0?Ool00`00O01l0003O0000`00Oomoo`2KOol001moo`03001oogoo
09eoo`030001W`6O00<1W`04001oogoo0005O0000`000Il1W`030Il01000Oomoo`001G`000<007oo
Ool037oo00<0006O0Il00`6O00@007ooOol000El00030001W`6O00<1W`04001oogoo0005O0000`00
0Il1W`030Il00`00Oomoo`0?Ool00`00O01l0003O0000`00Oomoo`2KOol001moo`03001oogoo09eo
o`030001W`6O00<1W`04001oogoo0005O0000`000Il1W`030Il01000Oomoo`001G`000<007ooOol0
37oo00<0006O0Il00`6O00@007ooOol000El00030001W`6O00<1W`04001oogoo0005O0000`000Il1
W`030Il00`00Oomoo`0?Ool00`00O01l0003O0000`00Oomoo`2KOol001moo`03001oogoo09eoo`03
0001W`6O00<1W`04001oogoo0005O0000`000Il1W`030Il01000Oomoo`001G`000<007ooOol037oo
00<0006O0Il00`6O00@007ooOol000El00030001W`6O00<1W`04001oogoo0005O0000`000Il1W`03
0Il00`00Oomoo`0?Ool00`00O01l0003O0000`00Oomoo`2KOol001moo`03001oogoo09eoo`030001
W`6O00<1W`04001oogoo0005O0000`000Il1W`030Il01000Oomoo`001G`000<007ooOol037oo00<0
006O0Il00`6O00@007ooOol000El00030001W`6O00<1W`04001oogoo0005O0000`000Il1W`030Il0
0`00Oomoo`0?Ool00`00O01l0003O0000`00Oomoo`2KOol001moo`03001oogoo09eoo`030001W`6O
00<1W`04001oogoo0005O0000`000Il1W`030Il01000Oomoo`001G`000<007ooOol037oo00<0006O
0Il00`6O00@007ooOol000El00030001W`6O00<1W`04001oogoo0005O0000`000Il1W`030Il00`00
Oomoo`0?Ool00`00O01l0003O0000`00Oomoo`2KOol001moo`03001oogoo09eoo`030001W`6O00<1
W`04001oogoo0005O0000`000Il1W`030Il01000Oomoo`001G`000<007ooOol037oo00<0006O0Il0
0`6O00@007ooOol000El00030001W`6O00<1W`04001oogoo0005O0000`000Il1W`030Il00`00Oomo
o`0?Ool00`00O01l0003O0000`00Oomoo`2KOol001moo`03001oogoo09eoo`030001W`6O00<1W`04
001oogoo0005O0000`000Il1W`030Il01000Oomoo`001G`000<007ooOol037oo00<0006O0Il00`6O
00@007ooOol000El00030001W`6O00<1W`04001oogoo0005O0000`000Il1W`030Il00`00Oomoo`0?
Ool00`00O01l0003O0000`00Oomoo`2KOol001moo`<009eoo`030001W`6O00<1W`04001oogoo0005
O0000`000Il1W`030Il01000Oomoo`001G`000<007ooOol037oo00<0006O0Il00`6O00@007ooOol0
00El00030001W`6O00<1W`04001oogoo0005O0000`000Il1W`030Il00`00Oomoo`0?Ool00`00O01l
0003O0000`00Oomoo`2KOol001moo`03001oogoo09eoo`030001W`6O00<1W`04001oogoo0005O000
0`000Il1W`030Il01000Oomoo`001G`000<007ooOol037oo00<0006O0Il00`6O00@007ooOol000El
00030001W`6O00<1W`04001oogoo0005O0000`000Il1W`030Il00`00Oomoo`0?Ool00`00O01l0003
O0000`00Oomoo`2KOol001moo`03001oogoo09eoo`030001W`6O00<1W`04001oogoo0005O0000`00
0Il1W`030Il01000Oomoo`001G`000<007ooOol037oo00<0006O0Il00`6O00@007ooOol000El0003
0001W`6O00<1W`04001oogoo0005O0000`000Il1W`030Il00`00Oomoo`0?Ool00`00O01l0003O000
0`00Oomoo`2KOol001moo`03001oogoo09eoo`030001W`6O00<1W`04001oogoo0005O0000`000Il1
W`030Il01000Oomoo`001G`000<007ooOol037oo00<0006O0Il00`6O00@007ooOol000El00030001
W`6O00<1W`04001oogoo0005O0000`000Il1W`030Il00`00Oomoo`0?Ool00`00O01l0003O0000`00
Oomoo`2KOol001moo`03001oogoo09eoo`030001W`6O00<1W`04001oogoo0005O0000`000Il1W`03
0Il01000Oomoo`001G`000<007ooOol037oo00<0006O0Il00`6O00@007ooOol000El00030001W`6O
00<1W`04001oogoo0005O0000`000Il1W`030Il00`00Oomoo`0?Ool00`00O01l0003O0000`00Oomo
o`2KOol001moo`03001oogoo09eoo`L0009oo`03001l07`000=l00030001W`6O00<1W`04001oogoo
0005O0000`00Oomoo`0<Ool00`000Il1W`030Il01000Oomoo`001G`000<0006O0Il00`6O00@007oo
Ool000El00030001W`6O00<1W`03001oogoo00moo`L009eoo`007goo00<007ooOol0YWoo00<007`0
O0000g`000<0006O0Il00`6O00@007ooOol000El0003001oogoo00aoo`030001W`6O00<1W`04001o
ogoo0005O0000`000Il1W`030Il01000Oomoo`001G`000<0006O0Il00`6O00<007ooOol0/goo000O
Ool00`00Oomoo`2VOol00`00O01l0003O0000`000Il1W`030Il01000Oomoo`001G`000<007ooOol0
37oo00<0006O0Il00`6O00@007ooOol000El00030001W`6O00<1W`04001oogoo0005O0000`000Il1
W`030Il00`00Oomoo`2cOol001moo`03001oogoo0:Ioo`03001l07`000=l00030001W`6O00<1W`04
001oogoo0005O0000`00Oomoo`0<Ool00`000Il1W`030Il01000Oomoo`001G`000<0006O0Il00`6O
00@007ooOol000El00030001W`6O00<1W`03001oogoo0;=oo`007goo00<007ooOol0YWoo00<007`0
O0000g`000<0006O0Il00`6O00@007ooOol000El0003001oogoo00aoo`030001W`6O00<1W`04001o
ogoo0005O0000`000Il1W`030Il01000Oomoo`001G`000<0006O0Il00`6O00<007ooOol0/goo000O
Ool00`00Oomoo`2VOol00`00O01l0003O0000`000Il1W`030Il01000Oomoo`001G`000<007ooOol0
37oo00<0006O0Il00`6O00@007ooOol000El00030001W`6O00<1W`04001oogoo0005O0000`000Il1
W`030Il00`00Oomoo`2cOol001moo`03001oogoo0:Ioo`03001l07`000=l00030001W`6O00<1W`04
001oogoo0005O0000`00Oomoo`0<Ool00`000Il1W`030Il01000Oomoo`001G`000<0006O0Il00`6O
00@007ooOol000El00030001W`6O00<1W`03001oogoo0;=oo`007goo00<007ooOol0YWoo00<007`0
O0000g`000<0006O0Il00`6O00@007ooOol000El0003001oogoo00aoo`030001W`6O00<1W`04001o
ogoo0005O0000`000Il1W`030Il01000Oomoo`001G`000<0006O0Il00`6O00<007ooOol0/goo000O
Ool3002VOol00`00O01l0003O0000`000Il1W`030Il00`00Oomoo`07000>Ool00`000Il1W`030Il0
1000Oomoo`001G`000<0006O0Il00`6O00@007ooOol000El00030001W`6O00<1W`03001oogoo0;=o
o`007goo00<007ooOol0YWoo00<007`0O0000g`000<0006O0Il00`6O00<007ooOol05Goo00<0006O
0Il00`6O00@007ooOol000El00030001W`6O00<1W`04001oogoo0005O0000`000Il1W`030Il00`00
Oomoo`2cOol001moo`03001oogoo0:Ioo`03001l07`000=l00030001W`6O00<1W`03001oogoo01Eo
o`030001W`6O00<1W`04001oogoo0005O0000`000Il1W`030Il01000Oomoo`001G`000<0006O0Il0
0`6O00<007ooOol0/goo000OOol00`00Oomoo`2VOol700050Il00`00Oomoo`0EOol00`000Il1W`03
0Il00`00Oomoo`0700050Il01000Oomoo`001G`000<0006O0Il00`6O00<007ooOol0/goo000OOol0
0`00Oomoo`2/Ool00`000Il1W`030Il00`00Oomoo`0EOol00`000Il1W`030Il00`00Oomoo`06Ool0
0`000Il1W`030Il01000Oomoo`001G`000<0006O0Il00`6O00<007ooOol0/goo000OOol00`00Oomo
o`2/Ool00`000Il1W`030Il00`00Oomoo`0EOol00`000Il1W`030Il00`00Oomoo`06Ool00`000Il1
W`030Il01000Oomoo`001G`000<0006O0Il00`6O00<007ooOol0/goo000OOol00`00Oomoo`2/Ool0
0`000Il1W`030Il00`00Oomoo`0EOol00`000Il1W`030Il00`00Oomoo`06Ool00`000Il1W`030Il0
1000Oomoo`001G`000<0006O0Il00`6O00<007ooOol0/goo000OOol00`00Oomoo`2/Ool00`000Il1
W`030Il00`00Oomoo`0EOol00`000Il1W`030Il00`00Oomoo`06Ool00`000Il1W`030Il01000Oomo
o`001G`000<0006O0Il00`6O00<007ooOol0/goo000OOol00`00Oomoo`2/Ool7000GOol00`000Il1
W`030Il00`00Oomoo`06Ool00`000Il1W`030Il00`00Oomoo`0700050Il00`00Oomoo`2cOol001mo
o`03001oogoo0<Yoo`030001W`6O00<1W`03001oogoo00Ioo`030001W`6O00<1W`03001oogoo00Io
o`030001W`6O00<1W`03001oogoo0;=oo`007goo00<007ooOol0bWoo00<0006O0Il00`6O00<007oo
Ool01Woo00<0006O0Il00`6O00<007ooOol01Woo00<0006O0Il00`6O00<007ooOol0/goo000OOol0
0`00Oomoo`3:Ool00`000Il1W`030Il00`00Oomoo`06Ool00`000Il1W`030Il00`00Oomoo`06Ool0
0`000Il1W`030Il00`00Oomoo`2cOol001moo`03001oogoo0<Yoo`030001W`6O00<1W`03001oogoo
00Ioo`030001W`6O00<1W`03001oogoo00Ioo`030001W`6O00<1W`03001oogoo0;=oo`007goo0`00
bWoo00<0006O0Il00`6O00<007ooOol01Woo00<0006O0Il00`6O00<007ooOol01Woo00<0006O0Il0
0`6O00<007ooOol0/goo000OOol00`00Oomoo`3:Ool00`000Il1W`030Il00`00Oomoo`06Ool00`00
0Il1W`030Il00`00Oomoo`06Ool00`000Il1W`030Il00`00Oomoo`2cOol001moo`03001oogoo0<Yo
o`030001W`6O00<1W`03001oogoo00Ioo`030001W`6O00<1W`03001oogoo00Ioo`030001W`6O00<1
W`03001oogoo0;=oo`007goo00<007ooOol0bWoo00<0006O0Il00`6O00<007ooOol01Woo00<0006O
0Il00`6O00<007ooOol01Woo00<0006O0Il00`6O00<007ooOol0/goo000OOol00`00Oomoo`3:Ool0
0`000Il1W`030Il00`00Oomoo`06Ool00`000Il1W`030Il00`00Oomoo`06Ool00`000Il1W`030Il0
0`00Oomoo`2cOol001moo`03001oogoo0<Yoo`030001W`6O00<1W`03001oogoo00Ioo`L000Qoo`03
0001W`6O00<1W`03001oogoo0;=oo`007goo00<007ooOol0bWoo00<0006O0Il00`6O00<007ooOol0
5Goo00<0006O0Il00`6O00<007ooOol0/goo000OOol00`00Oomoo`3:Ool00`000Il1W`030Il00`00
Oomoo`0EOol00`000Il1W`030Il00`00Oomoo`2cOol001moo`03001oogoo0<Yoo`030001W`6O00<1
W`03001oogoo01Eoo`L00;Eoo`007goo00<007ooOol0bWoo00<0006O0Il00`6O00<007ooOol0dGoo
000OOol00`00Oomoo`3:Ool7003COol000Uoo`<000Aoo`8000Aoo`8000Moo`03001oogoo0?moojEo
o`002Woo00<007ooOol00Woo00@007ooOol0009oo`04001oogoo0006Ool00`00Oomoo`3oOonUOol0
00Yoo`03001oogoo009oo`04001oogoo0002Ool01000Oomoo`001Woo1000ogooY7oo000:Ool00`00
Oomoo`02Ool01000Oomoo`000Woo00@007ooOol00?moojioo`002Woo00<007ooOol00Woo00@007oo
Ool0009oo`04001oogoo003oOon^Ool000Uoo`8000Eoo`8000Aoo`800?moojmoo`00ogooagoo0000
\
\>"],
  ImageRangeCache->{{{0, 453}, {279.438, 0}} -> {-1.50932, -5.47577, 
  0.0663878, 0.383635}}]
}, Closed]]
}, Open  ]]
},
FrontEndVersion->"4.0 for Macintosh",
ScreenRectangle->{{0, 1024}, {0, 748}},
WindowSize->{520, 653},
WindowMargins->{{Automatic, -8}, {Automatic, -1}},
StyleDefinitions -> "HelpBrowser.nb",
MacintoshSystemPageSetup->"\<\
00`0001804P000000_02@?o/onh3109BI085:0?l0@00005X0FP000003[0;@001
0000I00100000@0000000BL?0040000000000000000000000000000000000?nL
ojH?50^J00P100000000000000000000\>"
]


(***********************************************************************
Cached data follows.  If you edit this Notebook file directly, not using
Mathematica, you must remove the line containing CacheID at the top of 
the file.  The cache data will then be recreated when you save this file 
from within Mathematica.
***********************************************************************)

(*CellTagsOutline
CellTagsIndex->{
  "Stochastic GT algorithm"->{
    Cell[1739, 51, 106, 1, 36, "SubsectionIcon",
      CellTags->"Stochastic GT algorithm"]},
  "MonteCarloGriffithsTavare"->{
    Cell[1848, 54, 729, 12, 124, "DefinitionBox",
      CellTags->"MonteCarloGriffithsTavare"]},
  "Small example"->{
    Cell[63252, 1913, 70, 1, 36, "SubsectionIcon",
      CellTags->"Small example"]},
  "Comparison with MonteCarloProbability"->{
    Cell[349065, 10934, 118, 1, 36, "SubsectionIcon",
      CellTags->"Comparison with MonteCarloProbability"]}
  }
*)

(*CellTagsIndex
CellTagsIndex->{
  {"Stochastic GT algorithm", 563570, 15642},
  {"MonteCarloGriffithsTavare", 563697, 15645},
  {"Small example", 563815, 15648},
  {"Comparison with MonteCarloProbability", 563946, 15651}
  }
*)

(*NotebookFileOutline
Notebook[{

Cell[CellGroupData[{
Cell[1739, 51, 106, 1, 36, "SubsectionIcon",
  CellTags->"Stochastic GT algorithm"],
Cell[1848, 54, 729, 12, 124, "DefinitionBox",
  CellTags->"MonteCarloGriffithsTavare"],
Cell[2580, 68, 95, 3, 28, "MathCaption"],

Cell[CellGroupData[{
Cell[2700, 75, 377, 10, 73, "Input"],
Cell[3080, 87, 8791, 228, 184, 3029, 152, "GraphicsData", "PostScript", \
"Graphics"]
}, Closed]],
Cell[11886, 318, 248, 8, 32, "Text"],
Cell[12137, 328, 74, 0, 28, "MathCaption"],

Cell[CellGroupData[{
Cell[12236, 332, 383, 7, 67, "Input"],
Cell[12622, 341, 276, 5, 40, "Output"]
}, Closed]],
Cell[12913, 349, 1688, 40, 107, "Text"],
Cell[14604, 391, 1072, 21, 152, "Text"],
Cell[15679, 414, 122, 3, 42, "MathCaption"],
Cell[15804, 419, 133, 3, 27, "Input"],
Cell[15940, 424, 2148, 51, 142, "Text"],

Cell[CellGroupData[{
Cell[18113, 479, 79, 2, 27, "Input"],
Cell[18195, 483, 537, 10, 40, "Output"]
}, Closed]],
Cell[18747, 496, 138, 3, 18, "MathCaption"],

Cell[CellGroupData[{
Cell[18910, 503, 343, 7, 72, "Input"],
Cell[19256, 512, 42673, 1352, 311, 23237, 1107, "GraphicsData", "PostScript", \
"Graphics"]
}, Closed]],
Cell[61944, 1867, 92, 3, 18, "MathCaption"],
Cell[62039, 1872, 134, 3, 27, "Input"],

Cell[CellGroupData[{
Cell[62198, 1879, 82, 2, 27, "Input"],
Cell[62283, 1883, 538, 10, 40, "Output"]
}, Closed]],
Cell[62836, 1896, 75, 0, 18, "MathCaption"],

Cell[CellGroupData[{
Cell[62936, 1900, 150, 3, 42, "Input"],
Cell[63089, 1905, 114, 2, 20, "Output"]
}, Closed]]
}, Open  ]],

Cell[CellGroupData[{
Cell[63252, 1913, 70, 1, 36, "SubsectionIcon",
  CellTags->"Small example"],
Cell[63325, 1916, 75, 0, 28, "MathCaption"],

Cell[CellGroupData[{
Cell[63425, 1920, 126, 3, 27, "Input"],
Cell[63554, 1925, 1017, 19, 95, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[64608, 1949, 164, 3, 53, "Input"],
Cell[64775, 1954, 14466, 390, 184, 5676, 276, "GraphicsData", "PostScript", \
"Graphics"],
Cell[79244, 2346, 382, 10, 46, "Output"]
}, Closed]],
Cell[79641, 2359, 62, 0, 18, "MathCaption"],

Cell[CellGroupData[{
Cell[79728, 2363, 100, 2, 27, "Input"],
Cell[79831, 2367, 1045, 17, 110, "Output"]
}, Closed]],
Cell[80891, 2387, 74, 0, 18, "MathCaption"],

Cell[CellGroupData[{
Cell[80990, 2391, 116, 2, 27, "Input"],
Cell[81109, 2395, 78, 2, 20, "Output"]
}, Closed]],
Cell[81202, 2400, 72, 0, 18, "MathCaption"],

Cell[CellGroupData[{
Cell[81299, 2404, 149, 3, 42, "Input"],
Cell[81451, 2409, 15066, 394, 192, 5612, 272, "GraphicsData", "PostScript", \
"Graphics"]
}, Closed]],
Cell[96532, 2806, 208, 4, 32, "Text"],

Cell[CellGroupData[{
Cell[96765, 2814, 158, 3, 27, "Input"],
Cell[96926, 2819, 93, 2, 20, "Output"]
}, Closed]],
Cell[97034, 2824, 418, 6, 60, "Text"],
Cell[97455, 2832, 178, 4, 42, "MathCaption"],

Cell[CellGroupData[{
Cell[97658, 2840, 137, 3, 27, "Input"],
Cell[97798, 2845, 96, 2, 20, "Output"]
}, Closed]],
Cell[97909, 2850, 70, 0, 18, "MathCaption"],
Cell[97982, 2852, 264, 6, 42, "Input"],
Cell[98249, 2860, 192, 3, 36, "Text"],

Cell[CellGroupData[{
Cell[98466, 2867, 173, 3, 44, "Input"],
Cell[98642, 2872, 175, 3, 22, "Output"]
}, Closed]],
Cell[98832, 2878, 140, 5, 18, "Text"],
Cell[98975, 2885, 156, 4, 42, "MathCaption"],
Cell[99134, 2891, 102, 2, 27, "Input"],

Cell[CellGroupData[{
Cell[99261, 2897, 292, 6, 57, "Input"],
Cell[99556, 2905, 44355, 1352, 328, 24286, 1099, "GraphicsData", \
"PostScript", "Graphics"]
}, Closed]],
Cell[143926, 4260, 161, 4, 32, "MathCaption"],

Cell[CellGroupData[{
Cell[144112, 4268, 257, 5, 57, "Input"],
Cell[144372, 4275, 149090, 4189, 344, 26721, 2673, "GraphicsData", \
"PostScript", "Graphics"]
}, Closed]],
Cell[293477, 8467, 113, 3, 18, "MathCaption"],

Cell[CellGroupData[{
Cell[293615, 8474, 187, 4, 43, "Input"],
Cell[293805, 8480, 55211, 2448, 373, 21338, 2025, "GraphicsData", \
"PostScript", "Graphics"]
}, Closed]]
}, Open  ]],

Cell[CellGroupData[{
Cell[349065, 10934, 118, 1, 36, "SubsectionIcon",
  CellTags->"Comparison with MonteCarloProbability"],
Cell[349186, 10937, 386, 7, 64, "Text"],
Cell[349575, 10946, 72, 0, 28, "MathCaption"],

Cell[CellGroupData[{
Cell[349672, 10950, 116, 2, 27, "Input"],
Cell[349791, 10954, 526, 12, 78, "Output"]
}, Closed]],
Cell[350332, 10969, 102, 3, 18, "MathCaption"],
Cell[350437, 10974, 228, 5, 42, "Input"],
Cell[350668, 10981, 186, 4, 42, "MathCaption"],
Cell[350857, 10987, 394, 8, 57, "Input"],
Cell[351254, 10997, 322, 7, 42, "Input"],
Cell[351579, 11006, 503, 9, 109, "Input"],

Cell[CellGroupData[{
Cell[352107, 11019, 74, 2, 27, "Input"],
Cell[352184, 11023, 2388, 61, 237, "Output"]
}, Closed]],
Cell[354587, 11087, 152, 4, 32, "Text"],
Cell[354742, 11093, 104, 3, 28, "MathCaption"],

Cell[CellGroupData[{
Cell[354871, 11100, 74, 2, 27, "Input"],
Cell[354948, 11104, 2388, 61, 237, "Output"]
}, Closed]],
Cell[357351, 11168, 51, 0, 18, "Text"],
Cell[357405, 11170, 462, 9, 66, "Text"],

Cell[CellGroupData[{
Cell[357892, 11183, 112, 2, 42, "Input"],
Cell[358007, 11187, 110, 2, 20, "Output"]
}, Closed]],
Cell[358132, 11192, 92, 3, 18, "Text"],
Cell[358227, 11197, 343, 6, 50, "Text"],
Cell[358573, 11205, 228, 5, 42, "Input"],

Cell[CellGroupData[{
Cell[358826, 11214, 235, 4, 42, "Input"],
Cell[359064, 11220, 80485, 1920, 314, 12481, 1075, "GraphicsData", \
"PostScript", "Graphics"]
}, Closed]],
Cell[439564, 13143, 163, 2, 32, "Text"],

Cell[CellGroupData[{
Cell[439752, 13149, 75, 2, 27, "Input"],
Cell[439830, 13153, 2387, 61, 237, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[442254, 13219, 75, 2, 23, "Input"],
Cell[442332, 13223, 2389, 61, 237, "Output"]
}, Closed]],
Cell[444736, 13287, 49, 0, 18, "Text"],

Cell[CellGroupData[{
Cell[444810, 13291, 237, 4, 42, "Input"],
Cell[445050, 13297, 117645, 2320, 287, 11668, 1006, "GraphicsData", \
"PostScript", "Graphics"]
}, Closed]]
}, Open  ]]
}
]
*)




(***********************************************************************
End of Mathematica Notebook file.
***********************************************************************)

