(************** Content-type: application/mathematica **************
                     CreatedBy='Mathematica 4.2'

                    Mathematica-Compatible Notebook

This notebook can be used with any Mathematica-compatible
application, such as Mathematica, MathReader or Publicon. The data
for the notebook starts with the line containing stars above.

To get the notebook into a Mathematica-compatible application, do
one of the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the
  application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing
the word CacheID, otherwise Mathematica-compatible applications may
try to use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
*******************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[    218409,       5778]*)
(*NotebookOutlinePosition[    257236,       7085]*)
(*  CellTagsIndexPosition[    257192,       7081]*)
(*WindowFrame->Normal*)



Notebook[{
Cell[BoxData[
    \(\(BeginPackage["\<Genealogies`Genealogies`\>", \
{"\<Statistics`DiscreteDistributions`\>", \
"\<Statistics`ContinuousDistributions`\>", \
"\<Statistics`DataManipulation`\>", "\<Statistics`DescriptiveStatistics`\>", \
"\<Utilities`RandomNumbers`\>", "\<Utilities`SetManipulation`\>", \
\[IndentingNewLine]"\<DiscreteMath`Combinatorica`\>", \
\[IndentingNewLine]"\<Graphics`Colors`\>"}];\)\)], "Input",
  PageWidth->PaperWidth,
  InitializationCell->True,
  AspectRatioFixed->False],

Cell[BoxData[
    \( (*\ There\ is\ a\ slight\ problem\ in\ this\ package, \ 
      in\ that\ notation\ such\ \(\(as\)\(\ \)\(\[Vee]\)\), \ \
\(\(\[Backslash]\)\(\ \)\(is\)\)\ not\ evaluated\ properly . \ \ Use\ Join, \ 
      TakeAway\ etc\ instead\ *) \)], "Input"],

Cell[CellGroupData[{

Cell[" Usage statements", "Section",
  Evaluatable->False,
  InitializationCell->True,
  AspectRatioFixed->False],

Cell[CellGroupData[{

Cell["Describing genealogies", "Subsection"],

Cell[CellGroupData[{

Cell["\<\
Node[i,{info},{Node[j,\[Ellipsis]],Node[k,\[Ellipsis]]}] denotes a \
node in a branching tree.  This node is labelled by the integer i; \
information on it is given by {info}.  The node has descendant nodes labelled \
j, k.  A terminal node (a leaf) is denoted by Node[i,{info},{}].\
\>", \
"Subsubsection"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(Node::usage = \
"\<Node[i,{info},{Node[j,\[Ellipsis]],Node[k,\[Ellipsis]]}] denotes a node in \
a branching tree.  This node is labelled by the integer i; information on it \
is given by {info}.  The node has descendant nodes labelled j, k.  A terminal \
node (a leaf) is denoted by Node[i,{info},{}].\>";\)\)], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(General::"spell" \(\(:\)\(\ \)\) 
      "Possible spelling error: new symbol name \"\!\(Node\)\" is similar to \
existing symbols \!\({Mode, None}\)."\)], "Message"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["\<\
NodeFunction is an option for CollapseGenealogy and MakeGenealogy \
which can be set to extract information about each node.\
\>", "Subsubsection"],

Cell[BoxData[
    \(\(NodeFunction::usage = "\<NodeFunction is an option for \
CollapseGenealogy and MakeGenealogy which can be set to extract information \
about each node.\>";\)\)], "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{

Cell["\<\
ExtractGenealogy[g,i] gives the genealogy that descends from node \
i.\
\>", "Subsubsection"],

Cell[BoxData[
    \(\(ExtractGenealogy::usage = "\<ExtractGenealogy[g,i] gives the \
genealogy that descends from node i.  For an ancestral graph, \
ExtractGenealogy[{AncestralLineage[\[Ellipsis]]\[Ellipsis]},x] generates the \
genealogy corresponding to map position x. InformationFunction->f generates \
an information list f[i,x]. ExtractGenealogy[{AncestralLineage[\[Ellipsis]]\
\[Ellipsis]}] generates the set of genealogies, applying to segments \
demarcated by Junctions[g].  All parts of the genome must have a single \
common ancestor.\>";\)\)], "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{

Cell["\<\
DeleteGenealogy[g,i] deletes the genealogy that descends from node \
i.\
\>", "Subsubsection"],

Cell[BoxData[
    \(\(DeleteGenealogy::usage = "\<DeleteGenealogy[g,i] deletes the \
genealogy that descends from node i.\>";\)\)], "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    FormBox[
      RowBox[{
      \(AddGenealogy[g\_1, g\_2, i, j, info]\ adds\ genealogy\ g\_2\ to\ 
          genealogy\ g\_1\), ",", " ", 
        \(immediately\ above\ existing\ node\ i\ of\ g\_1 . \ \ The\ new\ node
          \ is\ labelled\ j\), ",", " ", 
        RowBox[{"and", " ", "carries", " ", "information", " ", 
          RowBox[{
            StyleBox["info",
              FontSlant->"Italic"], "."}]}]}], TextForm]], "Subsubsection"],

Cell[BoxData[
    \(\(AddGenealogy::usage = \
\*"\"\<AddGenealogy[\!\(g\_1\),\!\(g\_2\),i,j,info] adds genealogy \!\(g\_2\) \
to genealogy \!\(g\_1\), immediately above existing node i of \!\(g\_1\).  \
The new node is labelled j.  The new node is labelled j, and carries \
information info.  If i=j, then \!\(g\_2\) is added to existing node i, and \
its information is unaltered.  Node i must be found once and only once within \
\!\(g\_1\).\>\"";\)\)], "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{

Cell["\<\
AddNode[g,i,k,info] adds a new node k immediately above existing \
node i of g.  The new node carries information info.  AddNode[g,i,j,k,info] \
adds a new node k between nodes i and j of an unrooted genealogy\
\>", \
"Subsubsection"],

Cell[BoxData[
    \(\(AddNode::usage = "\<AddNode[g,i,k,info] adds a new node k immediately \
above existing node i of g.  The new node carries information info.  \
AddNode[g,i,j,k,info] adds a new node k between nodes i and j of an unrooted \
genealogy.\>";\)\)], "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{

Cell["\<\
CondenseGenealogy[g] removes all nodes that have only one \
descendant.\
\>", "Subsubsection"],

Cell[BoxData[
    \(\(CondenseGenealogy::usage = "\<CondenseGenealogy[g] removes all nodes \
that have only one descendant. However, the root node is not affected. \>";\)\
\)], "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{

Cell["\<\
Nodes[g] lists all the nodes of the genealogy g, including the \
leaves. \
\>", "Subsubsection"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(Nodes::usage = "\<Nodes[g] lists all the nodes of the genealogy g, \
including the leaves. \>";\)\)], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(General::"spell1" \(\(:\)\(\ \)\) 
      "Possible spelling error: new symbol name \"\!\(Nodes\)\" is similar to \
existing symbol \"\!\(Node\)\"."\)], "Message"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["\<\
InternalNodes[g] lists the internal nodes of the genealogy g.\
\>", 
  "Subsubsection"],

Cell[BoxData[
    \(\(InternalNodes::usage = "\<InternalNodes[g] lists the internal nodes \
of the genealogy g. \>";\)\)], "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{

Cell["Leaves[g] lists the terminal nodes of the genealogy g.", "Subsubsection"],

Cell[BoxData[
    \(\(Leaves::usage = "\<Leaves[g] lists the terminal nodes of the \
genealogy g. For an ancestral graph, Leaves[{AncestralLineage[\[Ellipsis]]\
\[Ellipsis]}] gives those lineages which start at times when no other \
lineages end\>";\)\)], "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData[
"CollapseGenealogy[genealogy] reduces the genealogy to a nested list. \
CollapseGenealogy[genealogy, Node\[Rule]False] only lists the leaves."], 
  "Subsubsection"],

Cell[BoxData[
    \(\(\(\ \)\(CollapseGenealogy::usage = "\<CollapseGenealogy[genealogy] \
reduces the genealogy to a nested list.  Node\[Rule]False only lists the \
leaves. NodeFunction\[Rule]f extracts a nested list of the information \
associated with each node, by applying f[i,{info}] to the full set of \
information contained in the genealogy. Nested\[Rule]False does not preserve \
the nested structure.\>";\)\)\)], "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{

Cell["\<\
SizeOfGenealogyPlot[g] gives the minimum and maximum coordinates, \
held as the last element of the information lists in g.\
\>", "Subsubsection"],

Cell[BoxData[
    \(\(SizeOfGenealogyPlot::usage = \*"\"\<SizeOfGenealogyPlot[g] gives the \
minimum and maximum coordinates, held as the last element of the information \
lists in g, in the form {{\!\(x\_min\),\!\(y\_min\)},{\!\(x\_max\),\!\(y\_max\
\)}}.\>\"";\)\)], "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{

Cell["\<\
MakeGenealogyPlot[g] appends coordinates to the information lists; \
these are used by PlotGenealogy[].\
\>", "Subsubsection"],

Cell[BoxData[
    \(\(MakeGenealogyPlot::usage = "\<MakeGenealogyPlot[g] appends \
coordinates to the information lists; these are used by PlotGenealogy[].  The \
vertical coordinate is incremented in units of 1, and the vertical span \
equals the number of lineages, minus 1. \>";\)\)], "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData[
"PlotGenealogy[g] plots a genealogy; the coordinates are held as the last \
element of the information lists.  These may be generated by \
MakeGenealogyPlot[g].   PlotGenealogy[g,NodeFunction\[Rule]f] uses f[i,info] \
to derive the vertical coordinate; this might represent coalescence time, for \
example."], "Subsubsection"],

Cell[BoxData[
    \(\(PlotGenealogy::usage = "\<PlotGenealogy[g] plots a genealogy.  \
PlotGenealogy[g,NodeFunction\[Rule]f] uses f[i,info] to derive the \
coordinates; this might represent coalescence time, for example.  By default, \
nodes & leaves are labelled.  NodeLabels\[Rule]None suppresses the labelling; \
NodeLabels\[Rule]f uses f[i,info] to derive labels.  \
MakeGenealogyPlot\[Rule]False requires that  the coordinates are held as the \
last element of the information list.  By default, these are generated by \
MakeGenealogyPlot[g].\>";\)\)], "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{

Cell["\<\
LeafOffset is an option for PlotGenealogy which determines the \
position of leaf labels.\
\>", "Subsubsection"],

Cell[BoxData[
    \(\(LeafOffset::usage = "\<LeafOffset is an option for PlotGenealogy \
which determines the position of leaf labels.\>";\)\)], "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{

Cell["\<\
NodeOffset is an option for PlotGenealogy which determines the \
position of node labels.\
\>", "Subsubsection"],

Cell[BoxData[
    \(\(NodeOffset::usage = "\<NodeOffset is an option for PlotGenealogy \
which determines the position of node labels.\>";\)\)], "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData[
"LeafLabels\[Rule]f is an option for PlotGenealogy which uses f[i,info] to \
construct labels for the leaves; LeafLabels\[Rule]None suppresses labels."], 
  "Subsubsection"],

Cell[BoxData[
    \(\(LeafLabels::usage = "\<LeafLabels\[Rule]f is an option for \
PlotGenealogy which uses f[i,info] to construct labels for the leaves; \
LeafLabels\[Rule]None suppresses labels.\>";\)\)], "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{

Cell["\<\
MostRecentCommonAncestor[pop,i,j] gives the most recent common \
ancestor of nodes i, j\
\>", "Subsubsection"],

Cell[BoxData[
    \(\(MostRecentCommonAncestor::usage = "\<MostRecentCommonAncestor[g,i,j] \
gives the most recent common ancestor of nodes i, j.  \>";\)\)], "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{

Cell["\<\
Nested is an option for CollapseGenealogy which determines whether \
the nested structure is preserved.\
\>", "Subsubsection"],

Cell[BoxData[
    \(\(Nested::usage = "\<Nested is an option for CollapseGenealogy which \
determines whether the nested structure is preserved. \>";\)\)], "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{

Cell["\<\
ExtractInformation[g,i] gives the information associated with node \
i.\
\>", "Subsubsection"],

Cell[BoxData[
    \(\(ExtractInformation::usage = \*"\"\<ExtractInformation[g,i] gives the \
information associated with node i. ExtractInformation[g] gives a list of the \
information for all the nodes.  For an ancestral graph, \
ExtractInformation[{AncestralLineage[\[Ellipsis]]\[Ellipsis]},l] extracts the \
information associated with the lineage labelled by l.  Checks that there is \
only one such lineage. ExtractInformation[{AncestralLineage[\[Ellipsis]]\
\[Ellipsis]},{\!\(l\_1\),\[Ellipsis]}] extracts a list of such information. \
\>\"";\)\)], "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{

Cell["\<\
TransformInformation[g,f] replaces the information list info by \
f[node,info].\
\>", "Subsubsection"],

Cell[BoxData[
    \(\(TransformInformation::usage = "\<TransformInformation[g,f] replaces \
the information list info by f[node,info].\>";\)\)], "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    \(TextForm
    \`ListToGenealogy[list]\ constructs\ a\ genealogy\ from\ a\ nested\ list\ 
        of\ the\ form
        \ {label, {node\_1, node\_2, \[Ellipsis]}} . \ \ Information\ on\ each
        \ node\ can\ be\ included\ using\ NodeFunction \[Rule] f, \ 
    where\ f[label]\ gives\ a\ list\ of\ information\ for\ the\ node\ with\ 
      that\ label . \ \ 
        ListToGenealogy[{{a, b}, {c, d}}, Node \[Rule] False]\ gives\ a\ 
      genealogy\ relating\ objects\ {a, b, \[Ellipsis]} . \ \ Internal\ nodes
      \ are\ \(unlabelled . \)\)], "Subsubsection"],

Cell[BoxData[
    \(\(ListToGenealogy::usage = \*"\"\<ListToGenealogy[list] constructs a \
genealogy from a nested list of the form {label,{\!\(node\_1\),\!\(node\_2\),\
\[Ellipsis]}}.  Information on each node can be included using NodeFunction\
\[Rule]f, where f[label] gives a list of information for the node with that \
label.  ListToGenealogy[{{a,b},{c,d}},Node\[Rule]False] gives a genealogy \
relating objects {a,b,\[Ellipsis]}.  Internal nodes are \
unlabelled.\>\"";\)\)], "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{

Cell["\<\
OrderedNodes[g,f] gives a list of the nodes in the genealogy, in \
the order defined by f[ i,{info}]\
\>", "Subsubsection"],

Cell[BoxData[
    \(\(OrderedNodes::usage = "\<OrderedNodes[g,f] gives a list of the nodes \
in the genealogy, in the order defined by f[ i,{info}].  \
OrderedNodes[g,f,Node\[Rule]True] only lists internal nodes.\>";\)\)], "Input",\

  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{

Cell["Ancestors[g,node] lists the ancestors of the node.", "Subsubsection"],

Cell[BoxData[
    \(\(Ancestors::usage = \*"\"\<Ancestors[g,node] lists the ancestors of \
the node.  For an ancestral graph, Ancestors[{AncestralLineage[\[Ellipsis]],\
\[Ellipsis]},l] lists the immediate ancestors of lineage l.  MapPosition\
\[Rule]x restricts the list to ancestors at map position x.  AncestorList\
\[Rule]All gives a list of all ancestors, in  the form {\!\(l\_1\),{{\!\(d\_1\
\),{\[Ellipsis]}},{\!\(d\_2\),{\[Ellipsis]}}}}.  AncestorList\[Rule]Roots \
gives only the root ancestors.  \>\"";\)\)], "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData[
"Descendants[g,node] lists the immediate descendants of the node.  \
Descendants[g,node,DescendantList\[Rule]All] lists all the descendants of the \
node. Descendants[g,node,DescendantList\[Rule]Leaves] lists only the \
descendant leaves of the node."], "Subsubsection"],

Cell[BoxData[
    \(\(Descendants::usage = \*"\"\<Descendants[g,node] lists the immediate \
descendants of the node.  Descendants[g,node,DescendantList\[Rule]All] lists \
all the descendants of the node. \
Descendants[g,node,DescendantList\[Rule]Leaves] lists only the descendant \
leaves of the node.  For an ancestral graph, Descendants[{AncestralLineage[\
\[Ellipsis]],\[Ellipsis]},l] lists the immediate descendants from lineage l.  \
MapPosition\[Rule]x restricts the list to descendants at map position x.  \
DescendantList\[Rule]All gives a list of all descendants, in  the form {\!\(l\
\_1\),{{\!\(d\_1\),{\[Ellipsis]}},{\!\(d\_2\),{\[Ellipsis]}}}}. \
DescendantList\[Rule]Leaves gives only the descendant leaves.\>\"";\)\)], \
"Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{

Cell["\<\
DescendantList is an option for Descendants[]; may be set to Next, \
All or Leaves.\
\>", "Subsubsection"],

Cell[BoxData[
    \(\(DescendantList::usage = "\<DescendantList is an option for \
Descendants[]; may be set to Next, All or Leaves.\>";\)\)], "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{

Cell["UnrootedGenealogy[g] gives an unrooted genealogy.", "Subsubsection"],

Cell[BoxData[
    \(\(UnrootedGenealogy::usage = "\<UnrootedGenealogy[g] gives an unrooted \
genealogy.\>";\)\)], "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    FormBox[GridBox[{
          {\(RootedGenealogy[g, i]\), 
            \(roots\ an\ unrooted\ genealogy\ at\ node\ i\)}
          }], TextForm]], "Subsubsection"],

Cell[BoxData[
    RowBox[{
      RowBox[{\(RootedGenealogy::usage\), "=", 
        "\"\<\!\(TextForm\`RootedGenealogy\)[g,i] roots an unrooted genealogy \
at node i\>\""}], ";"}]], "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{

Cell["\<\
SiblingList[g] lists all pairs of leaves which are directly \
related.\
\>", "Subsubsection"],

Cell[BoxData[
    \(\(SiblingList::usage = "\<SiblingList[g] lists all pairs of leaves \
which are directly related.\>";\)\)], "Input",
  InitializationCell->True]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["Family structures", "Subsection"],

Cell[CellGroupData[{

Cell["\<\
GenealogyToFamily[g,f] gives a list of the family structures \
following successive coalescences. The function f[i,{info}] gives the \
ordering of the coalescence for node i.\
\>", "Subsubsection"],

Cell[BoxData[
    \(\(GenealogyToFamily::usage = "\<GenealogyToFamily[g,f] gives a list of \
the family structures following successive coalescences. The function \
f[i,{info}] gives the ordering of the coalescence for node i.\>";\)\)], \
"Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    \(TextForm
    \`FamilyToGenealogy[{a, b, c, \[Ellipsis]}, S]\ gives\ a\ randomly\ 
      constructed\ genealogy\ which\ satistfies\ the\ sequence\ of\ family\ 
      structures\ S, \ 
    and\ which\ relates\ {a, b, c, \[Ellipsis]} . \ \ The\ terminal\ nodes\ 
      are\ labelled\ by\ {a, b, c, \[Ellipsis]}, \ 
    and\ the\ internal\ nodes\ are\ labelled\ by\ integers\ giving\ the\ order
        \ of\ the\ coalescence\ events . \ NodeLabels \[Rule] 
      \({label\_1, \[Ellipsis]}\ allows\ an\ arbitrary\ list\ of\ labels\ for
          \ the\ internal\ nodes . \ \ NodeInformation 
        \[Rule] {info\_1, \[Ellipsis]}\), \ 
    LeafInformation 
      \[Rule] {info\_a, \[Ellipsis]}\ allow\ arbitrary\ lists\ of\ information
        \ to\ be\ associated\ with\ the\ nodes\ and\ leaves . \ \ With\ n\ 
        items, \ there\ are\ n\ nodes, \ 
    and\ so\ all\ the\ optional\ lists\ must\ have\ length\ \(n . \)\)], 
  "Subsubsection"],

Cell[BoxData[
    \(\(FamilyToGenealogy::usage = \
\*"\"\<FamilyToGenealogy[{a,b,c,\[Ellipsis]},S] gives a randomly constructed \
genealogy which satistfies the sequence of family structures S, and which \
relates {a,b,c,\[Ellipsis]}.  The terminal nodes are labelled by {a,b,c,\
\[Ellipsis]}, and the internal nodes are labelled by integers giving the \
order of the coalescence events. \
NodeLabels\[Rule]{\!\(label\_1\),\[Ellipsis]} allows an arbitrary list of \
labels for the internal nodes.  NodeInformation\[Rule]{\!\(info\_1\),\
\[Ellipsis]}, LeafInformation\[Rule]{\!\(info\_a\),\[Ellipsis]} allow \
arbitrary lists of information to be associated with the nodes and leaves.  \
With n items, there are n nodes, and so all the optional lists must have \
length n.\>\"";\)\)], "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    \(TextForm
    \`LeafInformation 
      \[Rule] {info\_a, \[Ellipsis]}\ is\ an\ option\ for\ 
        FamilyToGenealogy[]\ which\ specifies\ information\ associated\ with\ 
        each\ \(leaf . \)\)], "Subsubsection"],

Cell[BoxData[
    \(\(\(\ \)\(LeafInformation::usage = \
\*"\"\<LeafInformation\[Rule]{\!\(info\_a\),\[Ellipsis]} is an option for \
FamilyToGenealogy[] which specifies information associated with each \
leaf.\>\"";\)\)\)], "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    \(TextForm
    \`NodeInformation 
      \[Rule] {info\_1, \[Ellipsis]}\ is\ an\ option\ for\ 
        FamilyToGenealogy[]\ which\ specifies\ information\ associated\ with\ 
        each\ internal\ node . \ \ The\ number\ of\ such\ nodes\ is\ the\ same
        \ as\ the\ number\ of\ leaves; \ 
    nodes\ are\ ordered\ by\ their\ \(timing . \)\)], "Subsubsection"],

Cell[BoxData[
    \(\(\(\ \)\(NodeInformation::usage = \
\*"\"\<NodeInformation\[Rule]{\!\(info\_1\),\[Ellipsis]} is an option for \
FamilyToGenealogy[] which specifies information associated with each internal \
node.  The number of such nodes is the same as the number of leaves; nodes \
are ordered by their timing.\>\"";\)\)\)], "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    \(TextForm
    \`NodeLabels 
      \[Rule] {label\_1, \[Ellipsis]}\ is\ an\ option\ for\ 
        FamilyToGenealogy[]\ which\ specifies\ labels\ for\ each\ internal\ 
        node . \ \ The\ number\ of\ such\ nodes\ is\ the\ same\ as\ the\ 
        number\ of\ leaves; \ 
    nodes\ are\ ordered\ by\ their\ \(timing . \)\)], "Subsubsection"],

Cell[BoxData[
    \(\(\(\ \)\(NodeLabels::usage = \*"\"\<NodeLabels\[Rule]{\!\(label\_1\),\
\[Ellipsis]} is an option for FamilyToGenealogy[] which specifies labels for \
each internal node.  The number of such nodes is the same as the number of \
leaves; nodes are ordered by their timing.  NodeLabels\[Rule]f is an option \
for PlotGenealogy which uses f[i,info] to construct labels for the nodes; \
NodeLabels\[Rule]None suppresses labels.\>\"";\)\)\)], "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    \(TextForm
    \`GenealogyB[j, i, k]\ is\ the\ coefficient\ of\ 
      Exp[\(-\[Lambda]\_i\) t/2  N]\ in\ the\ expression\ for\ P\_j, \ 
    the\ probability\ of\ j\ coalescences\ having\ \(occurred . \)\)], 
  "Subsubsection",
  InitializationCell->True],

Cell[BoxData[
    \(\(GenealogyB::usage = \*"\"\<GenealogyB[j,i,k] is the coefficient of \
Exp[-\!\(\[Lambda]\_i\)t/2N] in the expression for \!\(P\_j\), the \
probability of j coalescences having occurred.\>\"";\)\)], "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{

Cell["\<\
CoalescenceDistribution[j,k,t] is the probability of j coalescences \
having occurred among k lineages over t generations (scaled to 2N)\
\>", 
  "Subsubsection",
  InitializationCell->True],

Cell[BoxData[
    \(\(CoalescenceDistribution::usage = "\<CoalescenceDistribution[j,k,t] is \
the probability of j coalescences having occurred among k lineages over t \
generations (scaled to 2N) \>";\)\)], "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{

Cell["\<\
SimplifyFamilies replaces duplications such as {{1,3},{2,2},{2,1}} \
by {{1,3},{2,3}}\
\>", "Subsubsection",
  InitializationCell->True],

Cell[BoxData[
    \(\(SimplifyFamilies::usage = "\<SimplifyFamilies replaces duplications \
such as {{3,1},{2,2},{1,2}} by {{3,1},{3,2}}\>";\)\)], "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{

Cell["\<\
FamilyProbability[S] gives the probability that this family \
structure would be produced, given a certain number of coalescence \
events\
\>", "Subsubsection",
  InitializationCell->True],

Cell[BoxData[
    \(\(FamilyProbability::usage = "\<FamilyProbability[S] gives the \
probability that the family structure S would be produced, given a certain \
number of coalescence events.\>";\)\)], "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{

Cell["NumberOfLineages[S] gives the total number of genes involved", 
  "Subsubsection",
  InitializationCell->True],

Cell[BoxData[
    \(\(NumberOfLineages::usage = "\<NumberOfLineages[g]  gives the total \
number of lineages (i.e., terminal nodes) involved in the genealogy g. \
NumberOfLineages[g,i] gives the number that descend from node i.  \
NumberOfLineages[S] can also be applied to a list of family sizes, \
S\>";\)\)], "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{

Cell["PairwiseIdentity[S] gives the mean pairwise identity", "Subsubsection",
  InitializationCell->True],

Cell[BoxData[
    \(\(PairwiseIdentity::usage = "\<PairwiseIdentity[S] gives the mean \
pairwise identity, given the family structure S.\>";\)\)], "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{

Cell["\<\
AllSets[j,k] lists all the family structures that could yield j \
families and k genes\
\>", "Subsubsection",
  InitializationCell->True],

Cell[BoxData[
    \(\(AllSets::usage = "\<AllSets[j,k] lists all the family structures that \
could yield j families and k genes\>";\)\)], "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{

Cell["NewS[S] gives a recursion for the family structures", "Subsubsection",
  InitializationCell->True],

Cell[BoxData[
    \(\(NewS::usage = "\<NewS[S] gives a recursion for the family \
structures\>";\)\)], "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{

Cell["NumberOfFamilies[S] gives the number of families", "Subsubsection",
  InitializationCell->True],

Cell[BoxData[
    \(\(NumberOfFamilies::usage = "\<NumberOfFamilies[S] gives the number of \
families\>";\)\)], "Input",
  InitializationCell->True]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["Random genealogies", "Subsection"],

Cell[CellGroupData[{

Cell["CoalescenceTimes", "Subsubsection"],

Cell[BoxData[
    \(\(CoalescenceTimes::usage = "\<CoalescenceTimes is an option for \
RandomGenealogy.  CoalescenceTimes\[Rule]Random uses \
RandomCoalescenceTimes[k]; otherwise a list of times must be \
supplied\>";\)\)], "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{

Cell["\<\
RandomCoalescenceTimes[k] gives a list of random coalescence \
times\
\>", "Subsubsection"],

Cell[BoxData[
    \(\(RandomCoalescenceTimes::usage = "\<RandomCoalescenceTimes[k] gives a \
list of random coalescence times, scaled to 2N generations. \
RandomCoalescenceTimes[n,k,R] generates a sequence of n coalescences and \
recombinations, starting with k lineages at t=0. The output is a list of n \
items of the form {t,k,j}, where t is the time of the event;k is the number \
of lineages after the event; and j is the location of the recombination event \
in the interval {0,R}. j=None indicates a coalescence.  \
RandomCoalescenceTimes[k,R] generates a single item, with rate k(k-1)/2 of \
coalescence and k R of recombination.\>";\)\)], "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{

Cell["\<\
NumberOfCoalescences[k,T] gives a randomly sampled number of \
coalescence events that occur in T (scaled to 2N) \
NumberOfCoalescences[{t1,t2..}] does the same, for a list of coalescence \
times.\
\>", "Subsubsection",
  InitializationCell->True],

Cell[BoxData[
    \(\(NumberOfCoalescences::usage = "\<NumberOfCoalescences[k,T] gives a \
randomly sampled number of coalescence events that occur in T (scaled to 2N). \
NumberOfCoalescences[{t1,t2..},T] does the same, for a list of coalescence \
times. \>";\)\)], "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{

Cell["TotalLength[{t1,t2,..}] is the total length of the tree", \
"Subsubsection"],

Cell[BoxData[
    \(\(TotalLength::usage = "\<TotalLength[{t1,t2,..}] is the total length \
of the tree, given the coalescence times.\>";\)\)], "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{

Cell["\<\
RandomFamilies[k] generates a list of the family sizes going back \
through time to the common ancestor of k genes.\
\>", "Subsubsection"],

Cell[BoxData[
    \(\(RandomFamilies::usage = "\<RandomFamilies[k] generates a list of the \
family sizes going back through time to the common ancestor of k genes.\>";\)\
\)], "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{

Cell["\<\
RandomPreviousFamily[{1,1,2,3}] generates a random coalescence to \
give the previous family structure\
\>", "Subsubsection",
  InitializationCell->True],

Cell[BoxData[
    \(\(RandomPreviousFamily::usage = "\<RandomPreviousFamily[{1,1,2,3}] \
generates a random coalescence to give the previous family \
structure\>";\)\)], "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    \(TextForm\`RandomGenealogy[{leaf\_1, 
          leaf\_2, \[Ellipsis]}]\ gives\ a\ random\ realisation\ of\ the\ \
coalescent\ process . \ \ Terminal\ nodes\ are\ labelled\ {leaf\_1, 
        leaf\_2, \[Ellipsis]}, \ 
    and\ internal\ nodes\ are\ labelled\ by\ an\ integer, \ 
    in\ the\ order\ in\ which\ they\ occur . \ \ Each\ node\ carries\ its\ \
time, \ scaled\ to\ 2  
          N\ generations . \ \ MutationRate \[Rule] \[Theta]\ simulates\ \
infinite - sites\ mutation\ at\ a\ rate\ \[Theta] = 4  N\[Mu]; \ 
    mutations\ are\ labelled\ by\ unique\ integers . \ 
          NodeLabels \[Rule] {label\_1, \[Ellipsis]}\ can\ be\ used\ to\ \
label\ internal\ \(\(nodes\)\(.\)\)\)], "Subsubsection"],

Cell[BoxData[
    \(\(RandomGenealogy::usage = \
\*"\"\<RandomGenealogy[{\!\(leaf\_1\),\!\(leaf\_2\),\[Ellipsis]}] gives a \
random realisation of the coalescent process.  Terminal nodes are labelled \
{\!\(leaf\_1\),\!\(leaf\_2\),\[Ellipsis]}, and internal nodes are labelled by \
an integer, in the order in which they occur.  Each node carries its time, \
scaled to 2N generations.  MutationRate\[Rule]\[Theta] simulates \
infinite-sites mutation at a rate \[Theta]=4N\[Mu]; mutations are labelled by \
unique integers. NodeLabels\[Rule]{\!\(label\_1\),\[Ellipsis]} can be used to \
label internal nodes.   RandomGenealogy[{\!\(leaf\_1\),\!\(leaf\_2\)\
\[Ellipsis]},n,R] gives a random realisation of the coalescent process with \
recombination; there are n events. RandomGenealogy[{\!\(leaf\_1\),\!\(leaf\_2\
\)\[Ellipsis]},{{\!\(t\_1\),\!\(k\_1\),\!\(x\_1\)}\[Ellipsis]},R] gives a \
random realisation for a specific sequence of events, generated by \
RandomCoalescenceTimes[n,k,R]; this preserves null lineages, however.  \
DeleteNullLineages->True ignores null events; can only be used with the first \
form. PrintDetails\[Rule]True prints details of the construction.  MaxTime->t \
stops after time t.  Fixation->True stops when the whole genome is \
fixed.\>\"";\)\)], "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData[
"MutationRate\[Rule]\[Theta] is an option for RandomGenealogy[] which sets \
the scaled mutation rate \[Theta]=4N\[VeryThinSpace]\[Mu].  Default is \
MutationRate\[Rule]None."], "Subsubsection"],

Cell[BoxData[
    \(\(MutationRate::usage = "\<MutationRate\[Rule]\[Theta] is an option for \
RandomGenealogy[] which sets the scaled mutation rate \[Theta]=4N\
\[VeryThinSpace]\[Mu].  Default is MutationRate\[Rule]None.\>";\)\)], "Input",\

  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    \(TextForm
    \`DeletedMutations[g, {T\_0, T\_1}]\ lists\ those\ mutations\ that\ should
      \ be\ deleted\ because\ they\ occurred\ in\ time\ interval
      \ {T\_0, T\_1} . \ \ This\ list\ may\ be\ to\ some\ extent\ randomly\ 
      \(generated . \)\)], "Subsubsection"],

Cell[BoxData[
    \(\(DeletedMutations::usage = \*"\"\<DeletedMutations[g,{\!\(T\_0\),\!\(T\
\_1\)}] lists those mutations that should be deleted because they occurred in \
time interval {\!\(T\_0\),\!\(T\_1\)}.  This list may be to some extent \
randomly generated. \>\"";\)\)], "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData[
"RandomBottleneckedGenealogy[leaves,{T0,T1},\[Theta]] gives a random \
genealogy, with no mutations occurring in time interval {T0,T1}."], 
  "Subsubsection"],

Cell[BoxData[
    \(\(RandomBottleneckedGenealogy::usage = \
"\<RandomBottleneckedGenealogy[leaves,{T0,T1},\[Theta]] gives a random \
genealogy, with no mutations occurring in time interval {T0,T1}.\>";\)\)], \
"Input",
  InitializationCell->True]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["Generating functions", "Subsection"],

Cell[CellGroupData[{

Cell[TextData[
"MomentGeneratingFunction[g,\[Omega],\[Theta]] gives the generating function \
for the number of mutations along each branch of the genealogy, under the \
infinite sites model."], "Subsubsection"],

Cell[BoxData[
    \(\(MomentGeneratingFunction::usage = "\<MomentGeneratingFunction[g,\
\[Omega],\[Theta]] gives the generating function for the number of mutations \
along each branch of the genealogy, under the infinite sites model. \
MomentGeneratingFunction[{{a},{b},\[Ellipsis]},\[Omega],\[Theta]] gives the \
generating function for all tree topologies, in terms of variables \
\[Omega][S] which correspond to those mutations in branches ancestral to the \
set of leaves S. Stores results. \>";\)\)], "Input",
  InitializationCell->True]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["The probability of genealogies", "Subsection"],

Cell[CellGroupData[{

Cell[TextData[
"IncidenceMatrix[g,nodelist] gives the matrix describing an ordering of \
coalescences defined by nodelist.  The last member of nodelist is the root \
node.  The elements of the matrix show whether a branch is present during the \
time for which there are 1\[LessEqual]i\[LessEqual]n lineages. Rows \
correspond to branches, in the order specified by nodelist. "], 
  "Subsubsection"],

Cell[BoxData[
    \(\(IncidenceMatrix::usage = 
        IncidenceMatrix::usage <> "\<  For genealogies, \
IncidenceMatrix[g,nodelist] gives the matrix describing an ordering of \
coalescences defined by nodelist.  The last member of nodelist is the root \
node.  The elements of the matrix show whether a branch is present during the \
time for which there are 1\[LessEqual]i\[LessEqual]n lineages. Rows \
correspond to branches, in the order specified by nodelist. \>";\)\)], "Input",\

  InitializationCell->True]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[
"MonteCarloProbability[g,nodelist,J,\[Theta],ns] makes a Monte Carlo estimate \
of the probability of the genealogy g and the mutational configuration J, \
assuming that the coalescences are in the order specified by nodelist. A list \
of ns values is returned. MonteCarloProbability[g,J,\[Theta],ns] makes no \
assumptions as to the order of events."], "Subsubsection"],

Cell[BoxData[
    \(\(MonteCarloProbability::usage = \
\*"\"\<MonteCarloProbability[g,nodelist,J,\[Theta],\!\(\(\[Theta]\^*\)\),ns] \
makes a Monte Carlo estimate of the probability of the genealogy g and the \
mutational configuration J, assuming that the coalescences are in the order \
specified by nodelist. A list of ns values is returned. \
MonteCarloProbability[g,J,\[Theta],\!\(\(\[Theta]\^*\)\),ns] makes no \
assumptions as to the order of events. Uses the arbitrary parameter \!\(\(\
\[Theta]\^*\)\) to make random partitions.  \!\(\(\[Theta]\^*\)\) must be a \
number, but \[Theta] can be symbolic.\>\"";\)\)], "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{

Cell["\<\
PossibleCoalescenceOrder[g] lists the possible orders in which \
coalescence events might occur; each is given by an ordered list of \
nodes.\
\>", "Subsubsection"],

Cell[BoxData[
    \(\(PossibleCoalescenceOrder::usage = "\<PossibleCoalescenceOrder[g] \
lists the possible orders in which coalescence events might occur; each is \
given by an ordered list of nodes.  Leaves are listed first, and the root \
node last.\>";\)\)], "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{

Cell["\<\
RandomCoalescenceOrder[g] gives a random ordering of the possible \
coalescence events\
\>", "Subsubsection"],

Cell[BoxData[
    \(\(RandomCoalescenceOrder::usage = "\<RandomCoalescenceOrder[g] gives a \
random ordering of the possible coalescence events\>";\)\)], "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{

Cell["\<\
NumberOfPossibleCoalescences[g,nodelist] gives the number of \
possible coalescences that could occur at each step. Only internal nodes are \
included. The order of coalescences is defined by nodelist\
\>", 
  "Subsubsection"],

Cell[BoxData[
    \(\(NumberOfPossibleCoalescences::usage = \
"\<NumberOfPossibleCoalescences[g,nodelist] gives the number of possible \
coalescences that could occur at each step. Only internal nodes are included. \
The order of coalescences is defined by nodelist\>";\)\)], "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{

Cell["\<\
NumberOfMutations[g,node] gives the number of mutations that \
occurred on the branch leading down to the specified node. The set of \
mutations is given in the second element of the information for each \
node.\
\>", "Subsubsection"],

Cell[BoxData[
    \(\(NumberOfMutations::usage = "\<NumberOfMutations[g,node] gives the \
number of mutations that occurred on the branch leading down to the specified \
node. The set of mutations is given in the second element of the information \
for each node. \>";\)\)], "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData[
"Mutations[g] gives the set of mutations that occured on g.  Mutations[g,i] \
gives the mutations that arose on the branch leading down to node i.  By \
default, these are held in the second element of the information list.  \
NodeFunction\[Rule]f uses f[i,info] to extract the mutation list."], 
  "Subsubsection"],

Cell[BoxData[
    \(\(Mutations::usage = "\<Mutations[g] gives the set of mutations that \
occured on g.  Mutations[g,i] gives the mutations that arose on the branch \
leading down to node i.  By default, these are held in the second element of \
the information list.  NodeFunction\[Rule]f uses f[i,info] to extract the \
mutation list.\>";\)\)], "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{

Cell["\<\
MutationOrigin[g,k] gives the first node at which mutation k \
appears.\
\>", "Subsubsection"],

Cell[BoxData[
    \(\(MutationOrigin::usage = "\<MutationOrigin[g,k] gives the first node \
at which mutation k appears.   By default, the mutations are held in the \
second element of the information list, and the coalescence time as the first \
element.  NodeFunction\[Rule]f uses f[i,info] to return {time,mutations}.\>";\
\)\)], "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{

Cell["\<\
MutationInterval[g,k] gives the time .interval in which mutation k \
arose.  \
\>", "Subsubsection"],

Cell[BoxData[
    \(\(MutationInterval::usage = "\<MutationInterval[g,k] gives the time \
interval in which mutation k arose.  By default, the mutations are held in \
the second element of the information list, and the coalescence time as the \
first element.  NodeFunction\[Rule]f uses f[i,info] to return \
{time,mutations}.\>";\)\)], "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData[
"ExactProbability[g,\[Theta]] gives the probability of this genealogy, given \
a scaled mutation rate \[Theta]=4N\[VeryThinSpace]\[Mu]. By default, the \
number of mutations is deduced from a list of unique mutations held in the \
second element of the information list.  NodeFunction\[Rule]f uses f[i,info] \
to find the number of mutations. Uses MomentGeneratingFunction[], and so is \
intractable for large numbers of mutations and for large genealogies.  \
ExactProbability[S,\[Theta]] uses the generating function over all topologies \
to find the net probability of the configuration of mutations represented by \
the matrix S."], "Subsubsection"],

Cell[BoxData[
    \(\(ExactProbability::usage = "\<ExactProbability[g,\[Theta]] gives the \
probability of this genealogy, given a scaled mutation rate \[Theta]=4N\
\[VeryThinSpace]\[Mu]. By default, the number of mutations is deduced from a \
list of unique mutations held in the second element of the information list.  \
NodeFunction\[Rule]f uses f[i,info] to find the number of mutations. Uses \
MomentGeneratingFunction[], and so is intractable for large numbers of \
mutations and for large genealogies.  ExactProbability[S,\[Theta]] uses the \
generating function over all topologies to find the net probability of the \
configuration of mutations represented by the matrix S.\>";\)\)], "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData[{
  "GenealogyToMatrix",
  "[g] gives a matrix whose rows specify which mutations are found in which \
leaf of the genealogy.  By default, the list of mutations is taken from the \
second element of the information list.  NodeFunction\[Rule]f uses f[i,info] \
to specify the mutations in each node."
}], "Subsubsection"],

Cell[BoxData[
    \(\(GenealogyToMatrix::usage = \*"\"\<GenealogyToMatrix[g] gives a matrix \
whose rows specify which mutations are found in which leaf of the genealogy. \
The genealogy can be unrooted. By default, the list of mutations is taken \
from the second element of the information list.  NodeFunction\[Rule]f uses \
f[i,info] to specify the mutations in each node.  \
MutationLabels->{\!\(m\_1\),\[Ellipsis]} specifies the names of the \
mutations; by default, the list is the set of mutations found in \
g.\>\"";\)\)], "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    \(TextForm
    \`MatrixToGenealogy[
        S, {leaf\_1, \ leaf\_2, \[Ellipsis]}, {\[Mu]\_1, \[Ellipsis]}]\ 
      constructs\ a\ genealogy\ from\ the\ matrix\ S . \ \ The\ leaves\ are\ 
      labelled\ by\ {leaf\_1, \ \[Ellipsis]}\ and\ the\ mutations\ by
      \ {\[Mu]\_1, \[Ellipsis]}; \ 
    internal\ nodes\ are\ labelled\ by\ unique\ integers\)], "Subsubsection"],

Cell[BoxData[
    \(\(MatrixToGenealogy::usage = \*"\"\<MatrixToGenealogy[S,{\!\(leaf\_1\), \
\!\(leaf\_2\),\[Ellipsis]},{\!\(\[Mu]\_1\),\[Ellipsis]}] constructs a \
genealogy from the matrix S.  The leaves are labelled by {\!\(leaf\_1\), \
\[Ellipsis]} and the mutations by {\!\(\[Mu]\_1\),\[Ellipsis]}; internal \
nodes are labelled by unique integers.  Unrooted->True yields an unrooted \
genealogy; no assumption is made as to which allele is ancestral and which \
derived.\>\"";\)\)], "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    \(TextForm
    \`MatrixToList[S]\ converts\ a\ matrix\ representation\ to\ a\ list\ of\ 
      the\ mutations\ held\ by\ each\ leaf . \ \ By\ default, \ 
    mutations\ are\ numbered\ 1, 
    2  \[Ellipsis] . \ \ MutationLabels 
      \[Rule] {m\_1, \[Ellipsis]}\ uses\ the\ specified\ \(labels . \)\)], 
  "Subsubsection"],

Cell[BoxData[
    \(\(MatrixToList::usage = \*"\"\<MatrixToList[S] converts a matrix \
representation to a list of the mutations held by each leaf.  By default, \
mutations are numbered 1,2\[Ellipsis].  MutationLabels\[Rule]{\!\(m\_1\),\
\[Ellipsis]} uses the specified labels.\>\"";\)\)], "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    \(TextForm
    \`FindNode[g, {m\_1, \[Ellipsis]}, newNode]\ finds\ from\ where\ in\ the\ 
      genealogy\ g\ a\ leaf\ carrying\ mutations\ {m\_1, \[Ellipsis]}\ 
      descends . \ \ If\ no\ node\ or\ branch\ matches, \ 
    returns\ $Failed . \ If\ the\ leaf\ joins\ the\ branch\ above\ node\ i, \ 
    returns\ {i, newNode, {m\_1, \[Ellipsis]}}, \ 
    where\ newNode\ is\ a\ new\ node\ label, \ 
    distinct\ from\ any\ other\ in\ g . \ The\ last\ element\ lists\ the\ 
      mutations\ carried\ at\ the\ new\ node . \ \ If\ the\ leaf\ joins\ at\ 
      node\ i, \ returns\ {i, i, {m\_1, \[Ellipsis]}}, \ 
    where\ the\ last\ element\ lists\ the\ mutations\ carried\ at\ node\ 
      i . \ \ \ \ The\ new\ leaf\ MUST\ contain\ all\ the\ mutations\ in\ the
      \ root\ node\ of\ \(g . \)\)], "Subsubsection"],

Cell[BoxData[
    \(\(FindNode::usage = \*"\"\<FindNode[g,{\!\(m\_1\),\[Ellipsis]},newNode] \
finds from where in the genealogy g a leaf carrying mutations {\!\(m\_1\),\
\[Ellipsis]} descends.  If no node or branch matches, returns $Failed. If the \
leaf joins the branch above node i, returns \
{i,newNode,{\!\(m\_1\),\[Ellipsis]}}, where newNode is a new node label, \
distinct from any other in g. The last element lists the mutations carried at \
the new node.  If the leaf joins at node i, returns {i,i,{\!\(m\_1\),\
\[Ellipsis]}}, where the last element lists the mutations carried at node i.  \
  The new leaf MUST contain all the mutations in the root node of g, and g \
must carry at least one mutation on each branch, except for branches loeading \
down to leaves.\>\"";\)\)], "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    FormBox[
      RowBox[{
        FormBox[\(MutationLabels \[Rule] {m\_1, \[Ellipsis]}\),
          "TextForm"], " ", "is", " ", "an", " ", "option", " ", "for", " ", 
        \(MatrixToList[]\), " ", "which", " ", "labels", " ", "the", " ", 
        "mutations", " ", "as", " ", \({m\_1, \[Ellipsis]}\)}], TextForm]], 
  "Subsubsection"],

Cell[BoxData[
    \(\(MutationLabels::usage = "\<MutationLabels is an option for \
MatrixToList[] which labels the mutations.\>";\)\)], "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    \(TextForm
    \`ListToMatrix[{{1, 2, 3}, {4}, \[Ellipsis]}]\ converts\ a\ list\ of\ 
        mutations\ present\ at\ each\ node\ into\ a\ matrix\ 
        representation . \ \ MutationLabels 
      \[Rule] {m\_1, \[Ellipsis]}\ gives\ the\ columns\ in\ the\ specified\ 
        \(order . \)\)], "Subsubsection"],

Cell[BoxData[
    \(\(ListToMatrix::usage = \*"\"\<ListToMatrix[{{1,2,3},{4},\[Ellipsis]}] \
converts a list of mutations present at each node into a matrix \
representation.  MutationLabels\[Rule]{\!\(m\_1\),\[Ellipsis]} gives the \
columns in the specified order.\>\"";\)\)], "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData[
"GriffithsTavare[S,\[Theta]] uses the Griffiths-Tavare algorithm to find the \
probability of a configuration of mutations defined by the matrix S."], 
  "Subsubsection"],

Cell[BoxData[
    \(\(GriffithsTavare::usage = "\<GriffithsTavare[S,\[Theta]] uses the \
Griffiths-Tavare algorithm to find the probability of a configuration of \
mutations defined by the matrix S.\>";\)\)], "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData[
"MonteCarloGriffithsTavare[S,\[Theta]] uses the Monte-Carlo Griffiths-Tavare \
algorithm to find the probability of a configuration of mutations defined by \
the matrix S."], "Subsubsection"],

Cell[BoxData[
    \(\(MonteCarloGriffithsTavare::usage = "\<MonteCarloGriffithsTavare[S,\
\[Theta]] uses the Monte-Carlo Griffiths-Tavare algorithm to find the \
probability of a configuration of mutations defined by the matrix \
S.\>";\)\)], "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{

Cell["ValidMatrixQ", "Subsubsection"],

Cell[BoxData[
    \(\(ValidMatrixQ::usage = "\<ValidMatrixQ[S] determines whether a matrix \
of mutations, S, is compatible with a genealogy. The i'th row of S is a list \
of {1,0,\[Ellipsis]} representing the set of mutations present in the i'th \
leaf. Unrooted\[Rule]True does not assume that a '1' represents a new \
mutation: 0, 1 just represent two alternative alleles. ValidMatrixQ[{0,1\
\[Ellipsis]},{1,0,\[Ellipsis]}] tests a particular pair of \
mutations.\>";\)\)], "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{

Cell["Unrooted", "Subsubsection"],

Cell[BoxData[
    \(\(Unrooted::usage = "\<Unrooted is an option for ValidMatrixQ which \
specifies that the genealogy is unrooted - i.e., no assumption is made about \
which allele is ancestral\>";\)\)], "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{

Cell["SwapStates", "Subsubsection",
  InitializationCell->True],

Cell[BoxData[
    \(\(SwapStates::usage = "\<SwapStates[s,S] swaps the states of mutations \
listed in the matrix S, according to the specification s.  The matrix S has \
dimensions # leaves\[Times]# mutations, and s is a vector of length equal to \
the # of mutations.  Both consist of 0 or 1.\>";\)\)], "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{

Cell["MissingCombination", "Subsubsection"],

Cell[BoxData[
    \(\(MissingCombination::usage = "\<MissingCombination[S] tabulates the \
missing combinations for each pair of mutations listed in S.  Each element \
contains {} if there are less than 3 combinations for that pair.  If there \
are 4 combinations, the matrix is invalid, and an error message is returned.  \
If there are three combinations, the missing combination is returned; swaps \
represented by this combination are not allowed.  Stores results.\>";\)\)], \
"Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{

Cell["PossibleRootings", "Subsubsection"],

Cell[BoxData[
    \(\(PossibleRootings::usage = "\<PossibleRootings[S] lists all valid ways \
of rooting the mutations listed in S. Returns a list, in which each row {0,1,\
\[Ellipsis]} indicates whether an allele `1` is to be taken as ancestral (1) \
or derived (0). PossibleRootings[{{Null,0,1,Null\[Ellipsis]},\[Ellipsis]},S] \
eliminates indeterminate mutations, indicated by Null, until the solution is \
found.\>";\)\)], "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{

Cell["AddMutation", "Subsubsection"],

Cell[BoxData[
    \(\(AddMutation::usage = \*"\"\<AddMutation[n,m,g] adds the mutations m \
to node n; m can be one mutation,or a list of mutations. \
AddMutation[{\!\(n\_1\),\!\(n\_2\),\[Ellipsis]},{\!\(m\_1\),\!\(m\_2\),\
\[Ellipsis]},g] adds to a list of nodes. Mutations are held as the second \
element of the information list.  \>\"";\)\)], "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{

Cell["CondenseMatrix", "Subsubsection"],

Cell[BoxData[
    \(\(CondenseMatrix::usage = "\<CondenseMatrix[S] reduces the matrix S to \
the minimum informative size. Columns depicting mutations with the same \
distribution across leaves, mutations fixed across the whole set, or present \
in only one leaf, are removed.  Unrooted->True also removes one of each pair \
of complementary mutations (e.g. {0,0,1,1} and {1,1,0,0}).\>";\)\)], "Input",
  InitializationCell->True]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["Recombination", "Subsection"],

Cell[CellGroupData[{

Cell["AncestralLineage", "Subsubsection",
  InitializationCell->True],

Cell[BoxData[
    RowBox[{
      RowBox[{\(AncestralLineage::usage\), "=", 
        "\"\<\!\(TraditionalForm\`\(TraditionalForm\`AncestralLineage[l, {t0, \
t1}, {{a, b}, {}, {c, d}, {c}}, {r1, r2, r3, R}, info]\)\) represents one \
lineage in an ancestral graph.  It gives the name of the lineage, l; the \
timespan, {t0,t1}; the leaves which descend from the various segments, \
{{a,b},{},{c,d},{c}}; and the rightmost positions of each segment, \
{r1,r2,r3,R}.  The genome spans {0,R}.\>\""}], ";"}]], "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{

Cell["AncestralGraphPattern", "Subsubsection",
  InitializationCell->True],

Cell[BoxData[
    \(\(AncestralGraphPattern::usage = "\<AncestralGraphPattern is matched by \
a list {AncestralLineage[\[Ellipsis]]...}, representing an ancestral graph. \
No detailed checks are made that this is a valid graph, however.\>";\)\)], \
"Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{

Cell["AncestralLineagePattern", "Subsubsection",
  InitializationCell->True],

Cell[BoxData[
    \(\(AncestralLineagePattern::usage = "\<AncestralLineagePattern is \
matched by an AncestralLineage[\[Ellipsis]]\>";\)\)], "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{

Cell["ExtractLabel", "Subsubsection",
  InitializationCell->True],

Cell[BoxData[
    \(\(ExtractLabel::usage = "\<ExtractLabel is a rule which replaces \
AncestralLineage[l,\[Ellipsis]] by its label, l.\>";\)\)], "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{

Cell["CoalesceLineages", "Subsubsection",
  InitializationCell->True],

Cell[BoxData[
    \(\(CoalesceLineages::usage = \
\*"\"\<CoalesceLineages[AncestralLineage[l1,\[Ellipsis]],AncestralLineage[l2,\
\[Ellipsis]],l12,t] gives a lineage l12 which is ancestral to l1, l2, \
generated by a coalescence event at time t.  By default, corresponding \
elements of information lists are put into a set; InformationFunction\[Rule]f \
generates a new information list f[\!\(i\_1\),\!\(i\_2\)]\>\"";\)\)], "Input",\

  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{

Cell["InformationFunction", "Subsubsection",
  InitializationCell->True],

Cell[BoxData[
    \(\(InformationFunction::usage = "\<InformationFunction->f is an option \
for functions dealing with ancestral graphs, which specifies how the \
information associated with each lineage should be handled.\>";\)\)], "Input",\

  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{

Cell["RecombineLineage", "Subsubsection",
  InitializationCell->True],

Cell[BoxData[
    \(\(RecombineLineage::usage = "\<RecombineLineage[AncestralLineage[l,\
\[Ellipsis]],{lL,lR},x,t] generates two recombinant lineages, with breakpoint \
at map position x, and labelled lL, lR. By default, the information lists are \
duplicated; InformationFunction\[Rule]{fL,fR} generates a pair of information \
lists {fL[i],fR[i]}.\>";\)\)], "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{

Cell["Junctions", "Subsubsection",
  InitializationCell->True],

Cell[BoxData[
    \(\(Junctions::usage = "\<Junctions[AncestralLineage[\[Ellipsis]]] lists \
the junctions present in the lineage.  \
Junctions[{AncestralLineage[\[Ellipsis]]\[Ellipsis]}] lists all the junctions \
present in the ancestral graph. \>";\)\)], "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{

Cell["MapLength", "Subsubsection",
  InitializationCell->True],

Cell[BoxData[
    \(\(MapLength::usage = "\<MapLength[AncestralLineage[\[Ellipsis]]] or \
MapLength[{AncestralLineage[\[Ellipsis]]\[Ellipsis]}] gives the map length, \
R. \>";\)\)], "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{

Cell["LineagesPresent", "Subsubsection",
  InitializationCell->True],

Cell[BoxData[
    \(\(LineagesPresent::usage = "\<LineagesPresent[{AncestralLineage[\
\[Ellipsis]],\[Ellipsis]},t] gives the set of lineages present at time t. \
LineagesPresent[{AncestralLineage[\[Ellipsis]],\[Ellipsis]}] lists all \
lineages\>";\)\)], "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{

Cell["RecombinantLineages", "Subsubsection",
  InitializationCell->True],

Cell[BoxData[
    \(\(RecombinantLineages::usage = \
"\<RecombinantLineages[{AncestralLineage[\[Ellipsis]]\[Ellipsis]}] gives \
lineages which start at the same time as a sister lineage\>";\)\)], "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{

Cell["CoalescentLineages", "Subsubsection",
  InitializationCell->True],

Cell[BoxData[
    \(\(CoalescentLineages::usage = "\<CoalescentLineages[{AncestralLineage[\
\[Ellipsis]]\[Ellipsis]}] gives lineages which start at the same time as two \
other lineages end\>";\)\)], "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{

Cell["RootLineages", "Subsubsection",
  InitializationCell->True],

Cell[BoxData[
    \(\(RootLineages::usage = "\<RootLineages[{AncestralLineage[\[Ellipsis]]\
\[Ellipsis]}] gives lineages which end when no other lineages \
begin.\>";\)\)], "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{

Cell["ExtractLineage", "Subsubsection",
  InitializationCell->True],

Cell[BoxData[
    \(\(ExtractLineage::usage = \*"\"\<ExtractLineage[{AncestralLineage[\
\[Ellipsis]]\[Ellipsis]},l] extracts the lineage labelled by l. Checks that \
there is only one such lineage. ExtractLineage[{AncestralLineage[\[Ellipsis]]\
\[Ellipsis]},{\!\(l\_1\),\[Ellipsis]}] extracts a list of lineages. \
\>\"";\)\)], "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{

Cell["ExtractLineagesEndingAtT", "Subsubsection",
  InitializationCell->True],

Cell[BoxData[
    \(\(ExtractLineagesEndingAtT::usage = \
"\<ExtractLineagesEndingAtT[{AncestralLineage[\[Ellipsis]]\[Ellipsis]},t] \
extracts those lineages which end at time t.  These are either root lineages, \
with no ancestors, or are generated by a coalescence or recombination.  \
Checks that these are present in the appropriate numbers.\>";\)\)], "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{

Cell["ExtractLineagesStartingAtT", "Subsubsection",
  InitializationCell->True],

Cell[BoxData[
    \(\(ExtractLineagesStartingAtT::usage = \
"\<ExtractLineagesStartingAtT[{AncestralLineage[\[Ellipsis]]\[Ellipsis]},t] \
extracts those lineages which start at time t.  These are either leaves, with \
no descendants, or are generated by a coalescence or recombination.  Checks \
that these are present in the appropriate numbers.\>";\)\)], "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{

Cell["TimesOfEvents", "Subsubsection",
  InitializationCell->True],

Cell[BoxData[
    \(\(TimesOfEvents::usage = \
"\<TimesOfEvents[{AncestralLineage[\[Ellipsis]]\[Ellipsis]}] lists all the \
times at which lineages begin or end.\>";\)\)], "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{

Cell["AllEvents", "Subsubsection",
  InitializationCell->True],

Cell[BoxData[
    \(\(AllEvents::usage = "\<AllEvents[{AncestralLineage[\[Ellipsis]]\
\[Ellipsis]}] lists all events at which lineages begin or end, in the form \
{t,descendants,ancestors,map position}. (The last element is set if there has \
been a recombination event; otherwise it is None).\>";\)\)], "Input",
  InitializationCell->True],

Cell["CoalescenceEvents", "SubsubsectionIcon",
  InitializationCell->True],

Cell[BoxData[
    \(\(CoalescenceEvents::usage = \
\*"\"\<CoalescenceEvents[{AncestralLineage[\[Ellipsis]]\[Ellipsis]}] lists \
events at which lineages {\!\(l\_1\),\[Ellipsis]} coalesce into lineage \!\(l\
\_p\), in the form {t,{\!\(l\_1\),\!\(l\_2\)},\!\(l\_P\)}.\>\"";\)\)], "Input",\

  InitializationCell->True],

Cell["NullLineages", "SubsubsectionIcon"],

Cell[BoxData[
    \(\(NullLineages::usage = "\<NullLineages[g] lists those lineages which \
contain no material ancestral to the sample.\>";\)\)], "Input",
  InitializationCell->True],

Cell["RecombinationEvents", "SubsubsectionIcon",
  InitializationCell->True],

Cell[BoxData[
    \(\(RecombinationEvents::usage = \
\*"\"\<RecombinationEvents[{AncestralLineage[\[Ellipsis]]\[Ellipsis]}] lists \
events at which a lineages \!\(l\_1\) splits into two lineage {\!\(l\_L\), \!\
\(l\_R\)} in the form {t,{\!\(l\_p\)},{\!\(l\_L\),\!\(l\_R\)},r}.\>\"";\)\)], \
"Input",
  InitializationCell->True],

Cell["NullRecombinationEvents", "SubsubsectionIcon",
  InitializationCell->True],

Cell[BoxData[
    \(\(NullRecombinationEvents::usage = \
\*"\"\<NullRecombinationEvents[{AncestralLineage[\[Ellipsis]]\[Ellipsis]}] \
lists events at which a lineages \!\(l\_1\) splits into two lineages \
{\!\(l\_L\), \!\(l\_R\)}, but where one of these is null.  These have the \
form {t,{\!\(l\_p\)},{\!\(l\_L\),\!\(l\_R\)},R}.\>\"";\)\)], "Input",
  InitializationCell->True],

Cell["LeafEvents", "SubsubsectionIcon",
  InitializationCell->True],

Cell[BoxData[
    \(\(LeafEvents::usage = "\<LeafEvents[{AncestralLineage[\[Ellipsis]]\
\[Ellipsis]}] lists events at which a lineages becomes extinct.\>";\)\)], \
"Input",
  InitializationCell->True],

Cell["RootEvents", "SubsubsectionIcon",
  InitializationCell->True],

Cell[BoxData[
    \(\(RootEvents::usage = "\<RootEvents[{AncestralLineage[\[Ellipsis]]\
\[Ellipsis]}] lists events at which an ancestral lineage begins.\>";\)\)], \
"Input",
  InitializationCell->True],

Cell["TimespanOfLineage", "SubsubsectionIcon",
  InitializationCell->True],

Cell[BoxData[
    \(\(TimespanOfLineage::usage = "\<TimespanOfLineage[{AncestralLineage[\
\[Ellipsis]]\[Ellipsis]},l] gives the start and end times,{t0,t1}, of lineage \
l.\>";\)\)], "Input",
  InitializationCell->True],

Cell["MapPosition", "SubsubsectionIcon",
  InitializationCell->True],

Cell[BoxData[
    \(\(MapPosition::usage = "\<MapPosition\[Rule]x is an option for \
Descendants which specifies that only descendants at map position x are \
counted.\>";\)\)], "Input",
  InitializationCell->True],

Cell["AddDescendants", "SubsubsectionIcon",
  InitializationCell->True],

Cell[BoxData[
    \(\(AddDescendants::usage = "\<AddDescendants[g,{l}] returns \
{l,Descendants[g,l]}.\>";\)\)], "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{

Cell["AncestorList", "Subsubsection",
  InitializationCell->True],

Cell[BoxData[
    \(\(AncestorList::usage = "\<AncestorList is an option for Ancestors; it \
may be set to Previous, All or Roots\>";\)\)], "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{

Cell["AddAncestors", "Subsubsection",
  InitializationCell->True],

Cell[BoxData[
    \(\(AddAncestors::usage = "\<AddAncestors[g,{l}] returns \
{l,Ancestors[g,l]}.\>";\)\)], "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{

Cell["DeleteNullLineages", "Subsubsection"],

Cell[BoxData[
    \(\(DeleteNullLineages::usage = "\<DeleteNullLineages[g] deletes \
ancestral lineages that have no descedants.  DeleteNullLineages is also an \
option for AddRecombinantLineages which specifies whether lineages carrying \
no material ancestral to thhe sample are to be included.\>";\)\)], "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{

Cell["AddRecombinantLineages", "Subsubsection",
  InitializationCell->True],

Cell[BoxData[
    \(\(AddRecombinantLineages::usage = \
"\<AddRecombinantLineages[g,l,{lL,lR},x,t] terminates lineage l, and adds two \
recombinant lineages {lL,lR} to the list g. DeleteNullLineages->True ignores \
null recombination events.\>";\)\)], "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{

Cell["AddCoalescentLineage", "Subsubsection",
  InitializationCell->True],

Cell[BoxData[
    \(\(AddCoalescentLineage::usage = "\<AddCoalescentLineage[g,{l1,l2},lC,t] \
terminates lineages {l1,l2} at t, and adds a coalescent lineage lC to the \
list g.\>";\)\)], "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{

Cell["PrintDetails", "Subsubsection"],

Cell[BoxData[
    \(\(PrintDetails::usage = "\<PrintDetails is an option for \
RandomGenealogy\>";\)\)], "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{

Cell["Segments", "Subsubsection"],

Cell[BoxData[
    \(\(Segments::usage = "\<Segments[AncestralLineage[\[Ellipsis]],l] gives \
the blocks ancestral to l present within the lineage.  \
Segments[{AncestralLineage[\[Ellipsis]]\[Ellipsis]},l] applies to several \
lineages\>";\)\)], "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{

Cell["PlotSegments", "Subsubsection"],

Cell[BoxData[
    \(\(PlotSegments::usage = \
"\<PlotSegments[AncestralLineage[\[Ellipsis]],leaf,y] gives a Graphics[] \
object depicting the segments ancestral to the leaf; drawn at height y.  \
SegmentStyle\[Rule]{Blue,\[Ellipsis]} and BackgroundStyle\[Rule]{Yellow,\
\[Ellipsis]} set the style of the lines.  PlotSegments[{AncestralLineage[\
\[Ellipsis]]\[Ellipsis]},leaf,{y0,y1}] plots a series of lineages spanning \
{y0,y1}; JunctionStyle specifies vertical lines depicting the junctions. \>";\
\)\)], "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{

Cell["BackgroundStyle", "Subsubsection"],

Cell[BoxData[
    \(\(BackgroundStyle::usage = "\<BackgroundStyle is an option for \
PlotSegments which sets the style of non-ancestral parts of the chromosome; \
default {Yellow}\>";\)\)], "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{

Cell["SegmentStyle", "Subsubsection"],

Cell[BoxData[
    \(\(SegmentStyle::usage = "\<SegmentStyle is an option for PlotSegments \
which sets the style of ancestral parts of the chromosome; default {Blue}\>";\
\)\)], "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{

Cell["JunctionStyle", "Subsubsection"],

Cell[BoxData[
    \(\(JunctionStyle::usage = "\<JunctionStyle is an option for PlotSegments \
which sets the style of vertical lines depicting junctions; default \
{Black}\>";\)\)], "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{

Cell["TimeSpanOfJunctions", "Subsubsection"],

Cell[BoxData[
    \(\(TimespanOfJunction::usage = "\<TimespanOfJunction[{AncestralLineage[\
\[Ellipsis]]\[Ellipsis]},j] finds the first and last occurrence of j. \
\>";\)\)], "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{

Cell["FixedQ", "Subsubsection"],

Cell[BoxData[
    \(\(FixedQ::usage = "\<FixedQ[AncestralLineage[\[Ellipsis]],lvs] tests \
whether this ancestral lineage only contains segments ancestral to the entire \
set lvs.  Can also apply to an ancestral graph\>";\)\)], "Input",
  InitializationCell->True]
}, Open  ]],

Cell[CellGroupData[{

Cell["MaxTime", "Subsubsection"],

Cell[BoxData[
    \(\(MaxTime::usage = "\<MaxTime is an option for RandomGenealogy which \
specifies the maximum time to run the coalescent with \
recombination.\>";\)\)], "Input",
  InitializationCell->True]
}, Open  ]],

Cell[CellGroupData[{

Cell["Fixation", "Subsubsection",
  InitializationCell->True],

Cell[BoxData[
    \(\(Fixation::usage = "\<Fixation is an option for RandomGenealogy which \
specifies that the coalescent with recombination stops at fixation\>";\)\)], \
"Input",
  InitializationCell->True]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["Describing genealogies", "Subsection"],

Cell[CellGroupData[{

Cell["MRCA", "Subsubsection",
  InitializationCell->True],

Cell[BoxData[
    \(\(MRCA::usage = \*"\"\<MRCA[g,{\!\(node\_1\),\[Ellipsis]}] gives the \
most recent common ancestor of the list of nodes.\>\"";\)\)], "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{

Cell["PairwiseDivergence", "Subsubsection",
  InitializationCell->True],

Cell[BoxData[
    \(\(PairwiseDivergence::usage = \*"\"\<PairwiseDivergence[g] lists the \
time to MRCA of all pairs of leaves.  \
PairwiseDivergence[g,{\!\(node\_1\),\!\(node\_2\)}] gives the time to the \
MRCA of these nodes.\>\"";\)\)], "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{

Cell["PairwiseDifference", "Subsubsection",
  InitializationCell->True],

Cell[BoxData[
    \(\(PairwiseDifference::usage = \*"\"\<PairwiseDifference[g] lists the \
number of sites which differ between randomly chosen pairs.  \
PairwiseDifference[g,{\!\(node\_1\),\!\(node\_2\)}] gives the mutations which \
differ between the nodes.\>\"";\)\)], "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{

Cell["MeanPairwiseDivergence", "Subsubsection",
  InitializationCell->True],

Cell[BoxData[
    \(\(MeanPairwiseDivergence::usage = "\<MeanPairwiseDivergence[g] gives \
the mean time back to a common ancestor between two genes.\>";\)\)], "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{

Cell["ExtractCoalescenceTimes", "Subsubsection",
  InitializationCell->True],

Cell[BoxData[
    \(\(ExtractCoalescenceTimes::usage = "\<ExtractCoalescenceTimes[g] \
extracts a list of the coalescence times.\>";\)\)], "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{

Cell["LengthOfGenealogy", "Subsubsection",
  InitializationCell->True],

Cell[BoxData[
    \(\(LengthOfGenealogy::usage = "\<LengthOfGenealogy[g] gives the total \
length of the genealogy.\>";\)\)], "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{

Cell["DepthOfGenealogy", "Subsubsection",
  InitializationCell->True],

Cell[BoxData[
    \(\(DepthOfGenealogy::usage = "\<DepthOfGenealogy[g] gives the time to \
the last common ancestor.\>";\)\)], "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{

Cell["PairwiseDivergencePlot", "Subsubsection",
  InitializationCell->True],

Cell[BoxData[
    \(\(PairwiseDivergencePlot::usage = \
\*"\"\<PairwiseDivergencePlot[g,{Dmax,\[Delta]}] plots the distribution of \
pairwise divergence as a histogram, on the range {0,Dmax}.  \
PairwiseDivergencePlot[{\!\(g\_1\),\[Ellipsis]},{Dmax,\[Delta]}] plots the \
overall distribution for a set of replicate genealogies.\>\"";\)\)], "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{

Cell["PairwiseDifferencePlot", "Subsubsection",
  InitializationCell->True],

Cell[BoxData[
    \(\(PairwiseDifferencePlot::usage = \
\*"\"\<PairwiseDifferencePlot[g,{Dmax,\[Delta]}] plots the distribution of \
pairwise difference as a histogram, on the range {0,Dmax}.  \
PairwiseDifferencePlot[{\!\(g\_1\),\[Ellipsis]},{Dmax,\[Delta]}] plots the \
overall distribution for a set of replicate genealogies.\>\"";\)\)], "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{

Cell["BlockSizes", "Subsubsection"],

Cell[BoxData[
    \(\(BlockSizes::usage = \*"\"\<BlockSizes[AncestralLineage[l,{\!\(t\_0\),\
\!\(t\_1\)},{{},{\[Ellipsis]},\[Ellipsis]},{\!\(r\_1\),\[Ellipsis],R},{\
\[Ellipsis]}]] returns the sizes of blocks with different descendants. \
BlockSizes[g] applies to a whole ancestral graph.\>\"";\)\)], "Input",
  InitializationCell->True]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Private parts", "Section"],

Cell[BoxData[
    \(\(Begin["\<Genealogies`Genealogies`Private`\>"];\)\)], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(\(<< "\<Utilities`SetManipulation`\>";\)\)], "Input",
  InitializationCell->True],

Cell[CellGroupData[{

Cell["Describing genealogies", "Subsection"],

Cell[CellGroupData[{

Cell[TextData[
"CollapseGenealogy[genealogy] reduces the genealogy to a nested list. \
CollapseGenealogy[genealogy, Node\[Rule]False] only lists the leaves."], 
  "Subsubsection"],

Cell[BoxData[
    \(\(Options[CollapseGenealogy] = {Node \[Rule] True, 
          NodeFunction \[Rule] \((#1 &)\), Nested \[Rule] True};\)\)], "Input",\

  InitializationCell->True],

Cell[BoxData[
    \(\(CollapseGenealogy[g_Node, opts___Rule] := 
        Module[{ff = \(NodeFunction /. {opts}\) /. 
                Options[CollapseGenealogy]}, 
          If[\(Nested /. {opts}\) /. Options[CollapseGenealogy], \n
            If[\(Node /. {opts}\) /. 
                Options[
                  CollapseGenealogy], \(g //. {Node[i_, 
                        s_List, {m___Node}] :> {ff[i, 
                          s], {m}}}\) /. {{i_, {}} :> 
                    i}, \n\t\tg //. {Node[i_, s_List, {m__Node}] :> {m}, 
                  Node[i_, s_List, {}] :> ff[i, s]}], \n
            If[\(Node /. {opts}\) /. 
                  Options[
                    CollapseGenealogy], \n\t\t\t\t\(Extract[{g}, #] &\) /@ 
                  Position[{g}, 
                    Node[i_, s_List, {m___Node}]], \n\t\(Extract[{g}, #] &\) /@ 
                  Position[{g}, Node[i_, s_List, {}]]] //. 
              Node[i_, s_List, {m___Node}] :> ff[i, s]]];\)\)], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(\(CollapseGenealogy[{g__Node}, opts___Rule] := 
        Module[{ff = \(NodeFunction /. {opts}\) /. 
                Options[CollapseGenealogy]}, 
          If[\(Node /. {opts}\) /. Options[CollapseGenealogy], \n\t\t\t\t{g} /. 
              Node[i_, s_List, _List] :> 
                ff[i, s], \n\t\ \ \ \ \ \ \ Cases[{g}, \ Node[_, _, {_}]] /. 
              Node[i_, s_List, {_}] :> ff[i, s]]];\)\)], "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{

Cell["\<\
Nodes[g] lists all the nodes of the genealogy g, including the \
leaves. \
\>", "Subsubsection"],

Cell[BoxData[
    \(\(Nodes[
          g_Node] := \(\(Extract[{g}, #]\)\[LeftDoubleBracket]1\
\[RightDoubleBracket] &\) /@ 
          Position[{g}, Node[_, _List, {___Node}]];\)\)], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(\(Nodes[{g___Node}] := \t{g} /. 
          Node[i_, _List, _List] :> i;\)\)], "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{

Cell["\<\
InternalNodes[g] lists the internal nodes of the genealogy g.\
\>", 
  "Subsubsection"],

Cell[BoxData[
    \(\(InternalNodes[
          g_Node] := \(\(Extract[{g}, #]\)\[LeftDoubleBracket]1\
\[RightDoubleBracket] &\) /@ 
          Position[{g}, Node[_, _List, {m__Node}]];\)\)], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(\(InternalNodes[{g___Node}] := 
        Complement[Nodes[{g}], Leaves[{g}]];\)\)], "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{

Cell["Leaves[g] lists the terminal nodes of the genealogy g.", "Subsubsection"],

Cell[BoxData[
    \(\(Leaves[
          g_Node] := \(\(Extract[{g}, #]\)\[LeftDoubleBracket]1\
\[RightDoubleBracket] &\) /@ 
          Position[{g}, Node[i_, s_List, {}]];\)\)], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(\(Leaves[{g___Node}] := 
        Cases[{g}, \ Node[_, _List, {_}]] /. 
          Node[i_, _List, {_}] :> i;\)\)], "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{

Cell["\<\
ExtractInformation[g,i] gives the information associated with node \
i.\
\>", "Subsubsection"],

Cell[BoxData[
    \(\(ExtractInformation[g_Node, i_] := 
        Module[{ps = Position[g, Node[i, _List, _List]]}, \n\t\tSwitch[
            Length[ps], \n\t\t\t1, 
            Extract[g, 
              Append[ps\[LeftDoubleBracket]1\[RightDoubleBracket], 
                2]], \n\t\t\t0, \(Print[i, "\< does not appear in \>", 
                g];\), \n\t\t\t_, 
            Print[i, "\< appears more than once in \>", g]]];\)\)], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(\(ExtractInformation[g_Node] := \(ExtractInformation[g, #] &\) /@ 
          Nodes[g];\)\)], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(\(ExtractInformation[{___Node, Node[i_, info_List, _List], ___Node}, 
          i_] := info;\)\)], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(\(ExtractInformation[{g__Node}] := \(ExtractInformation[{g}, #] &\) /@ 
          Nodes[{g}];\)\)], "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{

Cell["\<\
TransformInformation[g,f] replaces the information list info by \
f[node,info].\
\>", "Subsubsection"],

Cell[BoxData[
    \(\(TransformInformation[g_Node, 
          f_] := \(g //. {Node[i_, si_List, {nn___Node}] :> 
                NodeTemp[i, f[i, si], {nn}]}\) /. {NodeTemp \[Rule] 
              Node};\)\)], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(\(TransformInformation[{g__Node}, 
          f_] := \({g} //. {Node[i_, si_List, {nn___}] :> 
                NodeTemp[i, f[i, si], {nn}]}\) /. {NodeTemp \[Rule] 
              Node};\)\)], "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{

Cell["\<\
DeleteGenealogy[g,i] deletes the genealogy that descends from node \
i.\
\>", "Subsubsection"],

Cell[BoxData[
    \(\(DeleteGenealogy[g_Node, i_] := 
        Module[{ps = Position[g, Node[i, _List, _List]]}, \n\t\tSwitch[
            Length[ps], \n\t\t\t1, 
            Delete[g, 
              ps\[LeftDoubleBracket]1\[RightDoubleBracket]], \n\t\t\t0, \
\(Print[i, "\< does not appear in \>", g];\), \n\t\t\t_, 
            Print[i, "\< appears more than once in \>", g]]];\)\)], "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{

Cell["\<\
CondenseGenealogy[g] removes all nodes that have only one \
descendant.\
\>", "Subsubsection"],

Cell[BoxData[
    \(\(CondenseGenealogy[g_Node] := 
        g //. {Node[p_, 
                pi_List, {m1___Node, Node[x_, y_List, {z_Node}], m2___Node}] :> 
              Node[p, pi, {m1, z, m2}]};\)\)], "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{

Cell["\<\
ExtractGenealogy[g,i] gives the genealogy that descends from node \
i.\
\>", "Subsubsection"],

Cell[BoxData[
    \(\(ExtractGenealogy[g_Node, i_] := 
        Module[{ps = Position[g, Node[i, _List, _List]]}, \n\t\tSwitch[
            Length[ps], \n\t\t\t1, 
            If[ps\[LeftDoubleBracket]1\[RightDoubleBracket] == {}, g, 
              Extract[g, 
                ps\[LeftDoubleBracket]1\[RightDoubleBracket]]], \n\t\t\t0, \
\(Print[i, "\< does not appear in \>", g];\), \n\t\t\t_, 
            Print[i, "\< appears more than once in \>", g]]];\)\)], "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    FormBox[
      RowBox[{
      \(AddGenealogy[g\_1, g\_2, i, j, info]\ adds\ genealogy\ g\_2\ to\ 
          genealogy\ g\_1\), ",", " ", 
        \(immediately\ above\ existing\ node\ i\ of\ g\_1 . \ \ The\ new\ node
          \ is\ labelled\ j\), ",", " ", 
        RowBox[{"and", " ", "carries", " ", "information", " ", 
          RowBox[{
            StyleBox["info",
              FontSlant->"Italic"], "."}]}]}], TextForm]], "Subsubsection"],

Cell[BoxData[{
    \(\(AddGenealogy[g1_Node, g2_Node, nn_, nn_] := 
        g1 /. {Node[nn, s1_List, {n1___}] :> 
              Node[nn, s1, {n1, g2}]};\)\), "\n", 
    \(\(AddGenealogy[g1_Node, g2_Node, nn_, nn_, info_] := 
        AddGenealogy[g1, g2, nn, nn];\)\)}], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(\(AddGenealogy[g1_Node, g2_Node, i_, nn_, info_] := 
        g1 /. {Node[i, s1_List, n1_List] :> 
              Node[nn, info, {Node[i, s1, n1], g2}]};\)\)], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(\(AddGenealogy[{g1__Node}, {g2__Node}, i1_, 
          i2_] := {g1, 
              g2} /. {Node[i1, inf1_, {a___}] :> Node[i1, inf1, {a, i2}], 
              Node[i2, inf2_, {a___}] :> Node[i2, inf2, {a, i1}]} // 
          Sort;\)\)], "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{

Cell["\<\
AddNode[g,i,k,info] adds a new node k immediately above existing \
node i of g.  The new node carries information info.  AddNode[g,i,j,k,info] \
adds a new node k between nodes i and j of an unrooted genealogy\
\>", 
  "Subsubsection"],

Cell[BoxData[
    \(\(AddNode[g_Node, i_, k_, info_]\  := \n\t
        g /. Node[i, si_, {m___Node}] :> 
            Node[k, info, {Node[i, si, {m}]}];\)\)], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(\(AddNode[{g__Node}, i_, j_, k_, 
          info_]\  := \n{g, 
            Node[k, info, {i, j}]} /. {Node[i, si_, {m___Node}] :> 
              Node[i, si, {m, k}], 
            Node[j, sj_, {m___Node}] :> Node[j, sj, {m, k}]};\)\)], "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    \(TextForm
    \`ListToGenealogy[list]\ constructs\ a\ genealogy\ from\ a\ nested\ list\ 
        of\ the\ form
        \ {label, {node\_1, node\_2, \[Ellipsis]}} . \ \ Information\ on\ each
        \ node\ can\ be\ included\ using\ NodeFunction \[Rule] f, \ 
    where\ f[label]\ gives\ a\ list\ of\ information\ for\ the\ node\ with\ 
      that\ label . \ \ 
        ListToGenealogy[{{a, b}, {c, d}}, Node \[Rule] False]\ gives\ a\ 
      genealogy\ relating\ objects\ {a, b, \[Ellipsis]} . \ \ Internal\ nodes
      \ are\ \(unlabelled . \)\)], "Subsubsection"],

Cell[BoxData[
    \(\(Options[ListToGenealogy] = {Node \[Rule] True, 
          NodeFunction \[Rule] \(({} &)\)};\)\)], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(\(ListToGenealogy[s_List, opts___Rule] := 
        Module[{ff = \(NodeFunction /. {opts}\) /. 
                Options[
                  ListToGenealogy]}, \n\t\t\(\(If[\(Node /. {opts}\) /. 
                    Options[
                      ListToGenealogy], \n\t\t\ts //. {List[i_, {m___}] :> 
                        Node[i /. 
                            List -> ListTemp, \((ff[i] /. 
                              List -> ListTemp)\), 
                          ListTemp[m]]}, \n\t\ts //. {m___} :> 
                      Node[ListTemp[], ListTemp[], 
                        ListTemp[m]]] /. {ListTemp -> List}\) //. {Node[i_, 
                    z_List, {x___, 
                      m_?\((\((FreeQ[#, Node] && FreeQ[#, NodeTemp])\) &)\), 
                      y___}] :> 
                  Node[i, z, {x, NodeTemp[m, ff[m], {}], y}]}\) /. 
            NodeTemp -> Node];\)\)], "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{

Cell["\<\
OrderedNodes[g,f] gives a list of the nodes in the genealogy, in \
the order defined by f[ i,{info}]\
\>", "Subsubsection"],

Cell[BoxData[
    \(\(Options[OrderedNodes] = {Node \[Rule] False};\)\)], "Input",
  InitializationCell->True],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(OrderedNodes[g_Node, f_, opts___Rule]\  := \n\t
        Module[{tt = CollapseGenealogy[g, NodeFunction \[Rule] f], 
            nn = CollapseGenealogy[g], 
            leaves}, \n\t\tIf[\(Node /. {opts}\) /. 
              Options[OrderedNodes], \n\t\t\ \ leaves = 
              CollapseGenealogy[g, Node \[Rule] False]; \n\t\t\ \ Select[
              OrderedNodes[g, 
                f], \((FreeQ[
                    leaves, \ #])\) &], \n\t\tJoin @@ \((\(\(Extract[
                          nn, #] &\) /@ Position[tt, \ #] &\) /@ \((Sort[
                      Union[tt // Flatten]])\))\)]];\)\)], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(General::"spell1" \(\(:\)\(\ \)\) 
      "Possible spelling error: new symbol name \"\!\(leaves\)\" is similar \
to existing symbol \"\!\(Leaves\)\"."\)], "Message"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["Ancestors[g,node] lists the ancestors of the node.", "Subsubsection"],

Cell[BoxData[
    \(\(Ancestors[g_Node, 
          i_] := \(\(g /. Node[i, {___}, {Node___}] :> {None}\) //. 
            Node[j_, {___}, {___, {None, k___}, ___}] :> {None, j, 
                k}\) /. {None, j___} :> {j};\)\)], "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{

Cell["\<\
Descendants[g,node] lists the immediate descendants of the node.  \
Descendants[g,node,DescendantList\[Rule]All] lists all the descendants of the \
node. Descendants[g,node,DescendantList\[Rule]Leaves] lists only the \
descendant leaves of the node.\
\>", "Subsubsection"],

Cell[BoxData[
    \(\(Options[Descendants] = {DescendantList \[Rule] Next};\)\)], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(\(Descendants[g_Node, i_, opts___Rule] := \n\t
        Module[{dl = \(DescendantList /. {opts}\) /. Options[Descendants], 
            tt, dd, ddn}, \n\t\tSwitch[
            dl, \n\t\t\ \ Next, \n\t\t\ \ \ \ Last[ExtractGenealogy[g, i]] /. 
              Node[j_, _List, _List] :> 
                j, \n\t\t\ \ All, \n\t\t\ \ \ \ tt = \(dd = 
                Descendants[g, i]\); \n\ \ \ \ \ \ \ \ \ While[
              Length[dd] > 0, \n\t\t\t\t\ \ ddn = {}; 
              Scan[\((ddn = Join[ddn, Descendants[g, #]])\) &, 
                dd]; \n\t\t\t\t\ \ dd = ddn; \n\t\t\t\t\ \ tt = 
                Join[tt, dd]]; 
            tt, \n\t\t\ \ Leaves, \n\t\t\ \ \ \ Intersection[
              Descendants[g, i, DescendantList \[Rule] All], 
              Leaves[g]], \n\t\t\ \ _, \n\t\t\ \ \ \ Print[
              dl, "\< is not a valid setting for DescendantList\>"]; \n\t\t\t\
$Failed]];\)\)], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(\(Descendants[{g__Node}, i_] := 
        Cases[{g}, 
            Node[i, _List, _List]] /. {{Node[_, _List, s_List]} :> 
              s};\)\)], "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{

Cell["\<\
MostRecentCommonAncestor[pop,i,j] gives the most recent common \
ancestor of nodes i, j\
\>", "Subsubsection"],

Cell[BoxData[
    \(\(MostRecentCommonAncestor[g_Node, i_, j_]\  := 
        First[Intersection[Ancestors[g, i], Ancestors[g, j]]];\)\)], "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{

Cell["UnrootedGenealogy[g] gives an unrooted genealogy.", "Subsubsection"],

Cell[BoxData[
    \(\(UnrootedGenealogy[g_Node] := 
        Module[{aa, 
            dd}, \n\t\t\(\((aa = 
                  Ancestors[g, #\[LeftDoubleBracket]1\[RightDoubleBracket]]; 
                dd = Descendants[
                    g, #\[LeftDoubleBracket]1\[RightDoubleBracket]]; \n\t
                Node[#\[LeftDoubleBracket]1\[RightDoubleBracket], #\
\[LeftDoubleBracket]2\[RightDoubleBracket], 
                  If[aa === {}, dd, Append[dd, Last[aa]]]])\) &\) /@ 
            Sort[CollapseGenealogy[g, Nested \[Rule] False, 
                NodeFunction \[Rule] \(({#1, #2} &)\)]]];\)\)], "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    FormBox[GridBox[{
          {\(RootedGenealogy[g, i]\), 
            \(roots\ an\ unrooted\ genealogy\ at\ node\ i\)}
          }], TextForm]], "Subsubsection"],

Cell[BoxData[
    \(\(RootedGenealogy[{g__Node}, k_] := 
        Node[k, ExtractInformation[{g}, k], 
            List /@ Descendants[{g}, k]] //. {Node[i_, 
                si_List, {m__List}] :> \n\t\t\t\t\t\tNode[i, 
                si, \(Node[#\[LeftDoubleBracket]1\[RightDoubleBracket], 
                      ExtractInformation[{g}, #\[LeftDoubleBracket]1\
\[RightDoubleBracket]], \n\t\t\t\t\t\tList /@ 
                        DeleteCases[
                          Descendants[{g}, #\[LeftDoubleBracket]1\
\[RightDoubleBracket]], i]] &\) /@ {m}]};\)\)], "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{

Cell["\<\
SiblingList[g] lists all pairs of leaves which are directly \
related.\
\>", "Subsubsection"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(SiblingList[g_Node]\  := 
        Module[{\n\t\t\tleaves = Leaves[g], \n\t\t\tnodes = 
              InternalNodes[g], \n\t\t\tdl, ff, ss, i, j, n}, \n\t\tn = 
            Length[leaves]; \n\t\tdl = \(Descendants[g, #] &\) /@ 
              nodes; \n\t\ ff[{x_, y_}] := 
            Or @@ \((\(\((MemberQ[#, \ x] && MemberQ[#, \ y])\) &\) /@ 
                  dl)\); \n\t\ \ ss = 
            Flatten[Table[{leaves\[LeftDoubleBracket]i\[RightDoubleBracket], 
                  leaves\[LeftDoubleBracket]j\[RightDoubleBracket]}, {i, 2, 
                  Length[leaves]}, {j, i - 1}], 1]; \n\t\ \ Select[ss, 
            ff]];\)\)], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(General::"spell1" \(\(:\)\(\ \)\) 
      "Possible spelling error: new symbol name \"\!\(nodes\)\" is similar to \
existing symbol \"\!\(Nodes\)\"."\)], "Message"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["\<\
SizeOfGenealogyPlot[g] gives the minimum and maximum coordinates, \
held as the last element of the information lists in g.\
\>", "Subsubsection"],

Cell[BoxData[
    \(\(SizeOfGenealogyPlot[g_Node] := 
        Module[{ei = Transpose[Last /@ ExtractInformation[g]]}, \n\t\t{Min /@ 
              ei, Max /@ ei}];\)\)], "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{

Cell["\<\
MakeGenealogyPlot[g] appends coordinates to the information lists; \
these are used by PlotGenealogy[].\
\>", "Subsubsection"],

Cell[BoxData[
    \(\(MakeGenealogyPlot[\ Node[i_, si_, {}]] := 
        Node[i, Append[si, {0, 0}], {}];\)\)], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(\(MakeGenealogyPlot[Node[i_, si_List, {nn__Node}]] := \n\t
        Module[{k = Length[{nn}], j, gl = MakeGenealogyPlot /@ {nn}, xl, xt, 
            al, ngl}, \n\t\tsl = 
            SizeOfGenealogyPlot /@ 
              gl; \n\t\txl = \(\((#\[LeftDoubleBracket]2, 
                      1\[RightDoubleBracket] - #\[LeftDoubleBracket]1, 
                      1\[RightDoubleBracket])\) &\) /@ sl; \n\t\tal = 
            Range[0, k] + FoldList[Plus, 0, xl]; \n\t\tngl = 
            Table[TransformInformation[
                gl\[LeftDoubleBracket]
                  j\[RightDoubleBracket], \((ReplacePart[#2, {#2\
\[LeftDoubleBracket]\(-1\), 1\[RightDoubleBracket] + 
                          al\[LeftDoubleBracket]
                            j\[RightDoubleBracket], \
#2\[LeftDoubleBracket]\(-1\), 2\[RightDoubleBracket]}, \(-1\)] &)\)], {j, 
                k}]; Node[i, 
            Append[si, {\((Last[al] - 1)\)/2, 
                1 + Max[\(\((# /. {{_, _}, {_, y_}} :> y)\) &\) /@ sl]}], 
            ngl]];\)\)], "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData[
"PlotGenealogy[g] plots a genealogy; the coordinates are held as the last \
element of the information lists.  These may be generated by \
MakeGenealogyPlot[g].   PlotGenealogy[g,NodeFunction\[Rule]f] uses f[i,info] \
to derive the coordinates; this might represent coalescence time, for \
example."], "Subsubsection"],

Cell[BoxData[
    \(\(Options[
          PlotGenealogy] = {NodeFunction \[Rule] \
\((#2\[LeftDoubleBracket]\(-1\)\[RightDoubleBracket] &)\), 
          NodeLabels \[Rule] \((#1 &)\), LeafLabels \[Rule] \((#1 &)\), 
          MakeGenealogyPlot \[Rule] True, LeafOffset \[Rule] {0, \(-0.2\)}, 
          NodeOffset \[Rule] {\(-0.2\), 0.2}};\)\)], "Input",
  InitializationCell->True],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(PlotGenealogy[gg_Node, opts___Rule] := 
        Module[{nf = \(NodeFunction /. {opts}\) /. Options[PlotGenealogy], 
            nlab, llab, \n\t\t\ \ \ lv = Leaves[gg], 
            nl = Nodes[gg], \n\t\t\t\ dl, ll, j, gl, nlF, llF, 
            g, \n\t\t\t\ lo = \(LeafOffset /. {opts}\) /. 
                Options[
                  PlotGenealogy], \n\t\t\t\ no = \(NodeOffset /. {opts}\) /. 
                Options[PlotGenealogy]}, \n\t\tg = 
            If[\(MakeGenealogyPlot /. {opts}\) /. Options[PlotGenealogy], 
              MakeGenealogyPlot[gg], 
              gg]; \n\t\tnlF = \(NodeLabels /. {opts}\) /. 
              Options[PlotGenealogy]; \n\t\tllF = \(LeafLabels /. {opts}\) /. 
              Options[PlotGenealogy]; \n\t\tnl = Complement[nl, lv]; 
          dl = \((\(Descendants[g, #] &\) /@ nl)\); \n\t\ \ ll = 
            Flatten[Table[\({nl\[LeftDoubleBracket]
                        j\[RightDoubleBracket], #} &\) /@ 
                  dl\[LeftDoubleBracket]j\[RightDoubleBracket], {j, 
                  Length[dl]}], 
              1]; \n\t\ \ gl = \(Line[{nf[#\[LeftDoubleBracket]1\
\[RightDoubleBracket], 
                      ExtractInformation[
                        g, #\[LeftDoubleBracket]1\[RightDoubleBracket]]], 
                    nf[#\[LeftDoubleBracket]1\[RightDoubleBracket], 
                      ExtractInformation[
                        g, #\[LeftDoubleBracket]2\[RightDoubleBracket]]]}] \
&\) /@ ll; \n\t\ \ nlab = \(ExtractInformation[g, #] &\) /@ nl; \n\t\tnlab = 
            If[nlF === None, \n\t\t\t\t{}, \n\t\t\tMapThread[
                Text, {MapThread[
                    nlF, {nl, 
                      nlab}], \n\t\t\t\t\t\t\((\(\((nf[#, 
                              ExtractInformation[g, #]] + no)\) &\) /@ 
                      nl)\)}]]; \n\ \ \ \ \ llab = \(ExtractInformation[
                  g, #] &\) /@ lv; \n\t\t\ llab = 
            If[llF === None, \n\t\t\t\t{}, \n\t\t\tMapThread[
                Text, {MapThread[
                    llF, {lv, 
                      llab}], \n\t\t\t\t\t\t\((\(\((nf[#, 
                              ExtractInformation[g, #]] + lo)\) &\) /@ 
                      lv)\)}]]; \n
          Graphics[Join[gl, nlab, llab], 
            PlotRange \[Rule] \((Transpose[
                    SizeOfGenealogyPlot[g]] + {{\(-1\), 1}, {\(-1\), 
                      1}})\)]];\)\)], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(General::"spell1" \(\(:\)\(\ \)\) 
      "Possible spelling error: new symbol name \"\!\(llab\)\" is similar to \
existing symbol \"\!\(nlab\)\"."\)], "Message"]
}, Closed]]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["Family structures", "Subsection"],

Cell[CellGroupData[{

Cell["\<\
GenealogyToFamily[g,f] gives a list of the family structures \
following successive coalescences. The function f[i,{info}] gives the \
ordering of the coalescence for node i.\
\>", "Subsubsection"],

Cell[BoxData[
    \(\(GenealogyToFamily[g_Node, f_] := 
        Module[{no = OrderedNodes[g, f], 
            leaves = CollapseGenealogy[g, Node \[Rule] False], ng, 
            fl}, \n\t\tno = 
            Select[no, \((FreeQ[leaves, \ #])\) &]; \n\t\tng = \(g //. 
                Node[i_, s_List, m_List] :> 
                  NodeTemp[i, {NumberOfLineages[g, i]}, m]\) /. 
              NodeTemp -> Node; \n\t\tfl = 
            FoldList[\((#1 /. Node[#2, x_, m_List] :> Node[#2, x, {}])\) &, 
              ng, no]; \n\t\t\(Flatten[
                CollapseGenealogy[#, Node -> False, 
                  NodeFunction -> \((#2 &)\)]] &\) /@ fl];\)\)], "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    \(TextForm
    \`FamilyToGenealogy[{a, b, c, \[Ellipsis]}, S]\ gives\ a\ randomly\ 
      constructed\ genealogy\ which\ satistfies\ the\ sequence\ of\ family\ 
      structures\ S, \ 
    and\ which\ relates\ {a, b, c, \[Ellipsis]} . \ \ The\ terminal\ nodes\ 
      are\ labelled\ by\ {a, b, c, \[Ellipsis]}, \ 
    and\ the\ internal\ nodes\ are\ labelled\ by\ integers\ giving\ the\ order
        \ of\ the\ coalescence\ events . \ NodeLabels \[Rule] 
      \({label\_1, \[Ellipsis]}\ allows\ an\ arbitrary\ list\ of\ labels\ for
          \ the\ internal\ nodes . \ \ NodeInformation 
        \[Rule] {info\_1, \[Ellipsis]}\), \ 
    LeafInformation 
      \[Rule] {info\_a, \[Ellipsis]}\ allow\ arbitrary\ lists\ of\ information
        \ to\ be\ associated\ with\ the\ nodes\ and\ leaves . \ \ With\ n\ 
        items, \ there\ are\ n\ nodes, \ 
    and\ so\ all\ the\ optional\ lists\ must\ have\ length\ \(n . \)\)], 
  "Subsubsection"],

Cell[BoxData[
    \(\(Options[FamilyToGenealogy] = {NodeInformation \[Rule] None, 
          LeafInformation \[Rule] None, 
          NodeLabels \[Rule] None};\)\)], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(\(FamilyToGenealogy[ls_, sf_, opts___Rule] := 
        Module[{ss, ds, ts, j, k, n = Length[sf], nl, ni, 
            li}, \n\t\tni = \(NodeInformation /. {opts}\) /. 
              Options[FamilyToGenealogy]; \n\t\ \ nl = \(NodeLabels /. {opts}\
\) /. Options[FamilyToGenealogy]; \n\t\tli = \(LeafInformation /. {opts}\) /. 
              Options[FamilyToGenealogy]; 
          If[nl == None, nl = Range[n]]; \n\t\t\tIf[ni == None, 
            ni = \({} &\) /@ nl]; 
          If[li == None, li = \({} &\) /@ nl]; \n\t\tss = 
            Node[nl\[LeftDoubleBracket]\(-1\)\[RightDoubleBracket], 
              ni\[LeftDoubleBracket]\(-1\)\[RightDoubleBracket], 
              MapThread[Node[#1, #2, {}] &, {ls, li}]]; \n\t\tDo[\n\t\t\tds = 
              Frequencies[
                TakeAway[sf\[LeftDoubleBracket]j\[RightDoubleBracket], 
                  ExactIntersection[
                    sf\[LeftDoubleBracket]j\[RightDoubleBracket], 
                    sf\[LeftDoubleBracket]j + 
                        1\[RightDoubleBracket]]]]; \n\t\t\tts = 
              Flatten[Table[
                  RandomSet[ds\[LeftDoubleBracket]k, 1\[RightDoubleBracket], 
                    Select[ss\[LeftDoubleBracket]3\[RightDoubleBracket], \
\((NumberOfLineages[#] == ds\[LeftDoubleBracket]k, 
                              2\[RightDoubleBracket])\) &]], \n\t\t\t\t\t{k, 
                    Length[ds]}], 1]; \n\t\t\tss = 
              Node[nl\[LeftDoubleBracket]\(-1\)\[RightDoubleBracket], 
                ni\[LeftDoubleBracket]\(-1\)\[RightDoubleBracket], 
                Append[TakeAway[ss\[LeftDoubleBracket]3\[RightDoubleBracket], 
                    ts], Node[nl\[LeftDoubleBracket]j\[RightDoubleBracket], 
                    ni\[LeftDoubleBracket]j\[RightDoubleBracket], 
                    ts]]], \n\t\t\t{j, n - 1}]; \n\t\tss];\)\)], "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    \(TextForm
    \`GenealogyB[j, i, k]\ is\ the\ coefficient\ of\ 
      Exp[\(-\[Lambda]\_i\) t/2  N]\ in\ the\ expression\ for\ P\_j, \ 
    the\ probability\ of\ j\ coalescences\ having\ \(occurred . \)\)], 
  "Subsubsection",
  InitializationCell->True],

Cell[BoxData[{
    \(\(GenealogyB[k_, k_, k_] := \(GenealogyB[k, k, k] = 1\);\)\), "\n", 
    \(\(GenealogyB[j_, i_, k_] := \(GenealogyB[j, i, k] = 
          If[i < j, 
            0, \n\t\t\tIf[
              i == j, \(-\(\[Sum]\+\(ii = j + 1\)\%k GenealogyB[j, ii, 
                    k]\)\), \(\(j \((j + 1)\)\)\/\(j \((j - 1)\) - 
                      i \((i - 1)\)\)\) 
                GenealogyB[j + 1, i, k]]]\);\)\)}], "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{

Cell["\<\
CoalescenceDistribution[j,k,t] is the probability of j coalescences \
having occurred among k lineages over t generations (scaled to 2N)\
\>", 
  "Subsubsection",
  InitializationCell->True],

Cell[BoxData[
    \(\(CoalescenceDistribution[j_, k_, t_] := 
        Module[{i}, 
          Sum[GenealogyB[j, i, k] Exp[\(-i\) \((i - 1)\) t/2], {i, j, 
              k}]\ ];\)\)], "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{

Cell["\<\
SimplifyFamilies replaces duplications such as {{1,3},{2,2},{2,1}} \
by {{1,3},{2,3}}\
\>", "Subsubsection",
  InitializationCell->True],

Cell[BoxData[
    \(\(SimplifyFamilies = {{x___List, {n1a_, a_}, y___List, {n2a_, a_}, 
              z___List} :> Sort[{x, {n1a + n2a, a}, y, z}]};\)\)], "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{

Cell["\<\
FamilyProbability[S] gives the probability that this family \
structure would be produced, given a certain number of coalescence \
events\
\>", "Subsubsection",
  InitializationCell->True],

Cell[BoxData[{
    \(\(FamilyProbability[{x__Integer}] := 
        FamilyProbability[Frequencies[{x}]];\)\), "\n", 
    \(\(FamilyProbability[{{_, 1}}] := 1;\)\)}], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(\(FamilyProbability[
          s_List] := \(FamilyProbability[s /. SimplifyFamilies] = 
          Module[{ss, i, \[Alpha], l, j, tl, tr, ni, mi, nm, ns, n1, 
              n2}, \n\t\tss = s /. SimplifyFamilies; l = Length[ss]; 
            j = NumberOfFamilies[
                ss]; \n\t\t\tSum[\((tl = Take[ss, i - 1]; \n\t\t\t\tni = 
                  ss\[LeftDoubleBracket]i, 2\[RightDoubleBracket]; \t
                mi = ss\[LeftDoubleBracket]i, 1\[RightDoubleBracket]; 
                nm = {mi - 1, ni}; \n\t\t\t\ttr = Take[ss, \(-\((l - i)\)\)]; 
                If[mi > 1, 
                  tr = Prepend[tr, \ nm]]; \n\t\t\tSum[\((ns = 
                      Join[tl, {{1, \[Alpha]}, {1, ni - \[Alpha]}}, tr] //. 
                        SimplifyFamilies; \n\t\t\t\t\tn1 = 
                      ns /. {___, {x_, \[Alpha]}, ___} -> 
                          x; \t\n\t\t\t\t\t\t\tn2 = 
                      ns /. {___, {x_, ni - \[Alpha]}, ___} -> 
                          x; \n\t\t\t\t\t\tIf[\[Alpha] == 
                          ni - \[Alpha], \(n1 \((n1 - 1)\)\)\/\(j \((j + 1)\)\
\), \(n1\ n2\)\/\(j \((j + 1)\)\)] FamilyProbability[ns])\), {\[Alpha], 1, 
                    ni - 1}])\), {i, 1, l}]]\);\)\)], "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{

Cell["NumberOfLineages[S] gives the total number of genes involved", 
  "Subsubsection",
  InitializationCell->True],

Cell[BoxData[{
    \(\(NumberOfLineages[{s__Integer}] := 
        NumberOfLineages[Frequencies[{s}]];\)\), "\n", 
    \(\(NumberOfLineages[{s___Integer}] := 
        Plus @@ \((\(\((Times @@ #)\) &\) /@ {s})\);\)\), "\n", 
    \(\(NumberOfLineages[g_Node] := 
        Length[Position[g, Node[_, _List, {}]]];\)\), "\n", 
    \(\(NumberOfLineages[g_Node, i_] := 
        Length[Position[ExtractGenealogy[g, i], 
            Node[_, _List, {}]]];\)\), "\n", 
    \(\(NumberOfLineages[{g__Node}] := 
        Count[{g}, Node[_, _, {_}]];\)\), "\n", 
    \(\(NumberOfLineages[{g__Node}, _] := 
        NumberOfLineages[{g}];\)\)}], "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{

Cell["PairwiseIdentity[S] gives the mean pairwise identity", "Subsubsection",
  InitializationCell->True],

Cell[BoxData[{
    \(\(PairwiseIdentity[{s__Integer}] := 
        PairwiseIdentity[Frequencies[{s}]];\)\), "\n", 
    \(\(PairwiseIdentity[s__List] := 
        Module[{i, k = NumberOfLineages[s]}, \n
          Sum[s\[LeftDoubleBracket]i, 1\[RightDoubleBracket] s\
\[LeftDoubleBracket]i, 2\[RightDoubleBracket] \((s\[LeftDoubleBracket]i, 2\
\[RightDoubleBracket] - 1)\), {i, 1, Length[s]}]\/\(k \((k - 1)\)\)];\)\)}], \
"Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{

Cell["\<\
AllSets[j,k] lists all the family structures that could yield j \
families and k genes\
\>", "Subsubsection",
  InitializationCell->True],

Cell[BoxData[{
    \(\(AllSets[1] = {{{1, 1}}};\)\), "\n", 
    \(\(AllSets[
          k_Integer] := \(AllSets[k] = \n\t\t\tUnion[
            Sort /@ Flatten[NewS /@ AllSets[k - 1], 1]]\);\)\)}], "Input",
  InitializationCell->True],

Cell[BoxData[{
    \(\(AllSets[1, 1] = {{{1, 1}}};\)\), "\n", 
    \(\(AllSets[j_Integer, 
          k_Integer] := \(AllSets[j, 
            k] = \n\t\t\tIf[\((j == 0)\) || \((k == 0)\), {}, 
            Union[Sort /@ 
                Flatten[
                  Join[\(NewS[#, same] &\) /@ 
                      AllSets[j, k - 1], \(NewS[#, diff] &\) /@ 
                      AllSets[j - 1, k - 1]], 1]]]\);\)\)}], "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{

Cell["NewS[S] gives a recursion for the family structures", "Subsubsection",
  InitializationCell->True],

Cell[BoxData[{
    \(\(NewS[s_, same] := 
        Module[{i, l = Length[s], tl, tr, ni, mi}, \n\t
          Table[\((tl = Take[s, i - 1]; \n\t\t\t\tni = 
                s\[LeftDoubleBracket]i, 2\[RightDoubleBracket]; \t
              mi = s\[LeftDoubleBracket]i, 1\[RightDoubleBracket]; 
              nm = {mi - 1, ni}; \n\t\t\t\ttr = Take[s, \(-\((l - i)\)\)]; 
              If[mi > 1, 
                tr = Prepend[tr, \ nm]]; \n\t\tJoin[tl, {{1, ni + 1}}, tr] //. 
                SimplifyFamilies)\), {i, 1, l}]];\)\), "\n", 
    \(\(NewS[s_, 
          diff] := {Prepend[s, {1, 1}] //. SimplifyFamilies};\)\), "\n", 
    \(\(NewS[s_] := Join[NewS[s, diff], NewS[s, same]];\)\)}], "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{

Cell["NumberOfFamilies[S] gives the number of families", "Subsubsection",
  InitializationCell->True],

Cell[BoxData[{
    \(\(NumberOfFamilies[{s__Integer}] := 
        NumberOfFamilies[Frequencies[{s}]];\)\), "\n", 
    \(\(NumberOfFamilies[
          s__List] := \((Plus @@ 
              s)\)\[LeftDoubleBracket]1\[RightDoubleBracket];\)\)}], "Input",
  InitializationCell->True]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["Random genealogies", "Subsection"],

Cell[CellGroupData[{

Cell["\<\
RandomCoalescenceTimes[k] gives a list of random coalescence \
times\
\>", "Subsubsection"],

Cell[BoxData[
    \(\(RandomCoalescenceTimes[k0_] := 
        Module[{k = k0 + 1}, 
          Drop[FoldList[Plus, 0, 
              Table[k -= 1; 
                Random[ExponentialDistribution[\(k \((k - 1)\)\)\/2]], {k0 - 
                    1}]], 1]];\)\)], "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{

Cell["\<\
NumberOfCoalescences[k,T] gives a randomly sampled number of \
coalescence events that occur in T (scaled to 2N) \
NumberOfCoalescences[{t1,t2..}] does the same, for a given list of \
coalescence times.\
\>", "Subsubsection",
  InitializationCell->True],

Cell[BoxData[
    \(\(NumberOfCoalescences[k_Integer, T_] := 
        NumberOfCoalescences[RandomCoalescenceTimes[k], T];\)\)], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(\(NumberOfCoalescences[tl_List, T_] := 
        Length[Select[tl, \((# < T)\) &]];\)\)], "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{

Cell["TotalLength[{t1,t2,..}] is the total length of the tree", 
  "Subsubsection"],

Cell[BoxData[
    \(\(TotalLength[tl_List] := Plus @@ tl + Last[tl];\)\)], "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{

Cell["\<\
RandomFamilies[k] generates a list of the family sizes going back \
through time to the common ancestor of k genes.\
\>", "Subsubsection"],

Cell[BoxData[
    \(\(RandomFamilies[k_Integer] := 
        NestList[RandomPreviousFamily, Array[1 &, k], k - 1];\)\)], "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{

Cell["\<\
RandomPreviousFamily[{1,1,2,3}] generates a random coalescence to \
give the previous family structure\
\>", "Subsubsection",
  InitializationCell->True],

Cell[BoxData[{
    \(\(RandomPreviousFamily[{k_Integer}] := {k};\)\), "\n", 
    \(\(RandomPreviousFamily[n_List] := 
        Module[{rp, k = Length[n], n2}, \n\t\trp = RandomSet[2, k]; 
          n2 = n\[LeftDoubleBracket]
              rp\[LeftDoubleBracket]2\[RightDoubleBracket]\
\[RightDoubleBracket]; 
          Sort[ReplacePart[
              Delete[n, rp\[LeftDoubleBracket]2\[RightDoubleBracket]], 
              n2 + n\[LeftDoubleBracket]
                  rp\[LeftDoubleBracket]1\[RightDoubleBracket]\
\[RightDoubleBracket], 
              rp\[LeftDoubleBracket]1\[RightDoubleBracket]]]];\)\)}], "Input",\

  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    \(TextForm
    \`RandomGenealogy[{leaf\_1, leaf\_2, \[Ellipsis]}]\ gives\ a\ random\ 
      realisation\ of\ the\ coalescent\ process . \ \ Terminal\ nodes\ are\ 
      labelled\ {leaf\_1, leaf\_2, \[Ellipsis]}, \ 
    and\ internal\ nodes\ are\ labelled\ by\ an\ integer, \ 
    in\ the\ order\ in\ which\ they\ occur . \ \ Each\ node\ carries\ its\ 
      time, \ scaled\ to\ 2  N\ generations . \ \ MutationRate \[Rule] 
        \[Theta]\ simulates\ infinite - 
          sites\ mutation\ at\ a\ rate\ \[Theta] = 4  N\[Mu]; \ 
    mutations\ are\ labelled\ by\ unique\ integers . \ NodeLabels 
      \[Rule] {label\_1, \[Ellipsis]}\ can\ be\ used\ to\ label\ internal\ 
        \(nodes . \)\)], "Subsubsection"],

Cell[BoxData[
    \(\(Options[RandomGenealogy] = {NodeLabels \[Rule] None, 
          MutationRate \[Rule] None, 
          CoalescenceTimes \[Rule] Random};\)\)], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(\(RandomGenealogy[ls_, opts___Rule] := \n\t
        Module[{n = Length[ls], nl, li, ni, mu, \[Mu]T, rt, rg, nm = 0, 
            j, \[Lambda]}, \n\t\trt = \(CoalescenceTimes /. {opts}\) /. 
              Options[RandomGenealogy]; \[IndentingNewLine]\ \ \ \ \ \ \ \ \ \
\ \ \ \ If[rt === Random, 
            rt = RandomCoalescenceTimes[
                n]]; \n\t\tnl = \(NodeLabels /. {opts}\) /. 
              Options[RandomGenealogy]; \n\t\tmu = \(MutationRate /. {opts}\) \
/. Options[RandomGenealogy]; \n\t\tli = 
            If[mu === None, Array[{0} &, n], 
              Array[{0, \[Mu]T} &, n]]; \n\t\tni = 
            If[mu === None, \((List /@ rt)\), \({#, \[Mu]T} &\) /@ 
                rt]; \n\t\trg = 
            FamilyToGenealogy[ls, RandomFamilies[n], NodeLabels \[Rule] nl, 
              NodeInformation \[Rule] ni, LeafInformation \[Rule] li]; \n\t
          If[mu === 
              None, \n\t\t\trg, \n\t\t\ \ rg\[LeftDoubleBracket]2\
\[RightDoubleBracket] = {rt\[LeftDoubleBracket]\(-1\)\[RightDoubleBracket], \
{}}; \n\t\t\trg //. {Node[
                    i1_, {t1_, \[Mu]_List}, {a___, 
                      Node[i2_, {t2_, \[Mu]T}, {m___}], 
                      b___}] :> \n\t\t\t\t\t\t\((\[Lambda] = 
                      mu \((t1 - t2)\)/2; \n\t\t\t\t\t\t\tj = 
                      If[\[Lambda] == 0, 0, 
                        Random[
                          PoissonDistribution[\[Lambda]]]]; \n\t\t\t\t\t\t\t\
nm = nm + j; Node[i1, {t1, \[Mu]}, {a, 
                        Node[i2, {t2, 
                            Sort[Join[\[Mu], Range[nm - j + 1, nm]]]}, {m}], 
                        b}])\)}]];\)\)], "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    \(TextForm\`DeletedMutations[
        g, {T\_0, 
          T\_1}]\ lists\ those\ mutations\ that\ should\ be\ deleted\ because\
\ they\ occurred\ in\ time\ interval\ {T\_0, 
          T\_1} . \ \ This\ list\ may\ be\ to\ some\ extent\ randomly\ \
\(\(generated\)\(.\)\)\)], "Subsubsection"],

Cell[BoxData[
    \(\(DeletedMutations[g_Node, {T0_, T1_}] := 
        Module[{tt = {}, ii, 
            mi}, \n\t\t\(\((mi = MutationInterval[g, #]; \n\t\t\tii = 
                  IntervalIntersection[Interval[{T0, T1}], 
                    Interval[mi]]; \n\t\ \ \ If[Not[ii === Interval[]], 
                  If[\((Max[mi] - Min[mi])\) 
                        Random[] < \((Max[ii] - Min[ii])\), 
                    AppendTo[tt, #]]])\) &\) /@ Mutations[g]; \n\t
          tt];\)\)], "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData[
"RandomBottleneckedGenealogy[leaves,{T0,T1},\[Theta]] gives a random \
genealogy, with no mutations occurring in time interval {T0,T1}."], 
  "Subsubsection"],

Cell[BoxData[
    \(\(RandomBottleneckedGenealogy[lv_, {T0_, T1_}, \[Theta]_] := \n\t
        Module[{g = RandomGenealogy[lv, MutationRate \[Rule] \[Theta]]\ , 
            dl}, \n\t\ \ \ dl = 
            DeletedMutations[g, {T0, T1}]; \n\t\tTransformInformation[g, 
            ReplacePart[#2, 
                Complement[#2\[LeftDoubleBracket]2\[RightDoubleBracket], dl], 
                2] &]];\)\)], "Input",
  InitializationCell->True]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["Generating functions", "Subsection"],

Cell[CellGroupData[{

Cell[TextData[
"MomentGeneratingFunction[g,\[Omega],\[Theta]] gives the generating function \
for the number of mutations along each branch of the genealogy, under the \
infinite sites model."], "Subsubsection"],

Cell[BoxData[
    \(\(MomentGeneratingFunction[
          Node[i_, _List, {Node[a_, 
                s_List, {nn__Node}]}], \[Omega]_, \[Theta]_] := \n\t
        MomentGeneratingFunction[
          Node[a, s, {nn}], \[Omega], \[Theta]];\)\)], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(\(MomentGeneratingFunction[
          Node[i_, _List, {Node[a_, _List, {}], 
              Node[b_, _List, {}]}], \[Omega]_, \[Theta]_] := \n\t
        1\/\(1 + \[Theta] \((1 - \((\[Omega][a] + \
\[Omega][b])\)/2)\)\);\)\)], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(\(MomentGeneratingFunction[g_Node, \[Omega]_, \[Theta]_] := 
        Module[{\n\t\t\tleaves = 
              Leaves[g], \n\t\tn, \[Lambda], \[Phi]}, \n\t\tn = 
            Length[leaves]; \[Lambda] = \(n\/2\) \((\[Theta] + n - 
                  1)\); \[Phi] = \[Theta]\/\(n \((\[Theta] + n - 1)\)\); \n\t\
\t\t1\/\(\[Lambda] \((1 - \[Phi] \((Plus @@ \((\[Omega] /@ leaves)\))\))\)\)*\
\((Plus @@ \((\(\((MomentGeneratingFunction[
                          g /. {Node[x_, 
                                  y_, {Node[#\[LeftDoubleBracket]1\
\[RightDoubleBracket], _, {}], 
                                    Node[#\[LeftDoubleBracket]2\
\[RightDoubleBracket], _, {}]}] :> Node[x, y, {}], 
                              Node[x_, 
                                  y_, {Node[#\[LeftDoubleBracket]2\
\[RightDoubleBracket], _, {}], 
                                    Node[#\[LeftDoubleBracket]1\
\[RightDoubleBracket], _, {}]}] :> 
                                Node[x, y, {}]}, \[Omega], \[Theta]])\) &\) /@ 
                    SiblingList[g])\))\)];\)\)], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(\(MomentGeneratingFunction[{g__List}, \[Omega]_, \[Theta]_] := \
\(MomentGeneratingFunction[{g}, \[Omega], \[Theta]] = 
          Module[{\n\t\tn = Length[{g}], \[Lambda], \[Phi], ng, gl, i, 
              j}, \n\t\tIf[n == 1, 
              1, \[Lambda] = \(n\/2\) \((\[Theta] + n - 
                      1)\); \[Phi] = \[Theta]\/\(n \((\[Theta] + n - 1)\)\); \
\n\ \ \ \ gl = Flatten[
                  Table[Sort[{{g}\[LeftDoubleBracket]
                          i\[RightDoubleBracket], {g}\[LeftDoubleBracket]
                          j\[RightDoubleBracket]}], {i, 2, n}, {j, i - 1}], 
                  1]; \n\t\t\(1\/\(\[Lambda] \((1 - \[Phi] \((Plus @@ \((\(\
\[Omega][Sort[#]] &\) /@ {g})\))\))\)\)\) 
                Plus @@ \((\(\((ng = {g} /. {{x___, #\[LeftDoubleBracket]1\
\[RightDoubleBracket], y___, #\[LeftDoubleBracket]2\[RightDoubleBracket], 
                                    z___} :> 
                                  Sort[{x, 
                                      Join[#\[LeftDoubleBracket]1\
\[RightDoubleBracket], #\[LeftDoubleBracket]2\[RightDoubleBracket]], y, 
                                      z}], {x___, #\[LeftDoubleBracket]2\
\[RightDoubleBracket], y___, #\[LeftDoubleBracket]1\[RightDoubleBracket], 
                                    z___} :> 
                                  Sort[{x, 
                                      Join[#\[LeftDoubleBracket]1\
\[RightDoubleBracket], #\[LeftDoubleBracket]2\[RightDoubleBracket]], y, z}]}; 
                          MomentGeneratingFunction[
                            ng, \[Omega], \[Theta]])\) &\) /@ 
                      gl)\)]]\);\)\)], "Input",
  InitializationCell->True]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["The probability of genealogies", "Subsection"],

Cell[CellGroupData[{

Cell["\<\
PossibleCoalescenceOrder[g] lists the possible orders in which \
coalescence events might occur; each is given by an ordered list of \
nodes.\
\>", "Subsubsection"],

Cell[BoxData[
    \(\(PossibleCoalescenceOrder[
          Node[i_, _, {Node[a_, _, {}], Node[b_, _, {}]}]] := {Append[
            Sort[{a, b}], i]};\)\)], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(\(PossibleCoalescenceOrder[
          Node[i_, _, {Node[a_, s_, {nn__Node}]}]] := \(Append[#, i] &\) /@ 
          PossibleCoalescenceOrder[Node[a, s, {nn}]];\)\)], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(\(PossibleCoalescenceOrder[g_Node] := \n\t
        Module[{sl = SiblingList[g], tl = {}, lv, j}, \n\t\tDo[
            tl = Join[
                tl, \(Join[
                      sl\[LeftDoubleBracket]j\[RightDoubleBracket], #] &\) /@ 
                  PossibleCoalescenceOrder[
                    g /. {Node[i_, 
                            s_, {Node[
                                sl\[LeftDoubleBracket]j, 
                                  1\[RightDoubleBracket], _, {}], 
                              Node[sl\[LeftDoubleBracket]j, 
                                  2\[RightDoubleBracket], _, {}]}] :> 
                          Node[i, s, {}], 
                        Node[i_, 
                            s_, {Node[
                                sl\[LeftDoubleBracket]j, 
                                  2\[RightDoubleBracket], _, {}], 
                              Node[sl\[LeftDoubleBracket]j, 
                                  1\[RightDoubleBracket], _, {}]}] :> 
                          Node[i, s, {}]}]], {j, Length[sl]}]; 
          lv = Sort[Leaves[g]]; \n\t\t\(Join[lv, TakeAway[#, lv]] &\) /@ 
            tl];\)\)], "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{

Cell["\<\
RandomCoalescenceOrder[g] gives a random ordering of the possible \
coalescence events\
\>", "Subsubsection"],

Cell[BoxData[
    \(\(RandomCoalescenceOrder[
          Node[i_, _, {Node[a_, _, {}], Node[b_, _, {}]}]] := 
        Append[Sort[{a, b}], i];\)\)], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(\(RandomCoalescenceOrder[Node[i_, _, {Node[a_, s_, {nn__Node}]}]] := 
        Append[RandomCoalescenceOrder[Node[a, s, {nn}]], i];\)\)], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(\(RandomCoalescenceOrder[g_Node] := \n\t
        Module[{sl = SiblingList[g], lv, j, tl}, \n\t\tj = 
            Random[Integer, {1, Length[sl]}]; \n\t\ttl = 
            Join[sl\[LeftDoubleBracket]j\[RightDoubleBracket], 
              RandomCoalescenceOrder[
                g /. {Node[i_, 
                        s_, {Node[
                            sl\[LeftDoubleBracket]j, 
                              1\[RightDoubleBracket], _, {}], 
                          Node[sl\[LeftDoubleBracket]j, 
                              2\[RightDoubleBracket], _, {}]}] :> 
                      Node[i, s, {}], 
                    Node[i_, 
                        s_, {Node[
                            sl\[LeftDoubleBracket]j, 
                              2\[RightDoubleBracket], _, {}], 
                          Node[sl\[LeftDoubleBracket]j, 
                              1\[RightDoubleBracket], _, {}]}] :> 
                      Node[i, s, {}]}]]; 
          lv = Sort[Leaves[g]]; \n\t\tJoin[lv, 
            TakeAway[tl, lv]]];\)\)], "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{

Cell["\<\
NumberOfPossibleCoalescences[g,nodelist] gives the number of \
possible coalescences that could occur at each step. Only internal nodes are \
included. The order of coalescences is defined by nodelist\
\>", 
  "Subsubsection"],

Cell[BoxData[
    \(\(NumberOfPossibleCoalescences[g_Node, nl_] := 
        Module[{lv = Leaves[g], ng = g, 
            tt = {}}, \n\ \ \ \ \ \ \ Scan[\((AppendTo[tt, 
                  Length[SiblingList[ng]]]; \n\t\t\tng = 
                  ng /. Node[#, s_, {___}] :> Node[#, s, {}])\) &, 
            TakeAway[nl, lv]]; tt];\)\)], "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{

Cell["\<\
IncidenceMatrix[g,nodelist] gives the matrix describing an ordering \
of coalescences defined by nodelist.  The last member of nodelist is the root \
node.  The elements of the matrix show whether a branch is present during the \
time for which there are 1\[LessEqual]i\[LessEqual]n lineages. Rows \
correspond to branches, in the order specified by nodelist. \
\>", \
"Subsubsection"],

Cell[BoxData[
    \(\(Unprotect[IncidenceMatrix];\)\)], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(\(IncidenceMatrix[g_Node, nl_List]\  := 
        Module[{\n\t\t\tleaves = Leaves[g], \n\t\t\tn = NumberOfLineages[g], 
            S = {\(If[FreeQ[g, \ Node[#, _, {}]], 0, 1] &\) /@ nl}, x, 
            i}, \n\t\t\ Do[
            PrependTo[S, 
              First[S]]; \n\t\ \ \ \ \ \ \ \ \ S\[LeftDoubleBracket]1, 
                i\[RightDoubleBracket] = 1; 
            x = \((\(\(Position[nl, #]\)\[LeftDoubleBracket]1, 
                      1\[RightDoubleBracket] &\) /@ 
                  Descendants[g, 
                    nl\[LeftDoubleBracket]
                      i\[RightDoubleBracket]])\); \n\t\t\t\ \ \ \ S\
\[LeftDoubleBracket]1, 
                x\[LeftDoubleBracket]1\[RightDoubleBracket]\
\[RightDoubleBracket] = 
              0; \(S\[LeftDoubleBracket]1, 
                  x\[LeftDoubleBracket]2\[RightDoubleBracket]\
\[RightDoubleBracket] = 0;\), {i, n + 1, 2  n - 1}]; \n
          Transpose[S]];\)\)], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(\(Protect[IncidenceMatrix];\)\)], "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData[
"MonteCarloProbability[g,nodelist,J,\[Theta],ns] makes a Monte Carlo estimate \
of the probability of the genealogy g and the mutational configuration J, \
assuming that the coalescences are in the order specified by nodelist. A list \
of ns values is returned. MonteCarloProbability[g,J,\[Theta],ns] makes no \
assumptions as to the order of events."], "Subsubsection"],

Cell[BoxData[
    \(\(MonteCarloProbability[Node[i_, _, {g_Node}], nl_List, 
          J_List, \[Theta]_, \[Phi]_, ns_Integer]\  := \n\t
        Module[{ps = \(Position[nl, i]\)\[LeftDoubleBracket]1, 
                1\[RightDoubleBracket]}, \n\t\tMonteCarloProbability[g, 
            Delete[nl, ps], Delete[\ J, ps], \[Theta], \[Phi], 
            ns]];\)\)], "Input",
  InitializationCell->True],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(MonteCarloProbability[g_Node, nl_List, J_List, \[Theta]_, \[Theta]1_, 
          ns_Integer]\  := 
        Module[{n = NumberOfLineages[g], S = IncidenceMatrix[g, nl], i, 
            j, \[Phi]v, \[Phi]v1, \[Phi], \[Phi]1, \[Lambda], 
            Jt}, \n\t\t\[Phi] = 
            Table[\[Theta]\/\(i \((\[Theta] + i - 1)\)\), {i, 1, 
                n}]; \[Phi]v = \(\((# . \[Phi]1)\) &\) /@ S; \n\t\t\[Phi]1 = 
            Table[\[Theta]1\/\(i \((\[Theta]1 + i - 1)\)\), {i, 1, 
                n}]; \[Phi]v1 = \(\((# . \[Phi]1)\) &\) /@ 
              S; \n\t\t\[Lambda] = \[Product]\+\(i = 2\)\%n\((i\/2\ \((\
\[Theta] + i - 
                      1)\))\); \n\ \((Times @@ MapThread[Power, {\[Phi]v, J}]\
\/\(\[Lambda] \((Times @@ \((Factorial /@ J)\)\ )\)\))\)*
            Table[\n\t\t\t\tJt = 
                Plus @@ MapThread[
                    RandomMultinomial[#3, \(#1  \[Phi]1\)\/#2] &, {S, \
\[Phi]v1, J}]; \n\t\t\t\tTimes @@ 
                MapThread[\((\(#1!\) \((#2\/#3)\)\^#1)\) &, {Jt, \[Phi], \
\[Phi]1}], {ns}]];\)\)], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(General::"spell1" \(\(:\)\(\ \)\) 
      "Possible spelling error: new symbol name \"\!\(\[Phi]v\)\" is similar \
to existing symbol \"\!\(\[Phi]\)\"."\)], "Message"],

Cell[BoxData[
    \(General::"spell" \(\(:\)\(\ \)\) 
      "Possible spelling error: new symbol name \"\!\(\[Phi]1\)\" is similar \
to existing symbols \!\({\[Theta]1, \[Phi]v1}\)."\)], "Message"]
}, Closed]],

Cell[BoxData[
    \(\(MonteCarloProbability[g_Node, J_List, \[Theta]_, \[Theta]1_, 
          ns_Integer]\  := \n\t
        Module[{nl = RandomCoalescenceOrder[g]}, \n\t\tMonteCarloProbability[
              g, nl, J, \[Theta], \[Theta]1, 
              ns]*\((Times @@ 
                Drop[NumberOfPossibleCoalescences[g, 
                    nl], \(-1\)])\)];\)\)], "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{

Cell["\<\
NumberOfMutations[g,node] gives the number of mutations that \
occurred on the branch leading down to the specified node. The set of \
mutations is given in the second element of the information for each \
node.\
\>", "Subsubsection"],

Cell[BoxData[
    \(\(Options[
          NumberOfMutations] = {NodeFunction \[Rule] \
\((#2\[LeftDoubleBracket]2\[RightDoubleBracket] &)\)};\)\)], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(\(NumberOfMutations[g_Node, i_, opts___Rule] := \n\t
        Module[{a = Ancestors[g, i], \t
            nf = \(NodeFunction /. {opts}\) /. 
                Options[NumberOfMutations]}, \n\t\tIf[
            a === {}, \n\t\t\t0, \n\t\t\tLength[\n\t\t\t\tComplement[\n\t\t\t\
\t\tnf[i, ExtractInformation[g, i]], \n\t\t\t\t\tnf[Last[a], 
                  ExtractInformation[g, Last[a]]]]]]];\)\)], "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData[
"Mutations[g] gives the set of mutations that occured on g.  Mutations[g,i] \
gives the mutations that arose on the branch leading down to node i.  By \
default, these are held in the second element of the information list.  \
NodeFunction\[Rule]f uses f[i,info] to extract the mutation list."], 
  "Subsubsection"],

Cell[BoxData[
    \(\(Options[
          Mutations] = {NodeFunction \[Rule] \((#2\[LeftDoubleBracket]2\
\[RightDoubleBracket] &)\)};\)\)], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(Mutations[g_Node, opts___Rule] := 
      Module[{nf = \(NodeFunction /. {opts}\) /. 
              Options[Mutations]}, \n\t\tUnion[
          Flatten[\(CollapseGenealogy[g, 
                NodeFunction \[Rule] 
                  nf]\)\[LeftDoubleBracket]2\[RightDoubleBracket]]]]\)], \
"Input",
  InitializationCell->True],

Cell[BoxData[
    \(Mutations[g_Node, i_, opts___Rule] := 
      Module[{nf = \(NodeFunction /. {opts}\) /. Options[Mutations], 
          an = Ancestors[g, i]}, \n\t\tComplement[
          nf[i, ExtractInformation[g, i]], 
          If[an === {}, {}, 
            nf[Last[an], ExtractInformation[g, Last[an\ ]]]]]]\)], "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{

Cell["\<\
MutationOrigin[g,k] gives the first node at which mutation k \
appears.\
\>", "Subsubsection"],

Cell[BoxData[
    \(\(Options[
          MutationOrigin] = {NodeFunction \[Rule] \((Take[#2, 
                  2] &)\)};\)\)], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(\(MutationOrigin[g_Node, k_, opts___Rule]\  := 
        Module[{ll, 
            nf = \(NodeFunction /. {opts}\) /. 
                Options[MutationOrigin]}, \n\t\tll = 
            CollapseGenealogy[g, 
              NodeFunction \[Rule] \((If[
                      MemberQ[\(nf[#1, #2]\)\[LeftDoubleBracket]2\
\[RightDoubleBracket], 
                        k], {\(nf[#1, #2]\)\[LeftDoubleBracket]1\
\[RightDoubleBracket], #1}, {\(-\[Infinity]\), #1}] &)\), 
              Nested \[Rule] False]; \n\t\tll = 
            First[Sort[
                ll, \((#1\[LeftDoubleBracket]1\[RightDoubleBracket] > #2\
\[LeftDoubleBracket]1\[RightDoubleBracket])\) &]]; \n\t\tIf[
            ll\[LeftDoubleBracket]1\[RightDoubleBracket] === \
\(-\[Infinity]\), $Failed, 
            ll\[LeftDoubleBracket]2\[RightDoubleBracket]]];\)\)], "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{

Cell["\<\
MutationInterval[g,k,t] gives the time .interval in which mutation \
k arose.  \
\>", "Subsubsection"],

Cell[BoxData[
    \(\(Options[
          MutationInterval] = {NodeFunction \[Rule] \((Take[#2, 
                  2] &)\)};\)\)], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(\(MutationInterval[g_Node, k_, opts___Rule] := 
        Module[{nn = MutationOrigin[g, k, opts], an, t0, t1, 
            nf = \(NodeFunction /. {opts}\) /. 
                Options[MutationInterval]}, \n\t
          If[nn === $Failed, $Failed, \n\t\t\tt0 = \(nf[nn, 
                  ExtractInformation[g, 
                    nn]]\)\[LeftDoubleBracket]1\[RightDoubleBracket]; \n\t\t\t\
an = Ancestors[g, nn]; \n\t\t\tIf[
              an === {}, {t0, \[Infinity]}, \n\t\t\tt1 = \(nf[Last[an], 
                    ExtractInformation[g, 
                      Last[an]]]\)\[LeftDoubleBracket]1\[RightDoubleBracket]; \
\n\t\t\t{t0, t1}]]];\)\)], "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData[
"ExactProbability[g,\[Theta]] gives the probability of this genealogy, given \
a scaled mutation rate \[Theta]=4N\[VeryThinSpace]\[Mu]. By default, the \
number of mutations is deduced from a list of unique mutations held in the \
second element of the information list.  NodeFunction\[Rule]f uses f[i,info] \
to find the number of mutations. Uses MomentGeneratingFunction[], and so is \
intractable for large numbers of mutations and for large genealogies.  \
ExactProbability[S,\[Theta]] uses the generating function over all topologies \
to find the net probability of the configuration of mutations represented by \
the matrix S."], "Subsubsection"],

Cell[BoxData[
    \(\(Options[
          ExactProbability] = {NodeFunction \[Rule] \
\((#2\[LeftDoubleBracket]2\[RightDoubleBracket] &)\)};\)\)], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(\(ExactProbability[g_Node, \[Theta]_, opts___Rule] := 
        Module[{\[Omega], mgf, 
            jl, \n\t\t\tnl = 
              Nodes[g], \n\t\t\tnf = \(NodeFunction /. {opts}\) /. 
                Options[ExactProbability]}, \n\t\tmgf = 
            MomentGeneratingFunction[
              g, \[Omega], \[Theta]]; \n\t\ \ jl = \(NumberOfMutations[
                  g, #] &\) /@ nl; \n\t\ \ jl = 
            Reverse /@ 
              Sort[Transpose[{jl, \[Omega] /@ nl}]]; \n\t\tScan[\((mgf = 
                  D[mgf, #]\/\(#\[LeftDoubleBracket]2\[RightDoubleBracket]!\) \
/. #\[LeftDoubleBracket]1\[RightDoubleBracket] \[Rule] 0)\) &, jl]; 
          mgf // Factor];\)\)], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(\(ExactProbability[S_List, \[Theta]_] := 
        Module[\n\t\t{\[Omega], \[Nu], mgf, jl, rl, ll, nl = Length[S], 
            nm = Length[
                S\[LeftDoubleBracket]1\[RightDoubleBracket]], \n\t\t\tff = 
              Frequencies[Transpose[S]]}, \n\t\tll = 
            List /@ Range[nl]; \n\t\t\ \ mgf = 
            MomentGeneratingFunction[ll, \[Omega], \[Theta]]; \n\t\t\ If[
              0 == \((Plus @@ \(Plus @@ 
                      S\))\), \n\t\t\t\ \ mgf /. \[Omega][_] :> 
                  0, \n\t\t\t\ \ \ jl = \(ff /. \n\t\t\t\t\t{i_Integer, 
                        s_List} :> {i, \[Nu] @@ \((\(Extract[ll, #] &\) /@ 
                              Position[s, 1])\)}\) /. \[Nu][a__List] :> \[Nu][
                      Flatten[{a}]]; \n\t\t\ \ \ jl = Reverse /@ Sort[jl]; 
              rl = jl /. {{\[Nu][
                          a_], _} :> \((\[Omega][a] -> \[Nu][
                            a])\)}; \n\t\t\ \ \ \ mgf = \ \(mgf /. 
                    rl\) /. \[Omega][_] :> 
                    0; \n\t\ \ \ \ \ Scan[\((mgf = 
                      D[mgf, #]\/\(#\[LeftDoubleBracket]2\[RightDoubleBracket]\
!\) /. #\[LeftDoubleBracket]1\[RightDoubleBracket] \[Rule] 0)\) &, jl]; mgf] // 
            Factor];\)\)], "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{

Cell["\<\
GenealogyToMatrix[g] gives a matrix whose rows specify which \
mutations are found in which leaf of the genealogy.  By default, the list of \
mutations is taken from the second element of the information list.  \
NodeFunction\[Rule]f uses f[i,info] to specify the mutations in each \
node.\
\>", "Subsubsection"],

Cell[BoxData[
    \(\(Options[
          GenealogyToMatrix] = {NodeFunction \[Rule] \
\((#2\[LeftDoubleBracket]2\[RightDoubleBracket] &)\)};\)\)], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(\(GenealogyToMatrix[
          g : Node[_, _List, _List] | {Node[_, _List, _List] ... }, 
          opts___Rule] := 
        ListToMatrix[
          CollapseGenealogy[g, Nested \[Rule] False, Node \[Rule] False, 
            NodeFunction \[Rule] \((\(NodeFunction /. {opts}\) /. 
                  Options[GenealogyToMatrix])\)], opts];\)\)], "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    \(TextForm\`MatrixToGenealogy[
        S, {leaf\_1, \ 
          leaf\_2, \[Ellipsis]}, {\[Mu]\_1, \[Ellipsis]}]\ \ constructs\ a\ \
genealogy\ from\ the\ matrix\ S . \ \ The\ leaves\ are\ labelled\ by\ \
{leaf\_1, \ \[Ellipsis]}\ and\ the\ mutations\ by\ {\[Mu]\_1, \[Ellipsis]}; \ 
    internal\ nodes\ are\ labelled\ by\ unique\ integers\)], "Subsubsection"],

Cell[BoxData[
    \(\(Options[MatrixToGenealogy] = {Unrooted \[Rule] False};\)\)], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(\(MatrixToGenealogy[S_List, ll_List, ml_List, 
          opts___Rule] := \[IndentingNewLine]If[
          ValidMatrixQ[S, 
            opts], \[IndentingNewLine]If[\(Unrooted /. {opts}\) /. 
              Options[MatrixToGenealogy], \
\[IndentingNewLine]MatrixToUnrootedGenealogy[S, ll, 
              ml], \[IndentingNewLine]MatrixToRootedGenealogy[S, ll, 
              ml]], \[IndentingNewLine]Message[
            MatrixToGenealogy::invalidMatrix, S]; $Failed];\)\)], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(\(MatrixToRootedGenealogy[S_List, ll_List, ml_List] := 
        Module[{nl = Length[S], j, g, rtn, sharedMutations, nodeCount, 
            lS = MatrixToList[S, MutationLabels \[Rule] ml]}, \n\t
          sharedMutations = \(Extract[ml, #] &\) /@ 
              Position[Transpose[S], {\((1)\) .. }]; \n\tnodeCount = 2; \n\t
          g = Node[
              1, {0, sharedMutations}, {Node[
                  ll\[LeftDoubleBracket]1\[RightDoubleBracket], {0, 
                    lS\[LeftDoubleBracket]1\[RightDoubleBracket]}, {}]}]; \n\t
          Do[rtn = 
              FindNode[g, lS\[LeftDoubleBracket]j\[RightDoubleBracket], 
                nodeCount]; \n\t\t\t\ \ If[
              rtn === $Failed, \n\t\t\t\tg = $Failed; 
              Break[], \n\t\t\t\tIf[\(! \((rtn\[LeftDoubleBracket]1\
\[RightDoubleBracket] === rtn\[LeftDoubleBracket]2\[RightDoubleBracket])\)\), 
                nodeCount += 1]; \n\t\t\t\t\ g = 
                AddGenealogy[g, 
                  Node[ll\[LeftDoubleBracket]j\[RightDoubleBracket], {0, 
                      lS\[LeftDoubleBracket]j\[RightDoubleBracket]}, {}], 
                  rtn\[LeftDoubleBracket]1\[RightDoubleBracket], 
                  rtn\[LeftDoubleBracket]2\[RightDoubleBracket], {0, 
                    rtn\[LeftDoubleBracket]3\[RightDoubleBracket]}]], \n\t\t\t\
{j, 2, nl}]; \n\t\tg];\)\)], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(\(MatrixToGenealogy::invalidMatrix = "\<The matrix `1` is not \
consistent with any genealogy\>";\)\)], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(\(MatrixToGenealogy::multipleSplit = "\<Mutation `1` appears to split \
the genealogy at several nodes.  The list of possible nodes, and the current \
genealogy are `2`, `3`\>";\)\)], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(\(MatrixToUnrootedGenealogy[S_List, ll_List, 
          ml_List] := \[IndentingNewLine]Module[{nl, mlist, j, 
            nleaves = Length[S], 
            nmutns = Length[S\[LeftDoubleBracket]1\[RightDoubleBracket]], rs, 
            rs2, vms, nn = 1, ms1, ms2, mm}, \[IndentingNewLine]nl = 
            Append[\(Node[#, {0, {}}, {1}] &\) /@ ll, 
              Node[nn, {0, {}}, ll]]; \[IndentingNewLine]mlist = 
            MatrixToList[S, 
              MutationLabels \[Rule] ml]; \[IndentingNewLine]llist = 
            MatrixToList[Transpose[S], 
              MutationLabels \[Rule] 
                ll]; \[IndentingNewLine]vms = \(ml\[LeftDoubleBracket]#\
\[RightDoubleBracket] &\) /@ 
              Select[Range[nmutns], 
                Length[llist\[LeftDoubleBracket]#\[RightDoubleBracket]] > 
                    1 &]; \[IndentingNewLine]nl = 
            AddMutation[1, vms, 
              AddMutation[ll, mlist, nl]]; \[IndentingNewLine]Do[
            If[1 < Length[llist\[LeftDoubleBracket]j\[RightDoubleBracket]] < 
                nleaves - 
                  1, \[IndentingNewLine] (*\(Print["\<Doing mutation\>", 
                    j];\)*) \[IndentingNewLine]nds = 
                Cases[nl, 
                  Node[_, {_, {___, 
                        ml\[LeftDoubleBracket]
                          j\[RightDoubleBracket], ___}}, {_, _, __}]]; \
\[IndentingNewLine] (*\(Print["\<nds=\>", nds];\)*) \[IndentingNewLine]rs = 
                nds /. {Node[nd_, _, 
                        rs_] \[RuleDelayed] \((rs2 = 
                          Select[rs, 
                            MemberQ[\(ExtractInformation[
                                    nl, #]\)\[LeftDoubleBracket]2\
\[RightDoubleBracket], 
                                ml\[LeftDoubleBracket]
                                  j\[RightDoubleBracket]] &]; \
\[IndentingNewLine]{nd, rs2, 
                          Complement[rs, 
                            rs2]})\)}; \[IndentingNewLine] \
(*\(Print["\<rs=\>", rs];\)*) \[IndentingNewLine]rs = 
                Select[rs, \((1 < 
                          Length[#\[LeftDoubleBracket]2\[RightDoubleBracket]] \
&& 1 < Length[#\[LeftDoubleBracket]3\[RightDoubleBracket]])\) &]; \
\[IndentingNewLine] (*\(Print["\<rs=\>", rs];\)*) \[IndentingNewLine]If[
                Length[rs] > 1, 
                Message[MatrixToGenealogy::multipleSplit, 
                  ml\[LeftDoubleBracket]j\[RightDoubleBracket], rs, 
                  nl]]; \[IndentingNewLine]If[
                Length[rs] > 
                  0, \[IndentingNewLine]\((rs = 
                    First[rs]; \[IndentingNewLine] (*\(Print["\<Split at \>", 
                        rs];\)*) \[IndentingNewLine]nn += 1; 
                  mm = \(ExtractInformation[nl, 
                        rs\[LeftDoubleBracket]1\[RightDoubleBracket]]\)\
\[LeftDoubleBracket]2\[RightDoubleBracket]; \[IndentingNewLine]nl = 
                    nl /. Node[
                          rs\[LeftDoubleBracket]1\[RightDoubleBracket], _, _] \
\[RuleDelayed] \((ms1 = Union[
                              Flatten[\(\(ExtractInformation[
                                        nl, #]\)\[LeftDoubleBracket]2\
\[RightDoubleBracket] &\) /@ 
                                  rs\[LeftDoubleBracket]2\[RightDoubleBracket]\
]]; \[IndentingNewLine]Node[
                            rs\[LeftDoubleBracket]1\[RightDoubleBracket], {0, 
                              Intersection[ms1, mm]}, 
                            Append[
                              rs\[LeftDoubleBracket]2\[RightDoubleBracket], 
                              nn]])\); \[IndentingNewLine]AppendTo[nl, 
                    ms2 = Union[
                        Flatten[\(\(ExtractInformation[
                                  nl, #]\)\[LeftDoubleBracket]2\
\[RightDoubleBracket] &\) /@ 
                            rs\[LeftDoubleBracket]3\[RightDoubleBracket]]]; \
\[IndentingNewLine]Node[nn, {0, Intersection[ms2, mm]}, 
                      Append[rs\[LeftDoubleBracket]3\[RightDoubleBracket], 
                        rs\[LeftDoubleBracket]1\[RightDoubleBracket]]]]; \
\[IndentingNewLine]\((\(\((nl = 
                            nl /. Node[#, x_, y_] \[RuleDelayed] 
                                Node[#, x, 
                                  y /. rs\[LeftDoubleBracket]1\
\[RightDoubleBracket] \[RuleDelayed] nn])\) &\) /@ 
                      rs\[LeftDoubleBracket]3\[RightDoubleBracket])\);)\)]], \
\[IndentingNewLine]{j, Length[ml]}]; \[IndentingNewLine]nl];\)\)], "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    \(TextForm
    \`FindNode[g, {m\_1, \[Ellipsis]}, newNode]\ finds\ from\ where\ in\ the\ 
      genealogy\ g\ a\ leaf\ carrying\ mutations\ {m\_1, \[Ellipsis]}\ 
      descends . \ \ If\ no\ node\ or\ branch\ matches, \ 
    returns\ $Failed . \ If\ the\ leaf\ joins\ the\ branch\ above\ node\ i, \ 
    returns\ {i, newNode, {m\_1, \[Ellipsis]}}, \ 
    where\ newNode\ is\ a\ new\ node\ label, \ 
    distinct\ from\ any\ other\ in\ g . \ The\ last\ element\ lists\ the\ 
      mutations\ carried\ at\ the\ new\ node . \ \ If\ the\ leaf\ joins\ at\ 
      node\ i, \ returns\ {i, i, {m\_1, \[Ellipsis]}}, \ 
    where\ the\ last\ element\ lists\ the\ mutations\ carried\ at\ node\ 
      i . \ \ \ \ The\ new\ leaf\ MUST\ contain\ all\ the\ mutations\ in\ the
      \ root\ node\ of\ \(g . \)\)], "Subsubsection"],

Cell[BoxData[
    \(\(FindNode[g_Node, leafMutations_List, newNode_] := \n\t
        Module[{nd = g\[LeftDoubleBracket]1\[RightDoubleBracket], 
            oldNd = g\[LeftDoubleBracket]1\[RightDoubleBracket], desc, 
            nodeMutations, descendantMutations, sharedMutations, lsm, ps, 
            rtn = {}}, \n\t\tWhile[
            rtn === {}, \n\t\t\ \ desc = 
              Descendants[g, 
                nd]; \n\ \ \ \ \ \ \ nodeMutations = \(ExtractInformation[g, 
                  nd]\)\[LeftDoubleBracket]2\[RightDoubleBracket]; \n\ \ \ \ \
\ \ \ descendantMutations = \(Complement[#, 
                    nodeMutations] &\) /@ \((\(\(ExtractInformation[
                          g, #]\)\[LeftDoubleBracket]2\[RightDoubleBracket] &\
\) /@ desc)\); \n\ \ \ \ \ \ \ sharedMutations = \(Intersection[#, 
                    leafMutations] &\) /@ 
                descendantMutations; \n\ \ \ \ \ \ lsm = 
              Length /@ sharedMutations; \n\ \ \ \ \ \ If[
              Complement[nodeMutations, 
                  leafMutations] === {}, \n\t\ \ \ \ \ If[
                Max[lsm] == 
                  0, \n\t\ \ \ \ \ \ \ \ rtn = {nd, nd, 
                    nodeMutations}, \n\t\ \ \ \ \ \ \ \ If[
                  Max[lsm] != Plus @@ lsm, \n\t\t\ \ \ \ \ \ \ \ \ \ If[
                    Max[lsm] == \(-\[Infinity]\), \n\t\t\t\t\t\t\trtn = {nd, 
                        newNode, 
                        Intersection[leafMutations, 
                          nodeMutations]}, \n\t\t\t\t\t\t\tPrint["\<New \
leaf\>", leafMutations, "\<contains mutations from several branches:\>", 
                      lsm]; \n\t\t\ \ \ \ \ \ \ \ \ rtn = $Failed], \n\t\t\ \ \
\ \ \ \ \ \ \ ps = \(Position[lsm, Max[lsm]]\)\[LeftDoubleBracket]1, 
                      1\[RightDoubleBracket]; \n\t\t\ \ \ \ \ \ \ \ If[
                    Complement[
                        descendantMutations\[LeftDoubleBracket]
                          ps\[RightDoubleBracket], 
                        leafMutations] === {}, \n\t\t\t\ \ \ \ \ \ \ \ \ \ nd \
= desc\[LeftDoubleBracket]
                        ps\[RightDoubleBracket], \n\t\t\t\ \ \ \ \ \ \ \ \ \
rtn = {desc\[LeftDoubleBracket]ps\[RightDoubleBracket], newNode, 
                        Join[nodeMutations, 
                          Intersection[leafMutations, 
                            descendantMutations\[LeftDoubleBracket]
                              ps\[RightDoubleBracket]]]}]]], \n\t
              Print["\<New leaf\>", 
                leafMutations, "\<does not contain all mutations in node \>", 
                nd]; \n\trtn = $Failed]]; \n\trtn];\)\)], "Input",
  InitializationCell->True],

Cell["\<\
Choose a node at the top
If new leaf does not contain all mutations at the node and none of the new \
descendant mutations,then
\tif that node is a leaf, make a new node just above; otherwise join the \
node.
else if new leaf contains some new mutations from several descendant \
branches, FAIL
 \telse if contains ALL mutations from ONE branch, move down & repeat
 \t\telse attach to that branch\
\>", "Text"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    \(TextForm
    \`MatrixToList[S]\ converts\ a\ matrix\ representation\ to\ a\ list\ of\ 
      the\ mutations\ held\ by\ each\ leaf . \ \ By\ default, \ 
    mutations\ are\ numbered\ 1, 
    2  \[Ellipsis] . \ \ MutationLabels 
      \[Rule] {m\_1, \[Ellipsis]}\ uses\ the\ specified\ \(labels . \)\)], 
  "Subsubsection"],

Cell[BoxData[
    \(\(Options[
          MatrixToList] = {MutationLabels \[Rule] Automatic};\)\)], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(\(MatrixToList[S_List, opts___Rule]\  := 
        Module[{i, nl = Length[S], 
            nm = Length[S\[LeftDoubleBracket]1\[RightDoubleBracket]], 
            ml}, \n\t\t\tml = \(MutationLabels /. {opts}\) /. 
              Options[MatrixToList]; \n\t\t\ \ If[ml === Automatic, 
            ml = Range[nm]]; \n\t\t\ \ Table[\(Extract[ml, #] &\) /@ 
              Position[S\[LeftDoubleBracket]i\[RightDoubleBracket], 1], {i, 
              nl}]];\)\)], "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    \(TextForm
    \`ListToMatrix[{{1, 2, 3}, {4}, \[Ellipsis]}]\ converts\ a\ list\ of\ 
        mutations\ present\ at\ each\ node\ into\ a\ matrix\ 
        representation . \ \ MutationLabels 
      \[Rule] {m\_1, \[Ellipsis]}\ gives\ the\ columns\ in\ the\ specified\ 
        \(order . \)\)], "Subsubsection"],

Cell[BoxData[
    \(\(Options[
          ListToMatrix] = {MutationLabels \[Rule] Automatic};\)\)], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(\(ListToMatrix[z_List, opts___Rule]\  := \n\t
        Module[{i, nl = Length[z], 
            zl = Union[
                Flatten[z]]}, \n\t\t\tml = \(MutationLabels /. {opts}\) /. 
              Options[MatrixToList]; \n\t\t\ \ If[ml === Automatic, 
            ml = zl]; \n\t\t\ \ Table[\(If[
                  MemberQ[z\[LeftDoubleBracket]i\[RightDoubleBracket], #], 1, 
                  0] &\) /@ ml, {i, nl}]];\)\)], "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData[
"GriffithsTavare[S,\[Theta]] uses the Griffiths-Tavare algorithm to find the \
probability of a configuration of mutations defined by the matrix S."], 
  "Subsubsection"],

Cell[BoxData[
    \(\(GriffithsTavare[{}, \[Theta]_] := 
        GriffithsTavareFailed[{}];\)\)], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(\(GriffithsTavare[{g1_List, 
            g2_List}, \[Theta]_] := \n\t\(GriffithsTavare[{g1, 
              g2}, \[Theta]] = \n\t\tModule[{a1 = 
                Plus @@ \((g1 \((1 - g2)\))\), 
              a2 = Plus @@ \((g2 \((1 - g1)\))\)}, \n\t\tBinomial[a1 + a2, 
                a1] \(\((\[Theta]\/\(2 \((1 + \[Theta])\)\))\)\^\(a1 + a2\)\) 
              1\/\(1 + \[Theta]\)]\);\)\)], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(\(GriffithsTavare[S_List, \[Theta]_] := 
        If[OrderedQ[S] && 
            OrderedQ[Transpose[S]], \n\t\tGriffithsTavare[
              S, \[Theta]] = \n\t\t\tModule[{\[Lambda], ps, 
                dt, \n\t\t\t\t\tff = 
                  DeleteCases[Frequencies[S], {1, _}], \n\t\t\t\t\tn = 
                  Length[S], 
                nm = Length[S\[LeftDoubleBracket]1\[RightDoubleBracket]], 
                mutationTerms, coalescenceTerms}, \n\t\t\t\tps = 
                Position[Plus @@ S, 1]; \n\t\t\t\tmutationTerms = 
                If[Length[ps] == 0, 
                  0, \n\t\t\t\t\t\tIf[
                    nm == 1, \n\t\t\t\t\t\t\tGriffithsTavare[
                      S /. {1 -> 0}, \[Theta]], \n\t\t\t\t\t\t\tdt = 
                      Union[\(Transpose[
                              Delete[
                                Transpose[
                                  S], #\[LeftDoubleBracket]1\
\[RightDoubleBracket]]] &\) /@ 
                          ps]; \n\t\t\t\t\t\t\ \ Plus @@ \
\((\(GriffithsTavare[#, \[Theta]] &\) /@ 
                          dt)\)]]; \n\t\t\t\tcoalescenceTerms = 
                If[ff === {}, \n\t\t\t\t\t\t0, \n\t\t\t\t\t\tff = 
                    Transpose[ff]; \n\t\t\t\t\t\tIf[
                    Max[First[ff]] \[LessEqual] 
                      1, \n\t\t\t\t\t\t\t0, \n\t\t\t\t\t\t\tPlus @@ 
                      MapThread[\(\(#1 \((#1 - 1)\)\)\/2\) 
                            GriffithsTavare[
                              Delete[
                                S, \(Position[S, #2]\)\[LeftDoubleBracket]1, 
                                  1\[RightDoubleBracket]], \[Theta]] &, 
                        ff]]]; \[Lambda] = \(n\/2\) \((\[Theta] + n - 
                      1)\); \(1\/\[Lambda]\) \((\(\[Theta]\/2\) 
                        mutationTerms + coalescenceTerms)\) // Factor], 
          GriffithsTavare[
            Transpose[Sort[Transpose[Sort[S]]]], \[Theta]]];\)\)], "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData[
"MonteCarloGriffithsTavare[S,\[Theta]] uses the Monte-Carlo Griffiths-Tavare \
algorithm to find the probability of a configuration of mutations defined by \
the matrix S."], "Subsubsection"],

Cell[BoxData[
    \(\(MonteCarloGriffithsTavare[
          S_List, \[Theta]_, \[Phi]_] := \n\t\t\tModule[{pr = 1, nS = S, n, 
            ps, J, K, 
            nm = Length[
                S\[LeftDoubleBracket]1\[RightDoubleBracket]]}, \n\t\t\tWhile[\
\(! nS === {{0}}\), \n\t\ \ \ \ \ \ \ \ \ st = Transpose[nS]; 
            ust = Union[st]; \n\t\ \ \ \ \ \ \ \ \ ps = 
              Position[Plus @@ Transpose[ust], 1]; \n\t\ \ \ \ \ \ \ \ \ J = 
              Length[ps]; \n\t\ \ \ \ \ \ \ \ \ ff = 
              DeleteCases[Frequencies[nS], {1, _}]; \n\t\ \ \ \ \ \ \ \ \ K = 
              If[ff === {}, 0, 
                fft = Transpose[ff]; \n\t\ \ \ \ \ \ \ \ \ \ \ \ If[
                  Max[First[fft]] \[LessEqual] 
                    1, \n\t\t\t\t\t\t\ \ \t0, \n\t\t\t\t\ \ \ \ \ \ \ \ \ \ \
fft\[LeftDoubleBracket]1\[RightDoubleBracket] . \((fft\[LeftDoubleBracket]1\
\[RightDoubleBracket] - 1)\)/2]]; \n\t\t\ \ \ \ \ \ \ n = 
              Length[nS]; \n\t\ \ \ \ \ \ \ \ \  (*\(Print[nS // MatrixForm, 
                  Tab, {n, J, K}, Tab, pr];\)*) \n\t\t\tnS = 
              If[Random[] < \(J\ \[Phi]\)\/\(J\ \[Phi] + 2  K\), \n\t\t\ \ \ \
\ \ \ \ If[Length[nS\[LeftDoubleBracket]1\[RightDoubleBracket]] == 
                    1, \n\t\t\t\t\ \ \ \ \ \ \ \ \ \ nS /. {1 \[Rule] 
                        0}, \n\t\t\t\t\ \ \ \ \ \ \ \ \ \ rj = 
                    ps\[LeftDoubleBracket]Random[Integer, {1, J}], 
                      1\[RightDoubleBracket]; \n\t\ \ \ \ \ \ \ \ \ \ \ \ \ \ \
\ \ \ Transpose[Delete[
                      st, \(Position[st, 
                          ust\[LeftDoubleBracket]
                            rj\[RightDoubleBracket]]\)\[LeftDoubleBracket]1, 
                        1\[RightDoubleBracket]]]], \n\t\ \ \ \ \ \ \ \ \ \ rk \
= RandomList[
                    1, \(fft\[LeftDoubleBracket]1\[RightDoubleBracket] \((fft\
\[LeftDoubleBracket]1\[RightDoubleBracket] - 1)\)\)\/\(2  K\)]; \n\ \ \ \ \ \ \
\ \ \ \ \ \ Delete[
                  nS, \(Position[nS, 
                      fft\[LeftDoubleBracket]2, 
                        1\[RightDoubleBracket]]\)\[LeftDoubleBracket]1, 
                    1\[RightDoubleBracket]]]; \n\ \ \ \ \ \ \ \ \ \ \ \ \ \ \
pr *= \((J\ \[Phi] + 2  K)\)\/\(n \((\[Theta] + n - 1)\)\)]; 
          pr \((\[Theta]\/\[Phi])\)\^nm];\)\)], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(\(MonteCarloGriffithsTavare[S_List, \[Theta]_] := 
        MonteCarloGriffithsTavare[S, \[Theta], \[Theta]];\)\)], "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{

Cell["ValidMatrixQ", "Subsubsection",
  InitializationCell->True],

Cell[BoxData[
    \(\(ValidMatrixQ::notTensor = "\<ValidMatrixQ[`1`] should have as an \
argument a tensor of rank 2, containing 0 or 1\>";\)\)], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(\(Options[ValidMatrixQ] = {Unrooted \[Rule] \ False};\)\)], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(\(ValidMatrixQ[S : {{\((0 | 1)\) ... } ... }, opts___Rule] := 
        Module[{tS}, \[IndentingNewLine]If[
            MatrixQ[S], \[IndentingNewLine]If[\(Dimensions[
                    S]\)\[LeftDoubleBracket]\(-1\)\[RightDoubleBracket] < 
                2, \[IndentingNewLine]True, \[IndentingNewLine]tS = 
                Union[Transpose[
                    S]]; \[IndentingNewLine]If[\(Unrooted /. {opts}\) /. 
                  Options[
                    ValidMatrixQ], \[IndentingNewLine]Max[\(ValidMatrixQ[0, 
                          0]\)[tS] \(ValidMatrixQ[1, 0]\)[
                        tS] \(ValidMatrixQ[0, 1]\)[tS] \(ValidMatrixQ[1, 1]\)[
                        tS]] \[Equal] 
                  0, \[IndentingNewLine]Max[\(ValidMatrixQ[1, 0]\)[
                        tS] \(ValidMatrixQ[0, 1]\)[tS] \(ValidMatrixQ[1, 1]\)[
                        tS]] \[Equal] 0]], \[IndentingNewLine]Message[
              ValidMatrixQ::notTensor, S]]];\)\)], "Input",
  InitializationCell->True],

Cell[BoxData[{
    \(\(ValidMatrixQ[1, 1] = 
        Compile[{{tS, _Integer, 
              2}}, \[IndentingNewLine]1 - \((Times @@ 
                Transpose[
                  1 - Outer[Times, tS, tS, 1], {3, 2, 
                    1}])\)];\)\), "\[IndentingNewLine]", 
    \(\(ValidMatrixQ[0, 1] = 
        Compile[{{tS, _Integer, 
              2}}, \[IndentingNewLine]1 - \((Times @@ 
                Transpose[
                  1 - Outer[Times, 1 - tS, tS, 1], {3, 2, 
                    1}])\)];\)\), "\[IndentingNewLine]", 
    \(\(ValidMatrixQ[1, 0] = 
        Compile[{{tS, _Integer, 
              2}}, \[IndentingNewLine]1 - \((Times @@ 
                Transpose[
                  1 - Outer[Times, tS, 1 - tS, 1], {3, 2, 
                    1}])\)];\)\), "\[IndentingNewLine]", 
    \(\(ValidMatrixQ[0, 0] = 
        Compile[{{tS, _Integer, 
              2}}, \[IndentingNewLine]1 - \((Times @@ 
                Transpose[
                  1 - Outer[Times, 1 - tS, 1 - tS, 1], {3, 2, 
                    1}])\)];\)\)}], "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{

Cell["SwapStates", "Subsubsection",
  InitializationCell->True],

Cell[BoxData[
    \(\(SwapStates[s : {\((0 | 1)\) ... }, 
          S : {{\((0 | 1)\) ... } ... }] := \(\((s + # \((1 - 2  s)\))\) &\) /@ 
          S;\)\)], "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{

Cell["MissingCombination", "Subsubsection"],

Cell[BoxData[
    \(\(MissingCombination::invalidMatrix = "\<The matrix is not consistent \
with any genealogy: `1`\>";\)\)], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(\(MissingCombination[
          S : {{\((0 | 1)\) ... } ... }] := \(MissingCombination[
            S] = \[IndentingNewLine]Module[{ut, 
              tS = Transpose[
                  S]}, \[IndentingNewLine]Outer[\((ut = 
                    Union[Transpose[{##}]]; \[IndentingNewLine]Switch[
                    Length[ut], \[IndentingNewLine]4, 
                    Message[MissingCombination::invalidMatrix, 
                      S]; $Failed, \[IndentingNewLine]3, 
                    Complement[{{0, 0}, {0, 1}, {1, 0}, {1, 1}}, ut] // 
                      First, \[IndentingNewLine]_, {}])\) &, tS, tS, 
              1]]\);\)\)], "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{

Cell["PossibleRootings", "Subsubsection"],

Cell[BoxData[{
    \(\(PossibleRootings[x_?\((\((ListQ[#] && FreeQ[#, \ Null])\) &)\), 
          S : {{\((0 | 1 | Null)\) ... } ... }] := 
        x;\)\), "\[IndentingNewLine]", 
    \(\(PossibleRootings[{a___List, {c___, Null, d___}, b___List}, 
          S : {{\((0 | 1 | 
                        Null)\) ... } ... }] := \[IndentingNewLine]Module[{i, \
\[Alpha], \[Beta], nl = Length[S], 
            nm = Length[
                S\[LeftDoubleBracket]1\[RightDoubleBracket]], \
\[IndentingNewLine]tS = Transpose[S], miss, ut, j = Length[{c}] + 1, 
            cd = {c, Null, d}, t0, t1, t0Q = True, 
            t1Q = True}, \[IndentingNewLine]miss = \(Transpose[
                MissingCombination[S]]\)\[LeftDoubleBracket]
              j\[RightDoubleBracket]; \[IndentingNewLine]t0 = 
            Table[If[\[Alpha] \[Equal] 
                  j, \[IndentingNewLine]0, \[IndentingNewLine]Switch[
                  cd\[LeftDoubleBracket]\[Alpha]\[RightDoubleBracket], \
\[IndentingNewLine]Null, 
                  Switch[miss\[LeftDoubleBracket]\[Alpha]\[RightDoubleBracket]\
, \[IndentingNewLine]{0, 0}, 1, \[IndentingNewLine]{1, 0}, 
                    0, \[IndentingNewLine]_, Null], \[IndentingNewLine]0, 
                  If[miss\[LeftDoubleBracket]\[Alpha]\[RightDoubleBracket] \
\[Equal] {0, 0}, t0Q = False]; 0, \[IndentingNewLine]1, 
                  If[miss\[LeftDoubleBracket]\[Alpha]\[RightDoubleBracket] \
\[Equal] {1, 0}, t0Q = False]; 1]], {\[Alpha], nm}]; \[IndentingNewLine]t1 = 
            Table[If[\[Alpha] \[Equal] 
                  j, \[IndentingNewLine]1, \[IndentingNewLine]Switch[
                  cd\[LeftDoubleBracket]\[Alpha]\[RightDoubleBracket], \
\[IndentingNewLine]Null, 
                  Switch[miss\[LeftDoubleBracket]\[Alpha]\[RightDoubleBracket]\
, \[IndentingNewLine]{0, 1}, 1, \[IndentingNewLine]{1, 1}, 
                    0, \[IndentingNewLine]_, Null], \[IndentingNewLine]0, 
                  If[miss\[LeftDoubleBracket]\[Alpha]\[RightDoubleBracket] \
\[Equal] {0, 1}, t1Q = False]; 0, \[IndentingNewLine]1, 
                  If[miss\[LeftDoubleBracket]\[Alpha]\[RightDoubleBracket] \
\[Equal] {1, 1}, t1Q = False]; 1]], {\[Alpha], nm}]; \[IndentingNewLine]If[
            t0Q, If[t1Q, {a, t0, t1, b}, {a, t0, b}], 
            If[t1Q, {a, t1, b}, {a, b}]]];\)\)}], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(\(PossibleRootings[S : {{\((0 | 1 | Null)\) ... } ... }] := 
        FixedPoint[
          PossibleRootings[#, S] &, {Array[
              Null &, {Length[
                  S\[LeftDoubleBracket]1\[RightDoubleBracket]]}]}];\)\)], \
"Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{

Cell["AddMutation", "Subsubsection"],

Cell[BoxData[
    \(\(AddMutation::invalidLists = "\<The lists of nodes `1` and of \
mutations `2` are not compatible.\>";\)\)], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(AddMutation[n_?\((Not[ListQ[#]] &)\), m_?\((Not[ListQ[#]] &)\), 
        g : \((Node[_, _List, {___Node}] | {Node[_, _List, _List] ... })\)] \
:= \[IndentingNewLine]g /. 
        Node[n, {x_, y_List, z___}, d_List] \[RuleDelayed] 
          Node[n, {x, Append[y, m], z}, d]; 
    AddMutation[n_?\((Not[ListQ[#]] &)\), m_List, 
        g : \((Node[_, _List, {___Node}] | {Node[_, _List, _List] ... })\)] \
:= \[IndentingNewLine]g /. 
        Node[n, {x_, y_List, z___}, d_List] \[RuleDelayed] 
          Node[n, {x, Join[y, m], z}, d];\)], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(\(AddMutation[n_List, m_List, 
          g : \((Node[_, _List, {___Node}] | {Node[_, _List, _List] ... })\)] \
:= \[IndentingNewLine]If[
          Length[n] \[Equal] Length[m], \[IndentingNewLine]Fold[
            AddMutation[#2\[LeftDoubleBracket]1\[RightDoubleBracket], #2\
\[LeftDoubleBracket]2\[RightDoubleBracket], #1] &, g, 
            Transpose[{n, m}]], \[IndentingNewLine]Message[
            AddMutation::invalidLists, n, m]];\)\)], "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{

Cell["CondenseMatrix", "Subsubsection"],

Cell[BoxData[
    \(\(Options[CondenseMatrix] = {Unrooted \[Rule] False};\)\)], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(\(CondenseMatrix::notMatrix = "\<`1` is not a matrix\>";\)\)], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(\(CondenseMatrix[S : {{\((0 | 1)\) ... } ... }, opts___Rule] := 
        If[MatrixQ[
            S], \[IndentingNewLine]Module[{tSR}, \
\[IndentingNewLine]If[\(Unrooted /. {opts}\) /. 
                Options[CondenseMatrix], \[IndentingNewLine]tSR = 
                DeleteCases[
                  Union[Transpose[S]], {0\  ... } | {1\  ... } | {0\  ... \ , 
                      1, 0\  ... } | {1\  ... \ , 0, 
                      1\  ... }]; \[IndentingNewLine]Transpose[
                Union[tSR /. {x : {\((0 | 1)\) ... } \[RuleDelayed] 
                        First[Sort[{x, 
                              1 - x}]]}]], \[IndentingNewLine]Transpose[
                DeleteCases[
                  Union[Transpose[S]], {0\  ... } | {1\  ... } | {0\  ... \ , 
                      1, 0\  ... }]]]], \[IndentingNewLine]Message[
            CondenseMatrix::notMatrix, S]];\)\)], "Input",
  InitializationCell->True]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["Recombination", "Subsection"],

Cell[CellGroupData[{

Cell["AncestralGraphPattern", "Subsubsection",
  InitializationCell->True],

Cell[BoxData[
    \(\(AncestralGraphPattern = {AncestralLineagePattern ... };\)\)], "Input",\

  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{

Cell["AncestralLineagePattern", "Subsubsection",
  InitializationCell->True],

Cell[BoxData[
    \(\(AncestralLineagePattern = 
        AncestralLineage[_, {_, _}, _List, _List, {___List}];\)\)], "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{

Cell["Junctions", "Subsubsection",
  InitializationCell->True],

Cell[BoxData[{
    \(\(Junctions[AncestralLineage[_, {_, _}, _List, j_List, _List]] := 
        Drop[j, \(-1\)];\)\), "\[IndentingNewLine]", 
    \(\(Junctions[g : AncestralGraphPattern] := 
        Union[Flatten[Junctions /@ g]];\)\)}], "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{

Cell["MapLength", "Subsubsection",
  InitializationCell->True],

Cell[BoxData[
    \(\(MapLength::mixedLengths = "\<The map lengths `1` differ among \
lineages\>";\)\)], "Input",
  InitializationCell->True],

Cell[BoxData[{
    \(\(MapLength[AncestralLineage[_, {_, _}, _List, j_List, _List]] := 
        Last[j];\)\), "\[IndentingNewLine]", 
    \(\(MapLength[
          g : AncestralGraphPattern] := \[IndentingNewLine]Module[{ml = 
              Union[MapLength /@ g]}, \[IndentingNewLine]If[
            Length[ml] > 1, \[IndentingNewLine]Message[
              MapLength::mixedLengths, 
              ml]]; \[IndentingNewLine]ml\[LeftDoubleBracket]1\
\[RightDoubleBracket]];\)\)}], "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{

Cell["TimesOfEvents", "Subsubsection",
  InitializationCell->True],

Cell[BoxData[
    \(\(TimesOfEvents[g : AncestralGraphPattern] := 
        Union[Flatten[
            g /. AncestralLineage[_, {t0_, 
                    t1_}, _List, _List, _List] \[RuleDelayed] {t0, 
                  t1}]];\)\)], "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{

Cell["AllEvents", "Subsubsection",
  InitializationCell->True],

Cell[BoxData[
    \(\(AllEvents::badJunctions = "\<The junctions at the recombination event \
at t=`1` in graph `2` do not change by 1.\>";\)\)], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(\(AllEvents::badRelationship = "\<The event at t=`1` in graph `2` does \
not have the right form.\>";\)\)], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(\(AllEvents[g : AncestralGraphPattern] := \(AllEvents[g] = 
          Module[{cs, ce, 
              jj}, \[IndentingNewLine]\(\((cs = 
                    Cases[g, 
                      AncestralLineage[_, {#, _}, _List, _List, _List]]; \
\[IndentingNewLine]ce = 
                    Cases[g, 
                      AncestralLineage[_, {_, #}, _List, _List, _List]]; \
\[IndentingNewLine]Switch[
                    Length /@ {ce, cs}, \[IndentingNewLine]{0, _} | {_, 
                        0} | {2, 1}, \[IndentingNewLine]{#, 
                      ce /. ExtractLabel, cs /. ExtractLabel, 
                      None}, \[IndentingNewLine]{1, 
                      2}, \[IndentingNewLine]jj = 
                      TakeAway[
                        Join[cs\[LeftDoubleBracket]1, 4\[RightDoubleBracket], 
                          cs\[LeftDoubleBracket]2, 4\[RightDoubleBracket]], 
                        ce\[LeftDoubleBracket]1, 
                          4\[RightDoubleBracket]]; \[IndentingNewLine] (*If[\
\[InvisibleSpace]\(! \((MatchQ[jj, {x_, x_, 
                                  1}] || \((Sort[{cs\[LeftDoubleBracket]1, 
                                        3\[RightDoubleBracket], 
                                      cs\[LeftDoubleBracket]2, 
                                        3\[RightDoubleBracket]}] === 
                                  Sort[{{{}}, 
                                      ce\[LeftDoubleBracket]1, 
                                        3\[RightDoubleBracket]}])\))\)\), 
                        Message[AllEvents::"\<badJunctions\>", #1, g]]*)  (*\ 
                      too\ hard\ to\ do\ *) \[IndentingNewLine]If[
                      Not[{} === \(Cases[
                              Transpose[{cs\[LeftDoubleBracket]2, 
                                    4\[RightDoubleBracket], 
                                  cs\[LeftDoubleBracket]2, 
                                    3\[RightDoubleBracket]}], {jj\
\[LeftDoubleBracket]1\[RightDoubleBracket], _}]\)\[LeftDoubleBracket]1, 
                            2\[RightDoubleBracket]], \[IndentingNewLine]cs = 
                        Reverse[cs]]; \[IndentingNewLine]{#, 
                      ce /. ExtractLabel, cs /. ExtractLabel, 
                      jj\[LeftDoubleBracket]1\[RightDoubleBracket]}, \
\[IndentingNewLine]_, \[IndentingNewLine]Message[
                      AllEvents::badRelationship, #, 
                      g]; \[IndentingNewLine]{#, ce /. ExtractLabel, 
                      cs /. ExtractLabel, None}])\) &\) /@ 
              TimesOfEvents[g]]\);\)\)], "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{

Cell["CoalescenceEvents", "Subsubsection",
  InitializationCell->True],

Cell[BoxData[
    \(\(CoalescenceEvents[g : AncestralGraphPattern] := 
        Cases[AllEvents[g], {_, {_, _}, {_}, _}];\)\)], "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{

Cell["RecombinationEvents", "Subsubsection",
  InitializationCell->True],

Cell[BoxData[
    \(\(RecombinationEvents[
          g : AncestralGraphPattern] := \(RecombinationEvents[g] = 
          Cases[AllEvents[g], {_, {_}, {_, _}, _}]\);\)\)], "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{

Cell["NullRecombinationEvents", "Subsubsection",
  InitializationCell->True],

Cell[BoxData[
    \(\(NullRecombinationEvents[
          g : AncestralGraphPattern] := \(NullRecombinationEvents[g] = 
          Cases[AllEvents[g], {_, {_}, {_, _}, MapLength[g]}]\);\)\)], "Input",\

  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{

Cell["LeafEvents", "Subsubsection",
  InitializationCell->True],

Cell[BoxData[
    \(\(LeafEvents[g : AncestralGraphPattern] := \(LeafEvents[g] = 
          Cases[AllEvents[g], {_, {}, {__}, _}]\);\)\)], "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{

Cell["RootEvents", "Subsubsection",
  InitializationCell->True],

Cell[BoxData[
    \(\(RootEvents[g : AncestralGraphPattern] := \(RootEvents[g] = 
          Cases[AllEvents[g], {_, {__}, {}, _}]\);\)\)], "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{

Cell["Leaves", "Subsubsection",
  InitializationCell->True],

Cell[BoxData[
    \(\(\(Leaves::multipleLineages = "\<Some leaves share the same label: `1`\
\>";\)\(\ \)\)\)], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(\(Leaves[
          g : AncestralGraphPattern] := \[IndentingNewLine]Module[{ss = 
              Flatten[\(#\[LeftDoubleBracket]3\[RightDoubleBracket] &\) /@ 
                  LeafEvents[g]], uss, res}, \[IndentingNewLine]uss = 
            Union[ss]; 
          res = TakeAway[ss, uss] === {}; \[IndentingNewLine]If[Not[res], 
            Message[Leaves::multipleLineages, 
              g]]; \[IndentingNewLine]uss];\)\)], "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{

Cell["LineagesPresent", "Subsubsection",
  InitializationCell->True],

Cell[BoxData[{
    \(\(LineagesPresent[g : AncestralGraphPattern, 
          t_] := \[IndentingNewLine]Select[
            g, \((#\[LeftDoubleBracket]2, 1\[RightDoubleBracket] \[LessEqual] 
                  t < #\[LeftDoubleBracket]2, 2\[RightDoubleBracket])\) &] /. 
          ExtractLabel;\)\), "\[IndentingNewLine]", 
    \(\(LineagesPresent[g : AncestralGraphPattern] := \[IndentingNewLine]g /. 
          ExtractLabel;\)\)}], "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{

Cell["RecombinantLineages", "Subsubsection",
  InitializationCell->True],

Cell[BoxData[
    \(\(\(RecombinantLineages::multipleLineages = "\<Some recombinant \
lineages share the same label: `1`\>";\)\(\ \)\)\)], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(\(RecombinantLineages[
          g : AncestralGraphPattern] := \[IndentingNewLine]Module[{ss = 
              Flatten[\(#\[LeftDoubleBracket]3\[RightDoubleBracket] &\) /@ 
                  RecombinationEvents[g]], uss, 
            dss}, \[IndentingNewLine]uss = Union[ss]; 
          dss = ss\[Backslash]uss; \[IndentingNewLine]If[Not[dss === {}], 
            Message[RecombinantLineages::multipleLineages, 
              g]]; \[IndentingNewLine]uss];\)\)], "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{

Cell["CoalescentLineages", "Subsubsection",
  InitializationCell->True],

Cell[BoxData[
    \(\(\(CoalescentLineages::multipleLineages = "\<Some coalescent lineages \
share the same label: `1`\>";\)\(\ \)\)\)], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(\(CoalescentLineages[
          g : AncestralGraphPattern] := \[IndentingNewLine]Module[{ss = 
              Flatten[\(#\[LeftDoubleBracket]3\[RightDoubleBracket] &\) /@ 
                  CoalescenceEvents[g]], uss, dss}, \[IndentingNewLine]uss = 
            Union[ss]; 
          dss = ss\[Backslash]uss; \[IndentingNewLine]If[Not[dss === {}], 
            Message[CoalescentLineages::multipleLineages, 
              g]]; \[IndentingNewLine]uss];\)\)], "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{

Cell["RootLineages", "Subsubsection",
  InitializationCell->True],

Cell[BoxData[
    \(\(\(RootLineages::multipleLineages = "\<Some root lineages share the \
same label: `1`\>";\)\(\ \)\)\)], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(\(RootLineages[
          g : AncestralGraphPattern] := \[IndentingNewLine]Module[{ss = 
              Flatten[\(\((#\[LeftDoubleBracket]2\[RightDoubleBracket])\) &\) \
/@ RootEvents[g]], uss, res}, \[IndentingNewLine]uss = Union[ss]; 
          ss\[Backslash]uss === {}; \[IndentingNewLine]If[Not[res], 
            Message[RootLineages::multipleLineages, 
              g]]; \[IndentingNewLine]uss];\)\)], "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{

Cell["NullLineages", "Subsubsection"],

Cell[BoxData[
    \(\(NullLineages[g : AncestralGraphPattern] := \(NullLineages[g] = 
          Cases[g, 
            AncestralLineage[_, {_, _}, {{}}, {MapLength[
                  g]}, _List]]\);\)\)], "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{

Cell["TimespanOfLineage", "Subsubsection",
  InitializationCell->True],

Cell[BoxData[
    \(\(TimespanOfLineage[g : AncestralGraphPattern, 
          l_] := \(ExtractLineage[g, 
            l]\)\[LeftDoubleBracket]2\[RightDoubleBracket];\)\)], "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{

Cell["TimeSpanOfJunctions", "Subsubsection"],

Cell[BoxData[
    \(\(TimespanOfJunction[ag : AncestralGraphPattern, j_] := 
        Module[{cc}, \[IndentingNewLine]cc = 
            Cases[ag, 
              AncestralLineage[_, {_, _}, _, {___, 
                  j, ___}, _]]; \[IndentingNewLine]{First[
              Sort[cc /. 
                  AncestralLineage[_, {t0_, _}, _, _, _] \[RuleDelayed] t0]], 
            Last[Sort[
                cc /. AncestralLineage[_, {_, t1_}, _, _, _] \[RuleDelayed] 
                    t1]]}];\)\)], "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{

Cell["ExtractLabel", "Subsubsection",
  InitializationCell->True],

Cell[BoxData[
    \(\(ExtractLabel = {AncestralLineage[
              l_, {_, _}, _List, _List, _List] \[RuleDelayed] 
            l};\)\)], "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{

Cell["ExtractInformation", "Subsubsection",
  InitializationCell->True],

Cell[BoxData[
    \(\(ExtractInformation[g : AncestralGraphPattern, l_] := 
        Last[ExtractLineage[g, l]];\)\)], "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{

Cell["ExtractLineage", "Subsubsection",
  InitializationCell->True],

Cell[BoxData[
    \(\(ExtractLineage::notPresent = "\<Lineage `1` is not present in the \
graph `2`\>";\)\)], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(\(ExtractLineage::multipleLineages = "\<Lineage `1` occurs more than \
once in the graph `2`\>";\)\)], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(\(ExtractLineage[g : AncestralGraphPattern, l_List] := 
        Map[ExtractLineage[g, #] &, l, 1];\)\)], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(\(ExtractLineage[g : AncestralGraphPattern, l_?\((Not[ListQ[#]] &)\)] := 
        Module[{cs}, \[IndentingNewLine]cs = 
            Cases[g, 
              AncestralLineage[
                l, {_, _}, _List, _List, _List]]; \[IndentingNewLine]Switch[
            Length[cs], \[IndentingNewLine]0, 
            Message[ExtractLineage::notPresent, l, 
              g]; {}, \[IndentingNewLine]1, 
            cs\[LeftDoubleBracket]1\[RightDoubleBracket], \
\[IndentingNewLine]_, Message[ExtractLineage::multipleLineages, l, g]; 
            cs]];\)\)], "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{

Cell["ExtractLineagesEndingAtT", "Subsubsection",
  InitializationCell->True],

Cell[BoxData[
    \(\(ExtractLineagesEndingAtT[g : AncestralGraphPattern, t_] := 
        Module[{cs}, \[IndentingNewLine]cs = 
            Cases[g, AncestralLineage[_, {_, t}, _List, _List, _List]] /. 
              ExtractLabel];\)\)], "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{

Cell["ExtractLineagesStartingAtT", "Subsubsection",
  InitializationCell->True],

Cell[BoxData[
    \(\(ExtractLineagesStartingAtT[g : AncestralGraphPattern, t_] := 
        Module[{cs}, \[IndentingNewLine]cs = 
            Cases[g, AncestralLineage[_, {t, _}, _List, _List, _List]] /. 
              ExtractLabel];\)\)], "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{

Cell["ExtractGenealogy", "Subsubsection",
  InitializationCell->True],

Cell[BoxData[
    \(\(ExtractGenealogy::multipleRoots = "\<Some of the leaves `1` have more \
than one ancestral lineage at map position `3`: `2`\>";\)\)], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(\(ExtractGenealogy[g : AncestralGraphPattern, 
          x_] := \[IndentingNewLine]Module[{ng = g, ds, ll = Leaves[g], 
            rl}, \[IndentingNewLine]rl = 
            Union[\(Ancestors[g, #, AncestorList \[Rule] Roots, 
                    MapPosition \[Rule] x] &\) /@ ll]; \[IndentingNewLine]If[
            Length[rl] \[Equal] 1, \[IndentingNewLine]ds = 
              Descendants[g, rl\[LeftDoubleBracket]1\[RightDoubleBracket], 
                MapPosition \[Rule] x, 
                DescendantList \[Rule] All]; \[IndentingNewLine]ds = 
              ds //. {a___, {l_?\((Not[MemberQ[ll, \ #]] &)\), {}}, 
                    b___} \[RuleDelayed] {a, 
                    b}; \[IndentingNewLine]ListToGenealogy[
              ds, \[IndentingNewLine]NodeFunction \[Rule] \(({First[
                        TimespanOfLineage[
                          g, #]]} &)\)], \[IndentingNewLine]Message[
              ExtractGenealogy::multipleRoots, ll, rl, 
              x]; $Failed]];\)\)], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(\(\( (*\ 
      This\ is\ an\ old\ piece\ of\ code\ which\ is\ in\ some\ ways\ more\ \
efficient*) \)\(\[IndentingNewLine]\)\( \
(*\[IndentingNewLine]\(ExtractGenealogy[g : AncestralGraphPattern, 
            x_] := \[IndentingNewLine]Module[{ng = g, ds, ll = Leaves[g], 
              rl}, \[IndentingNewLine]rl = \(Union[
                    Flatten[
                      Ancestors[g, #, AncestorList \[Rule] Roots]]] &\) /@ 
                ll; \[IndentingNewLine]If[
              And @@ \((\(Length[#] \[Equal] 1 &\) /@ 
                    rl)\), \[IndentingNewLine]ds = 
                RecombinationEvents[
                    g] /. {_, _, {aL_, aR_}, j_} \[RuleDelayed] 
                    If[x < j, aR, aL]; \[IndentingNewLine]\(\((ng = 
                      DeleteCases[ng, 
                        AncestralLineage[#, {_, _}, _List, _List, _List]])\) \
&\) /@ ds; \[IndentingNewLine]ng, \[IndentingNewLine]Message[
                ExtractGenealogy::multipleRoots, ll, 
                rl]; $Failed]];\)\[IndentingNewLine]*) \)\)\)], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(\(ExtractGenealogy[g : AncestralGraphPattern] := 
        Module[{js = 
              Junctions[g]}, \[IndentingNewLine]\(ExtractGenealogy[
                g, #] &\) /@ \(\(Prepend[js, 0] + 
                  Append[js, 1]\)\/2\)];\)\)], "Input",
  InitializationCell->True],

Cell[CellGroupData[{

Cell[BoxData[
    \(Ancestors[ag, a]\)], "Input"],

Cell[BoxData[
    \({3}\)], "Output"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["Descendants", "Subsubsection",
  InitializationCell->True],

Cell[BoxData[
    \(\(Options[Descendants] = 
        Append[Options[Descendants], MapPosition \[Rule] None];\)\)], "Input",\

  InitializationCell->True],

Cell[BoxData[
    \(\(Descendants::multipleLineages = "\<Several events occur at `1`; \
`2`\>";\)\)], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(\(Descendants[g : AncestralGraphPattern, l_, 
          opts___Rule] := \[IndentingNewLine]Module[{t0, desc, f, 
            dl = \(DescendantList /. {opts}\) /. Options[Descendants], mp, 
            cs, re}, \[IndentingNewLine]Switch[
            dl, \[IndentingNewLine]Next, \[IndentingNewLine]mp = \
\(MapPosition /. {opts}\) /. Options[Descendants]; \[IndentingNewLine]t0 = 
              TimespanOfLineage[g, l] // First; \[IndentingNewLine]cs = 
              Cases[g, AncestralLineage[_, {_, t0}, _List, _List, _List]] /. 
                ExtractLabel; \[IndentingNewLine]If[
              mp === None, \[IndentingNewLine]cs, \[IndentingNewLine]re = 
                Cases[AllEvents[g], {t0, _, _, _}]; \[IndentingNewLine]If[
                Length[re] \[NotEqual] 1, 
                Message[Descendants::multipleLineages, t0, 
                  g]]; \[IndentingNewLine]If[
                re\[LeftDoubleBracket]1, \(-1\)\[RightDoubleBracket] === 
                  None, \[IndentingNewLine]cs, \[IndentingNewLine]If[\((mp < 
                          re\[LeftDoubleBracket]1, \
\(-1\)\[RightDoubleBracket] && 
                        re\[LeftDoubleBracket]1, 3, 1\[RightDoubleBracket] === 
                          l)\) || \((mp \[GreaterEqual] 
                          re\[LeftDoubleBracket]1, \
\(-1\)\[RightDoubleBracket] && 
                        re\[LeftDoubleBracket]1, 3, 2\[RightDoubleBracket] === 
                          l)\), \[IndentingNewLine]cs, {}]]], \
\[IndentingNewLine]All, \[IndentingNewLine]First[
              FixedPoint[
                Map[AddDescendants[g, #, 
                        opts] &, #, {\(-2\)}] &, \ {l}]], \
\[IndentingNewLine]Leaves, \[IndentingNewLine]First[{l} //. {{x__?\((Not[
                              ListQ[#]] &)\)} \[RuleDelayed] \((\(\((dd = 
                              Descendants[g, #, DescendantList \[Rule] Next, 
                                opts]; 
                            If[dd === {}, #, 
                              dd])\) &\) /@ {x})\)}]]];\)\)], "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{

Cell["AddDescendants", "Subsubsection",
  InitializationCell->True],

Cell[BoxData[{
    \(\(AddDescendants[
          g : AncestralGraphPattern, {}, ___Rule] := {};\)\), "\
\[IndentingNewLine]", 
    \(\(AddDescendants[
          g : AncestralGraphPattern, {x__?\((Not[ListQ[#]] &)\)}, 
          opts___Rule] := \[IndentingNewLine]\({#, 
              Descendants[g, #, DescendantList \[Rule] Next, 
                opts]} &\) /@ {x};\)\)}], "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{

Cell["Ancestors", "Subsubsection",
  InitializationCell->True],

Cell[BoxData[
    \(\(Options[Ancestors] = {AncestorList \[Rule] Previous, 
          MapPosition \[Rule] None};\)\)], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(\(Ancestors::multipleLineages = "\<Several events occur at `1`; `2`\>";\
\)\)], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(\(Ancestors[g : AncestralGraphPattern, l_, 
          opts___Rule] := \[IndentingNewLine]Module[{t0, anc, f, 
            al = \(AncestorList /. {opts}\) /. Options[Ancestors], mp, cs, 
            re}, \[IndentingNewLine]Switch[
            al, \[IndentingNewLine]Previous, \[IndentingNewLine]mp = \
\(MapPosition /. {opts}\) /. Options[Ancestors]; \[IndentingNewLine]t0 = 
              TimespanOfLineage[g, l] // Last; \[IndentingNewLine]cs = 
              Cases[g, AncestralLineage[_, {t0, _}, _List, _List, _List]] /. 
                ExtractLabel; \[IndentingNewLine]If[
              mp === None, \[IndentingNewLine]cs, \[IndentingNewLine]re = 
                Cases[AllEvents[g], {t0, _, _, _}]; \[IndentingNewLine]If[
                Length[re] \[NotEqual] 1, 
                Message[Ancestors::multipleLineages, t0, 
                  g]]; \[IndentingNewLine]If[
                re\[LeftDoubleBracket]1, \(-1\)\[RightDoubleBracket] === 
                  None, \[IndentingNewLine]cs, \[IndentingNewLine]If[
                  mp < re\[LeftDoubleBracket]1, \(-1\)\[RightDoubleBracket], \
{re\[LeftDoubleBracket]1, 3, 
                      1\[RightDoubleBracket]}, {re\[LeftDoubleBracket]1, 3, 
                      2\[RightDoubleBracket]}]]], \[IndentingNewLine]All, \
\[IndentingNewLine]First[
              FixedPoint[
                Map[AddAncestors[g, #, 
                        opts] &, #, {\(-2\)}] &, \ {l}]], \
\[IndentingNewLine]Roots, \[IndentingNewLine]First[{l} //. {{x__?\((Not[
                              ListQ[#]] &)\)} \[RuleDelayed] \((y = 
                        Union[Flatten[\((\(\((dd = 
                                      Ancestors[g, #, 
                                        AncestorList \[Rule] Previous, opts]; 
                                    If[dd === {}, #, 
                                      dd])\) &\) /@ {x})\)]];  (*\(Print[
                            y];\)*) y)\)}]]];\)\)], "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{

Cell["Problem with Ancestors", "Subsubsection"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(NestList[\((# /. {{x__?\((Not[
                            ListQ[#]] &)\)} \[RuleDelayed] \((\(\((dd = 
                            Ancestors[ng2, #]; 
                          If[dd === {}, #, dd])\) &\) /@ {x})\)})\) &, {a}, 
        20]\)\[LeftDoubleBracket]{\(-2\), \(-1\)}\[RightDoubleBracket]\)], \
"Input"],

Cell[BoxData[
    \({{{{{{{{{{{{{{{{{{{{{33, 34}}}, {{{33, 
                                        34}}}}, {{{{44}}, {{44}, {43}}}}}}, \
{{{{{{33, 34}}}, {{{33, 34}}}}, {{{{44}}, {{44}, {43}}}}}}}}, {{{{{{{{33, 
                                        34}}}, {{{33, 
                                        34}}}}, {{{{44}}, {{44}, {43}}}}}}, \
{{{{{{33, 34}}}, {{{33, 34}}}}, {{{{44}}, {{44}, {43}}}}}}}}}}, {{{{{{{{{{33, 
                                        34}}}, {{{33, 
                                        34}}}}, {{{{44}}, {{44}, {43}}}}}}, \
{{{{{{33, 34}}}, {{{33, 34}}}}, {{{{44}}, {{44}, {43}}}}}}}}, {{{{{{{{33, 
                                        34}}}, {{{33, 
                                        34}}}}, {{{{44}}, {{44}, {43}}}}}}, \
{{{{{{33, 34}}}, {{{33, 
                                        34}}}}, {{{{44}}, {{44}, \
{43}}}}}}}}}}}}, {{{{{{{{{{{{33, 34}}}, {{{33, 
                                        34}}}}, {{{{44}}, {{44}, {43}}}}}}, \
{{{{{{33, 34}}}, {{{33, 34}}}}, {{{{44}}, {{44}, {43}}}}}}}}, {{{{{{{{33, 
                                        34}}}, {{{33, 
                                        34}}}}, {{{{44}}, {{44}, {43}}}}}}, \
{{{{{{33, 34}}}, {{{33, 34}}}}, {{{{44}}, {{44}, {43}}}}}}}}}}, {{{{{{{{{{33, 
                                        34}}}, {{{33, 
                                        34}}}}, {{{{44}}, {{44}, {43}}}}}}, \
{{{{{{33, 34}}}, {{{33, 34}}}}, {{{{44}}, {{44}, {43}}}}}}}}, {{{{{{{{33, 
                                        34}}}, {{{33, 
                                        34}}}}, {{{{44}}, {{44}, {43}}}}}}, \
{{{{{{33, 34}}}, {{{33, 
                                        34}}}}, {{{{44}}, {{44}, \
{43}}}}}}}}}}}}}}, {{{{{{{{{{{{48, 49}, 47}}}}, {{{{{48, 49}, 
                                        47}}}, {{{{{48, 49}, 
                                        47}}}}}}}}, {{{{48, 49}, 
                                47}}, {{{{{{{{48, 49}, 47}}}}, {{{{{48, 49}, 
                                        47}}}, {{{{{48, 49}, 
                                        47}}}}}}}}}}}}, {{{{{{{{{{{48, 49}, 
                                        47}}}}, {{{{{48, 49}, 
                                        47}}}, {{{{{48, 49}, 
                                        47}}}}}}}}, {{{{48, 49}, 
                                47}}, {{{{{{{{48, 49}, 47}}}}, {{{{{48, 49}, 
                                        47}}}, {{{{{48, 49}, 
                                        47}}}}}}}}}}}}}}}, \
{{{{{{{{{{{{{{{{33, 34}}}, {{{33, 
                                        34}}}}, {{{{44}}, {{44}, {43}}}}}}, \
{{{{{{33, 34}}}, {{{33, 34}}}}, {{{{44}}, {{44}, {43}}}}}}}}, {{{{{{{{33, 
                                        34}}}, {{{33, 
                                        34}}}}, {{{{44}}, {{44}, {43}}}}}}, \
{{{{{{33, 34}}}, {{{33, 34}}}}, {{{{44}}, {{44}, {43}}}}}}}}}}, {{{{{{{{{{33, 
                                        34}}}, {{{33, 
                                        34}}}}, {{{{44}}, {{44}, {43}}}}}}, \
{{{{{{33, 34}}}, {{{33, 34}}}}, {{{{44}}, {{44}, {43}}}}}}}}, {{{{{{{{33, 
                                        34}}}, {{{33, 
                                        34}}}}, {{{{44}}, {{44}, {43}}}}}}, \
{{{{{{33, 34}}}, {{{33, 
                                        34}}}}, {{{{44}}, {{44}, \
{43}}}}}}}}}}}}, {{{{{{{{{{{{33, 34}}}, {{{33, 
                                        34}}}}, {{{{44}}, {{44}, {43}}}}}}, \
{{{{{{33, 34}}}, {{{33, 34}}}}, {{{{44}}, {{44}, {43}}}}}}}}, {{{{{{{{33, 
                                        34}}}, {{{33, 
                                        34}}}}, {{{{44}}, {{44}, {43}}}}}}, \
{{{{{{33, 34}}}, {{{33, 34}}}}, {{{{44}}, {{44}, {43}}}}}}}}}}, {{{{{{{{{{33, 
                                        34}}}, {{{33, 
                                        34}}}}, {{{{44}}, {{44}, {43}}}}}}, \
{{{{{{33, 34}}}, {{{33, 34}}}}, {{{{44}}, {{44}, {43}}}}}}}}, {{{{{{{{33, 
                                        34}}}, {{{33, 
                                        34}}}}, {{{{44}}, {{44}, {43}}}}}}, \
{{{{{{33, 34}}}, {{{33, 
                                        34}}}}, {{{{44}}, {{44}, \
{43}}}}}}}}}}}}}}, {{{{{{{{{{{{48, 49}, 47}}}}, {{{{{48, 49}, 
                                        47}}}, {{{{{48, 49}, 
                                        47}}}}}}}}, {{{{48, 49}, 
                                47}}, {{{{{{{{48, 49}, 47}}}}, {{{{{48, 49}, 
                                        47}}}, {{{{{48, 49}, 
                                        47}}}}}}}}}}}}, {{{{{{{{{{{48, 49}, 
                                        47}}}}, {{{{{48, 49}, 
                                        47}}}, {{{{{48, 49}, 
                                        47}}}}}}}}, {{{{48, 49}, 
                                47}}, {{{{{{{{48, 49}, 47}}}}, {{{{{48, 49}, 
                                        47}}}, {{{{{48, 49}, 
                                        47}}}}}}}}}}}}}}}}}}}, \
{{{{{{{{{{{{{{{{{{{{{37}, {35, 36}}}}, {{{{37}, {35, 
                                        36}}}}}, {{{{{45}}}, {{{45}}, \
{{44}}}}}}}, {{{{{{{37}, {35, 36}}}}, {{{{37}, {35, 
                                        36}}}}}, {{{{{45}}}, {{{45}}, \
{{44}}}}}}}}}, {{{{{{{{{37}, {35, 36}}}}, {{{{37}, {35, 
                                        36}}}}}, {{{{{45}}}, {{{45}}, \
{{44}}}}}}}, {{{{{{{37}, {35, 36}}}}, {{{{37}, {35, 
                                        36}}}}}, {{{{{45}}}, {{{45}}, \
{{44}}}}}}}}}}}, {{{{{{{{{{{37}, {35, 36}}}}, {{{{37}, {35, 
                                        36}}}}}, {{{{{45}}}, {{{45}}, \
{{44}}}}}}}, {{{{{{{37}, {35, 36}}}}, {{{{37}, {35, 
                                        36}}}}}, {{{{{45}}}, {{{45}}, \
{{44}}}}}}}}}, {{{{{{{{{37}, {35, 36}}}}, {{{{37}, {35, 
                                        36}}}}}, {{{{{45}}}, {{{45}}, \
{{44}}}}}}}, {{{{{{{37}, {35, 36}}}}, {{{{37}, {35, 
                                        36}}}}}, {{{{{45}}}, {{{45}}, \
{{44}}}}}}}}}}}}}, {{{{{{{{{{{{{37}, {35, 36}}}}, {{{{37}, {35, 
                                        36}}}}}, {{{{{45}}}, {{{45}}, \
{{44}}}}}}}, {{{{{{{37}, {35, 36}}}}, {{{{37}, {35, 
                                        36}}}}}, {{{{{45}}}, {{{45}}, \
{{44}}}}}}}}}, {{{{{{{{{37}, {35, 36}}}}, {{{{37}, {35, 
                                        36}}}}}, {{{{{45}}}, {{{45}}, \
{{44}}}}}}}, {{{{{{{37}, {35, 36}}}}, {{{{37}, {35, 
                                        36}}}}}, {{{{{45}}}, {{{45}}, \
{{44}}}}}}}}}}}, {{{{{{{{{{{37}, {35, 36}}}}, {{{{37}, {35, 
                                        36}}}}}, {{{{{45}}}, {{{45}}, \
{{44}}}}}}}, {{{{{{{37}, {35, 36}}}}, {{{{37}, {35, 
                                        36}}}}}, {{{{{45}}}, {{{45}}, \
{{44}}}}}}}}}, {{{{{{{{{37}, {35, 36}}}}, {{{{37}, {35, 
                                        36}}}}}, {{{{{45}}}, {{{45}}, \
{{44}}}}}}}, {{{{{{{37}, {35, 36}}}}, {{{{37}, {35, 
                                        36}}}}}, {{{{{45}}}, {{{45}}, \
{{44}}}}}}}}}}}}}}}, {{{{{{{{{{{{48, 49}, 47}}}}, {{{{{48, 49}, 
                                        47}}}, {{{{{48, 49}, 
                                        47}}}}}}}}, {{{{48, 49}, 
                                47}}, {{{{{{{{48, 49}, 47}}}}, {{{{{48, 49}, 
                                        47}}}, {{{{{48, 49}, 
                                        47}}}}}}}}}}}}, {{{{{{{{{{{48, 49}, 
                                        47}}}}, {{{{{48, 49}, 
                                        47}}}, {{{{{48, 49}, 
                                        47}}}}}}}}, {{{{48, 49}, 
                                47}}, {{{{{{{{48, 49}, 47}}}}, {{{{{48, 49}, 
                                        47}}}, {{{{{48, 49}, 
                                        47}}}}}}}}}}}}}}}, \
{{{{{{{{{{{{{{{{{37}, {35, 36}}}}, {{{{37}, {35, 
                                        36}}}}}, {{{{{45}}}, {{{45}}, \
{{44}}}}}}}, {{{{{{{37}, {35, 36}}}}, {{{{37}, {35, 
                                        36}}}}}, {{{{{45}}}, {{{45}}, \
{{44}}}}}}}}}, {{{{{{{{{37}, {35, 36}}}}, {{{{37}, {35, 
                                        36}}}}}, {{{{{45}}}, {{{45}}, \
{{44}}}}}}}, {{{{{{{37}, {35, 36}}}}, {{{{37}, {35, 
                                        36}}}}}, {{{{{45}}}, {{{45}}, \
{{44}}}}}}}}}}}, {{{{{{{{{{{37}, {35, 36}}}}, {{{{37}, {35, 
                                        36}}}}}, {{{{{45}}}, {{{45}}, \
{{44}}}}}}}, {{{{{{{37}, {35, 36}}}}, {{{{37}, {35, 
                                        36}}}}}, {{{{{45}}}, {{{45}}, \
{{44}}}}}}}}}, {{{{{{{{{37}, {35, 36}}}}, {{{{37}, {35, 
                                        36}}}}}, {{{{{45}}}, {{{45}}, \
{{44}}}}}}}, {{{{{{{37}, {35, 36}}}}, {{{{37}, {35, 
                                        36}}}}}, {{{{{45}}}, {{{45}}, \
{{44}}}}}}}}}}}}}, {{{{{{{{{{{{{37}, {35, 36}}}}, {{{{37}, {35, 
                                        36}}}}}, {{{{{45}}}, {{{45}}, \
{{44}}}}}}}, {{{{{{{37}, {35, 36}}}}, {{{{37}, {35, 
                                        36}}}}}, {{{{{45}}}, {{{45}}, \
{{44}}}}}}}}}, {{{{{{{{{37}, {35, 36}}}}, {{{{37}, {35, 
                                        36}}}}}, {{{{{45}}}, {{{45}}, \
{{44}}}}}}}, {{{{{{{37}, {35, 36}}}}, {{{{37}, {35, 
                                        36}}}}}, {{{{{45}}}, {{{45}}, \
{{44}}}}}}}}}}}, {{{{{{{{{{{37}, {35, 36}}}}, {{{{37}, {35, 
                                        36}}}}}, {{{{{45}}}, {{{45}}, \
{{44}}}}}}}, {{{{{{{37}, {35, 36}}}}, {{{{37}, {35, 
                                        36}}}}}, {{{{{45}}}, {{{45}}, \
{{44}}}}}}}}}, {{{{{{{{{37}, {35, 36}}}}, {{{{37}, {35, 
                                        36}}}}}, {{{{{45}}}, {{{45}}, \
{{44}}}}}}}, {{{{{{{37}, {35, 36}}}}, {{{{37}, {35, 
                                        36}}}}}, {{{{{45}}}, {{{45}}, \
{{44}}}}}}}}}}}}}}}, {{{{{{{{{{{{48, 49}, 47}}}}, {{{{{48, 49}, 
                                        47}}}, {{{{{48, 49}, 
                                        47}}}}}}}}, {{{{48, 49}, 
                                47}}, {{{{{{{{48, 49}, 47}}}}, {{{{{48, 49}, 
                                        47}}}, {{{{{48, 49}, 
                                        47}}}}}}}}}}}}, {{{{{{{{{{{48, 49}, 
                                        47}}}}, {{{{{48, 49}, 
                                        47}}}, {{{{{48, 49}, 
                                        47}}}}}}}}, {{{{48, 49}, 
                                47}}, {{{{{{{{48, 49}, 47}}}}, {{{{{48, 49}, 
                                        47}}}, {{{{{48, 49}, 
                                        47}}}}}}}}}}}}}}}}}}}}\)], "Output"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    \({a} /. {{x__?\((Not[ListQ[#]] &)\)} \[RuleDelayed] \((\(\((dd = 
                    Ancestors[ng2, #, MapPosition \[Rule] 0.2]; 
                  If[dd === {}, #, dd])\) &\) /@ {x})\)}\)], "Input"],

Cell[BoxData[
    \({{4}}\)], "Output"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    \({a} //. {{x__?\((Not[ListQ[#]] &)\)} \[RuleDelayed] 
          Flatten[\((\(\((dd = Ancestors[ng2, #, MapPosition \[Rule] 0.2]; 
                    If[dd === {}, #, dd])\) &\) /@ {x})\)]}\)], "Input"],

Cell[BoxData[
    \({48}\)], "Output"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    \(Ancestors[ng2, a, AncestorList \[Rule] Roots]\)], "Input"],

Cell[BoxData[
    \({4}\)], "Print"],

Cell[BoxData[
    \({5}\)], "Print"],

Cell[BoxData[
    \({6, 7}\)], "Print"],

Cell[BoxData[
    \({8}\)], "Print"],

Cell[BoxData[
    \({9, 10}\)], "Print"],

Cell[BoxData[
    \({11, 28, 29}\)], "Print"],

Cell[BoxData[
    \({12, 13, 30, 31}\)], "Print"],

Cell[BoxData[
    \({14, 32}\)], "Print"],

Cell[BoxData[
    \({15, 16, 33, 34}\)], "Print"],

Cell[BoxData[
    \({17, 35, 36, 37}\)], "Print"],

Cell[BoxData[
    \({18, 19, 37, 38, 45}\)], "Print"],

Cell[BoxData[
    \({20, 38, 39, 40, 46, 47}\)], "Print"],

Cell[BoxData[
    \({21, 22, 39, 40, 41, 42, 43, 47, 48, 49}\)], "Print"],

Cell[BoxData[
    \({23, 41, 42, 43, 44, 47, 48, 49}\)], "Print"],

Cell[BoxData[
    \({24, 25, 43, 44, 45, 47, 48, 49}\)], "Print"],

Cell[BoxData[
    \({26, 27, 38, 44, 45, 46, 47, 48, 49}\)], "Print"],

Cell[BoxData[
    \({30, 31, 39, 40, 45, 46, 47, 48, 49}\)], "Print"],

Cell[BoxData[
    \({32, 41, 42, 43, 46, 47, 48, 49}\)], "Print"],

Cell[BoxData[
    \({33, 34, 43, 44, 47, 48, 49}\)], "Print"],

Cell[BoxData[
    \({35, 36, 37, 44, 45, 47, 48, 49}\)], "Print"],

Cell[BoxData[
    \({37, 38, 45, 46, 47, 48, 49}\)], "Print"],

Cell[BoxData[
    \({38, 39, 40, 46, 47, 48, 49}\)], "Print"],

Cell[BoxData[
    \({39, 40, 41, 42, 43, 47, 48, 49}\)], "Print"],

Cell[BoxData[
    \({41, 42, 43, 44, 47, 48, 49}\)], "Print"],

Cell[BoxData[
    \({43, 44, 45, 47, 48, 49}\)], "Print"],

Cell[BoxData[
    \({44, 45, 46, 47, 48, 49}\)], "Print"],

Cell[BoxData[
    \({45, 46, 47, 48, 49}\)], "Print"],

Cell[BoxData[
    \({46, 47, 48, 49}\)], "Print"],

Cell[BoxData[
    \({47, 48, 49}\)], "Print"],

Cell[BoxData[
    \({47, 48, 49}\)], "Print"],

Cell[BoxData[
    \(47\)], "Output"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["AddAncestors", "Subsubsection",
  InitializationCell->True],

Cell[BoxData[{
    \(\(AddAncestors[
          g : AncestralGraphPattern, {}, ___Rule] := {};\)\), "\
\[IndentingNewLine]", 
    \(\(AddAncestors[g : AncestralGraphPattern, {x__?\((Not[ListQ[#]] &)\)}, 
          opts___Rule] := \[IndentingNewLine]\({#, 
              Ancestors[g, #, AncestorList \[Rule] Previous, 
                opts]} &\) /@ {x};\)\)}], "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{

Cell["CoalesceLineages", "Subsubsection",
  InitializationCell->True],

Cell[BoxData[
    \(\(Options[
          CoalesceLineages] = {InformationFunction \[Rule] \((Transpose[{##}] \
&)\)};\)\)], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(\(CoalesceLineages::badInfoLists = "\<The information lists associated \
with the two lineages have different lengths.\>";\)\)], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(\(CoalesceLineages[\[IndentingNewLine]AncestralLineage[_, {_, _}, 
            s1_List, j1_List, i1 : {___List}], 
          AncestralLineage[_, {_, _}, s2_List, j2_List, i2 : {___List}], 
          l12_, t12_, 
          opts___Rule] := \[IndentingNewLine]Module[{if = \
\(InformationFunction /. {opts}\) /. Options[CoalesceLineages], 
            jsl}, \[IndentingNewLine]If[
            Length[i1] \[NotEqual] Length[i2], \[IndentingNewLine]Message[
              CoalesceLineages::badInfoLists, i1, 
              i2]; $Failed, \[IndentingNewLine]jsl = 
              Transpose[
                Sort[Join[
                    Replace[
                      Transpose[{j1, s1}], {j_, s_} \[Rule] {j, s, Null}, 1], 
                    Replace[
                      Transpose[{j2, s2}], {j_, s_} \[Rule] {j, Null, s}, 
                      1]]]]; \[IndentingNewLine]jsl = 
              Drop[Transpose[
                  jsl //. {a___, Null, x_?\((Not[# === Null] &)\), 
                        b___} \[Rule] {a, x, x, 
                        b}], \(-1\)]; \[IndentingNewLine]jsl = 
              Replace[jsl, {j_, ss1_, ss2_} \[Rule] {j, 
                    Union[Join[ss1, ss2]]}, 1]; \[IndentingNewLine]jsl = 
              jsl //. {a___, {j_?\((Not[ListQ[#]] &)\), 
                      s__}, {j_?\((Not[ListQ[#]] &)\), __}, 
                    b___} \[Rule] {a, {j, s}, b}; \[IndentingNewLine]jsl = 
              jsl //. {a___, {_?\((Not[ListQ[#]] &)\), 
                      s__}, {jj2_?\((Not[ListQ[#]] &)\), s__}, 
                    b___} \[Rule] {a, {jj2, s}, b}; \[IndentingNewLine]jsl = 
              Transpose[jsl]; \[IndentingNewLine]AncestralLineage[
              l12, {t12, \[Infinity]}, 
              Sort /@ jsl\[LeftDoubleBracket]2\[RightDoubleBracket], 
              jsl\[LeftDoubleBracket]1\[RightDoubleBracket], 
              if[i1, i2]]]];\)\)], "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{

Cell["RecombineLineage", "Subsubsection",
  InitializationCell->True],

Cell[BoxData[
    \(\(Options[
          RecombineLineage] = {InformationFunction \[Rule] {Identity, 
              Identity}};\)\)], "Input",
  InitializationCell->True],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(RecombineLineage[
          AncestralLineage[_, {_, _}, s_List, j_List, i_List], {lL_, lR_}, 
          x_, t_, opts___Rule] := \[IndentingNewLine]Module[{if = \
\(InformationFunction /. {opts}\) /. Options[RecombineLineage], jsl, jsL, 
            jsR, jsRR}, \[IndentingNewLine]jsl = 
            Transpose[{j, s}]; \[IndentingNewLine]jsRR = 
            Select[jsl, \((#\[LeftDoubleBracket]1\[RightDoubleBracket] > 
                    x)\) &]; \[IndentingNewLine]If[
            jsRR\[LeftDoubleBracket]1, 
                2\[RightDoubleBracket] === {}, \[IndentingNewLine]jsR = 
              Transpose[jsRR]; \[IndentingNewLine]jsL = 
              Transpose[
                Join[Select[
                    jsl, \((#\[LeftDoubleBracket]1\[RightDoubleBracket] \
\[LessEqual] 
                          x)\) &], {{jsR\[LeftDoubleBracket]1, \(-1\)\
\[RightDoubleBracket], {}}}]], \[IndentingNewLine]jsR = 
              Transpose[Prepend[jsRR, {x, {}}]]; \[IndentingNewLine]jsL = 
              Transpose[
                Join[Select[
                    jsl, \((#\[LeftDoubleBracket]1\[RightDoubleBracket] \
\[LessEqual] x)\) &], {{x, 
                      jsR\[LeftDoubleBracket]2, 
                        2\[RightDoubleBracket]}, {jsR\[LeftDoubleBracket]1, \
\(-1\)\[RightDoubleBracket], {}}}]]]; \[IndentingNewLine]{AncestralLineage[
              lL, {t, \[Infinity]}, 
              Sort /@ jsL\[LeftDoubleBracket]2\[RightDoubleBracket], 
              jsL\[LeftDoubleBracket]1\[RightDoubleBracket], \(if\
\[LeftDoubleBracket]1\[RightDoubleBracket]\)[
                i]], \[IndentingNewLine]AncestralLineage[
              lR, {t, \[Infinity]}, 
              Sort /@ jsR\[LeftDoubleBracket]2\[RightDoubleBracket], 
              jsR\[LeftDoubleBracket]1\[RightDoubleBracket], \(if\
\[LeftDoubleBracket]2\[RightDoubleBracket]\)[i]]}];\)\)], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(General::"spell1" \(\(:\)\(\ \)\) 
      "Possible spelling error: new symbol name \"\!\(jsL\)\" is similar to \
existing symbol \"\!\(jsl\)\"."\)], "Message"],

Cell[BoxData[
    \(General::"spell1" \(\(:\)\(\ \)\) 
      "Possible spelling error: new symbol name \"\!\(jsRR\)\" is similar to \
existing symbol \"\!\(jsR\)\"."\)], "Message"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["AddRecombinantLineages", "Subsubsection",
  InitializationCell->True],

Cell[BoxData[
    \(\(Options[
          AddRecombinantLineages] = {DeleteNullLineages \[Rule] 
            False};\)\)], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(\(AddRecombinantLineages[g : AncestralGraphPattern, l_, {lL_, lR_}, x_, 
          t_, opts___Rule] := \[IndentingNewLine]Module[{rl = 
              RecombineLineage[ExtractLineage[g, l], {lL, lR}, x, 
                t]}, \[IndentingNewLine]If[\((\(DeleteNullLineages /. \
{opts}\) /. Options[
                    AddRecombinantLineages])\) && \((rl\[LeftDoubleBracket]1, 
                      3\[RightDoubleBracket] === {{}} || 
                  rl\[LeftDoubleBracket]2, 
                      3\[RightDoubleBracket] === {{}})\), \
\[IndentingNewLine]g, \[IndentingNewLine]Join[
              g /. AncestralLineage[l, {t0_, _}, s_, j_, i_] \[RuleDelayed] 
                  AncestralLineage[l, {t0, t}, s, j, i], rl]]];\)\)], "Input",\

  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{

Cell["AddCoalescentLineage", "Subsubsection",
  InitializationCell->True],

Cell[BoxData[
    \(\(AddCoalescentLineage[g : AncestralGraphPattern, {l1_, l2_}, lC_, t_] := 
        Module[{cl = 
              CoalesceLineages[ExtractLineage[g, l1], ExtractLineage[g, l2], 
                lC, t]}, 
          Append[g /. 
              AncestralLineage[ll : l1 | l2, {t0_, _}, s_, j_, 
                  i_] \[RuleDelayed] AncestralLineage[ll, {t0, t}, s, j, i], 
            cl]];\)\)], "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{

Cell["RandomCoalescenceTimes", "Subsubsection",
  InitializationCell->True],

Cell[BoxData[
    \(\(RandomCoalescenceTimes[k_Integer, R_] := 
        Module[{t, \[Lambda] = \(k \((k - 1)\)\)\/2 + 
                k\ R}, \[IndentingNewLine]t = 
            Random[ExponentialDistribution[\[Lambda]]]; \[IndentingNewLine]If[
            Random[] < k\ R/\[Lambda], \[IndentingNewLine]{t, k + 1, 
              Random[UniformDistribution[0, \ R]]}, \[IndentingNewLine]{t, 
              k - 1, None}]];\)\)], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(\(RandomCoalescenceTimes[n_Integer, k_Integer, R_] := 
        Drop[FoldList[#2 + {#1\[LeftDoubleBracket]1\[RightDoubleBracket], 0, 
                  0} &, {0, 0, 0}, \[IndentingNewLine]Drop[
              NestList[
                RandomCoalescenceTimes[#\[LeftDoubleBracket]2\
\[RightDoubleBracket], R] &, {0, k, 0}, n], 1]], 1];\)\)], "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{

Cell["RandomGenealogy", "Subsubsection",
  InitializationCell->True],

Cell[BoxData[
    \(\(Options[RandomGenealogy] = 
        Join[Options[RandomGenealogy], {PrintDetails \[Rule] False, 
            MaxTime \[Rule] \[Infinity], 
            Fixation \[Rule] False}];\)\)], "Input",
  InitializationCell->True],

Cell[BoxData[{
    \(\(RandomGenealogy::badRec = "\<Attempt to add recombinant lineages \
derived from `1` to `2` failed.\>";\)\), "\[IndentingNewLine]", 
    \(\(RandomGenealogy::oneRec = "\<Only one recombinant lineages derived \
from `1` added to `2`: error.\>";\)\)}], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(\(RandomGenealogy[ll_List, n_Integer, R_, 
          opts___Rule] := \[IndentingNewLine]Module[{rct, 
            g1 = \(g0 = \(AncestralLineage[#, {0, \[Infinity]}, {{#}}, {R}, \
{}] &\) /@ ll\), k = 0, lvs = ll, nl, t = 0, 
            cl, \[IndentingNewLine]pd = \(PrintDetails /. {opts}\) /. 
                Options[
                  RandomGenealogy], \[IndentingNewLine]tm = \(MaxTime /. \
{opts}\) /. Options[
                  RandomGenealogy], \[IndentingNewLine]fix = \(Fixation /. \
{opts}\) /. Options[RandomGenealogy]}, \[IndentingNewLine]While[
            k \[LessEqual] n \[And] t < tm \[And] 
              If[fix, \[IndentingNewLine]Not[
                  FixedQ[\(ExtractLineage[g0, #] &\) /@ lvs, 
                    ll]], \[IndentingNewLine]True], \[IndentingNewLine]\((k += 
                1; \[IndentingNewLine]rct = 
                RandomCoalescenceTimes[Length[lvs], R]; 
              t += rct\[LeftDoubleBracket]1\[RightDoubleBracket]; \
\[IndentingNewLine]If[pd, Print[rct]]; \[IndentingNewLine]If[
                Last[rct] === None, \[IndentingNewLine]nl = 
                  RandomSet[2, lvs]; \[IndentingNewLine]If[pd, 
                  Print["\<Coalescing \>", nl, "\<; current lineages \>", 
                    lvs]]; \[IndentingNewLine]g1 = 
                  AddCoalescentLineage[g0, nl, k + 1, 
                    t]; \[IndentingNewLine]lvs = TakeAway[lvs, nl]; 
                lvs = Append[lvs, k + 1]; 
                k += 1, \[IndentingNewLine]nl = \(RandomSet[1, 
                      lvs]\)\[LeftDoubleBracket]1\[RightDoubleBracket]; \
\[IndentingNewLine]If[pd, 
                  Print["\<Recombining \>", nl, "\<; current lineages \>", 
                    lvs]]; \[IndentingNewLine]g1 = 
                  AddRecombinantLineages[g0, nl, {k + 1, k + 2}, 
                    rct\[LeftDoubleBracket]3\[RightDoubleBracket], t, 
                    opts]; \[IndentingNewLine] (*\(If[pd, 
                      Print[g0, Tab, g1]];\)*) \[IndentingNewLine]Switch[
                  Length[g1] - Length[g0], \[IndentingNewLine]0, 
                  Null, \[IndentingNewLine]1, 
                  Message[RandomGenealogy::oneRec, nl, 
                    g1]; \[IndentingNewLine]lvs = TakeAway[lvs, {nl}]; 
                  lvs = Join[lvs, {k + 1}]; 
                  k += 1, \[IndentingNewLine]2, \[IndentingNewLine]lvs = 
                    TakeAway[lvs, {nl}]; lvs = Join[lvs, {k + 1, k + 2}]; 
                  k += 2, \[IndentingNewLine]_, 
                  Message[RandomGenealogy::badRec, nl, 
                    g1]]]; \[IndentingNewLine]If[
                pd, \[IndentingNewLine]cl = \(ExtractLineage[g1, #] &\) /@ 
                    lvs; \[IndentingNewLine]Print["\<Current lineages =\>", 
                  cl, "\< fixed? \>", FixedQ[cl, ll]]]; 
              g0 = g1)\)]; \[IndentingNewLine]g1];\)\)], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(\(RandomGenealogy[ll_List, rct : {{_, _Integer, _} ... }, R_, 
          opts___Rule] := \[IndentingNewLine]Module[{g1, 
            g0 = \(AncestralLineage[#, {0, \[Infinity]}, {{#}}, {R}, {}] &\) /@ 
                ll, k = 0, lvs = ll, nl, 
            pd = \(PrintDetails /. {opts}\) /. 
                Options[RandomGenealogy]}, \[IndentingNewLine]\(\((If[pd, 
                  Print[#]]; \[IndentingNewLine]If[
                  Last[#] === None, \[IndentingNewLine]nl = 
                    RandomSet[2, lvs]; \[IndentingNewLine]If[pd, 
                    Print["\<Coalescing \>", nl, "\<; current lineages \>", 
                      lvs]]; \[IndentingNewLine]g1 = 
                    AddCoalescentLineage[g0, nl, 
                      k + 1, #\[LeftDoubleBracket]1\[RightDoubleBracket]]; \
\[IndentingNewLine]lvs = TakeAway[lvs, nl]; lvs = Append[lvs, k + 1]; 
                  k += 1, \[IndentingNewLine]nl = \(RandomSet[1, 
                        lvs]\)\[LeftDoubleBracket]1\[RightDoubleBracket]; \
\[IndentingNewLine]If[pd, 
                    Print["\<Recombining \>", nl, "\<; current lineages \>", 
                      lvs]]; \[IndentingNewLine]g1 = 
                    AddRecombinantLineages[g0, 
                      nl, {k + 1, 
                        k + 2}, #\[LeftDoubleBracket]3\[RightDoubleBracket], \
#\[LeftDoubleBracket]1\[RightDoubleBracket]]; \[IndentingNewLine]Switch[
                    Length[g1] - Length[g0], \[IndentingNewLine]1, 
                    lvs = TakeAway[lvs, {nl}]; lvs = Join[lvs, {k + 1}]; 
                    k += 1, \[IndentingNewLine]2, lvs = TakeAway[lvs, {nl}]; 
                    lvs = Join[lvs, {k + 1, k + 2}]; 
                    k += 2, \[IndentingNewLine]_, 
                    Message[RandomGenealogy::badRec, nl, 
                      g1]]]; \[IndentingNewLine]If[pd, Print["\<G=\>", g1]]; 
                g0 = g1)\) &\) /@ rct; \[IndentingNewLine]g1];\)\)], "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{

Cell["Segments", "Subsubsection"],

Cell[BoxData[
    \(\(Segments[al : AncestralLineagePattern, l_] := 
        Module[{xx = al /. AncestralLineage[_, {_, _}, s_, j_, _] :> {s, j}, 
            yy}, \[IndentingNewLine]yy = 
            Replace[Transpose[
                  xx], {{___?\((FreeQ[#, 
                              l] &)\)} \[RuleDelayed] {}, {___?\((FreeQ[#, 
                              l] &)\), 
                      l, ___?\((FreeQ[#, 
                              l] &)\)} \[RuleDelayed] {l}}, {2}] //. {a___, \
{s_List, x0_}, {s_List, x1_}, b___} \[RuleDelayed] {a, {s, x1}, 
                  b}; \[IndentingNewLine]yy = \((yy \
//. \[IndentingNewLine]{{b___, {{}, x0_}, \[IndentingNewLine]{{___, l, ___}, 
                        x1_}, c___} \[RuleDelayed] {b, {x0, x1}, 
                      c}, \[IndentingNewLine]{b___, {{}, _}} \[RuleDelayed] \
{b}, \[IndentingNewLine]{{{___, l, ___}, x0_}, b___} \[RuleDelayed] {{0, x0}, 
                      b}})\)];\)\)], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(\(Segments[al : AncestralGraphPattern, l_] := \(Segments[#, l] &\) /@ 
          al;\)\)], "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{

Cell["PlotSegments", "Subsubsection"],

Cell[BoxData[
    \(\(Options[PlotSegments] = {JunctionStyle \[Rule] {Black}, 
          SegmentStyle \[Rule] {Blue}, 
          BackgroundStyle \[Rule] {Yellow}};\)\)], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(\(PlotSegments[al : AncestralLineagePattern, l_, y_, 
          opts___Rule] := \[IndentingNewLine]Module[{segs = Segments[al, l], 
            yy, \[IndentingNewLine]bs = \(BackgroundStyle /. {opts}\) /. 
                Options[
                  PlotSegments], \[IndentingNewLine]ss = \(SegmentStyle /. \
{opts}\) /. Options[PlotSegments]}, \[IndentingNewLine]yy = 
            bs\[Vee]{Line[{{0, y}, {MapLength[al], 
                      y}}]}\[Vee]ss\[Vee]\[IndentingNewLine]{Replace[
                  segs, {x0_, x1_} \[RuleDelayed] Line[{{x0, y}, {x1, y}}], 
                  1]}; \[IndentingNewLine]Graphics[yy]];\)\)], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(\(PlotSegments[al : AncestralGraphPattern, l_, {y0_, y1_}, 
          opts___Rule] := \[IndentingNewLine]Module[{segs = Segments[al, l], 
            yy, \[IndentingNewLine]jj = Junctions[al], y, k, 
            nl = Length[
                al], \[IndentingNewLine]bs = \(BackgroundStyle /. {opts}\) /. 
                Options[
                  PlotSegments], \[IndentingNewLine]js = \(JunctionStyle /. \
{opts}\) /. Options[
                  PlotSegments], \[IndentingNewLine]ss = \(SegmentStyle /. \
{opts}\) /. Options[PlotSegments]}, \[IndentingNewLine]yy = 
            js\[Vee]Replace[jj, x_ \[RuleDelayed] Line[{{x, y0}, {x, y1}}], 
                1]\[Vee]bs\[Vee]Table[
                Line[{{0, y}, {MapLength[al], y}}], {y, y0, 
                  y1, \(y1 - y0\)\/Max[1, nl - 1]}]\[Vee]Table[
                ss\[Vee]Replace[
                    segs[\([k]\)], {x0_, 
                        x1_} \[RuleDelayed] {Line[{{x0, \(y0 \((nl - k)\) + \
y1 \((k - 1)\)\)\/Max[1, nl - 1]}, {x1, \(y0 \((nl - k)\) + y1 \((k - \
1)\)\)\/Max[1, nl - 1]}}]}, 1], {k, nl}]; \[IndentingNewLine]Graphics[
            yy]];\)\)], "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{

Cell["FixedQ", "Subsubsection"],

Cell[BoxData[{
    \(\(FixedQ[AncestralLineage[_, _List, s_List, _List, _List], 
          lvs_List] := \((Complement[
              Sort /@ s, {{}, 
                Sort[lvs]}] === {})\);\)\), "\[IndentingNewLine]", 
    \(\(FixedQ[ag : AncestralGraphPattern, lvs_List] := 
        And @@ \((\(FixedQ[#, lvs] &\) /@ ag)\);\)\)}], "Input",
  InitializationCell->True]
}, Closed]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Describing genealogies", "Subsection"],

Cell[CellGroupData[{

Cell["MRCA", "Subsubsection",
  InitializationCell->True],

Cell[BoxData[{
    \(\(MRCA[g_Node, {}] := {};\)\), "\[IndentingNewLine]", 
    \(\(MRCA[g_Node, {\((x_)\) .. }] := x;\)\), "\[IndentingNewLine]", 
    \(\(MRCA[g_Node, nl_List] := 
        Module[{al = \(Ancestors[g, #] &\) /@ nl}, \[IndentingNewLine]Last[
            TakeAway[First[al], 
              Complement[First[al], Intersection @@ al]]]];\)\)}], "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{

Cell["PairwiseDivergence", "Subsubsection",
  InitializationCell->True],

Cell[BoxData[{
    \(\(PairwiseDivergence[g_Node, nl_List] := 
        First[ExtractInformation[g, 
            MRCA[g, nl]]];\)\), "\[IndentingNewLine]", 
    \(\(PairwiseDivergence[g_Node] := \(PairwiseDivergence[g, #] &\) /@ 
          Union[Sort /@ 
              DeleteCases[
                Flatten[Outer[List, Leaves[g], Leaves[g]], 1], {a_, 
                  a_}]];\)\)}], "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{

Cell["PairwiseDifference", "Subsubsection",
  InitializationCell->True],

Cell[BoxData[{
    \(\(PairwiseDifference[g_Node, nl_List] := 
        Module[{ml = \(\(ExtractInformation[
                      g, #]\)\[LeftDoubleBracket]2\[RightDoubleBracket] &\) /@ 
                nl}, \[IndentingNewLine]Complement[Union @@ ml, 
            Intersection @@ ml]];\)\), "\[IndentingNewLine]", 
    \(\(PairwiseDifference[g_Node] := \(Length[PairwiseDifference[g, #]] &\) /@ 
          Union[Sort /@ 
              DeleteCases[
                Flatten[Outer[List, Leaves[g], Leaves[g]], 1], {a_, 
                  a_}]];\)\)}], "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{

Cell["MeanPairwiseDivergence", "Subsubsection",
  InitializationCell->True],

Cell[BoxData[
    \(\(MeanPairwiseDivergence[g_Node] := 
        Mean[PairwiseDivergence[g]];\)\)], "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{

Cell["ExtractCoalescenceTimes", "Subsubsection",
  InitializationCell->True],

Cell[BoxData[
    \(\(ExtractCoalescenceTimes[g_Node] := 
        Union[First /@ ExtractInformation[g]];\)\)], "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{

Cell["LengthOfGenealogy", "Subsubsection",
  InitializationCell->True],

Cell[BoxData[
    \(\(LengthOfGenealogy[g_Node] := 
        Module[{ct = ExtractCoalescenceTimes[g]}, \[IndentingNewLine]Last[
              ct] + Plus @@ ct];\)\)], "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{

Cell["DepthOfGenealogy", "Subsubsection",
  InitializationCell->True],

Cell[BoxData[
    \(\(DepthOfGenealogy[g_Node] := 
        Last[ExtractCoalescenceTimes[g]];\)\)], "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{

Cell["PairwiseDivergencePlot", "Subsubsection",
  InitializationCell->True],

Cell[BoxData[{
    \(\(PairwiseDivergencePlot[gl : {__Node}, {dm_, d_}, 
          opts___Rule] := \[IndentingNewLine]Module[{bc = 
              Plus @@ \((\(BinCounts[PairwiseDivergence[#], {0, dm, d}] &\) /@ 
                    gl)\)}, \[IndentingNewLine]ListPlot[
            Transpose[{Range[d\/2, dm - d\/2, d], bc}], 
            opts]];\)\), "\[IndentingNewLine]", 
    \(\(PairwiseDivergencePlot[g_Node, {dm_, d_}, 
          opts___Rule] := \[IndentingNewLine]PairwiseDivergencePlot[{g}, {dm, 
            d}, opts];\)\)}], "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{

Cell["PairwiseDifferencePlot", "Subsubsection",
  InitializationCell->True],

Cell[BoxData[{
    \(\(PairwiseDifferencePlot[gl : {__Node}, {dm_, d_}, 
          opts___Rule] := \[IndentingNewLine]Module[{bc = 
              Plus @@ \((\(BinCounts[PairwiseDifference[#], {0, dm, d}] &\) /@ 
                    gl)\)}, \[IndentingNewLine]ListPlot[
            Transpose[{Range[d\/2, dm - d\/2, d], bc}], 
            opts]];\)\), "\[IndentingNewLine]", 
    \(\(PairwiseDifferencePlot[g_Node, {dm_, d_}, 
          opts___Rule] := \[IndentingNewLine]PairwiseDifferencePlot[{g}, {dm, 
            d}, opts];\)\)}], "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{

Cell["DeleteNullLineages", "Subsubsection"],

Cell[BoxData[
    \(\(DeleteNullLineages[g : AncestralGraphPattern] := 
        DeleteCases[g, 
          AncestralLineage[_, {_, _}, {{}}, {_}, _List]];\)\)], "Input",
  InitializationCell->True]
}, Open  ]],

Cell[CellGroupData[{

Cell["BlockSizes", "Subsubsection"],

Cell[BoxData[{
    \(\(BlockSizes[AncestralLineage[_, {_, _}, {{}}, _List, _List]] := 
        0;\)\), "\[IndentingNewLine]", 
    \(\(BlockSizes[AncestralLineage[_, {_, _}, _List, r_List, _List]] := 
        r - Prepend[Drop[r, \(-1\)], 0];\)\), "\[IndentingNewLine]", 
    \(\(BlockSizes[g : AncestralGraphPattern] := 
        BlockSizes /@ g;\)\)}], "Input",
  InitializationCell->True]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Ending", "Subsection"],

Cell[BoxData[{
    \(\(End[];\)\), "\n", 
    \(\(EndPackage[];\)\)}], "Input",
  InitializationCell->True]
}, Closed]]
}, Open  ]]
},
FrontEndVersion->"4.2 for Macintosh",
ScreenRectangle->{{0, 1276}, {0, 832}},
AutoGeneratedPackage->Automatic,
WindowSize->{1144, 789},
WindowMargins->{{Automatic, 47}, {Automatic, 7}},
Visible->True,
InputAliases->{"notation"->RowBox[ {"Notation", "[", 
        RowBox[ {
          TagBox[ 
          "\[Placeholder]", NotationBoxTag, TagStyle -> 
            "NotationTemplateStyle"], " ", "\[DoubleLongLeftRightArrow]", " ",
           
          TagBox[ 
          "\[Placeholder]", NotationBoxTag, TagStyle -> 
            "NotationTemplateStyle"]}], "]"}], 
    "notation>"->RowBox[ {"Notation", "[", 
        RowBox[ {
          TagBox[ 
          "\[Placeholder]", NotationBoxTag, TagStyle -> 
            "NotationTemplateStyle"], " ", "\[DoubleLongRightArrow]", " ", 
          TagBox[ 
          "\[Placeholder]", NotationBoxTag, TagStyle -> 
            "NotationTemplateStyle"]}], "]"}], 
    "notation<"->RowBox[ {"Notation", "[", 
        RowBox[ {
          TagBox[ 
          "\[Placeholder]", NotationBoxTag, TagStyle -> 
            "NotationTemplateStyle"], " ", "\[DoubleLongLeftArrow]", " ", 
          TagBox[ 
          "\[Placeholder]", NotationBoxTag, TagStyle -> 
            "NotationTemplateStyle"]}], "]"}], 
    "symb"->RowBox[ {"Symbolize", "[", 
        TagBox[ 
        "\[Placeholder]", NotationBoxTag, TagStyle -> 
          "NotationTemplateStyle"], "]"}], 
    "infixnotation"->RowBox[ {"InfixNotation", "[", 
        RowBox[ {
          TagBox[ 
          "\[Placeholder]", NotationBoxTag, TagStyle -> 
            "NotationTemplateStyle"], ",", "\[Placeholder]"}], "]"}], 
    "addia"->RowBox[ {"AddInputAlias", "[", 
        RowBox[ {"\[Placeholder]", "\[Rule]", 
          TagBox[ 
          "\[Placeholder]", NotationBoxTag, TagStyle -> 
            "NotationTemplateStyle"]}], "]"}], 
    "pattwraper"->TagBox[ 
      "\[Placeholder]", NotationPatternTag, TagStyle -> 
        "NotationPatternWrapperStyle"], 
    "madeboxeswraper"->TagBox[ 
      "\[Placeholder]", NotationMadeBoxesTag, TagStyle -> 
        "NotationMadeBoxesWrapperStyle"]},
StyleDefinitions -> Notebook[{
  
  Cell[CellGroupData[{
  Cell["Style Definitions", "Subtitle"],
  
  Cell["\<\
Modify the definitions below to change the default appearance of \
all cells in a given style.  Make modifications to any definition using \
commands in the Format menu.\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell["Style Environment Names", "Section"],
  
  Cell[StyleData[All, "Working"],
    PageWidth->WindowWidth,
    CellLabelMargins->{{12, Inherited}, {Inherited, Inherited}},
    ScriptMinSize->9],
  
  Cell[StyleData[All, "Presentation"],
    PageWidth->WindowWidth,
    CellLabelMargins->{{24, Inherited}, {Inherited, Inherited}},
    ScriptMinSize->12],
  
  Cell[StyleData[All, "Condensed"],
    PageWidth->WindowWidth,
    CellLabelMargins->{{8, Inherited}, {Inherited, Inherited}},
    ScriptMinSize->8],
  
  Cell[StyleData[All, "Printout"],
    PageWidth->PaperWidth,
    CellLabelMargins->{{2, Inherited}, {Inherited, Inherited}},
    ScriptMinSize->5,
    PrivateFontOptions->{"FontType"->"Outline"}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Notebook Options", "Section"],
  
  Cell["\<\
The options defined for the style below will be used at the \
Notebook level.\
\>", "Text"],
  
  Cell[StyleData["Notebook"],
    PageHeaders->{{Cell[ 
            TextData[ {
              CounterBox[ "Page"]}], "PageNumber"], None, Cell[ 
            TextData[ {
              ValueBox[ "FileName"]}], "Header"]}, {Cell[ 
            TextData[ {
              ValueBox[ "FileName"]}], "Header"], None, Cell[ 
            TextData[ {
              CounterBox[ "Page"]}], "PageNumber"]}},
    CellFrameLabelMargins->6,
    StyleMenuListing->None]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Styles for Headings", "Section"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Title"],
    CellMargins->{{12, Inherited}, {20, 40}},
    CellGroupingRules->{"TitleGrouping", 0},
    PageBreakBelow->False,
    DefaultNewInlineCellStyle->"None",
    InputAutoReplacements->{"TeX"->StyleBox[ 
            RowBox[ {"T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.074999999999999997, \
-0.085000000000000006}, {0, 0}}, BoxBaselineShift -> 0.5], "X"}]], 
        "LaTeX"->StyleBox[ 
            RowBox[ {"L", 
              StyleBox[ 
                AdjustmentBox[ 
                "A", BoxMargins -> {{-0.35999999999999999, \
-0.10000000000000001}, {0, 0}}, BoxBaselineShift -> -0.20000000000000001], 
                FontSize -> Smaller], "T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.074999999999999997, \
-0.085000000000000006}, {0, 0}}, BoxBaselineShift -> 0.5], "X"}]], 
        "mma"->"Mathematica", "Mma"->"Mathematica", "MMA"->"Mathematica"},
    LanguageCategory->"NaturalLanguage",
    CounterIncrements->"Title",
    CounterAssignments->{{"Section", 0}, {"Equation", 0}, {"Figure", 0}, {
        "Subtitle", 0}, {"Subsubtitle", 0}},
    FontFamily->"Helvetica",
    FontSize->36,
    FontWeight->"Bold"],
  
  Cell[StyleData["Title", "Presentation"],
    CellMargins->{{24, 10}, {20, 40}},
    LineSpacing->{1, 0},
    FontSize->44],
  
  Cell[StyleData["Title", "Condensed"],
    CellMargins->{{8, 10}, {4, 8}},
    FontSize->20],
  
  Cell[StyleData["Title", "Printout"],
    CellMargins->{{2, 10}, {12, 30}},
    FontSize->24]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Subtitle"],
    CellMargins->{{12, Inherited}, {20, 15}},
    CellGroupingRules->{"TitleGrouping", 10},
    PageBreakBelow->False,
    DefaultNewInlineCellStyle->"None",
    InputAutoReplacements->{"TeX"->StyleBox[ 
            RowBox[ {"T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.074999999999999997, \
-0.085000000000000006}, {0, 0}}, BoxBaselineShift -> 0.5], "X"}]], 
        "LaTeX"->StyleBox[ 
            RowBox[ {"L", 
              StyleBox[ 
                AdjustmentBox[ 
                "A", 
                  BoxMargins -> {{-0.35999999999999999, \
-0.10000000000000001}, {0, 0}}, BoxBaselineShift -> -0.20000000000000001], 
                FontSize -> Smaller], "T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.074999999999999997, \
-0.085000000000000006}, {0, 0}}, BoxBaselineShift -> 0.5], "X"}]], 
        "mma"->"Mathematica", "Mma"->"Mathematica", "MMA"->"Mathematica"},
    LanguageCategory->"NaturalLanguage",
    CounterIncrements->"Subtitle",
    CounterAssignments->{{"Section", 0}, {"Equation", 0}, {"Figure", 0}, {
        "Subsubtitle", 0}},
    FontFamily->"Helvetica",
    FontSize->24],
  
  Cell[StyleData["Subtitle", "Presentation"],
    CellMargins->{{24, 10}, {20, 20}},
    LineSpacing->{1, 0},
    FontSize->36],
  
  Cell[StyleData["Subtitle", "Condensed"],
    CellMargins->{{8, 10}, {4, 4}},
    FontSize->14],
  
  Cell[StyleData["Subtitle", "Printout"],
    CellMargins->{{2, 10}, {12, 8}},
    FontSize->18]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Subsubtitle"],
    CellMargins->{{12, Inherited}, {20, 15}},
    CellGroupingRules->{"TitleGrouping", 20},
    PageBreakBelow->False,
    DefaultNewInlineCellStyle->"None",
    InputAutoReplacements->{"TeX"->StyleBox[ 
            RowBox[ {"T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.074999999999999997, \
-0.085000000000000006}, {0, 0}}, BoxBaselineShift -> 0.5], "X"}]], 
        "LaTeX"->StyleBox[ 
            RowBox[ {"L", 
              StyleBox[ 
                AdjustmentBox[ 
                "A", BoxMargins -> {{-0.35999999999999999, \
-0.10000000000000001}, {0, 0}}, BoxBaselineShift -> -0.20000000000000001], 
                FontSize -> Smaller], "T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.074999999999999997, \
-0.085000000000000006}, {0, 0}}, BoxBaselineShift -> 0.5], "X"}]], 
        "mma"->"Mathematica", "Mma"->"Mathematica", "MMA"->"Mathematica"},
    LanguageCategory->"NaturalLanguage",
    CounterIncrements->"Subsubtitle",
    CounterAssignments->{{"Section", 0}, {"Equation", 0}, {"Figure", 0}},
    FontFamily->"Helvetica",
    FontSize->14,
    FontSlant->"Italic"],
  
  Cell[StyleData["Subsubtitle", "Presentation"],
    CellMargins->{{24, 10}, {20, 20}},
    LineSpacing->{1, 0},
    FontSize->24],
  
  Cell[StyleData["Subsubtitle", "Condensed"],
    CellMargins->{{8, 10}, {8, 8}},
    FontSize->12],
  
  Cell[StyleData["Subsubtitle", "Printout"],
    CellMargins->{{2, 10}, {12, 8}},
    FontSize->14]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Section"],
    CellDingbat->"\[FilledSquare]",
    CellMargins->{{25, Inherited}, {8, 24}},
    CellGroupingRules->{"SectionGrouping", 30},
    PageBreakBelow->False,
    DefaultNewInlineCellStyle->"None",
    InputAutoReplacements->{"TeX"->StyleBox[ 
            RowBox[ {"T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.074999999999999997, \
-0.085000000000000006}, {0, 0}}, BoxBaselineShift -> 0.5], "X"}]], 
        "LaTeX"->StyleBox[ 
            RowBox[ {"L", 
              StyleBox[ 
                AdjustmentBox[ 
                "A", BoxMargins -> {{-0.35999999999999999, \
-0.10000000000000001}, {0, 0}}, BoxBaselineShift -> -0.20000000000000001], 
                FontSize -> Smaller], "T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.074999999999999997, \
-0.085000000000000006}, {0, 0}}, BoxBaselineShift -> 0.5], "X"}]], 
        "mma"->"Mathematica", "Mma"->"Mathematica", "MMA"->"Mathematica"},
    LanguageCategory->"NaturalLanguage",
    CounterIncrements->"Section",
    CounterAssignments->{{"Subsection", 0}, {"Subsubsection", 0}},
    FontFamily->"Helvetica",
    FontSize->16,
    FontWeight->"Bold"],
  
  Cell[StyleData["Section", "Presentation"],
    CellMargins->{{40, 10}, {11, 32}},
    LineSpacing->{1, 0},
    FontSize->24],
  
  Cell[StyleData["Section", "Condensed"],
    CellMargins->{{18, Inherited}, {6, 12}},
    FontSize->12],
  
  Cell[StyleData["Section", "Printout"],
    CellMargins->{{13, 0}, {7, 22}},
    FontSize->14]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Subsection"],
    CellDingbat->"\[FilledSmallSquare]",
    CellMargins->{{22, Inherited}, {8, 20}},
    CellGroupingRules->{"SectionGrouping", 40},
    PageBreakBelow->False,
    DefaultNewInlineCellStyle->"None",
    InputAutoReplacements->{"TeX"->StyleBox[ 
            RowBox[ {"T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.074999999999999997, \
-0.085000000000000006}, {0, 0}}, BoxBaselineShift -> 0.5], "X"}]], 
        "LaTeX"->StyleBox[ 
            RowBox[ {"L", 
              StyleBox[ 
                AdjustmentBox[ 
                "A", BoxMargins -> {{-0.35999999999999999, \
-0.10000000000000001}, {0, 0}}, BoxBaselineShift -> -0.20000000000000001], 
                FontSize -> Smaller], "T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.074999999999999997, \
-0.085000000000000006}, {0, 0}}, BoxBaselineShift -> 0.5], "X"}]], 
        "mma"->"Mathematica", "Mma"->"Mathematica", "MMA"->"Mathematica"},
    LanguageCategory->"NaturalLanguage",
    CounterIncrements->"Subsection",
    CounterAssignments->{{"Subsubsection", 0}},
    FontFamily->"Times",
    FontSize->14,
    FontWeight->"Bold"],
  
  Cell[StyleData["Subsection", "Presentation"],
    CellMargins->{{36, 10}, {11, 32}},
    LineSpacing->{1, 0},
    FontSize->22],
  
  Cell[StyleData["Subsection", "Condensed"],
    CellMargins->{{16, Inherited}, {6, 12}},
    FontSize->12],
  
  Cell[StyleData["Subsection", "Printout"],
    CellMargins->{{9, 0}, {7, 22}},
    FontSize->12]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Subsubsection"],
    CellDingbat->"\[FilledSmallSquare]",
    CellMargins->{{22, Inherited}, {8, 18}},
    CellGroupingRules->{"SectionGrouping", 50},
    PageBreakBelow->False,
    DefaultNewInlineCellStyle->"None",
    InputAutoReplacements->{"TeX"->StyleBox[ 
            RowBox[ {"T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.074999999999999997, \
-0.085000000000000006}, {0, 0}}, BoxBaselineShift -> 0.5], "X"}]], 
        "LaTeX"->StyleBox[ 
            RowBox[ {"L", 
              StyleBox[ 
                AdjustmentBox[ 
                "A", BoxMargins -> {{-0.35999999999999999, \
-0.10000000000000001}, {0, 0}}, BoxBaselineShift -> -0.20000000000000001], 
                FontSize -> Smaller], "T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.074999999999999997, \
-0.085000000000000006}, {0, 0}}, BoxBaselineShift -> 0.5], "X"}]], 
        "mma"->"Mathematica", "Mma"->"Mathematica", "MMA"->"Mathematica"},
    LanguageCategory->"NaturalLanguage",
    CounterIncrements->"Subsubsection",
    FontFamily->"Times",
    FontWeight->"Bold"],
  
  Cell[StyleData["Subsubsection", "Presentation"],
    CellMargins->{{34, 10}, {11, 26}},
    LineSpacing->{1, 0},
    FontSize->18],
  
  Cell[StyleData["Subsubsection", "Condensed"],
    CellMargins->{{17, Inherited}, {6, 12}},
    FontSize->10],
  
  Cell[StyleData["Subsubsection", "Printout"],
    CellMargins->{{9, 0}, {7, 14}},
    FontSize->11]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Styles for Body Text", "Section"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Text"],
    CellMargins->{{12, 10}, {7, 7}},
    InputAutoReplacements->{"TeX"->StyleBox[ 
            RowBox[ {"T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.074999999999999997, \
-0.085000000000000006}, {0, 0}}, BoxBaselineShift -> 0.5], "X"}]], 
        "LaTeX"->StyleBox[ 
            RowBox[ {"L", 
              StyleBox[ 
                AdjustmentBox[ 
                "A", BoxMargins -> {{-0.35999999999999999, \
-0.10000000000000001}, {0, 0}}, BoxBaselineShift -> -0.20000000000000001], 
                FontSize -> Smaller], "T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.074999999999999997, \
-0.085000000000000006}, {0, 0}}, BoxBaselineShift -> 0.5], "X"}]], 
        "mma"->"Mathematica", "Mma"->"Mathematica", "MMA"->"Mathematica"},
    Hyphenation->True,
    LineSpacing->{1, 3},
    CounterIncrements->"Text"],
  
  Cell[StyleData["Text", "Presentation"],
    CellMargins->{{24, 10}, {10, 10}},
    LineSpacing->{1, 5},
    FontSize->16],
  
  Cell[StyleData["Text", "Condensed"],
    CellMargins->{{8, 10}, {6, 6}},
    LineSpacing->{1, 1},
    FontSize->11],
  
  Cell[StyleData["Text", "Printout"],
    CellMargins->{{2, 2}, {6, 6}},
    TextJustification->0.5,
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["SmallText"],
    CellMargins->{{12, 10}, {6, 6}},
    DefaultNewInlineCellStyle->"None",
    Hyphenation->True,
    LineSpacing->{1, 3},
    LanguageCategory->"NaturalLanguage",
    CounterIncrements->"SmallText",
    FontFamily->"Helvetica",
    FontSize->9],
  
  Cell[StyleData["SmallText", "Presentation"],
    CellMargins->{{24, 10}, {8, 8}},
    LineSpacing->{1, 5},
    FontSize->12],
  
  Cell[StyleData["SmallText", "Condensed"],
    CellMargins->{{8, 10}, {5, 5}},
    LineSpacing->{1, 2},
    FontSize->9],
  
  Cell[StyleData["SmallText", "Printout"],
    CellMargins->{{2, 2}, {5, 5}},
    TextJustification->0.5,
    FontSize->7]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Styles for Input/Output", "Section"],
  
  Cell["\<\
The cells in this section define styles used for input and output \
to the kernel.  Be careful when modifying, renaming, or removing these \
styles, because the front end associates special meanings with these style \
names. Some attributes for these styles are actually set in FormatType Styles \
(in the last section of this stylesheet). \
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Input"],
    CellMargins->{{45, 10}, {5, 7}},
    Evaluatable->True,
    CellGroupingRules->"InputGrouping",
    CellHorizontalScrolling->True,
    PageBreakWithin->False,
    GroupPageBreakWithin->False,
    DefaultFormatType->DefaultInputFormatType,
    HyphenationOptions->{"HyphenationCharacter"->"\[Continuation]"},
    AutoItalicWords->{},
    LanguageCategory->"Formula",
    FormatType->InputForm,
    ShowStringCharacters->True,
    NumberMarks->True,
    LinebreakAdjustments->{0.85, 2, 10, 0, 1},
    CounterIncrements->"Input",
    FontWeight->"Bold"],
  
  Cell[StyleData["Input", "Presentation"],
    CellMargins->{{72, Inherited}, {8, 10}},
    LineSpacing->{1, 0},
    FontSize->16],
  
  Cell[StyleData["Input", "Condensed"],
    CellMargins->{{40, 10}, {2, 3}},
    FontSize->11],
  
  Cell[StyleData["Input", "Printout"],
    CellMargins->{{39, 0}, {4, 6}},
    LinebreakAdjustments->{0.85, 2, 10, 1, 1},
    FontSize->9]
  }, Closed]],
  
  Cell[StyleData["InputOnly"],
    Evaluatable->True,
    CellGroupingRules->"InputGrouping",
    CellHorizontalScrolling->True,
    DefaultFormatType->DefaultInputFormatType,
    HyphenationOptions->{"HyphenationCharacter"->"\[Continuation]"},
    AutoItalicWords->{},
    LanguageCategory->"Formula",
    FormatType->InputForm,
    ShowStringCharacters->True,
    NumberMarks->True,
    LinebreakAdjustments->{0.85, 2, 10, 0, 1},
    CounterIncrements->"Input",
    StyleMenuListing->None,
    FontWeight->"Bold"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Output"],
    CellMargins->{{47, 10}, {7, 5}},
    CellEditDuplicate->True,
    CellGroupingRules->"OutputGrouping",
    CellHorizontalScrolling->True,
    PageBreakWithin->False,
    GroupPageBreakWithin->False,
    GeneratedCell->True,
    CellAutoOverwrite->True,
    DefaultFormatType->DefaultOutputFormatType,
    HyphenationOptions->{"HyphenationCharacter"->"\[Continuation]"},
    AutoItalicWords->{},
    LanguageCategory->"Formula",
    FormatType->InputForm,
    CounterIncrements->"Output"],
  
  Cell[StyleData["Output", "Presentation"],
    CellMargins->{{72, Inherited}, {10, 8}},
    LineSpacing->{1, 0},
    FontSize->16],
  
  Cell[StyleData["Output", "Condensed"],
    CellMargins->{{41, Inherited}, {3, 2}},
    FontSize->11],
  
  Cell[StyleData["Output", "Printout"],
    CellMargins->{{39, 0}, {6, 4}},
    FontSize->9]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Message"],
    CellMargins->{{45, Inherited}, {Inherited, Inherited}},
    CellGroupingRules->"OutputGrouping",
    PageBreakWithin->False,
    GroupPageBreakWithin->False,
    GeneratedCell->True,
    CellAutoOverwrite->True,
    ShowCellLabel->False,
    DefaultFormatType->DefaultOutputFormatType,
    HyphenationOptions->{"HyphenationCharacter"->"\[Continuation]"},
    AutoItalicWords->{},
    FormatType->InputForm,
    CounterIncrements->"Message",
    StyleMenuListing->None,
    FontSize->11,
    FontColor->RGBColor[0, 0, 1]],
  
  Cell[StyleData["Message", "Presentation"],
    CellMargins->{{72, Inherited}, {Inherited, Inherited}},
    LineSpacing->{1, 0},
    FontSize->16],
  
  Cell[StyleData["Message", "Condensed"],
    CellMargins->{{41, Inherited}, {Inherited, Inherited}},
    FontSize->11],
  
  Cell[StyleData["Message", "Printout"],
    CellMargins->{{39, Inherited}, {Inherited, Inherited}},
    FontSize->7,
    FontColor->GrayLevel[0]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Print"],
    CellMargins->{{45, Inherited}, {Inherited, Inherited}},
    CellGroupingRules->"OutputGrouping",
    CellHorizontalScrolling->True,
    PageBreakWithin->False,
    GroupPageBreakWithin->False,
    GeneratedCell->True,
    CellAutoOverwrite->True,
    ShowCellLabel->False,
    DefaultFormatType->DefaultOutputFormatType,
    HyphenationOptions->{"HyphenationCharacter"->"\[Continuation]"},
    AutoItalicWords->{},
    FormatType->InputForm,
    CounterIncrements->"Print",
    StyleMenuListing->None],
  
  Cell[StyleData["Print", "Presentation"],
    CellMargins->{{72, Inherited}, {Inherited, Inherited}},
    LineSpacing->{1, 0},
    FontSize->16],
  
  Cell[StyleData["Print", "Condensed"],
    CellMargins->{{41, Inherited}, {Inherited, Inherited}},
    FontSize->11],
  
  Cell[StyleData["Print", "Printout"],
    CellMargins->{{39, Inherited}, {Inherited, Inherited}},
    FontSize->8]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Graphics"],
    CellMargins->{{4, Inherited}, {Inherited, Inherited}},
    CellGroupingRules->"GraphicsGrouping",
    CellHorizontalScrolling->True,
    PageBreakWithin->False,
    GeneratedCell->True,
    CellAutoOverwrite->True,
    ShowCellLabel->False,
    DefaultFormatType->DefaultOutputFormatType,
    LanguageCategory->None,
    FormatType->InputForm,
    CounterIncrements->"Graphics",
    ImageMargins->{{43, Inherited}, {Inherited, 0}},
    StyleMenuListing->None,
    FontFamily->"Courier",
    FontSize->10],
  
  Cell[StyleData["Graphics", "Presentation"],
    ImageMargins->{{62, Inherited}, {Inherited, 0}}],
  
  Cell[StyleData["Graphics", "Condensed"],
    ImageMargins->{{38, Inherited}, {Inherited, 0}},
    Magnification->0.6],
  
  Cell[StyleData["Graphics", "Printout"],
    ImageMargins->{{30, Inherited}, {Inherited, 0}},
    Magnification->0.8]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["CellLabel"],
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->9,
    FontColor->RGBColor[0, 0, 1]],
  
  Cell[StyleData["CellLabel", "Presentation"],
    FontSize->12],
  
  Cell[StyleData["CellLabel", "Condensed"],
    FontSize->9],
  
  Cell[StyleData["CellLabel", "Printout"],
    FontFamily->"Courier",
    FontSize->8,
    FontSlant->"Italic",
    FontColor->GrayLevel[0]]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Inline Formatting", "Section"],
  
  Cell["\<\
These styles are for modifying individual words or letters in a \
cell exclusive of the cell tag.\
\>", "Text"],
  
  Cell[StyleData["RM"],
    StyleMenuListing->None,
    FontWeight->"Plain",
    FontSlant->"Plain"],
  
  Cell[StyleData["BF"],
    StyleMenuListing->None,
    FontWeight->"Bold"],
  
  Cell[StyleData["IT"],
    StyleMenuListing->None,
    FontSlant->"Italic"],
  
  Cell[StyleData["TR"],
    StyleMenuListing->None,
    FontFamily->"Times",
    FontWeight->"Plain",
    FontSlant->"Plain"],
  
  Cell[StyleData["TI"],
    StyleMenuListing->None,
    FontFamily->"Times",
    FontWeight->"Plain",
    FontSlant->"Italic"],
  
  Cell[StyleData["TB"],
    StyleMenuListing->None,
    FontFamily->"Times",
    FontWeight->"Bold",
    FontSlant->"Plain"],
  
  Cell[StyleData["TBI"],
    StyleMenuListing->None,
    FontFamily->"Times",
    FontWeight->"Bold",
    FontSlant->"Italic"],
  
  Cell[StyleData["MR"],
    StyleMenuListing->None,
    FontFamily->"Courier",
    FontWeight->"Plain",
    FontSlant->"Plain"],
  
  Cell[StyleData["MO"],
    StyleMenuListing->None,
    FontFamily->"Courier",
    FontWeight->"Plain",
    FontSlant->"Italic"],
  
  Cell[StyleData["MB"],
    StyleMenuListing->None,
    FontFamily->"Courier",
    FontWeight->"Bold",
    FontSlant->"Plain"],
  
  Cell[StyleData["MBO"],
    StyleMenuListing->None,
    FontFamily->"Courier",
    FontWeight->"Bold",
    FontSlant->"Italic"],
  
  Cell[StyleData["SR"],
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontWeight->"Plain",
    FontSlant->"Plain"],
  
  Cell[StyleData["SO"],
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontWeight->"Plain",
    FontSlant->"Italic"],
  
  Cell[StyleData["SB"],
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontWeight->"Bold",
    FontSlant->"Plain"],
  
  Cell[StyleData["SBO"],
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontWeight->"Bold",
    FontSlant->"Italic"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["SO10"],
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->10,
    FontWeight->"Plain",
    FontSlant->"Italic"],
  
  Cell[StyleData["SO10", "Printout"],
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->7,
    FontWeight->"Plain",
    FontSlant->"Italic"],
  
  Cell[StyleData["SO10", "EnhancedPrintout"],
    StyleMenuListing->None,
    FontFamily->"Futura",
    FontSize->7,
    FontWeight->"Plain",
    FontSlant->"Italic"]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Formulas and Programming", "Section"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["InlineFormula"],
    CellMargins->{{10, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    HyphenationOptions->{"HyphenationCharacter"->"\[Continuation]"},
    LanguageCategory->"Formula",
    ScriptLevel->1,
    SingleLetterItalics->True],
  
  Cell[StyleData["InlineFormula", "Presentation"],
    CellMargins->{{24, 10}, {10, 10}},
    LineSpacing->{1, 5},
    FontSize->16],
  
  Cell[StyleData["InlineFormula", "Condensed"],
    CellMargins->{{8, 10}, {6, 6}},
    LineSpacing->{1, 1},
    FontSize->11],
  
  Cell[StyleData["InlineFormula", "Printout"],
    CellMargins->{{2, 0}, {6, 6}},
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["DisplayFormula"],
    CellMargins->{{42, Inherited}, {Inherited, Inherited}},
    CellHorizontalScrolling->True,
    DefaultFormatType->DefaultInputFormatType,
    HyphenationOptions->{"HyphenationCharacter"->"\[Continuation]"},
    LanguageCategory->"Formula",
    ScriptLevel->0,
    SingleLetterItalics->True,
    UnderoverscriptBoxOptions->{LimitsPositioning->True}],
  
  Cell[StyleData["DisplayFormula", "Presentation"],
    LineSpacing->{1, 5},
    FontSize->16],
  
  Cell[StyleData["DisplayFormula", "Condensed"],
    LineSpacing->{1, 1},
    FontSize->11],
  
  Cell[StyleData["DisplayFormula", "Printout"],
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Program"],
    CellFrame->{{0, 0}, {0.5, 0.5}},
    CellMargins->{{10, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    LanguageCategory->"Formula",
    ScriptLevel->1,
    FontFamily->"Courier"],
  
  Cell[StyleData["Program", "Presentation"],
    CellMargins->{{24, 10}, {10, 10}},
    LineSpacing->{1, 5},
    FontSize->16],
  
  Cell[StyleData["Program", "Condensed"],
    CellMargins->{{8, 10}, {6, 6}},
    LineSpacing->{1, 1},
    FontSize->11],
  
  Cell[StyleData["Program", "Printout"],
    CellMargins->{{2, 0}, {6, 6}},
    FontSize->9]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Hyperlink Styles", "Section"],
  
  Cell["\<\
The cells below define styles useful for making hypertext \
ButtonBoxes.  The \"Hyperlink\" style is for links within the same Notebook, \
or between Notebooks.\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Hyperlink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontColor->RGBColor[0, 0, 1],
    FontVariations->{"Underline"->True},
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`NotebookLocate[ #2]}]&),
    Active->True,
    ButtonNote->ButtonData}],
  
  Cell[StyleData["Hyperlink", "Presentation"],
    FontSize->16],
  
  Cell[StyleData["Hyperlink", "Condensed"],
    FontSize->11],
  
  Cell[StyleData["Hyperlink", "Printout"],
    FontSize->10,
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Closed]],
  
  Cell["\<\
The following styles are for linking automatically to the on-line \
help system.\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["MainBookLink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontColor->RGBColor[0, 0, 1],
    FontVariations->{"Underline"->True},
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`HelpBrowserLookup[ "MainBook", #]}]&),
    Active->True,
    ButtonFrame->"None"}],
  
  Cell[StyleData["MainBookLink", "Presentation"],
    FontSize->16],
  
  Cell[StyleData["MainBookLink", "Condensed"],
    FontSize->11],
  
  Cell[StyleData["MainBookLink", "Printout"],
    FontSize->10,
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["AddOnsLink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontFamily->"Courier",
    FontColor->RGBColor[0, 0, 1],
    FontVariations->{"Underline"->True},
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`HelpBrowserLookup[ "AddOns", #]}]&),
    Active->True,
    ButtonFrame->"None"}],
  
  Cell[StyleData["AddOnsLink", "Presentation"],
    FontSize->16],
  
  Cell[StyleData["AddOnsLink", "Condensed"],
    FontSize->11],
  
  Cell[StyleData["AddOnsLink", "Printout"],
    FontSize->10,
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["RefGuideLink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontFamily->"Courier",
    FontColor->RGBColor[0, 0, 1],
    FontVariations->{"Underline"->True},
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`HelpBrowserLookup[ "RefGuide", #]}]&),
    Active->True,
    ButtonFrame->"None"}],
  
  Cell[StyleData["RefGuideLink", "Presentation"],
    FontSize->16],
  
  Cell[StyleData["RefGuideLink", "Condensed"],
    FontSize->11],
  
  Cell[StyleData["RefGuideLink", "Printout"],
    FontSize->10,
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["GettingStartedLink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontColor->RGBColor[0, 0, 1],
    FontVariations->{"Underline"->True},
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`HelpBrowserLookup[ "GettingStarted", #]}]&),
    Active->True,
    ButtonFrame->"None"}],
  
  Cell[StyleData["GettingStartedLink", "Presentation"],
    FontSize->16],
  
  Cell[StyleData["GettingStartedLink", "Condensed"],
    FontSize->11],
  
  Cell[StyleData["GettingStartedLink", "Printout"],
    FontSize->10,
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["OtherInformationLink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontColor->RGBColor[0, 0, 1],
    FontVariations->{"Underline"->True},
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`HelpBrowserLookup[ "OtherInformation", #]}]&),
    Active->True,
    ButtonFrame->"None"}],
  
  Cell[StyleData["OtherInformationLink", "Presentation"],
    FontSize->16],
  
  Cell[StyleData["OtherInformationLink", "Condensed"],
    FontSize->11],
  
  Cell[StyleData["OtherInformationLink", "Printout"],
    FontSize->10,
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Styles for Headers and Footers", "Section"],
  
  Cell[StyleData["Header"],
    CellMargins->{{0, 0}, {4, 1}},
    DefaultNewInlineCellStyle->"None",
    LanguageCategory->"NaturalLanguage",
    StyleMenuListing->None,
    FontSize->10,
    FontSlant->"Italic"],
  
  Cell[StyleData["Footer"],
    CellMargins->{{0, 0}, {0, 4}},
    DefaultNewInlineCellStyle->"None",
    LanguageCategory->"NaturalLanguage",
    StyleMenuListing->None,
    FontSize->9,
    FontSlant->"Italic"],
  
  Cell[StyleData["PageNumber"],
    CellMargins->{{0, 0}, {4, 1}},
    StyleMenuListing->None,
    FontFamily->"Times",
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Palette Styles", "Section"],
  
  Cell["\<\
The cells below define styles that define standard \
ButtonFunctions, for use in palette buttons.\
\>", "Text"],
  
  Cell[StyleData["Paste"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`NotebookApply[ 
          FrontEnd`InputNotebook[ ], #, After]}]&)}],
  
  Cell[StyleData["Evaluate"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`NotebookApply[ 
          FrontEnd`InputNotebook[ ], #, All], 
        SelectionEvaluate[ 
          FrontEnd`InputNotebook[ ], All]}]&)}],
  
  Cell[StyleData["EvaluateCell"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`NotebookApply[ 
          FrontEnd`InputNotebook[ ], #, All], 
        FrontEnd`SelectionMove[ 
          FrontEnd`InputNotebook[ ], All, Cell, 1], 
        FrontEnd`SelectionEvaluateCreateCell[ 
          FrontEnd`InputNotebook[ ], All]}]&)}],
  
  Cell[StyleData["CopyEvaluate"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`SelectionCreateCell[ 
          FrontEnd`InputNotebook[ ], All], 
        FrontEnd`NotebookApply[ 
          FrontEnd`InputNotebook[ ], #, All], 
        FrontEnd`SelectionEvaluate[ 
          FrontEnd`InputNotebook[ ], All]}]&)}],
  
  Cell[StyleData["CopyEvaluateCell"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`SelectionCreateCell[ 
          FrontEnd`InputNotebook[ ], All], 
        FrontEnd`NotebookApply[ 
          FrontEnd`InputNotebook[ ], #, All], 
        FrontEnd`SelectionEvaluateCreateCell[ 
          FrontEnd`InputNotebook[ ], All]}]&)}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Placeholder Styles", "Section"],
  
  Cell["\<\
The cells below define styles useful for making placeholder \
objects in palette templates.\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Placeholder"],
    Placeholder->True,
    StyleMenuListing->None,
    FontSlant->"Italic",
    FontColor->RGBColor[0.890623, 0.864698, 0.384756],
    TagBoxOptions->{Editable->False,
    Selectable->False,
    StripWrapperBoxes->False}],
  
  Cell[StyleData["Placeholder", "Presentation"]],
  
  Cell[StyleData["Placeholder", "Condensed"]],
  
  Cell[StyleData["Placeholder", "Printout"]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["PrimaryPlaceholder"],
    StyleMenuListing->None,
    DrawHighlighted->True,
    FontSlant->"Italic",
    Background->RGBColor[0.912505, 0.891798, 0.507774],
    TagBoxOptions->{Editable->False,
    Selectable->False,
    StripWrapperBoxes->False}],
  
  Cell[StyleData["PrimaryPlaceholder", "Presentation"]],
  
  Cell[StyleData["PrimaryPlaceholder", "Condensed"]],
  
  Cell[StyleData["PrimaryPlaceholder", "Printout"]]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["FormatType Styles", "Section"],
  
  Cell["\<\
The cells below define styles that are mixed in with the styles \
of most cells.  If a cell's FormatType matches the name of one of the styles \
defined below, then that style is applied between the cell's style and its \
own options. This is particularly true of Input and Output.\
\>", "Text"],
  
  Cell[StyleData["CellExpression"],
    PageWidth->Infinity,
    CellMargins->{{6, Inherited}, {Inherited, Inherited}},
    ShowCellLabel->False,
    ShowSpecialCharacters->False,
    AllowInlineCells->False,
    Hyphenation->False,
    AutoItalicWords->{},
    StyleMenuListing->None,
    FontFamily->"Courier",
    FontSize->12,
    Background->GrayLevel[1]],
  
  Cell[StyleData["InputForm"],
    InputAutoReplacements->{},
    AllowInlineCells->False,
    Hyphenation->False,
    StyleMenuListing->None,
    FontFamily->"Courier"],
  
  Cell[StyleData["OutputForm"],
    PageWidth->Infinity,
    TextAlignment->Left,
    LineSpacing->{0.6, 1},
    StyleMenuListing->None,
    FontFamily->"Courier"],
  
  Cell[StyleData["StandardForm"],
    InputAutoReplacements->{
      "->"->"\[Rule]", ":>"->"\[RuleDelayed]", "<="->"\[LessEqual]", 
        ">="->"\[GreaterEqual]", "!="->"\[NotEqual]", "=="->"\[Equal]", 
        Inherited},
    LineSpacing->{1.25, 0},
    StyleMenuListing->None,
    FontFamily->"Courier"],
  
  Cell[StyleData["TraditionalForm"],
    InputAutoReplacements->{
      "->"->"\[Rule]", ":>"->"\[RuleDelayed]", "<="->"\[LessEqual]", 
        ">="->"\[GreaterEqual]", "!="->"\[NotEqual]", "=="->"\[Equal]", 
        Inherited},
    LineSpacing->{1.25, 0},
    SingleLetterItalics->True,
    TraditionalFunctionNotation->True,
    DelimiterMatching->None,
    StyleMenuListing->None],
  
  Cell["\<\
The style defined below is mixed in to any cell that is in an \
inline cell within another.\
\>", "Text"],
  
  Cell[StyleData["InlineCell"],
    TextAlignment->Left,
    ScriptLevel->1,
    StyleMenuListing->None],
  
  Cell[StyleData["InlineCellEditing"],
    StyleMenuListing->None,
    Background->RGBColor[1, 0.749996, 0.8]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Automatic Styles", "Section"],
  
  Cell["\<\
The cells below define styles that are used to affect the display \
of certain types of objects in typeset expressions.  For example, \
\"UnmatchedBracket\" style defines how unmatched bracket, curly bracket, and \
parenthesis characters are displayed (typically by coloring them to make them \
stand out).\
\>", "Text"],
  
  Cell[StyleData["UnmatchedBracket"],
    StyleMenuListing->None,
    FontColor->RGBColor[0.760006, 0.330007, 0.8]]
  }, Closed]]
  }, Open  ]],
  
  Cell[CellGroupData[{
  
  Cell["Notation Package Styles", "Section",
    GeneratedCell->True,
    CellTags->"NotationPackage"],
  
  Cell["\<\
The cells below define certain styles needed by the Notation \
package. These styles serve to make visible otherwise invisible \
tagboxes.\
\>", "Text",
    GeneratedCell->True,
    CellTags->"NotationPackage"],
  
  Cell[StyleData["NotationTemplateStyle"],
    GeneratedCell->True,
    StyleMenuListing->None,
    Background->RGBColor[1, 1, 0.850004],
    TagBoxOptions->{SyntaxForm->"symbol"},
    CellTags->"NotationPackage"],
  
  Cell[StyleData["NotationPatternWrapperStyle"],
    GeneratedCell->True,
    StyleMenuListing->None,
    Background->RGBColor[1, 0.900008, 0.979995],
    TagBoxOptions->{SyntaxForm->"symbol"},
    CellTags->"NotationPackage"],
  
  Cell[StyleData["NotationMadeBoxesWrapperStyle"],
    GeneratedCell->True,
    StyleMenuListing->None,
    Background->RGBColor[0.900008, 0.889998, 1],
    TagBoxOptions->{SyntaxForm->"symbol"},
    CellTags->"NotationPackage"]
  }, Closed]]
  }]
]

(*******************************************************************
Cached data follows.  If you edit this Notebook file directly, not
using Mathematica, you must remove the line containing CacheID at
the top of  the file.  The cache data will then be recreated when
you save this file from within Mathematica.
*******************************************************************)

(*CellTagsOutline
CellTagsIndex->{}
*)

(*CellTagsIndex
CellTagsIndex->{}
*)

(*NotebookFileOutline
Notebook[{
Cell[1754, 51, 500, 10, 155, "Input",
  InitializationCell->True],
Cell[2257, 63, 267, 4, 43, "Input"],

Cell[CellGroupData[{
Cell[2549, 71, 113, 3, 50, "Section",
  Evaluatable->False,
  InitializationCell->True],

Cell[CellGroupData[{
Cell[2687, 78, 44, 0, 46, "Subsection"],

Cell[CellGroupData[{
Cell[2756, 82, 317, 6, 58, "Subsubsection"],

Cell[CellGroupData[{
Cell[3098, 92, 370, 6, 75, "Input",
  InitializationCell->True],
Cell[3471, 100, 185, 3, 70, "Message"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{
Cell[3705, 109, 157, 3, 28, "Subsubsection"],
Cell[3865, 114, 220, 4, 59, "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{
Cell[4122, 123, 103, 3, 28, "Subsubsection"],
Cell[4228, 128, 591, 9, 91, "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{
Cell[4856, 142, 104, 3, 28, "Subsubsection"],
Cell[4963, 147, 168, 3, 59, "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{
Cell[5168, 155, 465, 10, 28, "Subsubsection"],
Cell[5636, 167, 492, 8, 107, "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{
Cell[6165, 180, 244, 5, 44, "Subsubsection"],
Cell[6412, 187, 301, 5, 75, "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{
Cell[6750, 197, 104, 3, 28, "Subsubsection"],
Cell[6857, 202, 213, 4, 43, "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{
Cell[7107, 211, 106, 3, 28, "Subsubsection"],

Cell[CellGroupData[{
Cell[7238, 218, 160, 3, 43, "Input",
  InitializationCell->True],
Cell[7401, 223, 182, 3, 70, "Message"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{
Cell[7632, 232, 97, 3, 28, "Subsubsection"],
Cell[7732, 237, 159, 3, 43, "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{
Cell[7928, 245, 79, 0, 28, "Subsubsection"],
Cell[8010, 247, 292, 5, 75, "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{
Cell[8339, 257, 179, 3, 28, "Subsubsection"],
Cell[8521, 262, 460, 7, 107, "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{
Cell[9018, 274, 156, 3, 28, "Subsubsection"],
Cell[9177, 279, 305, 5, 59, "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{
Cell[9519, 289, 136, 3, 28, "Subsubsection"],
Cell[9658, 294, 324, 5, 75, "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{
Cell[10019, 304, 341, 5, 44, "Subsubsection"],
Cell[10363, 311, 594, 9, 139, "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{
Cell[10994, 325, 122, 3, 28, "Subsubsection"],
Cell[11119, 330, 181, 3, 43, "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{
Cell[11337, 338, 122, 3, 28, "Subsubsection"],
Cell[11462, 343, 181, 3, 43, "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{
Cell[11680, 351, 188, 3, 28, "Subsubsection"],
Cell[11871, 356, 243, 4, 59, "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{
Cell[12151, 365, 120, 3, 28, "Subsubsection"],
Cell[12274, 370, 194, 3, 43, "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{
Cell[12505, 378, 136, 3, 28, "Subsubsection"],
Cell[12644, 383, 192, 3, 43, "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{
Cell[12873, 391, 104, 3, 28, "Subsubsection"],
Cell[12980, 396, 591, 9, 139, "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{
Cell[13608, 410, 112, 3, 28, "Subsubsection"],
Cell[13723, 415, 181, 3, 43, "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{
Cell[13941, 423, 583, 10, 43, "Subsubsection"],
Cell[14527, 435, 519, 8, 123, "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{
Cell[15083, 448, 133, 3, 28, "Subsubsection"],
Cell[15219, 453, 261, 5, 75, "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{
Cell[15517, 463, 75, 0, 28, "Subsubsection"],
Cell[15595, 465, 554, 8, 139, "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{
Cell[16186, 478, 285, 4, 44, "Subsubsection"],
Cell[16474, 484, 772, 12, 187, "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{
Cell[17283, 501, 116, 3, 28, "Subsubsection"],
Cell[17402, 506, 179, 3, 43, "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{
Cell[17618, 514, 74, 0, 28, "Subsubsection"],
Cell[17695, 516, 150, 3, 43, "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{
Cell[17882, 524, 178, 4, 28, "Subsubsection"],
Cell[18063, 530, 217, 5, 43, "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{
Cell[18317, 540, 103, 3, 28, "Subsubsection"],
Cell[18423, 545, 163, 3, 43, "Input",
  InitializationCell->True]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[18635, 554, 39, 0, 30, "Subsection"],

Cell[CellGroupData[{
Cell[18699, 558, 207, 4, 58, "Subsubsection"],
Cell[18909, 564, 275, 5, 59, "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{
Cell[19221, 574, 963, 17, 118, "Subsubsection"],
Cell[20187, 593, 820, 13, 235, "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{
Cell[21044, 611, 237, 5, 43, "Subsubsection"],
Cell[21284, 618, 260, 5, 75, "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{
Cell[21581, 628, 382, 7, 43, "Subsubsection"],
Cell[21966, 637, 369, 6, 107, "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{
Cell[22372, 648, 360, 7, 43, "Subsubsection"],
Cell[22735, 657, 493, 7, 107, "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{
Cell[23265, 669, 273, 6, 44, "Subsubsection",
  InitializationCell->True],
Cell[23541, 677, 255, 4, 44, "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{
Cell[23833, 686, 200, 5, 44, "Subsubsection",
  InitializationCell->True],
Cell[24036, 693, 244, 4, 59, "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{
Cell[24317, 702, 146, 4, 28, "Subsubsection",
  InitializationCell->True],
Cell[24466, 708, 183, 3, 43, "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{
Cell[24686, 716, 198, 5, 44, "Subsubsection",
  InitializationCell->True],
Cell[24887, 723, 238, 4, 75, "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{
Cell[25162, 732, 116, 2, 28, "Subsubsection",
  InitializationCell->True],
Cell[25281, 736, 348, 6, 107, "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{
Cell[25666, 747, 105, 1, 28, "Subsubsection",
  InitializationCell->True],
Cell[25774, 750, 183, 3, 43, "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{
Cell[25994, 758, 147, 4, 28, "Subsubsection",
  InitializationCell->True],
Cell[26144, 764, 175, 3, 43, "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{
Cell[26356, 772, 104, 1, 28, "Subsubsection",
  InitializationCell->True],
Cell[26463, 775, 139, 3, 27, "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{
Cell[26639, 783, 101, 1, 28, "Subsubsection",
  InitializationCell->True],
Cell[26743, 786, 148, 3, 27, "Input",
  InitializationCell->True]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[26940, 795, 40, 0, 30, "Subsection"],

Cell[CellGroupData[{
Cell[27005, 799, 41, 0, 42, "Subsubsection"],
Cell[27049, 801, 260, 5, 75, "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{
Cell[27346, 811, 101, 3, 28, "Subsubsection"],
Cell[27450, 816, 684, 10, 187, "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{
Cell[28171, 831, 257, 6, 28, "Subsubsection",
  InitializationCell->True],
Cell[28431, 839, 302, 5, 75, "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{
Cell[28770, 849, 82, 1, 28, "Subsubsection"],
Cell[28855, 852, 180, 3, 43, "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{
Cell[29072, 860, 148, 3, 28, "Subsubsection"],
Cell[29223, 865, 213, 4, 59, "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{
Cell[29473, 874, 163, 4, 28, "Subsubsection",
  InitializationCell->True],
Cell[29639, 880, 206, 4, 43, "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{
Cell[29882, 889, 726, 12, 58, "Subsubsection"],
Cell[30611, 903, 1315, 19, 187, "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{
Cell[31963, 927, 209, 3, 28, "Subsubsection"],
Cell[32175, 932, 269, 5, 59, "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{
Cell[32481, 942, 293, 5, 28, "Subsubsection"],
Cell[32777, 949, 316, 5, 75, "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{
Cell[33130, 959, 173, 3, 28, "Subsubsection"],
Cell[33306, 964, 247, 5, 59, "Input",
  InitializationCell->True]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[33602, 975, 42, 0, 30, "Subsection"],

Cell[CellGroupData[{
Cell[33669, 979, 211, 3, 58, "Subsubsection"],
Cell[33883, 984, 543, 8, 139, "Input",
  InitializationCell->True]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[34475, 998, 52, 0, 30, "Subsection"],

Cell[CellGroupData[{
Cell[34552, 1002, 399, 6, 74, "Subsubsection"],
Cell[34954, 1010, 515, 9, 139, "Input",
  InitializationCell->True]
}, Open  ]],

Cell[CellGroupData[{
Cell[35506, 1024, 385, 5, 74, "Subsubsection"],
Cell[35894, 1031, 659, 10, 123, "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{
Cell[36590, 1046, 174, 4, 44, "Subsubsection"],
Cell[36767, 1052, 299, 5, 75, "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{
Cell[37103, 1062, 119, 3, 28, "Subsubsection"],
Cell[37225, 1067, 190, 3, 43, "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{
Cell[37452, 1075, 236, 5, 44, "Subsubsection"],
Cell[37691, 1082, 312, 5, 75, "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{
Cell[38040, 1092, 244, 5, 44, "Subsubsection"],
Cell[38287, 1099, 311, 5, 75, "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{
Cell[38635, 1109, 330, 5, 60, "Subsubsection"],
Cell[38968, 1116, 384, 6, 91, "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{
Cell[39389, 1127, 104, 3, 28, "Subsubsection"],
Cell[39496, 1132, 369, 6, 91, "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{
Cell[39902, 1143, 110, 3, 28, "Subsubsection"],
Cell[40015, 1148, 373, 6, 107, "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{
Cell[40425, 1159, 668, 9, 92, "Subsubsection"],
Cell[41096, 1170, 730, 10, 171, "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{
Cell[41863, 1185, 334, 6, 60, "Subsubsection"],
Cell[42200, 1193, 567, 9, 155, "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{
Cell[42804, 1207, 388, 7, 43, "Subsubsection"],
Cell[43195, 1216, 526, 8, 123, "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{
Cell[43758, 1229, 341, 7, 43, "Subsubsection"],
Cell[44102, 1238, 326, 5, 75, "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{
Cell[44465, 1248, 833, 13, 103, "Subsubsection"],
Cell[45301, 1263, 823, 12, 171, "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{
Cell[46161, 1280, 354, 7, 28, "Subsubsection"],
Cell[46518, 1289, 172, 3, 43, "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{
Cell[46727, 1297, 329, 6, 43, "Subsubsection"],
Cell[47059, 1305, 314, 5, 59, "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{
Cell[47410, 1315, 185, 3, 44, "Subsubsection"],
Cell[47598, 1320, 245, 4, 59, "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{
Cell[47880, 1329, 206, 3, 44, "Subsubsection"],
Cell[48089, 1334, 279, 5, 75, "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{
Cell[48405, 1344, 37, 0, 28, "Subsubsection"],
Cell[48445, 1346, 513, 8, 123, "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{
Cell[48995, 1359, 33, 0, 28, "Subsubsection"],
Cell[49031, 1361, 241, 4, 75, "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{
Cell[49309, 1370, 63, 1, 28, "Subsubsection",
  InitializationCell->True],
Cell[49375, 1373, 341, 5, 91, "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{
Cell[49753, 1383, 43, 0, 28, "Subsubsection"],
Cell[49799, 1385, 517, 8, 139, "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{
Cell[50353, 1398, 41, 0, 28, "Subsubsection"],
Cell[50397, 1400, 463, 7, 123, "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{
Cell[50897, 1412, 36, 0, 28, "Subsubsection"],
Cell[50936, 1414, 383, 6, 91, "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{
Cell[51356, 1425, 39, 0, 28, "Subsubsection"],
Cell[51398, 1427, 430, 6, 123, "Input",
  InitializationCell->True]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[51877, 1439, 35, 0, 30, "Subsection"],

Cell[CellGroupData[{
Cell[51937, 1443, 69, 1, 42, "Subsubsection",
  InitializationCell->True],
Cell[52009, 1446, 540, 9, 91, "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{
Cell[52586, 1460, 74, 1, 28, "Subsubsection",
  InitializationCell->True],
Cell[52663, 1463, 285, 5, 59, "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{
Cell[52985, 1473, 76, 1, 28, "Subsubsection",
  InitializationCell->True],
Cell[53064, 1476, 177, 3, 27, "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{
Cell[53278, 1484, 65, 1, 28, "Subsubsection",
  InitializationCell->True],
Cell[53346, 1487, 182, 3, 27, "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{
Cell[53565, 1495, 69, 1, 28, "Subsubsection",
  InitializationCell->True],
Cell[53637, 1498, 462, 8, 75, "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{
Cell[54136, 1511, 72, 1, 28, "Subsubsection",
  InitializationCell->True],
Cell[54211, 1514, 271, 5, 59, "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{
Cell[54519, 1524, 69, 1, 28, "Subsubsection",
  InitializationCell->True],
Cell[54591, 1527, 396, 6, 75, "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{
Cell[55024, 1538, 62, 1, 28, "Subsubsection",
  InitializationCell->True],
Cell[55089, 1541, 293, 5, 59, "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{
Cell[55419, 1551, 62, 1, 28, "Subsubsection",
  InitializationCell->True],
Cell[55484, 1554, 218, 4, 27, "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{
Cell[55739, 1563, 68, 1, 28, "Subsubsection",
  InitializationCell->True],
Cell[55810, 1566, 290, 5, 59, "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{
Cell[56137, 1576, 72, 1, 28, "Subsubsection",
  InitializationCell->True],
Cell[56212, 1579, 232, 4, 43, "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{
Cell[56481, 1588, 71, 1, 28, "Subsubsection",
  InitializationCell->True],
Cell[56555, 1591, 236, 4, 43, "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{
Cell[56828, 1600, 65, 1, 28, "Subsubsection",
  InitializationCell->True],
Cell[56896, 1603, 209, 4, 27, "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{
Cell[57142, 1612, 67, 1, 28, "Subsubsection",
  InitializationCell->True],
Cell[57212, 1615, 364, 6, 59, "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{
Cell[57613, 1626, 77, 1, 28, "Subsubsection",
  InitializationCell->True],
Cell[57693, 1629, 392, 6, 75, "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{
Cell[58122, 1640, 79, 1, 28, "Subsubsection",
  InitializationCell->True],
Cell[58204, 1643, 393, 6, 75, "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{
Cell[58634, 1654, 66, 1, 28, "Subsubsection",
  InitializationCell->True],
Cell[58703, 1657, 208, 4, 27, "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{
Cell[58948, 1666, 62, 1, 28, "Subsubsection",
  InitializationCell->True],
Cell[59013, 1669, 340, 5, 75, "Input",
  InitializationCell->True],
Cell[59356, 1676, 74, 1, 24, "SubsubsectionIcon",
  InitializationCell->True],
Cell[59433, 1679, 316, 6, 60, "Input",
  InitializationCell->True],
Cell[59752, 1687, 41, 0, 24, "SubsubsectionIcon"],
Cell[59796, 1689, 183, 3, 27, "Input",
  InitializationCell->True],
Cell[59982, 1694, 76, 1, 24, "SubsubsectionIcon",
  InitializationCell->True],
Cell[60061, 1697, 327, 6, 60, "Input",
  InitializationCell->True],
Cell[60391, 1705, 80, 1, 24, "SubsubsectionIcon",
  InitializationCell->True],
Cell[60474, 1708, 378, 6, 60, "Input",
  InitializationCell->True],
Cell[60855, 1716, 67, 1, 24, "SubsubsectionIcon",
  InitializationCell->True],
Cell[60925, 1719, 200, 4, 27, "Input",
  InitializationCell->True],
Cell[61128, 1725, 67, 1, 24, "SubsubsectionIcon",
  InitializationCell->True],
Cell[61198, 1728, 201, 4, 27, "Input",
  InitializationCell->True],
Cell[61402, 1734, 74, 1, 24, "SubsubsectionIcon",
  InitializationCell->True],
Cell[61479, 1737, 219, 4, 43, "Input",
  InitializationCell->True],
Cell[61701, 1743, 68, 1, 24, "SubsubsectionIcon",
  InitializationCell->True],
Cell[61772, 1746, 214, 4, 43, "Input",
  InitializationCell->True],
Cell[61989, 1752, 71, 1, 24, "SubsubsectionIcon",
  InitializationCell->True],
Cell[62063, 1755, 149, 3, 27, "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{
Cell[62249, 1763, 65, 1, 28, "Subsubsection",
  InitializationCell->True],
Cell[62317, 1766, 176, 3, 27, "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{
Cell[62530, 1774, 65, 1, 28, "Subsubsection",
  InitializationCell->True],
Cell[62598, 1777, 143, 3, 27, "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{
Cell[62778, 1785, 43, 0, 28, "Subsubsection"],
Cell[62824, 1787, 343, 5, 75, "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{
Cell[63204, 1797, 75, 1, 28, "Subsubsection",
  InitializationCell->True],
Cell[63282, 1800, 288, 5, 59, "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{
Cell[63607, 1810, 73, 1, 28, "Subsubsection",
  InitializationCell->True],
Cell[63683, 1813, 224, 4, 43, "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{
Cell[63944, 1822, 37, 0, 28, "Subsubsection"],
Cell[63984, 1824, 141, 3, 27, "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{
Cell[64162, 1832, 33, 0, 28, "Subsubsection"],
Cell[64198, 1834, 281, 5, 59, "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{
Cell[64516, 1844, 37, 0, 28, "Subsubsection"],
Cell[64556, 1846, 544, 9, 91, "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{
Cell[65137, 1860, 40, 0, 28, "Subsubsection"],
Cell[65180, 1862, 226, 4, 59, "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{
Cell[65443, 1871, 37, 0, 28, "Subsubsection"],
Cell[65483, 1873, 214, 4, 43, "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{
Cell[65734, 1882, 38, 0, 28, "Subsubsection"],
Cell[65775, 1884, 218, 4, 59, "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{
Cell[66030, 1893, 44, 0, 28, "Subsubsection"],
Cell[66077, 1895, 211, 4, 27, "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{
Cell[66325, 1904, 31, 0, 28, "Subsubsection"],
Cell[66359, 1906, 264, 4, 43, "Input",
  InitializationCell->True]
}, Open  ]],

Cell[CellGroupData[{
Cell[66660, 1915, 32, 0, 42, "Subsubsection"],
Cell[66695, 1917, 208, 4, 43, "Input",
  InitializationCell->True]
}, Open  ]],

Cell[CellGroupData[{
Cell[66940, 1926, 61, 1, 42, "Subsubsection",
  InitializationCell->True],
Cell[67004, 1929, 208, 4, 43, "Input",
  InitializationCell->True]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{
Cell[67261, 1939, 44, 0, 30, "Subsection"],

Cell[CellGroupData[{
Cell[67330, 1943, 57, 1, 42, "Subsubsection",
  InitializationCell->True],
Cell[67390, 1946, 189, 3, 27, "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{
Cell[67616, 1954, 71, 1, 28, "Subsubsection",
  InitializationCell->True],
Cell[67690, 1957, 276, 5, 59, "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{
Cell[68003, 1967, 71, 1, 28, "Subsubsection",
  InitializationCell->True],
Cell[68077, 1970, 308, 5, 59, "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{
Cell[68422, 1980, 75, 1, 28, "Subsubsection",
  InitializationCell->True],
Cell[68500, 1983, 196, 3, 43, "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{
Cell[68733, 1991, 76, 1, 28, "Subsubsection",
  InitializationCell->True],
Cell[68812, 1994, 175, 3, 27, "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{
Cell[69024, 2002, 70, 1, 28, "Subsubsection",
  InitializationCell->True],
Cell[69097, 2005, 162, 3, 27, "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{
Cell[69296, 2013, 69, 1, 28, "Subsubsection",
  InitializationCell->True],
Cell[69368, 2016, 163, 3, 27, "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{
Cell[69568, 2024, 75, 1, 28, "Subsubsection",
  InitializationCell->True],
Cell[69646, 2027, 377, 6, 75, "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{
Cell[70060, 2038, 75, 1, 28, "Subsubsection",
  InitializationCell->True],
Cell[70138, 2041, 377, 6, 75, "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{
Cell[70552, 2052, 35, 0, 28, "Subsubsection"],
Cell[70590, 2054, 337, 5, 59, "Input",
  InitializationCell->True]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[70988, 2066, 32, 0, 50, "Section"],
Cell[71023, 2068, 111, 2, 27, "Input",
  InitializationCell->True],
Cell[71137, 2072, 101, 2, 27, "Input",
  InitializationCell->True],

Cell[CellGroupData[{
Cell[71263, 2078, 44, 0, 46, "Subsection"],

Cell[CellGroupData[{
Cell[71332, 2082, 179, 3, 58, "Subsubsection"],
Cell[71514, 2087, 181, 4, 27, "Input",
  InitializationCell->True],
Cell[71698, 2093, 1007, 19, 171, "Input",
  InitializationCell->True],
Cell[72708, 2114, 460, 8, 91, "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{
Cell[73205, 2127, 106, 3, 28, "Subsubsection"],
Cell[73314, 2132, 218, 5, 43, "Input",
  InitializationCell->True],
Cell[73535, 2139, 134, 3, 27, "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{
Cell[73706, 2147, 97, 3, 28, "Subsubsection"],
Cell[73806, 2152, 226, 5, 43, "Input",
  InitializationCell->True],
Cell[74035, 2159, 139, 3, 27, "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{
Cell[74211, 2167, 79, 0, 28, "Subsubsection"],
Cell[74293, 2169, 214, 5, 27, "Input",
  InitializationCell->True],
Cell[74510, 2176, 170, 4, 43, "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{
Cell[74717, 2185, 104, 3, 28, "Subsubsection"],
Cell[74824, 2190, 468, 9, 107, "Input",
  InitializationCell->True],
Cell[75295, 2201, 149, 3, 27, "Input",
  InitializationCell->True],
Cell[75447, 2206, 155, 3, 43, "Input",
  InitializationCell->True],
Cell[75605, 2211, 156, 3, 27, "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{
Cell[75798, 2219, 112, 3, 28, "Subsubsection"],
Cell[75913, 2224, 245, 5, 59, "Input",
  InitializationCell->True],
Cell[76161, 2231, 246, 5, 59, "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{
Cell[76444, 2241, 104, 3, 28, "Subsubsection"],
Cell[76551, 2246, 421, 8, 107, "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{
Cell[77009, 2259, 104, 3, 28, "Subsubsection"],
Cell[77116, 2264, 241, 5, 59, "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{
Cell[77394, 2274, 103, 3, 28, "Subsubsection"],
Cell[77500, 2279, 499, 9, 107, "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{
Cell[78036, 2293, 465, 10, 43, "Subsubsection"],
Cell[78504, 2305, 306, 6, 75, "Input",
  InitializationCell->True],
Cell[78813, 2313, 214, 4, 43, "Input",
  InitializationCell->True],
Cell[79030, 2319, 292, 6, 75, "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{
Cell[79359, 2330, 245, 5, 44, "Subsubsection"],
Cell[79607, 2337, 194, 4, 43, "Input",
  InitializationCell->True],
Cell[79804, 2343, 291, 6, 59, "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{
Cell[80132, 2354, 583, 10, 73, "Subsubsection"],
Cell[80718, 2366, 156, 3, 43, "Input",
  InitializationCell->True],
Cell[80877, 2371, 945, 18, 235, "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{
Cell[81859, 2394, 133, 3, 28, "Subsubsection"],
Cell[81995, 2399, 110, 2, 27, "Input",
  InitializationCell->True],

Cell[CellGroupData[{
Cell[82130, 2405, 662, 12, 123, "Input",
  InitializationCell->True],
Cell[82795, 2419, 185, 3, 70, "Message"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[83029, 2428, 75, 0, 28, "Subsubsection"],
Cell[83107, 2430, 265, 5, 75, "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{
Cell[83409, 2440, 282, 5, 44, "Subsubsection"],
Cell[83694, 2447, 118, 2, 27, "Input",
  InitializationCell->True],
Cell[83815, 2451, 960, 17, 299, "Input",
  InitializationCell->True],
Cell[84778, 2470, 201, 5, 43, "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{
Cell[85016, 2480, 120, 3, 28, "Subsubsection"],
Cell[85139, 2485, 174, 3, 43, "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{
Cell[85350, 2493, 74, 0, 28, "Subsubsection"],
Cell[85427, 2495, 638, 12, 75, "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{
Cell[86102, 2512, 178, 4, 28, "Subsubsection"],
Cell[86283, 2518, 598, 11, 75, "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{
Cell[86918, 2534, 103, 3, 28, "Subsubsection"],

Cell[CellGroupData[{
Cell[87046, 2541, 691, 12, 171, "Input",
  InitializationCell->True],
Cell[87740, 2555, 183, 3, 70, "Message"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[87972, 2564, 156, 3, 44, "Subsubsection"],
Cell[88131, 2569, 206, 4, 59, "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{
Cell[88374, 2578, 136, 3, 28, "Subsubsection"],
Cell[88513, 2583, 148, 3, 27, "Input",
  InitializationCell->True],
Cell[88664, 2588, 1081, 20, 155, "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{
Cell[89782, 2613, 333, 5, 60, "Subsubsection"],
Cell[90118, 2620, 381, 7, 59, "Input",
  InitializationCell->True],

Cell[CellGroupData[{
Cell[90524, 2631, 2449, 44, 427, "Input",
  InitializationCell->True],
Cell[92976, 2677, 181, 3, 70, "Message"]
}, Closed]]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[93218, 2687, 39, 0, 30, "Subsection"],

Cell[CellGroupData[{
Cell[93282, 2691, 207, 4, 58, "Subsubsection"],
Cell[93492, 2697, 692, 13, 123, "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{
Cell[94221, 2715, 963, 17, 118, "Subsubsection"],
Cell[95187, 2734, 202, 4, 43, "Input",
  InitializationCell->True],
Cell[95392, 2740, 1904, 31, 283, "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{
Cell[97333, 2776, 273, 6, 44, "Subsubsection",
  InitializationCell->True],
Cell[97609, 2784, 466, 9, 145, "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{
Cell[98112, 2798, 200, 5, 44, "Subsubsection",
  InitializationCell->True],
Cell[98315, 2805, 218, 5, 43, "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{
Cell[98570, 2815, 146, 4, 28, "Subsubsection",
  InitializationCell->True],
Cell[98719, 2821, 191, 3, 43, "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{
Cell[98947, 2829, 198, 5, 44, "Subsubsection",
  InitializationCell->True],
Cell[99148, 2836, 201, 4, 43, "Input",
  InitializationCell->True],
Cell[99352, 2842, 1285, 21, 284, "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{
Cell[100674, 2868, 116, 2, 28, "Subsubsection",
  InitializationCell->True],
Cell[100793, 2872, 663, 14, 123, "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{
Cell[101493, 2891, 105, 1, 28, "Subsubsection",
  InitializationCell->True],
Cell[101601, 2894, 455, 9, 113, "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{
Cell[102093, 2908, 147, 4, 28, "Subsubsection",
  InitializationCell->True],
Cell[102243, 2914, 233, 5, 59, "Input",
  InitializationCell->True],
Cell[102479, 2921, 453, 10, 91, "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{
Cell[102969, 2936, 104, 1, 28, "Subsubsection",
  InitializationCell->True],
Cell[103076, 2939, 724, 13, 123, "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{
Cell[103837, 2957, 101, 1, 28, "Subsubsection",
  InitializationCell->True],
Cell[103941, 2960, 279, 6, 43, "Input",
  InitializationCell->True]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[104269, 2972, 40, 0, 30, "Subsection"],

Cell[CellGroupData[{
Cell[104334, 2976, 101, 3, 42, "Subsubsection"],
Cell[104438, 2981, 298, 7, 98, "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{
Cell[104773, 2993, 263, 6, 44, "Subsubsection",
  InitializationCell->True],
Cell[105039, 3001, 164, 3, 43, "Input",
  InitializationCell->True],
Cell[105206, 3006, 145, 3, 27, "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{
Cell[105388, 3014, 83, 1, 28, "Subsubsection"],
Cell[105474, 3017, 111, 2, 27, "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{
Cell[105622, 3024, 148, 3, 28, "Subsubsection"],
Cell[105773, 3029, 156, 3, 43, "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{
Cell[105966, 3037, 163, 4, 28, "Subsubsection",
  InitializationCell->True],
Cell[106132, 3043, 645, 14, 75, "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{
Cell[106814, 3062, 732, 12, 88, "Subsubsection"],
Cell[107549, 3076, 200, 4, 43, "Input",
  InitializationCell->True],
Cell[107752, 3082, 1707, 31, 347, "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{
Cell[109496, 3118, 308, 6, 43, "Subsubsection"],
Cell[109807, 3126, 528, 10, 139, "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{
Cell[110372, 3141, 173, 3, 44, "Subsubsection"],
Cell[110548, 3146, 442, 8, 91, "Input",
  InitializationCell->True]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[111039, 3160, 42, 0, 30, "Subsection"],

Cell[CellGroupData[{
Cell[111106, 3164, 211, 3, 58, "Subsubsection"],
Cell[111320, 3169, 279, 6, 59, "Input",
  InitializationCell->True],
Cell[111602, 3177, 281, 6, 78, "Input",
  InitializationCell->True],
Cell[111886, 3185, 1116, 20, 218, "Input",
  InitializationCell->True],
Cell[113005, 3207, 1689, 28, 236, "Input",
  InitializationCell->True]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[114743, 3241, 52, 0, 30, "Subsection"],

Cell[CellGroupData[{
Cell[114820, 3245, 174, 4, 42, "Subsubsection"],
Cell[114997, 3251, 192, 4, 43, "Input",
  InitializationCell->True],
Cell[115192, 3257, 221, 4, 43, "Input",
  InitializationCell->True],
Cell[115416, 3263, 1203, 23, 155, "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{
Cell[116656, 3291, 119, 3, 28, "Subsubsection"],
Cell[116778, 3296, 184, 4, 43, "Input",
  InitializationCell->True],
Cell[116965, 3302, 193, 3, 43, "Input",
  InitializationCell->True],
Cell[117161, 3307, 1098, 22, 155, "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{
Cell[118296, 3334, 236, 5, 28, "Subsubsection"],
Cell[118535, 3341, 373, 7, 75, "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{
Cell[118945, 3353, 395, 7, 44, "Subsubsection"],
Cell[119343, 3362, 92, 2, 27, "Input",
  InitializationCell->True],
Cell[119438, 3366, 985, 20, 139, "Input",
  InitializationCell->True],
Cell[120426, 3388, 90, 2, 27, "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{
Cell[120553, 3395, 385, 5, 44, "Subsubsection"],
Cell[120941, 3402, 398, 7, 75, "Input",
  InitializationCell->True],

Cell[CellGroupData[{
Cell[121364, 3413, 1100, 20, 282, "Input",
  InitializationCell->True],
Cell[122467, 3435, 186, 3, 70, "Message"],
Cell[122656, 3440, 197, 3, 70, "Message"]
}, Closed]],
Cell[122868, 3446, 405, 8, 75, "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{
Cell[123310, 3459, 244, 5, 44, "Subsubsection"],
Cell[123557, 3466, 183, 4, 27, "Input",
  InitializationCell->True],
Cell[123743, 3472, 454, 8, 155, "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{
Cell[124234, 3485, 330, 5, 44, "Subsubsection"],
Cell[124567, 3492, 175, 4, 27, "Input",
  InitializationCell->True],
Cell[124745, 3498, 344, 8, 59, "Input",
  InitializationCell->True],
Cell[125092, 3508, 356, 7, 75, "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{
Cell[125485, 3520, 104, 3, 28, "Subsubsection"],
Cell[125592, 3525, 164, 4, 27, "Input",
  InitializationCell->True],
Cell[125759, 3531, 884, 18, 123, "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{
Cell[126680, 3554, 112, 3, 28, "Subsubsection"],
Cell[126795, 3559, 166, 4, 27, "Input",
  InitializationCell->True],
Cell[126964, 3565, 703, 13, 155, "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{
Cell[127704, 3583, 668, 9, 60, "Subsubsection"],
Cell[128375, 3594, 182, 4, 27, "Input",
  InitializationCell->True],
Cell[128560, 3600, 736, 14, 145, "Input",
  InitializationCell->True],
Cell[129299, 3616, 1306, 22, 245, "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{
Cell[130642, 3643, 322, 6, 44, "Subsubsection"],
Cell[130967, 3651, 183, 4, 27, "Input",
  InitializationCell->True],
Cell[131153, 3657, 399, 8, 91, "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{
Cell[131589, 3670, 379, 6, 28, "Subsubsection"],
Cell[131971, 3678, 119, 2, 27, "Input",
  InitializationCell->True],
Cell[132093, 3682, 528, 10, 107, "Input",
  InitializationCell->True],
Cell[132624, 3694, 1412, 24, 235, "Input",
  InitializationCell->True],
Cell[134039, 3720, 160, 3, 43, "Input",
  InitializationCell->True],
Cell[134202, 3725, 240, 4, 59, "Input",
  InitializationCell->True],
Cell[134445, 3731, 4576, 83, 571, "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{
Cell[139058, 3819, 833, 13, 58, "Subsubsection"],
Cell[139894, 3834, 2673, 45, 459, "Input",
  InitializationCell->True],
Cell[142570, 3881, 420, 10, 110, "Text"]
}, Closed]],

Cell[CellGroupData[{
Cell[143027, 3896, 341, 7, 28, "Subsubsection"],
Cell[143371, 3905, 135, 3, 27, "Input",
  InitializationCell->True],
Cell[143509, 3910, 511, 9, 91, "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{
Cell[144057, 3924, 329, 6, 28, "Subsubsection"],
Cell[144389, 3932, 135, 3, 27, "Input",
  InitializationCell->True],
Cell[144527, 3937, 479, 9, 91, "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{
Cell[145043, 3951, 185, 3, 28, "Subsubsection"],
Cell[145231, 3956, 134, 3, 27, "Input",
  InitializationCell->True],
Cell[145368, 3961, 447, 8, 98, "Input",
  InitializationCell->True],
Cell[145818, 3971, 2017, 37, 420, "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{
Cell[147872, 4013, 206, 3, 28, "Subsubsection"],
Cell[148081, 4018, 2368, 40, 415, "Input",
  InitializationCell->True],
Cell[150452, 4060, 171, 3, 27, "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{
Cell[150660, 4068, 65, 1, 28, "Subsubsection",
  InitializationCell->True],
Cell[150728, 4071, 182, 3, 59, "Input",
  InitializationCell->True],
Cell[150913, 4076, 116, 2, 27, "Input",
  InitializationCell->True],
Cell[151032, 4080, 1024, 17, 203, "Input",
  InitializationCell->True],
Cell[152059, 4099, 1077, 25, 139, "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{
Cell[153173, 4129, 63, 1, 28, "Subsubsection",
  InitializationCell->True],
Cell[153239, 4132, 194, 4, 27, "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{
Cell[153470, 4141, 43, 0, 28, "Subsubsection"],
Cell[153516, 4143, 162, 3, 43, "Input",
  InitializationCell->True],
Cell[153681, 4148, 698, 13, 139, "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{
Cell[154416, 4166, 41, 0, 28, "Subsubsection"],
Cell[154460, 4168, 2356, 39, 443, "Input",
  InitializationCell->True],
Cell[156819, 4209, 288, 7, 43, "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{
Cell[157144, 4221, 36, 0, 28, "Subsubsection"],
Cell[157183, 4223, 165, 3, 43, "Input",
  InitializationCell->True],
Cell[157351, 4228, 595, 11, 107, "Input",
  InitializationCell->True],
Cell[157949, 4241, 500, 9, 91, "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{
Cell[158486, 4255, 39, 0, 28, "Subsubsection"],
Cell[158528, 4257, 116, 2, 27, "Input",
  InitializationCell->True],
Cell[158647, 4261, 119, 2, 27, "Input",
  InitializationCell->True],
Cell[158769, 4265, 942, 17, 171, "Input",
  InitializationCell->True]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[159760, 4288, 35, 0, 30, "Subsection"],

Cell[CellGroupData[{
Cell[159820, 4292, 74, 1, 42, "Subsubsection",
  InitializationCell->True],
Cell[159897, 4295, 122, 3, 27, "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{
Cell[160056, 4303, 76, 1, 28, "Subsubsection",
  InitializationCell->True],
Cell[160135, 4306, 153, 3, 43, "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{
Cell[160325, 4314, 62, 1, 28, "Subsubsection",
  InitializationCell->True],
Cell[160390, 4317, 274, 5, 43, "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{
Cell[160701, 4327, 62, 1, 28, "Subsubsection",
  InitializationCell->True],
Cell[160766, 4330, 141, 3, 27, "Input",
  InitializationCell->True],
Cell[160910, 4335, 514, 10, 107, "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{
Cell[161461, 4350, 66, 1, 28, "Subsubsection",
  InitializationCell->True],
Cell[161530, 4353, 269, 6, 75, "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{
Cell[161836, 4364, 62, 1, 28, "Subsubsection",
  InitializationCell->True],
Cell[161901, 4367, 182, 3, 59, "Input",
  InitializationCell->True],
Cell[162086, 4372, 164, 3, 43, "Input",
  InitializationCell->True],
Cell[162253, 4377, 2642, 45, 331, "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{
Cell[164932, 4427, 70, 1, 28, "Subsubsection",
  InitializationCell->True],
Cell[165005, 4430, 163, 3, 43, "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{
Cell[165205, 4438, 72, 1, 28, "Subsubsection",
  InitializationCell->True],
Cell[165280, 4441, 207, 4, 43, "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{
Cell[165524, 4450, 76, 1, 28, "Subsubsection",
  InitializationCell->True],
Cell[165603, 4453, 228, 5, 59, "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{
Cell[165868, 4463, 63, 1, 28, "Subsubsection",
  InitializationCell->True],
Cell[165934, 4466, 175, 3, 43, "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{
Cell[166146, 4474, 63, 1, 28, "Subsubsection",
  InitializationCell->True],
Cell[166212, 4477, 175, 3, 43, "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{
Cell[166424, 4485, 59, 1, 28, "Subsubsection",
  InitializationCell->True],
Cell[166486, 4488, 148, 3, 27, "Input",
  InitializationCell->True],
Cell[166637, 4493, 482, 9, 91, "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{
Cell[167156, 4507, 68, 1, 28, "Subsubsection",
  InitializationCell->True],
Cell[167227, 4510, 468, 8, 75, "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{
Cell[167732, 4523, 72, 1, 28, "Subsubsection",
  InitializationCell->True],
Cell[167807, 4526, 175, 3, 43, "Input",
  InitializationCell->True],
Cell[167985, 4531, 517, 9, 91, "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{
Cell[168539, 4545, 71, 1, 28, "Subsubsection",
  InitializationCell->True],
Cell[168613, 4548, 173, 3, 43, "Input",
  InitializationCell->True],
Cell[168789, 4553, 513, 9, 91, "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{
Cell[169339, 4567, 65, 1, 28, "Subsubsection",
  InitializationCell->True],
Cell[169407, 4570, 161, 3, 43, "Input",
  InitializationCell->True],
Cell[169571, 4575, 464, 8, 91, "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{
Cell[170072, 4588, 37, 0, 28, "Subsubsection"],
Cell[170112, 4590, 240, 5, 59, "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{
Cell[170389, 4600, 70, 1, 28, "Subsubsection",
  InitializationCell->True],
Cell[170462, 4603, 208, 4, 27, "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{
Cell[170707, 4612, 44, 0, 28, "Subsubsection"],
Cell[170754, 4614, 532, 11, 91, "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{
Cell[171323, 4630, 65, 1, 28, "Subsubsection",
  InitializationCell->True],
Cell[171391, 4633, 177, 4, 27, "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{
Cell[171605, 4642, 71, 1, 28, "Subsubsection",
  InitializationCell->True],
Cell[171679, 4645, 154, 3, 43, "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{
Cell[171870, 4653, 67, 1, 28, "Subsubsection",
  InitializationCell->True],
Cell[171940, 4656, 146, 3, 43, "Input",
  InitializationCell->True],
Cell[172089, 4661, 159, 3, 43, "Input",
  InitializationCell->True],
Cell[172251, 4666, 161, 3, 43, "Input",
  InitializationCell->True],
Cell[172415, 4671, 607, 12, 123, "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{
Cell[173059, 4688, 77, 1, 28, "Subsubsection",
  InitializationCell->True],
Cell[173139, 4691, 274, 5, 75, "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{
Cell[173450, 4701, 79, 1, 28, "Subsubsection",
  InitializationCell->True],
Cell[173532, 4704, 276, 5, 75, "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{
Cell[173845, 4714, 69, 1, 28, "Subsubsection",
  InitializationCell->True],
Cell[173917, 4717, 192, 3, 59, "Input",
  InitializationCell->True],
Cell[174112, 4722, 1054, 18, 155, "Input",
  InitializationCell->True],
Cell[175169, 4742, 1104, 20, 203, "Input",
  InitializationCell->True],
Cell[176276, 4764, 294, 6, 79, "Input",
  InitializationCell->True],

Cell[CellGroupData[{
Cell[176595, 4774, 49, 1, 27, "Input"],
Cell[176647, 4777, 37, 1, 26, "Output"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[176733, 4784, 64, 1, 28, "Subsubsection",
  InitializationCell->True],
Cell[176800, 4787, 154, 4, 27, "Input",
  InitializationCell->True],
Cell[176957, 4793, 138, 3, 27, "Input",
  InitializationCell->True],
Cell[177098, 4798, 2095, 35, 411, "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{
Cell[179230, 4838, 67, 1, 28, "Subsubsection",
  InitializationCell->True],
Cell[179300, 4841, 410, 9, 75, "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{
Cell[179747, 4855, 62, 1, 28, "Subsubsection",
  InitializationCell->True],
Cell[179812, 4858, 155, 3, 27, "Input",
  InitializationCell->True],
Cell[179970, 4863, 136, 3, 27, "Input",
  InitializationCell->True],
Cell[180109, 4868, 1997, 33, 411, "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{
Cell[182143, 4906, 47, 0, 28, "Subsubsection"],

Cell[CellGroupData[{
Cell[182215, 4910, 336, 6, 75, "Input"],
Cell[182554, 4918, 10692, 164, 1571, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[193283, 5087, 219, 3, 56, "Input"],
Cell[193505, 5092, 39, 1, 20, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[193581, 5098, 221, 3, 72, "Input"],
Cell[193805, 5103, 38, 1, 20, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[193880, 5109, 78, 1, 24, "Input"],
Cell[193961, 5112, 36, 1, 20, "Print"],
Cell[194000, 5115, 36, 1, 20, "Print"],
Cell[194039, 5118, 39, 1, 20, "Print"],
Cell[194081, 5121, 36, 1, 20, "Print"],
Cell[194120, 5124, 40, 1, 20, "Print"],
Cell[194163, 5127, 45, 1, 20, "Print"],
Cell[194211, 5130, 49, 1, 20, "Print"],
Cell[194263, 5133, 41, 1, 20, "Print"],
Cell[194307, 5136, 49, 1, 20, "Print"],
Cell[194359, 5139, 49, 1, 20, "Print"],
Cell[194411, 5142, 53, 1, 20, "Print"],
Cell[194467, 5145, 57, 1, 20, "Print"],
Cell[194527, 5148, 73, 1, 20, "Print"],
Cell[194603, 5151, 65, 1, 20, "Print"],
Cell[194671, 5154, 65, 1, 20, "Print"],
Cell[194739, 5157, 69, 1, 20, "Print"],
Cell[194811, 5160, 69, 1, 20, "Print"],
Cell[194883, 5163, 65, 1, 20, "Print"],
Cell[194951, 5166, 61, 1, 20, "Print"],
Cell[195015, 5169, 65, 1, 20, "Print"],
Cell[195083, 5172, 61, 1, 20, "Print"],
Cell[195147, 5175, 61, 1, 20, "Print"],
Cell[195211, 5178, 65, 1, 20, "Print"],
Cell[195279, 5181, 61, 1, 20, "Print"],
Cell[195343, 5184, 57, 1, 20, "Print"],
Cell[195403, 5187, 57, 1, 20, "Print"],
Cell[195463, 5190, 53, 1, 20, "Print"],
Cell[195519, 5193, 49, 1, 20, "Print"],
Cell[195571, 5196, 45, 1, 20, "Print"],
Cell[195619, 5199, 45, 1, 20, "Print"],
Cell[195667, 5202, 36, 1, 20, "Output"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[195752, 5209, 65, 1, 28, "Subsubsection",
  InitializationCell->True],
Cell[195820, 5212, 395, 8, 75, "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{
Cell[196252, 5225, 69, 1, 28, "Subsubsection",
  InitializationCell->True],
Cell[196324, 5228, 160, 4, 27, "Input",
  InitializationCell->True],
Cell[196487, 5234, 185, 3, 27, "Input",
  InitializationCell->True],
Cell[196675, 5239, 1941, 35, 251, "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{
Cell[198653, 5279, 69, 1, 28, "Subsubsection",
  InitializationCell->True],
Cell[198725, 5282, 170, 4, 27, "Input",
  InitializationCell->True],

Cell[CellGroupData[{
Cell[198920, 5290, 1913, 35, 187, "Input",
  InitializationCell->True],
Cell[200836, 5327, 179, 3, 35, "Message"],
Cell[201018, 5332, 180, 3, 35, "Message"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[201247, 5341, 75, 1, 28, "Subsubsection",
  InitializationCell->True],
Cell[201325, 5344, 158, 4, 27, "Input",
  InitializationCell->True],
Cell[201486, 5350, 789, 14, 91, "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{
Cell[202312, 5369, 73, 1, 28, "Subsubsection",
  InitializationCell->True],
Cell[202388, 5372, 446, 9, 107, "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{
Cell[202871, 5386, 75, 1, 28, "Subsubsection",
  InitializationCell->True],
Cell[202949, 5389, 463, 8, 129, "Input",
  InitializationCell->True],
Cell[203415, 5399, 395, 7, 59, "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{
Cell[203847, 5411, 68, 1, 28, "Subsubsection",
  InitializationCell->True],
Cell[203918, 5414, 241, 5, 27, "Input",
  InitializationCell->True],
Cell[204162, 5421, 309, 5, 43, "Input",
  InitializationCell->True],
Cell[204474, 5428, 2926, 49, 507, "Input",
  InitializationCell->True],
Cell[207403, 5479, 1997, 32, 299, "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{
Cell[209437, 5516, 33, 0, 28, "Subsubsection"],
Cell[209473, 5518, 991, 17, 155, "Input",
  InitializationCell->True],
Cell[210467, 5537, 147, 3, 27, "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{
Cell[210651, 5545, 37, 0, 28, "Subsubsection"],
Cell[210691, 5547, 206, 4, 27, "Input",
  InitializationCell->True],
Cell[210900, 5553, 687, 11, 123, "Input",
  InitializationCell->True],
Cell[211590, 5566, 1183, 21, 202, "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{
Cell[212810, 5592, 31, 0, 28, "Subsubsection"],
Cell[212844, 5594, 367, 7, 43, "Input",
  InitializationCell->True]
}, Closed]]
}, Open  ]],

Cell[CellGroupData[{
Cell[213260, 5607, 44, 0, 46, "Subsection"],

Cell[CellGroupData[{
Cell[213329, 5611, 57, 1, 42, "Subsubsection",
  InitializationCell->True],
Cell[213389, 5614, 394, 7, 75, "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{
Cell[213820, 5626, 71, 1, 28, "Subsubsection",
  InitializationCell->True],
Cell[213894, 5629, 418, 9, 59, "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{
Cell[214349, 5643, 71, 1, 28, "Subsubsection",
  InitializationCell->True],
Cell[214423, 5646, 586, 11, 75, "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{
Cell[215046, 5662, 75, 1, 28, "Subsubsection",
  InitializationCell->True],
Cell[215124, 5665, 136, 3, 27, "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{
Cell[215297, 5673, 76, 1, 28, "Subsubsection",
  InitializationCell->True],
Cell[215376, 5676, 147, 3, 27, "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{
Cell[215560, 5684, 70, 1, 28, "Subsubsection",
  InitializationCell->True],
Cell[215633, 5687, 202, 4, 43, "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{
Cell[215872, 5696, 69, 1, 28, "Subsubsection",
  InitializationCell->True],
Cell[215944, 5699, 135, 3, 27, "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{
Cell[216116, 5707, 75, 1, 28, "Subsubsection",
  InitializationCell->True],
Cell[216194, 5710, 571, 10, 113, "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{
Cell[216802, 5725, 75, 1, 28, "Subsubsection",
  InitializationCell->True],
Cell[216880, 5728, 571, 10, 113, "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{
Cell[217488, 5743, 43, 0, 28, "Subsubsection"],
Cell[217534, 5745, 196, 4, 27, "Input",
  InitializationCell->True]
}, Open  ]],

Cell[CellGroupData[{
Cell[217767, 5754, 35, 0, 42, "Subsubsection"],
Cell[217805, 5756, 389, 7, 59, "Input",
  InitializationCell->True]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[218243, 5769, 28, 0, 46, "Subsection"],
Cell[218274, 5771, 107, 3, 43, "Input",
  InitializationCell->True]
}, Closed]]
}, Open  ]]
}
]
*)



(*******************************************************************
End of Mathematica Notebook file.
*******************************************************************)

