(***********************************************************************

                    Mathematica-Compatible Notebook

This notebook can be used on any computer system with Mathematica 4.0,
MathReader 4.0, or any compatible application. The data for the notebook 
starts with the line containing stars above.

To get the notebook into a Mathematica-compatible application, do one of 
the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing the 
word CacheID, otherwise Mathematica-compatible applications may try to 
use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
***********************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[     56218,       1549]*)
(*NotebookOutlinePosition[     57129,       1578]*)
(*  CellTagsIndexPosition[     57085,       1574]*)
(*WindowFrame->Normal*)



Notebook[{
Cell[BoxData[
    \(BeginPackage["\<Multilocus`DataManipulation`\>", \n\t\
{"\<Utilities`SetManipulation`\>", \n\t\t\t\
"\<Statistics`DescriptiveStatistics`\>", \
"\<Statistics`MultiDescriptiveStatistics`\>"}]\)], "Input",
  InitializationCell->True,
  AspectRatioFixed->False],

Cell["\<\
I have removed the dependence on Multilocus`Multilocus` - that \
package should not be needed, but perhaps there is some unexpected \
dependence.\
\>", "Text"],

Cell[CellGroupData[{

Cell["Public parts", "Section"],

Cell[CellGroupData[{

Cell[TextData[
"HaploidTypes[{{a1,b1,..},{a2,b2,..}..}] lists all possible haploid \
genotypes, based on the set of alleles {a1,b1,..} at locus 1, etc.  \
HaploidTypes[{{a,b,..},n}] lists all possible genotypes, assuming the same \
set of alleles at n loci.  HaploidTypes[n] assumes n loci, with two alleles \
labelled {0,1}. HaploidTypes[n,SortByClass\[Rule]True] lists haplotypes \
ordered by the # of '1' alleles."], "Subsubsection"],

Cell[BoxData[
    \(\(HaploidTypes::usage = "\<HaploidTypes[{{a1,b1,..},{a2,b2,..}..}] \
lists all possible haploid genotypes, based on the set of alleles {a1,b1,..} \
at locus 1, etc.  HaploidTypes[{{a,b,..},n}] lists all possible genotypes, \
assuming the same set of alleles at n loci.  HaploidTypes[n] assumes n loci, \
with two alleles labelled {0,1}. HaploidTypes[n,SortByClass\[Rule]True] lists \
haplotypes ordered by the # of '1' alleles.\>";\)\)], "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{

Cell["\<\
SortByClass is an option for HaploidTypes[] and Diploid Types[] \
which determines the order of the genotypes.\
\>", "Subsubsection"],

Cell[BoxData[
    \(\(SortByClass::usage = 
      "\<SortByClass is an option for HaploidTypes[] and Diploid Types[] \
which determines the order of the genotypes.\>"; \)\)], "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{

Cell["\<\
DiploidTypes[{{a1,b1,..},{a2,b2,..}..}] lists all possible diploid \
genotypes, based on the set of alleles {a1,b1,..} at locus 1, etc.  \
DiploidTypes[{a,b,..},n] lists all possible genotypes, assuming the same set \
of alleles at n loci.  DiploidTypes[n] assumes n loci, with two alleles \
labelled {0,1}.  DiploidTypes[n,SortByClass\[Rule]True] lists  diploid \
genotypes ordered by the # of '1' alleles.\
\>", "Subsubsection"],

Cell[BoxData[
    \(\(DiploidTypes::usage = 
      "\<DiploidTypes[{{a1,b1,..},{a2,b2,..}..}] lists all possible diploid \
genotypes, based on the set of alleles {a1,b1,..} at locus 1, etc.  \
DiploidTypes[{a,b,..},n] lists all possible genotypes, assuming the same set \
of alleles at n loci.  DiploidTypes[n] assumes n loci, with two alleles \
labelled {0,1}.  DiploidTypes[n,SortByClass\[Rule]True] lists  diploid \
genotypes ordered by the # of '1' alleles.\>"; \)\)], "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{

Cell["\<\
DiploidSubsets[S] gives all the diploid subsets based on loci \
listed in S\
\>", "Subsubsection",
  InitializationCell->True],

Cell[BoxData[
    \(\(DiploidSubsets::usage = 
      "\<DiploidSubsets[S] gives all the diploid subsets based on loci listed \
in S. Stores results.\>"; \)\)], "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{

Cell["\<\
HaploidSubsets[S] gives all the haploid subsets based on loci \
listed in S. Stores results\
\>", "Subsubsection",
  InitializationCell->True],

Cell[BoxData[
    \(\(HaploidSubsets::usage = 
      "\<HaploidSubsets[S] gives all the haploid subsets based on loci listed \
in S. Stores results.\>"; \)\)], "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{

Cell["\<\
PossibleGenotypes[{{a,A},{b,B},{c,c}}] lists all the diploid \
genotypes compatible with the observed genotype, {{{a,b,c},{A,B,c}},\
\[Ellipsis]}. The default is to list both {{a,b,c},{A,B,c}} and \
{{A,B,c},{a,b,c}}; ListEquivalentGenotypes->True only lists one of these two \
complementary genotypes\
\>", "Subsubsection"],

Cell[BoxData[
    \(\(\(PossibleGenotypes::usage = \
"\<PossibleGenotypes[{{a,A},{b,B},{c,c}}] lists all the diploid genotypes \
compatible with the observed genotype, {{{a,b,c},{A,B,c}},\[Ellipsis]}. The \
default is to list both {{a,b,c},{A,B,c}} and {{A,B,c},{a,b,c}}; \
ListEquivalentGenotypes->True only lists one of these two complementary \
genotypes\>";\)\(\ \)\)\)], "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{

Cell["\<\
ListEquivalentGenotypes is an option for PossibleGenotypes[g]; if \
true, lists both equivalent genotypes (h1,h2} and {h2,h1}\
\>", \
"Subsubsection"],

Cell[BoxData[
    \(\(ListEquivalentGenotypes::usage = "\<ListEquivalentGenotypes is an \
option for PossibleGenotypes[g]; if true, lists both equivalent genotypes \
(h1,h2} and {h2,h1}.\>";\)\)], "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{

Cell["\<\
ObservableGenotype[{{a,b,\[Ellipsis]},{A,B,\[Ellipsis]}}] gives the \
diploid genotype that would be observed if cis and trans could not be \
distinguished.\
\>", "Subsubsection"],

Cell[BoxData[
    RowBox[{
      RowBox[{\(ObservableGenotype::usage\), "=", 
        "\"\<ObservableGenotype[{{a,b,\[Ellipsis]},{A,B,\[Ellipsis]}}] gives \
the diploid genotype that would be observed if \!\(\*
StyleBox[\\\"cis\\\",\\nFontSlant->\\\"Italic\\\"]\)\!\(\*
StyleBox[\\\" \\\",\\nFontSlant->\\\"Plain\\\"]\)\!\(\*
StyleBox[\\\"and\\\",\\nFontSlant->\\\"Plain\\\"]\)\!\(\*
StyleBox[\\\" \\\",\\nFontSlant->\\\"Plain\\\"]\)\!\(\*
StyleBox[\\\"trans\\\",\\nFontSlant->\\\"Italic\\\"]\)\!\(\*
StyleBox[\\\" \\\",\\nFontSlant->\\\"Plain\\\"]\)\!\(\*
StyleBox[\\\"could\\\",\\nFontSlant->\\\"Plain\\\"]\)\!\(\*
StyleBox[\\\" \\\",\\nFontSlant->\\\"Plain\\\"]\)\!\(\*
StyleBox[\\\"not\\\",\\nFontSlant->\\\"Plain\\\"]\)\!\(\*
StyleBox[\\\" \\\",\\nFontSlant->\\\"Plain\\\"]\)\!\(\*
StyleBox[\\\"be\\\",\\nFontSlant->\\\"Plain\\\"]\)\!\(\*
StyleBox[\\\" \\\",\\nFontSlant->\\\"Plain\\\"]\)\!\(\*
StyleBox[\\\"distinguished\\\",\\nFontSlant->\\\"Plain\\\"]\)\!\(\*
StyleBox[\\\".\\\",\\nFontSlant->\\\"Plain\\\"]\)\>\""}], ";"}]], "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{

Cell["\<\
Data[site] is a structure which denotes an array containing data on \
site;by default, it is a list of diploid genotypes written in the form \
{{0,0},{0,1},{1,1},..}\
\>", "Subsubsection"],

Cell[BoxData[
    \(\(Data::usage = 
      "\<Data[site] is a structure which denotes an array containing data on \
site; by default, it is a list of diploid genotypes written in the form \
{{0,0},{0,1},{1,1},..}\>"; \)\)], "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData["\[EmptySet] denotes missing data"], "Subsubsection"],

Cell[BoxData[
    \(\(\[EmptySet]::usage = "\<\[EmptySet] denotes missing data\>"; \)\)], 
  "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{

Cell["\<\
ConvertData[{{0,1,-1,2},\[Ellipsis]}}] converts data on biallelic \
loci into the more general form, \
{{{0,0},{0,1},\[EmptySet],{1,1}},\[Ellipsis]}.  ConvertData[{{0,1,-1,2},\
\[Ellipsis]}},{1,2,2,2,\[Ellipsis]}] allows for different ploidy across loci; \
gives  {{{0},{0,1},\[EmptySet],{1,1}},\[Ellipsis]}.\
\>", "Subsubsection"],

Cell[BoxData[
    \(\(ConvertData::usage = "\<ConvertData[{{0,1,-1,2},\[Ellipsis]}}] \
converts data on biallelic loci into the more general form, {{{0,0},{0,1},\
\[EmptySet],{1,1}},\[Ellipsis]}.  \
ConvertData[{{0,1,-1,2},\[Ellipsis]}},{1,2,2,2,\[Ellipsis]}] allows for \
different ploidy across loci; gives  {{{0},{0,1},\[EmptySet],{1,1}},\
\[Ellipsis]}.\>";\)\)], "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{

Cell["\<\
NumberOfIndividuals[site] gives the number of individuals in the \
site\
\>", "Subsubsection"],

Cell[BoxData[
    \(\(NumberOfIndividuals::"\<usage\>" = "\<NumberOfIndividuals[site] gives \
the number of individualsin site.\>";\)\)], "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{

Cell["NumberOfLoci[site] gives the number of loci", "Subsubsection"],

Cell[BoxData[
    \(\(NumberOfLoci::"\<usage\>" = "\<NumberOfLoci[site] gives the number of \
loci.\>";\)\)], "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{

Cell["\<\
NumberOfGenes[site] gives the number of genes sampled from the \
site, allowing for variation in ploidy\
\>", "Subsubsection"],

Cell[BoxData[
    \(\(NumberOfGenes::usage = "\<NumberOfGenes[site] gives the number of \
genes sampled from the site, allowing for variation in ploidy\>";\)\)], \
"Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{

Cell["\<\
Ploidy[site] gives the ploidy of the various loci in the site\
\>", \
"Subsubsection",
  InitializationCell->True],

Cell[BoxData[
    \(Ploidy::usage = "\<Ploidy[site] gives the ploidy of the various loci in \
the site\>"\)], "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{

Cell["LocusNames[site] gives the names of the loci at the site", 
  "Subsubsection",
  InitializationCell->True],

Cell[BoxData[
    \(\(LocusNames::usage = 
      "\<LocusNames[site] gives the names of the loci at the site\>"; \)\)], 
  "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{

Cell["\<\
SelectLoci[newsite,oldsite,loci] names a new dataset which is \
derived as a subset of the old one. Loci can be specified by number ({5,1,3}, \
say) or by name ({\"mtDNA\",\"Adh\"), say), provided that LocusNames[oldsite] \
is defined. SelectLoci[data,{5,1,3}] forms a new dataset which contains the \
chosen loci, specified by number.\
\>", "Subsubsection"],

Cell[BoxData[
    \(\(SelectLoci::usage = "\<SelectLoci[newsite,oldsite,loci] names a new \
dataset which is derived as a subset of the old one. Loci can be specified by \
number ({5,1,3}, say) or by name ({\"mtDNA\",\"Adh\"), say), provided that \
LocusNames[oldsite] is defined. SelectLoci[data,{5,1,3}] forms a new dataset \
which contains the chosen loci, specified by number.\>";\)\)], "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{

Cell["\<\
SelectIndividuals[newsite,oldsite,inds] names a new dataset which \
is derived as a subset of the old one. Individuals are specified by number \
({5,1,3}, say).\
\>", "Subsubsection"],

Cell[BoxData[
    \(\(SelectIndividuals::usage = "\<SelectIndividuals[newsite,oldsite,inds] \
names a new dataset which is derived as a subset of the old one. Individuals \
are specified by number ({5,1,3}, say).\>";\)\)], "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{

Cell["MissingData", "Subsubsection",
  InitializationCell->True],

Cell[BoxData[
    \(\(MissingData::usage = "\<MissingData is an option for \
GenotypeFrequency and AlleleFrequencyTable that specifies that missing data,\
\[EmptySet], are interpreted as homozygous null alleles\>";\)\)], "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{

Cell["NullAllele", "Subsubsection",
  InitializationCell->True],

Cell[BoxData[
    \(\(NullAllele::usage = "\<NullAllele\[Rule]\[Nu] is anmoption for \
GenotypeFrequency and AlleleFrequencyTable which specifies that \[Nu] \
represents a null allele.  This must be listed in the allele list for the \
relevant loci, and the same symbol must be used for all loci\>";\)\)], "Input",\

  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{

Cell["GenotypeFrequency", "Subsubsection",
  InitializationCell->True],

Cell[BoxData[
    \(\(GenotypeFrequency::usage = "\<GenotypeFrequency[d,alleleList,pList]  \
lists the diploid genotype frequency for each locus, given the allele \
frequencies p. The allele names are listed in the second argument.  \
NullAllele\[Rule]\[Nu]  specifies that allele \[Nu] is a null allele; null \
heterozygotes appear as homozygotes, and null homozygotes appear as missing \
data.  MissingData\[Rule]True allows missing data to be interpreted as null \
homozygotes and used in estimation; otherwise they are ignored\>";\)\)], \
"Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{

Cell["AlleleFrequency", "Subsubsection",
  InitializationCell->True],

Cell[BoxData[
    \(\(AlleleFrequency::usage = \
\*"\"\<AlleleFrequency[locus,allele,alleleList,pList] gives the frequency of \
the given allele. Missing data are represented by \[EmptySet] and return a \
frequency of \[EmptySet]. \
AlleleFrequency[{\!\(a\_1\),\[Ellipsis]},alleleList,pList] lists the \
frequencies of all the alleles. (These are assumed to be at successive \
loci,so that {\!\(a\_1\),\[Ellipsis]} is a haploid genotype).\>\"";\)\)], \
"Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{

Cell["\<\
AlleleFrequencyTable[site,alleles] gives a table of allele \
frequencies for the site\
\>", "Subsubsection"],

Cell[BoxData[
    \(\(AlleleFrequencyTable::"\<usage\>" = \
"\<AlleleFrequencyTable[site,alleles] gives a table of allele frequencies for \
the site.  NullAlleles\[Rule]\[Nu] allows for the presence of null alleles, \
labelled \[Nu].  The same symbol must be used for nulls at all loci.  \
MissingData->True specifies that \[EmptySet] is interpreted as a null \
homozygote.  Otherwise, missing data are ignored.\>";\)\)], "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{

Cell["\<\
NumberOfIndividualsTable[site] gives a table of the number of \
individuals with data for each locus\
\>", "Subsubsection"],

Cell[BoxData[
    \(\(NumberOfIndividualsTable::usage = "\<NumberOfIndividualsTable[site] \
gives a table of the number of individuals with data for each locus\>";\)\)], \
"Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{

Cell["\<\
NumberOfGenesTable[site] gives a table of the number of genes with \
data for each locus\
\>", "Subsubsection"],

Cell[BoxData[
    \(\(NumberOfGenesTable::usage = "\<NumberOfGenesTable[site] gives a table \
of the number of genes with data for each locus\>";\)\)], "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{

Cell["\<\
ReducedData[site,alleles,Detail->True] lists the number of \
observations of each diploid type for that site, together with that type. \
ReducedData[site,alleles] just lists the counts, in the same order as \
DiploidTypes[].\
\>", "Subsubsection"],

Cell[BoxData[
    \(\(ReducedData::usage = 
      "\<ReducedData[site,alleles,Detail->True] lists the number of \
observations of each diploid type for that site, together with that type. \
ReducedData[site,alleles] just lists the counts, in the same order as \
DiploidTypes[].\>"; \)\)], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(\(Detail::usage = 
      "\<Detail is an option for ReducedData which lists counts and types, \
rather than just counts\>"; \)\)], "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{

Cell["\<\
AlleleFrequencyMean[site,alleles] gives the mean allele frequency.  \
There must be the same number of alleles per locus.\
\>", "Subsubsection"],

Cell[BoxData[
    \(\(AlleleFrequencyMean::usage = "\<AlleleFrequencyMean[site,alleles] \
gives the mean allele frequency.  There must be the same number of alleles \
per locus.\>";\)\)], "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{

Cell["\<\
NetCovariance[site] gives the net covariance between each locus and \
the others\
\>", "Subsubsection",
  InitializationCell->True],

Cell[BoxData[
    \(\(NetCovariance::usage = 
      "\<NetCovariance[site] gives the net covariance between each locus and \
the others\>"; \)\)], "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{

Cell["\<\
RandomFamily[p1,
    p2] gives a random offspring from a cross between genotypes p1, p2.\
\>", \
"Subsubsection"],

Cell[BoxData[
    \(\(RandomFamily::usage = "\<RandomFamily[p] gives a haploid offspring \
from the diploid parent p.  RandomFamily[p1,p2] gives a random diploid \
offspring from a cross between diploid genotypes p1, p2.  \
RandomFamily[p1,p2,n] generates n such offspring.  Linkage\[Rule]{r12,r23,\
\[Ellipsis]} allows for linkage.  \
SegregationRatio\[Rule]{0.6,0.7,\[Ellipsis]} allows for a biased segregation \
at each locus; the proportion of alleles derived from the first genome in the \
diploid is given.\>";\)\)], "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    StyleBox[\(SegregationRatio\ is\ an\ option\ for\ RandomFamily\ that\ \
specifies\ the\ probability\ that\ the\ allele\ from\ the\ first\ genome\ in\ \
the\ diploid\ is\ transmitted . \ \ SegregationRatio \[Rule] {0.6, 
            0.7, \[Ellipsis]}\ specifies\ different\ ratios\ for\ each\ \
locus; \ SegregationRatio \[Rule] 1\/2, \ the\ default, \ 
      specifies\ the\ same\ ratio\ at\ all\ \(\(loci\)\(.\)\)\),
      FontFamily->"Times"]], "Subsubsection"],

Cell[BoxData[
    \(\(SegregationRatio::usage = \*"\"\<SegregationRatio is an option for \
RandomFamily that specifies the probability that the allele from the first \
genome in the diploid is transmitted.  SegregationRatio\[Rule]{0.6,0.7,\
\[Ellipsis]} specifies different ratios for each locus.  SegregationRatio\
\[Rule]{{0.6,0.7,\[Ellipsis]},{0.8,\[Ellipsis]}} allows different ratios in \
the two parents. SegregationRatio\[Rule]\!\(1\/2\), the default, specifies \
the same ratio at all loci.\>\"";\)\)], "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    \(TextForm\`Linkage \[Rule] {r\_\(1, 2\), 
          r\_\(2, 3\), \[Ellipsis]}\ is\ an\ option\ for\ Gametes[]\ and\ \
GameteTable[]\ which\ specifies\ the\ recombination\ rates\ in\ each\ \
interval; \ 
    assumes\ no\ interference\ and\ a\ linear\ map . \ \ The\ default\ \
Linkage \[Rule] False\ gives\ unlinked\ \(\(loci\)\(.\)\)\)], "Subsubsection"],

Cell[BoxData[
    \(\(Linkage::usage = \*"\"\<Linkage\[Rule]{\!\(r\_\(1, 2\)\),\!\(r\_\(2, \
\\\\\\\ 3\)\),\[Ellipsis]} is an option for Gametes[], GameteTable[] and \
RandomFamily[] which specifies the recombination rates in each interval; \
assumes no interference and a linear map.  The default Linkage\[Rule]False \
gives unlinked loci. \>\"";\)\)], "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    \(TextForm\`NetRecombination[{r\_1, r\_2, 
          r\_3, \[Ellipsis]}]\ gives\ the\ net\ recombination\ rate\ across\ \
a\ linear\ genetic\ map\)], "Subsubsection",
  InitializationCell->True],

Cell[BoxData[
    \(\(NetRecombination::usage = \
\*"\"\<NetRecombination[{\!\(r\_1\),\!\(r\_2\),\!\(r\_3\),\[Ellipsis]}] gives \
the net recombination rate across a linear genetic map\>\"";\)\)], "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    StyleBox[\(GenotypeProbability[o, 
          p]\ is\ the\ chance\ that\ haploid\ offspring\ o\ would\ be\ \
produced\ by\ diploid\ parent\ p . \ 
          GenotypeProbability[o, p\_1, 
            p\_2]\ is\ the\ chance\ that\ diploid\ offspring\ o\ would\ be\ \
produced\ by\ diploid\ parents\ p\_1, \(\(p\_2\)\(.\)\)\),
      FontFamily->"Times"]], "Subsubsection"],

Cell[BoxData[
    \(\(GenotypeProbability::usage = \*"\"\<GenotypeProbability[o,p] is the \
chance that haploid offspring o would be produced by diploid parent p. \
GenotypeProbability[o,\!\(p\_1\),\!\(p\_2\)] is the chance that diploid \
offspring o would be produced by diploid parents \!\(p\_1\),\!\(p\_2\).  \
Options Linkage and SegregationRatio can be used, as in RandomFamily[]. \
ObservableGenotype\[Rule]True sums over all full diploid offspring genotypes \
compatible with the observed genotype o. \>\"";\)\)], "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{

Cell["\<\
GenotypeFrequencyTable[site,alleles] lists the diploid genotype \
frequencies, locus by locus\
\>", "Subsubsection"],

Cell[BoxData[
    RowBox[{
      RowBox[{\(GenotypeFrequencyTable::usage\), "=", 
        "\"\<\!\(TraditionalForm\`GenotypeFrequencyTable\)[site,alleles] \
lists the diploid genotype frequencies, locus by locus\>\""}], ";"}]], "Input",\

  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{

Cell["ParentalGenotypes", "Subsubsection"],

Cell[BoxData[
    \(\(ParentalGenotypes::usage = \
"\<ParentalGenotypes[{{0,0,1,1,\[Ellipsis]},\[Ellipsis]}] returns a list of \
the joint parental genotypes inferred from a list of segregations.  Assumes \
two alleles per locus, with genotypes represented by 0,1, 2.  Missing data \
can be represented by \[EmptySet].\>";\)\)], "Input",
  InitializationCell->True]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["Private parts", "Section"],

Cell[BoxData[
    \(\(Begin["\<Multilocus`DataManipulation`Private`\>"]; \)\)], "Input",
  InitializationCell->True,
  AspectRatioFixed->False],

Cell[BoxData[
    \(\(Off[General::spell1, General::spell]; \)\)], "Input",
  InitializationCell->True],

Cell[CellGroupData[{

Cell[TextData[
"HaploidTypes[{{a1,b1,..},{a2,b2,..}..}] lists all possible haploid \
genotypes, based on the set of alleles {a1,b1,..} at locus 1, etc.  \
HaploidTypes[{{a,b,..},n}] lists all possible genotypes, assuming the same \
set of alleles at n loci.  HaploidTypes[n] assumes n loci, with two alleles \
labelled {0,1}. HaploidTypes[n,SortByClass\[Rule]True] lists haplotypes \
ordered by the # of '1' alleles."], "Subsubsection"],

Cell[BoxData[
    \(\(Options[HaploidTypes] = {SortByClass \[Rule] False}; \)\)], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(\(HaploidTypes[{}, ___] := {}; \)\)], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(\(HaploidTypes[g_List, opts___] := \(HaploidTypes[g, opts] = 
          If[\(SortByClass /. {opts}\) /. Options[HaploidTypes], \n\t\t\tSort[
              HaploidTypes[g], 
              Module[{p1 = Plus @@ #1, p2 = Plus @@ #2}, 
                  If[p1 < p2, True, 
                    If[p1 > p2, False, 
                      OrderedQ[{#1, #2}]]]] &], \n\t\t\tFlatten[
              Apply[Outer, Prepend[g, List]], Length[g] - 1]]\);\)\)], "Input",\

  InitializationCell->True],

Cell[BoxData[
    \(\(HaploidTypes[{g_List, n_Integer}, opts___] := 
      \(HaploidTypes[{g, n}, opts] = HaploidTypes[Table[g, {n}], opts]\); 
    \)\)], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(\(HaploidTypes[n_Integer, opts___] := 
      \(HaploidTypes[n, opts] = HaploidTypes[{{0, 1}, n}, opts]\); \)\)], 
  "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{

Cell["\<\
DiploidTypes[{{a1,b1,..},{a2,b2,..}..}] lists all possible diploid \
genotypes, based on the set of alleles {a1,b1,..} at locus 1, etc.  \
DiploidTypes[{a,b,..},n] lists all possible genotypes, assuming the same set \
of alleles at n loci.  DiploidTypes[n] assumes n loci, with two alleles \
labelled {0,1}.  DiploidTypes[n,SortByClass\[Rule]True] lists  diploid \
genotypes ordered by the # of '1' alleles.\
\>", "Subsubsection"],

Cell[BoxData[
    \(\(Options[DiploidTypes] = {SortByClass \[Rule] False};\)\)], "Input",
  InitializationCell->True],

Cell[BoxData[{
    \(\(DiploidTypes[{}, ___] = {};\)\), "\n", 
    \(\(DiploidTypes[{s_List}, opts___] := \(DiploidTypes[{s}, opts] = 
          If[\(SortByClass /. {opts}\) /. Options[DiploidTypes], \n\t\t\tSort[
              DiploidTypes[{s}], 
              Module[{p1 = Plus @@ \(Plus @@ #1\), 
                    p2 = Plus @@ \(Plus @@ #2\)}, 
                  If[p1 < p2, True, 
                    If[p1 > p2, False, 
                      OrderedQ[{#1, #2}]]]] &], \n\t\t\tModule[{fs, j, 
                k}, \[IndentingNewLine]fs = 
                Flatten[
                  Table[{Sort[{s\[LeftDoubleBracket]j\[RightDoubleBracket], 
                          s\[LeftDoubleBracket]k\[RightDoubleBracket]}]}, {j, 
                      Length[s]}, {k, j}], 1]]]\);\)\), "\n", 
    \(\(DiploidTypes[{s_List, t__List}, 
          opts___] := \(DiploidTypes[{s, t}, 
            opts] = \n\t\tIf[\(SortByClass /. {opts}\) /. 
              Options[DiploidTypes], \n\t\t\ Sort[DiploidTypes[{s, t}], 
              Module[{p1 = Plus @@ \(Plus @@ #1\), 
                    p2 = Plus @@ \(Plus @@ #2\)}, 
                  If[p1 < p2, True, 
                    If[p1 > p2, False, 
                      OrderedQ[{#1, #2}]]]] &], \n\t\t\tFlatten[
              Outer[Join, DiploidTypes[{s}], DiploidTypes[{t}], 1], 
              1]]\);\)\)}], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(\(DiploidTypes[{s_List, n_Integer}, 
          opts___] := \(DiploidTypes[s, n, opts] = \n\t\tDiploidTypes[
            Table[s, {n}], opts]\);\)\)], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(\(DiploidTypes[n_Integer, 
          opts___] := \(DiploidTypes[n, 
            opts] = \n\t\tDiploidTypes[{{0, 1}, n}, opts]\);\)\)], "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{

Cell["\<\
DiploidSubsets[S] gives all the diploid subsets based on loci \
listed in S\
\>", "Subsubsection",
  InitializationCell->True],

Cell[BoxData[
    \(\(DiploidSubsets[S_List] := \(DiploidSubsets[S] = 
          HaploidSubsets[Join[S, \(\((\(#\^*\))\) &\) /@ S]]\);\)\)], "Input",\

  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{

Cell["\<\
HaploidSubsets[S] gives all the haploid subsets based on loci \
listed in S. Stores results\
\>", "Subsubsection",
  InitializationCell->True],

Cell[BoxData[
    \(\(HaploidSubsets[S_List] := 
      \(HaploidSubsets[S] = Subsets[S, 2, Length[S]]\); \)\)], "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{

Cell["\<\
PossibleGenotypes[{{a,A},{b,B},{c,c}}] lists all the diploid \
genotypes compatible with the observed genotype, {{{a,b,c},{A,B,c}},\
\[Ellipsis]}. The default is to list both {{a,b,c},{A,B,c}} and \
{{A,B,c},{a,b,c}}; ListEquivalentGenotypes->True only lists one of these two \
complementary genotypes\
\>", "Subsubsection"],

Cell[BoxData[
    \(\(Options[
          PossibleGenotypes] = {ListEquivalentGenotypes \[Rule] 
            True};\)\)], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(\(PossibleGenotypes[g : {{_, _} ... }, 
          opts___Rule] := \[IndentingNewLine]Module[{ps}, \
\[IndentingNewLine]ps = \(Outer[List, ##] &\) @@ 
              Replace[g, {x_, x_} \[Rule] {x}, 1]; \[IndentingNewLine]ps = 
            Flatten[ps, 
              Depth[ps] - 
                3]; \[IndentingNewLine]ps = \({#, 
                  Flatten[MapThread[TakeAway[#1, {#2}] &, {g, #}]]} &\) /@ 
              ps; \[IndentingNewLine]If[\(ListEquivalentGenotypes /. {opts}\) \
/. Options[PossibleGenotypes], ps, \((Sort /@ ps)\) // Union]];\)\)], "Input",\

  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{

Cell["\<\
ObservableGenotype[{{a,b,\[Ellipsis]},{A,B,\[Ellipsis]}}] gives the \
diploid genotype that would be observed if cis and trans could not be \
distinguished.\
\>", "Subsubsection"],

Cell[BoxData[
    \(\(ObservableGenotype[{h1_List, h2_List}] := 
        Sort /@ Transpose[{h1, h2}];\)\)], "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{

Cell["\<\
NumberOfIndividuals[site] gives the number of individuals in the \
site\
\>", "Subsubsection"],

Cell[BoxData[
    \(\(NumberOfIndividuals[s_] := Length[Data[s]];\)\)], "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{

Cell["NumberOfLoci[site] gives the number of loci", "Subsubsection"],

Cell[BoxData[
    \(\(NumberOfLoci[s_] := 
        If[NumberOfIndividuals[s] == 0, Indeterminate, 
          Length[\(Data[
                s]\)\[LeftDoubleBracket]1\[RightDoubleBracket]]];\)\)], \
"Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{

Cell["\<\
NumberOfIndividualsTable[site] gives a table of the number of \
individuals with data for each locus\
\>", "Subsubsection"],

Cell[BoxData[
    \(\(NumberOfIndividualsTable[
          s_] := \(Length[DeleteCases[#, \[EmptySet]]] &\) /@ 
          Transpose[Data[s]];\)\)], "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{

Cell["\<\
NumberOfGenesTable[site] gives a table of the number of genes with \
data for each locus\
\>", "Subsubsection"],

Cell[BoxData[
    \(\(NumberOfGenesTable[
          s_] := \(Length[Flatten[DeleteCases[#, \[EmptySet]]]] &\) /@ 
          Transpose[Data[s]];\)\)], "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{

Cell["\<\
NumberOfGenes[site] gives the number of genes sampled from the \
site, allowing for variation in ploidy\
\>", "Subsubsection"],

Cell[BoxData[
    \(\(NumberOfGenes[s_] := 
        NumberOfIndividuals[s] \((Plus @@ Ploidy[s])\);\)\)], "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{

Cell["\<\
Ploidy[site] gives the ploidy of the various loci in the site\
\>", \
"Subsubsection",
  InitializationCell->True],

Cell[BoxData[
    \(\(Ploidy::baddata = "\<Data for a locus at site `1` are invalid or \
missing: `2`\>";\)\)], "Input",
  InitializationCell->True],

Cell[BoxData[
    RowBox[{
      RowBox[{\(Ploidy[s_]\), ":=", 
        RowBox[{"Module", "[", 
          RowBox[{\({pl, x}\), ",", "\[IndentingNewLine]", 
            RowBox[{
              RowBox[{"pl", "=", 
                RowBox[{"Transpose", "[", 
                  
                  RowBox[{\(\((\(If[# === \[EmptySet], \[EmptySet], 
                              Length[#]] &\) /@ #)\) &\), "/@", 
                    TagBox[\(Data[s]\),
                      (MatrixForm[ #]&)]}], "]"}]}], ";", 
              "\[IndentingNewLine]", \(\(\((x = 
                      DeleteCases[#, \[EmptySet]] /. {a_Integer .. } \[Rule] 
                          a; If[MatchQ[x, _List], 
                      Message[Ploidy::baddata, s, x]; \[EmptySet], x])\) &\) /@ 
                pl\)}]}], "]"}]}], ";"}]], "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{

Cell["\<\
SelectLoci[newsite,oldsite,loci] names a new dataset which is \
derived as a subset of the old one. Loci can be specified by number ({5,1,3}, \
say) or by name ({\"mtDNA\",\"Adh\"), say), provided that LocusNames[oldsite] \
is defined. SelectLoci[data,{5,1,3}] forms a new dataset which contains the \
chosen loci, specified by number.\
\>", "Subsubsection"],

Cell[BoxData[
    \(\(SelectLoci::badspec = "\<Specification `1` for loci does not match \
locus names `2` for site `3`\>";\)\)], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(\(SelectLoci[ns_, os_, 
          x_] := \[IndentingNewLine]Module[{xx, \[IndentingNewLine]lns = \
\((Head[LocusNames[os]] === List)\)}, \[IndentingNewLine]\ 
          If[MatchQ[x, {___Integer}], \[IndentingNewLine]xx = 
              x, \[IndentingNewLine]xx = 
              Flatten[\(Position[LocusNames[os], \ #] &\) /@ 
                  x]; \[IndentingNewLine]If[\((Length[xx] \[NotEqual] 
                    Length[x])\) || \((\(! MatchQ[
                      xx, {___Integer}]\))\), \[IndentingNewLine]Message[
                SelectLoci::badspec, x, LocusNames[os], 
                os]]]; \[IndentingNewLine]\((Data[ns] = 
              SelectLoci[Data[os], xx]; \[IndentingNewLine]If[lns, 
              LocusNames[ns] = \(LocusNames[os]\)\[LeftDoubleBracket]
                  xx\[RightDoubleBracket]])\);];\)\)], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(\(SelectLoci[d_, x : {___Integer}] := 
        Transpose[\(Transpose[d]\)\[LeftDoubleBracket]
            x\[RightDoubleBracket]];\)\)], "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{

Cell["\<\
SelectIndividuals[newsite,oldsite,inds] names a new dataset which \
is derived as a subset of the old one. Individuals are specified by number \
({5,1,3}, say).\
\>", "Subsubsection"],

Cell[BoxData[
    \(\(SelectIndividuals[ns_, os_, 
          x : {___Integer}] \
:= \[IndentingNewLine]Module[{\[IndentingNewLine]lns = \((Head[
                    LocusNames[os]] === 
                  List)\)}, \[IndentingNewLine]\ \(\((Data[
                  ns] = \(Data[os]\)\[LeftDoubleBracket]
                  x\[RightDoubleBracket]; \[IndentingNewLine]If[lns, 
                LocusNames[ns] = LocusNames[os]])\);\)];\)\)], "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{

Cell["GenotypeFrequency", "Subsubsection",
  InitializationCell->True],

Cell[BoxData[
    \(\(Options[GenotypeFrequency] = {MissingData \[Rule] False, 
          NullAllele \[Rule] None};\)\)], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(\(GenotypeFrequency[l_Integer, \[EmptySet], al : {_List ... }, pl_List, 
          opts___Rule] := \[IndentingNewLine]Module[{na = \(NullAllele /. \
{opts}\) /. Options[
                  GenotypeFrequency], \[IndentingNewLine]md = \(MissingData /. \
{opts}\) /. Options[GenotypeFrequency]}, \[IndentingNewLine]If[
            na === None, \[IndentingNewLine]\[EmptySet], \
\[IndentingNewLine]If[
              MemberQ[al\[LeftDoubleBracket]l\[RightDoubleBracket], 
                  na] \[And] 
                md, \[IndentingNewLine]AlleleFrequency[l, na, al, pl]\^2, \
\[IndentingNewLine]\[EmptySet]]]];\)\)], "Input",
  InitializationCell->True],

Cell[BoxData[{
    \(\(GenotypeFrequency[l_Integer, {a_, a_}, al : {_List ... }, pl_List, 
          opts___Rule] := \[IndentingNewLine]Module[{na = \(NullAllele /. \
{opts}\) /. Options[
                  GenotypeFrequency], \[IndentingNewLine]md = \(MissingData /. \
{opts}\) /. Options[GenotypeFrequency], pn}, \[IndentingNewLine]If[
            MemberQ[al\[LeftDoubleBracket]l\[RightDoubleBracket], 
              na], \[IndentingNewLine]pn = 
              AlleleFrequency[l, na, al, 
                pl]; \[IndentingNewLine]\(AlleleFrequency[l, a, al, pl]\^2 + \
2  AlleleFrequency[l, a, al, pl] pn\)\/If[MemberQ[al\[LeftDoubleBracket]l\
\[RightDoubleBracket], na] \[And] \(! md\), 1 - pn\^2, 1], \
\[IndentingNewLine]AlleleFrequency[l, a, al, pl]\^2]];\)\), "\
\[IndentingNewLine]", 
    \(\(GenotypeFrequency[l_Integer, {a1_, a2_}, al : {_List ... }, pl_List, 
          opts___Rule] := 
        Module[{na = \(NullAllele /. {opts}\) /. 
                Options[
                  GenotypeFrequency], \[IndentingNewLine]md = \(MissingData /. \
{opts}\) /. Options[
                  GenotypeFrequency]}, \[IndentingNewLine]\(2  \
AlleleFrequency[l, a1, al, pl] AlleleFrequency[l, a2, al, \
pl]\)\/If[MemberQ[al\[LeftDoubleBracket]l\[RightDoubleBracket], na] \[And] \
\(! md\), 1 - pn\^2, 1]];\)\)}], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(\(GenotypeFrequency[dg : {\(({_, _} | \[EmptySet])\) ... }, 
          al : {_List ... }, pl_List, 
          opts___Rule] := \[IndentingNewLine]MapIndexed[
          GenotypeFrequency[#2\[LeftDoubleBracket]1\[RightDoubleBracket], #1, 
              al, pl, opts] &, dg];\)\)], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(\(GenotypeFrequency[
          dg : {\(({_, _} | \[EmptySet])\) ... }, {as_List, n_Integer}, 
          pl_List, opts___Rule] := \n\t\tGenotypeFrequency[dg, 
          Table[as, {n}], pl, opts];\)\)], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(\(GenotypeFrequency[dg : {\(({_, _} | \[EmptySet])\) ... }, n_Integer, 
          pl_List, opts___Rule] := \n\t
        GenotypeFrequency[dg, {{0, 1}, n}, pl, opts];\)\)], "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{

Cell["AlleleFrequency", "Subsubsection",
  InitializationCell->True],

Cell[BoxData[
    \(\(AlleleFrequency::badAllele = "\<`1` is not an allele of locus `2`\>";\
\)\)], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(\(AlleleFrequency[l_Integer, a_, al : {_List ... }, pl_List] := 
        Module[{pos = 
              Position[al\[LeftDoubleBracket]l\[RightDoubleBracket], 
                a]}, \[IndentingNewLine]If[
            a === \[EmptySet], \[IndentingNewLine]\[EmptySet], \
\[IndentingNewLine]If[
              pos === {}, \[IndentingNewLine]Message[
                AlleleFrequency::badAllele, a, l]; 
              Indeterminate, \[IndentingNewLine]Extract[
                pl\[LeftDoubleBracket]l\[RightDoubleBracket], 
                pos\[LeftDoubleBracket]1\[RightDoubleBracket]]]]];\)\)], \
"Input",
  InitializationCell->True],

Cell[BoxData[
    \(\(AlleleFrequency[a_List, al : {_List ... }, pl_List] := 
        MapIndexed[
          AlleleFrequency[#2\[LeftDoubleBracket]1\[RightDoubleBracket], #1, 
              al, pl] &, a];\)\)], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(\(AlleleFrequency[l_Integer, a_, {as_List, n_Integer}, 
          pl_List] := \n\t\tAlleleFrequency[l, a, Table[as, {n}], 
          pl];\)\)], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(\(AlleleFrequency[l_Integer, a_, n_Integer, pl_List] := \n\t
        AlleleFrequencyTable[l, a, {{0, 1}, n}, pl];\)\)], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(\(AlleleFrequency[a_List, {as_List, n_Integer}, 
          pl_List] := \n\t\tAlleleFrequency[a, Table[as, {n}], 
          pl];\)\)], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(\(AlleleFrequency[a_List, n_Integer, pl_List] := \n\t
        AlleleFrequencyTable[a, {{0, 1}, n}, pl];\)\)], "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{

Cell["\<\
AlleleFrequencyTable[site,alleles] gives a table of allele \
frequencies for the site\
\>", "Subsubsection"],

Cell[BoxData[
    \(\(Options[AlleleFrequencyTable] = {NullAllele \[Rule] None, 
          MissingData \[Rule] False};\)\)], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(\(AlleleFrequencyTable::badNull = "\<Missing allele `1` is present more \
than once in allele list `2` for locus `3`\>";\)\)], "Input",
  InitializationCell->True],

Cell[BoxData[
    RowBox[{
      RowBox[{\(AlleleFrequencyTable[s_, al : {_List ... }, opts___Rule]\), ":=",
         
        RowBox[{\(AlleleFrequencyTable[s, as, opts]\), "=", 
          "\[IndentingNewLine]", 
          RowBox[{"Module", "[", 
            
            RowBox[{\({j, k, td = Transpose[Data[s]], pp, gt, ngt, nm, dt, 
                homs, ff, \[IndentingNewLine]ntot = 
                  2  NumberOfIndividuals[s], pna, px, 
                pl, \[IndentingNewLine]na = \(NullAllele /. {opts}\) /. 
                    Options[
                      AlleleFrequencyTable], \[IndentingNewLine]md = \
\(MissingData /. {opts}\) /. Options[AlleleFrequencyTable]}\), ",", 
              "\[IndentingNewLine]", 
              
              RowBox[{\(ngt = NumberOfGenesTable[s]\), ";", 
                "\[IndentingNewLine]", \(pp = 
                  Table[If[
                      ngt\[LeftDoubleBracket]j\[RightDoubleBracket] == 0, 
                      Indeterminate, 
                      Count[Flatten[
                            DeleteCases[
                              td\[LeftDoubleBracket]
                                j\[RightDoubleBracket], \[EmptySet]]], 
                          al\[LeftDoubleBracket]j, k\[RightDoubleBracket]]/
                        ngt\[LeftDoubleBracket]j\[RightDoubleBracket]], {j, 
                      NumberOfLoci[s]}, {k, 
                      Length[al\[LeftDoubleBracket]
                          j\[RightDoubleBracket]]}]\), ";", 
                "\[IndentingNewLine]", 
                RowBox[{"If", "[", 
                  
                  RowBox[{\(na === None\), ",", "\[IndentingNewLine]", "pp", 
                    ",", "\[IndentingNewLine]", 
                    
                    RowBox[{\(dt = \(DiploidTypes[{#}] &\) /@ al\), ";", 
                      "\[IndentingNewLine]", 
                      RowBox[{"gt", "=", 
                        RowBox[{
                          FormBox["GenotypeFrequencyTable",
                            "TraditionalForm"], "[", \(s, al\), "]"}]}], ";", 
                      "\[IndentingNewLine]", \(Table[\[IndentingNewLine]np = 
                          Position[
                            al\[LeftDoubleBracket]j\[RightDoubleBracket], 
                            na]; \[IndentingNewLine]If[
                          Length[np] > 1, \[IndentingNewLine]Message[
                            AlleleFrequencyTable::badNull, na, al, j]; 
                          Indeterminate, \[IndentingNewLine]If[
                            Length[np] \[Equal] 
                              0, \[IndentingNewLine]pp\[LeftDoubleBracket]
                              j\[RightDoubleBracket], \[IndentingNewLine]pna \
= np\[LeftDoubleBracket]1, 1\[RightDoubleBracket]; \[IndentingNewLine]px = 
                              Delete[
                                pp\[LeftDoubleBracket]j\[RightDoubleBracket], 
                                pna]; \[IndentingNewLine]homs = 
                              Delete[\(ngt\[LeftDoubleBracket]j\
\[RightDoubleBracket]*Extract[
  
,

Cell[BoxData[
    \(\(AlleleFrequencyTable[s_, {as_List, n_Integer}, 
          opts___Rule] := \n\t\tAlleleFrequencyTable[s, Table[as, {n}], 
          opts];\)\)], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(\(AlleleFrequencyTable[s_, n_Integer, opts___Rule] := \n\t
        AlleleFrequencyTable[s, {{0, 1}, n}, opts];\)\)], "Input",
  InitializationCell->True]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
ReducedData[site,alleles,Detail->True] lists the number of \
observations of each diploid type for that site, together with that type. \
ReducedData[site,alleles] just lists the counts, in the same order as \
DiploidTypes[].\
\>", "Subsubsection"],

Cell[BoxData[
    \(\(Options[ReducedData] := {Detail -> False}; \)\)], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(\(ReducedData[s_, as_, opts___] := 
      Module[{dd = Data[s], dt = DiploidTypes[as]}, 
        If[\(Detail /. {opts}\) /. Options[ReducedData], \n\t\t\t
          \({Count[dd, #], #}&\)/@dt, \n\t\t\t\(Count[dd, #]&\)/@dt]]; \)\)], 
  "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{

Cell["\<\
ConvertData[{{0,1,-1,2},\[Ellipsis]}}] converts data on biallelic \
loci into the more general form, \
{{{0,0},{0,1},\[EmptySet],{1,1}},\[Ellipsis]}.  ConvertData[{{0,1,-1,2},\
\[Ellipsis]}},{1,2,2,2,\[Ellipsis]}] allows for different ploidy across loci; \
gives  {{{0},{0,1},\[EmptySet],{1,1}},\[Ellipsis]}.\
\>", "Subsubsection"],

Cell[BoxData[{
    \(\(ConvertData[{a__List}] := ConvertData /@ {a};\)\), "\n", 
    \(\(ConvertData[{a___}] := \n\t{a} /. {0 \[Rule] {0, 0}, 
            1 \[Rule] {0, 1}, 
            2 \[Rule] {1, 1}, \(-1\) \[Rule] \[EmptySet]};\)\)}], "Input",
  InitializationCell->True],

Cell[BoxData[{
    \(\(ConvertData[{a__List}, 
          pl_List] := \(ConvertData[#, pl] &\) /@ {a};\)\), "\n", 
    \(\(ConvertData[{a___}, pl_List] := 
        Module[{j}, \n\t
          Table[If[
              pl\[LeftDoubleBracket]j\[RightDoubleBracket] == 
                2, \n\t\t\t\t{a}\[LeftDoubleBracket]
                  j\[RightDoubleBracket] /. {0 \[Rule] {0, 0}, 
                  1 \[Rule] {0, 1}, 
                  2 \[Rule] {1, 
                      1}, \(-1\) \[Rule] \[EmptySet]}, \n\t\t\t\t{a}\
\[LeftDoubleBracket]j\[RightDoubleBracket] /. {0 \[Rule] {0}, 
                  1 \[Rule] {1}}], {j, Length[{a}]}]];\)\)}], "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{

Cell["\<\
AlleleFrequencyMean[site,alleles] gives the mean allele frequency.  \
There must be the same number of alleles per locus.\
\>", "Subsubsection"],

Cell[BoxData[
    \(\(AlleleFrequencyMean[s_, as_] := 
        If[NumberOfIndividuals[s] == 0, 
          Indeterminate, \(\((# . NumberOfGenesTable[s])\) &\) /@ 
              Transpose[AlleleFrequencyTable[s, as]]/
            Plus @@ NumberOfGenesTable[s]];\)\)], "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{

Cell["\<\
NetCovariance[site] gives the net covariance between each locus and \
the others\
\>", "Subsubsection",
  InitializationCell->True],

Cell[BoxData[
    \(\(NetCovariance[s_] := 
        Module[{i, j, k, ss, dsdt, ds, sds, ff}, \n\t
          ds = \((Data[
                  s] /. {{i_?NumberQ, j_?NumberQ} :> i + j, {i_?NumberQ} :> 
                    i, \[EmptySet] \[Rule] 0})\)\t; \n\tsds = Plus @@ ds; \n\t
          dsdt = Table[
              If[\(NumberOfGenesTable[s]\)\[LeftDoubleBracket]
                    j\[RightDoubleBracket] == 0, Indeterminate, 
                sds\[LeftDoubleBracket]j\[RightDoubleBracket]\/\(\
NumberOfGenesTable[s]\)\[LeftDoubleBracket]j\[RightDoubleBracket]], {j, 
                NumberOfLoci[s]}]; \n\tff = \(\((# - dsdt)\) &\) /@ ds; \n\t
          Table[\((ss = 0; 
              Sum[If[\((\(Data[s]\)\[LeftDoubleBracket]i, 
                            j\[RightDoubleBracket] === \[EmptySet])\) || \
\((\(Data[s]\)\[LeftDoubleBracket]i, 
                            k\[RightDoubleBracket] === \[EmptySet])\), 0, 
                    ss += 1; 
                    ff\[LeftDoubleBracket]i, j\[RightDoubleBracket] 
                      ff\[LeftDoubleBracket]i, k\[RightDoubleBracket]], {i, 
                    NumberOfIndividuals[s]}]/ss)\), {k, NumberOfLoci[s]}, {j, 
              NumberOfLoci[s]}]];\)\)], "Input",
  CellLabel->"In[49]:=",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{

Cell["\<\
RandomFamily[p1,
    p2] gives a random offspring from a cross between genotypes p1, p2.\
\>", \
"Subsubsection"],

Cell[BoxData[
    \(\(Options[RandomFamily] = {Linkage \[Rule] False, 
          SegregationRatio \[Rule] False};\)\)], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(\(RandomFamily[p__List, n_Integer, opts___Rule]\  := 
        Table[RandomFamily[p, opts], {n}];\)\)], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(\(RandomFamily[p1_List, p2_List]\  := {RandomFamily[p1], 
          RandomFamily[p2]};\)\)], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(\(RandomFamily[p1_List, p2_List, 
          opts__Rule]\  := {RandomFamily[p1, 
            opts /. {\((Linkage \[Rule] {x_List, 
                        y_List})\) \[RuleDelayed] \((Linkage \[Rule] 
                      x)\), \((SegregationRatio \[Rule] {x_List, 
                        y_List})\) \[RuleDelayed] \((SegregationRatio \[Rule] 
                      x)\)}], \[IndentingNewLine]RandomFamily[p2, 
            opts /. {\((Linkage \[Rule] {x_List, 
                        y_List})\) \[RuleDelayed] \((Linkage \[Rule] 
                      y)\), \((SegregationRatio \[Rule] {x_List, 
                        y_List})\) \[RuleDelayed] \((SegregationRatio \[Rule] 
                      y)\)}]};\)\)], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(\(RandomFamily[{h1_List, h2_List}, 
          opts___Rule]\  := \[IndentingNewLine]Module[{\[IndentingNewLine]rl \
= \(Linkage /. {opts}\) /. Options[RandomFamily], 
            sr = \(SegregationRatio /. {opts}\) /. 
                Options[RandomFamily], \[IndentingNewLine]x, y, 
            tss = Transpose[{h1, h2}], j}, \[IndentingNewLine]If[
            rl === False, \[IndentingNewLine]If[sr === False, 
              sr = Table[
                  1\/2, {Length[
                      h1]}]]; \[IndentingNewLine]MapThread[\((#1\
\[LeftDoubleBracket]If[Random[] < #2, 1, 
                      2]\[RightDoubleBracket])\) &, {Transpose[{h1, h2}], 
                sr}], \[IndentingNewLine]x = Random[Integer, {1, 2}]; 
            y = {tss\[LeftDoubleBracket]1, 
                  x\[RightDoubleBracket]}; \[IndentingNewLine]Do[
              If[Random[] < rl\[LeftDoubleBracket]j\[RightDoubleBracket], 
                x = If[x \[Equal] 1, 2, 1]]; 
              AppendTo[y, 
                tss\[LeftDoubleBracket]j + 1, x\[RightDoubleBracket]], {j, 
                Length[rl]}]; y]];\)\)], "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    StyleBox[\(GenotypeProbability[o, 
          p]\ is\ the\ chance\ that\ haploid\ offspring\ o\ would\ be\ \
produced\ by\ diploid\ parent\ p . \ 
          GenotypeProbability[o, p\_1, 
            p\_2]\ is\ the\ chance\ that\ diploid\ offspring\ o\ would\ be\ \
produced\ by\ diploid\ parents\ p\_1, \(\(p\_2\)\(.\)\)\),
      FontFamily->"Times"]], "Subsubsection"],

Cell[BoxData[
    \(\(Options[GenotypeProbability] = {Linkage \[Rule] False, 
          SegregationRatio \[Rule] False, 
          ObservableGenotype \[Rule] False};\)\)], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(\(GenotypeProbability[o_List, {h1_List, h2_List}, 
          opts___Rule] := \[IndentingNewLine]Module[{\[IndentingNewLine]rl = \
\(Linkage /. {opts}\) /. Options[GenotypeProbability], 
            sr = \(SegregationRatio /. {opts}\) /. 
                Options[GenotypeProbability], z, rr, 
            xx}, \[IndentingNewLine]If[
            rl === False, \[IndentingNewLine]If[sr === False, 
              sr = Table[1\/2, {Length[h1]}]]; \[IndentingNewLine]Times @@ 
              MapThread[\((Plus @@ \((Position[#2, #1] /. {{1} \[Rule] #3, \
{2} \[Rule] 1 - #3})\))\) &, {o, {h1, h2} // Transpose, 
                  sr}], \[IndentingNewLine]z = 
              Transpose[{Transpose[{h1, h2}], o, 
                  Append[rl, \[Pi]]}]; \[IndentingNewLine]If[
              And @@ \((\(MemberQ[#\[LeftDoubleBracket]1\[RightDoubleBracket],\
 #\[LeftDoubleBracket]2\[RightDoubleBracket]] &\) /@ 
                    z)\), \[IndentingNewLine]z = \(\(z //. {a___, {{y1_, 
                              z1_}, o1_, r1x_}, {{x_, x_}, x_, 
                            rx2_}, {{y2_, z2_}, o2_, r2_}, 
                          b___} \[RuleDelayed] {a, {{y1, z1}, o1, 
                            NetRecombination[{r1x, rx2}]}, {{y2, z2}, o2, 
                            r2}, b}\) /. {a___, {{x_, x_}, x_, 
                          rx_}} \[RuleDelayed] {a}\) /. {{{x_, x_}, x_, rx_}, 
                      b___} \[RuleDelayed] {b}; \[IndentingNewLine]rr = 
                Transpose[
                  z /. {{{x_, y_}, x_, r_} \[RuleDelayed] {1, r}, {{x_, y_}, 
                          y_, r_} \[RuleDelayed] {2, 
                          r}}]; \[IndentingNewLine]xx = 
                Abs[rr\[LeftDoubleBracket]1\[RightDoubleBracket] - 
                    RotateLeft[
                      rr\[LeftDoubleBracket]1\[RightDoubleBracket]]]; \
\[IndentingNewLine]Times @@ 
                Drop[Transpose[{xx, 
                        rr\[LeftDoubleBracket]2\[RightDoubleBracket]}] /. \
{{1, r_} \[RuleDelayed] r, {0, r_} \[RuleDelayed] 
                        1 - r}, \(-1\)], \[IndentingNewLine]0]]];\)\)], \
"Input",
  InitializationCell->True],

Cell[BoxData[
    \(\(GenotypeProbability[{h1_List, h2_List}, p1_List, 
          p2_List] := \[IndentingNewLine]GenotypeProbability[h1, p1] 
          GenotypeProbability[h2, p2];\)\)], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(\(GenotypeProbability[{h1_List, h2_List}, p1_List, p2_List, 
          opts__Rule] := \[IndentingNewLine]If[\(ObservableGenotype /. {opts}\
\) /. Options[
              GenotypeProbability], \[IndentingNewLine]Module[{j, \
\[IndentingNewLine]ps = PossibleGenotypes[o], \[IndentingNewLine]nopts = 
                DeleteCases[opts, 
                  ObservableGenotype \[Rule] 
                    True]}, \[IndentingNewLine]Sum[\(GenotypeProbability[
                    ps\[LeftDoubleBracket]
                      j\[RightDoubleBracket], #\[LeftDoubleBracket]1\
\[RightDoubleBracket], #\[LeftDoubleBracket]2\[RightDoubleBracket], 
                    nopts] &\) /@ parents, {j, 
                Length[ps]}]], \[IndentingNewLine]GenotypeProbability[h1, p1, 
              opts /. {\((Linkage \[Rule] {x_List, 
                          y_List})\) \[RuleDelayed] \((Linkage \[Rule] 
                        x)\), \((SegregationRatio \[Rule] {x_List, 
                          y_List})\) \[RuleDelayed] \((SegregationRatio \
\[Rule] x)\)}] 
            GenotypeProbability[h2, p2, 
              opts /. {\((Linkage \[Rule] {x_List, 
                          y_List})\) \[RuleDelayed] \((Linkage \[Rule] 
                        y)\), \((SegregationRatio \[Rule] {x_List, 
                          y_List})\) \[RuleDelayed] \((SegregationRatio \
\[Rule] y)\)}]];\)\)], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(\(GenotypeProbability[g : {{_, _} ... }, p1_List, p2_List, 
          opts1___Rule, ObservableGenotype \[Rule] True, 
          opts2___Rule] := \[IndentingNewLine]Plus @@ \
\((\(GenotypeProbability[#, p1, p2, opts1, opts2] &\) /@ 
              PossibleGenotypes[g])\);\)\)], "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    \(TextForm\`NetRecombination[{r\_1, r\_2, 
          r\_3, \[Ellipsis]}]\ gives\ the\ net\ recombination\ rate\ across\ \
a\ linear\ genetic\ map\)], "Subsubsection",
  InitializationCell->True],

Cell[BoxData[{
    \(\(NetRecombination[{}] := 0;\)\), "\n", 
    \(\(NetRecombination[{r___, s_}] := 
        s + NetRecombination[{r}] \((1 - 2  s)\);\)\)}], "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{

Cell["\<\
GenotypeFrequencyTable[site,alleles] lists the diploid genotype \
frequencies, locus by locus\
\>", "Subsubsection"],

Cell[BoxData[
    RowBox[{
      RowBox[{
        RowBox[{
          FormBox["GenotypeFrequencyTable",
            "TraditionalForm"], "[", \(s_, a_\), "]"}], 
        ":=", \(Module[{f}, \[IndentingNewLine]f[d_, 
              aa_] := \((\(Count[
                    d, #] &\) /@ \((DiploidTypes[{aa}] /. {c_List} \[Rule] 
                      c)\))\); \[IndentingNewLine]MapThread[
              f, {Transpose[Data[s]], a}]/NumberOfIndividualsTable[s]]\)}], 
      ";"}]], "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{

Cell["ParentalGenotypes", "Subsubsection"],

Cell[BoxData[{
    \(\(ParentalGenotypes[{}] := \[EmptySet];\)\), "\n", 
    \(\(ParentalGenotypes[f : {\((0 | 1 | 2 | \[EmptySet])\) .. }] := 
        DeleteCases[
            Union[f], \[EmptySet]] /. {{0} \[Rule] {0, 0}, {1} \[Rule] {0, 
                2}, {2} \[Rule] {2, 2}, {0, 1, 2} \[Rule] {1, 1}, {0, 
                2} \[Rule] {1, 1}};\)\), "\n", 
    \(\(ParentalGenotypes[f : {___List}] := 
        ParentalGenotypes /@ Transpose[f];\)\)}], "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{

Cell["Ending", "Subsection"],

Cell[BoxData[
    \(\(On[General::spell1, General::spell]; \)\)], "Input",
  InitializationCell->True],

Cell["\<\
End[];
\
\>", "Input",
  InitializationCell->True],

Cell["EndPackage[];", "Input",
  InitializationCell->True]
}, Closed]]
}, Open  ]]
},
FrontEndVersion->"4.0 for Macintosh",
ScreenRectangle->{{0, 1152}, {0, 748}},
AutoGeneratedPackage->Automatic,
WindowSize->{792, 674},
WindowMargins->{{29, Automatic}, {Automatic, 9}},
StyleDefinitions -> "Default.nb",
MacintoshSystemPageSetup->"\<\
00l0001804P000000b02<?oaonl3>@91H`85N0?N0@00005X0FP000003j0:l001
0@00I00100000@0200000BL?00400000000000000000010000000000000@0?ne
oj/@7@]500P0000000000000000001T1\>"
]


(***********************************************************************
Cached data follows.  If you edit this Notebook file directly, not using
Mathematica, you must remove the line containing CacheID at the top of 
the file.  The cache data will then be recreated when you save this file 
from within Mathematica.
***********************************************************************)

(*CellTagsOutline
CellTagsIndex->{}
*)

(*CellTagsIndex
CellTagsIndex->{}
*)

(*NotebookFileOutline
Notebook[{
Cell[1717, 49, 277, 6, 75, "Input",
  InitializationCell->True],
Cell[1997, 57, 169, 4, 30, "Text"],

Cell[CellGroupData[{
Cell[2191, 65, 31, 0, 50, "Section"],

Cell[CellGroupData[{
Cell[2247, 69, 436, 6, 74, "Subsubsection"],
Cell[2686, 77, 494, 7, 123, "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{
Cell[3217, 89, 143, 3, 28, "Subsubsection"],
Cell[3363, 94, 211, 4, 59, "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{
Cell[3611, 103, 440, 7, 60, "Subsubsection"],
Cell[4054, 112, 509, 8, 123, "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{
Cell[4600, 125, 136, 4, 28, "Subsubsection",
  InitializationCell->True],
Cell[4739, 131, 196, 4, 59, "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{
Cell[4972, 140, 152, 4, 28, "Subsubsection",
  InitializationCell->True],
Cell[5127, 146, 196, 4, 59, "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{
Cell[5360, 155, 334, 6, 60, "Subsubsection"],
Cell[5697, 163, 412, 7, 107, "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{
Cell[6146, 175, 160, 4, 28, "Subsubsection"],
Cell[6309, 181, 233, 4, 38, "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{
Cell[6579, 190, 189, 4, 28, "Subsubsection"],
Cell[6771, 196, 1070, 19, 38, "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{
Cell[7878, 220, 198, 4, 44, "Subsubsection"],
Cell[8079, 226, 260, 5, 38, "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{
Cell[8376, 236, 67, 0, 28, "Subsubsection"],
Cell[8446, 238, 129, 3, 27, "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{
Cell[8612, 246, 341, 6, 44, "Subsubsection"],
Cell[8956, 254, 403, 7, 38, "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{
Cell[9396, 266, 104, 3, 28, "Subsubsection"],
Cell[9503, 271, 174, 3, 23, "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{
Cell[9714, 279, 68, 0, 28, "Subsubsection"],
Cell[9785, 281, 146, 3, 23, "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{
Cell[9968, 289, 136, 3, 28, "Subsubsection"],
Cell[10107, 294, 200, 4, 23, "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{
Cell[10344, 303, 124, 4, 28, "Subsubsection",
  InitializationCell->True],
Cell[10471, 309, 146, 3, 23, "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{
Cell[10654, 317, 112, 2, 28, "Subsubsection",
  InitializationCell->True],
Cell[10769, 321, 159, 4, 23, "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{
Cell[10965, 330, 368, 6, 60, "Subsubsection"],
Cell[11336, 338, 427, 6, 68, "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{
Cell[11800, 349, 193, 4, 44, "Subsubsection"],
Cell[11996, 355, 259, 4, 38, "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{
Cell[12292, 364, 64, 1, 28, "Subsubsection",
  InitializationCell->True],
Cell[12359, 367, 257, 4, 59, "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{
Cell[12653, 376, 63, 1, 28, "Subsubsection",
  InitializationCell->True],
Cell[12719, 379, 344, 6, 91, "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{
Cell[13100, 390, 70, 1, 28, "Subsubsection",
  InitializationCell->True],
Cell[13173, 393, 579, 9, 139, "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{
Cell[13789, 407, 68, 1, 28, "Subsubsection",
  InitializationCell->True],
Cell[13860, 410, 489, 9, 107, "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{
Cell[14386, 424, 118, 3, 28, "Subsubsection"],
Cell[14507, 429, 458, 7, 107, "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{
Cell[15002, 441, 133, 3, 28, "Subsubsection"],
Cell[15138, 446, 208, 4, 38, "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{
Cell[15383, 455, 121, 3, 28, "Subsubsection"],
Cell[15507, 460, 188, 3, 23, "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{
Cell[15732, 468, 257, 5, 44, "Subsubsection"],
Cell[15992, 475, 325, 6, 38, "Input",
  InitializationCell->True],
Cell[16320, 483, 187, 4, 27, "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{
Cell[16544, 492, 154, 3, 28, "Subsubsection"],
Cell[16701, 497, 224, 4, 38, "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{
Cell[16962, 506, 141, 4, 28, "Subsubsection",
  InitializationCell->True],
Cell[17106, 512, 183, 4, 23, "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{
Cell[17326, 521, 123, 4, 44, "Subsubsection"],
Cell[17452, 527, 559, 9, 83, "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{
Cell[18048, 541, 481, 7, 80, "Subsubsection"],
Cell[18532, 550, 547, 8, 82, "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{
Cell[19116, 563, 373, 6, 44, "Subsubsection"],
Cell[19492, 571, 390, 6, 54, "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{
Cell[19919, 582, 212, 4, 28, "Subsubsection",
  InitializationCell->True],
Cell[20134, 588, 233, 4, 23, "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{
Cell[20404, 597, 386, 7, 46, "Subsubsection"],
Cell[20793, 606, 557, 8, 83, "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{
Cell[21387, 619, 126, 3, 28, "Subsubsection"],
Cell[21516, 624, 266, 6, 23, "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{
Cell[21819, 635, 42, 0, 28, "Subsubsection"],
Cell[21864, 637, 365, 6, 38, "Input",
  InitializationCell->True]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[22278, 649, 32, 0, 30, "Section"],
Cell[22313, 651, 143, 3, 27, "Input",
  InitializationCell->True],
Cell[22459, 656, 103, 2, 27, "Input",
  InitializationCell->True],

Cell[CellGroupData[{
Cell[22587, 662, 436, 6, 74, "Subsubsection"],
Cell[23026, 670, 118, 2, 27, "Input",
  InitializationCell->True],
Cell[23147, 674, 94, 2, 27, "Input",
  InitializationCell->True],
Cell[23244, 678, 502, 10, 107, "Input",
  InitializationCell->True],
Cell[23749, 690, 191, 4, 43, "Input",
  InitializationCell->True],
Cell[23943, 696, 172, 4, 27, "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{
Cell[24152, 705, 440, 7, 60, "Subsubsection"],
Cell[24595, 714, 117, 2, 27, "Input",
  InitializationCell->True],
Cell[24715, 718, 1386, 26, 235, "Input",
  InitializationCell->True],
Cell[26104, 746, 206, 4, 43, "Input",
  InitializationCell->True],
Cell[26313, 752, 191, 4, 43, "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{
Cell[26541, 761, 136, 4, 28, "Subsubsection",
  InitializationCell->True],
Cell[26680, 767, 179, 4, 23, "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{
Cell[26896, 776, 152, 4, 28, "Subsubsection",
  InitializationCell->True],
Cell[27051, 782, 148, 3, 23, "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{
Cell[27236, 790, 334, 6, 60, "Subsubsection"],
Cell[27573, 798, 157, 4, 23, "Input",
  InitializationCell->True],
Cell[27733, 804, 613, 12, 102, "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{
Cell[28383, 821, 189, 4, 28, "Subsubsection"],
Cell[28575, 827, 144, 3, 23, "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{
Cell[28756, 835, 104, 3, 28, "Subsubsection"],
Cell[28863, 840, 108, 2, 23, "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{
Cell[29008, 847, 68, 0, 28, "Subsubsection"],
Cell[29079, 849, 234, 6, 23, "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{
Cell[29350, 860, 133, 3, 28, "Subsubsection"],
Cell[29486, 865, 183, 4, 23, "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{
Cell[29706, 874, 121, 3, 28, "Subsubsection"],
Cell[29830, 879, 186, 4, 23, "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{
Cell[30053, 888, 136, 3, 28, "Subsubsection"],
Cell[30192, 893, 142, 3, 23, "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{
Cell[30371, 901, 124, 4, 28, "Subsubsection",
  InitializationCell->True],
Cell[30498, 907, 148, 3, 23, "Input",
  InitializationCell->True],
Cell[30649, 912, 844, 18, 57, "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{
Cell[31530, 935, 368, 6, 60, "Subsubsection"],
Cell[31901, 943, 166, 3, 23, "Input",
  InitializationCell->True],
Cell[32070, 948, 885, 15, 162, "Input",
  InitializationCell->True],
Cell[32958, 965, 193, 4, 27, "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{
Cell[33188, 974, 193, 4, 44, "Subsubsection"],
Cell[33384, 980, 472, 9, 83, "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{
Cell[33893, 994, 70, 1, 28, "Subsubsection",
  InitializationCell->True],
Cell[33966, 997, 158, 3, 27, "Input",
  InitializationCell->True],
Cell[34127, 1002, 669, 12, 155, "Input",
  InitializationCell->True],
Cell[34799, 1016, 1344, 24, 247, "Input",
  InitializationCell->True],
Cell[36146, 1042, 334, 6, 43, "Input",
  InitializationCell->True],
Cell[36483, 1050, 257, 5, 43, "Input",
  InitializationCell->True],
Cell[36743, 1057, 228, 4, 43, "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{
Cell[37008, 1066, 68, 1, 28, "Subsubsection",
  InitializationCell->True],
Cell[37079, 1069, 136, 3, 27, "Input",
  InitializationCell->True],
Cell[37218, 1074, 647, 13, 123, "Input",
  InitializationCell->True],
Cell[37868, 1089, 246, 5, 43, "Input",
  InitializationCell->True],
Cell[38117, 1096, 200, 4, 43, "Input",
  InitializationCell->True],
Cell[38320, 1102, 176, 3, 43, "Input",
  InitializationCell->True],
Cell[38499, 1107, 190, 4, 43, "Input",
  InitializationCell->True],
Cell[38692, 1113, 166, 3, 43, "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{
Cell[38895, 1121, 118, 3, 28, "Subsubsection"],
Cell[39016, 1126, 161, 3, 27, "Input",
  InitializationCell->True],
Cell[39180, 1131, 183, 3, 43, "Input",
  InitializationCell->True],
Cell[39366, 1136, 3091, 61, 570, "Input",
  InitializationCell->True],
Cell[42460, 1199, 202, 4, 43, "Input",
  InitializationCell->True],
Cell[42665, 1205, 173, 3, 43, "Input",
  InitializationCell->True]
}, Open  ]],

Cell[CellGroupData[{
Cell[42875, 1213, 257, 5, 58, "Subsubsection"],
Cell[43135, 1220, 108, 2, 23, "Input",
  InitializationCell->True],
Cell[43246, 1224, 292, 6, 57, "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{
Cell[43575, 1235, 341, 6, 44, "Subsubsection"],
Cell[43919, 1243, 276, 5, 53, "Input",
  InitializationCell->True],
Cell[44198, 1250, 681, 14, 87, "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{
Cell[44916, 1269, 154, 3, 28, "Subsubsection"],
Cell[45073, 1274, 303, 6, 75, "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{
Cell[45413, 1285, 141, 4, 28, "Subsubsection",
  InitializationCell->True],
Cell[45557, 1291, 1278, 23, 172, "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{
Cell[46872, 1319, 123, 4, 44, "Subsubsection"],
Cell[46998, 1325, 156, 3, 27, "Input",
  InitializationCell->True],
Cell[47157, 1330, 159, 3, 27, "Input",
  InitializationCell->True],
Cell[47319, 1335, 149, 3, 27, "Input",
  InitializationCell->True],
Cell[47471, 1340, 770, 13, 72, "Input",
  InitializationCell->True],
Cell[48244, 1355, 1156, 21, 179, "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{
Cell[49437, 1381, 386, 7, 46, "Subsubsection"],
Cell[49826, 1390, 208, 4, 23, "Input",
  InitializationCell->True],
Cell[50037, 1396, 2166, 37, 269, "Input",
  InitializationCell->True],
Cell[52206, 1435, 223, 4, 42, "Input",
  InitializationCell->True],
Cell[52432, 1441, 1429, 25, 147, "Input",
  InitializationCell->True],
Cell[53864, 1468, 333, 6, 59, "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{
Cell[54234, 1479, 212, 4, 28, "Subsubsection",
  InitializationCell->True],
Cell[54449, 1485, 196, 4, 43, "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{
Cell[54682, 1494, 126, 3, 28, "Subsubsection"],
Cell[54811, 1499, 512, 12, 59, "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{
Cell[55360, 1516, 42, 0, 28, "Subsubsection"],
Cell[55405, 1518, 491, 9, 91, "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{
Cell[55933, 1532, 28, 0, 30, "Subsection"],
Cell[55964, 1534, 102, 2, 27, "Input",
  InitializationCell->True],
Cell[56069, 1538, 60, 4, 42, "Input",
  InitializationCell->True],
Cell[56132, 1544, 58, 1, 27, "Input",
  InitializationCell->True]
}, Closed]]
}, Open  ]]
}
]
*)




(***********************************************************************
End of Mathematica Notebook file.
***********************************************************************)

