(***********************************************************************

                    Mathematica-Compatible Notebook

This notebook can be used on any computer system with Mathematica 4.0,
MathReader 4.0, or any compatible application. The data for the notebook 
starts with the line containing stars above.

To get the notebook into a Mathematica-compatible application, do one of 
the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing the 
word CacheID, otherwise Mathematica-compatible applications may try to 
use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
***********************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[      7935,        228]*)
(*NotebookOutlinePosition[      9125,        266]*)
(*  CellTagsIndexPosition[      9018,        259]*)
(*WindowFrame->Normal*)



Notebook[{

Cell[CellGroupData[{
Cell["Abbreviating contexts", "SubsectionIcon"],

Cell[TextData[Cell[BoxData[
    FormBox[GridBox[{
          {
            RowBox[{
              
              FormBox[\({{\[GothicCapitalZ], t, \[GothicCapitalM], _}, 
                  i\_{\[GothicCapitalF]}, j\_{\[GothicCapitalM]}\),
                "TraditionalForm"], "}"}], 
            RowBox[{
              RowBox[{"is", " ", "a", " ", "shorthand", " ", "for", " ", 
                
                FormBox[\({i\_{\[GothicCapitalZ], t, \[GothicCapitalM], \
\[GothicCapitalF]}, 
                    j\_{\[GothicCapitalZ], t, \[GothicCapitalM], \
\[GothicCapitalM]}\),
                  "TraditionalForm"]}], "}"}]},
          {\(FullContext[{{\[GothicCapitalZ], t, \[GothicCapitalM], #}, 
                i\_{\[GothicCapitalF]}, j\_{\[GothicCapitalM]}}]\), 
            RowBox[{
              RowBox[{\(converts\ to\ the\ full\ form\), ",", " ", 
                
                FormBox[\({i\_{\[GothicCapitalZ], t, \[GothicCapitalM], \
\[GothicCapitalF]}, 
                    j\_{\[GothicCapitalZ], t, \[GothicCapitalM], \
\[GothicCapitalM]}\),
                  "TraditionalForm"]}], "}"}]},
          {\({\[GothicCapitalZ], 
              t, #1, #2}\), \(fills\ slots\ #1, \ #2\ with\ elements\ 1, \ 
            2\ from\ subscripts\ in\ the\ abbreviated\ form\)},
          {
            RowBox[{"ShortContext", "[", " ", 
              
              FormBox[\({i\_{\[GothicCapitalZ], t, \[GothicCapitalM], \
\[GothicCapitalF]}, 
                  j\_{\[GothicCapitalZ], t, \[GothicCapitalM], \
\[GothicCapitalM]}}\),
                "TraditionalForm"], 
              "]"}], \(converts\ to\ the\ short\ form, \ {{\[GothicCapitalZ], 
                t, \[GothicCapitalM], #}, i\_{\[GothicCapitalF]}, 
              j\_{\[GothicCapitalM]}}\)}
          }], TraditionalForm]]]], "DefinitionBox",
  CellTags->{"FullContext", "ShortContext"}],

Cell["\<\
Often, a set of genes-in-context contains genes which are all at \
the same stage, and which share other common components. FullContext[] and \
ShortContext[] convert between the full form, and a shorthand form that lists \
the common components ate the beginning of the list.  All functions in this \
package can take either the full or the shorthand form of the contexts.\
\>", \
"Text"],

Cell["\<\
This defines a context for diploid zygotes, structured by time, sex \
and sex-of-origin:\
\>", "MathCaption"],

Cell[BoxData[
    \(\(DefineContext[\[GothicCapitalZ], {Time, Sex, 
          SexOfOrigin}];\)\)], "Input",
  CellLabel->"In[43]:="],

Cell[TextData[{
  "The short form ",
  Cell[BoxData[
      \({{\[GothicCapitalZ], t, \[GothicCapitalM], #}, 
        i\_{\[GothicCapitalF]}, i\_{\[GothicCapitalM]}, 
        j\_{\[GothicCapitalF]}}\)]],
  " represents the set of genes-in-context where all genes are in male \
zygotes at time t; the single subscript fills the slow # with the \
sex-of-origin of each gene."
}], "Text"],

Cell["For example:", "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[
    \(FullContext[{{\[GothicCapitalZ], t, \[GothicCapitalM], #}, 
        i\_{\[GothicCapitalF]}, i\_{\[GothicCapitalM]}, 
        j\_{\[GothicCapitalF]}}]\)], "Input",
  CellLabel->"In[47]:="],

Cell[BoxData[
    \({i\_{\[GothicCapitalZ], t, \[GothicCapitalM], \[GothicCapitalF]}, 
      i\_{\[GothicCapitalZ], t, \[GothicCapitalM], \[GothicCapitalM]}, 
      j\_{\[GothicCapitalZ], t, \[GothicCapitalM], \[GothicCapitalF]}}\)], \
"Output",
  CellLabel->"Out[47]="]
}, Open  ]],

Cell["\<\
Any number of slots can be given, in any order.  \
\>", "Text"],

Cell[TextData[{
  "The short form ",
  Cell[BoxData[
      \({{\[GothicCapitalZ], t, #2, #1}, 
        i\_{\[GothicCapitalM], \[GothicCapitalF]}, 
        j\_{\[GothicCapitalF], \[GothicCapitalM]}}\)]],
  " represents a set of genes-in-context where all contexts share components  \
{\[GothicCapitalZ],t,#2,#1}:"
}], "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[
    \(FullContext[{{\[GothicCapitalZ], t, #2, #1}, 
        i\_{\[GothicCapitalM], \[GothicCapitalF]}, 
        j\_{\[GothicCapitalF], \[GothicCapitalM]}}]\)], "Input",
  CellLabel->"In[124]:="],

Cell[BoxData[
    \({i\_{\[GothicCapitalZ], t, \[GothicCapitalF], \[GothicCapitalM]}, 
      j\_{\[GothicCapitalZ], t, \[GothicCapitalM], \[GothicCapitalF]}}\)], \
"Output",
  CellLabel->"Out[124]="]
}, Open  ]],

Cell["\<\
The empty slots #1, #2 are filled by the first and second elements \
of the abbreviated subscripts: thus, the order of the abbreviated subscripts \
can differ from the order in the full form (though that may lead to \
confusion).\
\>", "Text"],

Cell["\<\
ShortContext[] represents a set of genes-in-context in the short \
form:\
\>", "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[
    \(ShortContext[{i\_{\[GothicCapitalZ], t, \[GothicCapitalM], \
\[GothicCapitalF]}, 
        i\_{\[GothicCapitalZ], t, \[GothicCapitalM], \[GothicCapitalM]}, 
        j\_{\[GothicCapitalZ], t, \[GothicCapitalM], \[GothicCapitalF]}}]\)], \
"Input",
  CellLabel->"In[110]:="],

Cell[BoxData[
    \({{\[GothicCapitalZ], t, \[GothicCapitalM], #1}, i\_{\[GothicCapitalF]}, 
      i\_{\[GothicCapitalM]}, j\_{\[GothicCapitalF]}}\)], "Output",
  CellLabel->"Out[110]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(ShortContext[{i\_{\[GothicCapitalZ], t, \[GothicCapitalM], \
\[GothicCapitalF]}, 
        i\_{\[GothicCapitalZ], t, \[GothicCapitalF], \[GothicCapitalM]}, 
        j\_{\[GothicCapitalZ], t, \[GothicCapitalM], \[GothicCapitalF]}}]\)], \
"Input",
  CellLabel->"In[111]:="],

Cell[BoxData[
    \({{\[GothicCapitalZ], t, #1, #2}, 
      i\_{\[GothicCapitalM], \[GothicCapitalF]}, 
      i\_{\[GothicCapitalF], \[GothicCapitalM]}, 
      j\_{\[GothicCapitalM], \[GothicCapitalF]}}\)], "Output",
  CellLabel->"Out[111]="]
}, Open  ]],

Cell["\<\
Using ShortContext[] on every set in a complicated expression can \
be slow; FullContext[] is much simpler, but still carries some overhead.  \
Also, operations on contexts can be much faster if it is known that all genes \
share components in common. Thus, functions that act on contexts are defined \
separately for full and short forms. \
\>", "Text"]
}, Open  ]]
},
FrontEndVersion->"4.0 for Macintosh",
ScreenRectangle->{{0, 1024}, {0, 748}},
WindowSize->{520, 626},
WindowMargins->{{Automatic, 98}, {Automatic, 4}},
StyleDefinitions -> "HelpBrowser.nb",
MacintoshSystemPageSetup->"\<\
00<0001804P000000]P2:?oQon82n@960dL5:0?l0080001804P000000]P2:001
0000I00000400`<300000BL?00400@0000000000000006P801T1T00000000000
00000000000000000000000000000000\>"
]


(***********************************************************************
Cached data follows.  If you edit this Notebook file directly, not using
Mathematica, you must remove the line containing CacheID at the top of 
the file.  The cache data will then be recreated when you save this file 
from within Mathematica.
***********************************************************************)

(*CellTagsOutline
CellTagsIndex->{
  "FullContext"->{
    Cell[1789, 53, 1855, 41, 116, "DefinitionBox",
      CellTags->{"FullContext", "ShortContext"}]},
  "ShortContext"->{
    Cell[1789, 53, 1855, 41, 116, "DefinitionBox",
      CellTags->{"FullContext", "ShortContext"}]}
  }
*)

(*CellTagsIndex
CellTagsIndex->{
  {"FullContext", 8769, 249},
  {"ShortContext", 8891, 252}
  }
*)

(*NotebookFileOutline
Notebook[{

Cell[CellGroupData[{
Cell[1739, 51, 47, 0, 36, "SubsectionIcon"],
Cell[1789, 53, 1855, 41, 116, "DefinitionBox",
  CellTags->{"FullContext", "ShortContext"}],
Cell[3647, 96, 399, 7, 64, "Text"],
Cell[4049, 105, 119, 3, 28, "MathCaption"],
Cell[4171, 110, 132, 3, 27, "Input"],
Cell[4306, 115, 384, 9, 36, "Text"],
Cell[4693, 126, 35, 0, 28, "MathCaption"],

Cell[CellGroupData[{
Cell[4753, 130, 207, 4, 27, "Input"],
Cell[4963, 136, 270, 5, 21, "Output"]
}, Open  ]],
Cell[5248, 144, 73, 2, 22, "Text"],
Cell[5324, 148, 331, 8, 42, "MathCaption"],

Cell[CellGroupData[{
Cell[5680, 160, 208, 4, 28, "Input"],
Cell[5891, 166, 199, 4, 21, "Output"]
}, Open  ]],
Cell[6105, 173, 253, 5, 50, "Text"],
Cell[6361, 180, 103, 3, 28, "MathCaption"],

Cell[CellGroupData[{
Cell[6489, 187, 290, 6, 28, "Input"],
Cell[6782, 195, 186, 3, 20, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[7005, 203, 290, 6, 28, "Input"],
Cell[7298, 211, 242, 5, 21, "Output"]
}, Open  ]],
Cell[7555, 219, 364, 6, 64, "Text"]
}, Open  ]]
}
]
*)




(***********************************************************************
End of Mathematica Notebook file.
***********************************************************************)

