(***********************************************************************

                    Mathematica-Compatible Notebook

This notebook can be used on any computer system with Mathematica 4.0,
MathReader 4.0, or any compatible application. The data for the notebook 
starts with the line containing stars above.

To get the notebook into a Mathematica-compatible application, do one of 
the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing the 
word CacheID, otherwise Mathematica-compatible applications may try to 
use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
***********************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[     15967,        467]*)
(*NotebookOutlinePosition[     17527,        517]*)
(*  CellTagsIndexPosition[     17328,        507]*)
(*WindowFrame->Normal*)



Notebook[{

Cell[CellGroupData[{
Cell["Additive selection", "SubsectionIcon"],

Cell[TextData[{
  "In the previous section, the change in allele frequencies and linkage \
disequilibria was calculated for the complete life cycle.  This gave a \
complicated expression in terms of the selection coefficients, ",
  Cell[BoxData[
      \(TraditionalForm\`\[GothicA]\_\[DoubleStruckCapitalU]\)]],
  ".  This simplifies considerably if some explicit selection scheme is used; \
if there are two alleles at each locus; and if the two sexes are equivalent.  \
"
}], "Text"],

Cell[CellGroupData[{

Cell["Defining fitnesses", "SubsubsectionIcon",
  CellTags->"Defining fitnesses"],

Cell[TextData[{
  "For example, suppose that there is additive selection of strength ",
  Cell[BoxData[
      \(TraditionalForm\`s\)]],
  " on locus ",
  Cell[BoxData[
      \(TraditionalForm\`i\)]],
  ":"
}], "MathCaption"],

Cell[BoxData[
    \(\(W\_sex_ := 
        1 + s \((X\_\(i\_{\[GothicCapitalZ], sex, \[GothicCapitalM]}\) + 
                X\_\(i\_{\[GothicCapitalZ], sex, \[GothicCapitalF]}\) - 
                1)\);\)\)], "Input",
  CellLabel->"In[6]:="],

Cell[TextData[{
  "The trait depends on maternal and paternal copies at ",
  Cell[BoxData[
      \(TraditionalForm\`i\)]],
  ":"
}], "MathCaption"],

Cell[BoxData[
    \(\(\[DoubleStruckCapitalW]\_sex_ := {i\_{\[GothicCapitalZ], sex, \
\[GothicCapitalM]}, 
          i\_{\[GothicCapitalZ], sex, \[GothicCapitalF]}};\)\)], "Input",
  CellLabel->"In[7]:="],

Cell["\<\
It is convenient to define the trait and fitness separately for \
each sex, even though they are in fact the same.  The expressions can be \
simplified later.\
\>", "Text"],

Cell["\<\
The mean fitness depends on associations among genes in zygotes, \
and on reference points:\
\>", "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[
    \(wbar = \[LeftAngleBracket]W\_\[GothicCapitalM]\[RightAngleBracket]\)], \
"Input",
  CellLabel->"In[8]:="],

Cell[BoxData[
    \(1 - s + 
      s\ \[GothicCapitalD]\_{i\_{\[GothicCapitalZ], \[GothicCapitalM], \
\[GothicCapitalF]}} + 
      s\ \[GothicCapitalD]\_{i\_{\[GothicCapitalZ], \[GothicCapitalM], \
\[GothicCapitalM]}} + 
      s\ \[WeierstrassP]\_\(i\_{\[GothicCapitalZ], \[GothicCapitalM], \
\[GothicCapitalF]}\) + 
      s\ \[WeierstrassP]\_\(i\_{\[GothicCapitalZ], \[GothicCapitalM], \
\[GothicCapitalM]}\)\)], "Output",
  CellLabel->"Out[8]="]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Defining rules for random union, selection and recombination", \
"SubsubsectionIcon",
  CellTags->"Defining rules"],

Cell["\<\
As in the previous section, define rules connecting the different \
stages of the life cycle, and defining reference points:\
\>", "MathCaption"],

Cell[BoxData[
    \(\(rules = \
\((Recombination[]\[Vee]SymmetricRecombination[]\[Vee]ReferencePointSame[\
\[GothicCapitalG], {\[GothicCapitalA], \
\[GothicCapitalZ]}]\[Vee]ReferencePointZero[{\(\[GothicCapitalG]\^*\), \
\[GothicCapitalG]}]\[Vee]Selection[{Sex}]\[Vee]UnionOfGametes[]\[Vee]\
RandomUnion[\[GothicCapitalG]])\);\)\)], "Input",
  CellLabel->"In[11]:="],

Cell["\<\
The mean contributions in the two sexes are assumed equal, as have \
all the linkage disequilibria, by including SymmetricSexes[].  This must be \
applied after the other rules:\
\>", "Text"],

Cell["\<\
The mean fitness is now a function of mean contributions in the \
gamete pool:\
\>", "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[
    \(wb = \(wbar //. rules\) //. SymmetricSexes[]\)], "Input",
  CellLabel->"In[12]:="],

Cell[BoxData[
    \(1 - s + 
      2\ s\ \[GothicM]\_\(i\_{\[GothicCapitalG], \[GothicCapitalF]}\)\)], \
"Output",
  CellLabel->"Out[12]="]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  "The new mean ",
  Cell[BoxData[
      \(\[GothicM]\_\(j\_{\(\[GothicCapitalG]\^*\), \[GothicCapitalF]}\)\)]]
}], "SubsubsectionIcon",
  CellTags->"New mean"],

Cell["\<\
The new means are the same in males and females, provided that \
selection is symmetric:\
\>", "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(\((\[GothicM]\_\(j\_{\(\[GothicCapitalG]\^*\), \[GothicCapitalM]}\) - \
\[GothicM]\_\(j\_{\(\[GothicCapitalG]\^*\), \[GothicCapitalF]}\))\) //. 
          rules\) //. SymmetricSexes[] // Simplify\)], "Input",
  CellLabel->"In[13]:="],

Cell[BoxData[
    \(1\/2\ \[GothicCapitalD]\_{j\_{\[GothicCapitalG], \[GothicCapitalF]}, \
i\_{\[GothicCapitalG], \[GothicCapitalF]}}\ \((\(-\[GothicA]\_\(\
\[GothicCapitalF], {i\_{\[GothicCapitalZ], \[GothicCapitalF], \
\[GothicCapitalF]}}\)\) - \[GothicA]\_\(\[GothicCapitalF], {i\_{\
\[GothicCapitalZ], \[GothicCapitalF], \[GothicCapitalM]}}\) + \[GothicA]\_\(\
\[GothicCapitalM], {i\_{\[GothicCapitalZ], \[GothicCapitalM], \
\[GothicCapitalF]}}\) + \[GothicA]\_\(\[GothicCapitalM], {i\_{\
\[GothicCapitalZ], \[GothicCapitalM], \[GothicCapitalM]}}\))\)\)], "Output",
  CellLabel->"Out[13]="]
}, Open  ]],

Cell["\<\
The new mean depends on the selection coefficients, averaged over \
the sexes:\
\>", "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[
    \(nm = \(\(\[GothicM]\_\(j\_{\(\[GothicCapitalG]\^*\), \[GothicCapitalM]}\
\) //. rules\) //. SymmetricSexes[]\) /. Symmetrise[Disequilibrium] // 
        Simplify\)], "Input",
  CellLabel->"In[15]:="],

Cell[BoxData[
    \(1\/2\ \((2\ \[GothicM]\_\(j\_{\[GothicCapitalG], \[GothicCapitalF]}\) + \
\[GothicCapitalD]\_{i\_{\[GothicCapitalG], \[GothicCapitalF]}, j\_{\
\[GothicCapitalG], \[GothicCapitalF]}}\ \((\[GothicA]\_\(\[GothicCapitalM], \
{i\_{\[GothicCapitalZ], \[GothicCapitalM], \[GothicCapitalF]}}\) + \[GothicA]\
\_\(\[GothicCapitalM], {i\_{\[GothicCapitalZ], \[GothicCapitalM], \
\[GothicCapitalM]}}\))\))\)\)], "Output",
  CellLabel->"Out[15]="]
}, Open  ]],

Cell[TextData[{
  "Note that ",
  "SymmetricSexes",
  "[] does not apply to the selection coefficients.  Also, \
Symmetrise[Disequilibrium] is used to convert ",
  Cell[BoxData[
      \(\[GothicCapitalD]\_{j\_{\[GothicCapitalG], \[GothicCapitalF]}, i\_{\
\[GothicCapitalG], \[GothicCapitalF]}}\)]],
  " into ",
  Cell[BoxData[
      \(\[GothicCapitalD]\_{i\_{\[GothicCapitalG], \[GothicCapitalF]}, j\_{\
\[GothicCapitalG], \[GothicCapitalF]}}\)]],
  ". "
}], "Text"],

Cell["\<\
Now, calculate the selection coefficients for this specific scheme:\
\
\>", "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[
    \(nm /. {\[GothicA]\_\(sex_, \[DoubleStruckCapitalU]_\) \[RuleDelayed] \
\((MakeSelectionCoefficient[\[DoubleStruckCapitalU], W\_sex]/wb //. 
                rules)\)} // Simplify\)], "Input",
  CellLabel->"In[17]:="],

Cell[BoxData[
    \(\(s\ \[GothicCapitalD]\_{i\_{\[GothicCapitalG], \[GothicCapitalF]}, \
j\_{\[GothicCapitalG], \[GothicCapitalF]}}\)\/\(1 - s + 2\ s\ \[GothicM]\_\(i\
\_{\[GothicCapitalG], \[GothicCapitalF]}\)\) + \[GothicM]\_\(j\_{\
\[GothicCapitalG], \[GothicCapitalF]}\)\)], "Output",
  CellLabel->"Out[17]="]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  "The new linkage disequilibrium ",
  Cell[BoxData[
      \(\[GothicCapitalD]\_{i\_{\(\[GothicCapitalG]\^*\), \[GothicCapitalM]}, \
j\_{\(\[GothicCapitalG]\^*\), \[GothicCapitalM]}}\)]]
}], "SubsubsectionIcon",
  CellTags->"New D"],

Cell["Similarly, the new linkage disequilibrium is:", "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[
    \(nd = \(\(\(\(\[GothicCapitalD]\_{i\_{\(\[GothicCapitalG]\^*\), \
\[GothicCapitalM]}, j\_{\(\[GothicCapitalG]\^*\), \[GothicCapitalM]}} //. 
                  rules\) //. SymmetricSexes[]\) /. 
              Symmetrise[
                Disequilibrium]\) /. {\[GothicA]\_\(sex_, \
\[DoubleStruckCapitalU]_\) \[RuleDelayed] \((MakeSelectionCoefficient[\
\[DoubleStruckCapitalU], W\_sex]/wb //. 
                    rules)\)}\) /. {\[GothicR]\_\({}, {i, j}\) \[Rule] \(1 - \
r\)\/2, \[GothicR]\_\({i}, {j}\) \[Rule] r\/2} // Simplify\)], "Input",
  CellLabel->"In[18]:="],

Cell[BoxData[
    \(\(-\(\(\((\(-1\) + 
                  r)\)\ s\ \[GothicCapitalD]\_{i\_{\[GothicCapitalG], \
\[GothicCapitalF]}, i\_{\[GothicCapitalG], \[GothicCapitalF]}, j\_{\
\[GothicCapitalG], \[GothicCapitalF]}}\)\/\(1 - s + 
              2\ s\ \[GothicM]\_\(i\_{\[GothicCapitalG], \[GothicCapitalF]}\)\
\)\)\) + \[GothicCapitalD]\_{i\_{\[GothicCapitalG], \[GothicCapitalF]}, j\_{\
\[GothicCapitalG], \[GothicCapitalF]}}\ \((1 - 
            r - \(s\^2\ \[GothicCapitalD]\_{i\_{\[GothicCapitalG], \
\[GothicCapitalF]}, i\_{\[GothicCapitalG], \[GothicCapitalF]}}\)\/\((\(-1\) + \
s - 2\ s\ \[GothicM]\_\(i\_{\[GothicCapitalG], \
\[GothicCapitalF]}\))\)\^2)\)\)], "Output",
  CellLabel->"Out[18]="]
}, Open  ]],

Cell["\<\
The last term arises from the shift in mean, and hence of reference \
point.  \
\>", "Text"],

Cell["\<\
This equation is not closed: the pairwise \[GothicCapitalD] depend \
on three-way \[GothicCapitalD], and so on.  An explicit formula can be found \
by assuming that loci are biallelic, and setting the mean, \[GothicM], equal \
to the allele frequency, \[GothicP]:\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(ndb = \(\(nd /. Biallelic[BiallelicPQ \[Rule] True]\) //. 
          rules\) /. \[GothicM]\_\(i\_{\[GothicCapitalG], \
\[GothicCapitalM]}\) \[Rule] \[GothicP]\_\(i\_{\[GothicCapitalG], \
\[GothicCapitalM]}\)\)], "Input",
  CellLabel->"In[19]:="],

Cell[BoxData[
    \(\((\(\(s\) \((1 - r)\)\(\ \)\((1 - 2\ \[GothicP]\_\(i\_{\
\[GothicCapitalG], \[GothicCapitalF]}\))\)\(\ \)\)\/\(1 - s + 2\ s\ \
\[GothicM]\_\(i\_{\[GothicCapitalG], \[GothicCapitalF]}\)\) + \ \((1 - 
              r - \(s\^2\ \[GothicP]\[GothicQ]\_\(i\_{\[GothicCapitalG], \
\[GothicCapitalF]}\)\)\/\((1 - s + 2\ s\ \[GothicM]\_\(i\_{\[GothicCapitalG], \
\[GothicCapitalF]}\))\)\^2)\))\) \[GothicCapitalD]\_{i\_{\[GothicCapitalG], \
\[GothicCapitalF]}, j\_{\[GothicCapitalG], \[GothicCapitalF]}}\)], "Output",
  CellLabel->"Out[19]="]
}, Open  ]],

Cell[TextData[{
  "The option BiallelicPQ\[Rule]True simplifies ",
  Cell[BoxData[
      \(TraditionalForm\`\(\(\[GothicP]\_\[DoubleStruckI]\) \(\[GothicQ]\_\
\[DoubleStruckI]\)\(\ \)\(to\)\(\ \)\)\)]],
  Cell[BoxData[
      \(TraditionalForm\`\[GothicP]\[GothicQ]\_\[DoubleStruckI]\)]]
}], "Text"],

Cell["If selection is weak, the change in disequilibrium is:", "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[
    \(SlowChange[ndb, s, 1]\)], "Input",
  CellLabel->"In[20]:="],

Cell[BoxData[
    \(\((1 - 
            r)\)\ \[GothicCapitalD]\_{i\_{\[GothicCapitalG], \
\[GothicCapitalF]}, j\_{\[GothicCapitalG], \[GothicCapitalF]}} + \((1 - 
            r)\)\ s\ \((1 - 
            2\ \[GothicP]\_\(i\_{\[GothicCapitalG], \[GothicCapitalF]}\))\)\ \
\[GothicCapitalD]\_{i\_{\[GothicCapitalG], \[GothicCapitalF]}, j\_{\
\[GothicCapitalG], \[GothicCapitalF]}}\)], "Output",
  CellLabel->"Out[20]="]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  "The scaled disequilibrium ",
  Cell[BoxData[
      \(\[GothicCapitalD]\_{i\_{\(\[GothicCapitalG]\^*\), \[GothicCapitalM]}, \
j\_{\(\[GothicCapitalG]\^*\), \[GothicCapitalM]}}\/\(\(\[GothicM]\_\(i\_{\(\
\[GothicCapitalG]\^*\), \[GothicCapitalM]}\)\) \((1 - \[GothicM]\_\(i\_{\(\
\[GothicCapitalG]\^*\), \[GothicCapitalM]}\))\)\)\)]]
}], "SubsubsectionIcon",
  CellTags->"Scaled D"],

Cell["\<\
We can easily calculate more complicated quantities.  \
\>", "Text"],

Cell["\<\
For example, the scaled \[GothicCapitalD] changes in a simple \
way:\
\>", "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[
    \(nsd = \((\(\(\(\(\(\(\[GothicCapitalD]\_{i\_{\(\[GothicCapitalG]\^*\), \
\[GothicCapitalM]}, j\_{\(\[GothicCapitalG]\^*\), \[GothicCapitalM]}}\/\(\(\
\[GothicM]\_\(i\_{\(\[GothicCapitalG]\^*\), \[GothicCapitalM]}\)\) \((1 - \
\[GothicM]\_\(i\_{\(\[GothicCapitalG]\^*\), \[GothicCapitalM]}\))\)\) //. 
                          rules\) //. SymmetricSexes[]\) /. 
                      Symmetrise[
                        Disequilibrium]\) /. {\[GothicA]\_\(sex_, \
\[DoubleStruckCapitalU]_\) \[RuleDelayed] \((MakeSelectionCoefficient[\
\[DoubleStruckCapitalU], W\_sex]/wb //. 
                            rules)\)}\) /. {\[GothicR]\_\({}, {i, j}\) \
\[Rule] \(1 - r\)\/2, \[GothicR]\_\({i}, {j}\) \[Rule] r\/2}\) /. 
                Biallelic[]\) //. 
              rules)\) /. {\[GothicM]\_\(i\_{\[GothicCapitalG], _}\) \[Rule] \
\[GothicP]\_\(i\_{\[GothicCapitalG], \[GothicCapitalF]}\)} // 
        Simplify\)], "Input",
  CellLabel->"In[23]:="],

Cell[BoxData[
    \(\(\(\((\((1 - r)\)\ \((1 - s + 
                    2\ s\ \[GothicP]\_\(i\_{\[GothicCapitalG], \
\[GothicCapitalF]}\))\) - 
              s\^2\ \(\[GothicP]\_\(i\_{\[GothicCapitalG], \[GothicCapitalF]}\
\)\) \((1 - \[GothicP]\_\(i\_{\[GothicCapitalG], \[GothicCapitalF]}\))\))\)\(\
\ \)\)\/\(\(\ \)\((1 - s + 
              2\ s\ \[GothicP]\_\(i\_{\[GothicCapitalG], \[GothicCapitalF]}\) \
- s\^2\ \(\[GothicP]\_\(i\_{\[GothicCapitalG], \[GothicCapitalF]}\)\) \((1 - \
\[GothicP]\_\(i\_{\[GothicCapitalG], \[GothicCapitalF]}\))\))\)\(\ \)\)\) \
\[GothicCapitalD]\_{i\_{\[GothicCapitalG], \[GothicCapitalF]}, j\_{\
\[GothicCapitalG], \[GothicCapitalF]}}\/\(\(\[GothicP]\_\(i\_{\
\[GothicCapitalG], \[GothicCapitalF]}\)\) \((1 - \[GothicP]\_\(i\_{\
\[GothicCapitalG], \[GothicCapitalF]}\))\)\)\)], "Output",
  CellLabel->"In[27]:="]
}, Open  ]],

Cell[TextData[{
  "This ratio is the difference in frequency of the neutral marker ",
  Cell[BoxData[
      \(TraditionalForm\`j\)]],
  " between backgrounds defined by locus ",
  Cell[BoxData[
      \(TraditionalForm\`i\)]],
  ".  When ",
  Cell[BoxData[
      \(TraditionalForm\`r = 0\)]],
  ", the scaled \[GothicCapitalD] is unchanged.  "
}], "Text"],

Cell[TextData[{
  "With recombination, the change is only ",
  Cell[BoxData[
      \(TraditionalForm\`O \((s\^2\)\)]],
  "):"
}], "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[
    \(SlowChange[nsd, s, 1] // Simplify\)], "Input",
  CellLabel->"In[29]:="],

Cell[BoxData[
    \(\((1 - 
          r)\) \(\(\ \)\(\[GothicCapitalD]\_{i\_{\[GothicCapitalG], \
\[GothicCapitalF]}, j\_{\[GothicCapitalG], \[GothicCapitalF]}}\)\)\/\(\(\
\[GothicP]\_\(i\_{\[GothicCapitalG], \[GothicCapitalF]}\)\) \((1 - \[GothicP]\
\_\(i\_{\[GothicCapitalG], \[GothicCapitalF]}\))\)\(\ \)\)\)], "Output",
  CellLabel->"Out[29]="]
}, Open  ]]
}, Open  ]]
}, Open  ]]
},
FrontEndVersion->"4.0 for Macintosh",
ScreenRectangle->{{0, 1024}, {0, 748}},
WindowSize->{783, 706},
WindowMargins->{{Automatic, 97}, {Automatic, -1}},
StyleDefinitions -> "HelpBrowser.nb",
MacintoshSystemPageSetup->"\<\
00<0001804P000000]P2:?oQon82n@960dL5:0?l0080001804P000000]P2:001
0000I00000400`<300000BL?00400@0000000000000006P801T1T00000000000
00000000000000000000000000000000\>"
]


(***********************************************************************
Cached data follows.  If you edit this Notebook file directly, not using
Mathematica, you must remove the line containing CacheID at the top of 
the file.  The cache data will then be recreated when you save this file 
from within Mathematica.
***********************************************************************)

(*CellTagsOutline
CellTagsIndex->{
  "Defining fitnesses"->{
    Cell[2296, 66, 81, 1, 24, "SubsubsectionIcon",
      CellTags->"Defining fitnesses"]},
  "Defining rules"->{
    Cell[4164, 133, 121, 2, 24, "SubsubsectionIcon",
      CellTags->"Defining rules"]},
  "New mean"->{
    Cell[5446, 178, 176, 5, 29, "SubsubsectionIcon",
      CellTags->"New mean"]},
  "New D"->{
    Cell[8656, 272, 248, 6, 30, "SubsubsectionIcon",
      CellTags->"New D"]},
  "Scaled D"->{
    Cell[12516, 374, 399, 8, 52, "SubsubsectionIcon",
      CellTags->"Scaled D"]}
  }
*)

(*CellTagsIndex
CellTagsIndex->{
  {"Defining fitnesses", 16809, 488},
  {"Defining rules", 16922, 491},
  {"New mean", 17027, 494},
  {"New D", 17123, 497},
  {"Scaled D", 17219, 500}
  }
*)

(*NotebookFileOutline
Notebook[{

Cell[CellGroupData[{
Cell[1739, 51, 44, 0, 36, "SubsectionIcon"],
Cell[1786, 53, 485, 9, 50, "Text"],

Cell[CellGroupData[{
Cell[2296, 66, 81, 1, 24, "SubsubsectionIcon",
  CellTags->"Defining fitnesses"],
Cell[2380, 69, 224, 8, 28, "MathCaption"],
Cell[2607, 79, 241, 5, 31, "Input"],
Cell[2851, 86, 147, 5, 28, "MathCaption"],
Cell[3001, 93, 204, 4, 28, "Input"],
Cell[3208, 99, 182, 4, 22, "Text"],
Cell[3393, 105, 122, 3, 28, "MathCaption"],

Cell[CellGroupData[{
Cell[3540, 112, 125, 3, 27, "Input"],
Cell[3668, 117, 447, 10, 26, "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[4164, 133, 121, 2, 24, "SubsubsectionIcon",
  CellTags->"Defining rules"],
Cell[4288, 137, 155, 3, 28, "MathCaption"],
Cell[4446, 142, 366, 7, 42, "Input"],
Cell[4815, 151, 201, 4, 36, "Text"],
Cell[5019, 157, 109, 3, 28, "MathCaption"],

Cell[CellGroupData[{
Cell[5153, 164, 102, 2, 27, "Input"],
Cell[5258, 168, 139, 4, 24, "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[5446, 178, 176, 5, 29, "SubsubsectionIcon",
  CellTags->"New mean"],
Cell[5625, 185, 119, 3, 28, "MathCaption"],

Cell[CellGroupData[{
Cell[5769, 192, 255, 4, 34, "Input"],
Cell[6027, 198, 594, 9, 36, "Output"]
}, Open  ]],
Cell[6636, 210, 109, 3, 28, "MathCaption"],

Cell[CellGroupData[{
Cell[6770, 217, 219, 4, 32, "Input"],
Cell[6992, 223, 454, 7, 36, "Output"]
}, Open  ]],
Cell[7461, 233, 466, 13, 46, "Text"],
Cell[7930, 248, 100, 3, 28, "MathCaption"],

Cell[CellGroupData[{
Cell[8055, 255, 235, 4, 28, "Input"],
Cell[8293, 261, 314, 5, 49, "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[8656, 272, 248, 6, 30, "SubsubsectionIcon",
  CellTags->"New D"],
Cell[8907, 280, 68, 0, 28, "MathCaption"],

Cell[CellGroupData[{
Cell[9000, 284, 587, 10, 63, "Input"],
Cell[9590, 296, 705, 12, 53, "Output"]
}, Open  ]],
Cell[10310, 311, 102, 3, 22, "Text"],
Cell[10415, 316, 287, 5, 36, "Text"],

Cell[CellGroupData[{
Cell[10727, 325, 265, 5, 31, "Input"],
Cell[10995, 332, 554, 8, 54, "Output"]
}, Open  ]],
Cell[11564, 343, 298, 7, 23, "Text"],
Cell[11865, 352, 77, 0, 28, "MathCaption"],

Cell[CellGroupData[{
Cell[11967, 356, 79, 2, 27, "Input"],
Cell[12049, 360, 418, 8, 28, "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[12516, 374, 399, 8, 52, "SubsubsectionIcon",
  CellTags->"Scaled D"],
Cell[12918, 384, 78, 2, 22, "Text"],
Cell[12999, 388, 99, 3, 28, "MathCaption"],

Cell[CellGroupData[{
Cell[13123, 395, 968, 16, 112, "Input"],
Cell[14094, 413, 850, 14, 51, "Output"]
}, Open  ]],
Cell[14959, 430, 354, 11, 22, "Text"],
Cell[15316, 443, 144, 5, 30, "MathCaption"],

Cell[CellGroupData[{
Cell[15485, 452, 91, 2, 27, "Input"],
Cell[15579, 456, 348, 6, 50, "Output"]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}
]
*)




(***********************************************************************
End of Mathematica Notebook file.
***********************************************************************)

