(***********************************************************************

                    Mathematica-Compatible Notebook

This notebook can be used on any computer system with Mathematica 4.0,
MathReader 4.0, or any compatible application. The data for the notebook 
starts with the line containing stars above.

To get the notebook into a Mathematica-compatible application, do one of 
the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing the 
word CacheID, otherwise Mathematica-compatible applications may try to 
use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
***********************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[      5788,        180]*)
(*NotebookOutlinePosition[      6809,        214]*)
(*  CellTagsIndexPosition[      6732,        208]*)
(*WindowFrame->Normal*)



Notebook[{

Cell[CellGroupData[{
Cell["Simplifying moments", "SubsectionIcon"],

Cell[TextData[Cell[BoxData[
    FormBox[GridBox[{
          {\(\(MomentSimple[i]\)[U, c, p\&_, \[Delta]p\_l]\), 
            
            RowBox[{\(simplifies\ \(c[i]\)[
                  U]\ by\ supposing\ that\ deme\ 0\ is\ in\ HW\), ",", " ", 
              RowBox[{
              "and", " ", "that", " ", "the", " ", "source", " ", "demes", 
                " ", "are", " ", "in", " ", "linkage", " ", "equilibrium", 
                " ", "and", " ", "HW", " ", 
                RowBox[{
                  RowBox[{"(", 
                    RowBox[{
                      RowBox[{"i", ".", "e", ".", " ", 
                        StyleBox["long",
                          FontSlant->"Italic"]}], 
                      StyleBox[" ",
                        FontSlant->"Italic"], 
                      StyleBox["range",
                        FontSlant->"Italic"], 
                      StyleBox[" ",
                        FontSlant->"Italic"], 
                      StyleBox["migration",
                        FontSlant->"Italic"]}], ")"}], "."}]}]}]},
          {\(\(MomentSimple[i]\)[U, c, 
              p\&_, \[Delta]p\_l, \[Delta]p\_s]\), \(allows\ for\ two\ \
migration\ rates\ from\ demes\ {\(-2\), \(-1\), 0, 1, 2}, \ 
            with\ the\ neighbouring\ demes\ {\(-1\), 
                1}\ now\ with\ the\ same\ c[]' s\ as\ deme\ 0. \)}
          }], TraditionalForm]]]], "DefinitionBox",
  CellTags->"MomentSimple"],

Cell["\<\
MomentSimple[] is used to simplify moments in the model of \
admixture with long- and short-range migration.  It is called by \
MomentNew[]\
\>", "Text"],

Cell["\<\
The deme of interest (labelled 0) is assumed to be in \
Hardy-Weinberg proportions:\
\>", "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(MomentSimple[0]\)[{i, \(j\^*\), k, \(l\^*\)}, c, p\&_, \[Delta]p\_l, 
      \[Delta]p\_s]\)], "Input",
  CellLabel->"In[25]:="],

Cell[BoxData[
    \(c[{i, k}]\ c[{\(j\^*\), \(l\^*\)}]\)], "Output",
  CellLabel->"Out[25]="]
}, Open  ]],

Cell["\<\
The neighbouring demes -1, 1 are assumed to have the same moments \
as deme 0; however, their allele frequencies differ, generating additional \
associations:\
\>", "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(MomentSimple[\(-1\)]\)[{i, j}, c, p\&_, \[Delta]p\_l, \[Delta]p\_s]
      \)], "Input",
  CellLabel->"In[29]:="],

Cell[BoxData[
    \(c[{i, j}] + p\&_\^2\ \[Delta]p\_s[{i}]\ \[Delta]p\_s[{j}]\)], "Output",
  CellLabel->"Out[29]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(MomentSimple[1]\)[{i, j}, c, p\&_, \[Delta]p\_l, \[Delta]p\_s]\)], 
  "Input",
  CellLabel->"In[28]:="],

Cell[BoxData[
    \(c[{i, j}] + \((1 - p\&_)\)\^2\ \[Delta]p\_s[{i}]\ \[Delta]p\_s[{j}]\)], 
  "Output",
  CellLabel->"Out[28]="]
}, Open  ]],

Cell[TextData[{
  "The sources of long-range migrants is assumed to be in Hardy-Weinberg and \
linkage equilibrium, with allele frequencies differing from deme 0 by ",
  Cell[BoxData[
      \(TraditionalForm\`\((1 - p\&_)\) \[Delta]p\_i\)]],
  " or ",
  Cell[BoxData[
      \(TraditionalForm\`\(-p\&_\) \[Delta]p\_i\)]],
  ".  MomentSimple[] then gives the moments defined ",
  StyleBox["relative",
    FontSlant->"Italic"],
  " to the allele frequency in deme 0:"
}], "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(MomentSimple[\(-2\)]\)[{i, \(j\^*\), k, \(l\^*\)}, c, p\&_, 
      \[Delta]p\_l, \[Delta]p\_s]\)], "Input",
  CellLabel->"In[26]:="],

Cell[BoxData[
    \(p\&_\^4\ \[Delta]p\_l[{i}]\ \[Delta]p\_l[{k}]\ 
      \[Delta]p\_l[{\(j\^*\)}]\ \[Delta]p\_l[{\(l\^*\)}]\)], "Output",
  CellLabel->"Out[26]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(MomentSimple[2]\)[{i, \(j\^*\), k, \(l\^*\)}, c, p\&_, \[Delta]p\_l, 
      \[Delta]p\_s]\)], "Input",
  CellLabel->"In[27]:="],

Cell[BoxData[
    \(\((1 - p\&_)\)\^4\ \[Delta]p\_l[{i}]\ \[Delta]p\_l[{k}]\ 
      \[Delta]p\_l[{\(j\^*\)}]\ \[Delta]p\_l[{\(l\^*\)}]\)], "Output",
  CellLabel->"Out[27]="]
}, Open  ]]
}, Open  ]]
},
FrontEndVersion->"4.0 for Macintosh",
ScreenRectangle->{{0, 1024}, {0, 748}},
WindowSize->{956, 721},
WindowMargins->{{-2, Automatic}, {Automatic, 1}},
StyleDefinitions -> "HelpBrowser.nb",
MacintoshSystemPageSetup->"\<\
00<0001804P000000`d26_oRon@3:`8f0dL5N`?N0080001804P000000`d26P01
0000I00000400@410?l00BL?00400@00000000000000000201T1T0000000@000
00000000004000000000000000010000\>"
]


(***********************************************************************
Cached data follows.  If you edit this Notebook file directly, not using
Mathematica, you must remove the line containing CacheID at the top of 
the file.  The cache data will then be recreated when you save this file 
from within Mathematica.
***********************************************************************)

(*CellTagsOutline
CellTagsIndex->{
  "MomentSimple"->{
    Cell[1787, 53, 1439, 30, 86, "DefinitionBox",
      CellTags->"MomentSimple"]}
  }
*)

(*CellTagsIndex
CellTagsIndex->{
  {"MomentSimple", 6623, 201}
  }
*)

(*NotebookFileOutline
Notebook[{

Cell[CellGroupData[{
Cell[1739, 51, 45, 0, 36, "SubsectionIcon"],
Cell[1787, 53, 1439, 30, 86, "DefinitionBox",
  CellTags->"MomentSimple"],
Cell[3229, 85, 163, 4, 22, "Text"],
Cell[3395, 91, 114, 3, 28, "MathCaption"],

Cell[CellGroupData[{
Cell[3534, 98, 149, 3, 29, "Input"],
Cell[3686, 103, 93, 2, 21, "Output"]
}, Open  ]],
Cell[3794, 108, 189, 4, 28, "MathCaption"],

Cell[CellGroupData[{
Cell[4008, 116, 134, 3, 29, "Input"],
Cell[4145, 121, 116, 2, 24, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[4298, 128, 125, 3, 29, "Input"],
Cell[4426, 133, 129, 3, 24, "Output"]
}, Open  ]],
Cell[4570, 139, 483, 12, 44, "MathCaption"],

Cell[CellGroupData[{
Cell[5078, 155, 154, 3, 29, "Input"],
Cell[5235, 160, 163, 3, 24, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[5435, 168, 149, 3, 29, "Input"],
Cell[5587, 173, 173, 3, 24, "Output"]
}, Open  ]]
}, Open  ]]
}
]
*)




(***********************************************************************
End of Mathematica Notebook file.
***********************************************************************)

