(***********************************************************************

                    Mathematica-Compatible Notebook

This notebook can be used on any computer system with Mathematica 4.0,
MathReader 4.0, or any compatible application. The data for the notebook 
starts with the line containing stars above.

To get the notebook into a Mathematica-compatible application, do one of 
the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing the 
word CacheID, otherwise Mathematica-compatible applications may try to 
use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
***********************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[    134287,       2076]*)
(*NotebookOutlinePosition[    135171,       2104]*)
(*  CellTagsIndexPosition[    135127,       2100]*)
(*WindowFrame->Normal*)



Notebook[{

Cell[CellGroupData[{
Cell["A method to avoid", "SubsectionIcon"],

Cell[TextData[{
  "One way of specifying the \[WeierstrassP], \[GothicCapitalD] at each stage \
is to define \[GothicCapitalD] itself as a function.  This works, but is not \
the best method;  a better method is used above.  First, define the reference \
points, ",
  Cell[BoxData[
      \(TraditionalForm\`\[WeierstrassP]\_\[DoubleStruckI]\)]],
  ".  The reference point in the initial gamete pool \[GothicCapitalG] is set \
equal to the means; the reference point in the new gamete pool ",
  Cell[BoxData[
      \(TraditionalForm\`\(\(\[GothicCapitalG]\^*\)\(\ \)\(is\)\(\ \)\)\)]],
  "set to the new means, after selection:"
}], "Text"],

Cell[BoxData[{
    \(\[WeierstrassP]\_\(i_\_{\[GothicCapitalG], sex_}\) := 
      m\_\(i\_{\[GothicCapitalG], sex}\); \[GothicCapitalD]\_{i_\_{\
\[GothicCapitalG], _}} := 0;\), "\[IndentingNewLine]", 
    \(\(\[WeierstrassP]\_\(i_\_{\[GothicCapitalZ], sex_, soo_}\) := \
\[WeierstrassP]\_\(i\_{\[GothicCapitalG], soo}\);\)\), "\[IndentingNewLine]", \

    \(\(\[WeierstrassP]\_\(i_\_{\[GothicCapitalA], x__}\) := \
\[WeierstrassP]\_\(i\_{\[GothicCapitalZ], x}\);\)\), "\[IndentingNewLine]", 
    \(\[WeierstrassP]\_\(i_\_{\(\[GothicCapitalG]\^*\), sex_}\) := \(1\/2\) \
\((\[WeierstrassP]\_\(i\_{\[GothicCapitalA], sex, \[GothicCapitalM]}\) + \
\[WeierstrassP]\_\(i\_{\[GothicCapitalA], sex, \[GothicCapitalF]}\) + \
\[GothicCapitalD]\_{i\_{\[GothicCapitalA], sex, \[GothicCapitalM]}} + \
\[GothicCapitalD]\_{i\_{\[GothicCapitalA], sex, \[GothicCapitalF]}})\)\)}], \
"Input",
  CellLabel->"In[9]:="],

Cell["\<\
Under random union, the zygotic \[GothicCapitalD] are just products \
of the gametic \[GothicCapitalD] in the nmale & female gamete pools:\
\>", \
"Text"],

Cell[BoxData[
    \(\[GothicCapitalD]\_\(\[DoubleStruckCapitalU] : {_\_{\[GothicCapitalZ], \
__} ... }\) := \
\(\[GothicCapitalD]\_\(\((\[DoubleStruckCapitalU]\[CirclePlus]UnionOfGametes)\
\)\(\[CircleDot]\_Sex\){\[GothicCapitalM]}\)\) \[GothicCapitalD]\_\(\((\
\[DoubleStruckCapitalU]\[CirclePlus]UnionOfGametes)\)\(\[CircleDot]\_Sex\){\
\[GothicCapitalF]}\)\)], "Input",
  CellLabel->"In[16]:="],

Cell[TextData[{
  "Fitness depends on the set of genes ",
  Cell[BoxData[
      \(TraditionalForm\`\[DoubleStruckCapitalW]\_\[GothicCapitalM], \ \
\[DoubleStruckCapitalW]\_\[GothicCapitalF]\)]],
  " in zygotes; loci i and j are selected: "
}], "Text"],

Cell[BoxData[
    \(\(\[DoubleStruckCapitalW]\_sex_ := {i\_{\[GothicCapitalZ], sex, \
\[GothicCapitalM]}, i\_{\[GothicCapitalZ], sex, \[GothicCapitalF]}, 
          j\_{\[GothicCapitalZ], sex, \[GothicCapitalM]}, 
          j\_{\[GothicCapitalZ], sex, \[GothicCapitalF]}};\)\)], "Input",
  CellLabel->"In[17]:="],

Cell["Selection involves a sum over selection coefficients:", "Text"],

Cell[BoxData[
    \(\(\[GothicCapitalD]\_\(\[DoubleStruckCapitalU] : \
{_\_{\[GothicCapitalA], sex_, _} ... }\) := 
        Module[{\[DoubleStruckCapitalZ] = \
\[DoubleStruckCapitalU]\[CirclePlus]{{\[GothicCapitalA], 
                      x__} \[LeftArrow] {\[GothicCapitalZ], 
                      x}}, \[DoubleStruckCapitalV]}, \[IndentingNewLine]\((\
\[GothicCapitalD]\_\[DoubleStruckCapitalZ] + \
\[Sum]\+\(\[DoubleStruckCapitalV] \[Element] \
Subsets[\[DoubleStruckCapitalW]\_sex]\)\(a\_\[DoubleStruckCapitalV]\) \((\
\[GothicCapitalD]\_\(\[DoubleStruckCapitalZ]\[Vee]\[DoubleStruckCapitalV]\) - \
\(\[GothicCapitalD]\_\[DoubleStruckCapitalZ]\) \[GothicCapitalD]\_\
\[DoubleStruckCapitalV])\))\)];\)\)], "Input",
  CellLabel->"In[20]:="],

Cell["\<\
The associations after a particular meiotic event {{i,j},{k}} are \
complicated by the change in reference point:\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\[GothicCapitalD]\_{j\_{\(\[GothicCapitalG]\^*\), \[GothicCapitalM]}, k\
\_{\(\[GothicCapitalG]\^*\), \[GothicCapitalM]}}\[CirclePlus]Meiosis[{j}, \
{k}]\)], "Input",
  CellLabel->"In[21]:="],

Cell[BoxData[
    \(\[GothicCapitalD]\_{j\_{\[GothicCapitalG], \[GothicCapitalF]}, i\_{\
\[GothicCapitalG], \[GothicCapitalF]}}\ \[GothicCapitalD]\_{k\_{\
\[GothicCapitalG], \[GothicCapitalM]}, i\_{\[GothicCapitalG], \
\[GothicCapitalM]}}\ a\_{i\_{\[GothicCapitalZ], \[GothicCapitalM], \
\[GothicCapitalF]}, i\_{\[GothicCapitalZ], \[GothicCapitalM], \
\[GothicCapitalM]}} + \[GothicCapitalD]\_{j\_{\[GothicCapitalG], \
\[GothicCapitalF]}, i\_{\[GothicCapitalG], \[GothicCapitalF]}}\ \
\[GothicCapitalD]\_{k\_{\[GothicCapitalG], \[GothicCapitalM]}, j\_{\
\[GothicCapitalG], \[GothicCapitalM]}}\ a\_{i\_{\[GothicCapitalZ], \
\[GothicCapitalM], \[GothicCapitalF]}, j\_{\[GothicCapitalZ], \
\[GothicCapitalM], \[GothicCapitalM]}} + \[GothicCapitalD]\_{j\_{\
\[GothicCapitalG], \[GothicCapitalF]}, j\_{\[GothicCapitalG], \
\[GothicCapitalF]}}\ \[GothicCapitalD]\_{k\_{\[GothicCapitalG], \
\[GothicCapitalM]}, i\_{\[GothicCapitalG], \[GothicCapitalM]}}\ a\_{i\_{\
\[GothicCapitalZ], \[GothicCapitalM], \[GothicCapitalM]}, j\_{\
\[GothicCapitalZ], \[GothicCapitalM], \[GothicCapitalF]}} + \[GothicCapitalD]\
\_{j\_{\[GothicCapitalG], \[GothicCapitalF]}, j\_{\[GothicCapitalG], \
\[GothicCapitalF]}}\ \[GothicCapitalD]\_{k\_{\[GothicCapitalG], \
\[GothicCapitalM]}, j\_{\[GothicCapitalG], \[GothicCapitalM]}}\ a\_{j\_{\
\[GothicCapitalZ], \[GothicCapitalM], \[GothicCapitalF]}, j\_{\
\[GothicCapitalZ], \[GothicCapitalM], \[GothicCapitalM]}} + \[GothicCapitalD]\
\_{k\_{\[GothicCapitalG], \[GothicCapitalM]}, i\_{\[GothicCapitalG], \
\[GothicCapitalM]}}\ \[GothicCapitalD]\_{j\_{\[GothicCapitalG], \
\[GothicCapitalF]}, i\_{\[GothicCapitalG], \[GothicCapitalF]}, j\_{\
\[GothicCapitalG], \[GothicCapitalF]}}\ a\_{i\_{\[GothicCapitalZ], \
\[GothicCapitalM], \[GothicCapitalF]}, i\_{\[GothicCapitalZ], \
\[GothicCapitalM], \[GothicCapitalM]}, j\_{\[GothicCapitalZ], \
\[GothicCapitalM], \[GothicCapitalF]}} + \[GothicCapitalD]\_{j\_{\
\[GothicCapitalG], \[GothicCapitalF]}, i\_{\[GothicCapitalG], \
\[GothicCapitalF]}}\ \[GothicCapitalD]\_{k\_{\[GothicCapitalG], \
\[GothicCapitalM]}, i\_{\[GothicCapitalG], \[GothicCapitalM]}, j\_{\
\[GothicCapitalG], \[GothicCapitalM]}}\ a\_{i\_{\[GothicCapitalZ], \
\[GothicCapitalM], \[GothicCapitalF]}, i\_{\[GothicCapitalZ], \
\[GothicCapitalM], \[GothicCapitalM]}, j\_{\[GothicCapitalZ], \
\[GothicCapitalM], \[GothicCapitalM]}} + \[GothicCapitalD]\_{k\_{\
\[GothicCapitalG], \[GothicCapitalM]}, j\_{\[GothicCapitalG], \
\[GothicCapitalM]}}\ \[GothicCapitalD]\_{j\_{\[GothicCapitalG], \
\[GothicCapitalF]}, i\_{\[GothicCapitalG], \[GothicCapitalF]}, j\_{\
\[GothicCapitalG], \[GothicCapitalF]}}\ a\_{i\_{\[GothicCapitalZ], \
\[GothicCapitalM], \[GothicCapitalF]}, j\_{\[GothicCapitalZ], \
\[GothicCapitalM], \[GothicCapitalF]}, j\_{\[GothicCapitalZ], \
\[GothicCapitalM], \[GothicCapitalM]}} + \[GothicCapitalD]\_{j\_{\
\[GothicCapitalG], \[GothicCapitalF]}, j\_{\[GothicCapitalG], \
\[GothicCapitalF]}}\ \[GothicCapitalD]\_{k\_{\[GothicCapitalG], \
\[GothicCapitalM]}, i\_{\[GothicCapitalG], \[GothicCapitalM]}, j\_{\
\[GothicCapitalG], \[GothicCapitalM]}}\ a\_{i\_{\[GothicCapitalZ], \
\[GothicCapitalM], \[GothicCapitalM]}, j\_{\[GothicCapitalZ], \
\[GothicCapitalM], \[GothicCapitalF]}, j\_{\[GothicCapitalZ], \
\[GothicCapitalM], \[GothicCapitalM]}} + \[GothicCapitalD]\_{j\_{\
\[GothicCapitalG], \[GothicCapitalF]}, i\_{\[GothicCapitalG], \
\[GothicCapitalF]}, j\_{\[GothicCapitalG], \[GothicCapitalF]}}\ \
\[GothicCapitalD]\_{k\_{\[GothicCapitalG], \[GothicCapitalM]}, i\_{\
\[GothicCapitalG], \[GothicCapitalM]}, j\_{\[GothicCapitalG], \
\[GothicCapitalM]}}\ a\_{i\_{\[GothicCapitalZ], \[GothicCapitalM], \
\[GothicCapitalF]}, i\_{\[GothicCapitalZ], \[GothicCapitalM], \
\[GothicCapitalM]}, j\_{\[GothicCapitalZ], \[GothicCapitalM], \
\[GothicCapitalF]}, j\_{\[GothicCapitalZ], \[GothicCapitalM], \
\[GothicCapitalM]}} + \((\[GothicCapitalD]\_{k\_{\[GothicCapitalG], \
\[GothicCapitalM]}, i\_{\[GothicCapitalG], \[GothicCapitalM]}}\ a\_{i\_{\
\[GothicCapitalZ], \[GothicCapitalM], \[GothicCapitalM]}} + \[GothicCapitalD]\
\_{k\_{\[GothicCapitalG], \[GothicCapitalM]}, j\_{\[GothicCapitalG], \
\[GothicCapitalM]}}\ a\_{j\_{\[GothicCapitalZ], \[GothicCapitalM], \
\[GothicCapitalM]}} + \[GothicCapitalD]\_{k\_{\[GothicCapitalG], \
\[GothicCapitalM]}, i\_{\[GothicCapitalG], \[GothicCapitalM]}, j\_{\
\[GothicCapitalG], \[GothicCapitalM]}}\ a\_{i\_{\[GothicCapitalZ], \
\[GothicCapitalM], \[GothicCapitalM]}, j\_{\[GothicCapitalZ], \
\[GothicCapitalM], \[GothicCapitalM]}} + \[GothicCapitalD]\_{i\_{\
\[GothicCapitalG], \[GothicCapitalF]}, j\_{\[GothicCapitalG], \
\[GothicCapitalF]}}\ \[GothicCapitalD]\_{k\_{\[GothicCapitalG], \
\[GothicCapitalM]}, i\_{\[GothicCapitalG], \[GothicCapitalM]}}\ a\_{i\_{\
\[GothicCapitalZ], \[GothicCapitalM], \[GothicCapitalF]}, i\_{\
\[GothicCapitalZ], \[GothicCapitalM], \[GothicCapitalM]}, j\_{\
\[GothicCapitalZ], \[GothicCapitalM], \[GothicCapitalF]}} + \[GothicCapitalD]\
\_{i\_{\[GothicCapitalG], \[GothicCapitalF]}, j\_{\[GothicCapitalG], \
\[GothicCapitalF]}}\ \[GothicCapitalD]\_{k\_{\[GothicCapitalG], \
\[GothicCapitalM]}, j\_{\[GothicCapitalG], \[GothicCapitalM]}}\ a\_{i\_{\
\[GothicCapitalZ], \[GothicCapitalM], \[GothicCapitalF]}, j\_{\
\[GothicCapitalZ], \[GothicCapitalM], \[GothicCapitalF]}, j\_{\
\[GothicCapitalZ], \[GothicCapitalM], \[GothicCapitalM]}} + \[GothicCapitalD]\
\_{i\_{\[GothicCapitalG], \[GothicCapitalF]}, j\_{\[GothicCapitalG], \
\[GothicCapitalF]}}\ \[GothicCapitalD]\_{k\_{\[GothicCapitalG], \
\[GothicCapitalM]}, i\_{\[GothicCapitalG], \[GothicCapitalM]}, j\_{\
\[GothicCapitalG], \[GothicCapitalM]}}\ a\_{i\_{\[GothicCapitalZ], \
\[GothicCapitalM], \[GothicCapitalF]}, i\_{\[GothicCapitalZ], \
\[GothicCapitalM], \[GothicCapitalM]}, j\_{\[GothicCapitalZ], \
\[GothicCapitalM], \[GothicCapitalF]}, j\_{\[GothicCapitalZ], \
\[GothicCapitalM], \[GothicCapitalM]}})\)\ \((m\_\(j\_{\[GothicCapitalG], \
\[GothicCapitalF]}\) + 
            1\/2\ \((\(-\[GothicCapitalD]\_{j\_{\[GothicCapitalG], \
\[GothicCapitalF]}, i\_{\[GothicCapitalG], \[GothicCapitalF]}}\)\ a\_{i\_{\
\[GothicCapitalZ], \[GothicCapitalM], \[GothicCapitalF]}} - \[GothicCapitalD]\
\_{j\_{\[GothicCapitalG], \[GothicCapitalM]}, i\_{\[GothicCapitalG], \
\[GothicCapitalM]}}\ a\_{i\_{\[GothicCapitalZ], \[GothicCapitalM], \
\[GothicCapitalM]}} - \[GothicCapitalD]\_{j\_{\[GothicCapitalG], \
\[GothicCapitalF]}, j\_{\[GothicCapitalG], \[GothicCapitalF]}}\ a\_{j\_{\
\[GothicCapitalZ], \[GothicCapitalM], \[GothicCapitalF]}} - \[GothicCapitalD]\
\_{j\_{\[GothicCapitalG], \[GothicCapitalM]}, j\_{\[GothicCapitalG], \
\[GothicCapitalM]}}\ a\_{j\_{\[GothicCapitalZ], \[GothicCapitalM], \
\[GothicCapitalM]}} - \[GothicCapitalD]\_{j\_{\[GothicCapitalG], \
\[GothicCapitalF]}, i\_{\[GothicCapitalG], \[GothicCapitalF]}, j\_{\
\[GothicCapitalG], \[GothicCapitalF]}}\ a\_{i\_{\[GothicCapitalZ], \
\[GothicCapitalM], \[GothicCapitalF]}, j\_{\[GothicCapitalZ], \
\[GothicCapitalM], \[GothicCapitalF]}} - \[GothicCapitalD]\_{j\_{\
\[GothicCapitalG], \[GothicCapitalM]}, i\_{\[GothicCapitalG], \
\[GothicCapitalM]}, j\_{\[GothicCapitalG], \[GothicCapitalM]}}\ a\_{i\_{\
\[GothicCapitalZ], \[GothicCapitalM], \[GothicCapitalM]}, j\_{\
\[GothicCapitalZ], \[GothicCapitalM], \[GothicCapitalM]}} - \[GothicCapitalD]\
\_{i\_{\[GothicCapitalG], \[GothicCapitalF]}, j\_{\[GothicCapitalG], \
\[GothicCapitalF]}}\ \[GothicCapitalD]\_{j\_{\[GothicCapitalG], \
\[GothicCapitalM]}, i\_{\[GothicCapitalG], \[GothicCapitalM]}}\ a\_{i\_{\
\[GothicCapitalZ], \[GothicCapitalM], \[GothicCapitalF]}, i\_{\
\[GothicCapitalZ], \[GothicCapitalM], \[GothicCapitalM]}, j\_{\
\[GothicCapitalZ], \[GothicCapitalM], \[GothicCapitalF]}} - \[GothicCapitalD]\
\_{i\_{\[GothicCapitalG], \[GothicCapitalM]}, j\_{\[GothicCapitalG], \
\[GothicCapitalM]}}\ \[GothicCapitalD]\_{j\_{\[GothicCapitalG], \
\[GothicCapitalF]}, i\_{\[GothicCapitalG], \[GothicCapitalF]}}\ a\_{i\_{\
\[GothicCapitalZ], \[GothicCapitalM], \[GothicCapitalF]}, i\_{\
\[GothicCapitalZ], \[GothicCapitalM], \[GothicCapitalM]}, j\_{\
\[GothicCapitalZ], \[GothicCapitalM], \[GothicCapitalM]}} - \[GothicCapitalD]\
\_{i\_{\[GothicCapitalG], \[GothicCapitalF]}, j\_{\[GothicCapitalG], \
\[GothicCapitalF]}}\ \[GothicCapitalD]\_{j\_{\[GothicCapitalG], \
\[GothicCapitalM]}, j\_{\[GothicCapitalG], \[GothicCapitalM]}}\ a\_{i\_{\
\[GothicCapitalZ], \[GothicCapitalM], \[GothicCapitalF]}, j\_{\
\[GothicCapitalZ], \[GothicCapitalM], \[GothicCapitalF]}, j\_{\
\[GothicCapitalZ], \[GothicCapitalM], \[GothicCapitalM]}} - \[GothicCapitalD]\
\_{i\_{\[GothicCapitalG], \[GothicCapitalM]}, j\_{\[GothicCapitalG], \
\[GothicCapitalM]}}\ \[GothicCapitalD]\_{j\_{\[GothicCapitalG], \
\[GothicCapitalF]}, j\_{\[GothicCapitalG], \[GothicCapitalF]}}\ a\_{i\_{\
\[GothicCapitalZ], \[GothicCapitalM], \[GothicCapitalM]}, j\_{\
\[GothicCapitalZ], \[GothicCapitalM], \[GothicCapitalF]}, j\_{\
\[GothicCapitalZ], \[GothicCapitalM], \[GothicCapitalM]}} - \[GothicCapitalD]\
\_{i\_{\[GothicCapitalG], \[GothicCapitalM]}, j\_{\[GothicCapitalG], \
\[GothicCapitalM]}}\ \[GothicCapitalD]\_{j\_{\[GothicCapitalG], \
\[GothicCapitalF]}, i\_{\[GothicCapitalG], \[GothicCapitalF]}, j\_{\
\[GothicCapitalG], \[GothicCapitalF]}}\ a\_{i\_{\[GothicCapitalZ], \
\[GothicCapitalM], \[GothicCapitalF]}, i\_{\[GothicCapitalZ], \
\[GothicCapitalM], \[GothicCapitalM]}, j\_{\[GothicCapitalZ], \
\[GothicCapitalM], \[GothicCapitalF]}, j\_{\[GothicCapitalZ], \
\[GothicCapitalM], \[GothicCapitalM]}} - \[GothicCapitalD]\_{i\_{\
\[GothicCapitalG], \[GothicCapitalF]}, j\_{\[GothicCapitalG], \
\[GothicCapitalF]}}\ \[GothicCapitalD]\_{j\_{\[GothicCapitalG], \
\[GothicCapitalM]}, i\_{\[GothicCapitalG], \[GothicCapitalM]}, j\_{\
\[GothicCapitalG], \[GothicCapitalM]}}\ a\_{i\_{\[GothicCapitalZ], \
\[GothicCapitalM], \[GothicCapitalF]}, i\_{\[GothicCapitalZ], \
\[GothicCapitalM], \[GothicCapitalM]}, j\_{\[GothicCapitalZ], \
\[GothicCapitalM], \[GothicCapitalF]}, j\_{\[GothicCapitalZ], \
\[GothicCapitalM], \[GothicCapitalM]}} - 
                  m\_\(j\_{\[GothicCapitalG], \[GothicCapitalF]}\) - 
                  m\_\(j\_{\[GothicCapitalG], \[GothicCapitalM]}\))\))\) + \
\((\[GothicCapitalD]\_{j\_{\[GothicCapitalG], \[GothicCapitalF]}, i\_{\
\[GothicCapitalG], \[GothicCapitalF]}}\ a\_{i\_{\[GothicCapitalZ], \
\[GothicCapitalM], \[GothicCapitalF]}} + \[GothicCapitalD]\_{j\_{\
\[GothicCapitalG], \[GothicCapitalF]}, j\_{\[GothicCapitalG], \
\[GothicCapitalF]}}\ a\_{j\_{\[GothicCapitalZ], \[GothicCapitalM], \
\[GothicCapitalF]}} + \[GothicCapitalD]\_{j\_{\[GothicCapitalG], \
\[GothicCapitalF]}, i\_{\[GothicCapitalG], \[GothicCapitalF]}, j\_{\
\[GothicCapitalG], \[GothicCapitalF]}}\ a\_{i\_{\[GothicCapitalZ], \
\[GothicCapitalM], \[GothicCapitalF]}, j\_{\[GothicCapitalZ], \
\[GothicCapitalM], \[GothicCapitalF]}} + \[GothicCapitalD]\_{i\_{\
\[GothicCapitalG], \[GothicCapitalM]}, j\_{\[GothicCapitalG], \
\[GothicCapitalM]}}\ \[GothicCapitalD]\_{j\_{\[GothicCapitalG], \
\[GothicCapitalF]}, i\_{\[GothicCapitalG], \[GothicCapitalF]}}\ a\_{i\_{\
\[GothicCapitalZ], \[GothicCapitalM], \[GothicCapitalF]}, i\_{\
\[GothicCapitalZ], \[GothicCapitalM], \[GothicCapitalM]}, j\_{\
\[GothicCapitalZ], \[GothicCapitalM], \[GothicCapitalM]}} + \[GothicCapitalD]\
\_{i\_{\[GothicCapitalG], \[GothicCapitalM]}, j\_{\[GothicCapitalG], \
\[GothicCapitalM]}}\ \[GothicCapitalD]\_{j\_{\[GothicCapitalG], \
\[GothicCapitalF]}, j\_{\[GothicCapitalG], \[GothicCapitalF]}}\ a\_{i\_{\
\[GothicCapitalZ], \[GothicCapitalM], \[GothicCapitalM]}, j\_{\
\[GothicCapitalZ], \[GothicCapitalM], \[GothicCapitalF]}, j\_{\
\[GothicCapitalZ], \[GothicCapitalM], \[GothicCapitalM]}} + \[GothicCapitalD]\
\_{i\_{\[GothicCapitalG], \[GothicCapitalM]}, j\_{\[GothicCapitalG], \
\[GothicCapitalM]}}\ \[GothicCapitalD]\_{j\_{\[GothicCapitalG], \
\[GothicCapitalF]}, i\_{\[GothicCapitalG], \[GothicCapitalF]}, j\_{\
\[GothicCapitalG], \[GothicCapitalF]}}\ a\_{i\_{\[GothicCapitalZ], \
\[GothicCapitalM], \[GothicCapitalF]}, i\_{\[GothicCapitalZ], \
\[GothicCapitalM], \[GothicCapitalM]}, j\_{\[GothicCapitalZ], \
\[GothicCapitalM], \[GothicCapitalF]}, j\_{\[GothicCapitalZ], \
\[GothicCapitalM], \[GothicCapitalM]}})\)\ \((1\/2\ \
\((\(-\[GothicCapitalD]\_{k\_{\[GothicCapitalG], \[GothicCapitalF]}, i\_{\
\[GothicCapitalG], \[GothicCapitalF]}}\)\ a\_{i\_{\[GothicCapitalZ], \
\[GothicCapitalM], \[GothicCapitalF]}} - \[GothicCapitalD]\_{k\_{\
\[GothicCapitalG], \[GothicCapitalM]}, i\_{\[GothicCapitalG], \
\[GothicCapitalM]}}\ a\_{i\_{\[GothicCapitalZ], \[GothicCapitalM], \
\[GothicCapitalM]}} - \[GothicCapitalD]\_{k\_{\[GothicCapitalG], \
\[GothicCapitalF]}, j\_{\[GothicCapitalG], \[GothicCapitalF]}}\ a\_{j\_{\
\[GothicCapitalZ], \[GothicCapitalM], \[GothicCapitalF]}} - \[GothicCapitalD]\
\_{k\_{\[GothicCapitalG], \[GothicCapitalM]}, j\_{\[GothicCapitalG], \
\[GothicCapitalM]}}\ a\_{j\_{\[GothicCapitalZ], \[GothicCapitalM], \
\[GothicCapitalM]}} - \[GothicCapitalD]\_{k\_{\[GothicCapitalG], \
\[GothicCapitalF]}, i\_{\[GothicCapitalG], \[GothicCapitalF]}, j\_{\
\[GothicCapitalG], \[GothicCapitalF]}}\ a\_{i\_{\[GothicCapitalZ], \
\[GothicCapitalM], \[GothicCapitalF]}, j\_{\[GothicCapitalZ], \
\[GothicCapitalM], \[GothicCapitalF]}} - \[GothicCapitalD]\_{k\_{\
\[GothicCapitalG], \[GothicCapitalM]}, i\_{\[GothicCapitalG], \
\[GothicCapitalM]}, j\_{\[GothicCapitalG], \[GothicCapitalM]}}\ a\_{i\_{\
\[GothicCapitalZ], \[GothicCapitalM], \[GothicCapitalM]}, j\_{\
\[GothicCapitalZ], \[GothicCapitalM], \[GothicCapitalM]}} - \[GothicCapitalD]\
\_{i\_{\[GothicCapitalG], \[GothicCapitalF]}, j\_{\[GothicCapitalG], \
\[GothicCapitalF]}}\ \[GothicCapitalD]\_{k\_{\[GothicCapitalG], \
\[GothicCapitalM]}, i\_{\[GothicCapitalG], \[GothicCapitalM]}}\ a\_{i\_{\
\[GothicCapitalZ], \[GothicCapitalM], \[GothicCapitalF]}, i\_{\
\[GothicCapitalZ], \[GothicCapitalM], \[GothicCapitalM]}, j\_{\
\[GothicCapitalZ], \[GothicCapitalM], \[GothicCapitalF]}} - \[GothicCapitalD]\
\_{i\_{\[GothicCapitalG], \[GothicCapitalM]}, j\_{\[GothicCapitalG], \
\[GothicCapitalM]}}\ \[GothicCapitalD]\_{k\_{\[GothicCapitalG], \
\[GothicCapitalF]}, i\_{\[GothicCapitalG], \[GothicCapitalF]}}\ a\_{i\_{\
\[GothicCapitalZ], \[GothicCapitalM], \[GothicCapitalF]}, i\_{\
\[GothicCapitalZ], \[GothicCapitalM], \[GothicCapitalM]}, j\_{\
\[GothicCapitalZ], \[GothicCapitalM], \[GothicCapitalM]}} - \[GothicCapitalD]\
\_{i\_{\[GothicCapitalG], \[GothicCapitalF]}, j\_{\[GothicCapitalG], \
\[GothicCapitalF]}}\ \[GothicCapitalD]\_{k\_{\[GothicCapitalG], \
\[GothicCapitalM]}, j\_{\[GothicCapitalG], \[GothicCapitalM]}}\ a\_{i\_{\
\[GothicCapitalZ], \[GothicCapitalM], \[GothicCapitalF]}, j\_{\
\[GothicCapitalZ], \[GothicCapitalM], \[GothicCapitalF]}, j\_{\
\[GothicCapitalZ], \[GothicCapitalM], \[GothicCapitalM]}} - \[GothicCapitalD]\
\_{i\_{\[GothicCapitalG], \[GothicCapitalM]}, j\_{\[GothicCapitalG], \
\[GothicCapitalM]}}\ \[GothicCapitalD]\_{k\_{\[GothicCapitalG], \
\[GothicCapitalF]}, j\_{\[GothicCapitalG], \[GothicCapitalF]}}\ a\_{i\_{\
\[GothicCapitalZ], \[GothicCapitalM], \[GothicCapitalM]}, j\_{\
\[GothicCapitalZ], \[GothicCapitalM], \[GothicCapitalF]}, j\_{\
\[GothicCapitalZ], \[GothicCapitalM], \[GothicCapitalM]}} - \[GothicCapitalD]\
\_{i\_{\[GothicCapitalG], \[GothicCapitalM]}, j\_{\[GothicCapitalG], \
\[GothicCapitalM]}}\ \[GothicCapitalD]\_{k\_{\[GothicCapitalG], \
\[GothicCapitalF]}, i\_{\[GothicCapitalG], \[GothicCapitalF]}, j\_{\
\[GothicCapitalG], \[GothicCapitalF]}}\ a\_{i\_{\[GothicCapitalZ], \
\[GothicCapitalM], \[GothicCapitalF]}, i\_{\[GothicCapitalZ], \
\[GothicCapitalM], \[GothicCapitalM]}, j\_{\[GothicCapitalZ], \
\[GothicCapitalM], \[GothicCapitalF]}, j\_{\[GothicCapitalZ], \
\[GothicCapitalM], \[GothicCapitalM]}} - \[GothicCapitalD]\_{i\_{\
\[GothicCapitalG], \[GothicCapitalF]}, j\_{\[GothicCapitalG], \
\[GothicCapitalF]}}\ \[GothicCapitalD]\_{k\_{\[GothicCapitalG], \
\[GothicCapitalM]}, i\_{\[GothicCapitalG], \[GothicCapitalM]}, j\_{\
\[GothicCapitalG], \[GothicCapitalM]}}\ a\_{i\_{\[GothicCapitalZ], \
\[GothicCapitalM], \[GothicCapitalF]}, i\_{\[GothicCapitalZ], \
\[GothicCapitalM], \[GothicCapitalM]}, j\_{\[GothicCapitalZ], \
\[GothicCapitalM], \[GothicCapitalF]}, j\_{\[GothicCapitalZ], \
\[GothicCapitalM], \[GothicCapitalM]}} - 
                  m\_\(k\_{\[GothicCapitalG], \[GothicCapitalF]}\) - 
                  m\_\(k\_{\[GothicCapitalG], \[GothicCapitalM]}\))\) + 
            m\_\(k\_{\[GothicCapitalG], \[GothicCapitalM]}\))\) + \
\((m\_\(j\_{\[GothicCapitalG], \[GothicCapitalF]}\) + 
            1\/2\ \((\(-\[GothicCapitalD]\_{j\_{\[GothicCapitalG], \
\[GothicCapitalF]}, i\_{\[GothicCapitalG], \[GothicCapitalF]}}\)\ a\_{i\_{\
\[GothicCapitalZ], \[GothicCapitalM], \[GothicCapitalF]}} - \[GothicCapitalD]\
\_{j\_{\[GothicCapitalG], \[GothicCapitalM]}, i\_{\[GothicCapitalG], \
\[GothicCapitalM]}}\ a\_{i\_{\[GothicCapitalZ], \[GothicCapitalM], \
\[GothicCapitalM]}} - \[GothicCapitalD]\_{j\_{\[GothicCapitalG], \
\[GothicCapitalF]}, j\_{\[GothicCapitalG], \[GothicCapitalF]}}\ a\_{j\_{\
\[GothicCapitalZ], \[GothicCapitalM], \[GothicCapitalF]}} - \[GothicCapitalD]\
\_{j\_{\[GothicCapitalG], \[GothicCapitalM]}, j\_{\[GothicCapitalG], \
\[GothicCapitalM]}}\ a\_{j\_{\[GothicCapitalZ], \[GothicCapitalM], \
\[GothicCapitalM]}} - \[GothicCapitalD]\_{j\_{\[GothicCapitalG], \
\[GothicCapitalF]}, i\_{\[GothicCapitalG], \[GothicCapitalF]}, j\_{\
\[GothicCapitalG], \[GothicCapitalF]}}\ a\_{i\_{\[GothicCapitalZ], \
\[GothicCapitalM], \[GothicCapitalF]}, j\_{\[GothicCapitalZ], \
\[GothicCapitalM], \[GothicCapitalF]}} - \[GothicCapitalD]\_{j\_{\
\[GothicCapitalG], \[GothicCapitalM]}, i\_{\[GothicCapitalG], \
\[GothicCapitalM]}, j\_{\[GothicCapitalG], \[GothicCapitalM]}}\ a\_{i\_{\
\[GothicCapitalZ], \[GothicCapitalM], \[GothicCapitalM]}, j\_{\
\[GothicCapitalZ], \[GothicCapitalM], \[GothicCapitalM]}} - \[GothicCapitalD]\
\_{i\_{\[GothicCapitalG], \[GothicCapitalF]}, j\_{\[GothicCapitalG], \
\[GothicCapitalF]}}\ \[GothicCapitalD]\_{j\_{\[GothicCapitalG], \
\[GothicCapitalM]}, i\_{\[GothicCapitalG], \[GothicCapitalM]}}\ a\_{i\_{\
\[GothicCapitalZ], \[GothicCapitalM], \[GothicCapitalF]}, i\_{\
\[GothicCapitalZ], \[GothicCapitalM], \[GothicCapitalM]}, j\_{\
\[GothicCapitalZ], \[GothicCapitalM], \[GothicCapitalF]}} - \[GothicCapitalD]\
\_{i\_{\[GothicCapitalG], \[GothicCapitalM]}, j\_{\[GothicCapitalG], \
\[GothicCapitalM]}}\ \[GothicCapitalD]\_{j\_{\[GothicCapitalG], \
\[GothicCapitalF]}, i\_{\[GothicCapitalG], \[GothicCapitalF]}}\ a\_{i\_{\
\[GothicCapitalZ], \[GothicCapitalM], \[GothicCapitalF]}, i\_{\
\[GothicCapitalZ], \[GothicCapitalM], \[GothicCapitalM]}, j\_{\
\[GothicCapitalZ], \[GothicCapitalM], \[GothicCapitalM]}} - \[GothicCapitalD]\
\_{i\_{\[GothicCapitalG], \[GothicCapitalF]}, j\_{\[GothicCapitalG], \
\[GothicCapitalF]}}\ \[GothicCapitalD]\_{j\_{\[GothicCapitalG], \
\[GothicCapitalM]}, j\_{\[GothicCapitalG], \[GothicCapitalM]}}\ a\_{i\_{\
\[GothicCapitalZ], \[GothicCapitalM], \[GothicCapitalF]}, j\_{\
\[GothicCapitalZ], \[GothicCapitalM], \[GothicCapitalF]}, j\_{\
\[GothicCapitalZ], \[GothicCapitalM], \[GothicCapitalM]}} - \[GothicCapitalD]\
\_{i\_{\[GothicCapitalG], \[GothicCapitalM]}, j\_{\[GothicCapitalG], \
\[GothicCapitalM]}}\ \[GothicCapitalD]\_{j\_{\[GothicCapitalG], \
\[GothicCapitalF]}, j\_{\[GothicCapitalG], \[GothicCapitalF]}}\ a\_{i\_{\
\[GothicCapitalZ], \[GothicCapitalM], \[GothicCapitalM]}, j\_{\
\[GothicCapitalZ], \[GothicCapitalM], \[GothicCapitalF]}, j\_{\
\[GothicCapitalZ], \[GothicCapitalM], \[GothicCapitalM]}} - \[GothicCapitalD]\
\_{i\_{\[GothicCapitalG], \[GothicCapitalM]}, j\_{\[GothicCapitalG], \
\[GothicCapitalM]}}\ \[GothicCapitalD]\_{j\_{\[GothicCapitalG], \
\[GothicCapitalF]}, i\_{\[GothicCapitalG], \[GothicCapitalF]}, j\_{\
\[GothicCapitalG], \[GothicCapitalF]}}\ a\_{i\_{\[GothicCapitalZ], \
\[GothicCapitalM], \[GothicCapitalF]}, i\_{\[GothicCapitalZ], \
\[GothicCapitalM], \[GothicCapitalM]}, j\_{\[GothicCapitalZ], \
\[GothicCapitalM], \[GothicCapitalF]}, j\_{\[GothicCapitalZ], \
\[GothicCapitalM], \[GothicCapitalM]}} - \[GothicCapitalD]\_{i\_{\
\[GothicCapitalG], \[GothicCapitalF]}, j\_{\[GothicCapitalG], \
\[GothicCapitalF]}}\ \[GothicCapitalD]\_{j\_{\[GothicCapitalG], \
\[GothicCapitalM]}, i\_{\[GothicCapitalG], \[GothicCapitalM]}, j\_{\
\[GothicCapitalG], \[GothicCapitalM]}}\ a\_{i\_{\[GothicCapitalZ], \
\[GothicCapitalM], \[GothicCapitalF]}, i\_{\[GothicCapitalZ], \
\[GothicCapitalM], \[GothicCapitalM]}, j\_{\[GothicCapitalZ], \
\[GothicCapitalM], \[GothicCapitalF]}, j\_{\[GothicCapitalZ], \
\[GothicCapitalM], \[GothicCapitalM]}} - 
                  m\_\(j\_{\[GothicCapitalG], \[GothicCapitalF]}\) - 
                  m\_\(j\_{\[GothicCapitalG], \[GothicCapitalM]}\))\))\)\ \
\((1\/2\ \((\(-\[GothicCapitalD]\_{k\_{\[GothicCapitalG], \[GothicCapitalF]}, \
i\_{\[GothicCapitalG], \[GothicCapitalF]}}\)\ a\_{i\_{\[GothicCapitalZ], \
\[GothicCapitalM], \[GothicCapitalF]}} - \[GothicCapitalD]\_{k\_{\
\[GothicCapitalG], \[GothicCapitalM]}, i\_{\[GothicCapitalG], \
\[GothicCapitalM]}}\ a\_{i\_{\[GothicCapitalZ], \[GothicCapitalM], \
\[GothicCapitalM]}} - \[GothicCapitalD]\_{k\_{\[GothicCapitalG], \
\[GothicCapitalF]}, j\_{\[GothicCapitalG], \[GothicCapitalF]}}\ a\_{j\_{\
\[GothicCapitalZ], \[GothicCapitalM], \[GothicCapitalF]}} - \[GothicCapitalD]\
\_{k\_{\[GothicCapitalG], \[GothicCapitalM]}, j\_{\[GothicCapitalG], \
\[GothicCapitalM]}}\ a\_{j\_{\[GothicCapitalZ], \[GothicCapitalM], \
\[GothicCapitalM]}} - \[GothicCapitalD]\_{k\_{\[GothicCapitalG], \
\[GothicCapitalF]}, i\_{\[GothicCapitalG], \[GothicCapitalF]}, j\_{\
\[GothicCapitalG], \[GothicCapitalF]}}\ a\_{i\_{\[GothicCapitalZ], \
\[GothicCapitalM], \[GothicCapitalF]}, j\_{\[GothicCapitalZ], \
\[GothicCapitalM], \[GothicCapitalF]}} - \[GothicCapitalD]\_{k\_{\
\[GothicCapitalG], \[GothicCapitalM]}, i\_{\[GothicCapitalG], \
\[GothicCapitalM]}, j\_{\[GothicCapitalG], \[GothicCapitalM]}}\ a\_{i\_{\
\[GothicCapitalZ], \[GothicCapitalM], \[GothicCapitalM]}, j\_{\
\[GothicCapitalZ], \[GothicCapitalM], \[GothicCapitalM]}} - \[GothicCapitalD]\
\_{i\_{\[GothicCapitalG], \[GothicCapitalF]}, j\_{\[GothicCapitalG], \
\[GothicCapitalF]}}\ \[GothicCapitalD]\_{k\_{\[GothicCapitalG], \
\[GothicCapitalM]}, i\_{\[GothicCapitalG], \[GothicCapitalM]}}\ a\_{i\_{\
\[GothicCapitalZ], \[GothicCapitalM], \[GothicCapitalF]}, i\_{\
\[GothicCapitalZ], \[GothicCapitalM], \[GothicCapitalM]}, j\_{\
\[GothicCapitalZ], \[GothicCapitalM], \[GothicCapitalF]}} - \[GothicCapitalD]\
\_{i\_{\[GothicCapitalG], \[GothicCapitalM]}, j\_{\[GothicCapitalG], \
\[GothicCapitalM]}}\ \[GothicCapitalD]\_{k\_{\[GothicCapitalG], \
\[GothicCapitalF]}, i\_{\[GothicCapitalG], \[GothicCapitalF]}}\ a\_{i\_{\
\[GothicCapitalZ], \[GothicCapitalM], \[GothicCapitalF]}, i\_{\
\[GothicCapitalZ], \[GothicCapitalM], \[GothicCapitalM]}, j\_{\
\[GothicCapitalZ], \[GothicCapitalM], \[GothicCapitalM]}} - \[GothicCapitalD]\
\_{i\_{\[GothicCapitalG], \[GothicCapitalF]}, j\_{\[GothicCapitalG], \
\[GothicCapitalF]}}\ \[GothicCapitalD]\_{k\_{\[GothicCapitalG], \
\[GothicCapitalM]}, j\_{\[GothicCapitalG], \[GothicCapitalM]}}\ a\_{i\_{\
\[GothicCapitalZ], \[GothicCapitalM], \[GothicCapitalF]}, j\_{\
\[GothicCapitalZ], \[GothicCapitalM], \[GothicCapitalF]}, j\_{\
\[GothicCapitalZ], \[GothicCapitalM], \[GothicCapitalM]}} - \[GothicCapitalD]\
\_{i\_{\[GothicCapitalG], \[GothicCapitalM]}, j\_{\[GothicCapitalG], \
\[GothicCapitalM]}}\ \[GothicCapitalD]\_{k\_{\[GothicCapitalG], \
\[GothicCapitalF]}, j\_{\[GothicCapitalG], \[GothicCapitalF]}}\ a\_{i\_{\
\[GothicCapitalZ], \[GothicCapitalM], \[GothicCapitalM]}, j\_{\
\[GothicCapitalZ], \[GothicCapitalM], \[GothicCapitalF]}, j\_{\
\[GothicCapitalZ], \[GothicCapitalM], \[GothicCapitalM]}} - \[GothicCapitalD]\
\_{i\_{\[GothicCapitalG], \[GothicCapitalM]}, j\_{\[GothicCapitalG], \
\[GothicCapitalM]}}\ \[GothicCapitalD]\_{k\_{\[GothicCapitalG], \
\[GothicCapitalF]}, i\_{\[GothicCapitalG], \[GothicCapitalF]}, j\_{\
\[GothicCapitalG], \[GothicCapitalF]}}\ a\_{i\_{\[GothicCapitalZ], \
\[GothicCapitalM], \[GothicCapitalF]}, i\_{\[GothicCapitalZ], \
\[GothicCapitalM], \[GothicCapitalM]}, j\_{\[GothicCapitalZ], \
\[GothicCapitalM], \[GothicCapitalF]}, j\_{\[GothicCapitalZ], \
\[GothicCapitalM], \[GothicCapitalM]}} - \[GothicCapitalD]\_{i\_{\
\[GothicCapitalG], \[GothicCapitalF]}, j\_{\[GothicCapitalG], \
\[GothicCapitalF]}}\ \[GothicCapitalD]\_{k\_{\[GothicCapitalG], \
\[GothicCapitalM]}, i\_{\[GothicCapitalG], \[GothicCapitalM]}, j\_{\
\[GothicCapitalG], \[GothicCapitalM]}}\ a\_{i\_{\[GothicCapitalZ], \
\[GothicCapitalM], \[GothicCapitalF]}, i\_{\[GothicCapitalZ], \
\[GothicCapitalM], \[GothicCapitalM]}, j\_{\[GothicCapitalZ], \
\[GothicCapitalM], \[GothicCapitalF]}, j\_{\[GothicCapitalZ], \
\[GothicCapitalM], \[GothicCapitalM]}} - 
                  m\_\(k\_{\[GothicCapitalG], \[GothicCapitalF]}\) - 
                  m\_\(k\_{\[GothicCapitalG], \[GothicCapitalM]}\))\) + 
            m\_\(k\_{\[GothicCapitalG], \[GothicCapitalM]}\))\)\)], "Output",
  CellLabel->"Out[21]="]
}, Closed]],

Cell["This is the sum over all possible meiotic events:", "Text"],

Cell[BoxData[
    \(\(\[GothicCapitalD]new\_\(\[DoubleStruckCapitalU] : {_\_{\(\
\[GothicCapitalG]\^*\), sex_} ... }\) := \((\[Sum]\+\(\[DoubleStruckCapitalA] \
\[Element] Subsets[\[DoubleStruckCapitalU]]\)\[GothicCapitalD]\_\(\
\[DoubleStruckCapitalA], \[DoubleStruckCapitalU]\[Backslash]\
\[DoubleStruckCapitalA]\)\ r\_\(\[Gamma][\[DoubleStruckCapitalA]], \[Gamma][\
\[DoubleStruckCapitalU]\[Backslash]\[DoubleStruckCapitalA]]\))\) /. \
\[GothicCapitalD]\_\(\[DoubleStruckCapitalA]_, \[DoubleStruckCapitalB]_\) \
\[RuleDelayed] \((\[GothicCapitalD]\_\(\[DoubleStruckCapitalA]\[Vee]\
\[DoubleStruckCapitalB]\)\[CirclePlus]Meiosis[\[Gamma][\[DoubleStruckCapitalA]\
], \[Gamma][\[DoubleStruckCapitalB]]])\);\)\)], "Input",
  CellLabel->"In[26]:="],

Cell["\<\
The disequilibrium has to be given a new name, because otherwise \
the rule for \[GothicCapitalD] is applied indefinitely, giving an infinite \
regress.\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\[GothicCapitalD]new\_{j\_{\(\[GothicCapitalG]\^*\), \
\[GothicCapitalM]}, k\_{\(\[GothicCapitalG]\^*\), \[GothicCapitalM]}}\)], \
"Input",
  CellLabel->"In[27]:="],

Cell[BoxData[
    \(\((\[GothicCapitalD]\_{j\_{\[GothicCapitalG], \[GothicCapitalM]}, k\_{\
\[GothicCapitalG], \[GothicCapitalM]}} + \[GothicCapitalD]\_{j\_{\
\[GothicCapitalG], \[GothicCapitalM]}, k\_{\[GothicCapitalG], \
\[GothicCapitalM]}, i\_{\[GothicCapitalG], \[GothicCapitalM]}}\ a\_{i\_{\
\[GothicCapitalZ], \[GothicCapitalM], \[GothicCapitalM]}} + \[GothicCapitalD]\
\_{j\_{\[GothicCapitalG], \[GothicCapitalM]}, k\_{\[GothicCapitalG], \
\[GothicCapitalM]}, j\_{\[GothicCapitalG], \[GothicCapitalM]}}\ a\_{j\_{\
\[GothicCapitalZ], \[GothicCapitalM], \[GothicCapitalM]}} + \((\(-\
\[GothicCapitalD]\_{i\_{\[GothicCapitalG], \[GothicCapitalM]}, j\_{\
\[GothicCapitalG], \[GothicCapitalM]}}\)\ \[GothicCapitalD]\_{j\_{\
\[GothicCapitalG], \[GothicCapitalM]}, k\_{\[GothicCapitalG], \
\[GothicCapitalM]}} + \[GothicCapitalD]\_{j\_{\[GothicCapitalG], \
\[GothicCapitalM]}, k\_{\[GothicCapitalG], \[GothicCapitalM]}, i\_{\
\[GothicCapitalG], \[GothicCapitalM]}, j\_{\[GothicCapitalG], \
\[GothicCapitalM]}})\)\ a\_{i\_{\[GothicCapitalZ], \[GothicCapitalM], \
\[GothicCapitalM]}, j\_{\[GothicCapitalZ], \[GothicCapitalM], \
\[GothicCapitalM]}} + \[GothicCapitalD]\_{i\_{\[GothicCapitalG], \
\[GothicCapitalF]}, j\_{\[GothicCapitalG], \[GothicCapitalF]}}\ \
\[GothicCapitalD]\_{j\_{\[GothicCapitalG], \[GothicCapitalM]}, k\_{\
\[GothicCapitalG], \[GothicCapitalM]}, i\_{\[GothicCapitalG], \
\[GothicCapitalM]}}\ a\_{i\_{\[GothicCapitalZ], \[GothicCapitalM], \
\[GothicCapitalF]}, i\_{\[GothicCapitalZ], \[GothicCapitalM], \
\[GothicCapitalM]}, j\_{\[GothicCapitalZ], \[GothicCapitalM], \
\[GothicCapitalF]}} + \[GothicCapitalD]\_{i\_{\[GothicCapitalG], \
\[GothicCapitalF]}, j\_{\[GothicCapitalG], \[GothicCapitalF]}}\ \
\[GothicCapitalD]\_{j\_{\[GothicCapitalG], \[GothicCapitalM]}, k\_{\
\[GothicCapitalG], \[GothicCapitalM]}, j\_{\[GothicCapitalG], \
\[GothicCapitalM]}}\ a\_{i\_{\[GothicCapitalZ], \[GothicCapitalM], \
\[GothicCapitalF]}, j\_{\[GothicCapitalZ], \[GothicCapitalM], \
\[GothicCapitalF]}, j\_{\[GothicCapitalZ], \[GothicCapitalM], \
\[GothicCapitalM]}} + \((\(-\[GothicCapitalD]\_{i\_{\[GothicCapitalG], \
\[GothicCapitalF]}, j\_{\[GothicCapitalG], \[GothicCapitalF]}}\)\ \
\[GothicCapitalD]\_{i\_{\[GothicCapitalG], \[GothicCapitalM]}, j\_{\
\[GothicCapitalG], \[GothicCapitalM]}}\ \[GothicCapitalD]\_{j\_{\
\[GothicCapitalG], \[GothicCapitalM]}, k\_{\[GothicCapitalG], \
\[GothicCapitalM]}} + \[GothicCapitalD]\_{i\_{\[GothicCapitalG], \
\[GothicCapitalF]}, j\_{\[GothicCapitalG], \[GothicCapitalF]}}\ \
\[GothicCapitalD]\_{j\_{\[GothicCapitalG], \[GothicCapitalM]}, k\_{\
\[GothicCapitalG], \[GothicCapitalM]}, i\_{\[GothicCapitalG], \
\[GothicCapitalM]}, j\_{\[GothicCapitalG], \[GothicCapitalM]}})\)\ a\_{i\_{\
\[GothicCapitalZ], \[GothicCapitalM], \[GothicCapitalF]}, i\_{\
\[GothicCapitalZ], \[GothicCapitalM], \[GothicCapitalM]}, j\_{\
\[GothicCapitalZ], \[GothicCapitalM], \[GothicCapitalF]}, j\_{\
\[GothicCapitalZ], \[GothicCapitalM], \[GothicCapitalM]}} + \((\
\[GothicCapitalD]\_{k\_{\[GothicCapitalG], \[GothicCapitalM]}, i\_{\
\[GothicCapitalG], \[GothicCapitalM]}}\ a\_{i\_{\[GothicCapitalZ], \
\[GothicCapitalM], \[GothicCapitalM]}} + \[GothicCapitalD]\_{k\_{\
\[GothicCapitalG], \[GothicCapitalM]}, j\_{\[GothicCapitalG], \
\[GothicCapitalM]}}\ a\_{j\_{\[GothicCapitalZ], \[GothicCapitalM], \
\[GothicCapitalM]}} + \[GothicCapitalD]\_{k\_{\[GothicCapitalG], \
\[GothicCapitalM]}, i\_{\[GothicCapitalG], \[GothicCapitalM]}, j\_{\
\[GothicCapitalG], \[GothicCapitalM]}}\ a\_{i\_{\[GothicCapitalZ], \
\[GothicCapitalM], \[GothicCapitalM]}, j\_{\[GothicCapitalZ], \
\[GothicCapitalM], \[GothicCapitalM]}} + \[GothicCapitalD]\_{i\_{\
\[GothicCapitalG], \[GothicCapitalF]}, j\_{\[GothicCapitalG], \
\[GothicCapitalF]}}\ \[GothicCapitalD]\_{k\_{\[GothicCapitalG], \
\[GothicCapitalM]}, i\_{\[GothicCapitalG], \[GothicCapitalM]}}\ a\_{i\_{\
\[GothicCapitalZ], \[GothicCapitalM], \[GothicCapitalF]}, i\_{\
\[GothicCapitalZ], \[GothicCapitalM], \[GothicCapitalM]}, j\_{\
\[GothicCapitalZ], \[GothicCapitalM], \[GothicCapitalF]}} + \[GothicCapitalD]\
\_{i\_{\[GothicCapitalG], \[GothicCapitalF]}, j\_{\[GothicCapitalG], \
\[GothicCapitalF]}}\ \[GothicCapitalD]\_{k\_{\[GothicCapitalG], \
\[GothicCapitalM]}, j\_{\[GothicCapitalG], \[GothicCapitalM]}}\ a\_{i\_{\
\[GothicCapitalZ], \[GothicCapitalM], \[GothicCapitalF]}, j\_{\
\[GothicCapitalZ], \[GothicCapitalM], \[GothicCapitalF]}, j\_{\
\[GothicCapitalZ], \[GothicCapitalM], \[GothicCapitalM]}} + \[GothicCapitalD]\
\_{i\_{\[GothicCapitalG], \[GothicCapitalF]}, j\_{\[GothicCapitalG], \
\[GothicCapitalF]}}\ \[GothicCapitalD]\_{k\_{\[GothicCapitalG], \
\[GothicCapitalM]}, i\_{\[GothicCapitalG], \[GothicCapitalM]}, j\_{\
\[GothicCapitalG], \[GothicCapitalM]}}\ a\_{i\_{\[GothicCapitalZ], \
\[GothicCapitalM], \[GothicCapitalF]}, i\_{\[GothicCapitalZ], \
\[GothicCapitalM], \[GothicCapitalM]}, j\_{\[GothicCapitalZ], \
\[GothicCapitalM], \[GothicCapitalF]}, j\_{\[GothicCapitalZ], \
\[GothicCapitalM], \[GothicCapitalM]}})\)\ \((1\/2\ \
\((\(-\[GothicCapitalD]\_{j\_{\[GothicCapitalG], \[GothicCapitalF]}, i\_{\
\[GothicCapitalG], \[GothicCapitalF]}}\)\ a\_{i\_{\[GothicCapitalZ], \
\[GothicCapitalM], \[GothicCapitalF]}} - \[GothicCapitalD]\_{j\_{\
\[GothicCapitalG], \[GothicCapitalM]}, i\_{\[GothicCapitalG], \
\[GothicCapitalM]}}\ a\_{i\_{\[GothicCapitalZ], \[GothicCapitalM], \
\[GothicCapitalM]}} - \[GothicCapitalD]\_{j\_{\[GothicCapitalG], \
\[GothicCapitalF]}, j\_{\[GothicCapitalG], \[GothicCapitalF]}}\ a\_{j\_{\
\[GothicCapitalZ], \[GothicCapitalM], \[GothicCapitalF]}} - \[GothicCapitalD]\
\_{j\_{\[GothicCapitalG], \[GothicCapitalM]}, j\_{\[GothicCapitalG], \
\[GothicCapitalM]}}\ a\_{j\_{\[GothicCapitalZ], \[GothicCapitalM], \
\[GothicCapitalM]}} - \[GothicCapitalD]\_{j\_{\[GothicCapitalG], \
\[GothicCapitalF]}, i\_{\[GothicCapitalG], \[GothicCapitalF]}, j\_{\
\[GothicCapitalG], \[GothicCapitalF]}}\ a\_{i\_{\[GothicCapitalZ], \
\[GothicCapitalM], \[GothicCapitalF]}, j\_{\[GothicCapitalZ], \
\[GothicCapitalM], \[GothicCapitalF]}} - \[GothicCapitalD]\_{j\_{\
\[GothicCapitalG], \[GothicCapitalM]}, i\_{\[GothicCapitalG], \
\[GothicCapitalM]}, j\_{\[GothicCapitalG], \[GothicCapitalM]}}\ a\_{i\_{\
\[GothicCapitalZ], \[GothicCapitalM], \[GothicCapitalM]}, j\_{\
\[GothicCapitalZ], \[GothicCapitalM], \[GothicCapitalM]}} - \[GothicCapitalD]\
\_{i\_{\[GothicCapitalG], \[GothicCapitalF]}, j\_{\[GothicCapitalG], \
\[GothicCapitalF]}}\ \[GothicCapitalD]\_{j\_{\[GothicCapitalG], \
\[GothicCapitalM]}, i\_{\[GothicCapitalG], \[GothicCapitalM]}}\ a\_{i\_{\
\[GothicCapitalZ], \[GothicCapitalM], \[GothicCapitalF]}, i\_{\
\[GothicCapitalZ], \[GothicCapitalM], \[GothicCapitalM]}, j\_{\
\[GothicCapitalZ], \[GothicCapitalM], \[GothicCapitalF]}} - \[GothicCapitalD]\
\_{i\_{\[GothicCapitalG], \[GothicCapitalM]}, j\_{\[GothicCapitalG], \
\[GothicCapitalM]}}\ \[GothicCapitalD]\_{j\_{\[GothicCapitalG], \
\[GothicCapitalF]}, i\_{\[GothicCapitalG], \[GothicCapitalF]}}\ a\_{i\_{\
\[GothicCapitalZ], \[GothicCapitalM], \[GothicCapitalF]}, i\_{\
\[GothicCapitalZ], \[GothicCapitalM], \[GothicCapitalM]}, j\_{\
\[GothicCapitalZ], \[GothicCapitalM], \[GothicCapitalM]}} - \[GothicCapitalD]\
\_{i\_{\[GothicCapitalG], \[GothicCapitalF]}, j\_{\[GothicCapitalG], \
\[GothicCapitalF]}}\ \[GothicCapitalD]\_{j\_{\[GothicCapitalG], \
\[GothicCapitalM]}, j\_{\[GothicCapitalG], \[GothicCapitalM]}}\ a\_{i\_{\
\[GothicCapitalZ], \[GothicCapitalM], \[GothicCapitalF]}, j\_{\
\[GothicCapitalZ], \[GothicCapitalM], \[GothicCapitalF]}, j\_{\
\[GothicCapitalZ], \[GothicCapitalM], \[GothicCapitalM]}} - \[GothicCapitalD]\
\_{i\_{\[GothicCapitalG], \[GothicCapitalM]}, j\_{\[GothicCapitalG], \
\[GothicCapitalM]}}\ \[GothicCapitalD]\_{j\_{\[GothicCapitalG], \
\[GothicCapitalF]}, j\_{\[GothicCapitalG], \[GothicCapitalF]}}\ a\_{i\_{\
\[GothicCapitalZ], \[GothicCapitalM], \[GothicCapitalM]}, j\_{\
\[GothicCapitalZ], \[GothicCapitalM], \[GothicCapitalF]}, j\_{\
\[GothicCapitalZ], \[GothicCapitalM], \[GothicCapitalM]}} - \[GothicCapitalD]\
\_{i\_{\[GothicCapitalG], \[GothicCapitalM]}, j\_{\[GothicCapitalG], \
\[GothicCapitalM]}}\ \[GothicCapitalD]\_{j\_{\[GothicCapitalG], \
\[GothicCapitalF]}, i\_{\[GothicCapitalG], \[GothicCapitalF]}, j\_{\
\[GothicCapitalG], \[GothicCapitalF]}}\ a\_{i\_{\[GothicCapitalZ], \
\[GothicCapitalM], \[GothicCapitalF]}, i\_{\[GothicCapitalZ], \
\[GothicCapitalM], \[GothicCapitalM]}, j\_{\[GothicCapitalZ], \
\[GothicCapitalM], \[GothicCapitalF]}, j\_{\[GothicCapitalZ], \
\[GothicCapitalM], \[GothicCapitalM]}} - \[GothicCapitalD]\_{i\_{\
\[GothicCapitalG], \[GothicCapitalF]}, j\_{\[GothicCapitalG], \
\[GothicCapitalF]}}\ \[GothicCapitalD]\_{j\_{\[GothicCapitalG], \
\[GothicCapitalM]}, i\_{\[GothicCapitalG], \[GothicCapitalM]}, j\_{\
\[GothicCapitalG], \[GothicCapitalM]}}\ a\_{i\_{\[GothicCapitalZ], \
\[GothicCapitalM], \[GothicCapitalF]}, i\_{\[GothicCapitalZ], \
\[GothicCapitalM], \[GothicCapitalM]}, j\_{\[GothicCapitalZ], \
\[GothicCapitalM], \[GothicCapitalF]}, j\_{\[GothicCapitalZ], \
\[GothicCapitalM], \[GothicCapitalM]}} - 
                        m\_\(j\_{\[GothicCapitalG], \[GothicCapitalF]}\) - 
                        m\_\(j\_{\[GothicCapitalG], \[GothicCapitalM]}\))\) + 
                  m\_\(j\_{\[GothicCapitalG], \[GothicCapitalM]}\))\) + \((\
\[GothicCapitalD]\_{j\_{\[GothicCapitalG], \[GothicCapitalM]}, i\_{\
\[GothicCapitalG], \[GothicCapitalM]}}\ a\_{i\_{\[GothicCapitalZ], \
\[GothicCapitalM], \[GothicCapitalM]}} + \[GothicCapitalD]\_{j\_{\
\[GothicCapitalG], \[GothicCapitalM]}, j\_{\[GothicCapitalG], \
\[GothicCapitalM]}}\ a\_{j\_{\[GothicCapitalZ], \[GothicCapitalM], \
\[GothicCapitalM]}} + \[GothicCapitalD]\_{j\_{\[GothicCapitalG], \
\[GothicCapitalM]}, i\_{\[GothicCapitalG], \[GothicCapitalM]}, j\_{\
\[GothicCapitalG], \[GothicCapitalM]}}\ a\_{i\_{\[GothicCapitalZ], \
\[GothicCapitalM], \[GothicCapitalM]}, j\_{\[GothicCapitalZ], \
\[GothicCapitalM], \[GothicCapitalM]}} + \[GothicCapitalD]\_{i\_{\
\[GothicCapitalG], \[GothicCapitalF]}, j\_{\[GothicCapitalG], \
\[GothicCapitalF]}}\ \[GothicCapitalD]\_{j\_{\[GothicCapitalG], \
\[GothicCapitalM]}, i\_{\[GothicCapitalG], \[GothicCapitalM]}}\ a\_{i\_{\
\[GothicCapitalZ], \[GothicCapitalM], \[GothicCapitalF]}, i\_{\
\[GothicCapitalZ], \[GothicCapitalM], \[GothicCapitalM]}, j\_{\
\[GothicCapitalZ], \[GothicCapitalM], \[GothicCapitalF]}} + \[GothicCapitalD]\
\_{i\_{\[GothicCapitalG], \[GothicCapitalF]}, j\_{\[GothicCapitalG], \
\[GothicCapitalF]}}\ \[GothicCapitalD]\_{j\_{\[GothicCapitalG], \
\[GothicCapitalM]}, j\_{\[GothicCapitalG], \[GothicCapitalM]}}\ a\_{i\_{\
\[GothicCapitalZ], \[GothicCapitalM], \[GothicCapitalF]}, j\_{\
\[GothicCapitalZ], \[GothicCapitalM], \[GothicCapitalF]}, j\_{\
\[GothicCapitalZ], \[GothicCapitalM], \[GothicCapitalM]}} + \[GothicCapitalD]\
\_{i\_{\[GothicCapitalG], \[GothicCapitalF]}, j\_{\[GothicCapitalG], \
\[GothicCapitalF]}}\ \[GothicCapitalD]\_{j\_{\[GothicCapitalG], \
\[GothicCapitalM]}, i\_{\[GothicCapitalG], \[GothicCapitalM]}, j\_{\
\[GothicCapitalG], \[GothicCapitalM]}}\ a\_{i\_{\[GothicCapitalZ], \
\[GothicCapitalM], \[GothicCapitalF]}, i\_{\[GothicCapitalZ], \
\[GothicCapitalM], \[GothicCapitalM]}, j\_{\[GothicCapitalZ], \
\[GothicCapitalM], \[GothicCapitalF]}, j\_{\[GothicCapitalZ], \
\[GothicCapitalM], \[GothicCapitalM]}})\)\ \((1\/2\ \
\((\(-\[GothicCapitalD]\_{k\_{\[GothicCapitalG], \[GothicCapitalF]}, i\_{\
\[GothicCapitalG], \[GothicCapitalF]}}\)\ a\_{i\_{\[GothicCapitalZ], \
\[GothicCapitalM], \[GothicCapitalF]}} - \[GothicCapitalD]\_{k\_{\
\[GothicCapitalG], \[GothicCapitalM]}, i\_{\[GothicCapitalG], \
\[GothicCapitalM]}}\ a\_{i\_{\[GothicCapitalZ], \[GothicCapitalM], \
\[GothicCapitalM]}} - \[GothicCapitalD]\_{k\_{\[GothicCapitalG], \
\[GothicCapitalF]}, j\_{\[GothicCapitalG], \[GothicCapitalF]}}\ a\_{j\_{\
\[GothicCapitalZ], \[GothicCapitalM], \[GothicCapitalF]}} - \[GothicCapitalD]\
\_{k\_{\[GothicCapitalG], \[GothicCapitalM]}, j\_{\[GothicCapitalG], \
\[GothicCapitalM]}}\ a\_{j\_{\[GothicCapitalZ], \[GothicCapitalM], \
\[GothicCapitalM]}} - \[GothicCapitalD]\_{k\_{\[GothicCapitalG], \
\[GothicCapitalF]}, i\_{\[GothicCapitalG], \[GothicCapitalF]}, j\_{\
\[GothicCapitalG], \[GothicCapitalF]}}\ a\_{i\_{\[GothicCapitalZ], \
\[GothicCapitalM], \[GothicCapitalF]}, j\_{\[GothicCapitalZ], \
\[GothicCapitalM], \[GothicCapitalF]}} - \[GothicCapitalD]\_{k\_{\
\[GothicCapitalG], \[GothicCapitalM]}, i\_{\[GothicCapitalG], \
\[GothicCapitalM]}, j\_{\[GothicCapitalG], \[GothicCapitalM]}}\ a\_{i\_{\
\[GothicCapitalZ], \[GothicCapitalM], \[GothicCapitalM]}, j\_{\
\[GothicCapitalZ], \[GothicCapitalM], \[GothicCapitalM]}} - \[GothicCapitalD]\
\_{i\_{\[GothicCapitalG], \[GothicCapitalF]}, j\_{\[GothicCapitalG], \
\[GothicCapitalF]}}\ \[GothicCapitalD]\_{k\_{\[GothicCapitalG], \
\[GothicCapitalM]}, i\_{\[GothicCapitalG], \[GothicCapitalM]}}\ a\_{i\_{\
\[GothicCapitalZ], \[GothicCapitalM], \[GothicCapitalF]}, i\_{\
\[GothicCapitalZ], \[GothicCapitalM], \[GothicCapitalM]}, j\_{\
\[GothicCapitalZ], \[GothicCapitalM], \[GothicCapitalF]}} - \[GothicCapitalD]\
\_{i\_{\[GothicCapitalG], \[GothicCapitalM]}, j\_{\[GothicCapitalG], \
\[GothicCapitalM]}}\ \[GothicCapitalD]\_{k\_{\[GothicCapitalG], \
\[GothicCapitalF]}, i\_{\[GothicCapitalG], \[GothicCapitalF]}}\ a\_{i\_{\
\[GothicCapitalZ], \[GothicCapitalM], \[GothicCapitalF]}, i\_{\
\[GothicCapitalZ], \[GothicCapitalM], \[GothicCapitalM]}, j\_{\
\[GothicCapitalZ], \[GothicCapitalM], \[GothicCapitalM]}} - \[GothicCapitalD]\
\_{i\_{\[GothicCapitalG], \[GothicCapitalF]}, j\_{\[GothicCapitalG], \
\[GothicCapitalF]}}\ \[GothicCapitalD]\_{k\_{\[GothicCapitalG], \
\[GothicCapitalM]}, j\_{\[GothicCapitalG], \[GothicCapitalM]}}\ a\_{i\_{\
\[GothicCapitalZ], \[GothicCapitalM], \[GothicCapitalF]}, j\_{\
\[GothicCapitalZ], \[GothicCapitalM], \[GothicCapitalF]}, j\_{\
\[GothicCapitalZ], \[GothicCapitalM], \[GothicCapitalM]}} - \[GothicCapitalD]\
\_{i\_{\[GothicCapitalG], \[GothicCapitalM]}, j\_{\[GothicCapitalG], \
\[GothicCapitalM]}}\ \[GothicCapitalD]\_{k\_{\[GothicCapitalG], \
\[GothicCapitalF]}, j\_{\[GothicCapitalG], \[GothicCapitalF]}}\ a\_{i\_{\
\[GothicCapitalZ], \[GothicCapitalM], \[GothicCapitalM]}, j\_{\
\[GothicCapitalZ], \[GothicCapitalM], \[GothicCapitalF]}, j\_{\
\[GothicCapitalZ], \[GothicCapitalM], \[GothicCapitalM]}} - \[GothicCapitalD]\
\_{i\_{\[GothicCapitalG], \[GothicCapitalM]}, j\_{\[GothicCapitalG], \
\[GothicCapitalM]}}\ \[GothicCapitalD]\_{k\_{\[GothicCapitalG], \
\[GothicCapitalF]}, i\_{\[GothicCapitalG], \[GothicCapitalF]}, j\_{\
\[GothicCapitalG], \[GothicCapitalF]}}\ a\_{i\_{\[GothicCapitalZ], \
\[GothicCapitalM], \[GothicCapitalF]}, i\_{\[GothicCapitalZ], \
\[GothicCapitalM], \[GothicCapitalM]}, j\_{\[GothicCapitalZ], \
\[GothicCapitalM], \[GothicCapitalF]}, j\_{\[GothicCapitalZ], \
\[GothicCapitalM], \[GothicCapitalM]}} - \[GothicCapitalD]\_{i\_{\
\[GothicCapitalG], \[GothicCapitalF]}, j\_{\[GothicCapitalG], \
\[GothicCapitalF]}}\ \[GothicCapitalD]\_{k\_{\[GothicCapitalG], \
\[GothicCapitalM]}, i\_{\[GothicCapitalG], \[GothicCapitalM]}, j\_{\
\[GothicCapitalG], \[GothicCapitalM]}}\ a\_{i\_{\[GothicCapitalZ], \
\[GothicCapitalM], \[GothicCapitalF]}, i\_{\[GothicCapitalZ], \
\[GothicCapitalM], \[GothicCapitalM]}, j\_{\[GothicCapitalZ], \
\[GothicCapitalM], \[GothicCapitalF]}, j\_{\[GothicCapitalZ], \
\[GothicCapitalM], \[GothicCapitalM]}} - 
                        m\_\(k\_{\[GothicCapitalG], \[GothicCapitalF]}\) - 
                        m\_\(k\_{\[GothicCapitalG], \[GothicCapitalM]}\))\) + 
                  m\_\(k\_{\[GothicCapitalG], \[GothicCapitalM]}\))\) + \
\((1\/2\ \((\(-\[GothicCapitalD]\_{j\_{\[GothicCapitalG], \[GothicCapitalF]}, \
i\_{\[GothicCapitalG], \[GothicCapitalF]}}\)\ a\_{i\_{\[GothicCapitalZ], \
\[GothicCapitalM], \[GothicCapitalF]}} - \[GothicCapitalD]\_{j\_{\
\[GothicCapitalG], \[GothicCapitalM]}, i\_{\[GothicCapitalG], \
\[GothicCapitalM]}}\ a\_{i\_{\[GothicCapitalZ], \[GothicCapitalM], \
\[GothicCapitalM]}} - \[GothicCapitalD]\_{j\_{\[GothicCapitalG], \
\[GothicCapitalF]}, j\_{\[GothicCapitalG], \[GothicCapitalF]}}\ a\_{j\_{\
\[GothicCapitalZ], \[GothicCapitalM], \[GothicCapitalF]}} - \[GothicCapitalD]\
\_{j\_{\[GothicCapitalG], \[GothicCapitalM]}, j\_{\[GothicCapitalG], \
\[GothicCapitalM]}}\ a\_{j\_{\[GothicCapitalZ], \[GothicCapitalM], \
\[GothicCapitalM]}} - \[GothicCapitalD]\_{j\_{\[GothicCapitalG], \
\[GothicCapitalF]}, i\_{\[GothicCapitalG], \[GothicCapitalF]}, j\_{\
\[GothicCapitalG], \[GothicCapitalF]}}\ a\_{i\_{\[GothicCapitalZ], \
\[GothicCapitalM], \[GothicCapitalF]}, j\_{\[GothicCapitalZ], \
\[GothicCapitalM], \[GothicCapitalF]}} - \[GothicCapitalD]\_{j\_{\
\[GothicCapitalG], \[GothicCapitalM]}, i\_{\[GothicCapitalG], \
\[GothicCapitalM]}, j\_{\[GothicCapitalG], \[GothicCapitalM]}}\ a\_{i\_{\
\[GothicCapitalZ], \[GothicCapitalM], \[GothicCapitalM]}, j\_{\
\[GothicCapitalZ], \[GothicCapitalM], \[GothicCapitalM]}} - \[GothicCapitalD]\
\_{i\_{\[GothicCapitalG], \[GothicCapitalF]}, j\_{\[GothicCapitalG], \
\[GothicCapitalF]}}\ \[GothicCapitalD]\_{j\_{\[GothicCapitalG], \
\[GothicCapitalM]}, i\_{\[GothicCapitalG], \[GothicCapitalM]}}\ a\_{i\_{\
\[GothicCapitalZ], \[GothicCapitalM], \[GothicCapitalF]}, i\_{\
\[GothicCapitalZ], \[GothicCapitalM], \[GothicCapitalM]}, j\_{\
\[GothicCapitalZ], \[GothicCapitalM], \[GothicCapitalF]}} - \[GothicCapitalD]\
\_{i\_{\[GothicCapitalG], \[GothicCapitalM]}, j\_{\[GothicCapitalG], \
\[GothicCapitalM]}}\ \[GothicCapitalD]\_{j\_{\[GothicCapitalG], \
\[GothicCapitalF]}, i\_{\[GothicCapitalG], \[GothicCapitalF]}}\ a\_{i\_{\
\[GothicCapitalZ], \[GothicCapitalM], \[GothicCapitalF]}, i\_{\
\[GothicCapitalZ], \[GothicCapitalM], \[GothicCapitalM]}, j\_{\
\[GothicCapitalZ], \[GothicCapitalM], \[GothicCapitalM]}} - \[GothicCapitalD]\
\_{i\_{\[GothicCapitalG], \[GothicCapitalF]}, j\_{\[GothicCapitalG], \
\[GothicCapitalF]}}\ \[GothicCapitalD]\_{j\_{\[GothicCapitalG], \
\[GothicCapitalM]}, j\_{\[GothicCapitalG], \[GothicCapitalM]}}\ a\_{i\_{\
\[GothicCapitalZ], \[GothicCapitalM], \[GothicCapitalF]}, j\_{\
\[GothicCapitalZ], \[GothicCapitalM], \[GothicCapitalF]}, j\_{\
\[GothicCapitalZ], \[GothicCapitalM], \[GothicCapitalM]}} - \[GothicCapitalD]\
\_{i\_{\[GothicCapitalG], \[GothicCapitalM]}, j\_{\[GothicCapitalG], \
\[GothicCapitalM]}}\ \[GothicCapitalD]\_{j\_{\[GothicCapitalG], \
\[GothicCapitalF]}, j\_{\[GothicCapitalG], \[GothicCapitalF]}}\ a\_{i\_{\
\[GothicCapitalZ], \[GothicCapitalM], \[GothicCapitalM]}, j\_{\
\[GothicCapitalZ], \[GothicCapitalM], \[GothicCapitalF]}, j\_{\
\[GothicCapitalZ], \[GothicCapitalM], \[GothicCapitalM]}} - \[GothicCapitalD]\
\_{i\_{\[GothicCapitalG], \[GothicCapitalM]}, j\_{\[GothicCapitalG], \
\[GothicCapitalM]}}\ \[GothicCapitalD]\_{j\_{\[GothicCapitalG], \
\[GothicCapitalF]}, i\_{\[GothicCapitalG], \[GothicCapitalF]}, j\_{\
\[GothicCapitalG], \[GothicCapitalF]}}\ a\_{i\_{\[GothicCapitalZ], \
\[GothicCapitalM], \[GothicCapitalF]}, i\_{\[GothicCapitalZ], \
\[GothicCapitalM], \[GothicCapitalM]}, j\_{\[GothicCapitalZ], \
\[GothicCapitalM], \[GothicCapitalF]}, j\_{\[GothicCapitalZ], \
\[GothicCapitalM], \[GothicCapitalM]}} - \[GothicCapitalD]\_{i\_{\
\[GothicCapitalG], \[GothicCapitalF]}, j\_{\[GothicCapitalG], \
\[GothicCapitalF]}}\ \[GothicCapitalD]\_{j\_{\[GothicCapitalG], \
\[GothicCapitalM]}, i\_{\[GothicCapitalG], \[GothicCapitalM]}, j\_{\
\[GothicCapitalG], \[GothicCapitalM]}}\ a\_{i\_{\[GothicCapitalZ], \
\[GothicCapitalM], \[GothicCapitalF]}, i\_{\[GothicCapitalZ], \
\[GothicCapitalM], \[GothicCapitalM]}, j\_{\[GothicCapitalZ], \
\[GothicCapitalM], \[GothicCapitalF]}, j\_{\[GothicCapitalZ], \
\[GothicCapitalM], \[GothicCapitalM]}} - 
                        m\_\(j\_{\[GothicCapitalG], \[GothicCapitalF]}\) - 
                        m\_\(j\_{\[GothicCapitalG], \[GothicCapitalM]}\))\) + 
                  m\_\(j\_{\[GothicCapitalG], \[GothicCapitalM]}\))\)\ \
\((1\/2\ \((\(-\[GothicCapitalD]\_{k\_{\[GothicCapitalG], \[GothicCapitalF]}, \
i\_{\[GothicCapitalG], \[GothicCapitalF]}}\)\ a\_{i\_{\[GothicCapitalZ], \
\[GothicCapitalM], \[GothicCapitalF]}} - \[GothicCapitalD]\_{k\_{\
\[GothicCapitalG], \[GothicCapitalM]}, i\_{\[GothicCapitalG], \
\[GothicCapitalM]}}\ a\_{i\_{\[GothicCapitalZ], \[GothicCapitalM], \
\[GothicCapitalM]}} - \[GothicCapitalD]\_{k\_{\[GothicCapitalG], \
\[GothicCapitalF]}, j\_{\[GothicCapitalG], \[GothicCapitalF]}}\ a\_{j\_{\
\[GothicCapitalZ], \[GothicCapitalM], \[GothicCapitalF]}} - \[GothicCapitalD]\
\_{k\_{\[GothicCapitalG], \[GothicCapitalM]}, j\_{\[GothicCapitalG], \
\[GothicCapitalM]}}\ a\_{j\_{\[GothicCapitalZ], \[GothicCapitalM], \
\[GothicCapitalM]}} - \[GothicCapitalD]\_{k\_{\[GothicCapitalG], \
\[GothicCapitalF]}, i\_{\[GothicCapitalG], \[GothicCapitalF]}, j\_{\
\[GothicCapitalG], \[GothicCapitalF]}}\ a\_{i\_{\[GothicCapitalZ], \
\[GothicCapitalM], \[GothicCapitalF]}, j\_{\[GothicCapitalZ], \
\[GothicCapitalM], \[GothicCapitalF]}} - \[GothicCapitalD]\_{k\_{\
\[GothicCapitalG], \[GothicCapitalM]}, i\_{\[GothicCapitalG], \
\[GothicCapitalM]}, j\_{\[GothicCapitalG], \[GothicCapitalM]}}\ a\_{i\_{\
\[GothicCapitalZ], \[GothicCapitalM], \[GothicCapitalM]}, j\_{\
\[GothicCapitalZ], \[GothicCapitalM], \[GothicCapitalM]}} - \[GothicCapitalD]\
\_{i\_{\[GothicCapitalG], \[GothicCapitalF]}, j\_{\[GothicCapitalG], \
\[GothicCapitalF]}}\ \[GothicCapitalD]\_{k\_{\[GothicCapitalG], \
\[GothicCapitalM]}, i\_{\[GothicCapitalG], \[GothicCapitalM]}}\ a\_{i\_{\
\[GothicCapitalZ], \[GothicCapitalM], \[GothicCapitalF]}, i\_{\
\[GothicCapitalZ], \[GothicCapitalM], \[GothicCapitalM]}, j\_{\
\[GothicCapitalZ], \[GothicCapitalM], \[GothicCapitalF]}} - \[GothicCapitalD]\
\_{i\_{\[GothicCapitalG], \[GothicCapitalM]}, j\_{\[GothicCapitalG], \
\[GothicCapitalM]}}\ \[GothicCapitalD]\_{k\_{\[GothicCapitalG], \
\[GothicCapitalF]}, i\_{\[GothicCapitalG], \[GothicCapitalF]}}\ a\_{i\_{\
\[GothicCapitalZ], \[GothicCapitalM], \[GothicCapitalF]}, i\_{\
\[GothicCapitalZ], \[GothicCapitalM], \[GothicCapitalM]}, j\_{\
\[GothicCapitalZ], \[GothicCapitalM], \[GothicCapitalM]}} - \[GothicCapitalD]\
\_{i\_{\[GothicCapitalG], \[GothicCapitalF]}, j\_{\[GothicCapitalG], \
\[GothicCapitalF]}}\ \[GothicCapitalD]\_{k\_{\[GothicCapitalG], \
\[GothicCapitalM]}, j\_{\[GothicCapitalG], \[GothicCapitalM]}}\ a\_{i\_{\
\[GothicCapitalZ], \[GothicCapitalM], \[GothicCapitalF]}, j\_{\
\[GothicCapitalZ], \[GothicCapitalM], \[GothicCapitalF]}, j\_{\
\[GothicCapitalZ], \[GothicCapitalM], \[GothicCapitalM]}} - \[GothicCapitalD]\
\_{i\_{\[GothicCapitalG], \[GothicCapitalM]}, j\_{\[GothicCapitalG], \
\[GothicCapitalM]}}\ \[GothicCapitalD]\_{k\_{\[GothicCapitalG], \
\[GothicCapitalF]}, j\_{\[GothicCapitalG], \[GothicCapitalF]}}\ a\_{i\_{\
\[GothicCapitalZ], \[GothicCapitalM], \[GothicCapitalM]}, j\_{\
\[GothicCapitalZ], \[GothicCapitalM], \[GothicCapitalF]}, j\_{\
\[GothicCapitalZ], \[GothicCapitalM], \[GothicCapitalM]}} - \[GothicCapitalD]\
\_{i\_{\[GothicCapitalG], \[GothicCapitalM]}, j\_{\[GothicCapitalG], \
\[GothicCapitalM]}}\ \[GothicCapitalD]\_{k\_{\[GothicCapitalG], \
\[GothicCapitalF]}, i\_{\[GothicCapitalG], \[GothicCapitalF]}, j\_{\
\[GothicCapitalG], \[GothicCapitalF]}}\ a\_{i\_{\[GothicCapitalZ], \
\[GothicCapitalM], \[GothicCapitalF]}, i\_{\[GothicCapitalZ], \
\[GothicCapitalM], \[GothicCapitalM]}, j\_{\[GothicCapitalZ], \
\[GothicCapitalM], \[GothicCapitalF]}, j\_{\[GothicCapitalZ], \
\[GothicCapitalM], \[GothicCapitalM]}} - \[GothicCapitalD]\_{i\_{\
\[GothicCapitalG], \[GothicCapitalF]}, j\_{\[GothicCapitalG], \
\[GothicCapitalF]}}\ \[GothicCapitalD]\_{k\_{\[GothicCapitalG], \
\[GothicCapitalM]}, i\_{\[GothicCapitalG], \[GothicCapitalM]}, j\_{\
\[GothicCapitalG], \[GothicCapitalM]}}\ a\_{i\_{\[GothicCapitalZ], \
\[GothicCapitalM], \[GothicCapitalF]}, i\_{\[GothicCapitalZ], \
\[GothicCapitalM], \[GothicCapitalM]}, j\_{\[GothicCapitalZ], \
\[GothicCapitalM], \[GothicCapitalF]}, j\_{\[GothicCapitalZ], \
\[GothicCapitalM], \[GothicCapitalM]}} - 
                        m\_\(k\_{\[GothicCapitalG], \[GothicCapitalF]}\) - 
                        m\_\(k\_{\[GothicCapitalG], \[GothicCapitalM]}\))\) + 
                  m\_\(k\_{\[GothicCapitalG], \[GothicCapitalM]}\))\))\)\ r\_\
\({}, {j, k}\) + \((\[GothicCapitalD]\_{j\_{\[GothicCapitalG], \
\[GothicCapitalF]}, i\_{\[GothicCapitalG], \[GothicCapitalF]}}\ \
\[GothicCapitalD]\_{k\_{\[GothicCapitalG], \[GothicCapitalM]}, i\_{\
\[GothicCapitalG], \[GothicCapitalM]}}\ a\_{i\_{\[GothicCapitalZ], \
\[GothicCapitalM], \[GothicCapitalF]}, i\_{\[GothicCapitalZ], \
\[GothicCapitalM], \[GothicCapitalM]}} + \[GothicCapitalD]\_{j\_{\
\[GothicCapitalG], \[GothicCapitalF]}, i\_{\[GothicCapitalG], \
\[GothicCapitalF]}}\ \[GothicCapitalD]\_{k\_{\[GothicCapitalG], \
\[GothicCapitalM]}, j\_{\[GothicCapitalG], \[GothicCapitalM]}}\ a\_{i\_{\
\[GothicCapitalZ], \[GothicCapitalM], \[GothicCapitalF]}, j\_{\
\[GothicCapitalZ], \[GothicCapitalM], \[GothicCapitalM]}} + \[GothicCapitalD]\
\_{j\_{\[GothicCapitalG], \[GothicCapitalF]}, j\_{\[GothicCapitalG], \
\[GothicCapitalF]}}\ \[GothicCapitalD]\_{k\_{\[GothicCapitalG], \
\[GothicCapitalM]}, i\_{\[GothicCapitalG], \[GothicCapitalM]}}\ a\_{i\_{\
\[GothicCapitalZ], \[GothicCapitalM], \[GothicCapitalM]}, j\_{\
\[GothicCapitalZ], \[GothicCapitalM], \[GothicCapitalF]}} + \[GothicCapitalD]\
\_{j\_{\[GothicCapitalG], \[GothicCapitalF]}, j\_{\[GothicCapitalG], \
\[GothicCapitalF]}}\ \[GothicCapitalD]\_{k\_{\[GothicCapitalG], \
\[GothicCapitalM]}, j\_{\[GothicCapitalG], \[GothicCapitalM]}}\ a\_{j\_{\
\[GothicCapitalZ], \[GothicCapitalM], \[GothicCapitalF]}, j\_{\
\[GothicCapitalZ], \[GothicCapitalM], \[GothicCapitalM]}} + \[GothicCapitalD]\
\_{k\_{\[GothicCapitalG], \[GothicCapitalM]}, i\_{\[GothicCapitalG], \
\[GothicCapitalM]}}\ \[GothicCapitalD]\_{j\_{\[GothicCapitalG], \
\[GothicCapitalF]}, i\_{\[GothicCapitalG], \[GothicCapitalF]}, j\_{\
\[GothicCapitalG], \[GothicCapitalF]}}\ a\_{i\_{\[GothicCapitalZ], \
\[GothicCapitalM], \[GothicCapitalF]}, i\_{\[GothicCapitalZ], \
\[GothicCapitalM], \[GothicCapitalM]}, j\_{\[GothicCapitalZ], \
\[GothicCapitalM], \[GothicCapitalF]}} + \[GothicCapitalD]\_{j\_{\
\[GothicCapitalG], \[GothicCapitalF]}, i\_{\[GothicCapitalG], \
\[GothicCapitalF]}}\ \[GothicCapitalD]\_{k\_{\[GothicCapitalG], \
\[GothicCapitalM]}, i\_{\[GothicCapitalG], \[GothicCapitalM]}, j\_{\
\[GothicCapitalG], \[GothicCapitalM]}}\ a\_{i\_{\[GothicCapitalZ], \
\[GothicCapitalM], \[GothicCapitalF]}, i\_{\[GothicCapitalZ], \
\[GothicCapitalM], \[GothicCapitalM]}, j\_{\[GothicCapitalZ], \
\[GothicCapitalM], \[GothicCapitalM]}} + \[GothicCapitalD]\_{k\_{\
\[GothicCapitalG], \[GothicCapitalM]}, j\_{\[GothicCapitalG], \
\[GothicCapitalM]}}\ \[GothicCapitalD]\_{j\_{\[GothicCapitalG], \
\[GothicCapitalF]}, i\_{\[GothicCapitalG], \[GothicCapitalF]}, j\_{\
\[GothicCapitalG], \[GothicCapitalF]}}\ a\_{i\_{\[GothicCapitalZ], \
\[GothicCapitalM], \[GothicCapitalF]}, j\_{\[GothicCapitalZ], \
\[GothicCapitalM], \[GothicCapitalF]}, j\_{\[GothicCapitalZ], \
\[GothicCapitalM], \[GothicCapitalM]}} + \[GothicCapitalD]\_{j\_{\
\[GothicCapitalG], \[GothicCapitalF]}, j\_{\[GothicCapitalG], \
\[GothicCapitalF]}}\ \[GothicCapitalD]\_{k\_{\[GothicCapitalG], \
\[GothicCapitalM]}, i\_{\[GothicCapitalG], \[GothicCapitalM]}, j\_{\
\[GothicCapitalG], \[GothicCapitalM]}}\ a\_{i\_{\[GothicCapitalZ], \
\[GothicCapitalM], \[GothicCapitalM]}, j\_{\[GothicCapitalZ], \
\[GothicCapitalM], \[GothicCapitalF]}, j\_{\[GothicCapitalZ], \
\[GothicCapitalM], \[GothicCapitalM]}} + \[GothicCapitalD]\_{j\_{\
\[GothicCapitalG], \[GothicCapitalF]}, i\_{\[GothicCapitalG], \
\[GothicCapitalF]}, j\_{\[GothicCapitalG], \[GothicCapitalF]}}\ \
\[GothicCapitalD]\_{k\_{\[GothicCapitalG], \[GothicCapitalM]}, i\_{\
\[GothicCapitalG], \[GothicCapitalM]}, j\_{\[GothicCapitalG], \
\[GothicCapitalM]}}\ a\_{i\_{\[GothicCapitalZ], \[GothicCapitalM], \
\[GothicCapitalF]}, i\_{\[GothicCapitalZ], \[GothicCapitalM], \
\[GothicCapitalM]}, j\_{\[GothicCapitalZ], \[GothicCapitalM], \
\[GothicCapitalF]}, j\_{\[GothicCapitalZ], \[GothicCapitalM], \
\[GothicCapitalM]}} + \((\[GothicCapitalD]\_{k\_{\[GothicCapitalG], \
\[GothicCapitalM]}, i\_{\[GothicCapitalG], \[GothicCapitalM]}}\ a\_{i\_{\
\[GothicCapitalZ], \[GothicCapitalM], \[GothicCapitalM]}} + \[GothicCapitalD]\
\_{k\_{\[GothicCapitalG], \[GothicCapitalM]}, j\_{\[GothicCapitalG], \
\[GothicCapitalM]}}\ a\_{j\_{\[GothicCapitalZ], \[GothicCapitalM], \
\[GothicCapitalM]}} + \[GothicCapitalD]\_{k\_{\[GothicCapitalG], \
\[GothicCapitalM]}, i\_{\[GothicCapitalG], \[GothicCapitalM]}, j\_{\
\[GothicCapitalG], \[GothicCapitalM]}}\ a\_{i\_{\[GothicCapitalZ], \
\[GothicCapitalM], \[GothicCapitalM]}, j\_{\[GothicCapitalZ], \
\[GothicCapitalM], \[GothicCapitalM]}} + \[GothicCapitalD]\_{i\_{\
\[GothicCapitalG], \[GothicCapitalF]}, j\_{\[GothicCapitalG], \
\[GothicCapitalF]}}\ \[GothicCapitalD]\_{k\_{\[GothicCapitalG], \
\[GothicCapitalM]}, i\_{\[GothicCapitalG], \[GothicCapitalM]}}\ a\_{i\_{\
\[GothicCapitalZ], \[GothicCapitalM], \[GothicCapitalF]}, i\_{\
\[GothicCapitalZ], \[GothicCapitalM], \[GothicCapitalM]}, j\_{\
\[GothicCapitalZ], \[GothicCapitalM], \[GothicCapitalF]}} + \[GothicCapitalD]\
\_{i\_{\[GothicCapitalG], \[GothicCapitalF]}, j\_{\[GothicCapitalG], \
\[GothicCapitalF]}}\ \[GothicCapitalD]\_{k\_{\[GothicCapitalG], \
\[GothicCapitalM]}, j\_{\[GothicCapitalG], \[GothicCapitalM]}}\ a\_{i\_{\
\[GothicCapitalZ], \[GothicCapitalM], \[GothicCapitalF]}, j\_{\
\[GothicCapitalZ], \[GothicCapitalM], \[GothicCapitalF]}, j\_{\
\[GothicCapitalZ], \[GothicCapitalM], \[GothicCapitalM]}} + \[GothicCapitalD]\
\_{i\_{\[GothicCapitalG], \[GothicCapitalF]}, j\_{\[GothicCapitalG], \
\[GothicCapitalF]}}\ \[GothicCapitalD]\_{k\_{\[GothicCapitalG], \
\[GothicCapitalM]}, i\_{\[GothicCapitalG], \[GothicCapitalM]}, j\_{\
\[GothicCapitalG], \[GothicCapitalM]}}\ a\_{i\_{\[GothicCapitalZ], \
\[GothicCapitalM], \[GothicCapitalF]}, i\_{\[GothicCapitalZ], \
\[GothicCapitalM], \[GothicCapitalM]}, j\_{\[GothicCapitalZ], \
\[GothicCapitalM], \[GothicCapitalF]}, j\_{\[GothicCapitalZ], \
\[GothicCapitalM], \[GothicCapitalM]}})\)\ \((m\_\(j\_{\[GothicCapitalG], \
\[GothicCapitalF]}\) + 
                  1\/2\ \((\(-\[GothicCapitalD]\_{j\_{\[GothicCapitalG], \
\[GothicCapitalF]}, i\_{\[GothicCapitalG], \[GothicCapitalF]}}\)\ a\_{i\_{\
\[GothicCapitalZ], \[GothicCapitalM], \[GothicCapitalF]}} - \[GothicCapitalD]\
\_{j\_{\[GothicCapitalG], \[GothicCapitalM]}, i\_{\[GothicCapitalG], \
\[GothicCapitalM]}}\ a\_{i\_{\[GothicCapitalZ], \[GothicCapitalM], \
\[GothicCapitalM]}} - \[GothicCapitalD]\_{j\_{\[GothicCapitalG], \
\[GothicCapitalF]}, j\_{\[GothicCapitalG], \[GothicCapitalF]}}\ a\_{j\_{\
\[GothicCapitalZ], \[GothicCapitalM], \[GothicCapitalF]}} - \[GothicCapitalD]\
\_{j\_{\[GothicCapitalG], \[GothicCapitalM]}, j\_{\[GothicCapitalG], \
\[GothicCapitalM]}}\ a\_{j\_{\[GothicCapitalZ], \[GothicCapitalM], \
\[GothicCapitalM]}} - \[GothicCapitalD]\_{j\_{\[GothicCapitalG], \
\[GothicCapitalF]}, i\_{\[GothicCapitalG], \[GothicCapitalF]}, j\_{\
\[GothicCapitalG], \[GothicCapitalF]}}\ a\_{i\_{\[GothicCapitalZ], \
\[GothicCapitalM], \[GothicCapitalF]}, j\_{\[GothicCapitalZ], \
\[GothicCapitalM], \[GothicCapitalF]}} - \[GothicCapitalD]\_{j\_{\
\[GothicCapitalG], \[GothicCapitalM]}, i\_{\[GothicCapitalG], \
\[GothicCapitalM]}, j\_{\[GothicCapitalG], \[GothicCapitalM]}}\ a\_{i\_{\
\[GothicCapitalZ], \[GothicCapitalM], \[GothicCapitalM]}, j\_{\
\[GothicCapitalZ], \[GothicCapitalM], \[GothicCapitalM]}} - \[GothicCapitalD]\
\_{i\_{\[GothicCapitalG], \[GothicCapitalF]}, j\_{\[GothicCapitalG], \
\[GothicCapitalF]}}\ \[GothicCapitalD]\_{j\_{\[GothicCapitalG], \
\[GothicCapitalM]}, i\_{\[GothicCapitalG], \[GothicCapitalM]}}\ a\_{i\_{\
\[GothicCapitalZ], \[GothicCapitalM], \[GothicCapitalF]}, i\_{\
\[GothicCapitalZ], \[GothicCapitalM], \[GothicCapitalM]}, j\_{\
\[GothicCapitalZ], \[GothicCapitalM], \[GothicCapitalF]}} - \[GothicCapitalD]\
\_{i\_{\[GothicCapitalG], \[GothicCapitalM]}, j\_{\[GothicCapitalG], \
\[GothicCapitalM]}}\ \[GothicCapitalD]\_{j\_{\[GothicCapitalG], \
\[GothicCapitalF]}, i\_{\[GothicCapitalG], \[GothicCapitalF]}}\ a\_{i\_{\
\[GothicCapitalZ], \[GothicCapitalM], \[GothicCapitalF]}, i\_{\
\[GothicCapitalZ], \[GothicCapitalM], \[GothicCapitalM]}, j\_{\
\[GothicCapitalZ], \[GothicCapitalM], \[GothicCapitalM]}} - \[GothicCapitalD]\
\_{i\_{\[GothicCapitalG], \[GothicCapitalF]}, j\_{\[GothicCapitalG], \
\[GothicCapitalF]}}\ \[GothicCapitalD]\_{j\_{\[GothicCapitalG], \
\[GothicCapitalM]}, j\_{\[GothicCapitalG], \[GothicCapitalM]}}\ a\_{i\_{\
\[GothicCapitalZ], \[GothicCapitalM], \[GothicCapitalF]}, j\_{\
\[GothicCapitalZ], \[GothicCapitalM], \[GothicCapitalF]}, j\_{\
\[GothicCapitalZ], \[GothicCapitalM], \[GothicCapitalM]}} - \[GothicCapitalD]\
\_{i\_{\[GothicCapitalG], \[GothicCapitalM]}, j\_{\[GothicCapitalG], \
\[GothicCapitalM]}}\ \[GothicCapitalD]\_{j\_{\[GothicCapitalG], \
\[GothicCapitalF]}, j\_{\[GothicCapitalG], \[GothicCapitalF]}}\ a\_{i\_{\
\[GothicCapitalZ], \[GothicCapitalM], \[GothicCapitalM]}, j\_{\
\[GothicCapitalZ], \[GothicCapitalM], \[GothicCapitalF]}, j\_{\
\[GothicCapitalZ], \[GothicCapitalM], \[GothicCapitalM]}} - \[GothicCapitalD]\
\_{i\_{\[GothicCapitalG], \[GothicCapitalM]}, j\_{\[GothicCapitalG], \
\[GothicCapitalM]}}\ \[GothicCapitalD]\_{j\_{\[GothicCapitalG], \
\[GothicCapitalF]}, i\_{\[GothicCapitalG], \[GothicCapitalF]}, j\_{\
\[GothicCapitalG], \[GothicCapitalF]}}\ a\_{i\_{\[GothicCapitalZ], \
\[GothicCapitalM], \[GothicCapitalF]}, i\_{\[GothicCapitalZ], \
\[GothicCapitalM], \[GothicCapitalM]}, j\_{\[GothicCapitalZ], \
\[GothicCapitalM], \[GothicCapitalF]}, j\_{\[GothicCapitalZ], \
\[GothicCapitalM], \[GothicCapitalM]}} - \[GothicCapitalD]\_{i\_{\
\[GothicCapitalG], \[GothicCapitalF]}, j\_{\[GothicCapitalG], \
\[GothicCapitalF]}}\ \[GothicCapitalD]\_{j\_{\[GothicCapitalG], \
\[GothicCapitalM]}, i\_{\[GothicCapitalG], \[GothicCapitalM]}, j\_{\
\[GothicCapitalG], \[GothicCapitalM]}}\ a\_{i\_{\[GothicCapitalZ], \
\[GothicCapitalM], \[GothicCapitalF]}, i\_{\[GothicCapitalZ], \
\[GothicCapitalM], \[GothicCapitalM]}, j\_{\[GothicCapitalZ], \
\[GothicCapitalM], \[GothicCapitalF]}, j\_{\[GothicCapitalZ], \
\[GothicCapitalM], \[GothicCapitalM]}} - 
                        m\_\(j\_{\[GothicCapitalG], \[GothicCapitalF]}\) - 
                        m\_\(j\_{\[GothicCapitalG], \
\[GothicCapitalM]}\))\))\) + \((\[GothicCapitalD]\_{j\_{\[GothicCapitalG], \
\[GothicCapitalF]}, i\_{\[GothicCapitalG], \[GothicCapitalF]}}\ a\_{i\_{\
\[GothicCapitalZ], \[GothicCapitalM], \[GothicCapitalF]}} + \[GothicCapitalD]\
\_{j\_{\[GothicCapitalG], \[GothicCapitalF]}, j\_{\[GothicCapitalG], \
\[GothicCapitalF]}}\ a\_{j\_{\[GothicCapitalZ], \[GothicCapitalM], \
\[GothicCapitalF]}} + \[GothicCapitalD]\_{j\_{\[GothicCapitalG], \
\[GothicCapitalF]}, i\_{\[GothicCapitalG], \[GothicCapitalF]}, j\_{\
\[GothicCapitalG], \[GothicCapitalF]}}\ a\_{i\_{\[GothicCapitalZ], \
\[GothicCapitalM], \[GothicCapitalF]}, j\_{\[GothicCapitalZ], \
\[GothicCapitalM], \[GothicCapitalF]}} + \[GothicCapitalD]\_{i\_{\
\[GothicCapitalG], \[GothicCapitalM]}, j\_{\[GothicCapitalG], \
\[GothicCapitalM]}}\ \[GothicCapitalD]\_{j\_{\[GothicCapitalG], \
\[GothicCapitalF]}, i\_{\[GothicCapitalG], \[GothicCapitalF]}}\ a\_{i\_{\
\[GothicCapitalZ], \[GothicCapitalM], \[GothicCapitalF]}, i\_{\
\[GothicCapitalZ], \[GothicCapitalM], \[GothicCapitalM]}, j\_{\
\[GothicCapitalZ], \[GothicCapitalM], \[GothicCapitalM]}} + \[GothicCapitalD]\
\_{i\_{\[GothicCapitalG], \[GothicCapitalM]}, j\_{\[GothicCapitalG], \
\[GothicCapitalM]}}\ \[GothicCapitalD]\_{j\_{\[GothicCapitalG], \
\[GothicCapitalF]}, j\_{\[GothicCapitalG], \[GothicCapitalF]}}\ a\_{i\_{\
\[GothicCapitalZ], \[GothicCapitalM], \[GothicCapitalM]}, j\_{\
\[GothicCapitalZ], \[GothicCapitalM], \[GothicCapitalF]}, j\_{\
\[GothicCapitalZ], \[GothicCapitalM], \[GothicCapitalM]}} + \[GothicCapitalD]\
\_{i\_{\[GothicCapitalG], \[GothicCapitalM]}, j\_{\[GothicCapitalG], \
\[GothicCapitalM]}}\ \[GothicCapitalD]\_{j\_{\[GothicCapitalG], \
\[GothicCapitalF]}, i\_{\[GothicCapitalG], \[GothicCapitalF]}, j\_{\
\[GothicCapitalG], \[GothicCapitalF]}}\ a\_{i\_{\[GothicCapitalZ], \
\[GothicCapitalM], \[GothicCapitalF]}, i\_{\[GothicCapitalZ], \
\[GothicCapitalM], \[GothicCapitalM]}, j\_{\[GothicCapitalZ], \
\[GothicCapitalM], \[GothicCapitalF]}, j\_{\[GothicCapitalZ], \
\[GothicCapitalM], \[GothicCapitalM]}})\)\ \((1\/2\ \
\((\(-\[GothicCapitalD]\_{k\_{\[GothicCapitalG], \[GothicCapitalF]}, i\_{\
\[GothicCapitalG], \[GothicCapitalF]}}\)\ a\_{i\_{\[GothicCapitalZ], \
\[GothicCapitalM], \[GothicCapitalF]}} - \[GothicCapitalD]\_{k\_{\
\[GothicCapitalG], \[GothicCapitalM]}, i\_{\[GothicCapitalG], \
\[GothicCapitalM]}}\ a\_{i\_{\[GothicCapitalZ], \[GothicCapitalM], \
\[GothicCapitalM]}} - \[GothicCapitalD]\_{k\_{\[GothicCapitalG], \
\[GothicCapitalF]}, j\_{\[GothicCapitalG], \[GothicCapitalF]}}\ a\_{j\_{\
\[GothicCapitalZ], \[GothicCapitalM], \[GothicCapitalF]}} - \[GothicCapitalD]\
\_{k\_{\[GothicCapitalG], \[GothicCapitalM]}, j\_{\[GothicCapitalG], \
\[GothicCapitalM]}}\ a\_{j\_{\[GothicCapitalZ], \[GothicCapitalM], \
\[GothicCapitalM]}} - \[GothicCapitalD]\_{k\_{\[GothicCapitalG], \
\[GothicCapitalF]}, i\_{\[GothicCapitalG], \[GothicCapitalF]}, j\_{\
\[GothicCapitalG], \[GothicCapitalF]}}\ a\_{i\_{\[GothicCapitalZ], \
\[GothicCapitalM], \[GothicCapitalF]}, j\_{\[GothicCapitalZ], \
\[GothicCapitalM], \[GothicCapitalF]}} - \[GothicCapitalD]\_{k\_{\
\[GothicCapitalG], \[GothicCapitalM]}, i\_{\[GothicCapitalG], \
\[GothicCapitalM]}, j\_{\[GothicCapitalG], \[GothicCapitalM]}}\ a\_{i\_{\
\[GothicCapitalZ], \[GothicCapitalM], \[GothicCapitalM]}, j\_{\
\[GothicCapitalZ], \[GothicCapitalM], \[GothicCapitalM]}} - \[GothicCapitalD]\
\_{i\_{\[GothicCapitalG], \[GothicCapitalF]}, j\_{\[GothicCapitalG], \
\[GothicCapitalF]}}\ \[GothicCapitalD]\_{k\_{\[GothicCapitalG], \
\[GothicCapitalM]}, i\_{\[GothicCapitalG], \[GothicCapitalM]}}\ a\_{i\_{\
\[GothicCapitalZ], \[GothicCapitalM], \[GothicCapitalF]}, i\_{\
\[GothicCapitalZ], \[GothicCapitalM], \[GothicCapitalM]}, j\_{\
\[GothicCapitalZ], \[GothicCapitalM], \[GothicCapitalF]}} - \[GothicCapitalD]\
\_{i\_{\[GothicCapitalG], \[GothicCapitalM]}, j\_{\[GothicCapitalG], \
\[GothicCapitalM]}}\ \[GothicCapitalD]\_{k\_{\[GothicCapitalG], \
\[GothicCapitalF]}, i\_{\[GothicCapitalG], \[GothicCapitalF]}}\ a\_{i\_{\
\[GothicCapitalZ], \[GothicCapitalM], \[GothicCapitalF]}, i\_{\
\[GothicCapitalZ], \[GothicCapitalM], \[GothicCapitalM]}, j\_{\
\[GothicCapitalZ], \[GothicCapitalM], \[GothicCapitalM]}} - \[GothicCapitalD]\
\_{i\_{\[GothicCapitalG], \[GothicCapitalF]}, j\_{\[GothicCapitalG], \
\[GothicCapitalF]}}\ \[GothicCapitalD]\_{k\_{\[GothicCapitalG], \
\[GothicCapitalM]}, j\_{\[GothicCapitalG], \[GothicCapitalM]}}\ a\_{i\_{\
\[GothicCapitalZ], \[GothicCapitalM], \[GothicCapitalF]}, j\_{\
\[GothicCapitalZ], \[GothicCapitalM], \[GothicCapitalF]}, j\_{\
\[GothicCapitalZ], \[GothicCapitalM], \[GothicCapitalM]}} - \[GothicCapitalD]\
\_{i\_{\[GothicCapitalG], \[GothicCapitalM]}, j\_{\[GothicCapitalG], \
\[GothicCapitalM]}}\ \[GothicCapitalD]\_{k\_{\[GothicCapitalG], \
\[GothicCapitalF]}, j\_{\[GothicCapitalG], \[GothicCapitalF]}}\ a\_{i\_{\
\[GothicCapitalZ], \[GothicCapitalM], \[GothicCapitalM]}, j\_{\
\[GothicCapitalZ], \[GothicCapitalM], \[GothicCapitalF]}, j\_{\
\[GothicCapitalZ], \[GothicCapitalM], \[GothicCapitalM]}} - \[GothicCapitalD]\
\_{i\_{\[GothicCapitalG], \[GothicCapitalM]}, j\_{\[GothicCapitalG], \
\[GothicCapitalM]}}\ \[GothicCapitalD]\_{k\_{\[GothicCapitalG], \
\[GothicCapitalF]}, i\_{\[GothicCapitalG], \[GothicCapitalF]}, j\_{\
\[GothicCapitalG], \[GothicCapitalF]}}\ a\_{i\_{\[GothicCapitalZ], \
\[GothicCapitalM], \[GothicCapitalF]}, i\_{\[GothicCapitalZ], \
\[GothicCapitalM], \[GothicCapitalM]}, j\_{\[GothicCapitalZ], \
\[GothicCapitalM], \[GothicCapitalF]}, j\_{\[GothicCapitalZ], \
\[GothicCapitalM], \[GothicCapitalM]}} - \[GothicCapitalD]\_{i\_{\
\[GothicCapitalG], \[GothicCapitalF]}, j\_{\[GothicCapitalG], \
\[GothicCapitalF]}}\ \[GothicCapitalD]\_{k\_{\[GothicCapitalG], \
\[GothicCapitalM]}, i\_{\[GothicCapitalG], \[GothicCapitalM]}, j\_{\
\[GothicCapitalG], \[GothicCapitalM]}}\ a\_{i\_{\[GothicCapitalZ], \
\[GothicCapitalM], \[GothicCapitalF]}, i\_{\[GothicCapitalZ], \
\[GothicCapitalM], \[GothicCapitalM]}, j\_{\[GothicCapitalZ], \
\[GothicCapitalM], \[GothicCapitalF]}, j\_{\[GothicCapitalZ], \
\[GothicCapitalM], \[GothicCapitalM]}} - 
                        m\_\(k\_{\[GothicCapitalG], \[GothicCapitalF]}\) - 
                        m\_\(k\_{\[GothicCapitalG], \[GothicCapitalM]}\))\) + 
                  m\_\(k\_{\[GothicCapitalG], \[GothicCapitalM]}\))\) + \
\((m\_\(j\_{\[GothicCapitalG], \[GothicCapitalF]}\) + 
                  1\/2\ \((\(-\[GothicCapitalD]\_{j\_{\[GothicCapitalG], \
\[GothicCapitalF]}, i\_{\[GothicCapitalG], \[GothicCapitalF]}}\)\ a\_{i\_{\
\[GothicCapitalZ], \[GothicCapitalM], \[GothicCapitalF]}} - \[GothicCapitalD]\
\_{j\_{\[GothicCapitalG], \[GothicCapitalM]}, i\_{\[GothicCapitalG], \
\[GothicCapitalM]}}\ a\_{i\_{\[GothicCapitalZ], \[GothicCapitalM], \
\[GothicCapitalM]}} - \[GothicCapitalD]\_{j\_{\[GothicCapitalG], \
\[GothicCapitalF]}, j\_{\[GothicCapitalG], \[GothicCapitalF]}}\ a\_{j\_{\
\[GothicCapitalZ], \[GothicCapitalM], \[GothicCapitalF]}} - \[GothicCapitalD]\
\_{j\_{\[GothicCapitalG], \[GothicCapitalM]}, j\_{\[GothicCapitalG], \
\[GothicCapitalM]}}\ a\_{j\_{\[GothicCapitalZ], \[GothicCapitalM], \
\[GothicCapitalM]}} - \[GothicCapitalD]\_{j\_{\[GothicCapitalG], \
\[GothicCapitalF]}, i\_{\[GothicCapitalG], \[GothicCapitalF]}, j\_{\
\[GothicCapitalG], \[GothicCapitalF]}}\ a\_{i\_{\[GothicCapitalZ], \
\[GothicCapitalM], \[GothicCapitalF]}, j\_{\[GothicCapitalZ], \
\[GothicCapitalM], \[GothicCapitalF]}} - \[GothicCapitalD]\_{j\_{\
\[GothicCapitalG], \[GothicCapitalM]}, i\_{\[GothicCapitalG], \
\[GothicCapitalM]}, j\_{\[GothicCapitalG], \[GothicCapitalM]}}\ a\_{i\_{\
\[GothicCapitalZ], \[GothicCapitalM], \[GothicCapitalM]}, j\_{\
\[GothicCapitalZ], \[GothicCapitalM], \[GothicCapitalM]}} - \[GothicCapitalD]\
\_{i\_{\[GothicCapitalG], \[GothicCapitalF]}, j\_{\[GothicCapitalG], \
\[GothicCapitalF]}}\ \[GothicCapitalD]\_{j\_{\[GothicCapitalG], \
\[GothicCapitalM]}, i\_{\[GothicCapitalG], \[GothicCapitalM]}}\ a\_{i\_{\
\[GothicCapitalZ], \[GothicCapitalM], \[GothicCapitalF]}, i\_{\
\[GothicCapitalZ], \[GothicCapitalM], \[GothicCapitalM]}, j\_{\
\[GothicCapitalZ], \[GothicCapitalM], \[GothicCapitalF]}} - \[GothicCapitalD]\
\_{i\_{\[GothicCapitalG], \[GothicCapitalM]}, j\_{\[GothicCapitalG], \
\[GothicCapitalM]}}\ \[GothicCapitalD]\_{j\_{\[GothicCapitalG], \
\[GothicCapitalF]}, i\_{\[GothicCapitalG], \[GothicCapitalF]}}\ a\_{i\_{\
\[GothicCapitalZ], \[GothicCapitalM], \[GothicCapitalF]}, i\_{\
\[GothicCapitalZ], \[GothicCapitalM], \[GothicCapitalM]}, j\_{\
\[GothicCapitalZ], \[GothicCapitalM], \[GothicCapitalM]}} - \[GothicCapitalD]\
\_{i\_{\[GothicCapitalG], \[GothicCapitalF]}, j\_{\[GothicCapitalG], \
\[GothicCapitalF]}}\ \[GothicCapitalD]\_{j\_{\[GothicCapitalG], \
\[GothicCapitalM]}, j\_{\[GothicCapitalG], \[GothicCapitalM]}}\ a\_{i\_{\
\[GothicCapitalZ], \[GothicCapitalM], \[GothicCapitalF]}, j\_{\
\[GothicCapitalZ], \[GothicCapitalM], \[GothicCapitalF]}, j\_{\
\[GothicCapitalZ], \[GothicCapitalM], \[GothicCapitalM]}} - \[GothicCapitalD]\
\_{i\_{\[GothicCapitalG], \[GothicCapitalM]}, j\_{\[GothicCapitalG], \
\[GothicCapitalM]}}\ \[GothicCapitalD]\_{j\_{\[GothicCapitalG], \
\[GothicCapitalF]}, j\_{\[GothicCapitalG], \[GothicCapitalF]}}\ a\_{i\_{\
\[GothicCapitalZ], \[GothicCapitalM], \[GothicCapitalM]}, j\_{\
\[GothicCapitalZ], \[GothicCapitalM], \[GothicCapitalF]}, j\_{\
\[GothicCapitalZ], \[GothicCapitalM], \[GothicCapitalM]}} - \[GothicCapitalD]\
\_{i\_{\[GothicCapitalG], \[GothicCapitalM]}, j\_{\[GothicCapitalG], \
\[GothicCapitalM]}}\ \[GothicCapitalD]\_{j\_{\[GothicCapitalG], \
\[GothicCapitalF]}, i\_{\[GothicCapitalG], \[GothicCapitalF]}, j\_{\
\[GothicCapitalG], \[GothicCapitalF]}}\ a\_{i\_{\[GothicCapitalZ], \
\[GothicCapitalM], \[GothicCapitalF]}, i\_{\[GothicCapitalZ], \
\[GothicCapitalM], \[GothicCapitalM]}, j\_{\[GothicCapitalZ], \
\[GothicCapitalM], \[GothicCapitalF]}, j\_{\[GothicCapitalZ], \
\[GothicCapitalM], \[GothicCapitalM]}} - \[GothicCapitalD]\_{i\_{\
\[GothicCapitalG], \[GothicCapitalF]}, j\_{\[GothicCapitalG], \
\[GothicCapitalF]}}\ \[GothicCapitalD]\_{j\_{\[GothicCapitalG], \
\[GothicCapitalM]}, i\_{\[GothicCapitalG], \[GothicCapitalM]}, j\_{\
\[GothicCapitalG], \[GothicCapitalM]}}\ a\_{i\_{\[GothicCapitalZ], \
\[GothicCapitalM], \[GothicCapitalF]}, i\_{\[GothicCapitalZ], \
\[GothicCapitalM], \[GothicCapitalM]}, j\_{\[GothicCapitalZ], \
\[GothicCapitalM], \[GothicCapitalF]}, j\_{\[GothicCapitalZ], \
\[GothicCapitalM], \[GothicCapitalM]}} - 
                        m\_\(j\_{\[GothicCapitalG], \[GothicCapitalF]}\) - 
                        m\_\(j\_{\[GothicCapitalG], \
\[GothicCapitalM]}\))\))\)\ \((1\/2\ \((\(-\[GothicCapitalD]\_{k\_{\
\[GothicCapitalG], \[GothicCapitalF]}, i\_{\[GothicCapitalG], \
\[GothicCapitalF]}}\)\ a\_{i\_{\[GothicCapitalZ], \[GothicCapitalM], \
\[GothicCapitalF]}} - \[GothicCapitalD]\_{k\_{\[GothicCapitalG], \
\[GothicCapitalM]}, i\_{\[GothicCapitalG], \[GothicCapitalM]}}\ a\_{i\_{\
\[GothicCapitalZ], \[GothicCapitalM], \[GothicCapitalM]}} - \[GothicCapitalD]\
\_{k\_{\[GothicCapitalG], \[GothicCapitalF]}, j\_{\[GothicCapitalG], \
\[GothicCapitalF]}}\ a\_{j\_{\[GothicCapitalZ], \[GothicCapitalM], \
\[GothicCapitalF]}} - \[GothicCapitalD]\_{k\_{\[GothicCapitalG], \
\[GothicCapitalM]}, j\_{\[GothicCapitalG], \[GothicCapitalM]}}\ a\_{j\_{\
\[GothicCapitalZ], \[GothicCapitalM], \[GothicCapitalM]}} - \[GothicCapitalD]\
\_{k\_{\[GothicCapitalG], \[GothicCapitalF]}, i\_{\[GothicCapitalG], \
\[GothicCapitalF]}, j\_{\[GothicCapitalG], \[GothicCapitalF]}}\ a\_{i\_{\
\[GothicCapitalZ], \[GothicCapitalM], \[GothicCapitalF]}, j\_{\
\[GothicCapitalZ], \[GothicCapitalM], \[GothicCapitalF]}} - \[GothicCapitalD]\
\_{k\_{\[GothicCapitalG], \[GothicCapitalM]}, i\_{\[GothicCapitalG], \
\[GothicCapitalM]}, j\_{\[GothicCapitalG], \[GothicCapitalM]}}\ a\_{i\_{\
\[GothicCapitalZ], \[GothicCapitalM], \[GothicCapitalM]}, j\_{\
\[GothicCapitalZ], \[GothicCapitalM], \[GothicCapitalM]}} - \[GothicCapitalD]\
\_{i\_{\[GothicCapitalG], \[GothicCapitalF]}, j\_{\[GothicCapitalG], \
\[GothicCapitalF]}}\ \[GothicCapitalD]\_{k\_{\[GothicCapitalG], \
\[GothicCapitalM]}, i\_{\[GothicCapitalG], \[GothicCapitalM]}}\ a\_{i\_{\
\[GothicCapitalZ], \[GothicCapitalM], \[GothicCapitalF]}, i\_{\
\[GothicCapitalZ], \[GothicCapitalM], \[GothicCapitalM]}, j\_{\
\[GothicCapitalZ], \[GothicCapitalM], \[GothicCapitalF]}} - \[GothicCapitalD]\
\_{i\_{\[GothicCapitalG], \[GothicCapitalM]}, j\_{\[GothicCapitalG], \
\[GothicCapitalM]}}\ \[GothicCapitalD]\_{k\_{\[GothicCapitalG], \
\[GothicCapitalF]}, i\_{\[GothicCapitalG], \[GothicCapitalF]}}\ a\_{i\_{\
\[GothicCapitalZ], \[GothicCapitalM], \[GothicCapitalF]}, i\_{\
\[GothicCapitalZ], \[GothicCapitalM], \[GothicCapitalM]}, j\_{\
\[GothicCapitalZ], \[GothicCapitalM], \[GothicCapitalM]}} - \[GothicCapitalD]\
\_{i\_{\[GothicCapitalG], \[GothicCapitalF]}, j\_{\[GothicCapitalG], \
\[GothicCapitalF]}}\ \[GothicCapitalD]\_{k\_{\[GothicCapitalG], \
\[GothicCapitalM]}, j\_{\[GothicCapitalG], \[GothicCapitalM]}}\ a\_{i\_{\
\[GothicCapitalZ], \[GothicCapitalM], \[GothicCapitalF]}, j\_{\
\[GothicCapitalZ], \[GothicCapitalM], \[GothicCapitalF]}, j\_{\
\[GothicCapitalZ], \[GothicCapitalM], \[GothicCapitalM]}} - \[GothicCapitalD]\
\_{i\_{\[GothicCapitalG], \[GothicCapitalM]}, j\_{\[GothicCapitalG], \
\[GothicCapitalM]}}\ \[GothicCapitalD]\_{k\_{\[GothicCapitalG], \
\[GothicCapitalF]}, j\_{\[GothicCapitalG], \[GothicCapitalF]}}\ a\_{i\_{\
\[GothicCapitalZ], \[GothicCapitalM], \[GothicCapitalM]}, j\_{\
\[GothicCapitalZ], \[GothicCapitalM], \[GothicCapitalF]}, j\_{\
\[GothicCapitalZ], \[GothicCapitalM], \[GothicCapitalM]}} - \[GothicCapitalD]\
\_{i\_{\[GothicCapitalG], \[GothicCapitalM]}, j\_{\[GothicCapitalG], \
\[GothicCapitalM]}}\ \[GothicCapitalD]\_{k\_{\[GothicCapitalG], \
\[GothicCapitalF]}, i\_{\[GothicCapitalG], \[GothicCapitalF]}, j\_{\
\[GothicCapitalG], \[GothicCapitalF]}}\ a\_{i\_{\[GothicCapitalZ], \
\[GothicCapitalM], \[GothicCapitalF]}, i\_{\[GothicCapitalZ], \
\[GothicCapitalM], \[GothicCapitalM]}, j\_{\[GothicCapitalZ], \
\[GothicCapitalM], \[GothicCapitalF]}, j\_{\[GothicCapitalZ], \
\[GothicCapitalM], \[GothicCapitalM]}} - \[GothicCapitalD]\_{i\_{\
\[GothicCapitalG], \[GothicCapitalF]}, j\_{\[GothicCapitalG], \
\[GothicCapitalF]}}\ \[GothicCapitalD]\_{k\_{\[GothicCapitalG], \
\[GothicCapitalM]}, i\_{\[GothicCapitalG], \[GothicCapitalM]}, j\_{\
\[GothicCapitalG], \[GothicCapitalM]}}\ a\_{i\_{\[GothicCapitalZ], \
\[GothicCapitalM], \[GothicCapitalF]}, i\_{\[GothicCapitalZ], \
\[GothicCapitalM], \[GothicCapitalM]}, j\_{\[GothicCapitalZ], \
\[GothicCapitalM], \[GothicCapitalF]}, j\_{\[GothicCapitalZ], \
\[GothicCapitalM], \[GothicCapitalM]}} - 
                        m\_\(k\_{\[GothicCapitalG], \[GothicCapitalF]}\) - 
                        m\_\(k\_{\[GothicCapitalG], \[GothicCapitalM]}\))\) + 
                  m\_\(k\_{\[GothicCapitalG], \[GothicCapitalM]}\))\))\)\ r\_\
\({j}, {k}\) + \((\[GothicCapitalD]\_{j\_{\[GothicCapitalG], \
\[GothicCapitalM]}, i\_{\[GothicCapitalG], \[GothicCapitalM]}}\ \
\[GothicCapitalD]\_{k\_{\[GothicCapitalG], \[GothicCapitalF]}, i\_{\
\[GothicCapitalG], \[GothicCapitalF]}}\ a\_{i\_{\[GothicCapitalZ], \
\[GothicCapitalM], \[GothicCapitalF]}, i\_{\[GothicCapitalZ], \
\[GothicCapitalM], \[GothicCapitalM]}} + \[GothicCapitalD]\_{j\_{\
\[GothicCapitalG], \[GothicCapitalM]}, j\_{\[GothicCapitalG], \
\[GothicCapitalM]}}\ \[GothicCapitalD]\_{k\_{\[GothicCapitalG], \
\[GothicCapitalF]}, i\_{\[GothicCapitalG], \[GothicCapitalF]}}\ a\_{i\_{\
\[GothicCapitalZ], \[GothicCapitalM], \[GothicCapitalF]}, j\_{\
\[GothicCapitalZ], \[GothicCapitalM], \[GothicCapitalM]}} + \[GothicCapitalD]\
\_{j\_{\[GothicCapitalG], \[GothicCapitalM]}, i\_{\[GothicCapitalG], \
\[GothicCapitalM]}}\ \[GothicCapitalD]\_{k\_{\[GothicCapitalG], \
\[GothicCapitalF]}, j\_{\[GothicCapitalG], \[GothicCapitalF]}}\ a\_{i\_{\
\[GothicCapitalZ], \[GothicCapitalM], \[GothicCapitalM]}, j\_{\
\[GothicCapitalZ], \[GothicCapitalM], \[GothicCapitalF]}} + \[GothicCapitalD]\
\_{j\_{\[GothicCapitalG], \[GothicCapitalM]}, j\_{\[GothicCapitalG], \
\[GothicCapitalM]}}\ \[GothicCapitalD]\_{k\_{\[GothicCapitalG], \
\[GothicCapitalF]}, j\_{\[GothicCapitalG], \[GothicCapitalF]}}\ a\_{j\_{\
\[GothicCapitalZ], \[GothicCapitalM], \[GothicCapitalF]}, j\_{\
\[GothicCapitalZ], \[GothicCapitalM], \[GothicCapitalM]}} + \[GothicCapitalD]\
\_{j\_{\[GothicCapitalG], \[GothicCapitalM]}, i\_{\[GothicCapitalG], \
\[GothicCapitalM]}}\ \[GothicCapitalD]\_{k\_{\[GothicCapitalG], \
\[GothicCapitalF]}, i\_{\[GothicCapitalG], \[GothicCapitalF]}, j\_{\
\[GothicCapitalG], \[GothicCapitalF]}}\ a\_{i\_{\[GothicCapitalZ], \
\[GothicCapitalM], \[GothicCapitalF]}, i\_{\[GothicCapitalZ], \
\[GothicCapitalM], \[GothicCapitalM]}, j\_{\[GothicCapitalZ], \
\[GothicCapitalM], \[GothicCapitalF]}} + \[GothicCapitalD]\_{k\_{\
\[GothicCapitalG], \[GothicCapitalF]}, i\_{\[GothicCapitalG], \
\[GothicCapitalF]}}\ \[GothicCapitalD]\_{j\_{\[GothicCapitalG], \
\[GothicCapitalM]}, i\_{\[GothicCapitalG], \[GothicCapitalM]}, j\_{\
\[GothicCapitalG], \[GothicCapitalM]}}\ a\_{i\_{\[GothicCapitalZ], \
\[GothicCapitalM], \[GothicCapitalF]}, i\_{\[GothicCapitalZ], \
\[GothicCapitalM], \[GothicCapitalM]}, j\_{\[GothicCapitalZ], \
\[GothicCapitalM], \[GothicCapitalM]}} + \[GothicCapitalD]\_{j\_{\
\[GothicCapitalG], \[GothicCapitalM]}, j\_{\[GothicCapitalG], \
\[GothicCapitalM]}}\ \[GothicCapitalD]\_{k\_{\[GothicCapitalG], \
\[GothicCapitalF]}, i\_{\[GothicCapitalG], \[GothicCapitalF]}, j\_{\
\[GothicCapitalG], \[GothicCapitalF]}}\ a\_{i\_{\[GothicCapitalZ], \
\[GothicCapitalM], \[GothicCapitalF]}, j\_{\[GothicCapitalZ], \
\[GothicCapitalM], \[GothicCapitalF]}, j\_{\[GothicCapitalZ], \
\[GothicCapitalM], \[GothicCapitalM]}} + \[GothicCapitalD]\_{k\_{\
\[GothicCapitalG], \[GothicCapitalF]}, j\_{\[GothicCapitalG], \
\[GothicCapitalF]}}\ \[GothicCapitalD]\_{j\_{\[GothicCapitalG], \
\[GothicCapitalM]}, i\_{\[GothicCapitalG], \[GothicCapitalM]}, j\_{\
\[GothicCapitalG], \[GothicCapitalM]}}\ a\_{i\_{\[GothicCapitalZ], \
\[GothicCapitalM], \[GothicCapitalM]}, j\_{\[GothicCapitalZ], \
\[GothicCapitalM], \[GothicCapitalF]}, j\_{\[GothicCapitalZ], \
\[GothicCapitalM], \[GothicCapitalM]}} + \[GothicCapitalD]\_{j\_{\
\[GothicCapitalG], \[GothicCapitalM]}, i\_{\[GothicCapitalG], \
\[GothicCapitalM]}, j\_{\[GothicCapitalG], \[GothicCapitalM]}}\ \
\[GothicCapitalD]\_{k\_{\[GothicCapitalG], \[GothicCapitalF]}, i\_{\
\[GothicCapitalG], \[GothicCapitalF]}, j\_{\[GothicCapitalG], \
\[GothicCapitalF]}}\ a\_{i\_{\[GothicCapitalZ], \[GothicCapitalM], \
\[GothicCapitalF]}, i\_{\[GothicCapitalZ], \[GothicCapitalM], \
\[GothicCapitalM]}, j\_{\[GothicCapitalZ], \[GothicCapitalM], \
\[GothicCapitalF]}, j\_{\[GothicCapitalZ], \[GothicCapitalM], \
\[GothicCapitalM]}} + \((\[GothicCapitalD]\_{k\_{\[GothicCapitalG], \
\[GothicCapitalF]}, i\_{\[GothicCapitalG], \[GothicCapitalF]}}\ a\_{i\_{\
\[GothicCapitalZ], \[GothicCapitalM], \[GothicCapitalF]}} + \[GothicCapitalD]\
\_{k\_{\[GothicCapitalG], \[GothicCapitalF]}, j\_{\[GothicCapitalG], \
\[GothicCapitalF]}}\ a\_{j\_{\[GothicCapitalZ], \[GothicCapitalM], \
\[GothicCapitalF]}} + \[GothicCapitalD]\_{k\_{\[GothicCapitalG], \
\[GothicCapitalF]}, i\_{\[GothicCapitalG], \[GothicCapitalF]}, j\_{\
\[GothicCapitalG], \[GothicCapitalF]}}\ a\_{i\_{\[GothicCapitalZ], \
\[GothicCapitalM], \[GothicCapitalF]}, j\_{\[GothicCapitalZ], \
\[GothicCapitalM], \[GothicCapitalF]}} + \[GothicCapitalD]\_{i\_{\
\[GothicCapitalG], \[GothicCapitalM]}, j\_{\[GothicCapitalG], \
\[GothicCapitalM]}}\ \[GothicCapitalD]\_{k\_{\[GothicCapitalG], \
\[GothicCapitalF]}, i\_{\[GothicCapitalG], \[GothicCapitalF]}}\ a\_{i\_{\
\[GothicCapitalZ], \[GothicCapitalM], \[GothicCapitalF]}, i\_{\
\[GothicCapitalZ], \[GothicCapitalM], \[GothicCapitalM]}, j\_{\
\[GothicCapitalZ], \[GothicCapitalM], \[GothicCapitalM]}} + \[GothicCapitalD]\
\_{i\_{\[GothicCapitalG], \[GothicCapitalM]}, j\_{\[GothicCapitalG], \
\[GothicCapitalM]}}\ \[GothicCapitalD]\_{k\_{\[GothicCapitalG], \
\[GothicCapitalF]}, j\_{\[GothicCapitalG], \[GothicCapitalF]}}\ a\_{i\_{\
\[GothicCapitalZ], \[GothicCapitalM], \[GothicCapitalM]}, j\_{\
\[GothicCapitalZ], \[GothicCapitalM], \[GothicCapitalF]}, j\_{\
\[GothicCapitalZ], \[GothicCapitalM], \[GothicCapitalM]}} + \[GothicCapitalD]\
\_{i\_{\[GothicCapitalG], \[GothicCapitalM]}, j\_{\[GothicCapitalG], \
\[GothicCapitalM]}}\ \[GothicCapitalD]\_{k\_{\[GothicCapitalG], \
\[GothicCapitalF]}, i\_{\[GothicCapitalG], \[GothicCapitalF]}, j\_{\
\[GothicCapitalG], \[GothicCapitalF]}}\ a\_{i\_{\[GothicCapitalZ], \
\[GothicCapitalM], \[GothicCapitalF]}, i\_{\[GothicCapitalZ], \
\[GothicCapitalM], \[GothicCapitalM]}, j\_{\[GothicCapitalZ], \
\[GothicCapitalM], \[GothicCapitalF]}, j\_{\[GothicCapitalZ], \
\[GothicCapitalM], \[GothicCapitalM]}})\)\ \((1\/2\ \
\((\(-\[GothicCapitalD]\_{j\_{\[GothicCapitalG], \[GothicCapitalF]}, i\_{\
\[GothicCapitalG], \[GothicCapitalF]}}\)\ a\_{i\_{\[GothicCapitalZ], \
\[GothicCapitalM], \[GothicCapitalF]}} - \[GothicCapitalD]\_{j\_{\
\[GothicCapitalG], \[GothicCapitalM]}, i\_{\[GothicCapitalG], \
\[GothicCapitalM]}}\ a\_{i\_{\[GothicCapitalZ], \[GothicCapitalM], \
\[GothicCapitalM]}} - \[GothicCapitalD]\_{j\_{\[GothicCapitalG], \
\[GothicCapitalF]}, j\_{\[GothicCapitalG], \[GothicCapitalF]}}\ a\_{j\_{\
\[GothicCapitalZ], \[GothicCapitalM], \[GothicCapitalF]}} - \[GothicCapitalD]\
\_{j\_{\[GothicCapitalG], \[GothicCapitalM]}, j\_{\[GothicCapitalG], \
\[GothicCapitalM]}}\ a\_{j\_{\[GothicCapitalZ], \[GothicCapitalM], \
\[GothicCapitalM]}} - \[GothicCapitalD]\_{j\_{\[GothicCapitalG], \
\[GothicCapitalF]}, i\_{\[GothicCapitalG], \[GothicCapitalF]}, j\_{\
\[GothicCapitalG], \[GothicCapitalF]}}\ a\_{i\_{\[GothicCapitalZ], \
\[GothicCapitalM], \[GothicCapitalF]}, j\_{\[GothicCapitalZ], \
\[GothicCapitalM], \[GothicCapitalF]}} - \[GothicCapitalD]\_{j\_{\
\[GothicCapitalG], \[GothicCapitalM]}, i\_{\[GothicCapitalG], \
\[GothicCapitalM]}, j\_{\[GothicCapitalG], \[GothicCapitalM]}}\ a\_{i\_{\
\[GothicCapitalZ], \[GothicCapitalM], \[GothicCapitalM]}, j\_{\
\[GothicCapitalZ], \[GothicCapitalM], \[GothicCapitalM]}} - \[GothicCapitalD]\
\_{i\_{\[GothicCapitalG], \[GothicCapitalF]}, j\_{\[GothicCapitalG], \
\[GothicCapitalF]}}\ \[GothicCapitalD]\_{j\_{\[GothicCapitalG], \
\[GothicCapitalM]}, i\_{\[GothicCapitalG], \[GothicCapitalM]}}\ a\_{i\_{\
\[GothicCapitalZ], \[GothicCapitalM], \[GothicCapitalF]}, i\_{\
\[GothicCapitalZ], \[GothicCapitalM], \[GothicCapitalM]}, j\_{\
\[GothicCapitalZ], \[GothicCapitalM], \[GothicCapitalF]}} - \[GothicCapitalD]\
\_{i\_{\[GothicCapitalG], \[GothicCapitalM]}, j\_{\[GothicCapitalG], \
\[GothicCapitalM]}}\ \[GothicCapitalD]\_{j\_{\[GothicCapitalG], \
\[GothicCapitalF]}, i\_{\[GothicCapitalG], \[GothicCapitalF]}}\ a\_{i\_{\
\[GothicCapitalZ], \[GothicCapitalM], \[GothicCapitalF]}, i\_{\
\[GothicCapitalZ], \[GothicCapitalM], \[GothicCapitalM]}, j\_{\
\[GothicCapitalZ], \[GothicCapitalM], \[GothicCapitalM]}} - \[GothicCapitalD]\
\_{i\_{\[GothicCapitalG], \[GothicCapitalF]}, j\_{\[GothicCapitalG], \
\[GothicCapitalF]}}\ \[GothicCapitalD]\_{j\_{\[GothicCapitalG], \
\[GothicCapitalM]}, j\_{\[GothicCapitalG], \[GothicCapitalM]}}\ a\_{i\_{\
\[GothicCapitalZ], \[GothicCapitalM], \[GothicCapitalF]}, j\_{\
\[GothicCapitalZ], \[GothicCapitalM], \[GothicCapitalF]}, j\_{\
\[GothicCapitalZ], \[GothicCapitalM], \[GothicCapitalM]}} - \[GothicCapitalD]\
\_{i\_{\[GothicCapitalG], \[GothicCapitalM]}, j\_{\[GothicCapitalG], \
\[GothicCapitalM]}}\ \[GothicCapitalD]\_{j\_{\[GothicCapitalG], \
\[GothicCapitalF]}, j\_{\[GothicCapitalG], \[GothicCapitalF]}}\ a\_{i\_{\
\[GothicCapitalZ], \[GothicCapitalM], \[GothicCapitalM]}, j\_{\
\[GothicCapitalZ], \[GothicCapitalM], \[GothicCapitalF]}, j\_{\
\[GothicCapitalZ], \[GothicCapitalM], \[GothicCapitalM]}} - \[GothicCapitalD]\
\_{i\_{\[GothicCapitalG], \[GothicCapitalM]}, j\_{\[GothicCapitalG], \
\[GothicCapitalM]}}\ \[GothicCapitalD]\_{j\_{\[GothicCapitalG], \
\[GothicCapitalF]}, i\_{\[GothicCapitalG], \[GothicCapitalF]}, j\_{\
\[GothicCapitalG], \[GothicCapitalF]}}\ a\_{i\_{\[GothicCapitalZ], \
\[GothicCapitalM], \[GothicCapitalF]}, i\_{\[GothicCapitalZ], \
\[GothicCapitalM], \[GothicCapitalM]}, j\_{\[GothicCapitalZ], \
\[GothicCapitalM], \[GothicCapitalF]}, j\_{\[GothicCapitalZ], \
\[GothicCapitalM], \[GothicCapitalM]}} - \[GothicCapitalD]\_{i\_{\
\[GothicCapitalG], \[GothicCapitalF]}, j\_{\[GothicCapitalG], \
\[GothicCapitalF]}}\ \[GothicCapitalD]\_{j\_{\[GothicCapitalG], \
\[GothicCapitalM]}, i\_{\[GothicCapitalG], \[GothicCapitalM]}, j\_{\
\[GothicCapitalG], \[GothicCapitalM]}}\ a\_{i\_{\[GothicCapitalZ], \
\[GothicCapitalM], \[GothicCapitalF]}, i\_{\[GothicCapitalZ], \
\[GothicCapitalM], \[GothicCapitalM]}, j\_{\[GothicCapitalZ], \
\[GothicCapitalM], \[GothicCapitalF]}, j\_{\[GothicCapitalZ], \
\[GothicCapitalM], \[GothicCapitalM]}} - 
                        m\_\(j\_{\[GothicCapitalG], \[GothicCapitalF]}\) - 
                        m\_\(j\_{\[GothicCapitalG], \[GothicCapitalM]}\))\) + 
                  m\_\(j\_{\[GothicCapitalG], \[GothicCapitalM]}\))\) + \((\
\[GothicCapitalD]\_{j\_{\[GothicCapitalG], \[GothicCapitalM]}, i\_{\
\[GothicCapitalG], \[GothicCapitalM]}}\ a\_{i\_{\[GothicCapitalZ], \
\[GothicCapitalM], \[GothicCapitalM]}} + \[GothicCapitalD]\_{j\_{\
\[GothicCapitalG], \[GothicCapitalM]}, j\_{\[GothicCapitalG], \
\[GothicCapitalM]}}\ a\_{j\_{\[GothicCapitalZ], \[GothicCapitalM], \
\[GothicCapitalM]}} + \[GothicCapitalD]\_{j\_{\[GothicCapitalG], \
\[GothicCapitalM]}, i\_{\[GothicCapitalG], \[GothicCapitalM]}, j\_{\
\[GothicCapitalG], \[GothicCapitalM]}}\ a\_{i\_{\[GothicCapitalZ], \
\[GothicCapitalM], \[GothicCapitalM]}, j\_{\[GothicCapitalZ], \
\[GothicCapitalM], \[GothicCapitalM]}} + \[GothicCapitalD]\_{i\_{\
\[GothicCapitalG], \[GothicCapitalF]}, j\_{\[GothicCapitalG], \
\[GothicCapitalF]}}\ \[GothicCapitalD]\_{j\_{\[GothicCapitalG], \
\[GothicCapitalM]}, i\_{\[GothicCapitalG], \[GothicCapitalM]}}\ a\_{i\_{\
\[GothicCapitalZ], \[GothicCapitalM], \[GothicCapitalF]}, i\_{\
\[GothicCapitalZ], \[GothicCapitalM], \[GothicCapitalM]}, j\_{\
\[GothicCapitalZ], \[GothicCapitalM], \[GothicCapitalF]}} + \[GothicCapitalD]\
\_{i\_{\[GothicCapitalG], \[GothicCapitalF]}, j\_{\[GothicCapitalG], \
\[GothicCapitalF]}}\ \[GothicCapitalD]\_{j\_{\[GothicCapitalG], \
\[GothicCapitalM]}, j\_{\[GothicCapitalG], \[GothicCapitalM]}}\ a\_{i\_{\
\[GothicCapitalZ], \[GothicCapitalM], \[GothicCapitalF]}, j\_{\
\[GothicCapitalZ], \[GothicCapitalM], \[GothicCapitalF]}, j\_{\
\[GothicCapitalZ], \[GothicCapitalM], \[GothicCapitalM]}} + \[GothicCapitalD]\
\_{i\_{\[GothicCapitalG], \[GothicCapitalF]}, j\_{\[GothicCapitalG], \
\[GothicCapitalF]}}\ \[GothicCapitalD]\_{j\_{\[GothicCapitalG], \
\[GothicCapitalM]}, i\_{\[GothicCapitalG], \[GothicCapitalM]}, j\_{\
\[GothicCapitalG], \[GothicCapitalM]}}\ a\_{i\_{\[GothicCapitalZ], \
\[GothicCapitalM], \[GothicCapitalF]}, i\_{\[GothicCapitalZ], \
\[GothicCapitalM], \[GothicCapitalM]}, j\_{\[GothicCapitalZ], \
\[GothicCapitalM], \[GothicCapitalF]}, j\_{\[GothicCapitalZ], \
\[GothicCapitalM], \[GothicCapitalM]}})\)\ \((m\_\(k\_{\[GothicCapitalG], \
\[GothicCapitalF]}\) + 
                  1\/2\ \((\(-\[GothicCapitalD]\_{k\_{\[GothicCapitalG], \
\[GothicCapitalF]}, i\_{\[GothicCapitalG], \[GothicCapitalF]}}\)\ a\_{i\_{\
\[GothicCapitalZ], \[GothicCapitalM], \[GothicCapitalF]}} - \[GothicCapitalD]\
\_{k\_{\[GothicCapitalG], \[GothicCapitalM]}, i\_{\[GothicCapitalG], \
\[GothicCapitalM]}}\ a\_{i\_{\[GothicCapitalZ], \[GothicCapitalM], \
\[GothicCapitalM]}} - \[GothicCapitalD]\_{k\_{\[GothicCapitalG], \
\[GothicCapitalF]}, j\_{\[GothicCapitalG], \[GothicCapitalF]}}\ a\_{j\_{\
\[GothicCapitalZ], \[GothicCapitalM], \[GothicCapitalF]}} - \[GothicCapitalD]\
\_{k\_{\[GothicCapitalG], \[GothicCapitalM]}, j\_{\[GothicCapitalG], \
\[GothicCapitalM]}}\ a\_{j\_{\[GothicCapitalZ], \[GothicCapitalM], \
\[GothicCapitalM]}} - \[GothicCapitalD]\_{k\_{\[GothicCapitalG], \
\[GothicCapitalF]}, i\_{\[GothicCapitalG], \[GothicCapitalF]}, j\_{\
\[GothicCapitalG], \[GothicCapitalF]}}\ a\_{i\_{\[GothicCapitalZ], \
\[GothicCapitalM], \[GothicCapitalF]}, j\_{\[GothicCapitalZ], \
\[GothicCapitalM], \[GothicCapitalF]}} - \[GothicCapitalD]\_{k\_{\
\[GothicCapitalG], \[GothicCapitalM]}, i\_{\[GothicCapitalG], \
\[GothicCapitalM]}, j\_{\[GothicCapitalG], \[GothicCapitalM]}}\ a\_{i\_{\
\[GothicCapitalZ], \[GothicCapitalM], \[GothicCapitalM]}, j\_{\
\[GothicCapitalZ], \[GothicCapitalM], \[GothicCapitalM]}} - \[GothicCapitalD]\
\_{i\_{\[GothicCapitalG], \[GothicCapitalF]}, j\_{\[GothicCapitalG], \
\[GothicCapitalF]}}\ \[GothicCapitalD]\_{k\_{\[GothicCapitalG], \
\[GothicCapitalM]}, i\_{\[GothicCapitalG], \[GothicCapitalM]}}\ a\_{i\_{\
\[GothicCapitalZ], \[GothicCapitalM], \[GothicCapitalF]}, i\_{\
\[GothicCapitalZ], \[GothicCapitalM], \[GothicCapitalM]}, j\_{\
\[GothicCapitalZ], \[GothicCapitalM], \[GothicCapitalF]}} - \[GothicCapitalD]\
\_{i\_{\[GothicCapitalG], \[GothicCapitalM]}, j\_{\[GothicCapitalG], \
\[GothicCapitalM]}}\ \[GothicCapitalD]\_{k\_{\[GothicCapitalG], \
\[GothicCapitalF]}, i\_{\[GothicCapitalG], \[GothicCapitalF]}}\ a\_{i\_{\
\[GothicCapitalZ], \[GothicCapitalM], \[GothicCapitalF]}, i\_{\
\[GothicCapitalZ], \[GothicCapitalM], \[GothicCapitalM]}, j\_{\
\[GothicCapitalZ], \[GothicCapitalM], \[GothicCapitalM]}} - \[GothicCapitalD]\
\_{i\_{\[GothicCapitalG], \[GothicCapitalF]}, j\_{\[GothicCapitalG], \
\[GothicCapitalF]}}\ \[GothicCapitalD]\_{k\_{\[GothicCapitalG], \
\[GothicCapitalM]}, j\_{\[GothicCapitalG], \[GothicCapitalM]}}\ a\_{i\_{\
\[GothicCapitalZ], \[GothicCapitalM], \[GothicCapitalF]}, j\_{\
\[GothicCapitalZ], \[GothicCapitalM], \[GothicCapitalF]}, j\_{\
\[GothicCapitalZ], \[GothicCapitalM], \[GothicCapitalM]}} - \[GothicCapitalD]\
\_{i\_{\[GothicCapitalG], \[GothicCapitalM]}, j\_{\[GothicCapitalG], \
\[GothicCapitalM]}}\ \[GothicCapitalD]\_{k\_{\[GothicCapitalG], \
\[GothicCapitalF]}, j\_{\[GothicCapitalG], \[GothicCapitalF]}}\ a\_{i\_{\
\[GothicCapitalZ], \[GothicCapitalM], \[GothicCapitalM]}, j\_{\
\[GothicCapitalZ], \[GothicCapitalM], \[GothicCapitalF]}, j\_{\
\[GothicCapitalZ], \[GothicCapitalM], \[GothicCapitalM]}} - \[GothicCapitalD]\
\_{i\_{\[GothicCapitalG], \[GothicCapitalM]}, j\_{\[GothicCapitalG], \
\[GothicCapitalM]}}\ \[GothicCapitalD]\_{k\_{\[GothicCapitalG], \
\[GothicCapitalF]}, i\_{\[GothicCapitalG], \[GothicCapitalF]}, j\_{\
\[GothicCapitalG], \[GothicCapitalF]}}\ a\_{i\_{\[GothicCapitalZ], \
\[GothicCapitalM], \[GothicCapitalF]}, i\_{\[GothicCapitalZ], \
\[GothicCapitalM], \[GothicCapitalM]}, j\_{\[GothicCapitalZ], \
\[GothicCapitalM], \[GothicCapitalF]}, j\_{\[GothicCapitalZ], \
\[GothicCapitalM], \[GothicCapitalM]}} - \[GothicCapitalD]\_{i\_{\
\[GothicCapitalG], \[GothicCapitalF]}, j\_{\[GothicCapitalG], \
\[GothicCapitalF]}}\ \[GothicCapitalD]\_{k\_{\[GothicCapitalG], \
\[GothicCapitalM]}, i\_{\[GothicCapitalG], \[GothicCapitalM]}, j\_{\
\[GothicCapitalG], \[GothicCapitalM]}}\ a\_{i\_{\[GothicCapitalZ], \
\[GothicCapitalM], \[GothicCapitalF]}, i\_{\[GothicCapitalZ], \
\[GothicCapitalM], \[GothicCapitalM]}, j\_{\[GothicCapitalZ], \
\[GothicCapitalM], \[GothicCapitalF]}, j\_{\[GothicCapitalZ], \
\[GothicCapitalM], \[GothicCapitalM]}} - 
                        m\_\(k\_{\[GothicCapitalG], \[GothicCapitalF]}\) - 
                        m\_\(k\_{\[GothicCapitalG], \
\[GothicCapitalM]}\))\))\) + \((1\/2\ \((\(-\[GothicCapitalD]\_{j\_{\
\[GothicCapitalG], \[GothicCapitalF]}, i\_{\[GothicCapitalG], \
\[GothicCapitalF]}}\)\ a\_{i\_{\[GothicCapitalZ], \[GothicCapitalM], \
\[GothicCapitalF]}} - \[GothicCapitalD]\_{j\_{\[GothicCapitalG], \
\[GothicCapitalM]}, i\_{\[GothicCapitalG], \[GothicCapitalM]}}\ a\_{i\_{\
\[GothicCapitalZ], \[GothicCapitalM], \[GothicCapitalM]}} - \[GothicCapitalD]\
\_{j\_{\[GothicCapitalG], \[GothicCapitalF]}, j\_{\[GothicCapitalG], \
\[GothicCapitalF]}}\ a\_{j\_{\[GothicCapitalZ], \[GothicCapitalM], \
\[GothicCapitalF]}} - \[GothicCapitalD]\_{j\_{\[GothicCapitalG], \
\[GothicCapitalM]}, j\_{\[GothicCapitalG], \[GothicCapitalM]}}\ a\_{j\_{\
\[GothicCapitalZ], \[GothicCapitalM], \[GothicCapitalM]}} - \[GothicCapitalD]\
\_{j\_{\[GothicCapitalG], \[GothicCapitalF]}, i\_{\[GothicCapitalG], \
\[GothicCapitalF]}, j\_{\[GothicCapitalG], \[GothicCapitalF]}}\ a\_{i\_{\
\[GothicCapitalZ], \[GothicCapitalM], \[GothicCapitalF]}, j\_{\
\[GothicCapitalZ], \[GothicCapitalM], \[GothicCapitalF]}} - \[GothicCapitalD]\
\_{j\_{\[GothicCapitalG], \[GothicCapitalM]}, i\_{\[GothicCapitalG], \
\[GothicCapitalM]}, j\_{\[GothicCapitalG], \[GothicCapitalM]}}\ a\_{i\_{\
\[GothicCapitalZ], \[GothicCapitalM], \[GothicCapitalM]}, j\_{\
\[GothicCapitalZ], \[GothicCapitalM], \[GothicCapitalM]}} - \[GothicCapitalD]\
\_{i\_{\[GothicCapitalG], \[GothicCapitalF]}, j\_{\[GothicCapitalG], \
\[GothicCapitalF]}}\ \[GothicCapitalD]\_{j\_{\[GothicCapitalG], \
\[GothicCapitalM]}, i\_{\[GothicCapitalG], \[GothicCapitalM]}}\ a\_{i\_{\
\[GothicCapitalZ], \[GothicCapitalM], \[GothicCapitalF]}, i\_{\
\[GothicCapitalZ], \[GothicCapitalM], \[GothicCapitalM]}, j\_{\
\[GothicCapitalZ], \[GothicCapitalM], \[GothicCapitalF]}} - \[GothicCapitalD]\
\_{i\_{\[GothicCapitalG], \[GothicCapitalM]}, j\_{\[GothicCapitalG], \
\[GothicCapitalM]}}\ \[GothicCapitalD]\_{j\_{\[GothicCapitalG], \
\[GothicCapitalF]}, i\_{\[GothicCapitalG], \[GothicCapitalF]}}\ a\_{i\_{\
\[GothicCapitalZ], \[GothicCapitalM], \[GothicCapitalF]}, i\_{\
\[GothicCapitalZ], \[GothicCapitalM], \[GothicCapitalM]}, j\_{\
\[GothicCapitalZ], \[GothicCapitalM], \[GothicCapitalM]}} - \[GothicCapitalD]\
\_{i\_{\[GothicCapitalG], \[GothicCapitalF]}, j\_{\[GothicCapitalG], \
\[GothicCapitalF]}}\ \[GothicCapitalD]\_{j\_{\[GothicCapitalG], \
\[GothicCapitalM]}, j\_{\[GothicCapitalG], \[GothicCapitalM]}}\ a\_{i\_{\
\[GothicCapitalZ], \[GothicCapitalM], \[GothicCapitalF]}, j\_{\
\[GothicCapitalZ], \[GothicCapitalM], \[GothicCapitalF]}, j\_{\
\[GothicCapitalZ], \[GothicCapitalM], \[GothicCapitalM]}} - \[GothicCapitalD]\
\_{i\_{\[GothicCapitalG], \[GothicCapitalM]}, j\_{\[GothicCapitalG], \
\[GothicCapitalM]}}\ \[GothicCapitalD]\_{j\_{\[GothicCapitalG], \
\[GothicCapitalF]}, j\_{\[GothicCapitalG], \[GothicCapitalF]}}\ a\_{i\_{\
\[GothicCapitalZ], \[GothicCapitalM], \[GothicCapitalM]}, j\_{\
\[GothicCapitalZ], \[GothicCapitalM], \[GothicCapitalF]}, j\_{\
\[GothicCapitalZ], \[GothicCapitalM], \[GothicCapitalM]}} - \[GothicCapitalD]\
\_{i\_{\[GothicCapitalG], \[GothicCapitalM]}, j\_{\[GothicCapitalG], \
\[GothicCapitalM]}}\ \[GothicCapitalD]\_{j\_{\[GothicCapitalG], \
\[GothicCapitalF]}, i\_{\[GothicCapitalG], \[GothicCapitalF]}, j\_{\
\[GothicCapitalG], \[GothicCapitalF]}}\ a\_{i\_{\[GothicCapitalZ], \
\[GothicCapitalM], \[GothicCapitalF]}, i\_{\[GothicCapitalZ], \
\[GothicCapitalM], \[GothicCapitalM]}, j\_{\[GothicCapitalZ], \
\[GothicCapitalM], \[GothicCapitalF]}, j\_{\[GothicCapitalZ], \
\[GothicCapitalM], \[GothicCapitalM]}} - \[GothicCapitalD]\_{i\_{\
\[GothicCapitalG], \[GothicCapitalF]}, j\_{\[GothicCapitalG], \
\[GothicCapitalF]}}\ \[GothicCapitalD]\_{j\_{\[GothicCapitalG], \
\[GothicCapitalM]}, i\_{\[GothicCapitalG], \[GothicCapitalM]}, j\_{\
\[GothicCapitalG], \[GothicCapitalM]}}\ a\_{i\_{\[GothicCapitalZ], \
\[GothicCapitalM], \[GothicCapitalF]}, i\_{\[GothicCapitalZ], \
\[GothicCapitalM], \[GothicCapitalM]}, j\_{\[GothicCapitalZ], \
\[GothicCapitalM], \[GothicCapitalF]}, j\_{\[GothicCapitalZ], \
\[GothicCapitalM], \[GothicCapitalM]}} - 
                        m\_\(j\_{\[GothicCapitalG], \[GothicCapitalF]}\) - 
                        m\_\(j\_{\[GothicCapitalG], \[GothicCapitalM]}\))\) + 
                  m\_\(j\_{\[GothicCapitalG], \[GothicCapitalM]}\))\)\ \((m\_\
\(k\_{\[GothicCapitalG], \[GothicCapitalF]}\) + 
                  1\/2\ \((\(-\[GothicCapitalD]\_{k\_{\[GothicCapitalG], \
\[GothicCapitalF]}, i\_{\[GothicCapitalG], \[GothicCapitalF]}}\)\ a\_{i\_{\
\[GothicCapitalZ], \[GothicCapitalM], \[GothicCapitalF]}} - \[GothicCapitalD]\
\_{k\_{\[GothicCapitalG], \[GothicCapitalM]}, i\_{\[GothicCapitalG], \
\[GothicCapitalM]}}\ a\_{i\_{\[GothicCapitalZ], \[GothicCapitalM], \
\[GothicCapitalM]}} - \[GothicCapitalD]\_{k\_{\[GothicCapitalG], \
\[GothicCapitalF]}, j\_{\[GothicCapitalG], \[GothicCapitalF]}}\ a\_{j\_{\
\[GothicCapitalZ], \[GothicCapitalM], \[GothicCapitalF]}} - \[GothicCapitalD]\
\_{k\_{\[GothicCapitalG], \[GothicCapitalM]}, j\_{\[GothicCapitalG], \
\[GothicCapitalM]}}\ a\_{j\_{\[GothicCapitalZ], \[GothicCapitalM], \
\[GothicCapitalM]}} - \[GothicCapitalD]\_{k\_{\[GothicCapitalG], \
\[GothicCapitalF]}, i\_{\[GothicCapitalG], \[GothicCapitalF]}, j\_{\
\[GothicCapitalG], \[GothicCapitalF]}}\ a\_{i\_{\[GothicCapitalZ], \
\[GothicCapitalM], \[GothicCapitalF]}, j\_{\[GothicCapitalZ], \
\[GothicCapitalM], \[GothicCapitalF]}} - \[GothicCapitalD]\_{k\_{\
\[GothicCapitalG], \[GothicCapitalM]}, i\_{\[GothicCapitalG], \
\[GothicCapitalM]}, j\_{\[GothicCapitalG], \[GothicCapitalM]}}\ a\_{i\_{\
\[GothicCapitalZ], \[GothicCapitalM], \[GothicCapitalM]}, j\_{\
\[GothicCapitalZ], \[GothicCapitalM], \[GothicCapitalM]}} - \[GothicCapitalD]\
\_{i\_{\[GothicCapitalG], \[GothicCapitalF]}, j\_{\[GothicCapitalG], \
\[GothicCapitalF]}}\ \[GothicCapitalD]\_{k\_{\[GothicCapitalG], \
\[GothicCapitalM]}, i\_{\[GothicCapitalG], \[GothicCapitalM]}}\ a\_{i\_{\
\[GothicCapitalZ], \[GothicCapitalM], \[GothicCapitalF]}, i\_{\
\[GothicCapitalZ], \[GothicCapitalM], \[GothicCapitalM]}, j\_{\
\[GothicCapitalZ], \[GothicCapitalM], \[GothicCapitalF]}} - \[GothicCapitalD]\
\_{i\_{\[GothicCapitalG], \[GothicCapitalM]}, j\_{\[GothicCapitalG], \
\[GothicCapitalM]}}\ \[GothicCapitalD]\_{k\_{\[GothicCapitalG], \
\[GothicCapitalF]}, i\_{\[GothicCapitalG], \[GothicCapitalF]}}\ a\_{i\_{\
\[GothicCapitalZ], \[GothicCapitalM], \[GothicCapitalF]}, i\_{\
\[GothicCapitalZ], \[GothicCapitalM], \[GothicCapitalM]}, j\_{\
\[GothicCapitalZ], \[GothicCapitalM], \[GothicCapitalM]}} - \[GothicCapitalD]\
\_{i\_{\[GothicCapitalG], \[GothicCapitalF]}, j\_{\[GothicCapitalG], \
\[GothicCapitalF]}}\ \[GothicCapitalD]\_{k\_{\[GothicCapitalG], \
\[GothicCapitalM]}, j\_{\[GothicCapitalG], \[GothicCapitalM]}}\ a\_{i\_{\
\[GothicCapitalZ], \[GothicCapitalM], \[GothicCapitalF]}, j\_{\
\[GothicCapitalZ], \[GothicCapitalM], \[GothicCapitalF]}, j\_{\
\[GothicCapitalZ], \[GothicCapitalM], \[GothicCapitalM]}} - \[GothicCapitalD]\
\_{i\_{\[GothicCapitalG], \[GothicCapitalM]}, j\_{\[GothicCapitalG], \
\[GothicCapitalM]}}\ \[GothicCapitalD]\_{k\_{\[GothicCapitalG], \
\[GothicCapitalF]}, j\_{\[GothicCapitalG], \[GothicCapitalF]}}\ a\_{i\_{\
\[GothicCapitalZ], \[GothicCapitalM], \[GothicCapitalM]}, j\_{\
\[GothicCapitalZ], \[GothicCapitalM], \[GothicCapitalF]}, j\_{\
\[GothicCapitalZ], \[GothicCapitalM], \[GothicCapitalM]}} - \[GothicCapitalD]\
\_{i\_{\[GothicCapitalG], \[GothicCapitalM]}, j\_{\[GothicCapitalG], \
\[GothicCapitalM]}}\ \[GothicCapitalD]\_{k\_{\[GothicCapitalG], \
\[GothicCapitalF]}, i\_{\[GothicCapitalG], \[GothicCapitalF]}, j\_{\
\[GothicCapitalG], \[GothicCapitalF]}}\ a\_{i\_{\[GothicCapitalZ], \
\[GothicCapitalM], \[GothicCapitalF]}, i\_{\[GothicCapitalZ], \
\[GothicCapitalM], \[GothicCapitalM]}, j\_{\[GothicCapitalZ], \
\[GothicCapitalM], \[GothicCapitalF]}, j\_{\[GothicCapitalZ], \
\[GothicCapitalM], \[GothicCapitalM]}} - \[GothicCapitalD]\_{i\_{\
\[GothicCapitalG], \[GothicCapitalF]}, j\_{\[GothicCapitalG], \
\[GothicCapitalF]}}\ \[GothicCapitalD]\_{k\_{\[GothicCapitalG], \
\[GothicCapitalM]}, i\_{\[GothicCapitalG], \[GothicCapitalM]}, j\_{\
\[GothicCapitalG], \[GothicCapitalM]}}\ a\_{i\_{\[GothicCapitalZ], \
\[GothicCapitalM], \[GothicCapitalF]}, i\_{\[GothicCapitalZ], \
\[GothicCapitalM], \[GothicCapitalM]}, j\_{\[GothicCapitalZ], \
\[GothicCapitalM], \[GothicCapitalF]}, j\_{\[GothicCapitalZ], \
\[GothicCapitalM], \[GothicCapitalM]}} - 
                        m\_\(k\_{\[GothicCapitalG], \[GothicCapitalF]}\) - 
                        m\_\(k\_{\[GothicCapitalG], \
\[GothicCapitalM]}\))\))\))\)\ r\_\({k}, {j}\) + \((\[GothicCapitalD]\_{j\_{\
\[GothicCapitalG], \[GothicCapitalF]}, k\_{\[GothicCapitalG], \
\[GothicCapitalF]}} + \[GothicCapitalD]\_{j\_{\[GothicCapitalG], \
\[GothicCapitalF]}, k\_{\[GothicCapitalG], \[GothicCapitalF]}, i\_{\
\[GothicCapitalG], \[GothicCapitalF]}}\ a\_{i\_{\[GothicCapitalZ], \
\[GothicCapitalM], \[GothicCapitalF]}} + \[GothicCapitalD]\_{j\_{\
\[GothicCapitalG], \[GothicCapitalF]}, k\_{\[GothicCapitalG], \
\[GothicCapitalF]}, j\_{\[GothicCapitalG], \[GothicCapitalF]}}\ a\_{j\_{\
\[GothicCapitalZ], \[GothicCapitalM], \[GothicCapitalF]}} + \((\(-\
\[GothicCapitalD]\_{i\_{\[GothicCapitalG], \[GothicCapitalF]}, j\_{\
\[GothicCapitalG], \[GothicCapitalF]}}\)\ \[GothicCapitalD]\_{j\_{\
\[GothicCapitalG], \[GothicCapitalF]}, k\_{\[GothicCapitalG], \
\[GothicCapitalF]}} + \[GothicCapitalD]\_{j\_{\[GothicCapitalG], \
\[GothicCapitalF]}, k\_{\[GothicCapitalG], \[GothicCapitalF]}, i\_{\
\[GothicCapitalG], \[GothicCapitalF]}, j\_{\[GothicCapitalG], \
\[GothicCapitalF]}})\)\ a\_{i\_{\[GothicCapitalZ], \[GothicCapitalM], \
\[GothicCapitalF]}, j\_{\[GothicCapitalZ], \[GothicCapitalM], \
\[GothicCapitalF]}} + \[GothicCapitalD]\_{i\_{\[GothicCapitalG], \
\[GothicCapitalM]}, j\_{\[GothicCapitalG], \[GothicCapitalM]}}\ \
\[GothicCapitalD]\_{j\_{\[GothicCapitalG], \[GothicCapitalF]}, k\_{\
\[GothicCapitalG], \[GothicCapitalF]}, i\_{\[GothicCapitalG], \
\[GothicCapitalF]}}\ a\_{i\_{\[GothicCapitalZ], \[GothicCapitalM], \
\[GothicCapitalF]}, i\_{\[GothicCapitalZ], \[GothicCapitalM], \
\[GothicCapitalM]}, j\_{\[GothicCapitalZ], \[GothicCapitalM], \
\[GothicCapitalM]}} + \[GothicCapitalD]\_{i\_{\[GothicCapitalG], \
\[GothicCapitalM]}, j\_{\[GothicCapitalG], \[GothicCapitalM]}}\ \
\[GothicCapitalD]\_{j\_{\[GothicCapitalG], \[GothicCapitalF]}, k\_{\
\[GothicCapitalG], \[GothicCapitalF]}, j\_{\[GothicCapitalG], \
\[GothicCapitalF]}}\ a\_{i\_{\[GothicCapitalZ], \[GothicCapitalM], \
\[GothicCapitalM]}, j\_{\[GothicCapitalZ], \[GothicCapitalM], \
\[GothicCapitalF]}, j\_{\[GothicCapitalZ], \[GothicCapitalM], \
\[GothicCapitalM]}} + \((\(-\[GothicCapitalD]\_{i\_{\[GothicCapitalG], \
\[GothicCapitalF]}, j\_{\[GothicCapitalG], \[GothicCapitalF]}}\)\ \
\[GothicCapitalD]\_{i\_{\[GothicCapitalG], \[GothicCapitalM]}, j\_{\
\[GothicCapitalG], \[GothicCapitalM]}}\ \[GothicCapitalD]\_{j\_{\
\[GothicCapitalG], \[GothicCapitalF]}, k\_{\[GothicCapitalG], \
\[GothicCapitalF]}} + \[GothicCapitalD]\_{i\_{\[GothicCapitalG], \
\[GothicCapitalM]}, j\_{\[GothicCapitalG], \[GothicCapitalM]}}\ \
\[GothicCapitalD]\_{j\_{\[GothicCapitalG], \[GothicCapitalF]}, k\_{\
\[GothicCapitalG], \[GothicCapitalF]}, i\_{\[GothicCapitalG], \
\[GothicCapitalF]}, j\_{\[GothicCapitalG], \[GothicCapitalF]}})\)\ a\_{i\_{\
\[GothicCapitalZ], \[GothicCapitalM], \[GothicCapitalF]}, i\_{\
\[GothicCapitalZ], \[GothicCapitalM], \[GothicCapitalM]}, j\_{\
\[GothicCapitalZ], \[GothicCapitalM], \[GothicCapitalF]}, j\_{\
\[GothicCapitalZ], \[GothicCapitalM], \[GothicCapitalM]}} + \((\
\[GothicCapitalD]\_{k\_{\[GothicCapitalG], \[GothicCapitalF]}, i\_{\
\[GothicCapitalG], \[GothicCapitalF]}}\ a\_{i\_{\[GothicCapitalZ], \
\[GothicCapitalM], \[GothicCapitalF]}} + \[GothicCapitalD]\_{k\_{\
\[GothicCapitalG], \[GothicCapitalF]}, j\_{\[GothicCapitalG], \
\[GothicCapitalF]}}\ a\_{j\_{\[GothicCapitalZ], \[GothicCapitalM], \
\[GothicCapitalF]}} + \[GothicCapitalD]\_{k\_{\[GothicCapitalG], \
\[GothicCapitalF]}, i\_{\[GothicCapitalG], \[GothicCapitalF]}, j\_{\
\[GothicCapitalG], \[GothicCapitalF]}}\ a\_{i\_{\[GothicCapitalZ], \
\[GothicCapitalM], \[GothicCapitalF]}, j\_{\[GothicCapitalZ], \
\[GothicCapitalM], \[GothicCapitalF]}} + \[GothicCapitalD]\_{i\_{\
\[GothicCapitalG], \[GothicCapitalM]}, j\_{\[GothicCapitalG], \
\[GothicCapitalM]}}\ \[GothicCapitalD]\_{k\_{\[GothicCapitalG], \
\[GothicCapitalF]}, i\_{\[GothicCapitalG], \[GothicCapitalF]}}\ a\_{i\_{\
\[GothicCapitalZ], \[GothicCapitalM], \[GothicCapitalF]}, i\_{\
\[GothicCapitalZ], \[GothicCapitalM], \[GothicCapitalM]}, j\_{\
\[GothicCapitalZ], \[GothicCapitalM], \[GothicCapitalM]}} + \[GothicCapitalD]\
\_{i\_{\[GothicCapitalG], \[GothicCapitalM]}, j\_{\[GothicCapitalG], \
\[GothicCapitalM]}}\ \[GothicCapitalD]\_{k\_{\[GothicCapitalG], \
\[GothicCapitalF]}, j\_{\[GothicCapitalG], \[GothicCapitalF]}}\ a\_{i\_{\
\[GothicCapitalZ], \[GothicCapitalM], \[GothicCapitalM]}, j\_{\
\[GothicCapitalZ], \[GothicCapitalM], \[GothicCapitalF]}, j\_{\
\[GothicCapitalZ], \[GothicCapitalM], \[GothicCapitalM]}} + \[GothicCapitalD]\
\_{i\_{\[GothicCapitalG], \[GothicCapitalM]}, j\_{\[GothicCapitalG], \
\[GothicCapitalM]}}\ \[GothicCapitalD]\_{k\_{\[GothicCapitalG], \
\[GothicCapitalF]}, i\_{\[GothicCapitalG], \[GothicCapitalF]}, j\_{\
\[GothicCapitalG], \[GothicCapitalF]}}\ a\_{i\_{\[GothicCapitalZ], \
\[GothicCapitalM], \[GothicCapitalF]}, i\_{\[GothicCapitalZ], \
\[GothicCapitalM], \[GothicCapitalM]}, j\_{\[GothicCapitalZ], \
\[GothicCapitalM], \[GothicCapitalF]}, j\_{\[GothicCapitalZ], \
\[GothicCapitalM], \[GothicCapitalM]}})\)\ \((m\_\(j\_{\[GothicCapitalG], \
\[GothicCapitalF]}\) + 
                  1\/2\ \((\(-\[GothicCapitalD]\_{j\_{\[GothicCapitalG], \
\[GothicCapitalF]}, i\_{\[GothicCapitalG], \[GothicCapitalF]}}\)\ a\_{i\_{\
\[GothicCapitalZ], \[GothicCapitalM], \[GothicCapitalF]}} - \[GothicCapitalD]\
\_{j\_{\[GothicCapitalG], \[GothicCapitalM]}, i\_{\[GothicCapitalG], \
\[GothicCapitalM]}}\ a\_{i\_{\[GothicCapitalZ], \[GothicCapitalM], \
\[GothicCapitalM]}} - \[GothicCapitalD]\_{j\_{\[GothicCapitalG], \
\[GothicCapitalF]}, j\_{\[GothicCapitalG], \[GothicCapitalF]}}\ a\_{j\_{\
\[GothicCapitalZ], \[GothicCapitalM], \[GothicCapitalF]}} - \[GothicCapitalD]\
\_{j\_{\[GothicCapitalG], \[GothicCapitalM]}, j\_{\[GothicCapitalG], \
\[GothicCapitalM]}}\ a\_{j\_{\[GothicCapitalZ], \[GothicCapitalM], \
\[GothicCapitalM]}} - \[GothicCapitalD]\_{j\_{\[GothicCapitalG], \
\[GothicCapitalF]}, i\_{\[GothicCapitalG], \[GothicCapitalF]}, j\_{\
\[GothicCapitalG], \[GothicCapitalF]}}\ a\_{i\_{\[GothicCapitalZ], \
\[GothicCapitalM], \[GothicCapitalF]}, j\_{\[GothicCapitalZ], \
\[GothicCapitalM], \[GothicCapitalF]}} - \[GothicCapitalD]\_{j\_{\
\[GothicCapitalG], \[GothicCapitalM]}, i\_{\[GothicCapitalG], \
\[GothicCapitalM]}, j\_{\[GothicCapitalG], \[GothicCapitalM]}}\ a\_{i\_{\
\[GothicCapitalZ], \[GothicCapitalM], \[GothicCapitalM]}, j\_{\
\[GothicCapitalZ], \[GothicCapitalM], \[GothicCapitalM]}} - \[GothicCapitalD]\
\_{i\_{\[GothicCapitalG], \[GothicCapitalF]}, j\_{\[GothicCapitalG], \
\[GothicCapitalF]}}\ \[GothicCapitalD]\_{j\_{\[GothicCapitalG], \
\[GothicCapitalM]}, i\_{\[GothicCapitalG], \[GothicCapitalM]}}\ a\_{i\_{\
\[GothicCapitalZ], \[GothicCapitalM], \[GothicCapitalF]}, i\_{\
\[GothicCapitalZ], \[GothicCapitalM], \[GothicCapitalM]}, j\_{\
\[GothicCapitalZ], \[GothicCapitalM], \[GothicCapitalF]}} - \[GothicCapitalD]\
\_{i\_{\[GothicCapitalG], \[GothicCapitalM]}, j\_{\[GothicCapitalG], \
\[GothicCapitalM]}}\ \[GothicCapitalD]\_{j\_{\[GothicCapitalG], \
\[GothicCapitalF]}, i\_{\[GothicCapitalG], \[GothicCapitalF]}}\ a\_{i\_{\
\[GothicCapitalZ], \[GothicCapitalM], \[GothicCapitalF]}, i\_{\
\[GothicCapitalZ], \[GothicCapitalM], \[GothicCapitalM]}, j\_{\
\[GothicCapitalZ], \[GothicCapitalM], \[GothicCapitalM]}} - \[GothicCapitalD]\
\_{i\_{\[GothicCapitalG], \[GothicCapitalF]}, j\_{\[GothicCapitalG], \
\[GothicCapitalF]}}\ \[GothicCapitalD]\_{j\_{\[GothicCapitalG], \
\[GothicCapitalM]}, j\_{\[GothicCapitalG], \[GothicCapitalM]}}\ a\_{i\_{\
\[GothicCapitalZ], \[GothicCapitalM], \[GothicCapitalF]}, j\_{\
\[GothicCapitalZ], \[GothicCapitalM], \[GothicCapitalF]}, j\_{\
\[GothicCapitalZ], \[GothicCapitalM], \[GothicCapitalM]}} - \[GothicCapitalD]\
\_{i\_{\[GothicCapitalG], \[GothicCapitalM]}, j\_{\[GothicCapitalG], \
\[GothicCapitalM]}}\ \[GothicCapitalD]\_{j\_{\[GothicCapitalG], \
\[GothicCapitalF]}, j\_{\[GothicCapitalG], \[GothicCapitalF]}}\ a\_{i\_{\
\[GothicCapitalZ], \[GothicCapitalM], \[GothicCapitalM]}, j\_{\
\[GothicCapitalZ], \[GothicCapitalM], \[GothicCapitalF]}, j\_{\
\[GothicCapitalZ], \[GothicCapitalM], \[GothicCapitalM]}} - \[GothicCapitalD]\
\_{i\_{\[GothicCapitalG], \[GothicCapitalM]}, j\_{\[GothicCapitalG], \
\[GothicCapitalM]}}\ \[GothicCapitalD]\_{j\_{\[GothicCapitalG], \
\[GothicCapitalF]}, i\_{\[GothicCapitalG], \[GothicCapitalF]}, j\_{\
\[GothicCapitalG], \[GothicCapitalF]}}\ a\_{i\_{\[GothicCapitalZ], \
\[GothicCapitalM], \[GothicCapitalF]}, i\_{\[GothicCapitalZ], \
\[GothicCapitalM], \[GothicCapitalM]}, j\_{\[GothicCapitalZ], \
\[GothicCapitalM], \[GothicCapitalF]}, j\_{\[GothicCapitalZ], \
\[GothicCapitalM], \[GothicCapitalM]}} - \[GothicCapitalD]\_{i\_{\
\[GothicCapitalG], \[GothicCapitalF]}, j\_{\[GothicCapitalG], \
\[GothicCapitalF]}}\ \[GothicCapitalD]\_{j\_{\[GothicCapitalG], \
\[GothicCapitalM]}, i\_{\[GothicCapitalG], \[GothicCapitalM]}, j\_{\
\[GothicCapitalG], \[GothicCapitalM]}}\ a\_{i\_{\[GothicCapitalZ], \
\[GothicCapitalM], \[GothicCapitalF]}, i\_{\[GothicCapitalZ], \
\[GothicCapitalM], \[GothicCapitalM]}, j\_{\[GothicCapitalZ], \
\[GothicCapitalM], \[GothicCapitalF]}, j\_{\[GothicCapitalZ], \
\[GothicCapitalM], \[GothicCapitalM]}} - 
                        m\_\(j\_{\[GothicCapitalG], \[GothicCapitalF]}\) - 
                        m\_\(j\_{\[GothicCapitalG], \
\[GothicCapitalM]}\))\))\) + \((\[GothicCapitalD]\_{j\_{\[GothicCapitalG], \
\[GothicCapitalF]}, i\_{\[GothicCapitalG], \[GothicCapitalF]}}\ a\_{i\_{\
\[GothicCapitalZ], \[GothicCapitalM], \[GothicCapitalF]}} + \[GothicCapitalD]\
\_{j\_{\[GothicCapitalG], \[GothicCapitalF]}, j\_{\[GothicCapitalG], \
\[GothicCapitalF]}}\ a\_{j\_{\[GothicCapitalZ], \[GothicCapitalM], \
\[GothicCapitalF]}} + \[GothicCapitalD]\_{j\_{\[GothicCapitalG], \
\[GothicCapitalF]}, i\_{\[GothicCapitalG], \[GothicCapitalF]}, j\_{\
\[GothicCapitalG], \[GothicCapitalF]}}\ a\_{i\_{\[GothicCapitalZ], \
\[GothicCapitalM], \[GothicCapitalF]}, j\_{\[GothicCapitalZ], \
\[GothicCapitalM], \[GothicCapitalF]}} + \[GothicCapitalD]\_{i\_{\
\[GothicCapitalG], \[GothicCapitalM]}, j\_{\[GothicCapitalG], \
\[GothicCapitalM]}}\ \[GothicCapitalD]\_{j\_{\[GothicCapitalG], \
\[GothicCapitalF]}, i\_{\[GothicCapitalG], \[GothicCapitalF]}}\ a\_{i\_{\
\[GothicCapitalZ], \[GothicCapitalM], \[GothicCapitalF]}, i\_{\
\[GothicCapitalZ], \[GothicCapitalM], \[GothicCapitalM]}, j\_{\
\[GothicCapitalZ], \[GothicCapitalM], \[GothicCapitalM]}} + \[GothicCapitalD]\
\_{i\_{\[GothicCapitalG], \[GothicCapitalM]}, j\_{\[GothicCapitalG], \
\[GothicCapitalM]}}\ \[GothicCapitalD]\_{j\_{\[GothicCapitalG], \
\[GothicCapitalF]}, j\_{\[GothicCapitalG], \[GothicCapitalF]}}\ a\_{i\_{\
\[GothicCapitalZ], \[GothicCapitalM], \[GothicCapitalM]}, j\_{\
\[GothicCapitalZ], \[GothicCapitalM], \[GothicCapitalF]}, j\_{\
\[GothicCapitalZ], \[GothicCapitalM], \[GothicCapitalM]}} + \[GothicCapitalD]\
\_{i\_{\[GothicCapitalG], \[GothicCapitalM]}, j\_{\[GothicCapitalG], \
\[GothicCapitalM]}}\ \[GothicCapitalD]\_{j\_{\[GothicCapitalG], \
\[GothicCapitalF]}, i\_{\[GothicCapitalG], \[GothicCapitalF]}, j\_{\
\[GothicCapitalG], \[GothicCapitalF]}}\ a\_{i\_{\[GothicCapitalZ], \
\[GothicCapitalM], \[GothicCapitalF]}, i\_{\[GothicCapitalZ], \
\[GothicCapitalM], \[GothicCapitalM]}, j\_{\[GothicCapitalZ], \
\[GothicCapitalM], \[GothicCapitalF]}, j\_{\[GothicCapitalZ], \
\[GothicCapitalM], \[GothicCapitalM]}})\)\ \((m\_\(k\_{\[GothicCapitalG], \
\[GothicCapitalF]}\) + 
                  1\/2\ \((\(-\[GothicCapitalD]\_{k\_{\[GothicCapitalG], \
\[GothicCapitalF]}, i\_{\[GothicCapitalG], \[GothicCapitalF]}}\)\ a\_{i\_{\
\[GothicCapitalZ], \[GothicCapitalM], \[GothicCapitalF]}} - \[GothicCapitalD]\
\_{k\_{\[GothicCapitalG], \[GothicCapitalM]}, i\_{\[GothicCapitalG], \
\[GothicCapitalM]}}\ a\_{i\_{\[GothicCapitalZ], \[GothicCapitalM], \
\[GothicCapitalM]}} - \[GothicCapitalD]\_{k\_{\[GothicCapitalG], \
\[GothicCapitalF]}, j\_{\[GothicCapitalG], \[GothicCapitalF]}}\ a\_{j\_{\
\[GothicCapitalZ], \[GothicCapitalM], \[GothicCapitalF]}} - \[GothicCapitalD]\
\_{k\_{\[GothicCapitalG], \[GothicCapitalM]}, j\_{\[GothicCapitalG], \
\[GothicCapitalM]}}\ a\_{j\_{\[GothicCapitalZ], \[GothicCapitalM], \
\[GothicCapitalM]}} - \[GothicCapitalD]\_{k\_{\[GothicCapitalG], \
\[GothicCapitalF]}, i\_{\[GothicCapitalG], \[GothicCapitalF]}, j\_{\
\[GothicCapitalG], \[GothicCapitalF]}}\ a\_{i\_{\[GothicCapitalZ], \
\[GothicCapitalM], \[GothicCapitalF]}, j\_{\[GothicCapitalZ], \
\[GothicCapitalM], \[GothicCapitalF]}} - \[GothicCapitalD]\_{k\_{\
\[GothicCapitalG], \[GothicCapitalM]}, i\_{\[GothicCapitalG], \
\[GothicCapitalM]}, j\_{\[GothicCapitalG], \[GothicCapitalM]}}\ a\_{i\_{\
\[GothicCapitalZ], \[GothicCapitalM], \[GothicCapitalM]}, j\_{\
\[GothicCapitalZ], \[GothicCapitalM], \[GothicCapitalM]}} - \[GothicCapitalD]\
\_{i\_{\[GothicCapitalG], \[GothicCapitalF]}, j\_{\[GothicCapitalG], \
\[GothicCapitalF]}}\ \[GothicCapitalD]\_{k\_{\[GothicCapitalG], \
\[GothicCapitalM]}, i\_{\[GothicCapitalG], \[GothicCapitalM]}}\ a\_{i\_{\
\[GothicCapitalZ], \[GothicCapitalM], \[GothicCapitalF]}, i\_{\
\[GothicCapitalZ], \[GothicCapitalM], \[GothicCapitalM]}, j\_{\
\[GothicCapitalZ], \[GothicCapitalM], \[GothicCapitalF]}} - \[GothicCapitalD]\
\_{i\_{\[GothicCapitalG], \[GothicCapitalM]}, j\_{\[GothicCapitalG], \
\[GothicCapitalM]}}\ \[GothicCapitalD]\_{k\_{\[GothicCapitalG], \
\[GothicCapitalF]}, i\_{\[GothicCapitalG], \[GothicCapitalF]}}\ a\_{i\_{\
\[GothicCapitalZ], \[GothicCapitalM], \[GothicCapitalF]}, i\_{\
\[GothicCapitalZ], \[GothicCapitalM], \[GothicCapitalM]}, j\_{\
\[GothicCapitalZ], \[GothicCapitalM], \[GothicCapitalM]}} - \[GothicCapitalD]\
\_{i\_{\[GothicCapitalG], \[GothicCapitalF]}, j\_{\[GothicCapitalG], \
\[GothicCapitalF]}}\ \[GothicCapitalD]\_{k\_{\[GothicCapitalG], \
\[GothicCapitalM]}, j\_{\[GothicCapitalG], \[GothicCapitalM]}}\ a\_{i\_{\
\[GothicCapitalZ], \[GothicCapitalM], \[GothicCapitalF]}, j\_{\
\[GothicCapitalZ], \[GothicCapitalM], \[GothicCapitalF]}, j\_{\
\[GothicCapitalZ], \[GothicCapitalM], \[GothicCapitalM]}} - \[GothicCapitalD]\
\_{i\_{\[GothicCapitalG], \[GothicCapitalM]}, j\_{\[GothicCapitalG], \
\[GothicCapitalM]}}\ \[GothicCapitalD]\_{k\_{\[GothicCapitalG], \
\[GothicCapitalF]}, j\_{\[GothicCapitalG], \[GothicCapitalF]}}\ a\_{i\_{\
\[GothicCapitalZ], \[GothicCapitalM], \[GothicCapitalM]}, j\_{\
\[GothicCapitalZ], \[GothicCapitalM], \[GothicCapitalF]}, j\_{\
\[GothicCapitalZ], \[GothicCapitalM], \[GothicCapitalM]}} - \[GothicCapitalD]\
\_{i\_{\[GothicCapitalG], \[GothicCapitalM]}, j\_{\[GothicCapitalG], \
\[GothicCapitalM]}}\ \[GothicCapitalD]\_{k\_{\[GothicCapitalG], \
\[GothicCapitalF]}, i\_{\[GothicCapitalG], \[GothicCapitalF]}, j\_{\
\[GothicCapitalG], \[GothicCapitalF]}}\ a\_{i\_{\[GothicCapitalZ], \
\[GothicCapitalM], \[GothicCapitalF]}, i\_{\[GothicCapitalZ], \
\[GothicCapitalM], \[GothicCapitalM]}, j\_{\[GothicCapitalZ], \
\[GothicCapitalM], \[GothicCapitalF]}, j\_{\[GothicCapitalZ], \
\[GothicCapitalM], \[GothicCapitalM]}} - \[GothicCapitalD]\_{i\_{\
\[GothicCapitalG], \[GothicCapitalF]}, j\_{\[GothicCapitalG], \
\[GothicCapitalF]}}\ \[GothicCapitalD]\_{k\_{\[GothicCapitalG], \
\[GothicCapitalM]}, i\_{\[GothicCapitalG], \[GothicCapitalM]}, j\_{\
\[GothicCapitalG], \[GothicCapitalM]}}\ a\_{i\_{\[GothicCapitalZ], \
\[GothicCapitalM], \[GothicCapitalF]}, i\_{\[GothicCapitalZ], \
\[GothicCapitalM], \[GothicCapitalM]}, j\_{\[GothicCapitalZ], \
\[GothicCapitalM], \[GothicCapitalF]}, j\_{\[GothicCapitalZ], \
\[GothicCapitalM], \[GothicCapitalM]}} - 
                        m\_\(k\_{\[GothicCapitalG], \[GothicCapitalF]}\) - 
                        m\_\(k\_{\[GothicCapitalG], \
\[GothicCapitalM]}\))\))\) + \((m\_\(j\_{\[GothicCapitalG], \
\[GothicCapitalF]}\) + 
                  1\/2\ \((\(-\[GothicCapitalD]\_{j\_{\[GothicCapitalG], \
\[GothicCapitalF]}, i\_{\[GothicCapitalG], \[GothicCapitalF]}}\)\ a\_{i\_{\
\[GothicCapitalZ], \[GothicCapitalM], \[GothicCapitalF]}} - \[GothicCapitalD]\
\_{j\_{\[GothicCapitalG], \[GothicCapitalM]}, i\_{\[GothicCapitalG], \
\[GothicCapitalM]}}\ a\_{i\_{\[GothicCapitalZ], \[GothicCapitalM], \
\[GothicCapitalM]}} - \[GothicCapitalD]\_{j\_{\[GothicCapitalG], \
\[GothicCapitalF]}, j\_{\[GothicCapitalG], \[GothicCapitalF]}}\ a\_{j\_{\
\[GothicCapitalZ], \[GothicCapitalM], \[GothicCapitalF]}} - \[GothicCapitalD]\
\_{j\_{\[GothicCapitalG], \[GothicCapitalM]}, j\_{\[GothicCapitalG], \
\[GothicCapitalM]}}\ a\_{j\_{\[GothicCapitalZ], \[GothicCapitalM], \
\[GothicCapitalM]}} - \[GothicCapitalD]\_{j\_{\[GothicCapitalG], \
\[GothicCapitalF]}, i\_{\[GothicCapitalG], \[GothicCapitalF]}, j\_{\
\[GothicCapitalG], \[GothicCapitalF]}}\ a\_{i\_{\[GothicCapitalZ], \
\[GothicCapitalM], \[GothicCapitalF]}, j\_{\[GothicCapitalZ], \
\[GothicCapitalM], \[GothicCapitalF]}} - \[GothicCapitalD]\_{j\_{\
\[GothicCapitalG], \[GothicCapitalM]}, i\_{\[GothicCapitalG], \
\[GothicCapitalM]}, j\_{\[GothicCapitalG], \[GothicCapitalM]}}\ a\_{i\_{\
\[GothicCapitalZ], \[GothicCapitalM], \[GothicCapitalM]}, j\_{\
\[GothicCapitalZ], \[GothicCapitalM], \[GothicCapitalM]}} - \[GothicCapitalD]\
\_{i\_{\[GothicCapitalG], \[GothicCapitalF]}, j\_{\[GothicCapitalG], \
\[GothicCapitalF]}}\ \[GothicCapitalD]\_{j\_{\[GothicCapitalG], \
\[GothicCapitalM]}, i\_{\[GothicCapitalG], \[GothicCapitalM]}}\ a\_{i\_{\
\[GothicCapitalZ], \[GothicCapitalM], \[GothicCapitalF]}, i\_{\
\[GothicCapitalZ], \[GothicCapitalM], \[GothicCapitalM]}, j\_{\
\[GothicCapitalZ], \[GothicCapitalM], \[GothicCapitalF]}} - \[GothicCapitalD]\
\_{i\_{\[GothicCapitalG], \[GothicCapitalM]}, j\_{\[GothicCapitalG], \
\[GothicCapitalM]}}\ \[GothicCapitalD]\_{j\_{\[GothicCapitalG], \
\[GothicCapitalF]}, i\_{\[GothicCapitalG], \[GothicCapitalF]}}\ a\_{i\_{\
\[GothicCapitalZ], \[GothicCapitalM], \[GothicCapitalF]}, i\_{\
\[GothicCapitalZ], \[GothicCapitalM], \[GothicCapitalM]}, j\_{\
\[GothicCapitalZ], \[GothicCapitalM], \[GothicCapitalM]}} - \[GothicCapitalD]\
\_{i\_{\[GothicCapitalG], \[GothicCapitalF]}, j\_{\[GothicCapitalG], \
\[GothicCapitalF]}}\ \[GothicCapitalD]\_{j\_{\[GothicCapitalG], \
\[GothicCapitalM]}, j\_{\[GothicCapitalG], \[GothicCapitalM]}}\ a\_{i\_{\
\[GothicCapitalZ], \[GothicCapitalM], \[GothicCapitalF]}, j\_{\
\[GothicCapitalZ], \[GothicCapitalM], \[GothicCapitalF]}, j\_{\
\[GothicCapitalZ], \[GothicCapitalM], \[GothicCapitalM]}} - \[GothicCapitalD]\
\_{i\_{\[GothicCapitalG], \[GothicCapitalM]}, j\_{\[GothicCapitalG], \
\[GothicCapitalM]}}\ \[GothicCapitalD]\_{j\_{\[GothicCapitalG], \
\[GothicCapitalF]}, j\_{\[GothicCapitalG], \[GothicCapitalF]}}\ a\_{i\_{\
\[GothicCapitalZ], \[GothicCapitalM], \[GothicCapitalM]}, j\_{\
\[GothicCapitalZ], \[GothicCapitalM], \[GothicCapitalF]}, j\_{\
\[GothicCapitalZ], \[GothicCapitalM], \[GothicCapitalM]}} - \[GothicCapitalD]\
\_{i\_{\[GothicCapitalG], \[GothicCapitalM]}, j\_{\[GothicCapitalG], \
\[GothicCapitalM]}}\ \[GothicCapitalD]\_{j\_{\[GothicCapitalG], \
\[GothicCapitalF]}, i\_{\[GothicCapitalG], \[GothicCapitalF]}, j\_{\
\[GothicCapitalG], \[GothicCapitalF]}}\ a\_{i\_{\[GothicCapitalZ], \
\[GothicCapitalM], \[GothicCapitalF]}, i\_{\[GothicCapitalZ], \
\[GothicCapitalM], \[GothicCapitalM]}, j\_{\[GothicCapitalZ], \
\[GothicCapitalM], \[GothicCapitalF]}, j\_{\[GothicCapitalZ], \
\[GothicCapitalM], \[GothicCapitalM]}} - \[GothicCapitalD]\_{i\_{\
\[GothicCapitalG], \[GothicCapitalF]}, j\_{\[GothicCapitalG], \
\[GothicCapitalF]}}\ \[GothicCapitalD]\_{j\_{\[GothicCapitalG], \
\[GothicCapitalM]}, i\_{\[GothicCapitalG], \[GothicCapitalM]}, j\_{\
\[GothicCapitalG], \[GothicCapitalM]}}\ a\_{i\_{\[GothicCapitalZ], \
\[GothicCapitalM], \[GothicCapitalF]}, i\_{\[GothicCapitalZ], \
\[GothicCapitalM], \[GothicCapitalM]}, j\_{\[GothicCapitalZ], \
\[GothicCapitalM], \[GothicCapitalF]}, j\_{\[GothicCapitalZ], \
\[GothicCapitalM], \[GothicCapitalM]}} - 
                        m\_\(j\_{\[GothicCapitalG], \[GothicCapitalF]}\) - 
                        m\_\(j\_{\[GothicCapitalG], \
\[GothicCapitalM]}\))\))\)\ \((m\_\(k\_{\[GothicCapitalG], \[GothicCapitalF]}\
\) + 1\/2\ \((\(-\[GothicCapitalD]\_{k\_{\[GothicCapitalG], \
\[GothicCapitalF]}, i\_{\[GothicCapitalG], \[GothicCapitalF]}}\)\ a\_{i\_{\
\[GothicCapitalZ], \[GothicCapitalM], \[GothicCapitalF]}} - \[GothicCapitalD]\
\_{k\_{\[GothicCapitalG], \[GothicCapitalM]}, i\_{\[GothicCapitalG], \
\[GothicCapitalM]}}\ a\_{i\_{\[GothicCapitalZ], \[GothicCapitalM], \
\[GothicCapitalM]}} - \[GothicCapitalD]\_{k\_{\[GothicCapitalG], \
\[GothicCapitalF]}, j\_{\[GothicCapitalG], \[GothicCapitalF]}}\ a\_{j\_{\
\[GothicCapitalZ], \[GothicCapitalM], \[GothicCapitalF]}} - \[GothicCapitalD]\
\_{k\_{\[GothicCapitalG], \[GothicCapitalM]}, j\_{\[GothicCapitalG], \
\[GothicCapitalM]}}\ a\_{j\_{\[GothicCapitalZ], \[GothicCapitalM], \
\[GothicCapitalM]}} - \[GothicCapitalD]\_{k\_{\[GothicCapitalG], \
\[GothicCapitalF]}, i\_{\[GothicCapitalG], \[GothicCapitalF]}, j\_{\
\[GothicCapitalG], \[GothicCapitalF]}}\ a\_{i\_{\[GothicCapitalZ], \
\[GothicCapitalM], \[GothicCapitalF]}, j\_{\[GothicCapitalZ], \
\[GothicCapitalM], \[GothicCapitalF]}} - \[GothicCapitalD]\_{k\_{\
\[GothicCapitalG], \[GothicCapitalM]}, i\_{\[GothicCapitalG], \
\[GothicCapitalM]}, j\_{\[GothicCapitalG], \[GothicCapitalM]}}\ a\_{i\_{\
\[GothicCapitalZ], \[GothicCapitalM], \[GothicCapitalM]}, j\_{\
\[GothicCapitalZ], \[GothicCapitalM], \[GothicCapitalM]}} - \[GothicCapitalD]\
\_{i\_{\[GothicCapitalG], \[GothicCapitalF]}, j\_{\[GothicCapitalG], \
\[GothicCapitalF]}}\ \[GothicCapitalD]\_{k\_{\[GothicCapitalG], \
\[GothicCapitalM]}, i\_{\[GothicCapitalG], \[GothicCapitalM]}}\ a\_{i\_{\
\[GothicCapitalZ], \[GothicCapitalM], \[GothicCapitalF]}, i\_{\
\[GothicCapitalZ], \[GothicCapitalM], \[GothicCapitalM]}, j\_{\
\[GothicCapitalZ], \[GothicCapitalM], \[GothicCapitalF]}} - \[GothicCapitalD]\
\_{i\_{\[GothicCapitalG], \[GothicCapitalM]}, j\_{\[GothicCapitalG], \
\[GothicCapitalM]}}\ \[GothicCapitalD]\_{k\_{\[GothicCapitalG], \
\[GothicCapitalF]}, i\_{\[GothicCapitalG], \[GothicCapitalF]}}\ a\_{i\_{\
\[GothicCapitalZ], \[GothicCapitalM], \[GothicCapitalF]}, i\_{\
\[GothicCapitalZ], \[GothicCapitalM], \[GothicCapitalM]}, j\_{\
\[GothicCapitalZ], \[GothicCapitalM], \[GothicCapitalM]}} - \[GothicCapitalD]\
\_{i\_{\[GothicCapitalG], \[GothicCapitalF]}, j\_{\[GothicCapitalG], \
\[GothicCapitalF]}}\ \[GothicCapitalD]\_{k\_{\[GothicCapitalG], \
\[GothicCapitalM]}, j\_{\[GothicCapitalG], \[GothicCapitalM]}}\ a\_{i\_{\
\[GothicCapitalZ], \[GothicCapitalM], \[GothicCapitalF]}, j\_{\
\[GothicCapitalZ], \[GothicCapitalM], \[GothicCapitalF]}, j\_{\
\[GothicCapitalZ], \[GothicCapitalM], \[GothicCapitalM]}} - \[GothicCapitalD]\
\_{i\_{\[GothicCapitalG], \[GothicCapitalM]}, j\_{\[GothicCapitalG], \
\[GothicCapitalM]}}\ \[GothicCapitalD]\_{k\_{\[GothicCapitalG], \
\[GothicCapitalF]}, j\_{\[GothicCapitalG], \[GothicCapitalF]}}\ a\_{i\_{\
\[GothicCapitalZ], \[GothicCapitalM], \[GothicCapitalM]}, j\_{\
\[GothicCapitalZ], \[GothicCapitalM], \[GothicCapitalF]}, j\_{\
\[GothicCapitalZ], \[GothicCapitalM], \[GothicCapitalM]}} - \[GothicCapitalD]\
\_{i\_{\[GothicCapitalG], \[GothicCapitalM]}, j\_{\[GothicCapitalG], \
\[GothicCapitalM]}}\ \[GothicCapitalD]\_{k\_{\[GothicCapitalG], \
\[GothicCapitalF]}, i\_{\[GothicCapitalG], \[GothicCapitalF]}, j\_{\
\[GothicCapitalG], \[GothicCapitalF]}}\ a\_{i\_{\[GothicCapitalZ], \
\[GothicCapitalM], \[GothicCapitalF]}, i\_{\[GothicCapitalZ], \
\[GothicCapitalM], \[GothicCapitalM]}, j\_{\[GothicCapitalZ], \
\[GothicCapitalM], \[GothicCapitalF]}, j\_{\[GothicCapitalZ], \
\[GothicCapitalM], \[GothicCapitalM]}} - \[GothicCapitalD]\_{i\_{\
\[GothicCapitalG], \[GothicCapitalF]}, j\_{\[GothicCapitalG], \
\[GothicCapitalF]}}\ \[GothicCapitalD]\_{k\_{\[GothicCapitalG], \
\[GothicCapitalM]}, i\_{\[GothicCapitalG], \[GothicCapitalM]}, j\_{\
\[GothicCapitalG], \[GothicCapitalM]}}\ a\_{i\_{\[GothicCapitalZ], \
\[GothicCapitalM], \[GothicCapitalF]}, i\_{\[GothicCapitalZ], \
\[GothicCapitalM], \[GothicCapitalM]}, j\_{\[GothicCapitalZ], \
\[GothicCapitalM], \[GothicCapitalF]}, j\_{\[GothicCapitalZ], \
\[GothicCapitalM], \[GothicCapitalM]}} - 
                        m\_\(k\_{\[GothicCapitalG], \[GothicCapitalF]}\) - 
                        m\_\(k\_{\[GothicCapitalG], \
\[GothicCapitalM]}\))\))\))\)\ r\_\({j, k}, {}\)\)], "Output",
  CellLabel->"Out[27]="]
}, Closed]],

Cell["\<\
The expression for even pairwise disequilibrium is extremely \
complicated, mainly because of the shift in allele frequencies.  With no \
selection, we have:\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\[GothicCapitalD]new\_{j\_{\(\[GothicCapitalG]\^*\), \
\[GothicCapitalM]}, k\_{\(\[GothicCapitalG]\^*\), \[GothicCapitalM]}} /. 
      a\__ \[Rule] 0\)], "Input",
  CellLabel->"In[28]:="],

Cell[BoxData[
    \(\((\[GothicCapitalD]\_{j\_{\[GothicCapitalG], \[GothicCapitalM]}, k\_{\
\[GothicCapitalG], \[GothicCapitalM]}} + \((1\/2\ \((\(-m\_\(j\_{\
\[GothicCapitalG], \[GothicCapitalF]}\)\) - 
                        m\_\(j\_{\[GothicCapitalG], \[GothicCapitalM]}\))\) + 
                  m\_\(j\_{\[GothicCapitalG], \[GothicCapitalM]}\))\)\ \
\((1\/2\ \((\(-m\_\(k\_{\[GothicCapitalG], \[GothicCapitalF]}\)\) - 
                        m\_\(k\_{\[GothicCapitalG], \[GothicCapitalM]}\))\) + 
                  m\_\(k\_{\[GothicCapitalG], \[GothicCapitalM]}\))\))\)\ r\_\
\({}, {j, k}\) + \((m\_\(j\_{\[GothicCapitalG], \[GothicCapitalF]}\) + 
            1\/2\ \((\(-m\_\(j\_{\[GothicCapitalG], \[GothicCapitalF]}\)\) - 
                  m\_\(j\_{\[GothicCapitalG], \[GothicCapitalM]}\))\))\)\ \
\((1\/2\ \((\(-m\_\(k\_{\[GothicCapitalG], \[GothicCapitalF]}\)\) - 
                  m\_\(k\_{\[GothicCapitalG], \[GothicCapitalM]}\))\) + 
            m\_\(k\_{\[GothicCapitalG], \[GothicCapitalM]}\))\)\ r\_\({j}, \
{k}\) + \((1\/2\ \((\(-m\_\(j\_{\[GothicCapitalG], \[GothicCapitalF]}\)\) - 
                  m\_\(j\_{\[GothicCapitalG], \[GothicCapitalM]}\))\) + 
            m\_\(j\_{\[GothicCapitalG], \[GothicCapitalM]}\))\)\ \((m\_\(k\_{\
\[GothicCapitalG], \[GothicCapitalF]}\) + 
            1\/2\ \((\(-m\_\(k\_{\[GothicCapitalG], \[GothicCapitalF]}\)\) - 
                  m\_\(k\_{\[GothicCapitalG], \[GothicCapitalM]}\))\))\)\ r\_\
\({k}, {j}\) + \((\[GothicCapitalD]\_{j\_{\[GothicCapitalG], \
\[GothicCapitalF]}, k\_{\[GothicCapitalG], \[GothicCapitalF]}} + \((m\_\(j\_{\
\[GothicCapitalG], \[GothicCapitalF]}\) + 
                  1\/2\ \((\(-m\_\(j\_{\[GothicCapitalG], \
\[GothicCapitalF]}\)\) - 
                        m\_\(j\_{\[GothicCapitalG], \
\[GothicCapitalM]}\))\))\)\ \((m\_\(k\_{\[GothicCapitalG], \[GothicCapitalF]}\
\) + 1\/2\ \((\(-m\_\(k\_{\[GothicCapitalG], \[GothicCapitalF]}\)\) - 
                        m\_\(k\_{\[GothicCapitalG], \
\[GothicCapitalM]}\))\))\))\)\ r\_\({j, k}, {}\)\)], "Output",
  CellLabel->"Out[28]="]
}, Open  ]],

Cell["\<\
With symmetrical recombination rates (i.e., no meiotic \
drive):\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(% /. {r\_\({}, {j, k}\) \[Rule] \(1 - \[Rho]\)\/2, 
          r\_\({j, k}, {}\) \[Rule] \(1 - \[Rho]\)\/2, 
          r\_\({j}, {k}\) \[Rule] \[Rho]\/2, 
          r\_\({k}, {j}\) \[Rule] \[Rho]\/2} // Simplify\)], "Input",
  CellLabel->"In[30]:="],

Cell[BoxData[
    \(\((1 - \[Rho])\)\ \((\[GothicCapitalD]\_{j\_{\[GothicCapitalG], \
\[GothicCapitalF]}, k\_{\[GothicCapitalG], \[GothicCapitalF]}} + \
\[GothicCapitalD]\_{j\_{\[GothicCapitalG], \[GothicCapitalM]}, k\_{\
\[GothicCapitalG], \[GothicCapitalM]}})\)\/2 + \ \((1 - 2\ \[Rho])\)\/4\ \((m\
\_\(j\_{\[GothicCapitalG], \[GothicCapitalF]}\) - 
            m\_\(j\_{\[GothicCapitalG], \[GothicCapitalM]}\))\)\ \((m\_\(k\_{\
\[GothicCapitalG], \[GothicCapitalF]}\) - 
            m\_\(k\_{\[GothicCapitalG], \[GothicCapitalM]}\))\)\)], "Output",
  CellLabel->"Out[31]="]
}, Open  ]],

Cell[TextData[{
  "Linkage disequilibrium is generated by differences in allele frequency \
between male and female gametes, provided that there is some linkage ",
  Cell[BoxData[
      \(TraditionalForm\`\((\[Rho] < 1\/2)\)\)]],
  "."
}], "Text"],

Cell["\<\
This approach suffers from two drawbacks.  First, it is liable to \
infinite recursions: because a rule is given which immediuately replaces \
\[GothicCapitalD] at one stage by that at the previous stage, it is easy for \
that to call itself indefinitely.  Second, even if this problem is avoided, \
every \[GothicCapitalD] is immediately replaced by an expression in terms of \
the \[GothicCapitalD] in the gamete pool.  This makes it hard to see what is \
happening at each intermediate stage.\
\>", "Text"]
}, Open  ]]
},
FrontEndVersion->"4.0 for Macintosh",
ScreenRectangle->{{0, 1024}, {0, 748}},
WindowSize->{520, 626},
WindowMargins->{{Automatic, 238}, {Automatic, 20}},
StyleDefinitions -> "HelpBrowser.nb",
MacintoshSystemPageSetup->"\<\
00<0001804P000000]P2:?oQon82n@960dL5:0?l0080001804P000000]P2:001
0000I00000400`<300000BL?00400@0000000000000006P801T1T00000000000
00000000000000000000000000000000\>"
]


(***********************************************************************
Cached data follows.  If you edit this Notebook file directly, not using
Mathematica, you must remove the line containing CacheID at the top of 
the file.  The cache data will then be recreated when you save this file 
from within Mathematica.
***********************************************************************)

(*CellTagsOutline
CellTagsIndex->{}
*)

(*CellTagsIndex
CellTagsIndex->{}
*)

(*NotebookFileOutline
Notebook[{

Cell[CellGroupData[{
Cell[1739, 51, 43, 0, 36, "SubsectionIcon"],
Cell[1785, 53, 639, 12, 64, "Text"],
Cell[2427, 67, 899, 15, 99, "Input"],
Cell[3329, 84, 164, 4, 36, "Text"],
Cell[3496, 90, 397, 7, 33, "Input"],
Cell[3896, 99, 251, 6, 22, "Text"],
Cell[4150, 107, 312, 5, 28, "Input"],
Cell[4465, 114, 69, 0, 22, "Text"],
Cell[4537, 116, 744, 13, 74, "Input"],
Cell[5284, 131, 137, 3, 36, "Text"],

Cell[CellGroupData[{
Cell[5446, 138, 211, 4, 34, "Input"],
Cell[5660, 144, 24933, 366, 888, "Output"]
}, Closed]],
Cell[30608, 513, 65, 0, 18, "Text"],
Cell[30676, 515, 746, 11, 72, "Input"],
Cell[31425, 528, 176, 4, 36, "Text"],

Cell[CellGroupData[{
Cell[31626, 536, 184, 4, 34, "Input"],
Cell[31813, 542, 98195, 1438, 3744, "Output"]
}, Closed]],
Cell[130023, 1983, 181, 4, 32, "Text"],

Cell[CellGroupData[{
Cell[130229, 1991, 207, 4, 33, "Input"],
Cell[130439, 1997, 2073, 31, 240, "Output"]
}, Open  ]],
Cell[132527, 2031, 88, 3, 22, "Text"],

Cell[CellGroupData[{
Cell[132640, 2038, 268, 5, 73, "Input"],
Cell[132911, 2045, 576, 9, 80, "Output"]
}, Open  ]],
Cell[133502, 2057, 247, 6, 42, "Text"],
Cell[133752, 2065, 519, 8, 78, "Text"]
}, Open  ]]
}
]
*)




(***********************************************************************
End of Mathematica Notebook file.
***********************************************************************)

