(***********************************************************************

                    Mathematica-Compatible Notebook

This notebook can be used on any computer system with Mathematica 4.0,
MathReader 4.0, or any compatible application. The data for the notebook 
starts with the line containing stars above.

To get the notebook into a Mathematica-compatible application, do one of 
the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing the 
word CacheID, otherwise Mathematica-compatible applications may try to 
use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
***********************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[    317940,      12820]*)
(*NotebookOutlinePosition[    429125,      15908]*)
(*  CellTagsIndexPosition[    403080,      15210]*)
(*WindowFrame->Normal*)



Notebook[{
Cell["Applications Packages", "IndexSection",
  CellTags->"MasterIndexHeading"],

Cell[TextData[{
  "|.",
  ",",
  " ReplaceAllSpecial",
  ", ",
  ButtonBox["|., ||.",
    ButtonData:>{"|., ||.", "ReplaceAllSpecial"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"|."],

Cell[TextData[{
  "\\\\",
  ",",
  " bugs with",
  ", ",
  ButtonBox["Bugs",
    ButtonData:>{"Bugs", "Repeated \\\\"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"\\\\"],

Cell[TextData[{
  "<>",
  ",",
  " Expectation",
  ", ",
  ButtonBox["Populations",
    ButtonData:>{"Populations", "Expectation"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"<>"],

Cell[TextData[{
  "||.",
  ",",
  " ReplaceRepeatedSpecial",
  ", ",
  ButtonBox["|., ||.",
    ButtonData:>{"|., ||.", "ReplaceAllSpecial"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"||."],

Cell[TextData[{
  "AddAncestors",
  ",",
  " to ancestral graphs",
  ", ",
  ButtonBox["Ancestors & descendants",
    ButtonData:>{"Ancestors & descendants", "AddAncestors"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"AddAncestors"],

Cell[TextData[{
  "AddCoalescentLineage",
  ",",
  " to ancestral graph",
  ", ",
  ButtonBox["Coalescence and recombination",
    ButtonData:>{"Coalescence and recombination", "AddCoalescentLineage"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"AddCoalescentLineage"],

Cell[TextData[{
  "AddDescendants",
  ",",
  " to ancestral graphs",
  ", ",
  ButtonBox["Ancestors & descendants",
    ButtonData:>{"Ancestors & descendants", "AddDescendants"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"AddDescendants"],

Cell[TextData[{
  "AddGenealogy",
  ",",
  " ",
  ButtonBox["Manipulating genealogies",
    ButtonData:>{"Manipulating genealogies", "AddGenealogy"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"AddGenealogy"],

Cell[TextData[{
  "Additive models",
  ",",
  " ",
  ButtonBox["Gaussian likelihoods",
    ButtonData:>{"Gaussian likelihoods", "additive models"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Additive models"],

Cell[TextData[{
  "Additive selection",
  ",",
  " defining fitnesses",
  ", ",
  ButtonBox["Additive selection",
    ButtonData:>{"Additive selection", "Defining fitnesses"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Additive selection"],

Cell[TextData[{
  " defining rules",
  ", ",
  ButtonBox["Additive selection",
    ButtonData:>{"Additive selection", "Defining rules"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " new D",
  ", ",
  ButtonBox["Additive selection",
    ButtonData:>{"Additive selection", "New D"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " new mean",
  ", ",
  ButtonBox["Additive selection",
    ButtonData:>{"Additive selection", "New mean"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " scaled D",
  ", ",
  ButtonBox["Additive selection",
    ButtonData:>{"Additive selection", "Scaled D"},
    ButtonStyle->"AddOnsLink"]
}], "IndexSubentry",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Additive selection"],

Cell[TextData[{
  "AddMutation",
  ",",
  " ",
  ButtonBox["Manipulating genealogies",
    ButtonData:>{"Manipulating genealogies", "AddMutation"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"AddMutation"],

Cell[TextData[{
  "AddNode",
  ",",
  " ",
  ButtonBox["Manipulating genealogies",
    ButtonData:>{"Manipulating genealogies", "AddNode"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"AddNode"],

Cell[TextData[{
  "AddRecombinantLineages",
  ",",
  " to ancestral graph",
  ", ",
  ButtonBox["Coalescence and recombination",
    ButtonData:>{"Coalescence and recombination", "AddRecombinantLineages"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"AddRecombinantLineages"],

Cell[TextData[{
  "AddTag",
  ",",
  " ",
  ButtonBox["Tagging sets",
    ButtonData:>{"Tagging sets", "AddTag"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"AddTag"],

Cell[TextData[{
  "AddUp",
  ",",
  " ",
  ButtonBox["AddUp",
    ButtonData:>{"AddUp", "AddUp"},
    ButtonStyle->"AddOnsLink"],
  ",",
  ButtonBox["Operations on sets",
    ButtonData:>{"Operations on sets", "AddUp"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"AddUp"],

Cell[TextData[{
  " multiple sums",
  ", ",
  ButtonBox["AddUp",
    ButtonData:>{"AddUp", "Multiple sums"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " over subsets",
  ", ",
  ButtonBox["AddUp",
    ButtonData:>{"AddUp", "Subsets"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " technicalities",
  ", ",
  ButtonBox["AddUp",
    ButtonData:>{"AddUp", "Technicalities"},
    ButtonStyle->"AddOnsLink"]
}], "IndexSubentry",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"AddUp"],

Cell[TextData[{
  "AdmixtureFrequency",
  ",",
  " ",
  ButtonBox["Equilibria",
    ButtonData:>{"Equilibria", "AdmixtureFrequency"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"AdmixtureFrequency"],

Cell[TextData[{
  "Admixture models",
  ",",
  " ",
  ButtonBox["Admixture models",
    ButtonData:>{"Admixture models", None},
    ButtonStyle->"AddOnsLink"],
  ",",
  ButtonBox["Overview",
    ButtonData:>{"Overview", None},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Admixture models"],

Cell[TextData[{
  " changing sex",
  ", ",
  ButtonBox["Changing sex",
    ButtonData:>{"Changing sex", None},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " equilibria",
  ", ",
  ButtonBox["Equilibria",
    ButtonData:>{"Equilibria", None},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " iteration",
  ", ",
  ButtonBox["Iteration",
    ButtonData:>{"Iteration", None},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " migration",
  ", ",
  ButtonBox["Migration in admixture models",
    ButtonData:>{"Migration in admixture models", None},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " recombination",
  ", ",
  ButtonBox["Recombination in admixture models",
    ButtonData:>{"Recombination in admixture models", None},
    ButtonStyle->"AddOnsLink"]
}], "IndexSubentry",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Admixture models"],

Cell[TextData[{
  "Adults",
  ",",
  " \[GothicCapitalA], \[AliasIndicator]goA\[AliasIndicator]",
  ", ",
  ButtonBox["Life cycle",
    ButtonData:>{"Life cycle", "Adults"},
    ButtonStyle->"AddOnsLink"],
  ",",
  ButtonBox["Notation reference",
    ButtonData:>{"Notation reference", None},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Adults"],

Cell[TextData[{
  "Allele frequencies",
  ",",
  " definition of fitness",
  ", ",
  ButtonBox["Allele frequencies:fitnesses",
    ButtonData:>{"Allele frequencies:fitnesses", "Defining fitnesses"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Allele frequencies"],

Cell[TextData[{
  " extracting",
  ", ",
  ButtonBox["Gene & genotype frequencies",
    ButtonData:>{"Gene & genotype frequencies", "AlleleFrequency"},
    ButtonStyle->"AddOnsLink"]
}], "IndexSubentry",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Allele frequencies"],

Cell[TextData[{
  "AlleleFrequencies",
  ",",
  " in numerical models",
  ", ",
  ButtonBox["Allele frequencies: representation",
    ButtonData:>{"Allele frequencies: representation", None},
    ButtonStyle->"AddOnsLink"],
  ",",
  ButtonBox["Overview of numerical models",
    ButtonData:>{"Overview of numerical models", "AlleleFrequencies"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"AlleleFrequencies"],

Cell[TextData[{
  "AlleleFrequency",
  ",",
  " ",
  ButtonBox["Gene & genotype frequencies",
    ButtonData:>{"Gene & genotype frequencies", "AlleleFrequency"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"AlleleFrequency"],

Cell[TextData[{
  "AlleleFrequencyMean",
  ",",
  " ",
  ButtonBox["Gene & genotype frequencies",
    ButtonData:>{"Gene & genotype frequencies", "AlleleFrequencyMean"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"AlleleFrequencyMean"],

Cell[TextData[{
  " for allele frequencies",
  ", ",
  ButtonBox["Allele frequencies: representation",
    ButtonData:>{"Allele frequencies: representation", "AlleleFrequencyMean"},
    
    ButtonStyle->"AddOnsLink"],
  "\n",
  " for genotype frequencies",
  ", ",
  ButtonBox["Recursions: description",
    ButtonData:>{"Recursions: description", "AlleleFrequencyMean"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " for individuals",
  ", ",
  ButtonBox["Simulating individuals: Describing populations",
    ButtonData:>{"Simulating individuals: Describing populations", 
      "AlleleFrequencyMean"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " for symmetric model",
  ", ",
  ButtonBox["Symmetric model: Describing populations",
    ButtonData:>{"Symmetric model: Describing populations", 
      "AlleleFrequencyMean"},
    ButtonStyle->"AddOnsLink"]
}], "IndexSubentry",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"AlleleFrequencyMean"],

Cell[TextData[{
  "AlleleFrequencyP",
  ",",
  " \[GothicP], \[AliasIndicator]gop\[AliasIndicator]",
  ", ",
  ButtonBox["Populations",
    ButtonData:>{"Populations", "AlleleFrequencyP"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"AlleleFrequencyP"],

Cell[TextData[{
  "AlleleFrequencyPermutations",
  ",",
  " ",
  ButtonBox["Internal functions",
    ButtonData:>{"Internal functions", "AlleleFrequencyPermutations"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"AlleleFrequencyPermutations"],

Cell[TextData[{
  "AlleleFrequencyPQ",
  ",",
  " \[GothicP]\[GothicQ], \[AliasIndicator]gop\[AliasIndicator]\
\[AliasIndicator]goq\[AliasIndicator]",
  ", ",
  ButtonBox["Populations",
    ButtonData:>{"Populations", "AlleleFrequencyPQ"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"AlleleFrequencyPQ"],

Cell[TextData[{
  "AlleleFrequencyQ",
  ",",
  " \[GothicQ], \[AliasIndicator]goq\[AliasIndicator]",
  ", ",
  ButtonBox["Populations",
    ButtonData:>{"Populations", "AlleleFrequencyQ"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"AlleleFrequencyQ"],

Cell[TextData[{
  "AlleleFrequencyTable",
  ",",
  " ",
  ButtonBox["Gene & genotype frequencies",
    ButtonData:>{"Gene & genotype frequencies", "AlleleFrequencyTable"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"AlleleFrequencyTable"],

Cell[TextData[{
  " for allele frequencies",
  ", ",
  ButtonBox["Allele frequencies: representation",
    ButtonData:>{"Allele frequencies: representation", 
      "AlleleFrequencyTable"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " for genotype frequencies",
  ", ",
  ButtonBox["Recursions: description",
    ButtonData:>{"Recursions: description", "AlleleFrequencyTable"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " for individuals",
  ", ",
  ButtonBox["Simulating individuals: Describing populations",
    ButtonData:>{"Simulating individuals: Describing populations", 
      "AlleleFrequencyTable"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " for symmetric model",
  ", ",
  ButtonBox["Symmetric model: Describing populations",
    ButtonData:>{"Symmetric model: Describing populations", 
      "AlleleFrequencyTable"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " with null alleles",
  ", ",
  ButtonBox["Gene & genotype frequencies",
    ButtonData:>{"Gene & genotype frequencies", "NulAllele"},
    ButtonStyle->"AddOnsLink"]
}], "IndexSubentry",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"AlleleFrequencyTable"],

Cell[TextData[{
  "AllelicDeviation",
  ",",
  " \[Zeta], \[AliasIndicator]z\[AliasIndicator]",
  ", ",
  ButtonBox["Allelic state",
    ButtonData:>{"Allelic state", "AllelicDeviation"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"AllelicDeviation"],

Cell[TextData[{
  "AllelicState",
  ",",
  " X",
  ", ",
  ButtonBox["Allelic state",
    ButtonData:>{"Allelic state", "AllelicState"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"AllelicState"],

Cell[TextData[{
  "AllEvents",
  ",",
  " in ancestral graphs",
  ", ",
  ButtonBox["Describing ancestral graphs",
    ButtonData:>{"Describing ancestral graphs", "AllEvents"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"AllEvents"],

Cell[TextData[{
  "AllSets",
  ",",
  " ",
  ButtonBox["The set of all structures",
    ButtonData:>{"The set of all structures", "AllSets"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"AllSets"],

Cell[TextData[{
  "Ancestors",
  ",",
  " determining",
  ", ",
  ButtonBox["Determining ancestry",
    ButtonData:>{"Determining ancestry", "Ancestors"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Ancestors"],

Cell[TextData[{
  " in ancestral graphs",
  ", ",
  ButtonBox["Ancestors & descendants",
    ButtonData:>{"Ancestors & descendants", "Ancestors"},
    ButtonStyle->"AddOnsLink"]
}], "IndexSubentry",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Ancestors"],

Cell[TextData[{
  "AncestralGraphPattern",
  ",",
  " ",
  ButtonBox["Representing ancestral graphs",
    ButtonData:>{"Representing ancestral graphs", "AncestralGraphPattern"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"AncestralGraphPattern"],

Cell[TextData[{
  "Ancestral graphs",
  ",",
  " describing",
  ", ",
  ButtonBox["Describing ancestral graphs",
    ButtonData:>{"Describing ancestral graphs", None},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Ancestral graphs"],

Cell[TextData[{
  " genealogies in",
  ", ",
  ButtonBox["Extracting genealogies",
    ButtonData:>{"Extracting genealogies", "ExtractGenealogy"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " introduction",
  ", ",
  ButtonBox["Ancestral graphs introduction",
    ButtonData:>{"Ancestral graphs introduction", None},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " plotting",
  ", ",
  ButtonBox["Plotting ancestral graphs",
    ButtonData:>{"Plotting ancestral graphs", None},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " random",
  ", ",
  ButtonBox["Random ancestral graphs",
    ButtonData:>{"Random ancestral graphs", None},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " representing",
  ", ",
  ButtonBox["Representing ancestral graphs",
    ButtonData:>{"Representing ancestral graphs", None},
    ButtonStyle->"AddOnsLink"]
}], "IndexSubentry",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Ancestral graphs"],

Cell[TextData[{
  "AncestralLineage",
  ",",
  " ",
  ButtonBox["Representing ancestral graphs",
    ButtonData:>{"Representing ancestral graphs", "AncestralLineage"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"AncestralLineage"],

Cell[TextData[{
  "AncestralLineagePattern",
  ",",
  " ",
  ButtonBox["Representing ancestral graphs",
    ButtonData:>{"Representing ancestral graphs", "AncestralLineagePattern"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"AncestralLineagePattern"],

Cell[TextData[{
  "Ancestry",
  ",",
  " ",
  ButtonBox["Describing individuals",
    ButtonData:>{"Describing individuals", "Ancestry"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Ancestry"],

Cell[TextData[{
  "Arbitrary sets of loci",
  ",",
  " as used in Kirkpatrick et al.",
  ", ",
  ButtonBox["Multilocus MS relation",
    ButtonData:>{"Multilocus MS relation", "Arbitrary sets of loci"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Arbitrary sets of loci"],

Cell[TextData[{
  "Arnold 1996",
  ",",
  " ",
  ButtonBox["References",
    ButtonData:>{"References", "Arnold 1996"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Arnold 1996"],

Cell[TextData[{
  "Asmussen and Orive 2000",
  ",",
  " ",
  ButtonBox["Migration example",
    ButtonData:>{"Migration example", "Asmussen and Orive 2000"},
    ButtonStyle->"AddOnsLink"],
  ",",
  ButtonBox["References",
    ButtonData:>{"References", "Asmussen and Orive 2000"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Asmussen and Orive 2000"],

Cell[TextData[{
  "Asmussen et al. 1987",
  ",",
  " ",
  ButtonBox["References",
    ButtonData:>{"References", "Asmussen et al 1987"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Asmussen et al. 1987"],

Cell[TextData[{
  "B",
  ",",
  " ",
  ButtonBox["Distribution of coalescence times",
    ButtonData:>{"Distribution of coalescence times", "B"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"B"],

Cell[TextData[{
  "Baake 2001",
  ",",
  " ",
  ButtonBox["Alternative measures",
    ButtonData:>{"Alternative measures", "Baake"},
    ButtonStyle->"AddOnsLink"],
  ",",
  ButtonBox["References",
    ButtonData:>{"References", "Baake 2001"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Baake 2001"],

Cell[TextData[{
  "BackgroundStyle",
  ",",
  " option for PlotSegments",
  ", ",
  ButtonBox["Plotting ancestral graphs",
    ButtonData:>{"Plotting ancestral graphs", "BackgroundStyle"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"BackgroundStyle"],

Cell[TextData[{
  "Barrier",
  ",",
  " in symmetric model",
  ", ",
  ButtonBox["Adding a neutral gene",
    ButtonData:>{"Adding a neutral gene", "Barrier"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Barrier"],

Cell[TextData[{
  "BarrierStrength",
  ",",
  " ",
  ButtonBox["Describing populations",
    ButtonData:>{"Describing populations", "BarrierStrength"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"BarrierStrength"],

Cell[TextData[{
  "Barton 1986",
  ",",
  " ",
  ButtonBox["References",
    ButtonData:>{"References", "Barton 1986"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Barton 1986"],

Cell[TextData[{
  "Barton 1995",
  ",",
  " ",
  ButtonBox["Multilocus references",
    ButtonData:>{"Multilocus references", "Barton 1995"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Barton 1995"],

Cell[TextData[{
  "Barton 2000",
  ",",
  " ",
  ButtonBox["References",
    ButtonData:>{"References", "Barton 2000"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Barton 2000"],

Cell[TextData[{
  "Barton and Turelli 1991",
  ",",
  " ",
  ButtonBox["Multilocus references",
    ButtonData:>{"Multilocus references", "Barton and Turelli 1991"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Barton and Turelli 1991"],

Cell[TextData[{
  "Barton & Gale 1993",
  ",",
  " ",
  ButtonBox["References",
    ButtonData:>{"References", "Barton & Gale 1993"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Barton & Gale 1993"],

Cell[TextData[{
  "Barton & Shpak 1999",
  ",",
  " ",
  ButtonBox["References",
    ButtonData:>{"References", "Barton & Shpak 1999"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Barton & Shpak 1999"],

Cell[TextData[{
  "Barton & Turelli 1991",
  ",",
  " ",
  ButtonBox["References",
    ButtonData:>{"References", "Barton & Turelli 1991"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Barton & Turelli 1991"],

Cell[TextData[{
  "Bennett 1954",
  ",",
  " ",
  ButtonBox["References",
    ButtonData:>{"References", "Bennett 1954"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Bennett 1954"],

Cell[TextData[{
  "BennettB",
  ",",
  " ",
  ButtonBox["Alternative measures",
    ButtonData:>{"Alternative measures", "BennettB"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"BennettB"],

Cell[TextData[{
  "BennettC",
  ",",
  " ",
  ButtonBox["Alternative measures",
    ButtonData:>{"Alternative measures", "BennettC"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"BennettC"],

Cell[TextData[{
  "BennettExpansion",
  ",",
  " ",
  ButtonBox["Alternative measures",
    ButtonData:>{"Alternative measures", "BennettExpansion"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"BennettExpansion"],

Cell[TextData[{
  "Biallelic",
  ",",
  " ",
  ButtonBox["Two alleles",
    ButtonData:>{"Two alleles", "Biallelic"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Biallelic"],

Cell[TextData[{
  " selection coefficients",
  ", ",
  ButtonBox["Fitness",
    ButtonData:>{"Fitness", "Two alleles"},
    ButtonStyle->"AddOnsLink"],
  ",",
  ButtonBox["Phenotypes",
    ButtonData:>{"Phenotypes", "Two alleles"},
    ButtonStyle->"AddOnsLink"]
}], "IndexSubentry",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Biallelic"],

Cell[TextData[{
  "BiallelicMutation",
  ",",
  " ",
  ButtonBox["Multilocus mutation",
    ButtonData:>{"Multilocus mutation", "BiallelicMutation"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"BiallelicMutation"],

Cell[TextData[{
  " Mutation option",
  ", ",
  ButtonBox["Multilocus mutation",
    ButtonData:>{"Multilocus mutation", "Mutation"},
    ButtonStyle->"AddOnsLink"]
}], "IndexSubentry",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"BiallelicMutation"],

Cell[TextData[{
  "Binary integers",
  ",",
  " ",
  ButtonBox["Set combinations",
    ButtonData:>{"Set combinations", "SetOfCombinations"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Binary integers"],

Cell[TextData[{
  "Birth",
  ",",
  " ",
  ButtonBox["Iterating  the continuum model",
    ButtonData:>{"Iterating  the continuum model", "Birth"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Birth"],

Cell[TextData[{
  "BirthTime",
  ",",
  " ",
  ButtonBox["Describing individuals",
    ButtonData:>{"Describing individuals", "BirthTime"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"BirthTime"],

Cell[TextData[{
  "Boundary conditions",
  ",",
  " in numerical models",
  ", ",
  ButtonBox["Allele frequencies:migration",
    ButtonData:>{"Allele frequencies:migration", "FixedEnds"},
    ButtonStyle->"AddOnsLink"],
  ",",
  ButtonBox["Recursions:migration",
    ButtonData:>{"Recursions:migration", "FixedEnds"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Boundary conditions"],

Cell[TextData[{
  "Box",
  ",",
  " ",
  ButtonBox["Boxing the individuals",
    ButtonData:>{"Boxing the individuals", "Box"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Box"],

Cell[TextData[{
  "Boxes",
  ",",
  " ",
  ButtonBox["Describing individuals",
    ButtonData:>{"Describing individuals", "Boxes"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Boxes"],

Cell[TextData[{
  "Browser categories",
  ",",
  " ",
  ButtonBox["How the Help Browser works",
    ButtonData:>{"How the Help Browser works", "Browser categories"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Browser categories"],

Cell[TextData[{
  "Bugs",
  ",",
  " applying rules",
  ", ",
  ButtonBox["Bugs",
    ButtonData:>{"Bugs", "Applying rules"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Bugs"],

Cell[TextData[{
  " clashes between packages",
  ", ",
  ButtonBox["Bugs",
    ButtonData:>{"Bugs", "Clashes between packages"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " estimating D",
  ", ",
  ButtonBox["Bugs",
    ButtonData:>{"Bugs", "Obsolete EstimatingD"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " incompatibilities",
  ", ",
  ButtonBox["Bugs",
    ButtonData:>{"Bugs", "Incompatibilities"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " manipulating notebooks",
  ", ",
  ButtonBox["Bugs",
    ButtonData:>{"Bugs", "Manipulating notebooks"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " multilocus notation",
  ", ",
  ButtonBox["Bugs",
    ButtonData:>{"Bugs", "Multilocus notation"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " numerical error with AlleleFrequencies",
  ", ",
  ButtonBox["Allele frequencies: iterating a cline",
    ButtonData:>{"Allele frequencies: iterating a cline", "Numerical bug"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " pasting hyperlinks",
  ", ",
  ButtonBox["Bugs",
    ButtonData:>{"Bugs", "Pasting hyperlinks"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " repeated \\\\",
  ", ",
  ButtonBox["Bugs",
    ButtonData:>{"Bugs", "Repeated \\\\"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " special notation",
  ", ",
  ButtonBox["Bugs",
    ButtonData:>{"Bugs", "Special notation"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " with style sheets",
  ", ",
  ButtonBox["Bugs",
    ButtonData:>{"Bugs", "Style sheets"},
    ButtonStyle->"AddOnsLink"]
}], "IndexSubentry",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Bugs"],

Cell[TextData[{
  "ChangeContext",
  ",",
  "\[CirclePlus], \[AliasIndicator]c+\[AliasIndicator]",
  ", ",
  ButtonBox["Changing contexts",
    ButtonData:>{"Changing contexts", "ChangeContext"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"ChangeContext"],

Cell[TextData[{
  "ChangeSex",
  ",",
  " ",
  ButtonBox["Changing sex",
    ButtonData:>{"Changing sex", "ChangeSex"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"ChangeSex"],

Cell[TextData[{
  "ClassToGenotypes",
  ",",
  " ",
  ButtonBox["Symmetric model: converting",
    ButtonData:>{"Symmetric model: converting", "ClassToGenotypes"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"ClassToGenotypes"],

Cell[TextData[{
  "Cline",
  ",",
  " example of",
  ", ",
  ButtonBox["Example: epistasis",
    ButtonData:>{"Example: epistasis", None},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Cline"],

Cell[TextData[{
  " in allele frequencies",
  ", ",
  ButtonBox["Allele frequencies: iterating a cline",
    ButtonData:>{"Allele frequencies: iterating a cline", None},
    ButtonStyle->"AddOnsLink"],
  ",",
  ButtonBox["Allele frequencies: setting up a cline",
    ButtonData:>{"Allele frequencies: setting up a cline", None},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " in genotype frequencies",
  ", ",
  ButtonBox["Recursions: iterating a cline",
    ButtonData:>{"Recursions: iterating a cline", None},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " in symmetric model",
  ", ",
  ButtonBox["Symmetric model: iterating a cline",
    ButtonData:>{"Symmetric model: iterating a cline", None},
    ButtonStyle->"AddOnsLink"],
  ",",
  ButtonBox["Symmetric model: setting up a cline",
    ButtonData:>{"Symmetric model: setting up a cline", None},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " stability of",
  ", ",
  ButtonBox["Allele frequencies: stability",
    ButtonData:>{"Allele frequencies: stability", None},
    ButtonStyle->"AddOnsLink"],
  ",",
  ButtonBox["Example: stability",
    ButtonData:>{"Example: stability", None},
    ButtonStyle->"AddOnsLink"],
  ",",
  ButtonBox["Symmetric stability: a cline",
    ButtonData:>{"Symmetric stability: a cline", None},
    ButtonStyle->"AddOnsLink"],
  ",",
  ButtonBox["Symmetric stability: spatially varying selection",
    ButtonData:>{"Symmetric stability: spatially varying selection", None},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " symmetric",
  ", ",
  ButtonBox["Recursions:setting up a symmetric cline",
    ButtonData:>{"Recursions:setting up a symmetric cline", "DoubleCline"},
    ButtonStyle->"AddOnsLink"],
  ",",
  ButtonBox["Simulating individuals: setting up a symmetric cline",
    ButtonData:>{"Simulating individuals: setting up a symmetric cline", 
      None},
    ButtonStyle->"AddOnsLink"],
  ",",
  ButtonBox["Symmetric model: setting up a symmetric cline",
    ButtonData:>{"Symmetric model: setting up a symmetric cline", None},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " with individuals",
  ", ",
  ButtonBox["Simulating individuals: iterating a cline",
    ButtonData:>{"Simulating individuals: iterating a cline", None},
    ButtonStyle->"AddOnsLink"],
  ",",
  ButtonBox["Simulating individuals:setting up a cline",
    ButtonData:>{"Simulating individuals:setting up a cline", None},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " with neutral marker",
  ", ",
  ButtonBox["Adding a neutral gene",
    ButtonData:>{"Adding a neutral gene", "Cline"},
    ButtonStyle->"AddOnsLink"]
}], "IndexSubentry",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Cline"],

Cell[TextData[{
  "ClineGradient",
  ",",
  "  for genotype frequencies",
  ", ",
  ButtonBox["ClineGradient: setting up a cline",
    ButtonData:>{"ClineGradient: setting up a cline", "ClineGradient"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"ClineGradient"],

Cell[TextData[{
  "ClineWidth",
  ",",
  " for allele frequencies",
  ", ",
  ButtonBox["Allele frequencies: setting up a cline",
    ButtonData:>{"Allele frequencies: setting up a cline", "ClineWidth"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"ClineWidth"],

Cell[TextData[{
  "  for genotype frequencies",
  ", ",
  ButtonBox["Recursions: setting up a cline",
    ButtonData:>{"Recursions: setting up a cline", "ClineWidth"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " for individuals",
  ", ",
  ButtonBox["Simulating individuals:setting up a cline",
    ButtonData:>{"Simulating individuals:setting up a cline", "ClineWidth"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " for symmetric model",
  ", ",
  ButtonBox["Symmetric model: setting up a cline",
    ButtonData:>{"Symmetric model: setting up a cline", "ClineWidth"},
    ButtonStyle->"AddOnsLink"]
}], "IndexSubentry",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"ClineWidth"],

Cell[TextData[{
  "CoalesceLineages",
  ",",
  " ",
  ButtonBox["Coalescence and recombination",
    ButtonData:>{"Coalescence and recombination", "CoalesceLineages"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"CoalesceLineages"],

Cell[TextData[{
  "CoalescenceDistribution",
  ",",
  " ",
  ButtonBox["Distribution of coalescence times",
    ButtonData:>{"Distribution of coalescence times", 
      "CoalescenceDistribution"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"CoalescenceDistribution"],

Cell[TextData[{
  "CoalescenceEvents",
  ",",
  " in ancestral graphs",
  ", ",
  ButtonBox["Describing ancestral graphs",
    ButtonData:>{"Describing ancestral graphs", "CoalescenceEvents"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"CoalescenceEvents"],

Cell[TextData[{
  "Coalescence times",
  ",",
  " random, for ancestral graphs",
  ", ",
  ButtonBox["Random ancestral graphs",
    ButtonData:>{"Random ancestral graphs", "RandomCoalescenceTimes"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Coalescence times"],

Cell[TextData[{
  "CoalescentLineages",
  ",",
  " in ancestral graphs",
  ", ",
  ButtonBox["Describing ancestral graphs",
    ButtonData:>{"Describing ancestral graphs", "CoalescentLineages"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"CoalescentLineages"],

Cell[TextData[{
  "Coalescing lineages",
  ",",
  " in ancestral graphs",
  ", ",
  ButtonBox["Coalescence and recombination",
    ButtonData:>{"Coalescence and recombination", "CoalesceLineages"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Coalescing lineages"],

Cell[TextData[{
  "CollapseGenealogy",
  ",",
  " ",
  ButtonBox["Describing genealogies",
    ButtonData:>{"Describing genealogies", "CollapseGenealogy"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"CollapseGenealogy"],

Cell[TextData[{
  "Combinations",
  ",",
  " set of",
  ", ",
  ButtonBox["Set combinations",
    ButtonData:>{"Set combinations", "SetOfCombinations"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Combinations"],

Cell[TextData[{
  "Combine",
  ",",
  " ",
  ButtonBox["Tagging sets",
    ButtonData:>{"Tagging sets", "Combine"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Combine"],

Cell[TextData[{
  "CompareLogL",
  ",",
  " ",
  ButtonBox["Presenting results",
    ButtonData:>{"Presenting results", "CompareLogL"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"CompareLogL"],

Cell[TextData[{
  "Compiled",
  ",",
  " option for IterateExact",
  ", ",
  ButtonBox["Allele frequencies: iterating a cline",
    ButtonData:>{"Allele frequencies: iterating a cline", "Compiled"},
    ButtonStyle->"AddOnsLink"],
  ",",
  ButtonBox["Allele frequencies: iterating one deme",
    ButtonData:>{"Allele frequencies: iterating one deme", "Compiled"},
    ButtonStyle->"AddOnsLink"],
  ",",
  ButtonBox["Recursions: compiling",
    ButtonData:>{"Recursions: compiling", "Compiled"},
    ButtonStyle->"AddOnsLink"],
  ",",
  ButtonBox["Recursions: iterating a cline",
    ButtonData:>{"Recursions: iterating a cline", "Compiled"},
    ButtonStyle->"AddOnsLink"],
  ",",
  ButtonBox["Symmetric model: iterating a cline",
    ButtonData:>{"Symmetric model: iterating a cline", "Compiled"},
    ButtonStyle->"AddOnsLink"],
  ",",
  ButtonBox["Symmetric model: iterating one deme",
    ButtonData:>{"Symmetric model: iterating one deme", "Compiled"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Compiled"],

Cell[TextData[{
  "Compiling",
  ",",
  " in numerical models",
  ", ",
  ButtonBox["Allele frequencies: iterating a cline",
    ButtonData:>{"Allele frequencies: iterating a cline", "Compiled"},
    ButtonStyle->"AddOnsLink"],
  ",",
  ButtonBox["Allele frequencies: iterating one deme",
    ButtonData:>{"Allele frequencies: iterating one deme", "Compiled"},
    ButtonStyle->"AddOnsLink"],
  ",",
  ButtonBox["Recursions: compiling",
    ButtonData:>{"Recursions: compiling", "Compiled"},
    ButtonStyle->"AddOnsLink"],
  ",",
  ButtonBox["Recursions: iterating a cline",
    ButtonData:>{"Recursions: iterating a cline", "Compiled"},
    ButtonStyle->"AddOnsLink"],
  ",",
  ButtonBox["Symmetric model: iterating a cline",
    ButtonData:>{"Symmetric model: iterating a cline", "Compiled"},
    ButtonStyle->"AddOnsLink"],
  ",",
  ButtonBox["Symmetric model: iterating one deme",
    ButtonData:>{"Symmetric model: iterating one deme", "Compiled"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Compiling"],

Cell[TextData[{
  "CondenseGenealogy",
  ",",
  " ",
  ButtonBox["Manipulating genealogies",
    ButtonData:>{"Manipulating genealogies", "CondenseGenealogy"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"CondenseGenealogy"],

Cell[TextData[{
  "CondenseMatrix",
  ",",
  " ",
  ButtonBox["Inferring a genealogy",
    ButtonData:>{"Inferring a genealogy", "CondenseMatrix"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"CondenseMatrix"],

Cell[TextData[{
  "ConfigurationSet",
  ",",
  " ",
  ButtonBox["Set combinations",
    ButtonData:>{"Set combinations", "ConfigurationSet"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"ConfigurationSet"],

Cell[TextData[{
  "ConstrainedIntervals",
  ",",
  " ",
  ButtonBox["Constrained intervals",
    ButtonData:>{"Constrained intervals", "ConstrainedIntervals"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"ConstrainedIntervals"],

Cell[TextData[{
  "ConstructMutateList",
  ",",
  " ",
  ButtonBox["Allele frequencies: mutation",
    ButtonData:>{"Allele frequencies: mutation", "ConstructMutateList"},
    ButtonStyle->"AddOnsLink"],
  ",",
  ButtonBox["Recursions: mutation",
    ButtonData:>{"Recursions: mutation", "ConstructMutateList"},
    ButtonStyle->"AddOnsLink"],
  ",",
  ButtonBox["Simulating individuals: mutation",
    ButtonData:>{"Simulating individuals: mutation", "ConstructMutateList"},
    ButtonStyle->"AddOnsLink"],
  ",",
  ButtonBox["Symmetric model: mutation",
    ButtonData:>{"Symmetric model: mutation", "ConstructMutateList"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"ConstructMutateList"],

Cell[TextData[{
  "ConstructMutateMatrix",
  ",",
  " ",
  ButtonBox["Recursions: mutation",
    ButtonData:>{"Recursions: mutation", "ConstructMutateMatrix"},
    ButtonStyle->"AddOnsLink"],
  ",",
  ButtonBox["Symmetric model: mutation",
    ButtonData:>{"Symmetric model: mutation", "ConstructMutateMatrix"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"ConstructMutateMatrix"],

Cell[TextData[{
  "ContextComponentQ",
  ",",
  " ",
  ButtonBox["Stages in the life cycle",
    ButtonData:>{"Stages in the life cycle", "ContextComponentQ"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"ContextComponentQ"],

Cell[TextData[{
  "ContextPosition",
  ",",
  " ",
  ButtonBox["Stages in the life cycle",
    ButtonData:>{"Stages in the life cycle", "ContextPosition"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"ContextPosition"],

Cell[TextData[{
  "ContextStageQ",
  ",",
  " ",
  ButtonBox["Stages in the life cycle",
    ButtonData:>{"Stages in the life cycle", "ContextStageQ"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"ContextStageQ"],

Cell[TextData[{
  "ContextStructure",
  ",",
  " ",
  ButtonBox["Stages in the life cycle",
    ButtonData:>{"Stages in the life cycle", "ContextStructure"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"ContextStructure"],

Cell[TextData[{
  "Continuous populations",
  ",",
  " estimating covariance",
  ", ",
  ButtonBox["Estimating the covariance",
    ButtonData:>{"Estimating the covariance", None},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Continuous populations"],

Cell[TextData[{
  " example",
  ", ",
  ButtonBox["An example",
    ButtonData:>{"An example", None},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " implementation",
  ", ",
  ButtonBox["Implementation",
    ButtonData:>{"Implementation", None},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " saving results",
  ", ",
  ButtonBox["Global variables",
    ButtonData:>{"Global variables", "Saving results"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " the model",
  ", ",
  ButtonBox["The model",
    ButtonData:>{"The model", None},
    ButtonStyle->"AddOnsLink"]
}], "IndexSubentry",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Continuous populations"],

Cell[TextData[{
  "ContinuumVariables",
  ",",
  " ",
  ButtonBox["Global variables",
    ButtonData:>{"Global variables", "ContinuumVariables"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"ContinuumVariables"],

Cell[TextData[{
  "ConvertData",
  ",",
  " ",
  ButtonBox["Converting a dataset",
    ButtonData:>{"Converting a dataset", "ConvertData"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"ConvertData"],

Cell[TextData[{
  "ConvertHyperlinkToAddOnsLink",
  ",",
  " ",
  ButtonBox["Hyperlinks",
    ButtonData:>{"Hyperlinks", "ConvertHyperlinkToAddOnsLink"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"ConvertHyperlinkToAddOnsLink"],

Cell[TextData[{
  "Converting",
  ",",
  " between representations",
  ", ",
  ButtonBox["Allele frequencies: converting",
    ButtonData:>{"Allele frequencies: converting", None},
    ButtonStyle->"AddOnsLink"],
  ",",
  ButtonBox["Recursions: converting",
    ButtonData:>{"Recursions: converting", None},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Converting"],

Cell[TextData[{
  "CountHeterozygotes",
  ",",
  " ",
  ButtonBox["Recursions:manipulation",
    ButtonData:>{"Recursions:manipulation", "CountHeterozygotes"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"CountHeterozygotes"],

Cell[TextData[{
  "Covariance",
  ",",
  " in continuous populations",
  ", ",
  ButtonBox["Estimating the covariance",
    ButtonData:>{"Estimating the covariance", None},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Covariance"],

Cell[TextData[{
  "CovarianceMidPoints",
  ",",
  " ",
  ButtonBox["Sampling",
    ButtonData:>{"Sampling", "CovarianceMidPoints"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"CovarianceMidPoints"],

Cell[TextData[{
  "Crow and Kimura 1970",
  ",",
  " ",
  ButtonBox["Multilocus references",
    ButtonData:>{"Multilocus references", "Crow and Kimura 1970"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Crow and Kimura 1970"],

Cell[TextData[{
  "Cumulant",
  ",",
  " ",
  ButtonBox["Moments and cumulants",
    ButtonData:>{"Moments and cumulants", "Cumulant"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Cumulant"],

Cell[TextData[{
  "CumulantDisequilibrium",
  ",",
  " \[GothicK], \[AliasIndicator]gok\[AliasIndicator]",
  ", ",
  ButtonBox["Populations",
    ButtonData:>{"Populations", "CumulantDisequilibrium"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"CumulantDisequilibrium"],

Cell[TextData[{
  "CumulantEquilibrium",
  ",",
  " ",
  ButtonBox["Equilibria",
    ButtonData:>{"Equilibria", "CumulantEquilibrium"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"CumulantEquilibrium"],

Cell[TextData[{
  "CumulantPopulationDisequilibrium",
  ",",
  " \[GothicCapitalK], \[AliasIndicator]goK\[AliasIndicator]",
  ", ",
  ButtonBox["Introduction to random drift",
    ButtonData:>{"Introduction to random drift", "Cumulants and moments"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"CumulantPopulationDisequilibrium"],

Cell[TextData[{
  "CumulantReduced",
  ",",
  " ",
  ButtonBox["Obsolete functions",
    ButtonData:>{"Obsolete functions", "CumulantReduced"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"CumulantReduced"],

Cell[TextData[{
  "Cumulants",
  ",",
  " ",
  ButtonBox["Cumulants",
    ButtonData:>{"Cumulants", "7.2"},
    ButtonStyle->"AddOnsLink"],
  ",",
  ButtonBox["Cumulants",
    ButtonData:>{"Cumulants", "Cumulant"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Cumulants"],

Cell[TextData[{
  "Cytoplasmic inheritance",
  ",",
  " ",
  ButtonBox["Non-Mendelian inheritance",
    ButtonData:>{"Non-Mendelian inheritance", "CytoplasmicLoci"},
    ButtonStyle->"AddOnsLink"],
  ",",
  ButtonBox["Reference points",
    ButtonData:>{"Reference points", "CytoplasmicLoci"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Cytoplasmic inheritance"],

Cell[TextData[{
  " and migration",
  ", ",
  ButtonBox["Migration example",
    ButtonData:>{"Migration example", "Cytonuclear associations"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " examples of",
  ", ",
  ButtonBox["Cytoplasmic inheritance",
    ButtonData:>{"Cytoplasmic inheritance", None},
    ButtonStyle->"AddOnsLink"]
}], "IndexSubentry",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Cytoplasmic inheritance"],

Cell[TextData[{
  "CytoplasmicLoci",
  ",",
  " example of",
  ", ",
  ButtonBox["Cytoplasmic inheritance",
    ButtonData:>{"Cytoplasmic inheritance", None},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"CytoplasmicLoci"],

Cell[TextData[{
  " option for NonMendelian",
  ", ",
  ButtonBox["Non-Mendelian inheritance",
    ButtonData:>{"Non-Mendelian inheritance", "CytoplasmicLoci"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " reference points",
  ", ",
  ButtonBox["Reference points",
    ButtonData:>{"Reference points", "CytoplasmicLoci"},
    ButtonStyle->"AddOnsLink"]
}], "IndexSubentry",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"CytoplasmicLoci"],

Cell[TextData[{
  "dAlleleFrequencyPermutations",
  ",",
  " ",
  ButtonBox["Internal functions",
    ButtonData:>{"Internal functions", "dAlleleFrequencyPermutations"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"dAlleleFrequencyPermutations"],

Cell[TextData[{
  "Data",
  ",",
  " ",
  ButtonBox["Defining a dataset",
    ButtonData:>{"Defining a dataset", "Data"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Data"],

Cell[TextData[{
  " missing",
  ", ",
  ButtonBox["Defining a dataset",
    ButtonData:>{"Defining a dataset", "Missing data"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " notation for",
  ", ",
  ButtonBox["Notation for genetic data",
    ButtonData:>{"Notation for genetic data", "NotationPackage"},
    ButtonStyle->"AddOnsLink"]
}], "IndexSubentry",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Data"],

Cell[TextData[{
  "Datasets",
  ",",
  " defining",
  ", ",
  ButtonBox["Defining a dataset",
    ButtonData:>{"Defining a dataset", "Data"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Datasets"],

Cell[TextData[{
  "Dawson 2000",
  ",",
  " ",
  ButtonBox["Alternative measures",
    ButtonData:>{"Alternative measures", "Bennett"},
    ButtonStyle->"AddOnsLink"],
  ",",
  ButtonBox["References",
    ButtonData:>{"References", "Dawson 2000"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Dawson 2000"],

Cell[TextData[{
  "Death",
  ",",
  " ",
  ButtonBox["Iterating  the continuum model",
    ButtonData:>{"Iterating  the continuum model", "Death"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Death"],

Cell[TextData[{
  "DeathTime",
  ",",
  " ",
  ButtonBox["Describing individuals",
    ButtonData:>{"Describing individuals", "DeathTime"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"DeathTime"],

Cell[TextData[{
  "DefineContext",
  ",",
  " ",
  ButtonBox["Stages in the life cycle",
    ButtonData:>{"Stages in the life cycle", "DefineContext"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"DefineContext"],

Cell[TextData[{
  "DegreesOfFreedom",
  ",",
  " ",
  ButtonBox["Degrees of freedom",
    ButtonData:>{"Degrees of freedom", "DegreesOfFreedom"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"DegreesOfFreedom"],

Cell[TextData[{
  "DeletedMutations",
  ",",
  " ",
  ButtonBox["Population bottlenecks",
    ButtonData:>{"Population bottlenecks", "DeletedMutations"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"DeletedMutations"],

Cell[TextData[{
  "DeleteGenealogy",
  ",",
  " ",
  ButtonBox["Manipulating genealogies",
    ButtonData:>{"Manipulating genealogies", "DeleteGenealogy"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"DeleteGenealogy"],

Cell[TextData[{
  "DeleteNullLineages",
  ",",
  " option for RandomGenealogy",
  ", ",
  ButtonBox["Random ancestral graphs",
    ButtonData:>{"Random ancestral graphs", "DeleteNullLineages"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"DeleteNullLineages"],

Cell[TextData[{
  " option for RecombineLineage",
  ", ",
  ButtonBox["Coalescence and recombination",
    ButtonData:>{"Coalescence and recombination", "DeleteNullLineages"},
    ButtonStyle->"AddOnsLink"]
}], "IndexSubentry",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"DeleteNullLineages"],

Cell[TextData[{
  "Deme",
  ",",
  " ",
  ButtonBox["Life cycle",
    ButtonData:>{"Life cycle", "Deme"},
    ButtonStyle->"AddOnsLink"],
  ",",
  ButtonBox["Migration",
    ButtonData:>{"Migration", "Deme"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Deme"],

Cell[TextData[{
  "DemeSize",
  ",",
  " compiling",
  ", ",
  ButtonBox["Allele frequencies: iterating one deme",
    ButtonData:>{"Allele frequencies: iterating one deme", "DemeSize"},
    ButtonStyle->"AddOnsLink"],
  ",",
  ButtonBox["Recursions: compiling",
    ButtonData:>{"Recursions: compiling", "DemeSize"},
    ButtonStyle->"AddOnsLink"],
  ",",
  ButtonBox["Symmetric model: iterating one deme",
    ButtonData:>{"Symmetric model: iterating one deme", 
      "Deme size (compiling)"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"DemeSize"],

Cell[TextData[{
  " for allele frequencies",
  ", ",
  ButtonBox["Allele frequencies: representation",
    ButtonData:>{"Allele frequencies: representation", "DemeSize"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " for genotype frequencies",
  ", ",
  ButtonBox["Recursions: description",
    ButtonData:>{"Recursions: description", "DemeSize"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " for individuals",
  ", ",
  ButtonBox["Simulating individuals: Describing populations",
    ButtonData:>{"Simulating individuals: Describing populations", 
      "DemeSize"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " for symmetric model",
  ", ",
  ButtonBox["Symmetric model: Describing populations",
    ButtonData:>{"Symmetric model: Describing populations", "DemeSize"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " option for IterateExact",
  ", ",
  ButtonBox["Allele frequencies: iterating a cline",
    ButtonData:>{"Allele frequencies: iterating a cline", "DemeSize"},
    ButtonStyle->"AddOnsLink"],
  ",",
  ButtonBox["Allele frequencies: iterating one deme",
    ButtonData:>{"Allele frequencies: iterating one deme", "DemeSize"},
    ButtonStyle->"AddOnsLink"],
  ",",
  ButtonBox["Recursions: iterating a cline",
    ButtonData:>{"Recursions: iterating a cline", "DemeSize"},
    ButtonStyle->"AddOnsLink"],
  ",",
  ButtonBox["Recursions: iterating one deme",
    ButtonData:>{"Recursions: iterating one deme", "DemeSize"},
    ButtonStyle->"AddOnsLink"],
  ",",
  ButtonBox["Simulating individuals: iterating a cline",
    ButtonData:>{"Simulating individuals: iterating a cline", "DemeSize"},
    ButtonStyle->"AddOnsLink"],
  ",",
  ButtonBox["Simulating individuals: iterating one deme",
    ButtonData:>{"Simulating individuals: iterating one deme", "DemeSize"},
    ButtonStyle->"AddOnsLink"],
  ",",
  ButtonBox["Symmetric model: iterating a cline",
    ButtonData:>{"Symmetric model: iterating a cline", "DemeSize"},
    ButtonStyle->"AddOnsLink"],
  ",",
  ButtonBox["Symmetric model: iterating one deme",
    ButtonData:>{"Symmetric model: iterating one deme", "DemeSize"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " option for MigrateExact",
  ", ",
  ButtonBox["Symmetric model: migration",
    ButtonData:>{"Symmetric model: migration", "DemeSize"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " option for NewGametes",
  ", ",
  ButtonBox["Allele frequencies:reproduction",
    ButtonData:>{"Allele frequencies:reproduction", "DemeSize"},
    ButtonStyle->"AddOnsLink"],
  ",",
  ButtonBox["Recursions:reproduction",
    ButtonData:>{"Recursions:reproduction", "DemeSize"},
    ButtonStyle->"AddOnsLink"],
  ",",
  ButtonBox["Simulating individuals: reproduction",
    ButtonData:>{"Simulating individuals: reproduction", "DemeSize"},
    ButtonStyle->"AddOnsLink"],
  ",",
  ButtonBox["Symmetric model: reproduction",
    ButtonData:>{"Symmetric model: reproduction", "DemeSize"},
    ButtonStyle->"AddOnsLink"]
}], "IndexSubentry",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"DemeSize"],

Cell[TextData[{
  "Dempster et al 1977",
  ",",
  " ",
  ButtonBox["References",
    ButtonData:>{"References", "Dempster et al 1977"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Dempster et al 1977"],

Cell[TextData[{
  "Density",
  ",",
  " ",
  ButtonBox["Describing individuals",
    ButtonData:>{"Describing individuals", "Density"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Density"],

Cell[TextData[{
  "Descendants",
  ",",
  " ",
  ButtonBox["Ancestors and descendants",
    ButtonData:>{"Ancestors and descendants", "Descendants"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Descendants"],

Cell[TextData[{
  " determining",
  ", ",
  ButtonBox["Determining ancestry",
    ButtonData:>{"Determining ancestry", "Descendants"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " in ancestral graphs",
  ", ",
  ButtonBox["Ancestors & descendants",
    ButtonData:>{"Ancestors & descendants", "Descendants"},
    ButtonStyle->"AddOnsLink"]
}], "IndexSubentry",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Descendants"],

Cell[TextData[{
  "Dicytonuclear associations",
  ",",
  " ",
  ButtonBox["Migration example",
    ButtonData:>{"Migration example", "Asmussen and Orive 2000"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Dicytonuclear associations"],

Cell[TextData[{
  "Diploid",
  ",",
  " option for MomentFromG",
  ", ",
  ButtonBox["Moments from genotype frequencies",
    ButtonData:>{"Moments from genotype frequencies", "Diploid"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Diploid"],

Cell[TextData[{
  "DiploidConstraints",
  ",",
  " ",
  ButtonBox["Obsolete functions",
    ButtonData:>{"Obsolete functions", "DiploidConstraints"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"DiploidConstraints"],

Cell[TextData[{
  "DiploidFrequencies",
  ",",
  " ",
  ButtonBox["Overview of numerical models",
    ButtonData:>{"Overview of numerical models", "DiploidFrequencies"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"DiploidFrequencies"],

Cell[TextData[{
  "DiploidGenotypeFrequency",
  ",",
  " ",
  ButtonBox["Genotype frequencies from moments",
    ButtonData:>{"Genotype frequencies from moments", 
      "DiploidGenotypeFrequency"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"DiploidGenotypeFrequency"],

Cell[TextData[{
  "DiploidGenotypeFrequencyList",
  ",",
  " ",
  ButtonBox["Fast calculations",
    ButtonData:>{"Fast calculations", "DiploidGenotypeFrequencyList"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"DiploidGenotypeFrequencyList"],

Cell[TextData[{
  "DiploidGenotypeFrequencyReduced",
  ",",
  " ",
  ButtonBox["Obsolete functions",
    ButtonData:>{"Obsolete functions", "DiploidGenotypeFrequencyReduced"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"DiploidGenotypeFrequencyReduced"],

Cell[TextData[{
  "DiploidGenotypeFrequencyTable",
  ",",
  " ",
  ButtonBox["Obsolete functions",
    ButtonData:>{"Obsolete functions", "DiploidGenotypeFrequencyTable"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"DiploidGenotypeFrequencyTable"],

Cell[TextData[{
  "DiploidIndividuals",
  ",",
  " ",
  ButtonBox["Overview of numerical models",
    ButtonData:>{"Overview of numerical models", "DiploidIndividuals"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"DiploidIndividuals"],

Cell[TextData[{
  "DiploidPhenotype",
  ",",
  " ",
  ButtonBox["Genotype frequencies",
    ButtonData:>{"Genotype frequencies", "DiploidPhenotype"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"DiploidPhenotype"],

Cell[TextData[{
  "DiploidPsi",
  ",",
  " ",
  ButtonBox["Genotype frequencies",
    ButtonData:>{"Genotype frequencies", "DiploidPsi"},
    ButtonStyle->"AddOnsLink"],
  ",",
  ButtonBox["Representing the population",
    ButtonData:>{"Representing the population", "DiploidPsi"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"DiploidPsi"],

Cell[TextData[{
  "DiploidRepresentations",
  ",",
  " ",
  ButtonBox["Overview of numerical models",
    ButtonData:>{"Overview of numerical models", "DiploidRepresentations"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"DiploidRepresentations"],

Cell[TextData[{
  "DiploidSource",
  ",",
  " ",
  ButtonBox["Genotype frequencies",
    ButtonData:>{"Genotype frequencies", "DiploidSource"},
    ButtonStyle->"AddOnsLink"],
  ",",
  ButtonBox["Representing the population",
    ButtonData:>{"Representing the population", "DiploidSource"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"DiploidSource"],

Cell[TextData[{
  "DiploidSubsets",
  ",",
  " ",
  ButtonBox["Subsets of loci",
    ButtonData:>{"Subsets of loci", "DiploidSubsets"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"DiploidSubsets"],

Cell[TextData[{
  "DiploidTypes",
  ",",
  " ",
  ButtonBox["Listing genotypes",
    ButtonData:>{"Listing genotypes", "DiploidTypes"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"DiploidTypes"],

Cell[TextData[{
  "Disequilibrium",
  ",",
  " Baake's measure",
  ", ",
  ButtonBox["Alternative measures",
    ButtonData:>{"Alternative measures", "Baake"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Disequilibrium"],

Cell[TextData[{
  " Bennett's principal components",
  ", ",
  ButtonBox["Alternative measures",
    ButtonData:>{"Alternative measures", "Bennett"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " population",
  ", ",
  ButtonBox["Expectations",
    ButtonData:>{"Expectations", "PopulationDisequilibrium"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " \[GothicCapitalD], \[AliasIndicator]\[GothicCapitalD]\[AliasIndicator]",
  ", ",
  ButtonBox["Disequilibrium",
    ButtonData:>{"Disequilibrium", "Disequilibrium"},
    ButtonStyle->"AddOnsLink"],
  ",",
  ButtonBox["Gene & genotype frequencies",
    ButtonData:>{"Gene & genotype frequencies", "Linkage disequilibrium"},
    ButtonStyle->"AddOnsLink"],
  ",",
  ButtonBox["Populations",
    ButtonData:>{"Populations", "Disequilibrium"},
    ButtonStyle->"AddOnsLink"]
}], "IndexSubentry",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Disequilibrium"],

Cell[TextData[{
  "DisequilibriumMean",
  ",",
  " for allele frequencies",
  ", ",
  ButtonBox["Allele frequencies: representation",
    ButtonData:>{"Allele frequencies: representation", "DisequilibriumMean"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"DisequilibriumMean"],

Cell[TextData[{
  " for genotype frequencies",
  ", ",
  ButtonBox["Recursions: description",
    ButtonData:>{"Recursions: description", "DisequilibriumMean"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " for individuals",
  ", ",
  ButtonBox["Simulating individuals: Describing populations",
    ButtonData:>{"Simulating individuals: Describing populations", 
      "DisequilibriumMean"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " for symmetric model",
  ", ",
  ButtonBox["Symmetric model: Describing populations",
    ButtonData:>{"Symmetric model: Describing populations", 
      "DisequilibriumMean"},
    ButtonStyle->"AddOnsLink"]
}], "IndexSubentry",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"DisequilibriumMean"],

Cell[TextData[{
  "DisequilibriumTable",
  ",",
  " for allele frequencies",
  ", ",
  ButtonBox["Allele frequencies: representation",
    ButtonData:>{"Allele frequencies: representation", "DisequilibriumTable"},
    
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"DisequilibriumTable"],

Cell[TextData[{
  " for genotype frequencies",
  ", ",
  ButtonBox["Recursions: description",
    ButtonData:>{"Recursions: description", "DisequilibriumTable"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " for individuals",
  ", ",
  ButtonBox["Simulating individuals: Describing populations",
    ButtonData:>{"Simulating individuals: Describing populations", 
      "DisequilibriumTable"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " for symmetric model",
  ", ",
  ButtonBox["Symmetric model: Describing populations",
    ButtonData:>{"Symmetric model: Describing populations", 
      "DisequilibriumTable"},
    ButtonStyle->"AddOnsLink"]
}], "IndexSubentry",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"DisequilibriumTable"],

Cell[TextData[{
  "Dispersal",
  ",",
  " in continuum simulations",
  ", ",
  ButtonBox["Iterating  the continuum model",
    ButtonData:>{"Iterating  the continuum model", None},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Dispersal"],

Cell[TextData[{
  "DistanceSquared",
  ",",
  " ",
  ButtonBox["Boxing the individuals",
    ButtonData:>{"Boxing the individuals", "DistanceSquared"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"DistanceSquared"],

Cell[TextData[{
  "Distribution",
  ",",
  " ",
  ButtonBox["Cumulants",
    ButtonData:>{"Cumulants", "Distribution"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Distribution"],

Cell[TextData[{
  "DivideZero",
  ",",
  " ",
  ButtonBox["DivideZero",
    ButtonData:>{"DivideZero", "DivideZero"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"DivideZero"],

Cell[TextData[{
  "DoReplicates",
  ",",
  " ",
  ButtonBox["Analysing replicate samples",
    ButtonData:>{"Analysing replicate samples", "DoReplicates"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"DoReplicates"],

Cell[TextData[{
  "DoubleCline",
  ",",
  " for allele frequencies",
  ", ",
  ButtonBox["Allele frequencies: setting up a symmetric cline",
    ButtonData:>{"Allele frequencies: setting up a symmetric cline", 
      "DoubleCline"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"DoubleCline"],

Cell[TextData[{
  " for genotype frequencies",
  ", ",
  ButtonBox["Recursions:setting up a symmetric cline",
    ButtonData:>{"Recursions:setting up a symmetric cline", "DoubleCline"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " for individuals",
  ", ",
  ButtonBox["Simulating individuals: setting up a symmetric cline",
    ButtonData:>{"Simulating individuals: setting up a symmetric cline", 
      "DoubleCline"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " for symmetric model",
  ", ",
  ButtonBox["Symmetric model: setting up a symmetric cline",
    ButtonData:>{"Symmetric model: setting up a symmetric cline", 
      "DoubleCline"},
    ButtonStyle->"AddOnsLink"]
}], "IndexSubentry",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"DoubleCline"],

Cell[TextData[{
  "DrawSamples",
  ",",
  " ",
  ButtonBox["Setting up replicates",
    ButtonData:>{"Setting up replicates", "DrawSamples"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"DrawSamples"],

Cell[TextData[{
  "DropOptions",
  ",",
  " ",
  ButtonBox["Manipulating options",
    ButtonData:>{"Manipulating options", "DropOptions"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"DropOptions"],

Cell[TextData[{
  "Edwards 1972",
  ",",
  " ",
  ButtonBox["References",
    ButtonData:>{"References", "Edwards 1972"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Edwards 1972"],

Cell[TextData[{
  "EmptySets",
  ",",
  "option for PartitionSet",
  ", ",
  ButtonBox["Set partitions",
    ButtonData:>{"Set partitions", "EmptySets"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"EmptySets"],

Cell[TextData[{
  "Epistasis",
  ",",
  " in numerical models",
  ", ",
  ButtonBox["Example: epistasis",
    ButtonData:>{"Example: epistasis", None},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Epistasis"],

Cell[TextData[{
  "EquivalentSexes",
  ",",
  " obsolete form of SymmetricSexes",
  ", ",
  ButtonBox["Symmetric sexes",
    ButtonData:>{"Symmetric sexes", "SymmetricSexes"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"EquivalentSexes"],

Cell[TextData[{
  "ErrorBound",
  ",",
  " ",
  ButtonBox["Options for StructuredMLE",
    ButtonData:>{"Options for StructuredMLE", "ErrorBound"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"ErrorBound"],

Cell[TextData[{
  "EstimateFamilyMoments",
  ",",
  " ",
  ButtonBox["Estimation from families",
    ButtonData:>{"Estimation from families", "EstimateFamilyMoments"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"EstimateFamilyMoments"],

Cell[TextData[{
  "EstimateMoments",
  ",",
  " ",
  ButtonBox["Estimating the matrix",
    ButtonData:>{"Estimating the matrix", "EstimateMoments"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"EstimateMoments"],

Cell[TextData[{
  "Estimating D",
  ",",
  " admixture models",
  ", ",
  ButtonBox["Admixture models",
    ButtonData:>{"Admixture models", None},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Estimating D"],

Cell[TextData[{
  " alternative methods",
  ", ",
  ButtonBox["Alternative methods",
    ButtonData:>{"Alternative methods", "Log-linear models"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " introduction",
  ", ",
  ButtonBox["Introduction to estimating D",
    ButtonData:>{"Introduction to estimating D", None},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " maximum entropy",
  ", ",
  ButtonBox["Alternative methods",
    ButtonData:>{"Alternative methods", "Maximum entropy"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " maximum likelihood, example of",
  ", ",
  ButtonBox["MLE example",
    ButtonData:>{"MLE example", None},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " Metropolis random walk",
  ", ",
  ButtonBox["Random walk",
    ButtonData:>{"Random walk", None},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " MLE, cumulants",
  ", ",
  ButtonBox["Finding the MLE",
    ButtonData:>{"Finding the MLE", "Cumulant"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " moments, families",
  ", ",
  ButtonBox["Estimating the matrix of moments",
    ButtonData:>{"Estimating the matrix of moments", "Extension to families"},
    
    ButtonStyle->"AddOnsLink"],
  "\n",
  " naive MLE",
  ", ",
  ButtonBox["Alternative methods",
    ButtonData:>{"Alternative methods", "Naive MLE"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " obsolete",
  ", ",
  ButtonBox["Bugs",
    ButtonData:>{"Bugs", "Obsolete EstimatingD"},
    ButtonStyle->"AddOnsLink"],
  ",",
  ButtonBox["Obsolete functions",
    ButtonData:>{"Obsolete functions", None},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " pairs of loci",
  ", ",
  ButtonBox["Pairs of loci",
    ButtonData:>{"Pairs of loci", None},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " pairs of loci, example of",
  ", ",
  ButtonBox["Pairwise example",
    ButtonData:>{"Pairwise example", None},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " random sampling, example of",
  ", ",
  ButtonBox["Sampling example",
    ButtonData:>{"Sampling example", None},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " summary",
  ", ",
  ButtonBox["Summary",
    ButtonData:>{"Summary", None},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " varying divergence",
  ", ",
  ButtonBox["Estimating the matrix",
    ButtonData:>{"Estimating the matrix", "Varying divergence"},
    ButtonStyle->"AddOnsLink"]
}], "IndexSubentry",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Estimating D"],

Cell[TextData[{
  "ExactEigenvalues",
  ",",
  " ",
  ButtonBox["Symmetric stability: one deme",
    ButtonData:>{"Symmetric stability: one deme", "ExactEigenvalues"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"ExactEigenvalues"],

Cell[TextData[{
  "ExactIntersection",
  ",",
  " \[Wedge], \[AliasIndicator]^\[AliasIndicator]",
  ", ",
  ButtonBox["ExactIntersection",
    ButtonData:>{"ExactIntersection", "ExactIntersection"},
    ButtonStyle->"AddOnsLink"],
  ",",
  ButtonBox["Operations on sets",
    ButtonData:>{"Operations on sets", "ExactIntersection"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"ExactIntersection"],

Cell[TextData[{
  "ExactProbability",
  ",",
  " ",
  ButtonBox["Exact probability",
    ButtonData:>{"Exact probability", "ExactProbability"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"ExactProbability"],

Cell[TextData[{
  "Expectation",
  ",",
  " <>",
  ", ",
  ButtonBox["Populations",
    ButtonData:>{"Populations", "Expectation"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Expectation"],

Cell[TextData[{
  " as used in Kirkpatrick et al.",
  ", ",
  ButtonBox["Multilocus MS relation",
    ButtonData:>{"Multilocus MS relation", "Expectation"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " population, \[LeftDoubleBracketingBar] \[RightDoubleBracketingBar], \
\[AliasIndicator]l||\[AliasIndicator] \[AliasIndicator]r||\[AliasIndicator]",
  ", ",
  ButtonBox["Expectations",
    ButtonData:>{"Expectations", "PopulationExpectation"},
    ButtonStyle->"AddOnsLink"]
}], "IndexSubentry",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Expectation"],

Cell[TextData[{
  "ExponentialF",
  ",",
  " for allele frequencies",
  ", ",
  ButtonBox["Allele frequencies: iterating one deme",
    ButtonData:>{"Allele frequencies: iterating one deme", "ExponentialF"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"ExponentialF"],

Cell[TextData[{
  " for genotype frequencies",
  ", ",
  ButtonBox["Recursions: iterating one deme",
    ButtonData:>{"Recursions: iterating one deme", "ExponentialF"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " for symmetric model",
  ", ",
  ButtonBox["Symmetric model: iterating one deme",
    ButtonData:>{"Symmetric model: iterating one deme", "ExponentialF"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " with individuals",
  ", ",
  ButtonBox["Simulating individuals: iterating one deme",
    ButtonData:>{"Simulating individuals: iterating one deme", 
      "ExponentialF"},
    ButtonStyle->"AddOnsLink"],
  ",",
  ButtonBox["Simulating individuals: reproduction",
    ButtonData:>{"Simulating individuals: reproduction", "ExponentialF"},
    ButtonStyle->"AddOnsLink"]
}], "IndexSubentry",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"ExponentialF"],

Cell[TextData[{
  "ExtantIndividuals",
  ",",
  " ",
  ButtonBox["Global variables",
    ButtonData:>{"Global variables", "ExtantIndividuals"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"ExtantIndividuals"],

Cell[TextData[{
  "ExtractContexts",
  ",",
  " \[Chi], \[AliasIndicator]c\[AliasIndicator]",
  ", ",
  ButtonBox["Extracting contexts",
    ButtonData:>{"Extracting contexts", "ExtractContexts"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"ExtractContexts"],

Cell[TextData[{
  "ExtractExtant",
  ",",
  " ",
  ButtonBox["Sampling",
    ButtonData:>{"Sampling", "ExtractExtant"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"ExtractExtant"],

Cell[TextData[{
  "ExtractGenealogy",
  ",",
  " ",
  ButtonBox["Extracting genealogies",
    ButtonData:>{"Extracting genealogies", "ExtractGenealogy"},
    ButtonStyle->"AddOnsLink"],
  ",",
  ButtonBox["Manipulating genealogies",
    ButtonData:>{"Manipulating genealogies", "ExtractGenealogy"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"ExtractGenealogy"],

Cell[TextData[{
  "ExtractGenes",
  ",",
  " \[Gamma], \[AliasIndicator]g\[AliasIndicator]",
  ", ",
  ButtonBox["Extracting contexts",
    ButtonData:>{"Extracting contexts", "ExtractGenes"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"ExtractGenes"],

Cell[TextData[{
  "ExtractInformation",
  ",",
  " ",
  ButtonBox["Describing genealogies",
    ButtonData:>{"Describing genealogies", "ExtractInformation"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"ExtractInformation"],

Cell[TextData[{
  " from ancestral graphs",
  ", ",
  ButtonBox["Describing ancestral graphs",
    ButtonData:>{"Describing ancestral graphs", "ExtractInformation"},
    ButtonStyle->"AddOnsLink"]
}], "IndexSubentry",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"ExtractInformation"],

Cell[TextData[{
  "ExtractLabel",
  ",",
  " from ancestral graphs",
  ", ",
  ButtonBox["Describing ancestral graphs",
    ButtonData:>{"Describing ancestral graphs", "ExtractLabel"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"ExtractLabel"],

Cell[TextData[{
  "ExtractLineagesEndingAtT",
  ",",
  " from ancestral graphs",
  ", ",
  ButtonBox["Describing ancestral graphs",
    ButtonData:>{"Describing ancestral graphs", "ExtractLineagesEndingAtT"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"ExtractLineagesEndingAtT"],

Cell[TextData[{
  "ExtractLineagesStartingAtT",
  ",",
  " from ancestral graphs",
  ", ",
  ButtonBox["Describing ancestral graphs",
    ButtonData:>{"Describing ancestral graphs", "ExtractLineagesStartingAtT"},
    
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"ExtractLineagesStartingAtT"],

Cell[TextData[{
  "ExtractRepeat",
  ",",
  " ",
  ButtonBox["Repeated elements",
    ButtonData:>{"Repeated elements", "ExtractRepeat"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"ExtractRepeat"],

Cell[TextData[{
  "ExtractSubMatrix",
  ",",
  " ",
  ButtonBox["Extracting submatrices",
    ButtonData:>{"Extracting submatrices", "ExtractSubMatrix"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"ExtractSubMatrix"],

Cell[TextData[{
  "FamilyAlleleFrequencyEstimate",
  ",",
  " ",
  ButtonBox["Estimation from families",
    ButtonData:>{"Estimation from families", "FamilyAlleleFrequencyEstimate"},
    
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"FamilyAlleleFrequencyEstimate"],

Cell[TextData[{
  "FamilyEffects",
  ",",
  " ",
  ButtonBox["Estimation from families",
    ButtonData:>{"Estimation from families", "FamilyEffects"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"FamilyEffects"],

Cell[TextData[{
  "FamilyM",
  ",",
  " ",
  ButtonBox["Estimation from families",
    ButtonData:>{"Estimation from families", "FamilyM"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"FamilyM"],

Cell[TextData[{
  "FamilyProbability",
  ",",
  " ",
  ButtonBox["Probabilities",
    ButtonData:>{"Probabilities", "FamilyProbability"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"FamilyProbability"],

Cell[TextData[{
  "Family structure",
  ",",
  " set of all",
  ", ",
  ButtonBox["The set of all structures",
    ButtonData:>{"The set of all structures", "NewS"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Family structure"],

Cell[TextData[{
  "Fecundity",
  ",",
  " ",
  ButtonBox["Describing individuals",
    ButtonData:>{"Describing individuals", "Fecundity"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Fecundity"],

Cell[TextData[{
  "FindHyperlinks",
  ",",
  " ",
  ButtonBox["Hyperlinks",
    ButtonData:>{"Hyperlinks", "FindHyperlinks"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"FindHyperlinks"],

Cell[TextData[{
  "FindIndexTag",
  ",",
  " ",
  ButtonBox["Hyperlinks",
    ButtonData:>{"Hyperlinks", "FindIndexTag"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"FindIndexTag"],

Cell[TextData[{
  "FindMLE",
  ",",
  " ",
  ButtonBox["Finding the MLE",
    ButtonData:>{"Finding the MLE", "FindMLE"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"FindMLE"],

Cell[TextData[{
  "FindNode",
  ",",
  " ",
  ButtonBox["Inferring a genealogy",
    ButtonData:>{"Inferring a genealogy", "FindNode"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"FindNode"],

Cell[TextData[{
  "FindPosition",
  ",",
  " ",
  ButtonBox["Sampling",
    ButtonData:>{"Sampling", "FindPosition"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"FindPosition"],

Cell[TextData[{
  "FindTags",
  ",",
  " ",
  ButtonBox["Automatic Numbering",
    ButtonData:>{"Automatic Numbering", "FindTags"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"FindTags"],

Cell[TextData[{
  "Fitness",
  ",",
  " definition for allele frequencies",
  ", ",
  ButtonBox["Allele frequencies:fitnesses",
    ButtonData:>{"Allele frequencies:fitnesses", "Defining fitnesses"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Fitness"],

Cell[TextData[{
  " in individuals",
  ", ",
  ButtonBox["Simulating individuals: fitnesses",
    ButtonData:>{"Simulating individuals: fitnesses", None},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " in symmetric model",
  ", ",
  ButtonBox["Symmetric model: fitnesses",
    ButtonData:>{"Symmetric model: fitnesses", None},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " problems redefining",
  ", ",
  ButtonBox["Potential problems",
    ButtonData:>{"Potential problems", "Redefining fitness"},
    ButtonStyle->"AddOnsLink"]
}], "IndexSubentry",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Fitness"],

Cell[TextData[{
  "FitnessSet",
  ",",
  " \[DoubleStruckCapitalW], \[AliasIndicator]dsW\[AliasIndicator]",
  ", ",
  ButtonBox["Selection",
    ButtonData:>{"Selection", "FitnessSet"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"FitnessSet"],

Cell[TextData[{
  "FitnessTable",
  ",",
  " for genotype frequencies",
  ", ",
  ButtonBox["Recursions:fitnesses",
    ButtonData:>{"Recursions:fitnesses", "FitnessTable"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"FitnessTable"],

Cell[TextData[{
  " for individuals",
  ", ",
  ButtonBox["Simulating individuals: fitnesses",
    ButtonData:>{"Simulating individuals: fitnesses", "FitnessTable"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " for symmetric model",
  ", ",
  ButtonBox["Symmetric model: fitnesses",
    ButtonData:>{"Symmetric model: fitnesses", "FitnessTable"},
    ButtonStyle->"AddOnsLink"]
}], "IndexSubentry",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"FitnessTable"],

Cell[TextData[{
  "FixedEnds",
  ",",
  " for allele frequencies",
  ", ",
  ButtonBox["Allele frequencies:migration",
    ButtonData:>{"Allele frequencies:migration", "FixedEnds"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"FixedEnds"],

Cell[TextData[{
  " for genotype frequencies",
  ", ",
  ButtonBox["Recursions:migration",
    ButtonData:>{"Recursions:migration", "FixedEnds"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " option for IterateExact",
  ", ",
  ButtonBox["Allele frequencies: iterating one deme",
    ButtonData:>{"Allele frequencies: iterating one deme", "FixedEnds"},
    ButtonStyle->"AddOnsLink"],
  ",",
  ButtonBox["Recursions: iterating one deme",
    ButtonData:>{"Recursions: iterating one deme", "FixedEnds"},
    ButtonStyle->"AddOnsLink"],
  ",",
  ButtonBox["Simulating individuals: iterating one deme",
    ButtonData:>{"Simulating individuals: iterating one deme", "FixedEnds"},
    ButtonStyle->"AddOnsLink"],
  ",",
  ButtonBox["Symmetric model: iterating one deme",
    ButtonData:>{"Symmetric model: iterating one deme", "FixedEnds"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " option for MigrateExact",
  ", ",
  ButtonBox["Simulating individuals:migration",
    ButtonData:>{"Simulating individuals:migration", "FixedEnds"},
    ButtonStyle->"AddOnsLink"],
  ",",
  ButtonBox["Symmetric model: migration",
    ButtonData:>{"Symmetric model: migration", "FixedEnds"},
    ButtonStyle->"AddOnsLink"]
}], "IndexSubentry",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"FixedEnds"],

Cell[TextData[{
  "Flatten",
  ",",
  " ",
  ButtonBox["Flattening lists at specific levels",
    ButtonData:>{"Flattening lists at specific levels", "Flatten"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Flatten"],

Cell[TextData[{
  "FlattenList",
  ",",
  " ",
  ButtonBox["Flattening lists by pattern",
    ButtonData:>{"Flattening lists by pattern", "FlattenList"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"FlattenList"],

Cell[TextData[{
  " PatternFree",
  ", ",
  ButtonBox["Flattening lists by pattern",
    ButtonData:>{"Flattening lists by pattern", "PatternFree"},
    ButtonStyle->"AddOnsLink"]
}], "IndexSubentry",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"FlattenList"],

Cell[TextData[{
  "FourierNormalised",
  ",",
  " ",
  ButtonBox["Fourier transforms",
    ButtonData:>{"Fourier transforms", "FourierNormalised"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"FourierNormalised"],

Cell[TextData[{
  "FourierNormalisedTable",
  ",",
  " ",
  ButtonBox["Fourier transforms",
    ButtonData:>{"Fourier transforms", "FourierNormalisedTable"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"FourierNormalisedTable"],

Cell[TextData[{
  "FrequencyRepresentations",
  ",",
  " ",
  ButtonBox["Overview of numerical models",
    ButtonData:>{"Overview of numerical models", "FrequencyRepresentations"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"FrequencyRepresentations"],

Cell[TextData[{
  "FromBaake",
  ",",
  " ",
  ButtonBox["Alternative measures",
    ButtonData:>{"Alternative measures", "FromBaake"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"FromBaake"],

Cell[TextData[{
  "FromBennett",
  ",",
  " ",
  ButtonBox["Alternative measures",
    ButtonData:>{"Alternative measures", "FromBennett"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"FromBennett"],

Cell[TextData[{
  "FromBennettExpression",
  ",",
  " ",
  ButtonBox["Alternative measures",
    ButtonData:>{"Alternative measures", "FromBennettExpression"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"FromBennettExpression"],

Cell[TextData[{
  "FullContext",
  ",",
  " ",
  ButtonBox["Abbreviating contexts",
    ButtonData:>{"Abbreviating contexts", "FullContext"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"FullContext"],

Cell[TextData[{
  "FullGenotypeFrequencyReduced",
  ",",
  " ",
  ButtonBox["Obsolete functions",
    ButtonData:>{"Obsolete functions", "FullGenotypeFrequencyReduced"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"FullGenotypeFrequencyReduced"],

Cell[TextData[{
  "FullGenotypeFrequencyTable",
  ",",
  " ",
  ButtonBox["Obsolete functions",
    ButtonData:>{"Obsolete functions", "FullGenotypeFrequencyTable"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"FullGenotypeFrequencyTable"],

Cell[TextData[{
  "FullOutput",
  ",",
  " ",
  ButtonBox["Gaussian likelihoods",
    ButtonData:>{"Gaussian likelihoods", "FullOutput"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"FullOutput"],

Cell[TextData[{
  "Function",
  ",",
  " ",
  ButtonBox["Marginal tables",
    ButtonData:>{"Marginal tables", "Function"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Function"],

Cell[TextData[{
  "Gametes",
  ",",
  " for genotype frequencies",
  ", ",
  ButtonBox["Recursions:reproduction",
    ButtonData:>{"Recursions:reproduction", "Gametes"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Gametes"],

Cell[TextData[{
  " for symmetric model",
  ", ",
  ButtonBox["Symmetric model: reproduction",
    ButtonData:>{"Symmetric model: reproduction", "Gametes"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " linkage",
  ", ",
  ButtonBox["Recursions:Linkage",
    ButtonData:>{"Recursions:Linkage", "Gametes"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " new, \!\(\(\[GothicCapitalG]\^*\)\), \
\[AliasIndicator]goG\[AliasIndicator]\[ControlKey]^*, \[GothicCapitalG]new",
  ", ",
  ButtonBox["Life cycle",
    ButtonData:>{"Life cycle", "Gametes new"},
    ButtonStyle->"AddOnsLink"],
  ",",
  ButtonBox["Notation reference",
    ButtonData:>{"Notation reference", None},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " \[GothicCapitalG], \[AliasIndicator]goG\[AliasIndicator]",
  ", ",
  ButtonBox["Life cycle",
    ButtonData:>{"Life cycle", "Gametes"},
    ButtonStyle->"AddOnsLink"],
  ",",
  ButtonBox["Notation reference",
    ButtonData:>{"Notation reference", None},
    ButtonStyle->"AddOnsLink"]
}], "IndexSubentry",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Gametes"],

Cell[TextData[{
  "GameteTable",
  ",",
  " for genotype frequencies",
  ", ",
  ButtonBox["Recursions:reproduction",
    ButtonData:>{"Recursions:reproduction", "GameteTable"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"GameteTable"],

Cell[TextData[{
  " for symmetric model",
  ", ",
  ButtonBox["Symmetric model: reproduction",
    ButtonData:>{"Symmetric model: reproduction", "GameteTable"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " linkage",
  ", ",
  ButtonBox["Recursions:Linkage",
    ButtonData:>{"Recursions:Linkage", "GameteTable"},
    ButtonStyle->"AddOnsLink"]
}], "IndexSubentry",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"GameteTable"],

Cell[TextData[{
  "GaussianLogLikelihood",
  ",",
  " ",
  ButtonBox["Gaussian likelihoods",
    ButtonData:>{"Gaussian likelihoods", "GaussianLogLikelihood"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"GaussianLogLikelihood"],

Cell[TextData[{
  "GaussianMLE",
  ",",
  " ",
  ButtonBox["Gaussian likelihoods",
    ButtonData:>{"Gaussian likelihoods", "GaussianMLE"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"GaussianMLE"],

Cell[TextData[{
  "Genealogies",
  ",",
  " exact probability",
  ", ",
  ButtonBox["Exact probability",
    ButtonData:>{"Exact probability", None},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Genealogies"],

Cell[TextData[{
  " extracting from ancestral graphs",
  ", ",
  ButtonBox["Extracting genealogies",
    ButtonData:>{"Extracting genealogies", "ExtractGenealogy"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " family structure",
  ", ",
  ButtonBox["Family structure",
    ButtonData:>{"Family structure", None},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " generating functions",
  ", ",
  ButtonBox["Deriving recursions for the MGF",
    ButtonData:>{"Deriving recursions for the MGF", None},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " probability of",
  ", ",
  ButtonBox["Deriving the probability",
    ButtonData:>{"Deriving the probability", None},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " sampling",
  ", ",
  ButtonBox["Sampling genealogies",
    ButtonData:>{"Sampling genealogies", None},
    ButtonStyle->"AddOnsLink"]
}], "IndexSubentry",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Genealogies"],

Cell[TextData[{
  "Genealogy",
  ",",
  " rooting",
  ", ",
  ButtonBox["Rooting a genealogy",
    ButtonData:>{"Rooting a genealogy", "SwapStates"},
    ButtonStyle->"AddOnsLink"],
  ",",
  ButtonBox["Structure of genealogies",
    ButtonData:>{"Structure of genealogies", "RootedGenealogy"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Genealogy"],

Cell[TextData[{
  "GenealogyToMatrix",
  ",",
  " ",
  ButtonBox["Describing mutation",
    ButtonData:>{"Describing mutation", "GenealogyToMatrix"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"GenealogyToMatrix"],

Cell[TextData[{
  "GeneralizedTransform",
  ",",
  " ",
  ButtonBox["Cumulants",
    ButtonData:>{"Cumulants", "GeneralizedTransform"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"GeneralizedTransform"],

Cell[TextData[{
  "Generating functions",
  ",",
  " examples",
  ", ",
  ButtonBox["Examples of the MGF",
    ButtonData:>{"Examples of the MGF", None},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Generating functions"],

Cell[TextData[{
  " for cumulants",
  ", ",
  ButtonBox["Cumulants",
    ButtonData:>{"Cumulants", "GeneralizedTransform"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " for genealogies",
  ", ",
  ButtonBox["Deriving recursions for the MGF",
    ButtonData:>{"Deriving recursions for the MGF", None},
    ButtonStyle->"AddOnsLink"]
}], "IndexSubentry",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Generating functions"],

Cell[TextData[{
  "Genes and contexts",
  ",",
  " ",
  ButtonBox["Genes and contexts",
    ButtonData:>{"Genes and contexts", "Genes and contexts"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Genes and contexts"],

Cell[TextData[{
  "Genome",
  ",",
  " set of all positions in, \[DoubleStruckCapitalG], \[AliasIndicator]dsG\
\[AliasIndicator]",
  ", ",
  ButtonBox["Notation reference",
    ButtonData:>{"Notation reference", None},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Genome"],

Cell[TextData[{
  "Genotype",
  ",",
  " in continuum simulations",
  ", ",
  ButtonBox["Describing individuals",
    ButtonData:>{"Describing individuals", "Genotype"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Genotype"],

Cell[TextData[{
  " observable",
  ", ",
  ButtonBox["Diploid genotypes",
    ButtonData:>{"Diploid genotypes", "ObservableGenotype"},
    ButtonStyle->"AddOnsLink"],
  ",",
  ButtonBox["Genotype probabilities",
    ButtonData:>{"Genotype probabilities", "ObservableGenotype"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " option for InitialiseContinuum",
  ", ",
  ButtonBox["Initialisation",
    ButtonData:>{"Initialisation", "Genotype"},
    ButtonStyle->"AddOnsLink"]
}], "IndexSubentry",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Genotype"],

Cell[TextData[{
  "Genotype frequencies",
  ",",
  " recursions",
  ", ",
  ButtonBox["Recursions: representation",
    ButtonData:>{"Recursions: representation", None},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Genotype frequencies"],

Cell[TextData[{
  "Genotype frequency",
  ",",
  " of a given genotype",
  ", ",
  ButtonBox["Gene & genotype frequencies",
    ButtonData:>{"Gene & genotype frequencies", "GenotypeFrequency"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Genotype frequency"],

Cell[TextData[{
  "GenotypeFrequency",
  ",",
  " ",
  ButtonBox["Gene & genotype frequencies",
    ButtonData:>{"Gene & genotype frequencies", "GenotypeFrequency"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"GenotypeFrequency"],

Cell[TextData[{
  "GenotypeFrequencyArguments",
  ",",
  " ",
  ButtonBox["Obsolete functions",
    ButtonData:>{"Obsolete functions", "GenotypeFrequencyArguments"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"GenotypeFrequencyArguments"],

Cell[TextData[{
  "GenotypeFrequencyConvert",
  ",",
  " ",
  ButtonBox["Full diploid genotypes",
    ButtonData:>{"Full diploid genotypes", "GenotypeFrequencyConvert"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"GenotypeFrequencyConvert"],

Cell[TextData[{
  "GenotypeFrequencyTable",
  ",",
  " ",
  ButtonBox["Gene & genotype frequencies",
    ButtonData:>{"Gene & genotype frequencies", "GenotypeFrequencyTable"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"GenotypeFrequencyTable"],

Cell[TextData[{
  "GenotypePosition",
  ",",
  " ",
  ButtonBox["Recursions:manipulation",
    ButtonData:>{"Recursions:manipulation", "GenotypePosition"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"GenotypePosition"],

Cell[TextData[{
  "GenotypeProbability",
  ",",
  " ",
  ButtonBox["Genotype probabilities",
    ButtonData:>{"Genotype probabilities", "GenotypeProbability"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"GenotypeProbability"],

Cell[TextData[{
  " segregation ratio",
  ", ",
  ButtonBox["Genotype probabilities",
    ButtonData:>{"Genotype probabilities", "SegregationRatio"},
    ButtonStyle->"AddOnsLink"]
}], "IndexSubentry",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"GenotypeProbability"],

Cell[TextData[{
  "Genotypes",
  ",",
  " notation for",
  ", ",
  ButtonBox["Notation",
    ButtonData:>{"Notation", "NotationPackage"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Genotypes"],

Cell[TextData[{
  "GlobalContinuumVariables",
  ",",
  " ",
  ButtonBox["Global variables",
    ButtonData:>{"Global variables", "GlobalContinuumVariables"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"GlobalContinuumVariables"],

Cell[TextData[{
  "Gnew",
  ",",
  " \!\(\(\[GothicCapitalG]\^*\)\), \[AliasIndicator]goG\[AliasIndicator]\
\[ControlKey]^*, new gametes",
  ", ",
  ButtonBox["Life cycle",
    ButtonData:>{"Life cycle", "Gametes new"},
    ButtonStyle->"AddOnsLink"],
  ",",
  ButtonBox["Notation reference",
    ButtonData:>{"Notation reference", None},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Gnew"],

Cell[TextData[{
  "Goodman et al 1999",
  ",",
  " ",
  ButtonBox["References",
    ButtonData:>{"References", "Goodman et al 1999"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Goodman et al 1999"],

Cell[TextData[{
  "Graphs",
  ",",
  " ancestral",
  ", ",
  ButtonBox["Ancestral graph introduction",
    ButtonData:>{"Ancestral graph introduction", None},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Graphs"],

Cell[TextData[{
  "Griffiths-Tavare",
  ",",
  " ",
  ButtonBox["Exact algorithm",
    ButtonData:>{"Exact algorithm", "GriffithsTavare"},
    ButtonStyle->"AddOnsLink"],
  ",",
  ButtonBox["Griffiths-Tavare algorithm",
    ButtonData:>{"Griffiths-Tavare algorithm", None},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Griffiths-Tavare"],

Cell[TextData[{
  " stochastic algorithm",
  ", ",
  ButtonBox["Stochastic algorithm",
    ButtonData:>{"Stochastic algorithm", "MonteCarloGriffithsTavare"},
    ButtonStyle->"AddOnsLink"],
  ",",
  ButtonBox["Stochastic algorithm",
    ButtonData:>{"Stochastic algorithm", "Stochastic GT algorithm"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " stochastic, comparison with MonteCarloProbability",
  ", ",
  ButtonBox["Stochastic algorithm",
    ButtonData:>{"Stochastic algorithm", 
      "Comparison with MonteCarloProbability"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " stochastic example",
  ", ",
  ButtonBox["Stochastic algorithm",
    ButtonData:>{"Stochastic algorithm", "Small example"},
    ButtonStyle->"AddOnsLink"]
}], "IndexSubentry",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Griffiths-Tavare"],

Cell[TextData[{
  "Guiasu & Shenitzer 1985",
  ",",
  " ",
  ButtonBox["References",
    ButtonData:>{"References", "Guiasu & Shenitzer 1985"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Guiasu & Shenitzer 1985"],

Cell[TextData[{
  "HaploidConstraints",
  ",",
  " ",
  ButtonBox["Obsolete functions",
    ButtonData:>{"Obsolete functions", "HaploidConstraints"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"HaploidConstraints"],

Cell[TextData[{
  "HaploidFrequencies",
  ",",
  " ",
  ButtonBox["Overview of numerical models",
    ButtonData:>{"Overview of numerical models", "HaploidFrequencies"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"HaploidFrequencies"],

Cell[TextData[{
  "HaploidGenotypeFrequency",
  ",",
  " ",
  ButtonBox["Genotype frequencies from moments",
    ButtonData:>{"Genotype frequencies from moments", 
      "HaploidGenotypeFrequency"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"HaploidGenotypeFrequency"],

Cell[TextData[{
  "HaploidIndividuals",
  ",",
  " ",
  ButtonBox["Overview of numerical models",
    ButtonData:>{"Overview of numerical models", "HaploidIndividuals"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"HaploidIndividuals"],

Cell[TextData[{
  "HaploidRepresentations",
  ",",
  " ",
  ButtonBox["Overview of numerical models",
    ButtonData:>{"Overview of numerical models", "HaploidRepresentations"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"HaploidRepresentations"],

Cell[TextData[{
  "Haploids",
  ",",
  " selection on",
  ", ",
  ButtonBox["Haploid selection",
    ButtonData:>{"Haploid selection", None},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Haploids"],

Cell[TextData[{
  "HaploidSource",
  ",",
  " ",
  ButtonBox["Genotype frequencies",
    ButtonData:>{"Genotype frequencies", "HaploidSource"},
    ButtonStyle->"AddOnsLink"],
  ",",
  ButtonBox["Representing the population",
    ButtonData:>{"Representing the population", "HaploidSource"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"HaploidSource"],

Cell[TextData[{
  "HaploidSubsets",
  ",",
  " ",
  ButtonBox["Subsets of loci",
    ButtonData:>{"Subsets of loci", "HaploidSubsets"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"HaploidSubsets"],

Cell[TextData[{
  "HaploidTypes",
  ",",
  " ",
  ButtonBox["Listing genotypes",
    ButtonData:>{"Listing genotypes", "HaploidTypes"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"HaploidTypes"],

Cell[TextData[{
  "Help browser",
  ",",
  " setting up new files",
  ", ",
  ButtonBox["Setting up new help files",
    ButtonData:>{"Setting up new help files", "Setting up new help files"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Help browser"],

Cell[TextData[{
  "Help Browser",
  ",",
  " ",
  ButtonBox["How the Help Browser works",
    ButtonData:>{"How the Help Browser works", "MasterIndexHeading"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Help Browser"],

Cell[TextData[{
  " setting up hyperlinks",
  ", ",
  ButtonBox["How the Help Browser works",
    ButtonData:>{"How the Help Browser works", "Setting up links"},
    ButtonStyle->"AddOnsLink"]
}], "IndexSubentry",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Help Browser"],

Cell[TextData[{
  "Hermaphrodites",
  ",",
  " \[GothicCapitalH], \[AliasIndicator]goH\[AliasIndicator]",
  ", ",
  ButtonBox["Life cycle",
    ButtonData:>{"Life cycle", "Hermaphrodites"},
    ButtonStyle->"AddOnsLink"],
  ",",
  ButtonBox["Notation reference",
    ButtonData:>{"Notation reference", None},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Hermaphrodites"],

Cell[TextData[{
  "HeterozygoteB",
  ",",
  " ",
  ButtonBox["Symmetric model: reproduction",
    ButtonData:>{"Symmetric model: reproduction", "HeterozygoteB"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"HeterozygoteB"],

Cell[TextData[{
  "Hill 1974a",
  ",",
  " ",
  ButtonBox["References",
    ButtonData:>{"References", "Hill 1974a"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Hill 1974a"],

Cell[TextData[{
  "Hill 1974b",
  ",",
  " ",
  ButtonBox["References",
    ButtonData:>{"References", "Hill 1974b"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Hill 1974b"],

Cell[TextData[{
  "Hill 1974c",
  ",",
  " ",
  ButtonBox["References",
    ButtonData:>{"References", "Hill 1974c"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Hill 1974c"],

Cell[TextData[{
  "Hudson 1990",
  ",",
  " ",
  ButtonBox["Ancestral graph references",
    ButtonData:>{"Ancestral graph references", "Hudson 1990"},
    ButtonStyle->"AddOnsLink"],
  ",",
  ButtonBox["Ancestral graphs introduction",
    ButtonData:>{"Ancestral graphs introduction", None},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Hudson 1990"],

Cell[TextData[{
  "Hypergeometric model",
  ",",
  " ",
  ButtonBox["Symmetric model: genotype frequencies",
    ButtonData:>{"Symmetric model: genotype frequencies", None},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Hypergeometric model"],

Cell[TextData[{
  "Hyperlinks",
  ",",
  " bugs in pasting",
  ", ",
  ButtonBox["Bugs",
    ButtonData:>{"Bugs", "Pasting hyperlinks"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Hyperlinks"],

Cell[TextData[{
  " saving",
  ", ",
  ButtonBox["Automatic Numbering",
    ButtonData:>{"Automatic Numbering", "Saving the links"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " setting up",
  ", ",
  ButtonBox["How the Help Browser works",
    ButtonData:>{"How the Help Browser works", "Setting up links"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " to cell tags",
  ", ",
  ButtonBox["Automatic Numbering",
    ButtonData:>{"Automatic Numbering", "Setting up links to a list of tags"},
    
    ButtonStyle->"AddOnsLink"]
}], "IndexSubentry",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Hyperlinks"],

Cell[TextData[{
  "IncidenceMatrix",
  ",",
  " ",
  ButtonBox["Ordered genealogies",
    ButtonData:>{"Ordered genealogies", "IncidenceMatrix"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"IncidenceMatrix"],

Cell[TextData[{
  "Index",
  ",",
  " setting up",
  ", ",
  ButtonBox["How the Help Browser works",
    ButtonData:>{"How the Help Browser works", "Setting up Master Index"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Index"],

Cell[TextData[{
  "Individual",
  ",",
  " ",
  ButtonBox["Life cycle",
    ButtonData:>{"Life cycle", "Individual"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Individual"],

Cell[TextData[{
  "IndividualContinuumVariables",
  ",",
  " ",
  ButtonBox["Global variables",
    ButtonData:>{"Global variables", "IndividualContinuumVariables"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"IndividualContinuumVariables"],

Cell[TextData[{
  "IndividualRepresentations",
  ",",
  " ",
  ButtonBox["Overview of numerical models",
    ButtonData:>{"Overview of numerical models", "IndividualRepresentations"},
    
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"IndividualRepresentations"],

Cell[TextData[{
  "Individuals",
  ",",
  " ",
  ButtonBox["Boxing the individuals",
    ButtonData:>{"Boxing the individuals", "Individuals"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Individuals"],

Cell[TextData[{
  "InferParentalGenotypes",
  ",",
  " ",
  ButtonBox["Estimation from families",
    ButtonData:>{"Estimation from families", "InferParentalGenotypes"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"InferParentalGenotypes"],

Cell[TextData[{
  "Infinite sites mutation",
  ",",
  " ",
  ButtonBox["Describing mutation",
    ButtonData:>{"Describing mutation", "None"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Infinite sites mutation"],

Cell[TextData[{
  "InformationFunction",
  ",",
  " option for CoalesceLineages",
  ", ",
  ButtonBox["Coalescence and recombination",
    ButtonData:>{"Coalescence and recombination", "InformationFunctionC"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"InformationFunction"],

Cell[TextData[{
  " option for ExtractGenealogy",
  ", ",
  ButtonBox["Extracting genealogies",
    ButtonData:>{"Extracting genealogies", "InformationFunction"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " option for RecombineLineage",
  ", ",
  ButtonBox["Coalescence and recombination",
    ButtonData:>{"Coalescence and recombination", "InformationFunctionR"},
    ButtonStyle->"AddOnsLink"]
}], "IndexSubentry",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"InformationFunction"],

Cell[TextData[{
  "InitialiseContinuum",
  ",",
  " ",
  ButtonBox["Initialisation",
    ButtonData:>{"Initialisation", "InitialiseContinuum"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"InitialiseContinuum"],

Cell[TextData[{
  "InitialiseCovariance",
  ",",
  " ",
  ButtonBox["Sampling",
    ButtonData:>{"Sampling", "InitialiseCovariance"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"InitialiseCovariance"],

Cell[TextData[{
  "InitialiseDemes",
  ",",
  " ",
  ButtonBox["Describing the population",
    ButtonData:>{"Describing the population", "InitialiseDemes"},
    ButtonStyle->"AddOnsLink"],
  ",",
  ButtonBox["Setting up a cline",
    ButtonData:>{"Setting up a cline", "InitialiseDemes"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"InitialiseDemes"],

Cell[TextData[{
  "InitialStep",
  ",",
  " ",
  ButtonBox["Initial step size",
    ButtonData:>{"Initial step size", "InitialStep"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"InitialStep"],

Cell[TextData[{
  "InitialStepReduced",
  ",",
  " ",
  ButtonBox["Obsolete functions",
    ButtonData:>{"Obsolete functions", "InitialStepReduced"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"InitialStepReduced"],

Cell[TextData[{
  "InternalNodes",
  ",",
  " ",
  ButtonBox["Describing genealogies",
    ButtonData:>{"Describing genealogies", "InternalNodes"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"InternalNodes"],

Cell[TextData[{
  "IntervalCombine",
  ",",
  " ",
  ButtonBox["Obsolete functions",
    ButtonData:>{"Obsolete functions", "IntervalCombine"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"IntervalCombine"],

Cell[TextData[{
  "IntervalPosition",
  ",",
  " ",
  ButtonBox["Obsolete functions",
    ButtonData:>{"Obsolete functions", "IntervalPosition"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"IntervalPosition"],

Cell[TextData[{
  "InverseFourierNormalised",
  ",",
  " ",
  ButtonBox["Fourier transforms",
    ButtonData:>{"Fourier transforms", "InverseFourierNormalised"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"InverseFourierNormalised"],

Cell[TextData[{
  "InverseFourierNormalisedTable",
  ",",
  " ",
  ButtonBox["Fourier transforms",
    ButtonData:>{"Fourier transforms", "InverseFourierNormalisedTable"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"InverseFourierNormalisedTable"],

Cell[TextData[{
  "Island model",
  ",",
  " for allele frequencies",
  ", ",
  ButtonBox["Allele frequencies: iterating one deme",
    ButtonData:>{"Allele frequencies: iterating one deme", "Immigration"},
    ButtonStyle->"AddOnsLink"],
  ",",
  ButtonBox["Allele frequencies:migration",
    ButtonData:>{"Allele frequencies:migration", "Immigration"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Island model"],

Cell[TextData[{
  " for genotype frequencies",
  ", ",
  ButtonBox["Recursions: iterating one deme",
    ButtonData:>{"Recursions: iterating one deme", "Immigration"},
    ButtonStyle->"AddOnsLink"],
  ",",
  ButtonBox["Recursions:migration",
    ButtonData:>{"Recursions:migration", "Immigration"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " in symmetric model",
  ", ",
  ButtonBox["Symmetric model: migration",
    ButtonData:>{"Symmetric model: migration", "Immigration"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " with individuals",
  ", ",
  ButtonBox["Simulating individuals:migration",
    ButtonData:>{"Simulating individuals:migration", "Immigration"},
    ButtonStyle->"AddOnsLink"]
}], "IndexSubentry",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Island model"],

Cell[TextData[{
  "IterateContinuum",
  ",",
  " ",
  ButtonBox["Iterating  the continuum model",
    ButtonData:>{"Iterating  the continuum model", "IterateContinuum"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"IterateContinuum"],

Cell[TextData[{
  "IterateExact",
  ",",
  " example",
  ", ",
  ButtonBox["Example: epistasis",
    ButtonData:>{"Example: epistasis", None},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"IterateExact"],

Cell[TextData[{
  " for allele frequencies",
  ", ",
  ButtonBox["Allele frequencies: iterating one deme",
    ButtonData:>{"Allele frequencies: iterating one deme", "IterateExact"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " for allele frequency clines",
  ", ",
  ButtonBox["Allele frequencies: iterating a cline",
    ButtonData:>{"Allele frequencies: iterating a cline", "IterateExact"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " for clines in symmetric model",
  ", ",
  ButtonBox["Symmetric model: iterating a cline",
    ButtonData:>{"Symmetric model: iterating a cline", "IterateExact"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " for clines with individuals",
  ", ",
  ButtonBox["Simulating individuals: iterating a cline",
    ButtonData:>{"Simulating individuals: iterating a cline", "IterateExact"},
    
    ButtonStyle->"AddOnsLink"],
  "\n",
  " for genotype frequencies",
  ", ",
  ButtonBox["Recursions: iterating one deme",
    ButtonData:>{"Recursions: iterating one deme", "IterateExact"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " for genotype frequency clines",
  ", ",
  ButtonBox["Recursions: iterating a cline",
    ButtonData:>{"Recursions: iterating a cline", "IterateExact"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " for individuals",
  ", ",
  ButtonBox["Simulating individuals: iterating one deme",
    ButtonData:>{"Simulating individuals: iterating one deme", 
      "IterateExact"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " for symmetric model",
  ", ",
  ButtonBox["Symmetric model: iterating one deme",
    ButtonData:>{"Symmetric model: iterating one deme", "IterateExact"},
    ButtonStyle->"AddOnsLink"]
}], "IndexSubentry",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"IterateExact"],

Cell[TextData[{
  "Join",
  ",",
  " ",
  ButtonBox["Join",
    ButtonData:>{"Join", "Join"},
    ButtonStyle->"AddOnsLink"],
  ",",
  ButtonBox["Operations on sets",
    ButtonData:>{"Operations on sets", "Join"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Join"],

Cell[TextData[{
  "Junctions",
  ",",
  " in ancestral graphs",
  ", ",
  ButtonBox["Describing ancestral graphs",
    ButtonData:>{"Describing ancestral graphs", "Junctions"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Junctions"],

Cell[TextData[{
  "JunctionStyle",
  ",",
  " option for PlotSegments",
  ", ",
  ButtonBox["Plotting ancestral graphs",
    ButtonData:>{"Plotting ancestral graphs", "JunctionStyle"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"JunctionStyle"],

Cell[TextData[{
  "Juveniles",
  ",",
  " \[GothicCapitalJ], \[AliasIndicator]goJ\[AliasIndicator]",
  ", ",
  ButtonBox["Life cycle",
    ButtonData:>{"Life cycle", "Juveniles"},
    ButtonStyle->"AddOnsLink"],
  ",",
  ButtonBox["Notation reference",
    ButtonData:>{"Notation reference", None},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Juveniles"],

Cell[TextData[{
  "Kirkpatrick and Barton 1997",
  ",",
  " ",
  ButtonBox["Multilocus references",
    ButtonData:>{"Multilocus references", "Kirkpatrick and Barton 1997"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Kirkpatrick and Barton 1997"],

Cell[TextData[{
  "Kirkpatrick and Servedio 1998",
  ",",
  " ",
  ButtonBox["Multilocus references",
    ButtonData:>{"Multilocus references", "Kirkpatrick and Servedio 1998"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Kirkpatrick and Servedio 1998"],

Cell[TextData[{
  "Kirkpatrick et al.",
  ",",
  " ",
  ButtonBox["Multilocus MS",
    ButtonData:>{"Multilocus MS", None},
    ButtonStyle->"AddOnsLink"],
  ",",
  ButtonBox["Multilocus references",
    ButtonData:>{"Multilocus references", "Kirkpatrick et al."},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Kirkpatrick et al."],

Cell[TextData[{
  " arbitrary sets of loci",
  ", ",
  ButtonBox["Multilocus MS relation",
    ButtonData:>{"Multilocus MS relation", "Arbitrary sets of loci"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " Expectation",
  ", ",
  ButtonBox["Multilocus MS relation",
    ButtonData:>{"Multilocus MS relation", "Expectation"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " migration",
  ", ",
  ButtonBox["Multilocus MS",
    ButtonData:>{"Multilocus MS", "Migration"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " mutation",
  ", ",
  ButtonBox["Multilocus MS",
    ButtonData:>{"Multilocus MS", "Mutation"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " permutations in defining coefficients",
  ", ",
  ButtonBox["Multilocus MS",
    ButtonData:>{"Multilocus MS", "Permutations"},
    ButtonStyle->"AddOnsLink"],
  ",",
  ButtonBox["Multilocus MS relation",
    ButtonData:>{"Multilocus MS relation", "Permutations"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " phenotypes",
  ", ",
  ButtonBox["Multilocus MS",
    ButtonData:>{"Multilocus MS", "Phenotypes"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " position",
  ", ",
  ButtonBox["Multilocus MS",
    ButtonData:>{"Multilocus MS", "Contexts and positions"},
    ButtonStyle->"AddOnsLink"],
  ",",
  ButtonBox["Multilocus MS relation",
    ButtonData:>{"Multilocus MS relation", "position"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " QLE",
  ", ",
  ButtonBox["Multilocus MS",
    ButtonData:>{"Multilocus MS", "The QLE approximation"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " quasi-linkage equilibrium",
  ", ",
  ButtonBox["Multilocus MS",
    ButtonData:>{"Multilocus MS", "The QLE approximation"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " random drift",
  ", ",
  ButtonBox["Multilocus MS relation",
    ButtonData:>{"Multilocus MS relation", "Random drift"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " reference values",
  ", ",
  ButtonBox["Multilocus MS",
    ButtonData:>{"Multilocus MS", "Describing genotypes and populations"},
    ButtonStyle->"AddOnsLink"],
  ",",
  ButtonBox["Multilocus MS relation",
    ButtonData:>{"Multilocus MS relation", "Reference values"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " relation with",
  ", ",
  ButtonBox["Migration example",
    ButtonData:>{"Migration example", "Multilocus MS"},
    ButtonStyle->"AddOnsLink"],
  ",",
  ButtonBox["Multilocus MS relation",
    ButtonData:>{"Multilocus MS relation", None},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " scripts and faces",
  ", ",
  ButtonBox["Multilocus MS relation",
    ButtonData:>{"Multilocus MS relation", "Scripts and faces"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " selection",
  ", ",
  ButtonBox["Multilocus MS",
    ButtonData:>{"Multilocus MS", "Phenotypes"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " sets in subscripts",
  ", ",
  ButtonBox["Multilocus MS relation",
    ButtonData:>{"Multilocus MS relation", "Sets in subscripts"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " sets of loci",
  ", ",
  ButtonBox["Multilocus MS relation",
    ButtonData:>{"Multilocus MS relation", "Sets of loci"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " stabilising selection",
  ", ",
  ButtonBox["Multilocus MS",
    ButtonData:>{"Multilocus MS", 
      "Natural selection on an additive polygenic trait"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " stages and contexts",
  ", ",
  ButtonBox["Multilocus MS relation",
    ButtonData:>{"Multilocus MS relation", "Stages and contexts"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " transmission rules",
  ", ",
  ButtonBox["Multilocus MS",
    ButtonData:>{"Multilocus MS", "Transmission"},
    ButtonStyle->"AddOnsLink"],
  ",",
  ButtonBox["Multilocus MS relation",
    ButtonData:>{"Multilocus MS relation", "Transmission rules"},
    ButtonStyle->"AddOnsLink"]
}], "IndexSubentry",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Kirkpatrick et al."],

Cell[TextData[{
  "Kirkpatrick et al. 1983",
  ",",
  " ",
  ButtonBox["References",
    ButtonData:>{"References", "Kirkpatrick et al 1983"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Kirkpatrick et al. 1983"],

Cell[TextData[{
  "Kruuk 1997",
  ",",
  " ",
  ButtonBox["References",
    ButtonData:>{"References", "Kruuk 1997"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Kruuk 1997"],

Cell[TextData[{
  "LeafEvents",
  ",",
  " in ancestral graphs",
  ", ",
  ButtonBox["Describing ancestral graphs",
    ButtonData:>{"Describing ancestral graphs", "LeafEvents"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"LeafEvents"],

Cell[TextData[{
  "LeafLabels",
  ",",
  " ",
  ButtonBox["Plotting genealogies",
    ButtonData:>{"Plotting genealogies", "LeafLabels"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"LeafLabels"],

Cell[TextData[{
  "LeafOffset",
  ",",
  " ",
  ButtonBox["Plotting genealogies",
    ButtonData:>{"Plotting genealogies", "LeafOffset"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"LeafOffset"],

Cell[TextData[{
  "Leaves",
  ",",
  " ",
  ButtonBox["Describing genealogies",
    ButtonData:>{"Describing genealogies", "Leaves"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Leaves"],

Cell[TextData[{
  " in ancestral graphs",
  ", ",
  ButtonBox["Describing ancestral graphs",
    ButtonData:>{"Describing ancestral graphs", "Leaves"},
    ButtonStyle->"AddOnsLink"]
}], "IndexSubentry",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Leaves"],

Cell[TextData[{
  "Life cycle",
  ",",
  " ",
  ButtonBox["Life cycle",
    ButtonData:>{"Life cycle", None},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Life cycle"],

Cell[TextData[{
  " adults",
  ", ",
  ButtonBox["Life cycle",
    ButtonData:>{"Life cycle", "Adults"},
    ButtonStyle->"AddOnsLink"],
  ",",
  ButtonBox["Notation reference",
    ButtonData:>{"Notation reference", None},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " complete",
  ", ",
  ButtonBox["Complete life cycle",
    ButtonData:>{"Complete life cycle", "Complete rules"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " gametes",
  ", ",
  ButtonBox["Life cycle",
    ButtonData:>{"Life cycle", "Gametes"},
    ButtonStyle->"AddOnsLink"],
  ",",
  ButtonBox["Notation reference",
    ButtonData:>{"Notation reference", None},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " hermaphrodites",
  ", ",
  ButtonBox["Life cycle",
    ButtonData:>{"Life cycle", "Hermaphrodites"},
    ButtonStyle->"AddOnsLink"],
  ",",
  ButtonBox["Notation reference",
    ButtonData:>{"Notation reference", None},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " in numerical models",
  ", ",
  ButtonBox["Allele frequencies: iterating one deme",
    ButtonData:>{"Allele frequencies: iterating one deme", "Life cycle"},
    ButtonStyle->"AddOnsLink"],
  ",",
  ButtonBox["Recursions: iterating one deme",
    ButtonData:>{"Recursions: iterating one deme", "Life cycle"},
    ButtonStyle->"AddOnsLink"],
  ",",
  ButtonBox["Symmetric model: iterating one deme",
    ButtonData:>{"Symmetric model: iterating one deme", "Life cycle"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " juveniles",
  ", ",
  ButtonBox["Life cycle",
    ButtonData:>{"Life cycle", "Juveniles"},
    ButtonStyle->"AddOnsLink"],
  ",",
  ButtonBox["Notation reference",
    ButtonData:>{"Notation reference", None},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " new gametes",
  ", ",
  ButtonBox["Life cycle",
    ButtonData:>{"Life cycle", "Gametes new"},
    ButtonStyle->"AddOnsLink"],
  ",",
  ButtonBox["Notation reference",
    ButtonData:>{"Notation reference", None},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " stages in",
  ", ",
  ButtonBox["Genes and contexts",
    ButtonData:>{"Genes and contexts", "Stages"},
    ButtonStyle->"AddOnsLink"],
  ",",
  ButtonBox["Life cycle",
    ButtonData:>{"Life cycle", "Stages"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " with cytoplasmic inheritance",
  ", ",
  ButtonBox["Cytoplasmic inheritance",
    ButtonData:>{"Cytoplasmic inheritance", None},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " with individuals",
  ", ",
  ButtonBox["Simulating individuals: iterating one deme",
    ButtonData:>{"Simulating individuals: iterating one deme", "Life cycle"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " with sex linkage",
  ", ",
  ButtonBox["Sex linkage",
    ButtonData:>{"Sex linkage", None},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " zygotes",
  ", ",
  ButtonBox["Life cycle",
    ButtonData:>{"Life cycle", "Zygotes"},
    ButtonStyle->"AddOnsLink"],
  ",",
  ButtonBox["Notation reference",
    ButtonData:>{"Notation reference", None},
    ButtonStyle->"AddOnsLink"]
}], "IndexSubentry",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Life cycle"],

Cell[TextData[{
  "LineagesPresent",
  ",",
  " in ancestral graphs",
  ", ",
  ButtonBox["Describing ancestral graphs",
    ButtonData:>{"Describing ancestral graphs", "LineagesPresent"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"LineagesPresent"],

Cell[TextData[{
  "Li & Nei 1974",
  ",",
  " ",
  ButtonBox["References",
    ButtonData:>{"References", "Li & Nei 1974"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Li & Nei 1974"],

Cell[TextData[{
  "Linkage",
  ",",
  " ",
  ButtonBox["Generating families",
    ButtonData:>{"Generating families", "Linkage"},
    ButtonStyle->"AddOnsLink"],
  ",",
  ButtonBox["Genotype probabilities",
    ButtonData:>{"Genotype probabilities", "Linkage"},
    ButtonStyle->"AddOnsLink"],
  ",",
  ButtonBox["Linkage",
    ButtonData:>{"Linkage", "Linkage"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Linkage"],

Cell[TextData[{
  " in numerical models",
  ", ",
  ButtonBox["Recursions:Linkage",
    ButtonData:>{"Recursions:Linkage", "Linkage"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " with individuals",
  ", ",
  ButtonBox["Simulating individuals: reproduction",
    ButtonData:>{"Simulating individuals: reproduction", "Linkage"},
    ButtonStyle->"AddOnsLink"]
}], "IndexSubentry",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Linkage"],

Cell[TextData[{
  "Linkage disequilibrium",
  ",",
  " ",
  ButtonBox["Gene & genotype frequencies",
    ButtonData:>{"Gene & genotype frequencies", "Linkage disequilibrium"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Linkage disequilibrium"],

Cell[TextData[{
  "LinkedRecombination",
  ",",
  " ",
  ButtonBox["Recombination",
    ButtonData:>{"Recombination", "LinkedRecombination"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"LinkedRecombination"],

Cell[TextData[{
  "ListToGenealogy",
  ",",
  " ",
  ButtonBox["Constructing genealogies",
    ButtonData:>{"Constructing genealogies", "ListToGenealogy"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"ListToGenealogy"],

Cell[TextData[{
  "ListToMatrix",
  ",",
  " ",
  ButtonBox["Converting between representations",
    ButtonData:>{"Converting between representations", "ListToMatrix"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"ListToMatrix"],

Cell[TextData[{
  "Location",
  ",",
  " ",
  ButtonBox["Describing individuals",
    ButtonData:>{"Describing individuals", "Location"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Location"],

Cell[TextData[{
  "Locations",
  ",",
  " ",
  ButtonBox["Locations",
    ButtonData:>{"Locations", "Locations"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Locations"],

Cell[TextData[{
  "LocusNames",
  ",",
  " ",
  ButtonBox["Defining a dataset",
    ButtonData:>{"Defining a dataset", "LocusNames"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"LocusNames"],

Cell[TextData[{
  "LogLikelihoodDisequilibrium",
  ",",
  " ",
  ButtonBox["Likelihood",
    ButtonData:>{"Likelihood", "LogLikelihoodDisequilibrium"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"LogLikelihoodDisequilibrium"],

Cell[TextData[{
  "LogLikelihoodDisequilibriumReduced",
  ",",
  " ",
  ButtonBox["Obsolete functions",
    ButtonData:>{"Obsolete functions", "LogLikelihoodDisequilibriumReduced"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"LogLikelihoodDisequilibriumReduced"],

Cell[TextData[{
  "LogLikelihoodTest",
  ",",
  " ",
  ButtonBox["Likelihood tests",
    ButtonData:>{"Likelihood tests", "LogLikelihoodTest"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"LogLikelihoodTest"],

Cell[TextData[{
  "Log-linear models",
  ",",
  " ",
  ButtonBox["Alternative methods",
    ButtonData:>{"Alternative methods", "Log-linear models"},
    ButtonStyle->"AddOnsLink"],
  ",",
  ButtonBox["Alternative methods",
    ButtonData:>{"Alternative methods", None},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Log-linear models"],

Cell[TextData[{
  "Long et al 1995",
  ",",
  " ",
  ButtonBox["References",
    ButtonData:>{"References", "Long et al 1995"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Long et al 1995"],

Cell[TextData[{
  "LowerOffDiagonal",
  ",",
  " ",
  ButtonBox["Diagonal matrices",
    ButtonData:>{"Diagonal matrices", "LowerOffDiagonal"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"LowerOffDiagonal"],

Cell[TextData[{
  "MacCallum 1994",
  ",",
  " ",
  ButtonBox["References",
    ButtonData:>{"References", "MacCallum 1994"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"MacCallum 1994"],

Cell[TextData[{
  "MacCallum et al. 1998",
  ",",
  " ",
  ButtonBox["References",
    ButtonData:>{"References", "MacCallum et al 1998"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"MacCallum et al. 1998"],

Cell[TextData[{
  "MakeCline",
  ",",
  " for allele frequencies",
  ", ",
  ButtonBox["Allele frequencies: setting up a cline",
    ButtonData:>{"Allele frequencies: setting up a cline", "MakeCline"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"MakeCline"],

Cell[TextData[{
  "  for genotype frequencies",
  ", ",
  ButtonBox["Recursions: setting up a cline",
    ButtonData:>{"Recursions: setting up a cline", "MakeCline"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " for individuals",
  ", ",
  ButtonBox["Simulating individuals:setting up a cline",
    ButtonData:>{"Simulating individuals:setting up a cline", "MakeCline"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " for symmetric model",
  ", ",
  ButtonBox["Symmetric model: setting up a cline",
    ButtonData:>{"Symmetric model: setting up a cline", "MakeCline"},
    ButtonStyle->"AddOnsLink"]
}], "IndexSubentry",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"MakeCline"],

Cell[TextData[{
  "MakeDiploid",
  ",",
  " for genotype frequencies",
  ", ",
  ButtonBox["Recursions: converting",
    ButtonData:>{"Recursions: converting", "MakeDiploid"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"MakeDiploid"],

Cell[TextData[{
  " for individuals",
  ", ",
  ButtonBox["Simulating individuals:converting",
    ButtonData:>{"Simulating individuals:converting", "MakeDiploid"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " for symmetric model",
  ", ",
  ButtonBox["Symmetric model: converting",
    ButtonData:>{"Symmetric model: converting", "MakeDiploid"},
    ButtonStyle->"AddOnsLink"]
}], "IndexSubentry",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"MakeDiploid"],

Cell[TextData[{
  "MakeDistanceList",
  ",",
  " ",
  ButtonBox["Boxing the individuals",
    ButtonData:>{"Boxing the individuals", "MakeDistanceList"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"MakeDistanceList"],

Cell[TextData[{
  "MakeDistances",
  ",",
  " ",
  ButtonBox["Boxing the individuals",
    ButtonData:>{"Boxing the individuals", "MakeDistances"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"MakeDistances"],

Cell[TextData[{
  "MakeFitnessSet",
  ",",
  " ",
  ButtonBox["Fitness",
    ButtonData:>{"Fitness", "MakeFitnessSet"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"MakeFitnessSet"],

Cell[TextData[{
  " with multiple alleles",
  ", ",
  ButtonBox["Fitness",
    ButtonData:>{"Fitness", "Multiple alleles"},
    ButtonStyle->"AddOnsLink"]
}], "IndexSubentry",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"MakeFitnessSet"],

Cell[TextData[{
  "MakeGenealogy",
  ",",
  " ",
  ButtonBox["Making a genealogy",
    ButtonData:>{"Making a genealogy", "MakeGenealogy"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"MakeGenealogy"],

Cell[TextData[{
  "MakeGenealogyPlot",
  ",",
  " ",
  ButtonBox["Plotting genealogies",
    ButtonData:>{"Plotting genealogies", "MakeGenealogyPlot"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"MakeGenealogyPlot"],

Cell[TextData[{
  "MakeHaploid",
  ",",
  " for genotype frequencies",
  ", ",
  ButtonBox["Recursions: converting",
    ButtonData:>{"Recursions: converting", "MakeHaploid"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"MakeHaploid"],

Cell[TextData[{
  " for individuals",
  ", ",
  ButtonBox["Simulating individuals:converting",
    ButtonData:>{"Simulating individuals:converting", "MakeHaploid"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " for symmetric model",
  ", ",
  ButtonBox["Symmetric model: converting",
    ButtonData:>{"Symmetric model: converting", "MakeHaploid"},
    ButtonStyle->"AddOnsLink"]
}], "IndexSubentry",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"MakeHaploid"],

Cell[TextData[{
  "MakeIndividuals",
  ",",
  " for allele frequencies",
  ", ",
  ButtonBox["Allele frequencies: converting",
    ButtonData:>{"Allele frequencies: converting", "MakeIndividuals"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"MakeIndividuals"],

Cell[TextData[{
  " for genotype frequencies",
  ", ",
  ButtonBox["Recursions: converting",
    ButtonData:>{"Recursions: converting", "MakeIndividuals"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " for individuals",
  ", ",
  ButtonBox["Simulating individuals:converting",
    ButtonData:>{"Simulating individuals:converting", "MakeIndividuals"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " for symmetric model",
  ", ",
  ButtonBox["Symmetric model: converting",
    ButtonData:>{"Symmetric model: converting", "MakeIndividuals"},
    ButtonStyle->"AddOnsLink"]
}], "IndexSubentry",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"MakeIndividuals"],

Cell[TextData[{
  "MakeOneWayTable",
  ",",
  " ",
  ButtonBox["Single-locus tables",
    ButtonData:>{"Single-locus tables", "MakeOneWayTable"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"MakeOneWayTable"],

Cell[TextData[{
  "MakePairwiseTable",
  ",",
  " ",
  ButtonBox["Pairwise tables",
    ButtonData:>{"Pairwise tables", "MakePairwiseTable"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"MakePairwiseTable"],

Cell[TextData[{
  "MakePopulation",
  ",",
  " for allele frequencies",
  ", ",
  ButtonBox["Allele frequencies: representation",
    ButtonData:>{"Allele frequencies: representation", "MakePopulation"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"MakePopulation"],

Cell[TextData[{
  " for genotype frequencies",
  ", ",
  ButtonBox["Recursions: representation",
    ButtonData:>{"Recursions: representation", "MakePopulation"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " for individuals",
  ", ",
  ButtonBox["Simulating individuals: Describing populations",
    ButtonData:>{"Simulating individuals: Describing populations", 
      "MakePopulation"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " for symmetric model",
  ", ",
  ButtonBox["Symmetric model: representation",
    ButtonData:>{"Symmetric model: representation", "MakePopulation"},
    ButtonStyle->"AddOnsLink"]
}], "IndexSubentry",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"MakePopulation"],

Cell[TextData[{
  "MakeSelectionCoefficient",
  ",",
  " ",
  ButtonBox["Fitness",
    ButtonData:>{"Fitness", "MakeSelectionCoefficient"},
    ButtonStyle->"AddOnsLink"],
  ",",
  ButtonBox["Phenotypes",
    ButtonData:>{"Phenotypes", "MakeSelectionCoefficient"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"MakeSelectionCoefficient"],

Cell[TextData[{
  " with multiple alleles",
  ", ",
  ButtonBox["Phenotypes",
    ButtonData:>{"Phenotypes", "MakeSelectionCoefficient"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " with two alleles",
  ", ",
  ButtonBox["Phenotypes",
    ButtonData:>{"Phenotypes", "Two alleles"},
    ButtonStyle->"AddOnsLink"]
}], "IndexSubentry",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"MakeSelectionCoefficient"],

Cell[TextData[{
  "Mangel & Hilborn 1996",
  ",",
  " ",
  ButtonBox["References",
    ButtonData:>{"References", "Mangel & Hilborn 1996"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Mangel & Hilborn 1996"],

Cell[TextData[{
  "MapLength",
  ",",
  " in ancestral graphs",
  ", ",
  ButtonBox["Describing ancestral graphs",
    ButtonData:>{"Describing ancestral graphs", "MapLength"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"MapLength"],

Cell[TextData[{
  "MapPosition",
  ",",
  " option for AncestorList",
  ", ",
  ButtonBox["Ancestors & descendants",
    ButtonData:>{"Ancestors & descendants", "MapPositionA"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"MapPosition"],

Cell[TextData[{
  " option for DescendantList",
  ", ",
  ButtonBox["Ancestors & descendants",
    ButtonData:>{"Ancestors & descendants", "MapPositionD"},
    ButtonStyle->"AddOnsLink"]
}], "IndexSubentry",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"MapPosition"],

Cell[TextData[{
  "Marginal fitness",
  ",",
  " for allele frequencies",
  ", ",
  ButtonBox["Allele frequencies: fitnesses",
    ButtonData:>{"Allele frequencies: fitnesses", "MarginalW"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Marginal fitness"],

Cell[TextData[{
  "for genotype frequencies",
  ", ",
  ButtonBox["Recursions:fitnesses",
    ButtonData:>{"Recursions:fitnesses", "MarginalW"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " in symmetric model",
  ", ",
  ButtonBox["Symmetric model: fitnesses",
    ButtonData:>{"Symmetric model: fitnesses", "MarginalW"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " with individuals",
  ", ",
  ButtonBox["Simulating individuals: fitnesses",
    ButtonData:>{"Simulating individuals: fitnesses", "MarginalW"},
    ButtonStyle->"AddOnsLink"]
}], "IndexSubentry",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Marginal fitness"],

Cell[TextData[{
  "MarginalTable",
  ",",
  " ",
  ButtonBox["Marginal tables",
    ButtonData:>{"Marginal tables", "MarginalTable"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"MarginalTable"],

Cell[TextData[{
  "MarginalW",
  ",",
  " for allele frequencies",
  ", ",
  ButtonBox["Allele frequencies: fitnesses",
    ButtonData:>{"Allele frequencies: fitnesses", "MarginalW"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"MarginalW"],

Cell[TextData[{
  " for genotype frequencies",
  ", ",
  ButtonBox["Recursions:fitnesses",
    ButtonData:>{"Recursions:fitnesses", "MarginalW"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " for individuals",
  ", ",
  ButtonBox["Simulating individuals: fitnesses",
    ButtonData:>{"Simulating individuals: fitnesses", "MarginalW"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " for symmetric model",
  ", ",
  ButtonBox["Symmetric model: fitnesses",
    ButtonData:>{"Symmetric model: fitnesses", "MarginalW"},
    ButtonStyle->"AddOnsLink"]
}], "IndexSubentry",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"MarginalW"],

Cell[TextData[{
  "MaternalLoci",
  ",",
  " example of",
  ", ",
  ButtonBox["Cytoplasmic inheritance",
    ButtonData:>{"Cytoplasmic inheritance", None},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"MaternalLoci"],

Cell[TextData[{
  " option for NonMendelian",
  ", ",
  ButtonBox["Non-Mendelian inheritance",
    ButtonData:>{"Non-Mendelian inheritance", "CytoplasmicLoci"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " reference points",
  ", ",
  ButtonBox["Reference points",
    ButtonData:>{"Reference points", "CytoplasmicLoci"},
    ButtonStyle->"AddOnsLink"]
}], "IndexSubentry",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"MaternalLoci"],

Cell[TextData[{
  "MatrixGamma",
  ",",
  " ",
  ButtonBox["Fast calculations",
    ButtonData:>{"Fast calculations", "MatrixGamma"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"MatrixGamma"],

Cell[TextData[{
  "MatrixToGenealogy",
  ",",
  " ",
  ButtonBox["Inferring a genealogy",
    ButtonData:>{"Inferring a genealogy", "MatrixToGenealogy"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"MatrixToGenealogy"],

Cell[TextData[{
  "MatrixToList",
  ",",
  " ",
  ButtonBox["Converting between representations",
    ButtonData:>{"Converting between representations", "MatrixToList"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"MatrixToList"],

Cell[TextData[{
  "MeanContribution",
  ",",
  " \[GothicM], \[AliasIndicator]gom\[AliasIndicator]",
  ", ",
  ButtonBox["Populations",
    ButtonData:>{"Populations", "MeanContribution"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"MeanContribution"],

Cell[TextData[{
  "Mean fitness",
  ",",
  " ",
  ButtonBox["Allele frequencies: fitnesses",
    ButtonData:>{"Allele frequencies: fitnesses", "MeanW"},
    ButtonStyle->"AddOnsLink"],
  ",",
  ButtonBox["Recursions:fitnesses",
    ButtonData:>{"Recursions:fitnesses", "MeanW"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Mean fitness"],

Cell[TextData[{
  " in symmetric model",
  ", ",
  ButtonBox["Symmetric model: fitnesses",
    ButtonData:>{"Symmetric model: fitnesses", "MeanW"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " with individuals",
  ", ",
  ButtonBox["Simulating individuals: fitnesses",
    ButtonData:>{"Simulating individuals: fitnesses", "MeanW"},
    ButtonStyle->"AddOnsLink"]
}], "IndexSubentry",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Mean fitness"],

Cell[TextData[{
  "MeanW",
  ",",
  " for allele frequencies",
  ", ",
  ButtonBox["Allele frequencies: fitnesses",
    ButtonData:>{"Allele frequencies: fitnesses", "MeanW"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"MeanW"],

Cell[TextData[{
  " for genotype frequencies",
  ", ",
  ButtonBox["Recursions:fitnesses",
    ButtonData:>{"Recursions:fitnesses", "MeanW"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " for individuals",
  ", ",
  ButtonBox["Simulating individuals: fitnesses",
    ButtonData:>{"Simulating individuals: fitnesses", "MeanW"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " for symmetric model",
  ", ",
  ButtonBox["Symmetric model: fitnesses",
    ButtonData:>{"Symmetric model: fitnesses", "MeanW"},
    ButtonStyle->"AddOnsLink"]
}], "IndexSubentry",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"MeanW"],

Cell[TextData[{
  "Meiosis",
  ",",
  " ",
  ButtonBox["Recombination",
    ButtonData:>{"Recombination", "Meiosis"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Meiosis"],

Cell[TextData[{
  " in numerical models",
  ", ",
  ButtonBox["Recursions:reproduction",
    ButtonData:>{"Recursions:reproduction", None},
    ButtonStyle->"AddOnsLink"]
}], "IndexSubentry",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Meiosis"],

Cell[TextData[{
  "MethodC",
  ",",
  " ",
  ButtonBox["Options for DoReplicates",
    ButtonData:>{"Options for DoReplicates", "MethodC"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"MethodC"],

Cell[TextData[{
  "MethodP",
  ",",
  " ",
  ButtonBox["Options for DoReplicates",
    ButtonData:>{"Options for DoReplicates", "MethodP"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"MethodP"],

Cell[TextData[{
  "Metropolis algorithm",
  ",",
  " estimating D",
  ", ",
  ButtonBox["Random walk",
    ButtonData:>{"Random walk", None},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Metropolis algorithm"],

Cell[TextData[{
  "MetropolisDisequilibrium",
  ",",
  " ",
  ButtonBox["Estimating moments",
    ButtonData:>{"Estimating moments", "MetropolisDisequilibrium"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"MetropolisDisequilibrium"],

Cell[TextData[{
  "MetropolisDisequilibriumReduced",
  ",",
  " ",
  ButtonBox["Obsolete functions",
    ButtonData:>{"Obsolete functions", "MetropolisDisequilibriumReduced"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"MetropolisDisequilibriumReduced"],

Cell[TextData[{
  "Metropolis et al. 1954",
  ",",
  " ",
  ButtonBox["References",
    ButtonData:>{"References", "Metropolis et al 1954"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Metropolis et al. 1954"],

Cell[TextData[{
  "MFromC",
  ",",
  " ",
  ButtonBox["Estimating the matrix",
    ButtonData:>{"Estimating the matrix", "MFromC"},
    ButtonStyle->"AddOnsLink"],
  ",",
  ButtonBox["Estimation from families",
    ButtonData:>{"Estimation from families", "MFromC"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"MFromC"],

Cell[TextData[{
  "Migrate",
  ",",
  " ",
  ButtonBox["Migration",
    ButtonData:>{"Migration", "Migrate"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Migrate"],

Cell[TextData[{
  "MigrateExact",
  ",",
  " for allele frequencies",
  ", ",
  ButtonBox["Allele frequencies: migration",
    ButtonData:>{"Allele frequencies: migration", "MigrateExact"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"MigrateExact"],

Cell[TextData[{
  " for genotype frequencies",
  ", ",
  ButtonBox["Recursions:migration",
    ButtonData:>{"Recursions:migration", "MigrateExact"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " for individuals",
  ", ",
  ButtonBox["Simulating individuals:migration",
    ButtonData:>{"Simulating individuals:migration", "MigrateExact"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " for symmetric model",
  ", ",
  ButtonBox["Symmetric model: migration",
    ButtonData:>{"Symmetric model: migration", "MigrateExact"},
    ButtonStyle->"AddOnsLink"]
}], "IndexSubentry",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"MigrateExact"],

Cell[TextData[{
  "Migration",
  ",",
  " and cytoplasmic inheritance",
  ", ",
  ButtonBox["Migration example",
    ButtonData:>{"Migration example", "Cytonuclear associations"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Migration"],

Cell[TextData[{
  " and sexual selection",
  ", ",
  ButtonBox["Migration",
    ButtonData:>{"Migration", "Sexual selection"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " context-dependent",
  ", ",
  ButtonBox["Migration",
    ButtonData:>{"Migration", "Context-dependent migration"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " example of",
  ", ",
  ButtonBox["Migration example",
    ButtonData:>{"Migration example", None},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " genotype-dependent",
  ", ",
  ButtonBox["Migration",
    ButtonData:>{"Migration", "Genotype-dependent migration"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " in numerical models",
  ", ",
  ButtonBox["Allele frequencies: migration",
    ButtonData:>{"Allele frequencies: migration", "MigrateExact"},
    ButtonStyle->"AddOnsLink"],
  ",",
  ButtonBox["Recursions:migration",
    ButtonData:>{"Recursions:migration", "MigrateExact"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " in symmetric model",
  ", ",
  ButtonBox["Symmetric model: migration",
    ButtonData:>{"Symmetric model: migration", "MigrateExact"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " Kirkpatrick et al.",
  ", ",
  ButtonBox["Multilocus MS",
    ButtonData:>{"Multilocus MS", "Migration"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " of constant numbers",
  ", ",
  ButtonBox["Allele frequencies: migration",
    ButtonData:>{"Allele frequencies: migration", "Constant numbers"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " of haploids",
  ", ",
  ButtonBox["Migration example",
    ButtonData:>{"Migration example", "Haploid migration"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " of juvenile diploids",
  ", ",
  ButtonBox["Migration example",
    ButtonData:>{"Migration example", "Juvenile diploid migration"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " of pollen",
  ", ",
  ButtonBox["Migration example",
    ButtonData:>{"Migration example", "Asmussen and Orive 2000"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " of seeds",
  ", ",
  ButtonBox["Migration example",
    ButtonData:>{"Migration example", "Asmussen and Orive 2000"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " with sindividuals",
  ", ",
  ButtonBox["Simulating individuals:migration",
    ButtonData:>{"Simulating individuals:migration", "MigrateExact"},
    ButtonStyle->"AddOnsLink"]
}], "IndexSubentry",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Migration"],

Cell[TextData[{
  "MigrationOrder",
  ",",
  "for genotype frequencies",
  ", ",
  ButtonBox["Allele frequencies: iterating one deme",
    ButtonData:>{"Allele frequencies: iterating one deme", "MigrationOrder"},
    ButtonStyle->"AddOnsLink"],
  ",",
  ButtonBox["Recursions: iterating one deme",
    ButtonData:>{"Recursions: iterating one deme", "MigrationOrder"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"MigrationOrder"],

Cell[TextData[{
  " for individuals",
  ", ",
  ButtonBox["Simulating individuals: iterating one deme",
    ButtonData:>{"Simulating individuals: iterating one deme", 
      "MigrationOrder"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " for symmetric model",
  ", ",
  ButtonBox["Symmetric model: iterating one deme",
    ButtonData:>{"Symmetric model: iterating one deme", "MigrationOrder"},
    ButtonStyle->"AddOnsLink"]
}], "IndexSubentry",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"MigrationOrder"],

Cell[TextData[{
  "MigrationRate",
  ",",
  " \[CapitalMu], \[AliasIndicator]M\[AliasIndicator]",
  ", ",
  ButtonBox["Notation reference",
    ButtonData:>{"Notation reference", None},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"MigrationRate"],

Cell[TextData[{
  "MigrationSet",
  ",",
  " \[DoubleStruckCapitalM], \[AliasIndicator]dsM\[AliasIndicator]",
  ", ",
  ButtonBox["Migration",
    ButtonData:>{"Migration", "MigrationSet"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"MigrationSet"],

Cell[TextData[{
  "MissingCombination",
  ",",
  " ",
  ButtonBox["Validity of a mutation matrix",
    ButtonData:>{"Validity of a mutation matrix", "MissingCombination"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"MissingCombination"],

Cell[TextData[{
  "Missing data",
  ",",
  " estimating allele frequencies with nulls",
  ", ",
  ButtonBox["Gene & genotype frequencies",
    ButtonData:>{"Gene & genotype frequencies", "NullAllele"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Missing data"],

Cell[TextData[{
  " estimating genotype frequencies with nulls",
  ", ",
  ButtonBox["Gene & genotype frequencies",
    ButtonData:>{"Gene & genotype frequencies", "GenotypeFrequency"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " notation",
  ", ",
  ButtonBox["Defining a dataset",
    ButtonData:>{"Defining a dataset", "Missing data"},
    ButtonStyle->"AddOnsLink"]
}], "IndexSubentry",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Missing data"],

Cell[TextData[{
  "MissingData",
  ",",
  " option for AlleleFrequencyTable",
  ", ",
  ButtonBox["Gene & genotype frequencies",
    ButtonData:>{"Gene & genotype frequencies", "NullAllele"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"MissingData"],

Cell[TextData[{
  " option for GenotypeFrequency",
  ", ",
  ButtonBox["Gene & genotype frequencies",
    ButtonData:>{"Gene & genotype frequencies", "GenotypeFrequency"},
    ButtonStyle->"AddOnsLink"]
}], "IndexSubentry",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"MissingData"],

Cell[TextData[{
  "Moment",
  ",",
  " ",
  ButtonBox["Cumulants",
    ButtonData:>{"Cumulants", "Moment"},
    ButtonStyle->"AddOnsLink"],
  ",",
  ButtonBox["Moments and cumulants",
    ButtonData:>{"Moments and cumulants", "Moment"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Moment"],

Cell[TextData[{
  "MomentAfterMigration",
  ",",
  " ",
  ButtonBox["Migration in admixture models",
    ButtonData:>{"Migration in admixture models", "MomentAfterMigration"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"MomentAfterMigration"],

Cell[TextData[{
  "MomentAfterRecombination",
  ",",
  " ",
  ButtonBox["Recombination in admixture models",
    ButtonData:>{"Recombination in admixture models", 
      "MomentAfterRecombination"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"MomentAfterRecombination"],

Cell[TextData[{
  "MomentEquilibrium",
  ",",
  " ",
  ButtonBox["Equilibria",
    ButtonData:>{"Equilibria", "MomentEquilibrium"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"MomentEquilibrium"],

Cell[TextData[{
  "MomentGeneratingFunction",
  ",",
  " deriving",
  ", ",
  ButtonBox["Deriving recursions for the MGF",
    ButtonData:>{"Deriving recursions for the MGF", None},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"MomentGeneratingFunction"],

Cell[TextData[{
  " examples",
  ", ",
  ButtonBox["Examples of the MGF",
    ButtonData:>{"Examples of the MGF", None},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " for genealogies",
  ", ",
  ButtonBox["Calculating the MGF",
    ButtonData:>{"Calculating the MGF", None},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " over topologies",
  ", ",
  ButtonBox["Calculating over topologies",
    ButtonData:>{"Calculating over topologies", None},
    ButtonStyle->"AddOnsLink"]
}], "IndexSubentry",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"MomentGeneratingFunction"],

Cell[TextData[{
  "MomentLimits",
  ",",
  " ",
  ButtonBox["Constraints on moments",
    ButtonData:>{"Constraints on moments", "MomentLimits"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"MomentLimits"],

Cell[TextData[{
  "MomentNew",
  ",",
  " ",
  ButtonBox["Iteration",
    ButtonData:>{"Iteration", "MomentNew"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"MomentNew"],

Cell[TextData[{
  "MomentReduced",
  ",",
  " ",
  ButtonBox["Obsolete functions",
    ButtonData:>{"Obsolete functions", "MomentReduced"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"MomentReduced"],

Cell[TextData[{
  "Moments",
  ",",
  " ",
  ButtonBox["Cumulants",
    ButtonData:>{"Cumulants", "7.2"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Moments"],

Cell[TextData[{
  " estimating the matrix of",
  ", ",
  ButtonBox["Estimating the matrix of moments",
    ButtonData:>{"Estimating the matrix of moments", "Estimating the matrix"},
    
    ButtonStyle->"AddOnsLink"],
  "\n",
  " extension to description by",
  ", ",
  ButtonBox["References",
    ButtonData:>{"References", "Haber 1984"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " extension to estimation of",
  ", ",
  ButtonBox["Estimating the matrix of moments",
    ButtonData:>{"Estimating the matrix of moments", "MLE"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " full description by",
  ", ",
  ButtonBox["A matrix of moments",
    ButtonData:>{"A matrix of moments", "g[X] matrix"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " matrix of",
  ", ",
  ButtonBox["A matrix of moments",
    ButtonData:>{"A matrix of moments", "g[X] full matrix"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  "ML estimation of",
  ", ",
  ButtonBox["Estimating the matrix of moments",
    ButtonData:>{"Estimating the matrix of moments", "simple method"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " reduced description by",
  ", ",
  ButtonBox["A matrix of moments",
    ButtonData:>{"A matrix of moments", "g[X] matrix"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " simple method for estimating",
  ", ",
  ButtonBox["Estimating the matrix of moments",
    ButtonData:>{"Estimating the matrix of moments", "extension to families"},
    
    ButtonStyle->"AddOnsLink"]
}], "IndexSubentry",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Moments"],

Cell[TextData[{
  "MomentsFromG",
  ",",
  " ",
  ButtonBox["Moments from genotype frequencies",
    ButtonData:>{"Moments from genotype frequencies", "MomentsFromG"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"MomentsFromG"],

Cell[TextData[{
  "MomentSimple",
  ",",
  " ",
  ButtonBox["Simplifying the moments",
    ButtonData:>{"Simplifying the moments", "MomentSimple"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"MomentSimple"],

Cell[TextData[{
  "MonteCarloGriffithsTavare",
  ",",
  " ",
  ButtonBox["Stochastic algorithm",
    ButtonData:>{"Stochastic algorithm", "MonteCarloGriffithsTavare"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"MonteCarloGriffithsTavare"],

Cell[TextData[{
  "MonteCarloProbability",
  ",",
  " ",
  ButtonBox["Estimating the probability",
    ButtonData:>{"Estimating the probability", "MonteCarloProbability"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"MonteCarloProbability"],

Cell[TextData[{
  "Mortality",
  ",",
  " ",
  ButtonBox["Describing individuals",
    ButtonData:>{"Describing individuals", "Mortality"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Mortality"],

Cell[TextData[{
  "MostRecentCommonAncestor",
  ",",
  " ",
  ButtonBox["Determining ancestry",
    ButtonData:>{"Determining ancestry", "MostRecentCommonAncestor"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"MostRecentCommonAncestor"],

Cell[TextData[{
  "MToC",
  ",",
  " ",
  ButtonBox["Estimating the matrix",
    ButtonData:>{"Estimating the matrix", "MToC"},
    ButtonStyle->"AddOnsLink"],
  ",",
  ButtonBox["Estimation from families",
    ButtonData:>{"Estimation from families", "MToC"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"MToC"],

Cell[TextData[{
  "MToCEquations",
  ",",
  " ",
  ButtonBox["Estimating the matrix",
    ButtonData:>{"Estimating the matrix", "MToCEquations"},
    ButtonStyle->"AddOnsLink"],
  ",",
  ButtonBox["Estimation from families",
    ButtonData:>{"Estimation from families", "MToCEquations"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"MToCEquations"],

Cell[TextData[{
  "Muddle",
  ",",
  " ",
  ButtonBox["Muddling and subdividing sets",
    ButtonData:>{"Muddling and subdividing sets", "Muddle"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Muddle"],

Cell[TextData[{
  "Multilocus algebra",
  ",",
  " basic notation",
  ", ",
  ButtonBox["Genes and contexts",
    ButtonData:>{"Genes and contexts", "Basic notation"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Multilocus algebra"],

Cell[TextData[{
  " fitness",
  ", ",
  ButtonBox["Fitness",
    ButtonData:>{"Fitness", "Fitness"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " introduction to",
  ", ",
  ButtonBox["Introduction to multilocus algebra",
    ButtonData:>{"Introduction to multilocus algebra", "1.1"},
    ButtonStyle->"AddOnsLink"],
  ",",
  ButtonBox["Introduction to multilocus algebra",
    ButtonData:>{"Introduction to multilocus algebra", 
      "Multilocus`Multilocus`"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " stages in life cycle",
  ", ",
  ButtonBox["Genes and contexts",
    ButtonData:>{"Genes and contexts", "Stages"},
    ButtonStyle->"AddOnsLink"],
  ",",
  ButtonBox["Life cycle",
    ButtonData:>{"Life cycle", "Stages"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " technicalities",
  ", ",
  ButtonBox["Populations",
    ButtonData:>{"Populations", "Technicalities"},
    ButtonStyle->"AddOnsLink"]
}], "IndexSubentry",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Multilocus algebra"],

Cell[TextData[{
  "Multilocus MS",
  ",",
  " relation with",
  ", ",
  ButtonBox["Migration example",
    ButtonData:>{"Migration example", "Multilocus MS"},
    ButtonStyle->"AddOnsLink"],
  ",",
  ButtonBox["Multilocus MS relation",
    ButtonData:>{"Multilocus MS relation", None},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Multilocus MS"],

Cell[TextData[{
  "Multilocus notation",
  ",",
  " bugs",
  ", ",
  ButtonBox["Bugs",
    ButtonData:>{"Bugs", "Multilocus notation"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Multilocus notation"],

Cell[TextData[{
  "Multinomial sampling",
  ",",
  " without replacement",
  ", ",
  ButtonBox["Multinomial distribution",
    ButtonData:>{"Multinomial distribution", 
      "Multinomial sampling wo replacement"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Multinomial sampling"],

Cell[TextData[{
  "MultinomialSamplingProbability",
  ",",
  " ",
  ButtonBox["Multinomial distribution",
    ButtonData:>{"Multinomial distribution", 
      "MultinomialSamplingProbability"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"MultinomialSamplingProbability"],

Cell[TextData[{
  "Multiple alleles",
  ",",
  " and selection coefficients",
  ", ",
  ButtonBox["Phenotypes",
    ButtonData:>{"Phenotypes", "Multiple alleles"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Multiple alleles"],

Cell[TextData[{
  " MakeFitnessSet",
  ", ",
  ButtonBox["Fitness",
    ButtonData:>{"Fitness", "Multiple alleles"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " mutation",
  ", ",
  ButtonBox["Multilocus mutation",
    ButtonData:>{"Multilocus mutation", "Multiple alleles"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " representation of",
  ", ",
  ButtonBox["Allelic state",
    ButtonData:>{"Allelic state", None},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " selection on",
  ", ",
  ButtonBox["Selection",
    ButtonData:>{"Selection", "Multiple alleles"},
    ButtonStyle->"AddOnsLink"]
}], "IndexSubentry",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Multiple alleles"],

Cell[TextData[{
  "Multiple arguments",
  ",",
  " in PopulationExpectation",
  ", ",
  ButtonBox["Expectations",
    ButtonData:>{"Expectations", "multiple arguments"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Multiple arguments"],

Cell[TextData[{
  "Multiplicative models",
  ",",
  " in negative binomial",
  ", ",
  ButtonBox["Negative binomial likelihoods",
    ButtonData:>{"Negative binomial likelihoods", "multiplicative models"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Multiplicative models"],

Cell[TextData[{
  "MUS",
  ",",
  " for allele frequencies",
  ", ",
  ButtonBox["Allele frequencies: iterating one deme",
    ButtonData:>{"Allele frequencies: iterating one deme", "MUS"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"MUS"],

Cell[TextData[{
  "for genotype frequencies",
  ", ",
  ButtonBox["Recursions: iterating one deme",
    ButtonData:>{"Recursions: iterating one deme", "MUS"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " for individuals",
  ", ",
  ButtonBox["Simulating individuals: iterating one deme",
    ButtonData:>{"Simulating individuals: iterating one deme", "MUS"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " for symmetric model",
  ", ",
  ButtonBox["Symmetric model: iterating one deme",
    ButtonData:>{"Symmetric model: iterating one deme", "MUS"},
    ButtonStyle->"AddOnsLink"]
}], "IndexSubentry",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"MUS"],

Cell[TextData[{
  "Mutate",
  ",",
  " allele frequencies",
  ", ",
  ButtonBox["Allele frequencies: mutation",
    ButtonData:>{"Allele frequencies: mutation", "Mutate"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Mutate"],

Cell[TextData[{
  "genotype frequencies",
  ", ",
  ButtonBox["Recursions: mutation",
    ButtonData:>{"Recursions: mutation", "Mutate"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " individuals",
  ", ",
  ButtonBox["Simulating individuals: mutation",
    ButtonData:>{"Simulating individuals: mutation", "Mutate"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " symmetric model",
  ", ",
  ButtonBox["Symmetric model: mutation",
    ButtonData:>{"Symmetric model: mutation", "Mutate"},
    ButtonStyle->"AddOnsLink"]
}], "IndexSubentry",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Mutate"],

Cell[TextData[{
  "MutateCompiled",
  ",",
  " ",
  ButtonBox["Allele frequencies: mutation",
    ButtonData:>{"Allele frequencies: mutation", "MutateCompiled"},
    ButtonStyle->"AddOnsLink"],
  ",",
  ButtonBox["Recursions: mutation",
    ButtonData:>{"Recursions: mutation", "MutateCompiled"},
    ButtonStyle->"AddOnsLink"],
  ",",
  ButtonBox["Simulating individuals: mutation",
    ButtonData:>{"Simulating individuals: mutation", "MutateCompiled"},
    ButtonStyle->"AddOnsLink"],
  ",",
  ButtonBox["Symmetric model: mutation",
    ButtonData:>{"Symmetric model: mutation", "MutateCompiled"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"MutateCompiled"],

Cell[TextData[{
  "Mutation",
  ",",
  " Kirkpatrick et al.",
  ", ",
  ButtonBox["Multilocus MS",
    ButtonData:>{"Multilocus MS", "Mutation"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Mutation"],

Cell[TextData[{
  " Mutations, in multilocus genetics",
  ", ",
  ButtonBox["Multilocus mutation",
    ButtonData:>{"Multilocus mutation", "Mutation"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " option for BiallelicMutation",
  ", ",
  ButtonBox["Multilocus mutation",
    ButtonData:>{"Multilocus mutation", "Mutation"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " option for NewGametes",
  ", ",
  ButtonBox["Allele frequencies: reproduction",
    ButtonData:>{"Allele frequencies: reproduction", "Mutation"},
    ButtonStyle->"AddOnsLink"],
  ",",
  ButtonBox["Recursions: reproduction",
    ButtonData:>{"Recursions: reproduction", "Mutation"},
    ButtonStyle->"AddOnsLink"],
  ",",
  ButtonBox["Simulating individuals: reproduction",
    ButtonData:>{"Simulating individuals: reproduction", "Mutation"},
    ButtonStyle->"AddOnsLink"],
  ",",
  ButtonBox["Symmetric model: reproduction",
    ButtonData:>{"Symmetric model: reproduction", "Mutation"},
    ButtonStyle->"AddOnsLink"]
}], "IndexSubentry",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Mutation"],

Cell[TextData[{
  "MutationInterval",
  ",",
  " ",
  ButtonBox["Describing mutations",
    ButtonData:>{"Describing mutations", "MutationInterval"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"MutationInterval"],

Cell[TextData[{
  "MutationLabels",
  ",",
  " ",
  ButtonBox["Converting between representations",
    ButtonData:>{"Converting between representations", "MutationLabels"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"MutationLabels"],

Cell[TextData[{
  "MutationOrigin",
  ",",
  " ",
  ButtonBox["Describing mutations",
    ButtonData:>{"Describing mutations", "MutationOrigin"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"MutationOrigin"],

Cell[TextData[{
  "MutationRate",
  ",",
  " ",
  ButtonBox["Drawing a genealogy",
    ButtonData:>{"Drawing a genealogy", "MutationRate"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"MutationRate"],

Cell[TextData[{
  "Mutations",
  ",",
  " adding to a genealogy",
  ", ",
  ButtonBox["Manipulating genealogies",
    ButtonData:>{"Manipulating genealogies", "AddMutation"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Mutations"],

Cell[TextData[{
  " consistency with a genealogy",
  ", ",
  ButtonBox["Validity of a mutation matrix",
    ButtonData:>{"Validity of a mutation matrix", None},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " inferring genealogies from",
  ", ",
  ButtonBox["Inferring a genealogy",
    ButtonData:>{"Inferring a genealogy", None},
    ButtonStyle->"AddOnsLink"],
  "\n",
  "infinite site",
  ", ",
  ButtonBox["Describing mutations",
    ButtonData:>{"Describing mutations", "Mutations"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " in genealogies",
  ", ",
  ButtonBox["Describing mutations",
    ButtonData:>{"Describing mutations", "Mutations"},
    ButtonStyle->"AddOnsLink"]
}], "IndexSubentry",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Mutations"],

Cell[TextData[{
  "MVariables",
  ",",
  " ",
  ButtonBox["Estimating the matrix",
    ButtonData:>{"Estimating the matrix", "MVariables"},
    ButtonStyle->"AddOnsLink"],
  ",",
  ButtonBox["Estimation from families",
    ButtonData:>{"Estimation from families", "MVariables"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"MVariables"],

Cell[TextData[{
  "Negative binomial",
  ",",
  " c<1",
  ", ",
  ButtonBox["Negative binomial likelihoods",
    ButtonData:>{"Negative binomial likelihoods", "c<1"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Negative binomial"],

Cell[TextData[{
  " compiled",
  ", ",
  ButtonBox["Negative binomial likelihoods",
    ButtonData:>{"Negative binomial likelihoods", "Compiled"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " multiplicative models",
  ", ",
  ButtonBox["Negative binomial likelihoods",
    ButtonData:>{"Negative binomial likelihoods", "multiplicative models"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " normalisation",
  ", ",
  ButtonBox["Negative binomial likelihoods",
    ButtonData:>{"Negative binomial likelihoods", "Normalisation"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " timings",
  ", ",
  ButtonBox["Negative binomial likelihoods",
    ButtonData:>{"Negative binomial likelihoods", "Timings"},
    ButtonStyle->"AddOnsLink"]
}], "IndexSubentry",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Negative binomial"],

Cell[TextData[{
  "NegativeBinomialLogLikelihood",
  ",",
  " ",
  ButtonBox["Negative binomial likelihoods",
    ButtonData:>{"Negative binomial likelihoods", 
      "NegativeBinomialLogLikelihood"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"NegativeBinomialLogLikelihood"],

Cell[TextData[{
  "NegativeBinomialMLE",
  ",",
  " ",
  ButtonBox["Negative binomial likelihoods",
    ButtonData:>{"Negative binomial likelihoods", "NegativeBinomialMLE"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"NegativeBinomialMLE"],

Cell[TextData[{
  "NegativeHypergeometricDistribution",
  ",",
  " ",
  ButtonBox["Negative hypergeometric distribution",
    ButtonData:>{"Negative hypergeometric distribution", 
      "NegativeHypergeometricDistribution"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"NegativeHypergeometricDistribution"],

Cell[TextData[{
  "NeighbourArray",
  ",",
  " ",
  ButtonBox["Boxing the individuals",
    ButtonData:>{"Boxing the individuals", "NeighbourArray"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"NeighbourArray"],

Cell[TextData[{
  "Neighbours",
  ",",
  " ",
  ButtonBox["Boxing the individuals",
    ButtonData:>{"Boxing the individuals", "Neighbours"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Neighbours"],

Cell[TextData[{
  "NetCovariance",
  ",",
  " ",
  ButtonBox["Gene & genotype frequencies",
    ButtonData:>{"Gene & genotype frequencies", "NetCovariance"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"NetCovariance"],

Cell[TextData[{
  "NetFecundity",
  ",",
  " ",
  ButtonBox["Global variables",
    ButtonData:>{"Global variables", "NetFecundity"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"NetFecundity"],

Cell[TextData[{
  "NetMortality",
  ",",
  " ",
  ButtonBox["Global variables",
    ButtonData:>{"Global variables", "NetMortality"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"NetMortality"],

Cell[TextData[{
  "NetRecombination",
  ",",
  " ",
  ButtonBox["Linkage",
    ButtonData:>{"Linkage", "NetRecombination"},
    ButtonStyle->"AddOnsLink"],
  ",",
  ButtonBox["Linkage in families",
    ButtonData:>{"Linkage in families", "NetRecombination"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"NetRecombination"],

Cell[TextData[{
  " in multilocus genetics",
  ", ",
  ButtonBox["Recombination",
    ButtonData:>{"Recombination", "NetRecombination"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " in numerical models",
  ", ",
  ButtonBox["Recursions:Linkage",
    ButtonData:>{"Recursions:Linkage", "NetRecombination"},
    ButtonStyle->"AddOnsLink"]
}], "IndexSubentry",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"NetRecombination"],

Cell[TextData[{
  "Neutral marker",
  ",",
  " in symmetric model",
  ", ",
  ButtonBox["Adding a neutral gene",
    ButtonData:>{"Adding a neutral gene", None},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Neutral marker"],

Cell[TextData[{
  "NeutralRepresentations",
  ",",
  " ",
  ButtonBox["Overview of numerical models",
    ButtonData:>{"Overview of numerical models", "NeutralRepresentations"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"NeutralRepresentations"],

Cell[TextData[{
  "NewGametes",
  ",",
  " for allele frequencies",
  ", ",
  ButtonBox["Allele frequencies:reproduction",
    ButtonData:>{"Allele frequencies:reproduction", "NewGametes"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"NewGametes"],

Cell[TextData[{
  " for genotype frequencies",
  ", ",
  ButtonBox["Recursions:reproduction",
    ButtonData:>{"Recursions:reproduction", "NewGametes"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " for symmetric model",
  ", ",
  ButtonBox["Symmetric model: reproduction",
    ButtonData:>{"Symmetric model: reproduction", "NewGametes"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " linkage",
  ", ",
  ButtonBox["Recursions:Linkage",
    ButtonData:>{"Recursions:Linkage", "NewGametes"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " Mutation option",
  ", ",
  ButtonBox["Allele frequencies: reproduction",
    ButtonData:>{"Allele frequencies: reproduction", "Mutation"},
    ButtonStyle->"AddOnsLink"],
  ",",
  ButtonBox["Recursions: reproduction",
    ButtonData:>{"Recursions: reproduction", "Mutation"},
    ButtonStyle->"AddOnsLink"],
  ",",
  ButtonBox["Simulating individuals: reproduction",
    ButtonData:>{"Simulating individuals: reproduction", "Mutation"},
    ButtonStyle->"AddOnsLink"],
  ",",
  ButtonBox["Symmetric model: reproduction",
    ButtonData:>{"Symmetric model: reproduction", "Mutation"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " truncation selection",
  ", ",
  ButtonBox["Simulating individuals: reproduction",
    ButtonData:>{"Simulating individuals: reproduction", 
      "TruncationSelection"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " with individuals",
  ", ",
  ButtonBox["Simulating individuals: reproduction",
    ButtonData:>{"Simulating individuals: reproduction", "NewGametes"},
    ButtonStyle->"AddOnsLink"]
}], "IndexSubentry",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"NewGametes"],

Cell[TextData[{
  "NewS",
  ",",
  " ",
  ButtonBox["The set of all structures",
    ButtonData:>{"The set of all structures", "NewS"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"NewS"],

Cell[TextData[{
  "Node",
  ",",
  " ",
  ButtonBox["Constructing genealogies",
    ButtonData:>{"Constructing genealogies", "Node"},
    ButtonStyle->"AddOnsLink"],
  ",",
  ButtonBox["Structure of genealogies",
    ButtonData:>{"Structure of genealogies", "Node"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Node"],

Cell[TextData[{
  "NodeFunction",
  ",",
  " ",
  ButtonBox["Constructing genealogies",
    ButtonData:>{"Constructing genealogies", "NodeFunction"},
    ButtonStyle->"AddOnsLink"],
  ",",
  ButtonBox["Plotting genealogies",
    ButtonData:>{"Plotting genealogies", "NodeFunction"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"NodeFunction"],

Cell[TextData[{
  " option for ExactProbability",
  ", ",
  ButtonBox["Exact probability",
    ButtonData:>{"Exact probability", "NodeFunction"},
    ButtonStyle->"AddOnsLink"]
}], "IndexSubentry",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"NodeFunction"],

Cell[TextData[{
  "NodeLabels",
  ",",
  " ",
  ButtonBox["Plotting genealogies",
    ButtonData:>{"Plotting genealogies", "NodeLabels"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"NodeLabels"],

Cell[TextData[{
  "NodeOffset",
  ",",
  " ",
  ButtonBox["Plotting genealogies",
    ButtonData:>{"Plotting genealogies", "NodeOffset"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"NodeOffset"],

Cell[TextData[{
  "Nodes",
  ",",
  " ",
  ButtonBox["Describing genealogies",
    ButtonData:>{"Describing genealogies", "Nodes"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Nodes"],

Cell[TextData[{
  "NonMendelian",
  ",",
  " ",
  ButtonBox["Non-Mendelian inheritance",
    ButtonData:>{"Non-Mendelian inheritance", None},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"NonMendelian"],

Cell[TextData[{
  " examples of",
  ", ",
  ButtonBox["Cytoplasmic inheritance",
    ButtonData:>{"Cytoplasmic inheritance", None},
    ButtonStyle->"AddOnsLink"],
  ",",
  ButtonBox["Sex linkage",
    ButtonData:>{"Sex linkage", None},
    ButtonStyle->"AddOnsLink"]
}], "IndexSubentry",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"NonMendelian"],

Cell[TextData[{
  "NonNeutralRepresentations",
  ",",
  " ",
  ButtonBox["Overview of numerical models",
    ButtonData:>{"Overview of numerical models", "NonNeutralRepresentations"},
    
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"NonNeutralRepresentations"],

Cell[TextData[{
  "NonSymmetricRepresentations",
  ",",
  " ",
  ButtonBox["Overview of numerical models",
    ButtonData:>{"Overview of numerical models", 
      "NonSymmetricRepresentations"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"NonSymmetricRepresentations"],

Cell[TextData[{
  "Normalisation",
  ",",
  " ",
  ButtonBox["Negative binomial likelihoods",
    ButtonData:>{"Negative binomial likelihoods", "Normalisation"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Normalisation"],

Cell[TextData[{
  "Normalised",
  ",",
  " ",
  ButtonBox["Negative binomial likelihoods",
    ButtonData:>{"Negative binomial likelihoods", "Normalised"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Normalised"],

Cell[TextData[{
  "Notation",
  ",",
  " clearing definitions",
  ", ",
  ButtonBox["Notation reference",
    ButtonData:>{"Notation reference", "Clearing definitions"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Notation"],

Cell[TextData[{
  " data",
  ", ",
  ButtonBox["Notation for genetic data",
    ButtonData:>{"Notation for genetic data", "NotationPackage"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " defining new",
  ", ",
  ButtonBox["Notation reference",
    ButtonData:>{"Notation reference", "Defining new notation"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " genotypes",
  ", ",
  ButtonBox["Notation",
    ButtonData:>{"Notation", "NotationPackage"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " reference",
  ", ",
  ButtonBox["Notation reference",
    ButtonData:>{"Notation reference", "NotationPackage"},
    ButtonStyle->"AddOnsLink"]
}], "IndexSubentry",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Notation"],

Cell[TextData[{
  "Notation Package",
  ",",
  " ",
  ButtonBox["Notation package",
    ButtonData:>{"Notation package", None},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Notation Package"],

Cell[TextData[{
  "NullAllele",
  ",",
  " option for AlleleFrequencyTable",
  ", ",
  ButtonBox["Gene & genotype frequencies",
    ButtonData:>{"Gene & genotype frequencies", "NullAllele"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"NullAllele"],

Cell[TextData[{
  " option for GenotypeFrequency",
  ", ",
  ButtonBox["Gene & genotype frequencies",
    ButtonData:>{"Gene & genotype frequencies", "GenotypeFrequency"},
    ButtonStyle->"AddOnsLink"]
}], "IndexSubentry",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"NullAllele"],

Cell[TextData[{
  "Null alleles",
  ",",
  " estimating allele frequencies",
  ", ",
  ButtonBox["Gene & genotype frequencies",
    ButtonData:>{"Gene & genotype frequencies", "NullAllele"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Null alleles"],

Cell[TextData[{
  " estimating genotype frequencies",
  ", ",
  ButtonBox["Gene & genotype frequencies",
    ButtonData:>{"Gene & genotype frequencies", "GenotypeFrequency"},
    ButtonStyle->"AddOnsLink"]
}], "IndexSubentry",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Null alleles"],

Cell[TextData[{
  "Null lineages",
  ",",
  " in ancestral graphs",
  ", ",
  ButtonBox["Random ancestral graphs",
    ButtonData:>{"Random ancestral graphs", "DeleteNullLineages"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Null lineages"],

Cell[TextData[{
  "NullLineages",
  ",",
  " in ancestral graphs",
  ", ",
  ButtonBox["Describing ancestral graphs",
    ButtonData:>{"Describing ancestral graphs", "NullLineages"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"NullLineages"],

Cell[TextData[{
  "NullRecombinationEvents",
  ",",
  " in ancestral graphs",
  ", ",
  ButtonBox["Describing ancestral graphs",
    ButtonData:>{"Describing ancestral graphs", "NullRecombinationEvents"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"NullRecombinationEvents"],

Cell[TextData[{
  "NumberedLink",
  ",",
  " ",
  ButtonBox["Automatic Numbering",
    ButtonData:>{"Automatic Numbering", "NumberedLink"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"NumberedLink"],

Cell[TextData[{
  "Numbering",
  ",",
  " aesthetics",
  ", ",
  ButtonBox["Automatic Numbering",
    ButtonData:>{"Automatic Numbering", "Aesthetics"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Numbering"],

Cell[TextData[{
  " automatic",
  ", ",
  ButtonBox["Automatic Numbering",
    ButtonData:>{"Automatic Numbering", "7.2"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " notes on",
  ", ",
  ButtonBox["Automatic Numbering",
    ButtonData:>{"Automatic Numbering", "Notes"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " saving links",
  ", ",
  ButtonBox["Automatic Numbering",
    ButtonData:>{"Automatic Numbering", "Saving the links"},
    ButtonStyle->"AddOnsLink"]
}], "IndexSubentry",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Numbering"],

Cell[TextData[{
  "NumberOfCoalescences",
  ",",
  " ",
  ButtonBox["Distribution of coalescence times",
    ButtonData:>{"Distribution of coalescence times", "NumberOfCoalescences"},
    
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"NumberOfCoalescences"],

Cell[TextData[{
  "NumberOfGenes",
  ",",
  " ",
  ButtonBox["Describing a dataset",
    ButtonData:>{"Describing a dataset", "NumberOfGenes"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"NumberOfGenes"],

Cell[TextData[{
  " for allele frequencies",
  ", ",
  ButtonBox["Allele frequencies: representation",
    ButtonData:>{"Allele frequencies: representation", "NumberOfGenes"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " for genotype frequencies",
  ", ",
  ButtonBox["Recursions: description",
    ButtonData:>{"Recursions: description", "NumberOfGenes"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " for individuals",
  ", ",
  ButtonBox["Simulating individuals: Describing populations",
    ButtonData:>{"Simulating individuals: Describing populations", 
      "NumberOfGenes"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " for symmetric model",
  ", ",
  ButtonBox["Symmetric model: Describing populations",
    ButtonData:>{"Symmetric model: Describing populations", "NumberOfGenes"},
    ButtonStyle->"AddOnsLink"]
}], "IndexSubentry",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"NumberOfGenes"],

Cell[TextData[{
  "NumberOfGenesTable",
  ",",
  " ",
  ButtonBox["Describing a dataset",
    ButtonData:>{"Describing a dataset", "NumberOfGenesTable"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"NumberOfGenesTable"],

Cell[TextData[{
  "NumberOfIndividuals",
  ",",
  " ",
  ButtonBox["Describing a dataset",
    ButtonData:>{"Describing a dataset", "NumberOfIndividuals"},
    ButtonStyle->"AddOnsLink"],
  ",",
  ButtonBox["Global variables",
    ButtonData:>{"Global variables", "NumberOfIndividuals"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"NumberOfIndividuals"],

Cell[TextData[{
  "NumberOfIndividualsTable",
  ",",
  " ",
  ButtonBox["Describing a dataset",
    ButtonData:>{"Describing a dataset", "NumberOfIndividualsTable"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"NumberOfIndividualsTable"],

Cell[TextData[{
  "NumberOfLineages",
  ",",
  " ",
  ButtonBox["Describing genealogies",
    ButtonData:>{"Describing genealogies", "NumberOfLineages"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"NumberOfLineages"],

Cell[TextData[{
  "NumberOfLoci",
  ",",
  " ",
  ButtonBox["Describing a dataset",
    ButtonData:>{"Describing a dataset", "NumberOfLoci"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"NumberOfLoci"],

Cell[TextData[{
  "NumberOfMutations",
  ",",
  " ",
  ButtonBox["Describing mutations",
    ButtonData:>{"Describing mutations", "NumberOfMutations"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"NumberOfMutations"],

Cell[TextData[{
  "NumberOfPossibleCoalescences",
  ",",
  " ",
  ButtonBox["Finding possible orders",
    ButtonData:>{"Finding possible orders", "NumberOfPossibleCoalescences"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"NumberOfPossibleCoalescences"],

Cell[TextData[{
  "NumberOfSamplePartitions",
  ",",
  " ",
  ButtonBox["Set partitions",
    ButtonData:>{"Set partitions", "NumberOfSamplePartitions"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"NumberOfSamplePartitions"],

Cell[TextData[{
  "NumberOfSetPartitions",
  ",",
  " ",
  ButtonBox["Set partitions",
    ButtonData:>{"Set partitions", "NumberOfSetPartitions"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"NumberOfSetPartitions"],

Cell[TextData[{
  "NumericalModel",
  ",",
  " for allele frequencies",
  ", ",
  ButtonBox["Allele frequencies: representation",
    ButtonData:>{"Allele frequencies: representation", "NumericalModel"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"NumericalModel"],

Cell[TextData[{
  " for genotype frequencies",
  ", ",
  ButtonBox["Recursions: representation",
    ButtonData:>{"Recursions: representation", "NumericalModel"},
    ButtonStyle->"AddOnsLink"]
}], "IndexSubentry",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"NumericalModel"],

Cell[TextData[{
  "Numerical models",
  ",",
  " genotype frequencies",
  ", ",
  ButtonBox["Recursions: representation",
    ButtonData:>{"Recursions: representation", None},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Numerical models"],

Cell[TextData[{
  " of allele frequencies",
  ", ",
  ButtonBox["Allele frequencies: representation",
    ButtonData:>{"Allele frequencies: representation", None},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " overview",
  ", ",
  ButtonBox["Overview of numerical models",
    ButtonData:>{"Overview of numerical models", None},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " problems",
  ", ",
  ButtonBox["Potential problems",
    ButtonData:>{"Potential problems", None},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " problems with migration",
  ", ",
  ButtonBox["Allele frequencies: migration",
    ButtonData:>{"Allele frequencies: migration", "Constant numbers"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " stability of",
  ", ",
  ButtonBox["Allele frequencies: stability",
    ButtonData:>{"Allele frequencies: stability", None},
    ButtonStyle->"AddOnsLink"],
  ",",
  ButtonBox["Example: stability",
    ButtonData:>{"Example: stability", None},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " symmetric",
  ", ",
  ButtonBox["Symmetric model: genotype frequencies",
    ButtonData:>{"Symmetric model: genotype frequencies", None},
    ButtonStyle->"AddOnsLink"]
}], "IndexSubentry",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Numerical models"],

Cell[TextData[{
  "Observable genotype",
  ",",
  " ",
  ButtonBox["Diploid genotypes",
    ButtonData:>{"Diploid genotypes", "ObservableGenotype"},
    ButtonStyle->"AddOnsLink"],
  ",",
  ButtonBox["Genotype probabilities",
    ButtonData:>{"Genotype probabilities", "ObservableGenotype"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Observable genotype"],

Cell[TextData[{
  "Obsolete",
  ",",
  " Combine",
  ", ",
  ButtonBox["Tagging sets",
    ButtonData:>{"Tagging sets", "Separate"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Obsolete"],

Cell[TextData[{
  " CumulantReduced",
  ", ",
  ButtonBox["Obsolete functions",
    ButtonData:>{"Obsolete functions", "CumulantReduced"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " DiploidConstraints",
  ", ",
  ButtonBox["Obsolete functions",
    ButtonData:>{"Obsolete functions", "DiploidConstraints"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " DiploidGenotypeFrequencyReduced",
  ", ",
  ButtonBox["Obsolete functions",
    ButtonData:>{"Obsolete functions", "DiploidGenotypeFrequencyReduced"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " DiploidGenotypeFrequencyTable",
  ", ",
  ButtonBox["Obsolete functions",
    ButtonData:>{"Obsolete functions", "DiploidGenotypeFrequencyTable"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " Estimating D",
  ", ",
  ButtonBox["Bugs",
    ButtonData:>{"Bugs", "Obsolete EstimatingD"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " fitness",
  ", ",
  ButtonBox["Fitness",
    ButtonData:>{"Fitness", "Obsolete notation"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " FullGenotypeFrequencyReduced",
  ", ",
  ButtonBox["Obsolete functions",
    ButtonData:>{"Obsolete functions", "FullGenotypeFrequencyReduced"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " FullGenotypeFrequencyTable",
  ", ",
  ButtonBox["Obsolete functions",
    ButtonData:>{"Obsolete functions", "FullGenotypeFrequencyTable"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " GenotypeFrequencyArguments",
  ", ",
  ButtonBox["Obsolete functions",
    ButtonData:>{"Obsolete functions", "GenotypeFrequencyArguments"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " HaploidConstraints",
  ", ",
  ButtonBox["Obsolete functions",
    ButtonData:>{"Obsolete functions", "HaploidConstraints"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " InitialStepReduced",
  ", ",
  ButtonBox["Obsolete functions",
    ButtonData:>{"Obsolete functions", "InitialStepReduced"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " IntervalCombine",
  ", ",
  ButtonBox["Obsolete functions",
    ButtonData:>{"Obsolete functions", "IntervalCombine"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " IntervalPosition",
  ", ",
  ButtonBox["Obsolete functions",
    ButtonData:>{"Obsolete functions", "IntervalPosition"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " LogLikelihoodDisequilibriumReduced",
  ", ",
  ButtonBox["Obsolete functions",
    ButtonData:>{"Obsolete functions", "LogLikelihoodDisequilibriumReduced"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " MetropolisDisequilibriumReduced",
  ", ",
  ButtonBox["Obsolete functions",
    ButtonData:>{"Obsolete functions", "MetropolisDisequilibriumReduced"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " MomentReduced",
  ", ",
  ButtonBox["Obsolete functions",
    ButtonData:>{"Obsolete functions", "MomentReduced"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " notation",
  ", ",
  ButtonBox["Bugs",
    ButtonData:>{"Bugs", "Obsolete EstimatingD"},
    ButtonStyle->"AddOnsLink"],
  ",",
  ButtonBox["Tagging sets",
    ButtonData:>{"Tagging sets", "Obsolete"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " Separate",
  ", ",
  ButtonBox["Tagging sets",
    ButtonData:>{"Tagging sets", "Combine"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " SetPartition",
  ", ",
  ButtonBox["Set partitions",
    ButtonData:>{"Set partitions", "SetPartition"},
    ButtonStyle->"AddOnsLink"]
}], "IndexSubentry",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Obsolete"],

Cell[TextData[{
  "Offspring",
  ",",
  " ",
  ButtonBox["Describing individuals",
    ButtonData:>{"Describing individuals", "Offspring"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Offspring"],

Cell[TextData[{
  "Ordered",
  ",",
  "option for PartitionSet",
  ", ",
  ButtonBox["Set partitions",
    ButtonData:>{"Set partitions", "Ordered"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Ordered"],

Cell[TextData[{
  "Orive & Barton 1999",
  ",",
  " ",
  ButtonBox["References",
    ButtonData:>{"References", "Orive & Barton 1999"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Orive & Barton 1999"],

Cell[TextData[{
  "OtherSex",
  ",",
  " ",
  ButtonBox["Genes and contexts",
    ButtonData:>{"Genes and contexts", "OtherSex"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"OtherSex"],

Cell[TextData[{
  "Packages",
  ",",
  " help",
  ", ",
  ButtonBox["How the Help Browser works",
    ButtonData:>{"How the Help Browser works", "Packages"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Packages"],

Cell[TextData[{
  " overview of",
  ", ",
  ButtonBox["Overview of the packages",
    ButtonData:>{"Overview of the packages", None},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " saving using PackageSaver",
  ", ",
  ButtonBox["Bugs",
    ButtonData:>{"Bugs", "Special notation"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " setting up",
  ", ",
  ButtonBox["Setting up the packages",
    ButtonData:>{"Setting up the packages", "Setting up the packages"},
    ButtonStyle->"AddOnsLink"],
  ",",
  ButtonBox["Special notation",
    ButtonData:>{"Special notation", "Setting up packages"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " versions of",
  ", ",
  ButtonBox["Versions",
    ButtonData:>{"Versions", None},
    ButtonStyle->"AddOnsLink"]
}], "IndexSubentry",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Packages"],

Cell[TextData[{
  "PackageSaver",
  ",",
  " ",
  ButtonBox["Bugs",
    ButtonData:>{"Bugs", "Special notation"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"PackageSaver"],

Cell[TextData[{
  "ParentalGenotypes",
  ",",
  " ",
  ButtonBox["Inferring parents",
    ButtonData:>{"Inferring parents", "ParentalGenotypes"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"ParentalGenotypes"],

Cell[TextData[{
  "Partitions",
  ",",
  " of sets",
  ", ",
  ButtonBox["Set partitions",
    ButtonData:>{"Set partitions", "PartitionSet"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Partitions"],

Cell[TextData[{
  " standard form",
  ", ",
  ButtonBox["Set partitions",
    ButtonData:>{"Set partitions", "StandardPartition"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " testing for standard form",
  ", ",
  ButtonBox["Set partitions",
    ButtonData:>{"Set partitions", "StandardPartitionQ"},
    ButtonStyle->"AddOnsLink"]
}], "IndexSubentry",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Partitions"],

Cell[TextData[{
  "PartitionSet",
  ",",
  " ",
  ButtonBox["Set partitions",
    ButtonData:>{"Set partitions", "PartitionSet"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"PartitionSet"],

Cell[TextData[{
  "Paternal inheritance",
  ",",
  " ",
  ButtonBox["Non-Mendelian inheritance",
    ButtonData:>{"Non-Mendelian inheritance", "PaternalLoci"},
    ButtonStyle->"AddOnsLink"],
  ",",
  ButtonBox["Reference points",
    ButtonData:>{"Reference points", "PaternalLoci"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Paternal inheritance"],

Cell[TextData[{
  "PaternalLoci",
  ",",
  " example of",
  ", ",
  ButtonBox["Cytoplasmic inheritance",
    ButtonData:>{"Cytoplasmic inheritance", None},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"PaternalLoci"],

Cell[TextData[{
  " option for NonMendelian",
  ", ",
  ButtonBox["Non-Mendelian inheritance",
    ButtonData:>{"Non-Mendelian inheritance", "PaternalLoci"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " reference points",
  ", ",
  ButtonBox["Reference points",
    ButtonData:>{"Reference points", "PaternalLoci"},
    ButtonStyle->"AddOnsLink"]
}], "IndexSubentry",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"PaternalLoci"],

Cell[TextData[{
  "PatternFree",
  ",",
  " ",
  ButtonBox["Flattening lists by pattern",
    ButtonData:>{"Flattening lists by pattern", "PatternFree"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"PatternFree"],

Cell[TextData[{
  "Permutations",
  ",",
  "option for PartitionSet",
  ", ",
  ButtonBox["Set partitions",
    ButtonData:>{"Set partitions", "Permutations"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Permutations"],

Cell[TextData[{
  "Permutations in defining coefficients",
  ",",
  " Kirkpatrick et al.",
  ", ",
  ButtonBox["Multilocus MS",
    ButtonData:>{"Multilocus MS", "Permutations"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Permutations in defining coefficients"],

Cell[TextData[{
  "Phenotypes",
  ",",
  " Kirkpatrick et al.",
  ", ",
  ButtonBox["Multilocus MS",
    ButtonData:>{"Multilocus MS", "Phenotypes"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Phenotypes"],

Cell[TextData[{
  "Phipps & Brill 1995",
  ",",
  " ",
  ButtonBox["References",
    ButtonData:>{"References", "Phipps & Brill 1995"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Phipps & Brill 1995"],

Cell[TextData[{
  "Ploidy",
  ",",
  " ",
  ButtonBox["Describing a dataset",
    ButtonData:>{"Describing a dataset", "Ploidy"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Ploidy"],

Cell[TextData[{
  "PloidyWeightList",
  ",",
  " ",
  ButtonBox["Internal functions",
    ButtonData:>{"Internal functions", "PloidyWeightList"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"PloidyWeightList"],

Cell[TextData[{
  "PlotGenealogy",
  ",",
  " ",
  ButtonBox["Plotting genealogies",
    ButtonData:>{"Plotting genealogies", "PlotGenealogy"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"PlotGenealogy"],

Cell[TextData[{
  "PlotLogL",
  ",",
  " ",
  ButtonBox["Presenting results",
    ButtonData:>{"Presenting results", "PlotLogL"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"PlotLogL"],

Cell[TextData[{
  "PlotSegments",
  ",",
  " of ancestral graphs",
  ", ",
  ButtonBox["Plotting ancestral graphs",
    ButtonData:>{"Plotting ancestral graphs", "PlotSegments"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"PlotSegments"],

Cell[TextData[{
  "Plotting",
  ",",
  " ancestral graphs",
  ", ",
  ButtonBox["Plotting ancestral graphs",
    ButtonData:>{"Plotting ancestral graphs", None},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Plotting"],

Cell[TextData[{
  "PopulationDisequilibrium",
  ",",
  "\[GothicCapitalC], \[AliasIndicator]goC\[AliasIndicator]",
  ", ",
  ButtonBox["Expectations",
    ButtonData:>{"Expectations", "PopulationDisequilibrium"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"PopulationDisequilibrium"],

Cell[TextData[{
  "PopulationExpectation",
  ",",
  " ",
  ButtonBox["Expectations",
    ButtonData:>{"Expectations", "PopulationExpectation"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"PopulationExpectation"],

Cell[TextData[{
  " multiple arguments",
  ", ",
  ButtonBox["Expectations",
    ButtonData:>{"Expectations", "multiple arguments"},
    ButtonStyle->"AddOnsLink"]
}], "IndexSubentry",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"PopulationExpectation"],

Cell[TextData[{
  "PopulationRepresentations",
  ",",
  " ",
  ButtonBox["Overview of numerical models",
    ButtonData:>{"Overview of numerical models", "PopulationRepresentations"},
    
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"PopulationRepresentations"],

Cell[TextData[{
  "Position",
  ",",
  " ",
  ButtonBox["Genes and contexts",
    ButtonData:>{"Genes and contexts", "position"},
    ButtonStyle->"AddOnsLink"],
  ",",
  ButtonBox["Multilocus MS relation",
    ButtonData:>{"Multilocus MS relation", "position"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Position"],

Cell[TextData[{
  " as used in Kirkpatrick et al.",
  ", ",
  ButtonBox["Multilocus MS relation",
    ButtonData:>{"Multilocus MS relation", "position"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " Kirkpatrick et al.",
  ", ",
  ButtonBox["Multilocus MS",
    ButtonData:>{"Multilocus MS", "Contexts and positions"},
    ButtonStyle->"AddOnsLink"]
}], "IndexSubentry",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Position"],

Cell[TextData[{
  "PositionsList",
  ",",
  " ",
  ButtonBox["Full diploid genotypes",
    ButtonData:>{"Full diploid genotypes", "PositionsList"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"PositionsList"],

Cell[TextData[{
  "PositionsMatrix",
  ",",
  " ",
  ButtonBox["Full diploid genotypes",
    ButtonData:>{"Full diploid genotypes", "PositionsMatrix"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"PositionsMatrix"],

Cell[TextData[{
  "PossibleCoalescenceOrder",
  ",",
  " ",
  ButtonBox["Finding possible orders",
    ButtonData:>{"Finding possible orders", "PossibleCoalescenceOrder"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"PossibleCoalescenceOrder"],

Cell[TextData[{
  "PossibleDiploidGenotypes",
  ",",
  " ",
  ButtonBox["Full diploid genotypes",
    ButtonData:>{"Full diploid genotypes", "PossibleDiploidGenotypes"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"PossibleDiploidGenotypes"],

Cell[TextData[{
  "PossibleGenotypes",
  ",",
  " ",
  ButtonBox["Diploid genotypes",
    ButtonData:>{"Diploid genotypes", "PossibleGenotypes"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"PossibleGenotypes"],

Cell[TextData[{
  "PossibleRootings",
  ",",
  " ",
  ButtonBox["Rooting a genealogy",
    ButtonData:>{"Rooting a genealogy", "PossibleRootings"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"PossibleRootings"],

Cell[TextData[{
  "PowerF",
  ",",
  " for allele frequencies",
  ", ",
  ButtonBox["Allele frequencies: iterating one deme",
    ButtonData:>{"Allele frequencies: iterating one deme", "PowerF"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"PowerF"],

Cell[TextData[{
  " for genotype frequencies",
  ", ",
  ButtonBox["Recursions: iterating one deme",
    ButtonData:>{"Recursions: iterating one deme", "PowerF"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " for individuals",
  ", ",
  ButtonBox["Simulating individuals: iterating one deme",
    ButtonData:>{"Simulating individuals: iterating one deme", "PowerF"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " for symmetric model",
  ", ",
  ButtonBox["Symmetric model: iterating one deme",
    ButtonData:>{"Symmetric model: iterating one deme", "PowerF"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " with individuals",
  ", ",
  ButtonBox["Simulating individuals: reproduction",
    ButtonData:>{"Simulating individuals: reproduction", "PowerF"},
    ButtonStyle->"AddOnsLink"]
}], "IndexSubentry",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"PowerF"],

Cell[TextData[{
  "PresentOneWayTable",
  ",",
  " ",
  ButtonBox["Single-locus tables",
    ButtonData:>{"Single-locus tables", "PresentOneWayTable"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"PresentOneWayTable"],

Cell[TextData[{
  "PresentPairwiseTable",
  ",",
  " ",
  ButtonBox["Pairwise tables",
    ButtonData:>{"Pairwise tables", "PresentPairwiseTable"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"PresentPairwiseTable"],

Cell[TextData[{
  "PresentResults",
  ",",
  " ",
  ButtonBox["Presenting results",
    ButtonData:>{"Presenting results", "PresentResults"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"PresentResults"],

Cell[TextData[{
  "Principal components",
  ",",
  " Bennett's measure of disequilibrium",
  ", ",
  ButtonBox["Alternative measures",
    ButtonData:>{"Alternative measures", "Bennett"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Principal components"],

Cell[TextData[{
  "PrintDetails",
  ",",
  " ",
  ButtonBox["Options for StructuredMLE",
    ButtonData:>{"Options for StructuredMLE", "PrintDetails"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"PrintDetails"],

Cell[TextData[{
  " option for RandomGenealogy",
  ", ",
  ButtonBox["Random ancestral graphs",
    ButtonData:>{"Random ancestral graphs", 
      "PrintDetails, option for RandomGenealogy"},
    ButtonStyle->"AddOnsLink"]
}], "IndexSubentry",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"PrintDetails"],

Cell[TextData[{
  "Problems",
  ",",
  " avoid integers",
  ", ",
  ButtonBox["Potential problems",
    ButtonData:>{"Potential problems", "Avoid integers"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Problems"],

Cell[TextData[{
  " redefining fitness",
  ", ",
  ButtonBox["Potential problems",
    ButtonData:>{"Potential problems", "Allele frequencies"},
    ButtonStyle->"AddOnsLink"],
  ",",
  ButtonBox["Potential problems",
    ButtonData:>{"Potential problems", "Redefining fitness"},
    ButtonStyle->"AddOnsLink"],
  ",",
  ButtonBox["Symmetric model: iterating one deme",
    ButtonData:>{"Symmetric model: iterating one deme", 
      "StoreResults (compiling)"},
    ButtonStyle->"AddOnsLink"]
}], "IndexSubentry",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Problems"],

Cell[TextData[{
  "Products",
  ",",
  " multiple",
  ", ",
  ButtonBox["TimesUp",
    ButtonData:>{"TimesUp", "Multiple products"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Products"],

Cell[TextData[{
  "ProductSum",
  ",",
  " ",
  ButtonBox["ProductSum",
    ButtonData:>{"ProductSum", "ProductSum"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"ProductSum"],

Cell[TextData[{
  " over sets",
  ", ",
  ButtonBox["ProductSum",
    ButtonData:>{"ProductSum", "ProductSum over sets"},
    ButtonStyle->"AddOnsLink"]
}], "IndexSubentry",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"ProductSum"],

Cell[TextData[{
  "QLE",
  ",",
  " haploid selection example",
  ", ",
  ButtonBox["Haploid selection",
    ButtonData:>{"Haploid selection", "QLE"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"QLE"],

Cell[TextData[{
  " Kirkpatrick et al.",
  ", ",
  ButtonBox["Multilocus MS",
    ButtonData:>{"Multilocus MS", "The QLE approximation"},
    ButtonStyle->"AddOnsLink"]
}], "IndexSubentry",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"QLE"],

Cell[TextData[{
  "Quasi-linkage equilibrium",
  ",",
  " Kirkpatrick et al.",
  ", ",
  ButtonBox["Multilocus MS",
    ButtonData:>{"Multilocus MS", "The QLE approximation"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Quasi-linkage equilibrium"],

Cell[TextData[{
  "RandomBottleneckedGenealogy",
  ",",
  " ",
  ButtonBox["Population bottlenecks",
    ButtonData:>{"Population bottlenecks", "RandomBottleneckedGenealogy"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"RandomBottleneckedGenealogy"],

Cell[TextData[{
  "RandomCoalescenceOrder",
  ",",
  " ",
  ButtonBox["Finding possible orders",
    ButtonData:>{"Finding possible orders", "RandomCoalescenceOrder"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"RandomCoalescenceOrder"],

Cell[TextData[{
  "RandomCoalescenceTimes",
  ",",
  " ",
  ButtonBox["Distribution of coalescence times",
    ButtonData:>{"Distribution of coalescence times", 
      "RandomCoalescenceTimes"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"RandomCoalescenceTimes"],

Cell[TextData[{
  " for ancestral graphs",
  ", ",
  ButtonBox["Random ancestral graphs",
    ButtonData:>{"Random ancestral graphs", "RandomCoalescenceTimes"},
    ButtonStyle->"AddOnsLink"]
}], "IndexSubentry",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"RandomCoalescenceTimes"],

Cell[TextData[{
  "RandomCum",
  ",",
  " ",
  ButtonBox["Sampling from arbitrary distributions",
    ButtonData:>{"Sampling from arbitrary distributions", "RandomCum"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"RandomCum"],

Cell[TextData[{
  "Random drift",
  ",",
  " changing reference points",
  ", ",
  ButtonBox["Introduction to random drift",
    ButtonData:>{"Introduction to random drift", "Changing reference points"},
    
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Random drift"],

Cell[TextData[{
  " cumulants and moments",
  ", ",
  ButtonBox["Introduction to random drift",
    ButtonData:>{"Introduction to random drift", "Cumulants and moments"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " describing a distribution",
  ", ",
  ButtonBox["Introduction to random drift",
    ButtonData:>{"Introduction to random drift", "Describing a distribution"},
    
    ButtonStyle->"AddOnsLink"],
  "\n",
  " equations for the moments",
  ", ",
  ButtonBox["Introduction to random drift",
    ButtonData:>{"Introduction to random drift", "Equations for the moments"},
    
    ButtonStyle->"AddOnsLink"],
  "\n",
  " in a cline",
  ", ",
  ButtonBox["Allele frequencies: iterating a cline",
    ButtonData:>{"Allele frequencies: iterating a cline", "RandomDrift"},
    ButtonStyle->"AddOnsLink"],
  ",",
  ButtonBox["Recursions: iterating a cline",
    ButtonData:>{"Recursions: iterating a cline", "RandomDrift"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " of allele frequencies",
  ", ",
  ButtonBox["Allele frequencies: drift",
    ButtonData:>{"Allele frequencies: drift", None},
    ButtonStyle->"AddOnsLink"],
  ",",
  ButtonBox["Allele frequencies: iterating one deme",
    ButtonData:>{"Allele frequencies: iterating one deme", "RandomDrift"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " of genotype frequencies",
  ", ",
  ButtonBox["Recursions: drift",
    ButtonData:>{"Recursions: drift", None},
    ButtonStyle->"AddOnsLink"],
  ",",
  ButtonBox["Recursions: iterating one deme",
    ButtonData:>{"Recursions: iterating one deme", "RandomDrift"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " population disequilibrium",
  ", ",
  ButtonBox["Expectations",
    ButtonData:>{"Expectations", "PopulationDisequilibrium"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " population expectation",
  ", ",
  ButtonBox["Expectations",
    ButtonData:>{"Expectations", "PopulationExpectation"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " population expectations",
  ", ",
  ButtonBox["Expectations",
    ButtonData:>{"Expectations", None},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " Wright-Fisher sampling",
  ", ",
  ButtonBox["Wright-Fisher sampling",
    ButtonData:>{"Wright-Fisher sampling", None},
    ButtonStyle->"AddOnsLink"]
}], "IndexSubentry",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Random drift"],

Cell[TextData[{
  "RandomDrift",
  ",",
  " for genotype frequencies",
  ", ",
  ButtonBox["Recursions: drift",
    ButtonData:>{"Recursions: drift", "RandomDrift"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"RandomDrift"],

Cell[TextData[{
  " option for IterateExact",
  ", ",
  ButtonBox["Allele frequencies: iterating a cline",
    ButtonData:>{"Allele frequencies: iterating a cline", "RandomDrift"},
    ButtonStyle->"AddOnsLink"],
  ",",
  ButtonBox["Allele frequencies: iterating one deme",
    ButtonData:>{"Allele frequencies: iterating one deme", "RandomDrift"},
    ButtonStyle->"AddOnsLink"],
  ",",
  ButtonBox["Recursions: iterating a cline",
    ButtonData:>{"Recursions: iterating a cline", "RandomDrift"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " option for NewGametes",
  ", ",
  ButtonBox["Allele frequencies:reproduction",
    ButtonData:>{"Allele frequencies:reproduction", "RandomDrift"},
    ButtonStyle->"AddOnsLink"],
  ",",
  ButtonBox["Recursions:reproduction",
    ButtonData:>{"Recursions:reproduction", "RandomDrift"},
    ButtonStyle->"AddOnsLink"]
}], "IndexSubentry",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"RandomDrift"],

Cell[TextData[{
  "RandomFamilies",
  ",",
  " ",
  ButtonBox["Random families",
    ButtonData:>{"Random families", "RandomFamilies"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"RandomFamilies"],

Cell[TextData[{
  "RandomFamily",
  ",",
  " ",
  ButtonBox["Generating families",
    ButtonData:>{"Generating families", "RandomFamily"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"RandomFamily"],

Cell[TextData[{
  " segregation ratio",
  ", ",
  ButtonBox["Generating families",
    ButtonData:>{"Generating families", "SegregationRatio"},
    ButtonStyle->"AddOnsLink"]
}], "IndexSubentry",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"RandomFamily"],

Cell[TextData[{
  "Random genealogies",
  ",",
  " population bottlenecks",
  ", ",
  ButtonBox["Population bottlenecks",
    ButtonData:>{"Population bottlenecks", None},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Random genealogies"],

Cell[TextData[{
  "RandomGenealogy",
  ",",
  " ",
  ButtonBox["Drawing a genealogy",
    ButtonData:>{"Drawing a genealogy", "RandomGenealogy"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"RandomGenealogy"],

Cell[TextData[{
  " for ancestral graphs",
  ", ",
  ButtonBox["Random ancestral graphs",
    ButtonData:>{"Random ancestral graphs", "RandomGenealogy"},
    ButtonStyle->"AddOnsLink"]
}], "IndexSubentry",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"RandomGenealogy"],

Cell[TextData[{
  "RandomList",
  ",",
  " ",
  ButtonBox["Random lists",
    ButtonData:>{"Random lists", "RandomList"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"RandomList"],

Cell[TextData[{
  " sampling without replacement",
  ", ",
  ButtonBox["Random lists",
    ButtonData:>{"Random lists", "Replace"},
    ButtonStyle->"AddOnsLink"]
}], "IndexSubentry",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"RandomList"],

Cell[TextData[{
  "Random lists",
  ",",
  " compiled",
  ", ",
  ButtonBox["Random lists",
    ButtonData:>{"Random lists", "Compiled"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Random lists"],

Cell[TextData[{
  "RandomMating",
  ",",
  " ",
  ButtonBox["Recombination in admixture models",
    ButtonData:>{"Recombination in admixture models", "RandomMating"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"RandomMating"],

Cell[TextData[{
  "RandomMultinomial",
  ",",
  " ",
  ButtonBox["Multinomial distribution",
    ButtonData:>{"Multinomial distribution", "RandomMultinomial"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"RandomMultinomial"],

Cell[TextData[{
  "RandomPreviousFamily",
  ",",
  " ",
  ButtonBox["Random families",
    ButtonData:>{"Random families", "RandomPreviousFamily"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"RandomPreviousFamily"],

Cell[TextData[{
  "Random sampling",
  ",",
  " ",
  ButtonBox["Introduction to random drift",
    ButtonData:>{"Introduction to random drift", "Random sampling"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Random sampling"],

Cell[TextData[{
  " example in estimating D",
  ", ",
  ButtonBox["Sampling example",
    ButtonData:>{"Sampling example", None},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " of genealogies",
  ", ",
  ButtonBox["Sampling genealogies",
    ButtonData:>{"Sampling genealogies", None},
    ButtonStyle->"AddOnsLink"]
}], "IndexSubentry",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Random sampling"],

Cell[TextData[{
  "RandomSet",
  ",",
  " ",
  ButtonBox["Random sets",
    ButtonData:>{"Random sets", "RandomSet"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"RandomSet"],

Cell[TextData[{
  "Random union",
  ",",
  " ",
  ButtonBox["Random union",
    ButtonData:>{"Random union", "RandomUnion"},
    ButtonStyle->"AddOnsLink"],
  ",",
  ButtonBox["Sexual selection",
    ButtonData:>{"Sexual selection", "Random union"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Random union"],

Cell[TextData[{
  " in admixture models",
  ", ",
  ButtonBox["Recombination in admixture models",
    ButtonData:>{"Recombination in admixture models", "RandomUnionObsolete"},
    ButtonStyle->"AddOnsLink"]
}], "IndexSubentry",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Random union"],

Cell[TextData[{
  "RandomUnion",
  ",",
  " ",
  ButtonBox["Random union",
    ButtonData:>{"Random union", "RandomUnion"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"RandomUnion"],

Cell[TextData[{
  "RandomUnionMethod",
  ",",
  " ",
  ButtonBox["Options for DoReplicates",
    ButtonData:>{"Options for DoReplicates", "MethodC"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"RandomUnionMethod"],

Cell[TextData[{
  "RandomUnionObsolete",
  ",",
  " ",
  ButtonBox["Random union",
    ButtonData:>{"Random union", "RandomUnion"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"RandomUnionObsolete"],

Cell[TextData[{
  "Random walk",
  ",",
  " in estimating D",
  ", ",
  ButtonBox["Random walk",
    ButtonData:>{"Random walk", None},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Random walk"],

Cell[TextData[{
  "RecombinantLineages",
  ",",
  " in ancestral graphs",
  ", ",
  ButtonBox["Describing ancestral graphs",
    ButtonData:>{"Describing ancestral graphs", "RecombinantLineages"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"RecombinantLineages"],

Cell[TextData[{
  "Recombination",
  ",",
  " ",
  ButtonBox["Recombination",
    ButtonData:>{"Recombination", "Recombination"},
    ButtonStyle->"AddOnsLink"],
  ",",
  ButtonBox["Sexual selection",
    ButtonData:>{"Sexual selection", "Recombination"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Recombination"],

Cell[TextData[{
  " across several linked loci",
  ", ",
  ButtonBox["Recombination",
    ButtonData:>{"Recombination", "NetRecombination"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " between linked loci",
  ", ",
  ButtonBox["Recombination",
    ButtonData:>{"Recombination", "LinkedRecombination"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " context-dependent",
  ", ",
  ButtonBox["Recombination",
    ButtonData:>{"Recombination", "Context-dependent recombination"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " genotype-dependent",
  ", ",
  ButtonBox["Recombination",
    ButtonData:>{"Recombination", "Genotype-dependent recombination"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " in admixture models",
  ", ",
  ButtonBox["Recombination in admixture models",
    ButtonData:>{"Recombination in admixture models", "Recombined"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " no linkage",
  ", ",
  ButtonBox["Recombination",
    ButtonData:>{"Recombination", "UnlinkedRecombination"},
    ButtonStyle->"AddOnsLink"]
}], "IndexSubentry",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Recombination"],

Cell[TextData[{
  "RecombinationEvents",
  ",",
  " in ancestral graphs",
  ", ",
  ButtonBox["Describing ancestral graphs",
    ButtonData:>{"Describing ancestral graphs", "RecombinationEvents"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"RecombinationEvents"],

Cell[TextData[{
  "RecombinationRate",
  ",",
  " \[GothicR], \[AliasIndicator]gor\[AliasIndicator]",
  ", ",
  ButtonBox["Recombination",
    ButtonData:>{"Recombination", "RecombinationRate"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"RecombinationRate"],

Cell[TextData[{
  "RecombinationSet",
  ",",
  " \[DoubleStruckCapitalR], \[AliasIndicator]dsR\[AliasIndicator]",
  ", ",
  ButtonBox["Notation reference",
    ButtonData:>{"Notation reference", None},
    ButtonStyle->"AddOnsLink"],
  ",",
  ButtonBox["Recombination",
    ButtonData:>{"Recombination", "RecombinationSet"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"RecombinationSet"],

Cell[TextData[{
  "Recombined",
  ",",
  " ",
  ButtonBox["Recombination in admixture models",
    ButtonData:>{"Recombination in admixture models", "Recombined"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Recombined"],

Cell[TextData[{
  "RecombineLineage",
  ",",
  " ",
  ButtonBox["Coalescence and recombination",
    ButtonData:>{"Coalescence and recombination", "RecombineLineage"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"RecombineLineage"],

Cell[TextData[{
  "ReducedData",
  ",",
  " ",
  ButtonBox["Simplifying a dataset",
    ButtonData:>{"Simplifying a dataset", "ReducedData"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"ReducedData"],

Cell[TextData[{
  "ReferencePoint",
  ",",
  " \[WeierstrassP], \[AliasIndicator]wp\[AliasIndicator]",
  ", ",
  ButtonBox["Allelic state",
    ButtonData:>{"Allelic state", "ReferencePoint"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"ReferencePoint"],

Cell[TextData[{
  "ReferencePointMean",
  ",",
  " ",
  ButtonBox["Reference points",
    ButtonData:>{"Reference points", "ReferencePointMean"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"ReferencePointMean"],

Cell[TextData[{
  " cytoplasmic inheritance",
  ", ",
  ButtonBox["Cytoplasmic inheritance",
    ButtonData:>{"Cytoplasmic inheritance", "ReferencePointMean"},
    ButtonStyle->"AddOnsLink"],
  ",",
  ButtonBox["Reference points",
    ButtonData:>{"Reference points", "CytoplasmicLoci"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " paternal inheritance",
  ", ",
  ButtonBox["Cytoplasmic inheritance",
    ButtonData:>{"Cytoplasmic inheritance", "ReferencePointMean"},
    ButtonStyle->"AddOnsLink"],
  ",",
  ButtonBox["Reference points",
    ButtonData:>{"Reference points", "PaternalLoci"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " sex-linkage",
  ", ",
  ButtonBox["Reference points",
    ButtonData:>{"Reference points", "XLinkedLoci"},
    ButtonStyle->"AddOnsLink"],
  ",",
  ButtonBox["Reference points",
    ButtonData:>{"Reference points", "ZLinkedLoci"},
    ButtonStyle->"AddOnsLink"],
  ",",
  ButtonBox["Sex linkage",
    ButtonData:>{"Sex linkage", "ReferencePointMean"},
    ButtonStyle->"AddOnsLink"]
}], "IndexSubentry",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"ReferencePointMean"],

Cell[TextData[{
  "ReferencePointSame",
  ",",
  " ",
  ButtonBox["Reference points",
    ButtonData:>{"Reference points", "ReferencePointSame"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"ReferencePointSame"],

Cell[TextData[{
  "ReferencePointZero",
  ",",
  " ",
  ButtonBox["Reference points",
    ButtonData:>{"Reference points", "ReferencePointZero"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"ReferencePointZero"],

Cell[TextData[{
  "References",
  ",",
  " for ancestral graphs",
  ", ",
  ButtonBox["Ancestral graph references",
    ButtonData:>{"Ancestral graph references", None},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"References"],

Cell[TextData[{
  "Reference values",
  ",",
  " ",
  ButtonBox["Allelic state",
    ButtonData:>{"Allelic state", "ReferencePoint"},
    ButtonStyle->"AddOnsLink"],
  ",",
  ButtonBox["Multilocus MS relation",
    ButtonData:>{"Multilocus MS relation", "Reference values"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Reference values"],

Cell[TextData[{
  " as used in Kirkpatrick et al.",
  ", ",
  ButtonBox["Multilocus MS relation",
    ButtonData:>{"Multilocus MS relation", "Reference values"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " Kirkpatrick et al.",
  ", ",
  ButtonBox["Multilocus MS",
    ButtonData:>{"Multilocus MS", "Describing genotypes and populations"},
    ButtonStyle->"AddOnsLink"]
}], "IndexSubentry",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Reference values"],

Cell[TextData[{
  "RemoveTag",
  ",",
  " ",
  ButtonBox["Tagging sets",
    ButtonData:>{"Tagging sets", "RemoveTag"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"RemoveTag"],

Cell[TextData[{
  "Repeat",
  ",",
  " ",
  ButtonBox["Repeated elements",
    ButtonData:>{"Repeated elements", "Repeat"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Repeat"],

Cell[TextData[{
  "Replace",
  ",",
  " ",
  ButtonBox["Random lists",
    ButtonData:>{"Random lists", "Replace"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Replace"],

Cell[TextData[{
  "ReplaceAllSpecial",
  ",",
  " |.",
  ", ",
  ButtonBox["|., ||.",
    ButtonData:>{"|., ||.", "ReplaceAllSpecial"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"ReplaceAllSpecial"],

Cell[TextData[{
  "ReplaceRepeatedSpecial",
  ",",
  " ||.",
  ", ",
  ButtonBox["|., ||.",
    ButtonData:>{"|., ||.", "ReplaceRepeatedSpecial"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"ReplaceRepeatedSpecial"],

Cell[TextData[{
  "Representations",
  ",",
  " converting between",
  ", ",
  ButtonBox["Simulating individuals:converting",
    ButtonData:>{"Simulating individuals:converting", None},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Representations"],

Cell[TextData[{
  "of populations",
  ", ",
  ButtonBox["Overview of numerical models",
    ButtonData:>{"Overview of numerical models", 
      "Representing the population"},
    ButtonStyle->"AddOnsLink"]
}], "IndexSubentry",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Representations"],

Cell[TextData[{
  "Reproduction",
  ",",
  " in numerical models",
  ", ",
  ButtonBox["Recursions:reproduction",
    ButtonData:>{"Recursions:reproduction", None},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Reproduction"],

Cell[TextData[{
  "Reverse",
  ",",
  " ",
  ButtonBox["Sorting",
    ButtonData:>{"Sorting", "Reverse"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Reverse"],

Cell[TextData[{
  "Root",
  ",",
  " of a genealogy",
  ", ",
  ButtonBox["Rooting a genealogy",
    ButtonData:>{"Rooting a genealogy", None},
    ButtonStyle->"AddOnsLink"],
  ",",
  ButtonBox["Structure of genealogies",
    ButtonData:>{"Structure of genealogies", "RootedGenealogy"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Root"],

Cell[TextData[{
  "RootedGenealogy",
  ",",
  " ",
  ButtonBox["Structure of genealogies",
    ButtonData:>{"Structure of genealogies", "RootedGenealogy"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"RootedGenealogy"],

Cell[TextData[{
  "RootEvents",
  ",",
  " in ancestral graphs",
  ", ",
  ButtonBox["Describing ancestral graphs",
    ButtonData:>{"Describing ancestral graphs", "RootEvents"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"RootEvents"],

Cell[TextData[{
  "Rootings",
  ",",
  " of a genealogy, possible",
  ", ",
  ButtonBox["Rooting a genealogy",
    ButtonData:>{"Rooting a genealogy", "PossibleRootings"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Rootings"],

Cell[TextData[{
  "Rules",
  ",",
  " ",
  ButtonBox["Stabilising selection",
    ButtonData:>{"Stabilising selection", "Rules"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Rules"],

Cell[TextData[{
  " non-evaluation of",
  ", ",
  ButtonBox["Bugs",
    ButtonData:>{"Bugs", "Applying rules"},
    ButtonStyle->"AddOnsLink"]
}], "IndexSubentry",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Rules"],

Cell[TextData[{
  "SampleCovariance",
  ",",
  " ",
  ButtonBox["Sampling",
    ButtonData:>{"Sampling", "SampleCovariance"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"SampleCovariance"],

Cell[TextData[{
  "SampleIndividuals",
  ",",
  " ",
  ButtonBox["Sampling individuals",
    ButtonData:>{"Sampling individuals", "SampleIndividuals"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"SampleIndividuals"],

Cell[TextData[{
  "SamplePartition",
  ",",
  " ",
  ButtonBox["Set partitions",
    ButtonData:>{"Set partitions", "SamplePartition"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"SamplePartition"],

Cell[TextData[{
  "Sampling",
  ",",
  " without replacement",
  ", ",
  ButtonBox["Random lists",
    ButtonData:>{"Random lists", "Replace"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Sampling"],

Cell[TextData[{
  "Scripts and faces",
  ",",
  " as used in Kirkpatrick et al.",
  ", ",
  ButtonBox["Multilocus MS relation",
    ButtonData:>{"Multilocus MS relation", "Scripts and faces"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Scripts and faces"],

Cell[TextData[{
  "Segments",
  ",",
  " in ancestral graphs",
  ", ",
  ButtonBox["Describing ancestral graphs",
    ButtonData:>{"Describing ancestral graphs", "Segments"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Segments"],

Cell[TextData[{
  "SegmentStyle",
  ",",
  " option for PlotSegments",
  ", ",
  ButtonBox["Plotting ancestral graphs",
    ButtonData:>{"Plotting ancestral graphs", "SegmentStyle"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"SegmentStyle"],

Cell[TextData[{
  "SegregationRatio",
  ",",
  " ",
  ButtonBox["Generating families",
    ButtonData:>{"Generating families", "SegregationRatio"},
    ButtonStyle->"AddOnsLink"],
  ",",
  ButtonBox["Genotype probabilities",
    ButtonData:>{"Genotype probabilities", "SegregationRatio"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"SegregationRatio"],

Cell[TextData[{
  "SelectContext",
  ",",
  " \[CircleDot], \[AliasIndicator]c.\[AliasIndicator]",
  ", ",
  ButtonBox["Selecting contexts",
    ButtonData:>{"Selecting contexts", "SelectContexts"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"SelectContext"],

Cell[TextData[{
  "SelectIndividuals",
  ",",
  " ",
  ButtonBox["Selecting subsets",
    ButtonData:>{"Selecting subsets", "SelectIndividuals"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"SelectIndividuals"],

Cell[TextData[{
  "Selection",
  ",",
  " ",
  ButtonBox["Selection",
    ButtonData:>{"Selection", "Selection"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Selection"],

Cell[TextData[{
  " in symmetric model",
  ", ",
  ButtonBox["Symmetric model: fitnesses",
    ButtonData:>{"Symmetric model: fitnesses", "SelectionExact"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " Kirkpatrick et al.",
  ", ",
  ButtonBox["Multilocus MS",
    ButtonData:>{"Multilocus MS", "Phenotypes"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " on allele frequencies",
  ", ",
  ButtonBox["Allele frequencies: fitnesses",
    ButtonData:>{"Allele frequencies: fitnesses", None},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " on genotype frequencies",
  ", ",
  ButtonBox["Recursions: fitnesses",
    ButtonData:>{"Recursions: fitnesses", None},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " on multiple alleles",
  ", ",
  ButtonBox["Selection",
    ButtonData:>{"Selection", "Multiple alleles"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " technicalities",
  ", ",
  ButtonBox["Selection",
    ButtonData:>{"Selection", "Technicalities"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " truncation",
  ", ",
  ButtonBox["Simulating individuals: fitnesses",
    ButtonData:>{"Simulating individuals: fitnesses", "TruncationSelection"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " with individuals",
  ", ",
  ButtonBox["Simulating individuals: fitnesses",
    ButtonData:>{"Simulating individuals: fitnesses", "SelectionExact"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " with two alleles",
  ", ",
  ButtonBox["Fitness",
    ButtonData:>{"Fitness", "Two alleles"},
    ButtonStyle->"AddOnsLink"],
  ",",
  ButtonBox["Phenotypes",
    ButtonData:>{"Phenotypes", "Two alleles"},
    ButtonStyle->"AddOnsLink"]
}], "IndexSubentry",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Selection"],

Cell[TextData[{
  "SelectionCoefficient",
  ",",
  " \[GothicA], \[AliasIndicator]goa\[AliasIndicator]",
  ", ",
  ButtonBox["Fitness",
    ButtonData:>{"Fitness", "SelectionCoefficient"},
    ButtonStyle->"AddOnsLink"],
  ",",
  ButtonBox["Selection",
    ButtonData:>{"Selection", "SelectionCoefficient"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"SelectionCoefficient"],

Cell[TextData[{
  "Selection coefficients",
  ",",
  " as defined in Kirkpatrick et al.",
  ", ",
  ButtonBox["Multilocus MS relation",
    ButtonData:>{"Multilocus MS relation", "Permutations"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Selection coefficients"],

Cell[TextData[{
  " making",
  ", ",
  ButtonBox["Phenotypes",
    ButtonData:>{"Phenotypes", "Multiple alleles"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " with multiple alleles",
  ", ",
  ButtonBox["Fitness",
    ButtonData:>{"Fitness", "Multiple alleles"},
    ButtonStyle->"AddOnsLink"],
  ",",
  ButtonBox["Phenotypes",
    ButtonData:>{"Phenotypes", "Multiple alleles"},
    ButtonStyle->"AddOnsLink"]
}], "IndexSubentry",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Selection coefficients"],

Cell[TextData[{
  "SelectionExact",
  ",",
  " for allele frequencies",
  ", ",
  ButtonBox["Allele frequencies: fitnesses",
    ButtonData:>{"Allele frequencies: fitnesses", "SelectionExact"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"SelectionExact"],

Cell[TextData[{
  " for genotype frequencies",
  ", ",
  ButtonBox["Recursions: fitnesses",
    ButtonData:>{"Recursions: fitnesses", "SelectionExact"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " for individuals",
  ", ",
  ButtonBox["Simulating individuals: fitnesses",
    ButtonData:>{"Simulating individuals: fitnesses", "SelectionExact"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " for symmetric model",
  ", ",
  ButtonBox["Symmetric model: fitnesses",
    ButtonData:>{"Symmetric model: fitnesses", "SelectionExact"},
    ButtonStyle->"AddOnsLink"]
}], "IndexSubentry",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"SelectionExact"],

Cell[TextData[{
  "Selection on diploids",
  ",",
  " a method to avoid",
  ", ",
  ButtonBox["A method to avoid",
    ButtonData:>{"A method to avoid", None},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Selection on diploids"],

Cell[TextData[{
  " cautionary notes",
  ", ",
  ButtonBox["Cautionary notes",
    ButtonData:>{"Cautionary notes", None},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " complete life cycle",
  ", ",
  ButtonBox["Complete life cyle",
    ButtonData:>{"Complete life cyle", None},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " explaining the rules",
  ", ",
  ButtonBox["Explaining the rules",
    ButtonData:>{"Explaining the rules", None},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " introduction",
  ", ",
  ButtonBox["Introduction to selection on diploids",
    ButtonData:>{"Introduction to selection on diploids", None},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " life cycle",
  ", ",
  ButtonBox["Life cycle",
    ButtonData:>{"Life cycle", None},
    ButtonStyle->"AddOnsLink"]
}], "IndexSubentry",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Selection on diploids"],

Cell[TextData[{
  "SelectionRate",
  ",",
  " \[GothicS],\[AliasIndicator]gos\[AliasIndicator]",
  ", ",
  ButtonBox["Slow change",
    ButtonData:>{"Slow change", "SelectionRate"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"SelectionRate"],

Cell[TextData[{
  "SelectLoci",
  ",",
  " ",
  ButtonBox["Selecting subsets",
    ButtonData:>{"Selecting subsets", "SelectLoci"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"SelectLoci"],

Cell[TextData[{
  "Selfing",
  ",",
  " ",
  ButtonBox["Selfing",
    ButtonData:>{"Selfing", None},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Selfing"],

Cell[TextData[{
  "Separate",
  ",",
  " ",
  ButtonBox["Tagging sets",
    ButtonData:>{"Tagging sets", "Separate"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Separate"],

Cell[TextData[{
  "Servedio",
  ",",
  " Maria",
  ", ",
  ButtonBox["Haploid selection",
    ButtonData:>{"Haploid selection", "Servedio"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Servedio"],

Cell[TextData[{
  "Set",
  ",",
  " of all positions affecting a trait, \[DoubleStruckCapitalZ], \
\[AliasIndicator]dsZ\[AliasIndicator]",
  ", ",
  ButtonBox["Notation reference",
    ButtonData:>{"Notation reference", None},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Set"],

Cell[TextData[{
  " of all positions in genome, \[DoubleStruckCapitalG], \[AliasIndicator]dsG\
\[AliasIndicator]",
  ", ",
  ButtonBox["Notation reference",
    ButtonData:>{"Notation reference", None},
    ButtonStyle->"AddOnsLink"]
}], "IndexSubentry",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Set"],

Cell[TextData[{
  "Set manipulation",
  ",",
  " overview",
  ", ",
  ButtonBox["Overview of set manipulation",
    ButtonData:>{"Overview of set manipulation", None},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Set manipulation"],

Cell[TextData[{
  "SetOfCombinations",
  ",",
  " ",
  ButtonBox["Set combinations",
    ButtonData:>{"Set combinations", "SetOfCombinations"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"SetOfCombinations"],

Cell[TextData[{
  "SetPartition",
  ",",
  " ",
  ButtonBox["Set partitions",
    ButtonData:>{"Set partitions", "SetPartition"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"SetPartition"],

Cell[TextData[{
  "Sets of loci",
  ",",
  " as used in Kirkpatrick et al.",
  ", ",
  ButtonBox["Multilocus MS relation",
    ButtonData:>{"Multilocus MS relation", "Sets of loci"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Sets of loci"],

Cell[TextData[{
  "Sex",
  ",",
  " ",
  ButtonBox["Life cycle",
    ButtonData:>{"Life cycle", "Sex"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Sex"],

Cell[TextData[{
  "Sex linkage",
  ",",
  " ",
  ButtonBox["Non-Mendelian inheritance",
    ButtonData:>{"Non-Mendelian inheritance", "XLinkedLoci"},
    ButtonStyle->"AddOnsLink"],
  ",",
  ButtonBox["Reference points",
    ButtonData:>{"Reference points", "XLinkedLoci"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Sex linkage"],

Cell[TextData[{
  " examples of",
  ", ",
  ButtonBox["Sex linkage",
    ButtonData:>{"Sex linkage", None},
    ButtonStyle->"AddOnsLink"]
}], "IndexSubentry",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Sex linkage"],

Cell[TextData[{
  "SexOfOrigin",
  ",",
  " ",
  ButtonBox["Life cycle",
    ButtonData:>{"Life cycle", "SexOfOrigin"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"SexOfOrigin"],

Cell[TextData[{
  "Sexual selection",
  ",",
  " ",
  ButtonBox["Sexual selection",
    ButtonData:>{"Sexual selection", "Sexual selection"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Sexual selection"],

Cell[TextData[{
  " and migration",
  ", ",
  ButtonBox["Migration",
    ButtonData:>{"Migration", "Sexual selection"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " complete life cycle",
  ", ",
  ButtonBox["Sexual selection",
    ButtonData:>{"Sexual selection", "Complete cycle"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " defining fitnesses",
  ", ",
  ButtonBox["Sexual selection",
    ButtonData:>{"Sexual selection", "Defining fitnesses"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " Kirkpatrick et al.",
  ", ",
  ButtonBox["Multilocus MS",
    ButtonData:>{"Multilocus MS", "Sexual selection by female choice"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  "on haploids",
  ", ",
  ButtonBox["Haploid selection",
    ButtonData:>{"Haploid selection", None},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " recombination",
  ", ",
  ButtonBox["Sexual selection",
    ButtonData:>{"Sexual selection", "Recombination"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " subtle problem",
  ", ",
  ButtonBox["Sexual selection",
    ButtonData:>{"Sexual selection", "subtle problem"},
    ButtonStyle->"AddOnsLink"]
}], "IndexSubentry",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Sexual selection"],

Cell[TextData[{
  "ShortContext",
  ",",
  " ",
  ButtonBox["Abbreviating contexts",
    ButtonData:>{"Abbreviating contexts", "ShortContext"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"ShortContext"],

Cell[TextData[{
  "SigmaMatrix",
  ",",
  " ",
  ButtonBox["Symmetric stability: one deme",
    ButtonData:>{"Symmetric stability: one deme", "SigmaMatrix"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"SigmaMatrix"],

Cell[TextData[{
  "SignMask",
  ",",
  " ",
  ButtonBox["Internal functions",
    ButtonData:>{"Internal functions", "SignMask"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"SignMask"],

Cell[TextData[{
  "SimplifyAddUp",
  ",",
  " ",
  ButtonBox["AddUp",
    ButtonData:>{"AddUp", "SimplifyAddUp"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"SimplifyAddUp"],

Cell[TextData[{
  "SimplifyAddUpQ",
  ",",
  " ",
  ButtonBox["AddUp",
    ButtonData:>{"AddUp", "SimplifyAddUpQ"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"SimplifyAddUpQ"],

Cell[TextData[{
  "SimplifyFamilies",
  ",",
  " ",
  ButtonBox["Probabilities",
    ButtonData:>{"Probabilities", "SimplifyFamilies"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"SimplifyFamilies"],

Cell[TextData[{
  "Simulating individuals",
  ",",
  " recursions",
  ", ",
  ButtonBox["Simulating individuals: iterating one deme",
    ButtonData:>{"Simulating individuals: iterating one deme", None},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Simulating individuals"],

Cell[TextData[{
  " representation",
  ", ",
  ButtonBox["Simulating individuals: Describing populations",
    ButtonData:>{"Simulating individuals: Describing populations", None},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " reproduction",
  ", ",
  ButtonBox["Simulating individuals: reproduction",
    ButtonData:>{"Simulating individuals: reproduction", None},
    ButtonStyle->"AddOnsLink"]
}], "IndexSubentry",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Simulating individuals"],

Cell[TextData[{
  "SizeOfGenealogyPlot",
  ",",
  " ",
  ButtonBox["Plotting genealogies",
    ButtonData:>{"Plotting genealogies", "SizeOfGenealogyPlot"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"SizeOfGenealogyPlot"],

Cell[TextData[{
  "Slatkin & Excoffier 1996",
  ",",
  " ",
  ButtonBox["References",
    ButtonData:>{"References", "Slatkin & Excoffier 1996"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Slatkin & Excoffier 1996"],

Cell[TextData[{
  "SlowChange",
  ",",
  " ",
  ButtonBox["Slow change",
    ButtonData:>{"Slow change", "SlowChange"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"SlowChange"],

Cell[TextData[{
  "SortByClass",
  ",",
  " ",
  ButtonBox["Representing the population",
    ButtonData:>{"Representing the population", "SortByClass"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"SortByClass"],

Cell[TextData[{
  " genotype frequencies",
  ", ",
  ButtonBox["Recursions: representation",
    ButtonData:>{"Recursions: representation", "SortByClass"},
    ButtonStyle->"AddOnsLink"]
}], "IndexSubentry",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"SortByClass"],

Cell[TextData[{
  "SortByHead",
  ",",
  " ",
  ButtonBox["Sorting",
    ButtonData:>{"Sorting", "SortByHead"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"SortByHead"],

Cell[TextData[{
  "SpatialCovariance",
  ",",
  " ",
  ButtonBox["Sampling",
    ButtonData:>{"Sampling", "SpatialCovariance"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"SpatialCovariance"],

Cell[TextData[{
  "Spatially varying selection",
  ",",
  " in symmetric model",
  ", ",
  ButtonBox["Spatially varying selection",
    ButtonData:>{"Spatially varying selection", None},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Spatially varying selection"],

Cell[TextData[{
  "Special notation",
  ",",
  " ",
  ButtonBox["Special notation",
    ButtonData:>{"Special notation", "Defining notation"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Special notation"],

Cell[TextData[{
  "SplitSet",
  ",",
  " ",
  ButtonBox["Set partitions",
    ButtonData:>{"Set partitions", "SplitSet"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"SplitSet"],

Cell[TextData[{
  "Stabilising selection",
  ",",
  " change in D",
  ", ",
  ButtonBox["Stabilising selection",
    ButtonData:>{"Stabilising selection", "Change in D"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Stabilising selection"],

Cell[TextData[{
  " change in mean",
  ", ",
  ButtonBox["Stabilising selection",
    ButtonData:>{"Stabilising selection", "Change in mean"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " defining fitness",
  ", ",
  ButtonBox["Stabilising selection",
    ButtonData:>{"Stabilising selection", "Defining fitness"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  "Kirkpatrick et al.",
  ", ",
  ButtonBox["Multilocus MS",
    ButtonData:>{"Multilocus MS", 
      "Natural selection on an additive polygenic trait"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  "mean fitness",
  ", ",
  ButtonBox["Stabilising selection",
    ButtonData:>{"Stabilising selection", "Mean fitness"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " new mean",
  ", ",
  ButtonBox["Stabilising selection",
    ButtonData:>{"Stabilising selection", "New mean"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " new mean fitness",
  ", ",
  ButtonBox["Stabilising selection",
    ButtonData:>{"Stabilising selection", "New mean fitness"},
    ButtonStyle->"AddOnsLink"]
}], "IndexSubentry",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Stabilising selection"],

Cell[TextData[{
  "Stability",
  ",",
  " of numerical models",
  ", ",
  ButtonBox["Allele frequencies: stability",
    ButtonData:>{"Allele frequencies: stability", None},
    ButtonStyle->"AddOnsLink"],
  ",",
  ButtonBox["Example: stability",
    ButtonData:>{"Example: stability", None},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Stability"],

Cell[TextData[{
  " of symmetric model",
  ", ",
  ButtonBox["Symmetric stability: outline",
    ButtonData:>{"Symmetric stability: outline", None},
    ButtonStyle->"AddOnsLink"]
}], "IndexSubentry",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Stability"],

Cell[TextData[{
  "StabilityDirect",
  ",",
  " for allele frequencies",
  ", ",
  ButtonBox["Allele frequencies: stability",
    ButtonData:>{"Allele frequencies: stability", "StabilityDirect"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"StabilityDirect"],

Cell[TextData[{
  " for genotype frequencies",
  ", ",
  ButtonBox["Example: stability",
    ButtonData:>{"Example: stability", "StabilityDirect"},
    ButtonStyle->"AddOnsLink"]
}], "IndexSubentry",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"StabilityDirect"],

Cell[TextData[{
  "StabilityK",
  ",",
  " ",
  ButtonBox["Symmetric stability: a cline",
    ButtonData:>{"Symmetric stability: a cline", "StabilityK"},
    ButtonStyle->"AddOnsLink"],
  ",",
  ButtonBox["Symmetric stability: one deme",
    ButtonData:>{"Symmetric stability: one deme", "StabilityK"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"StabilityK"],

Cell[TextData[{
  "StabilityKTable",
  ",",
  " ",
  ButtonBox["Symmetric stability: faster algorithms",
    ButtonData:>{"Symmetric stability: faster algorithms", "StabilityKTable"},
    
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"StabilityKTable"],

Cell[TextData[{
  "StabilityMatrix",
  ",",
  " ",
  ButtonBox["Making a stability matrix",
    ButtonData:>{"Making a stability matrix", "StabilityMatrix"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"StabilityMatrix"],

Cell[TextData[{
  "Stage",
  ",",
  " \[Sampi], \[AliasIndicator]sa\[AliasIndicator]",
  ", ",
  ButtonBox["Genes and contexts",
    ButtonData:>{"Genes and contexts", "Stages"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Stage"],

Cell[TextData[{
  "Stages",
  ",",
  " ",
  ButtonBox["Life cycle",
    ButtonData:>{"Life cycle", "Stages"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Stages"],

Cell[TextData[{
  " as used in Kirkpatrick et al.",
  ", ",
  ButtonBox["Multilocus MS relation",
    ButtonData:>{"Multilocus MS relation", "Stages and contexts"},
    ButtonStyle->"AddOnsLink"]
}], "IndexSubentry",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Stages"],

Cell[TextData[{
  "StandardPartition",
  ",",
  " ",
  ButtonBox["Set partitions",
    ButtonData:>{"Set partitions", "StandardPartition"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"StandardPartition"],

Cell[TextData[{
  "StandardPartitionQ",
  ",",
  " ",
  ButtonBox["Set partitions",
    ButtonData:>{"Set partitions", "StandardPartitionQ"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"StandardPartitionQ"],

Cell[TextData[{
  "StartingStepSize",
  ",",
  " ",
  ButtonBox["Options for StructuredMLE",
    ButtonData:>{"Options for StructuredMLE", "StartingStepSize"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"StartingStepSize"],

Cell[TextData[{
  "Stepping-stone migration",
  ",",
  " with individuals",
  ", ",
  ButtonBox["Simulating individuals:migration",
    ButtonData:>{"Simulating individuals:migration", 
      "Nearest-neighbour migration"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Stepping-stone migration"],

Cell[TextData[{
  "Stepping-stone model",
  ",",
  " for allele frequencies",
  ", ",
  ButtonBox["Allele frequencies:migration",
    ButtonData:>{"Allele frequencies:migration", 
      "Nearest-neighbour migration"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Stepping-stone model"],

Cell[TextData[{
  " for genotype frequencies",
  ", ",
  ButtonBox["Recursions:migration",
    ButtonData:>{"Recursions:migration", "Nearest-neighbour migration"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " for symmetric model",
  ", ",
  ButtonBox["Symmetric model: migration",
    ButtonData:>{"Symmetric model: migration", "Nearest-neighbour migration"},
    
    ButtonStyle->"AddOnsLink"]
}], "IndexSubentry",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Stepping-stone model"],

Cell[TextData[{
  "StoreExact",
  ",",
  " for allele frequencies",
  ", ",
  ButtonBox["Allele frequencies: iterating one deme",
    ButtonData:>{"Allele frequencies: iterating one deme", "StoreExact"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"StoreExact"],

Cell[TextData[{
  " for allele frequency clines",
  ", ",
  ButtonBox["Allele frequencies: iterating a cline",
    ButtonData:>{"Allele frequencies: iterating a cline", "StoreExact"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " for clines in symmetric model",
  ", ",
  ButtonBox["Symmetric model: iterating a cline",
    ButtonData:>{"Symmetric model: iterating a cline", "StoreExact"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " for clines with individuals",
  ", ",
  ButtonBox["Simulating individuals: iterating a cline",
    ButtonData:>{"Simulating individuals: iterating a cline", "StoreExact"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " for genotype frequencies",
  ", ",
  ButtonBox["Recursions: iterating one deme",
    ButtonData:>{"Recursions: iterating one deme", "StoreExact"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " for genotype frequency clines",
  ", ",
  ButtonBox["Recursions: iterating a cline",
    ButtonData:>{"Recursions: iterating a cline", "StoreExact"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " for individuals",
  ", ",
  ButtonBox["Simulating individuals: iterating one deme",
    ButtonData:>{"Simulating individuals: iterating one deme", "StoreExact"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " for symmetric model",
  ", ",
  ButtonBox["Symmetric model: iterating one deme",
    ButtonData:>{"Symmetric model: iterating one deme", "StoreExact"},
    ButtonStyle->"AddOnsLink"]
}], "IndexSubentry",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"StoreExact"],

Cell[TextData[{
  "StoreResults",
  ",",
  " option for GameteTable",
  ", ",
  ButtonBox["Recursions:reproduction",
    ButtonData:>{"Recursions:reproduction", "StoreResults"},
    ButtonStyle->"AddOnsLink"],
  ",",
  ButtonBox["Symmetric model: reproduction",
    ButtonData:>{"Symmetric model: reproduction", "StoreResults"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"StoreResults"],

Cell[TextData[{
  " option for NewGametes",
  ", ",
  ButtonBox["Symmetric model: reproduction",
    ButtonData:>{"Symmetric model: reproduction", "StoreResults"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " use when compiling",
  ", ",
  ButtonBox["Allele frequencies: iterating one deme",
    ButtonData:>{"Allele frequencies: iterating one deme", "StoreResults"},
    ButtonStyle->"AddOnsLink"],
  ",",
  ButtonBox["Recursions: compiling",
    ButtonData:>{"Recursions: compiling", "StoreResults"},
    ButtonStyle->"AddOnsLink"],
  ",",
  ButtonBox["Symmetric model: iterating one deme",
    ButtonData:>{"Symmetric model: iterating one deme", 
      "StoreResults (compiling)"},
    ButtonStyle->"AddOnsLink"]
}], "IndexSubentry",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"StoreResults"],

Cell[TextData[{
  "StructuredArray",
  ",",
  " ",
  ButtonBox["Useful functions",
    ButtonData:>{"Useful functions", "StructuredArray"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"StructuredArray"],

Cell[TextData[{
  "StructuredInitialParameters",
  ",",
  " ",
  ButtonBox["Initial parameters",
    ButtonData:>{"Initial parameters", "StructuredInitialParameters"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"StructuredInitialParameters"],

Cell[TextData[{
  "StructuredLogLikelihood",
  ",",
  " ",
  ButtonBox["Likelihood of a structured model",
    ButtonData:>{"Likelihood of a structured model", 
      "StructuredLogLikelihood"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"StructuredLogLikelihood"],

Cell[TextData[{
  "StructuredMLE",
  ",",
  " ",
  ButtonBox["Likelihood of a structured model",
    ButtonData:>{"Likelihood of a structured model", "StructuredMLE"},
    ButtonStyle->"AddOnsLink"],
  ",",
  ButtonBox["Options for StructuredMLE",
    ButtonData:>{"Options for StructuredMLE", "StructuredMLE"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"StructuredMLE"],

Cell[TextData[{
  "StructuredModel",
  ",",
  " ",
  ButtonBox["Useful functions",
    ButtonData:>{"Useful functions", "StructuredModel"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"StructuredModel"],

Cell[TextData[{
  "StructuredModelReduce",
  ",",
  " ",
  ButtonBox["Simplifying a model",
    ButtonData:>{"Simplifying a model", "StructuredModelReduce"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"StructuredModelReduce"],

Cell[TextData[{
  "Structured models",
  ",",
  " example",
  ", ",
  ButtonBox["Example data",
    ButtonData:>{"Example data", None},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Structured models"],

Cell[TextData[{
  " hierarchical analysis",
  ", ",
  ButtonBox["Hierarchical analysis",
    ButtonData:>{"Hierarchical analysis", None},
    ButtonStyle->"AddOnsLink"]
}], "IndexSubentry",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Structured models"],

Cell[TextData[{
  "StructuredParameter",
  ",",
  " ",
  ButtonBox["Structured parameters",
    ButtonData:>{"Structured parameters", "StructuredParameter"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"StructuredParameter"],

Cell[TextData[{
  "StructuredVariance",
  ",",
  " ",
  ButtonBox["Variance components for a structured model",
    ButtonData:>{"Variance components for a structured model", 
      "StructuredVariance"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"StructuredVariance"],

Cell[TextData[{
  "Style sheets",
  ",",
  " bugs with",
  ", ",
  ButtonBox["Bugs",
    ButtonData:>{"Bugs", "Style sheets"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Style sheets"],

Cell[TextData[{
  "Subdivide",
  ",",
  " ",
  ButtonBox["Muddling and subdividing sets",
    ButtonData:>{"Muddling and subdividing sets", "Subdivide"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Subdivide"],

Cell[TextData[{
  "Subscripts",
  ",",
  " as written in Kirkpatrick et al.",
  ", ",
  ButtonBox["Multilocus MS relation",
    ButtonData:>{"Multilocus MS relation", "Sets in subscripts"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Subscripts"],

Cell[TextData[{
  "Subsets",
  ",",
  " ",
  ButtonBox["Subsets",
    ButtonData:>{"Subsets", "Subsets"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Subsets"],

Cell[TextData[{
  " option for AddUp",
  ", ",
  ButtonBox["AddUp",
    ButtonData:>{"AddUp", "Subsets"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " option for TimesUp",
  ", ",
  ButtonBox["TimesUp",
    ButtonData:>{"TimesUp", "Subsets"},
    ButtonStyle->"AddOnsLink"]
}], "IndexSubentry",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Subsets"],

Cell[TextData[{
  "Sums",
  ",",
  " multiple",
  ", ",
  ButtonBox["AddUp",
    ButtonData:>{"AddUp", "Multiple sums"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Sums"],

Cell[TextData[{
  "SwapStates",
  ",",
  " ",
  ButtonBox["Rooting a genealogy",
    ButtonData:>{"Rooting a genealogy", "SwapStates"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"SwapStates"],

Cell[TextData[{
  "Symmetric cline",
  ",",
  " in allele frequencies",
  ", ",
  ButtonBox["Allele frequencies: setting up a symmetric cline",
    ButtonData:>{"Allele frequencies: setting up a symmetric cline", None},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Symmetric cline"],

Cell[TextData[{
  " in genotype frequencies",
  ", ",
  ButtonBox["Recursions:setting up a symmetric cline",
    ButtonData:>{"Recursions:setting up a symmetric cline", "DoubleCline"},
    ButtonStyle->"AddOnsLink"]
}], "IndexSubentry",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Symmetric cline"],

Cell[TextData[{
  "SymmetricDiploidFrequencies",
  ",",
  " ",
  ButtonBox["Overview of numerical models",
    ButtonData:>{"Overview of numerical models", 
      "SymmetricDiploidFrequencies"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"SymmetricDiploidFrequencies"],

Cell[TextData[{
  "SymmetricHaploidFrequencies",
  ",",
  " ",
  ButtonBox["Overview of numerical models",
    ButtonData:>{"Overview of numerical models", 
      "SymmetricHaploidFrequencies"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"SymmetricHaploidFrequencies"],

Cell[TextData[{
  "Symmetric model",
  ",",
  " adding a neutral marker",
  ", ",
  ButtonBox["Adding a neutral gene",
    ButtonData:>{"Adding a neutral gene", None},
    ButtonStyle->"AddOnsLink"],
  ",",
  ButtonBox["Symmetric model: limitations",
    ButtonData:>{"Symmetric model: limitations", None},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Symmetric model"],

Cell[TextData[{
  " cline example",
  ", ",
  ButtonBox["Symmetric stability: a cline",
    ButtonData:>{"Symmetric stability: a cline", None},
    ButtonStyle->"AddOnsLink"],
  ",",
  ButtonBox["Symmetric stability: spatially varying selection",
    ButtonData:>{"Symmetric stability: spatially varying selection", None},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " limitations",
  ", ",
  ButtonBox["Symmetric model: limitations",
    ButtonData:>{"Symmetric model: limitations", None},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " one deme example",
  ", ",
  ButtonBox["Symmetric stability: one deme",
    ButtonData:>{"Symmetric stability: one deme", None},
    ButtonStyle->"AddOnsLink"],
  "\n",
  "overview",
  ", ",
  ButtonBox["Symmetric model: genotype frequencies",
    ButtonData:>{"Symmetric model: genotype frequencies", None},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " references",
  ", ",
  ButtonBox["Symmetric model: references",
    ButtonData:>{"Symmetric model: references", None},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " reproduction",
  ", ",
  ButtonBox["Symmetric model: reproduction",
    ButtonData:>{"Symmetric model: reproduction", None},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " stability of",
  ", ",
  ButtonBox["Symmetric stability: outline",
    ButtonData:>{"Symmetric stability: outline", None},
    ButtonStyle->"AddOnsLink"]
}], "IndexSubentry",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Symmetric model"],

Cell[TextData[{
  "SymmetricNeutralDiploidFrequencies",
  ",",
  " ",
  ButtonBox["Adding a neutral gene",
    ButtonData:>{"Adding a neutral gene", None},
    ButtonStyle->"AddOnsLink"],
  ",",
  ButtonBox["Overview of numerical models",
    ButtonData:>{"Overview of numerical models", 
      "SymmetricNeutralDiploidFrequencies"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"SymmetricNeutralDiploidFrequencies"],

Cell[TextData[{
  "SymmetricNeutralHaploidFrequencies",
  ",",
  " ",
  ButtonBox["Adding a neutral gene",
    ButtonData:>{"Adding a neutral gene", None},
    ButtonStyle->"AddOnsLink"],
  ",",
  ButtonBox["Overview of numerical models",
    ButtonData:>{"Overview of numerical models", 
      "SymmetricNeutralHaploidFrequencies"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"SymmetricNeutralHaploidFrequencies"],

Cell[TextData[{
  "SymmetricRecombination",
  ",",
  " ",
  ButtonBox["Recombination",
    ButtonData:>{"Recombination", "SymmetricRecombination"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"SymmetricRecombination"],

Cell[TextData[{
  "SymmetricRepresentations",
  ",",
  " ",
  ButtonBox["Overview of numerical models",
    ButtonData:>{"Overview of numerical models", "SymmetricRepresentations"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"SymmetricRepresentations"],

Cell[TextData[{
  "SymmetricSexes",
  ",",
  " ",
  ButtonBox["Symmetric sexes",
    ButtonData:>{"Symmetric sexes", "SymmetricSexes"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"SymmetricSexes"],

Cell[TextData[{
  "Symmetrise",
  ",",
  " ",
  ButtonBox["Disequilibrium",
    ButtonData:>{"Disequilibrium", "Symmetrise"},
    ButtonStyle->"AddOnsLink"],
  ",",
  ButtonBox["Symmetrise",
    ButtonData:>{"Symmetrise", "Symmetrise"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Symmetrise"],

Cell[TextData[{
  "T",
  ",",
  " time",
  ", ",
  ButtonBox["Global variables",
    ButtonData:>{"Global variables", "T"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"T"],

Cell[TextData[{
  "Table",
  ",",
  " option for VarianceComponents",
  ", ",
  ButtonBox["Variance components",
    ButtonData:>{"Variance components", "Table"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Table"],

Cell[TextData[{
  "Tag",
  ",",
  " ",
  ButtonBox["Tagging sets",
    ButtonData:>{"Tagging sets", "Tag"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Tag"],

Cell[TextData[{
  "Tags",
  ",",
  " finding",
  ", ",
  ButtonBox["Automatic Numbering",
    ButtonData:>{"Automatic Numbering", "Finding tags"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Tags"],

Cell[TextData[{
  " setting up hyperlinks to",
  ", ",
  ButtonBox["Automatic Numbering",
    ButtonData:>{"Automatic Numbering", "Setting up links to a list of tags"},
    
    ButtonStyle->"AddOnsLink"]
}], "IndexSubentry",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Tags"],

Cell[TextData[{
  "TakeAway, \[Backslash], \[AliasIndicator]\[AliasIndicator], ",
  ButtonBox["Operations on sets",
    ButtonData:>{"Operations on sets", "TakeAway"},
    ButtonStyle->"AddOnsLink"],
  ",",
  ButtonBox["TakeAway",
    ButtonData:>{"TakeAway", "TakeAway"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"TakeAway"],

Cell[TextData[{
  "TakeOptions",
  ",",
  " ",
  ButtonBox["Manipulating options",
    ButtonData:>{"Manipulating options", "TakeOptions"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"TakeOptions"],

Cell[TextData[{
  "Time",
  ",",
  " T",
  ", ",
  ButtonBox["Global variables",
    ButtonData:>{"Global variables", "T"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Time"],

Cell[TextData[{
  "TimesOfEvents",
  ",",
  " in ancestral graphs",
  ", ",
  ButtonBox["Describing ancestral graphs",
    ButtonData:>{"Describing ancestral graphs", "TimesOfEvents"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"TimesOfEvents"],

Cell[TextData[{
  "TimespanOfJunction",
  ",",
  " in ancestral graphs",
  ", ",
  ButtonBox["Describing ancestral graphs",
    ButtonData:>{"Describing ancestral graphs", "TimespanOfJunction"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"TimespanOfJunction"],

Cell[TextData[{
  "TimespanOfLineage",
  ",",
  " in ancestral graphs",
  ", ",
  ButtonBox["Describing ancestral graphs",
    ButtonData:>{"Describing ancestral graphs", "TimespanOfLineage"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"TimespanOfLineage"],

Cell[TextData[{
  "TimesUp",
  ",",
  " ",
  ButtonBox["Operations on sets",
    ButtonData:>{"Operations on sets", "TimesUp"},
    ButtonStyle->"AddOnsLink"],
  ",",
  ButtonBox["TimesUp",
    ButtonData:>{"TimesUp", "TimesUp"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"TimesUp"],

Cell[TextData[{
  " multiple products",
  ", ",
  ButtonBox["TimesUp",
    ButtonData:>{"TimesUp", "Multiple products"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " over subsets",
  ", ",
  ButtonBox["TimesUp",
    ButtonData:>{"TimesUp", "Subsets"},
    ButtonStyle->"AddOnsLink"]
}], "IndexSubentry",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"TimesUp"],

Cell[TextData[{
  "ToBaake",
  ",",
  " ",
  ButtonBox["Alternative measures",
    ButtonData:>{"Alternative measures", "ToBaake"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"ToBaake"],

Cell[TextData[{
  "ToBennett",
  ",",
  " ",
  ButtonBox["Alternative measures",
    ButtonData:>{"Alternative measures", "ToBennett"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"ToBennett"],

Cell[TextData[{
  "ToBennettExpression",
  ",",
  " ",
  ButtonBox["Alternative measures",
    ButtonData:>{"Alternative measures", "ToBennettExpression"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"ToBennettExpression"],

Cell[TextData[{
  "ToCumulants",
  ",",
  " ",
  ButtonBox["Multilocus cumulants",
    ButtonData:>{"Multilocus cumulants", "ToCumulants"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"ToCumulants"],

Cell[TextData[{
  "ToMoments",
  ",",
  " ",
  ButtonBox["Multilocus cumulants",
    ButtonData:>{"Multilocus cumulants", "ToMoments"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"ToMoments"],

Cell[TextData[{
  "ToPopulationCumulants",
  ",",
  " ",
  ButtonBox["Random drift: cumulants",
    ButtonData:>{"Random drift: cumulants", "ToPopulationCumulants"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"ToPopulationCumulants"],

Cell[TextData[{
  "ToPopulationMoments",
  ",",
  " ",
  ButtonBox["Random drift: cumulants",
    ButtonData:>{"Random drift: cumulants", "ToPopulationMoments"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"ToPopulationMoments"],

Cell[TextData[{
  "TotalLength",
  ",",
  " ",
  ButtonBox["Distribution of coalescence times",
    ButtonData:>{"Distribution of coalescence times", "TotalLength"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"TotalLength"],

Cell[TextData[{
  "TotalNumber",
  ",",
  " ",
  ButtonBox["Global variables",
    ButtonData:>{"Global variables", "TotalNumber"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"TotalNumber"],

Cell[TextData[{
  "Trait",
  ",",
  " set of all positions affecting, \[DoubleStruckCapitalZ], \
\[AliasIndicator]dsZ\[AliasIndicator]",
  ", ",
  ButtonBox["Notation reference",
    ButtonData:>{"Notation reference", None},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Trait"],

Cell[TextData[{
  "TransformedRange",
  ",",
  " ",
  ButtonBox["Fourier transforms",
    ButtonData:>{"Fourier transforms", "TransformedRange"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"TransformedRange"],

Cell[TextData[{
  "TransformInformation",
  ",",
  " ",
  ButtonBox["Describing genealogies",
    ButtonData:>{"Describing genealogies", "TransformInformation"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"TransformInformation"],

Cell[TextData[{
  "TransmissionRule",
  ",",
  " ",
  ButtonBox["Changing contexts",
    ButtonData:>{"Changing contexts", "TransmissionRule"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"TransmissionRule"],

Cell[TextData[{
  "Transmission rules",
  ",",
  " applying",
  ", ",
  ButtonBox["Changing contexts",
    ButtonData:>{"Changing contexts", "Applying transmission rules"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Transmission rules"],

Cell[TextData[{
  " as used in Kirkpatrick et al.",
  ", ",
  ButtonBox["Multilocus MS relation",
    ButtonData:>{"Multilocus MS relation", "Transmission rules"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " distinct from Mathematica rules",
  ", ",
  ButtonBox["Changing contexts",
    ButtonData:>{"Changing contexts", "Transmission vs Mathematica rules"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " Kirkpatrick et al.",
  ", ",
  ButtonBox["Multilocus MS",
    ButtonData:>{"Multilocus MS", "Transmission"},
    ButtonStyle->"AddOnsLink"]
}], "IndexSubentry",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Transmission rules"],

Cell[TextData[{
  "TriDiagonalMatrix",
  ",",
  " ",
  ButtonBox["Diagonal matrices",
    ButtonData:>{"Diagonal matrices", "TriDiagonalMatrix"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"TriDiagonalMatrix"],

Cell[TextData[{
  "TruncationSelection",
  ",",
  " option for NewGametes",
  ", ",
  ButtonBox["Simulating individuals: reproduction",
    ButtonData:>{"Simulating individuals: reproduction", 
      "TruncationSelection"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"TruncationSelection"],

Cell[TextData[{
  "option for SelectionExact",
  ", ",
  ButtonBox["Simulating individuals: fitnesses",
    ButtonData:>{"Simulating individuals: fitnesses", "TruncationSelection"},
    ButtonStyle->"AddOnsLink"]
}], "IndexSubentry",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"TruncationSelection"],

Cell[TextData[{
  "Turelli and Barton 1994",
  ",",
  " ",
  ButtonBox["Multilocus references",
    ButtonData:>{"Multilocus references", "Turelli and Barton 1994"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Turelli and Barton 1994"],

Cell[TextData[{
  "Turelli & Barton 1994",
  ",",
  " ",
  ButtonBox["References",
    ButtonData:>{"References", "Turelli & Barton 1994"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Turelli & Barton 1994"],

Cell[TextData[{
  "Two alleles",
  ",",
  " ",
  ButtonBox["Two alleles",
    ButtonData:>{"Two alleles", "Biallelic"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Two alleles"],

Cell[TextData[{
  " selection coefficients",
  ", ",
  ButtonBox["Fitness",
    ButtonData:>{"Fitness", "Two alleles"},
    ButtonStyle->"AddOnsLink"],
  ",",
  ButtonBox["Phenotypes",
    ButtonData:>{"Phenotypes", "Two alleles"},
    ButtonStyle->"AddOnsLink"]
}], "IndexSubentry",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Two alleles"],

Cell[TextData[{
  "UMS",
  ",",
  " for allele frequencies",
  ", ",
  ButtonBox["Allele frequencies: iterating one deme",
    ButtonData:>{"Allele frequencies: iterating one deme", "UMS"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"UMS"],

Cell[TextData[{
  "for genotype frequencies",
  ", ",
  ButtonBox["Recursions: iterating one deme",
    ButtonData:>{"Recursions: iterating one deme", "UMS"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " for individuals",
  ", ",
  ButtonBox["Simulating individuals: iterating one deme",
    ButtonData:>{"Simulating individuals: iterating one deme", "UMS"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " for symmetric model",
  ", ",
  ButtonBox["Symmetric model: iterating one deme",
    ButtonData:>{"Symmetric model: iterating one deme", "UMS"},
    ButtonStyle->"AddOnsLink"]
}], "IndexSubentry",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"UMS"],

Cell[TextData[{
  "UnionOfGametes",
  ",",
  " ",
  ButtonBox["Union of gametes",
    ButtonData:>{"Union of gametes", "UnionOfGametes"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"UnionOfGametes"],

Cell[TextData[{
  "UnlinkedRecombination",
  ",",
  " ",
  ButtonBox["Recombination",
    ButtonData:>{"Recombination", "UnlinkedRecombination"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"UnlinkedRecombination"],

Cell[TextData[{
  "UnrootedGenealogy",
  ",",
  " ",
  ButtonBox["Structure of genealogies",
    ButtonData:>{"Structure of genealogies", "UnrootedGenealogy"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"UnrootedGenealogy"],

Cell[TextData[{
  "UpperOffDiagonal",
  ",",
  " ",
  ButtonBox["Diagonal matrices",
    ButtonData:>{"Diagonal matrices", "UpperOffDiagonal"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"UpperOffDiagonal"],

Cell[TextData[{
  "USM",
  ",",
  " for allele frequencies",
  ", ",
  ButtonBox["Allele frequencies: iterating one deme",
    ButtonData:>{"Allele frequencies: iterating one deme", "USM"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"USM"],

Cell[TextData[{
  "for genotype frequencies",
  ", ",
  ButtonBox["Recursions: iterating one deme",
    ButtonData:>{"Recursions: iterating one deme", "USM"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " for individuals",
  ", ",
  ButtonBox["Simulating individuals: iterating one deme",
    ButtonData:>{"Simulating individuals: iterating one deme", "USM"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " for symmetric model",
  ", ",
  ButtonBox["Symmetric model: iterating one deme",
    ButtonData:>{"Symmetric model: iterating one deme", "USM"},
    ButtonStyle->"AddOnsLink"]
}], "IndexSubentry",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"USM"],

Cell[TextData[{
  "ValidMatrixQ",
  ",",
  " ",
  ButtonBox["Validity of a mutation matrix",
    ButtonData:>{"Validity of a mutation matrix", "ValidMatrixQ"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"ValidMatrixQ"],

Cell[TextData[{
  "VarianceComponents",
  ",",
  " ",
  ButtonBox["Variance components for a structured model",
    ButtonData:>{"Variance components for a structured model", 
      "VarianceComponents"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"VarianceComponents"],

Cell[TextData[{
  " Table option",
  ", ",
  ButtonBox["Variance components",
    ButtonData:>{"Variance components", "Table"},
    ButtonStyle->"AddOnsLink"]
}], "IndexSubentry",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"VarianceComponents"],

Cell[TextData[{
  "Versions",
  ",",
  " of applications packages",
  ", ",
  ButtonBox["Versions",
    ButtonData:>{"Versions", None},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Versions"],

Cell[TextData[{
  "Wiuf & Hein 1999",
  ",",
  " ",
  ButtonBox["Ancestral graph references",
    ButtonData:>{"Ancestral graph references", "Wiuf & Hein 1999"},
    ButtonStyle->"AddOnsLink"],
  ",",
  ButtonBox["Ancestral graphs introduction",
    ButtonData:>{"Ancestral graphs introduction", None},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Wiuf & Hein 1999"],

Cell[TextData[{
  "WLinkedLoci",
  ",",
  " example of",
  ", ",
  ButtonBox["Sex linkage",
    ButtonData:>{"Sex linkage", "WLinkedLoci"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"WLinkedLoci"],

Cell[TextData[{
  " option for NonMendelian",
  ", ",
  ButtonBox["Non-Mendelian inheritance",
    ButtonData:>{"Non-Mendelian inheritance", "WLinkedLoci"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " reference points",
  ", ",
  ButtonBox["Reference points",
    ButtonData:>{"Reference points", "WLinkedLoci"},
    ButtonStyle->"AddOnsLink"]
}], "IndexSubentry",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"WLinkedLoci"],

Cell[TextData[{
  "Wright-Fisher sampling",
  ",",
  " ",
  ButtonBox["Wright-Fisher sampling",
    ButtonData:>{"Wright-Fisher sampling", None},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Wright-Fisher sampling"],

Cell[TextData[{
  "X",
  ",",
  " AllelicState",
  ", ",
  ButtonBox["Allelic state",
    ButtonData:>{"Allelic state", "AllelicState"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"X"],

Cell[TextData[{
  "XLinkedLoci",
  ",",
  " example of",
  ", ",
  ButtonBox["Sex linkage",
    ButtonData:>{"Sex linkage", "XLinkedLoci"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"XLinkedLoci"],

Cell[TextData[{
  " option for NonMendelian",
  ", ",
  ButtonBox["Non-Mendelian inheritance",
    ButtonData:>{"Non-Mendelian inheritance", "XLinkedLoci"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " reference points",
  ", ",
  ButtonBox["Reference points",
    ButtonData:>{"Reference points", "XLinkedLoci"},
    ButtonStyle->"AddOnsLink"]
}], "IndexSubentry",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"XLinkedLoci"],

Cell[TextData[{
  "YLinkedLoci",
  ",",
  " example of",
  ", ",
  ButtonBox["Sex linkage",
    ButtonData:>{"Sex linkage", "YLinkedLoci"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"YLinkedLoci"],

Cell[TextData[{
  " option for NonMendelian",
  ", ",
  ButtonBox["Non-Mendelian inheritance",
    ButtonData:>{"Non-Mendelian inheritance", "YLinkedLoci"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " reference points",
  ", ",
  ButtonBox["Reference points",
    ButtonData:>{"Reference points", "YLinkedLoci"},
    ButtonStyle->"AddOnsLink"]
}], "IndexSubentry",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"YLinkedLoci"],

Cell[TextData[{
  "ZLinkedLoci",
  ",",
  " example of",
  ", ",
  ButtonBox["Sex linkage",
    ButtonData:>{"Sex linkage", "ZLinkedLoci"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"ZLinkedLoci"],

Cell[TextData[{
  " option for NonMendelian",
  ", ",
  ButtonBox["Non-Mendelian inheritance",
    ButtonData:>{"Non-Mendelian inheritance", "ZLinkedLoci"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  " reference points",
  ", ",
  ButtonBox["Reference points",
    ButtonData:>{"Reference points", "ZLinkedLoci"},
    ButtonStyle->"AddOnsLink"]
}], "IndexSubentry",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"ZLinkedLoci"],

Cell[TextData[{
  "Zygotes",
  ",",
  " \[GothicCapitalZ], \[AliasIndicator]goZ\[AliasIndicator]",
  ", ",
  ButtonBox["Life cycle",
    ButtonData:>{"Life cycle", "Zygotes"},
    ButtonStyle->"AddOnsLink"],
  ",",
  ButtonBox["Notation reference",
    ButtonData:>{"Notation reference", None},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"Zygotes"],

Cell[TextData[{
  "\[GothicA]",
  ",",
  " \[AliasIndicator]goa\[AliasIndicator], SelectionCoefficient",
  ", ",
  ButtonBox["Fitness",
    ButtonData:>{"Fitness", "SelectionCoefficient"},
    ButtonStyle->"AddOnsLink"],
  ",",
  ButtonBox["Selection",
    ButtonData:>{"Selection", "SelectionCoefficient"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"\[GothicA]"],

Cell[TextData[{
  "\[GothicCapitalA]",
  ",",
  " \[AliasIndicator]goA\[AliasIndicator], adults",
  ", ",
  ButtonBox["Life cycle",
    ButtonData:>{"Life cycle", "Adults"},
    ButtonStyle->"AddOnsLink"],
  ",",
  ButtonBox["Notation reference",
    ButtonData:>{"Notation reference", None},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"\[GothicCapitalA]"],

Cell[TextData[{
  "\[GothicCapitalC]",
  ",",
  " \[AliasIndicator]goC\[AliasIndicator], PopulationDisequilibrium",
  ", ",
  ButtonBox["Expectations",
    ButtonData:>{"Expectations", "PopulationDisequilibrium"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"\[GothicCapitalC]"],

Cell[TextData[{
  "\[GothicCapitalD]",
  ",",
  " \[AliasIndicator]\[GothicCapitalD]\[AliasIndicator], Disequilibrium",
  ", ",
  ButtonBox["Disequilibrium",
    ButtonData:>{"Disequilibrium", "Disequilibrium"},
    ButtonStyle->"AddOnsLink"],
  ",",
  ButtonBox["Gene & genotype frequencies",
    ButtonData:>{"Gene & genotype frequencies", "Linkage disequilibrium"},
    ButtonStyle->"AddOnsLink"],
  ",",
  ButtonBox["Populations",
    ButtonData:>{"Populations", "Disequilibrium"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"\[GothicCapitalD]"],

Cell[TextData[{
  "\!\(\(\[GothicCapitalG]\^*\)\)",
  ",",
  " \[AliasIndicator]goG\[AliasIndicator]\[ControlKey]^*, \
\[GothicCapitalG]new, new gametes",
  ", ",
  ButtonBox["Life cycle",
    ButtonData:>{"Life cycle", "Gametes new"},
    ButtonStyle->"AddOnsLink"],
  ",",
  ButtonBox["Notation reference",
    ButtonData:>{"Notation reference", None},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"\!\(\(\[GothicCapitalG]\^*\)\)"],

Cell[TextData[{
  "\[GothicCapitalG]",
  ",",
  " \[AliasIndicator]goG\[AliasIndicator], Gametes",
  ", ",
  ButtonBox["Life cycle",
    ButtonData:>{"Life cycle", "Gametes"},
    ButtonStyle->"AddOnsLink"],
  ",",
  ButtonBox["Notation reference",
    ButtonData:>{"Notation reference", None},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"\[GothicCapitalG]"],

Cell[TextData[{
  "\[GothicCapitalH]",
  ",",
  " \[AliasIndicator]goH\[AliasIndicator], hermaphrodites",
  ", ",
  ButtonBox["Life cycle",
    ButtonData:>{"Life cycle", "Hermaphrodites"},
    ButtonStyle->"AddOnsLink"],
  ",",
  ButtonBox["Notation reference",
    ButtonData:>{"Notation reference", None},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"\[GothicCapitalH]"],

Cell[TextData[{
  "\[GothicCapitalJ]",
  ",",
  " \[AliasIndicator]goJ\[AliasIndicator], juveniles",
  ", ",
  ButtonBox["Life cycle",
    ButtonData:>{"Life cycle", "Juveniles"},
    ButtonStyle->"AddOnsLink"],
  ",",
  ButtonBox["Notation reference",
    ButtonData:>{"Notation reference", None},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"\[GothicCapitalJ]"],

Cell[TextData[{
  "\[GothicK]",
  ",",
  " \[AliasIndicator]gok\[AliasIndicator], CumulantDisequilibrium",
  ", ",
  ButtonBox["Populations",
    ButtonData:>{"Populations", "CumulantDisequilibrium"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"\[GothicK]"],

Cell[TextData[{
  "\[GothicCapitalK]",
  ",",
  " \[AliasIndicator]goK\[AliasIndicator], CumulantPopulationDisequilibrium",
  ", ",
  ButtonBox["Introduction to random drift",
    ButtonData:>{"Introduction to random drift", "Cumulants and moments"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"\[GothicCapitalK]"],

Cell[TextData[{
  "\[GothicM]",
  ",",
  " \[AliasIndicator]gom\[AliasIndicator], MeanContribution",
  ", ",
  ButtonBox["Populations",
    ButtonData:>{"Populations", "MeanContribution"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"\[GothicM]"],

Cell[TextData[{
  "\[GothicP]",
  ",",
  " \[AliasIndicator]gop\[AliasIndicator], AlleleFrequencyP",
  ", ",
  ButtonBox["Populations",
    ButtonData:>{"Populations", "AlleleFrequencyP"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"\[GothicP]"],

Cell[TextData[{
  "\[GothicP]\[GothicQ]",
  ",",
  " \[AliasIndicator]gop\[AliasIndicator]\[AliasIndicator]goq\[AliasIndicator]\
, AlleleFrequencyPQ",
  ", ",
  ButtonBox["Populations",
    ButtonData:>{"Populations", "AlleleFrequencyPQ"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"\[GothicP]\[GothicQ]"],

Cell[TextData[{
  "\[GothicQ]",
  ",",
  " \[AliasIndicator]goq\[AliasIndicator], AlleleFrequencyQ",
  ", ",
  ButtonBox["Populations",
    ButtonData:>{"Populations", "AlleleFrequencyQ"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"\[GothicQ]"],

Cell[TextData[{
  "\[GothicR]",
  ",",
  " \[AliasIndicator]gor\[AliasIndicator], RecombinationRate",
  ", ",
  ButtonBox["Recombination",
    ButtonData:>{"Recombination", "RecombinationRate"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"\[GothicR]"],

Cell[TextData[{
  "\[GothicS]",
  ",",
  "\[AliasIndicator]gos\[AliasIndicator], SelectionRate",
  ", ",
  ButtonBox["Slow change",
    ButtonData:>{"Slow change", "SelectionRate"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"\[GothicS]"],

Cell[TextData[{
  "\[GothicCapitalZ]",
  ",",
  " \[AliasIndicator]goZ\[AliasIndicator], Zygotes",
  ", ",
  ButtonBox["Life cycle",
    ButtonData:>{"Life cycle", "Zygotes"},
    ButtonStyle->"AddOnsLink"],
  ",",
  ButtonBox["Notation reference",
    ButtonData:>{"Notation reference", None},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"\[GothicCapitalZ]"],

Cell[TextData[{
  "\[DoubleStruckCapitalG]",
  ",",
  " \[AliasIndicator]dsG\[AliasIndicator], set of all positions in genome",
  ", ",
  ButtonBox["Notation reference",
    ButtonData:>{"Notation reference", None},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"\[DoubleStruckCapitalG]"],

Cell[TextData[{
  "\[DoubleStruckCapitalM]",
  ",",
  " \[AliasIndicator]dsM\[AliasIndicator], MigrationSet",
  ", ",
  ButtonBox["Migration",
    ButtonData:>{"Migration", "MigrationSet"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"\[DoubleStruckCapitalM]"],

Cell[TextData[{
  "\[DoubleStruckCapitalR]",
  ",",
  " \[AliasIndicator]dsR\[AliasIndicator], RecombinationSet",
  ", ",
  ButtonBox["Notation reference",
    ButtonData:>{"Notation reference", None},
    ButtonStyle->"AddOnsLink"],
  ",",
  ButtonBox["Recombination",
    ButtonData:>{"Recombination", "RecombinationSet"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"\[DoubleStruckCapitalR]"],

Cell[TextData[{
  "\[DoubleStruckCapitalW]",
  ",",
  " \[AliasIndicator]dsW\[AliasIndicator], FitnessSet",
  ", ",
  ButtonBox["Selection",
    ButtonData:>{"Selection", "FitnessSet"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"\[DoubleStruckCapitalW]"],

Cell[TextData[{
  "\[DoubleStruckCapitalZ]",
  ",",
  " \[AliasIndicator]dsZ\[AliasIndicator], set of all positions affecting a \
trait",
  ", ",
  ButtonBox["Notation reference",
    ButtonData:>{"Notation reference", None},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"\[DoubleStruckCapitalZ]"],

Cell[TextData[{
  "\[Gamma]",
  ",",
  " \[AliasIndicator]g\[AliasIndicator], ExtractGenes",
  ", ",
  ButtonBox["Extracting contexts",
    ButtonData:>{"Extracting contexts", "ExtractGenes"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"\[Gamma]"],

Cell[TextData[{
  "\[Zeta]",
  ",",
  " \[AliasIndicator]z\[AliasIndicator], AllelicDeviation",
  ", ",
  ButtonBox["Allelic state",
    ButtonData:>{"Allelic state", "AllelicDeviation"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"\[Zeta]"],

Cell[TextData[{
  "\[CapitalMu]",
  ",",
  " \[AliasIndicator]M\[AliasIndicator], MigrationRate",
  ", ",
  ButtonBox["Notation reference",
    ButtonData:>{"Notation reference", None},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"\[CapitalMu]"],

Cell[TextData[{
  "\[Chi]",
  ",",
  " \[AliasIndicator]c\[AliasIndicator], ExtractContexts",
  ", ",
  ButtonBox["Extracting contexts",
    ButtonData:>{"Extracting contexts", "ExtractContexts"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"\[Chi]"],

Cell[TextData[{
  "\[Sampi]",
  ",",
  " \[AliasIndicator]sa\[AliasIndicator], Stage",
  ", ",
  ButtonBox["Genes and contexts",
    ButtonData:>{"Genes and contexts", "Stages"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"\[Sampi]"],

Cell[TextData[{
  "$MetropolisAdjustment",
  ",",
  " ",
  ButtonBox["Metropolis algorithm",
    ButtonData:>{"Metropolis algorithm", "$MetropolisAdjustment"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"$MetropolisAdjustment"],

Cell[TextData[{
  "\[WeierstrassP]",
  ",",
  " \[AliasIndicator]wp\[AliasIndicator], ReferencePoint",
  ", ",
  ButtonBox["Allelic state",
    ButtonData:>{"Allelic state", "ReferencePoint"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"\[WeierstrassP]"],

Cell[TextData[{
  "\[LeftDoubleBracketingBar] \[RightDoubleBracketingBar]",
  ",",
  " \[AliasIndicator]l||\[AliasIndicator] \[AliasIndicator]r||\
\[AliasIndicator], population expectation",
  ", ",
  ButtonBox["Expectations",
    ButtonData:>{"Expectations", "PopulationExpectation"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"\[LeftDoubleBracketingBar] \[RightDoubleBracketingBar]"],

Cell[TextData[{
  "\[CircleDot]",
  ",",
  " \[AliasIndicator]c.\[AliasIndicator], SelectContext",
  ", ",
  ButtonBox["Selecting contexts",
    ButtonData:>{"Selecting contexts", "SelectContexts"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"\[CircleDot]"],

Cell[TextData[{
  "\[Backslash], \[AliasIndicator]\[AliasIndicator], TakeAway, ",
  ButtonBox["Operations on sets",
    ButtonData:>{"Operations on sets", "TakeAway"},
    ButtonStyle->"AddOnsLink"],
  ",",
  ButtonBox["TakeAway",
    ButtonData:>{"TakeAway", "TakeAway"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"\[Backslash]"],

Cell[TextData[{
  "\[Wedge]",
  ",",
  " \[AliasIndicator]^\[AliasIndicator], ExactIntersection",
  ", ",
  ButtonBox["ExactIntersection",
    ButtonData:>{"ExactIntersection", "ExactIntersection"},
    ButtonStyle->"AddOnsLink"],
  ",",
  ButtonBox["Operations on sets",
    ButtonData:>{"Operations on sets", "ExactIntersection"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"\[Wedge]"],

Cell[TextData[{
  "\[CirclePlus]",
  ",",
  " \[AliasIndicator]c+\[AliasIndicator], ChangeContext",
  ", ",
  ButtonBox["Changing contexts",
    ButtonData:>{"Changing contexts", "ChangeContext"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"\[CirclePlus]"]
},
FrontEndVersion->"4.0 for Macintosh",
ScreenRectangle->{{0, 1152}, {0, 748}},
WindowSize->{1011, 628},
WindowMargins->{{0, Automatic}, {Automatic, 12}},
StyleDefinitions -> "HelpBrowser.nb",
MacintoshSystemPageSetup->"\<\
00h0001804P000000b02<?oaonl3>@91H`85N0?N0@00005X0FP000003j0:l001
0@00I00100000@0200000BL?00400000000000000000010000000000000@0?ne
oj/@7@]500P1000000000000000001T1\>"
]


(***********************************************************************
Cached data follows.  If you edit this Notebook file directly, not using
Mathematica, you must remove the line containing CacheID at the top of 
the file.  The cache data will then be recreated when you save this file 
from within Mathematica.
***********************************************************************)

(*CellTagsOutline
CellTagsIndex->{
  "MasterIndexHeading"->{
    Cell[1717, 49, 79, 1, 41, "IndexSection",
      CellTags->"MasterIndexHeading"]},
  "|."->{
    Cell[1799, 52, 247, 11, 15, "Index",
      CellTags->"|."]},
  "\\\\"->{
    Cell[2049, 65, 233, 11, 15, "Index",
      CellTags->"\\\\"]},
  "<>"->{
    Cell[2285, 78, 243, 11, 15, "Index",
      CellTags->"<>"]},
  "||."->{
    Cell[2531, 91, 254, 11, 15, "Index",
      CellTags->"||."]},
  "AddAncestors"->{
    Cell[2788, 104, 296, 11, 15, "Index",
      CellTags->"AddAncestors"]},
  "AddCoalescentLineage"->{
    Cell[3087, 117, 331, 11, 15, "Index",
      CellTags->"AddCoalescentLineage"]},
  "AddDescendants"->{
    Cell[3421, 130, 302, 11, 15, "Index",
      CellTags->"AddDescendants"]},
  "AddGenealogy"->{
    Cell[3726, 143, 271, 10, 15, "Index",
      CellTags->"AddGenealogy"]},
  "Additive models"->{
    Cell[4000, 155, 272, 10, 15, "Index",
      CellTags->"Additive models"]},
  "Additive selection"->{
    Cell[4275, 167, 303, 11, 15, "Index",
      CellTags->"Additive selection"],
    Cell[4581, 180, 713, 27, 60, "IndexSubentry",
      CellTags->"Additive selection"]},
  "AddMutation"->{
    Cell[5297, 209, 268, 10, 15, "Index",
      CellTags->"AddMutation"]},
  "AddNode"->{
    Cell[5568, 221, 256, 10, 15, "Index",
      CellTags->"AddNode"]},
  "AddRecombinantLineages"->{
    Cell[5827, 233, 337, 11, 15, "Index",
      CellTags->"AddRecombinantLineages"]},
  "AddTag"->{
    Cell[6167, 246, 229, 10, 15, "Index",
      CellTags->"AddTag"]},
  "AddUp"->{
    Cell[6399, 258, 334, 14, 15, "Index",
      CellTags->"AddUp"],
    Cell[6736, 274, 492, 21, 45, "IndexSubentry",
      CellTags->"AddUp"]},
  "AdmixtureFrequency"->{
    Cell[7231, 297, 261, 10, 15, "Index",
      CellTags->"AdmixtureFrequency"]},
  "Admixture models"->{
    Cell[7495, 309, 352, 14, 15, "Index",
      CellTags->"Admixture models"],
    Cell[7850, 325, 843, 33, 75, "IndexSubentry",
      CellTags->"Admixture models"]},
  "Adults"->{
    Cell[8696, 360, 408, 15, 15, "Index",
      CellTags->"Adults"]},
  "Allele frequencies"->{
    Cell[9107, 377, 326, 11, 15, "Index",
      CellTags->"Allele frequencies"],
    Cell[9436, 390, 287, 9, 15, "IndexSubentry",
      CellTags->"Allele frequencies"]},
  "AlleleFrequencies"->{
    Cell[9726, 401, 472, 15, 15, "Index",
      CellTags->"AlleleFrequencies"]},
  "AlleleFrequency"->{
    Cell[10201, 418, 286, 10, 15, "Index",
      CellTags->"AlleleFrequency"]},
  "AlleleFrequencyMean"->{
    Cell[10490, 430, 298, 10, 15, "Index",
      CellTags->"AlleleFrequencyMean"],
    Cell[10791, 442, 959, 30, 60, "IndexSubentry",
      CellTags->"AlleleFrequencyMean"]},
  "AlleleFrequencyP"->{
    Cell[11753, 474, 314, 11, 23, "Index",
      CellTags->"AlleleFrequencyP"]},
  "AlleleFrequencyPermutations"->{
    Cell[12070, 487, 304, 10, 23, "Index",
      CellTags->"AlleleFrequencyPermutations"]},
  "AlleleFrequencyPQ"->{
    Cell[12377, 499, 366, 12, 23, "Index",
      CellTags->"AlleleFrequencyPQ"]},
  "AlleleFrequencyQ"->{
    Cell[12746, 513, 314, 11, 23, "Index",
      CellTags->"AlleleFrequencyQ"]},
  "AlleleFrequencyTable"->{
    Cell[13063, 526, 301, 10, 23, "Index",
      CellTags->"AlleleFrequencyTable"],
    Cell[13367, 538, 1143, 36, 83, "IndexSubentry",
      CellTags->"AlleleFrequencyTable"]},
  "AllelicDeviation"->{
    Cell[14513, 576, 313, 11, 23, "Index",
      CellTags->"AllelicDeviation"]},
  "AllelicState"->{
    Cell[14829, 589, 258, 11, 23, "Index",
      CellTags->"AllelicState"]},
  "AllEvents"->{
    Cell[15090, 602, 295, 11, 23, "Index",
      CellTags->"AllEvents"]},
  "AllSets"->{
    Cell[15388, 615, 258, 10, 23, "Index",
      CellTags->"AllSets"]},
  "Ancestors"->{
    Cell[15649, 627, 273, 11, 23, "Index",
      CellTags->"Ancestors"],
    Cell[15925, 640, 273, 9, 23, "IndexSubentry",
      CellTags->"Ancestors"]},
  "AncestralGraphPattern"->{
    Cell[16201, 651, 308, 10, 23, "Index",
      CellTags->"AncestralGraphPattern"]},
  "Ancestral graphs"->{
    Cell[16512, 663, 293, 11, 23, "Index",
      CellTags->"Ancestral graphs"],
    Cell[16808, 676, 926, 33, 83, "IndexSubentry",
      CellTags->"Ancestral graphs"]},
  "AncestralLineage"->{
    Cell[17737, 711, 293, 10, 23, "Index",
      CellTags->"AncestralLineage"]},
  "AncestralLineagePattern"->{
    Cell[18033, 723, 314, 10, 23, "Index",
      CellTags->"AncestralLineagePattern"]},
  "Ancestry"->{
    Cell[18350, 735, 255, 10, 23, "Index",
      CellTags->"Ancestry"]},
  "Arbitrary sets of loci"->{
    Cell[18608, 747, 334, 11, 23, "Index",
      CellTags->"Arbitrary sets of loci"]},
  "Arnold 1996"->{
    Cell[18945, 760, 240, 10, 23, "Index",
      CellTags->"Arnold 1996"]},
  "Asmussen and Orive 2000"->{
    Cell[19188, 772, 414, 14, 23, "Index",
      CellTags->"Asmussen and Orive 2000"]},
  "Asmussen et al. 1987"->{
    Cell[19605, 788, 266, 10, 23, "Index",
      CellTags->"Asmussen et al. 1987"]},
  "B"->{
    Cell[19874, 800, 256, 10, 23, "Index",
      CellTags->"B"]},
  "Baake 2001"->{
    Cell[20133, 812, 363, 14, 23, "Index",
      CellTags->"Baake 2001"]},
  "BackgroundStyle"->{
    Cell[20499, 828, 313, 11, 23, "Index",
      CellTags->"BackgroundStyle"]},
  "Barrier"->{
    Cell[20815, 841, 276, 11, 23, "Index",
      CellTags->"Barrier"]},
  "BarrierStrength"->{
    Cell[21094, 854, 276, 10, 23, "Index",
      CellTags->"BarrierStrength"]},
  "Barton 1986"->{
    Cell[21373, 866, 240, 10, 23, "Index",
      CellTags->"Barton 1986"]},
  "Barton 1995"->{
    Cell[21616, 878, 262, 10, 23, "Index",
      CellTags->"Barton 1995"]},
  "Barton 2000"->{
    Cell[21881, 890, 240, 10, 23, "Index",
      CellTags->"Barton 2000"]},
  "Barton and Turelli 1991"->{
    Cell[22124, 902, 298, 10, 23, "Index",
      CellTags->"Barton and Turelli 1991"]},
  "Barton & Gale 1993"->{
    Cell[22425, 914, 261, 10, 23, "Index",
      CellTags->"Barton & Gale 1993"]},
  "Barton & Shpak 1999"->{
    Cell[22689, 926, 264, 10, 23, "Index",
      CellTags->"Barton & Shpak 1999"]},
  "Barton & Turelli 1991"->{
    Cell[22956, 938, 270, 10, 23, "Index",
      CellTags->"Barton & Turelli 1991"]},
  "Bennett 1954"->{
    Cell[23229, 950, 243, 10, 23, "Index",
      CellTags->"Bennett 1954"]},
  "BennettB"->{
    Cell[23475, 962, 251, 10, 23, "Index",
      CellTags->"BennettB"]},
  "BennettC"->{
    Cell[23729, 974, 251, 10, 23, "Index",
      CellTags->"BennettC"]},
  "BennettExpansion"->{
    Cell[23983, 986, 275, 10, 23, "Index",
      CellTags->"BennettExpansion"]},
  "Biallelic"->{
    Cell[24261, 998, 236, 10, 23, "Index",
      CellTags->"Biallelic"],
    Cell[24500, 1010, 358, 13, 23, "IndexSubentry",
      CellTags->"Biallelic"]},
  "BiallelicMutation"->{
    Cell[24861, 1025, 276, 10, 23, "Index",
      CellTags->"BiallelicMutation"],
    Cell[25140, 1037, 268, 9, 23, "IndexSubentry",
      CellTags->"BiallelicMutation"]},
  "Binary integers"->{
    Cell[25411, 1048, 266, 10, 23, "Index",
      CellTags->"Binary integers"]},
  "Birth"->{
    Cell[25680, 1060, 262, 10, 23, "Index",
      CellTags->"Birth"]},
  "BirthTime"->{
    Cell[25945, 1072, 258, 10, 23, "Index",
      CellTags->"BirthTime"]},
  "Boundary conditions"->{
    Cell[26206, 1084, 447, 15, 23, "Index",
      CellTags->"Boundary conditions"]},
  "Box"->{
    Cell[26656, 1101, 240, 10, 23, "Index",
      CellTags->"Box"]},
  "Boxes"->{
    Cell[26899, 1113, 246, 10, 23, "Index",
      CellTags->"Boxes"]},
  "Browser categories"->{
    Cell[27148, 1125, 293, 10, 23, "Index",
      CellTags->"Browser categories"]},
  "Bugs"->{
    Cell[27444, 1137, 239, 11, 23, "Index",
      CellTags->"Bugs"],
    Cell[27686, 1150, 1583, 63, 158, "IndexSubentry",
      CellTags->"Bugs"]},
  "ChangeContext"->{
    Cell[29272, 1215, 318, 11, 23, "Index",
      CellTags->"ChangeContext"]},
  "ChangeSex"->{
    Cell[29593, 1228, 238, 10, 23, "Index",
      CellTags->"ChangeSex"]},
  "ClassToGenotypes"->{
    Cell[29834, 1240, 289, 10, 23, "Index",
      CellTags->"ClassToGenotypes"]},
  "Cline"->{
    Cell[30126, 1252, 253, 11, 23, "Index",
      CellTags->"Cline"],
    Cell[30382, 1265, 2662, 78, 113, "IndexSubentry",
      CellTags->"Cline"]},
  "ClineGradient"->{
    Cell[33047, 1345, 325, 11, 23, "Index",
      CellTags->"ClineGradient"]},
  "ClineWidth"->{
    Cell[33375, 1358, 323, 11, 15, "Index",
      CellTags->"ClineWidth"],
    Cell[33701, 1371, 695, 21, 45, "IndexSubentry",
      CellTags->"ClineWidth"]},
  "CoalesceLineages"->{
    Cell[34399, 1394, 293, 10, 15, "Index",
      CellTags->"CoalesceLineages"]},
  "CoalescenceDistribution"->{
    Cell[34695, 1406, 329, 11, 15, "Index",
      CellTags->"CoalescenceDistribution"]},
  "CoalescenceEvents"->{
    Cell[35027, 1419, 319, 11, 15, "Index",
      CellTags->"CoalescenceEvents"]},
  "Coalescence times"->{
    Cell[35349, 1432, 325, 11, 15, "Index",
      CellTags->"Coalescence times"]},
  "CoalescentLineages"->{
    Cell[35677, 1445, 322, 11, 15, "Index",
      CellTags->"CoalescentLineages"]},
  "Coalescing lineages"->{
    Cell[36002, 1458, 326, 11, 15, "Index",
      CellTags->"Coalescing lineages"]},
  "CollapseGenealogy"->{
    Cell[36331, 1471, 282, 10, 15, "Index",
      CellTags->"CollapseGenealogy"]},
  "Combinations"->{
    Cell[36616, 1483, 274, 11, 15, "Index",
      CellTags->"Combinations"]},
  "Combine"->{
    Cell[36893, 1496, 232, 10, 15, "Index",
      CellTags->"Combine"]},
  "CompareLogL"->{
    Cell[37128, 1508, 256, 10, 15, "Index",
      CellTags->"CompareLogL"]},
  "Compiled"->{
    Cell[37387, 1520, 1075, 31, 30, "Index",
      CellTags->"Compiled"]},
  "Compiling"->{
    Cell[38465, 1553, 1073, 31, 30, "Index",
      CellTags->"Compiling"]},
  "CondenseGenealogy"->{
    Cell[39541, 1586, 286, 10, 15, "Index",
      CellTags->"CondenseGenealogy"]},
  "CondenseMatrix"->{
    Cell[39830, 1598, 271, 10, 15, "Index",
      CellTags->"CondenseMatrix"]},
  "ConfigurationSet"->{
    Cell[40104, 1610, 267, 10, 15, "Index",
      CellTags->"ConfigurationSet"]},
  "ConstrainedIntervals"->{
    Cell[40374, 1622, 289, 10, 15, "Index",
      CellTags->"ConstrainedIntervals"]},
  "ConstructMutateList"->{
    Cell[40666, 1634, 754, 22, 15, "Index",
      CellTags->"ConstructMutateList"]},
  "ConstructMutateMatrix"->{
    Cell[41423, 1658, 442, 14, 15, "Index",
      CellTags->"ConstructMutateMatrix"]},
  "ContextComponentQ"->{
    Cell[41868, 1674, 286, 10, 15, "Index",
      CellTags->"ContextComponentQ"]},
  "ContextPosition"->{
    Cell[42157, 1686, 280, 10, 15, "Index",
      CellTags->"ContextPosition"]},
  "ContextStageQ"->{
    Cell[42440, 1698, 274, 10, 15, "Index",
      CellTags->"ContextStageQ"]},
  "ContextStructure"->{
    Cell[42717, 1710, 283, 10, 15, "Index",
      CellTags->"ContextStructure"]},
  "Continuous populations"->{
    Cell[43003, 1722, 312, 11, 15, "Index",
      CellTags->"Continuous populations"],
    Cell[43318, 1735, 665, 27, 60, "IndexSubentry",
      CellTags->"Continuous populations"]},
  "ContinuumVariables"->{
    Cell[43986, 1764, 273, 10, 15, "Index",
      CellTags->"ContinuumVariables"]},
  "ConvertData"->{
    Cell[44262, 1776, 260, 10, 15, "Index",
      CellTags->"ConvertData"]},
  "ConvertHyperlinkToAddOnsLink"->{
    Cell[44525, 1788, 291, 10, 15, "Index",
      CellTags->"ConvertHyperlinkToAddOnsLink"]},
  "Converting"->{
    Cell[44819, 1800, 427, 15, 15, "Index",
      CellTags->"Converting"]},
  "CountHeterozygotes"->{
    Cell[45249, 1817, 287, 10, 15, "Index",
      CellTags->"CountHeterozygotes"]},
  "Covariance"->{
    Cell[45539, 1829, 292, 11, 15, "Index",
      CellTags->"Covariance"]},
  "CovarianceMidPoints"->{
    Cell[45834, 1842, 260, 10, 15, "Index",
      CellTags->"CovarianceMidPoints"]},
  "Crow and Kimura 1970"->{
    Cell[46097, 1854, 289, 10, 15, "Index",
      CellTags->"Crow and Kimura 1970"]},
  "Cumulant"->{
    Cell[46389, 1866, 253, 10, 23, "Index",
      CellTags->"Cumulant"]},
  "CumulantDisequilibrium"->{
    Cell[46645, 1878, 332, 11, 23, "Index",
      CellTags->"CumulantDisequilibrium"]},
  "CumulantEquilibrium"->{
    Cell[46980, 1891, 264, 10, 23, "Index",
      CellTags->"CumulantEquilibrium"]},
  "CumulantPopulationDisequilibrium"->{
    Cell[47247, 1903, 392, 11, 23, "Index",
      CellTags->"CumulantPopulationDisequilibrium"]},
  "CumulantReduced"->{
    Cell[47642, 1916, 268, 10, 23, "Index",
      CellTags->"CumulantReduced"]},
  "Cumulants"->{
    Cell[47913, 1928, 333, 14, 23, "Index",
      CellTags->"Cumulants"]},
  "Cytoplasmic inheritance"->{
    Cell[48249, 1944, 426, 14, 23, "Index",
      CellTags->"Cytoplasmic inheritance"],
    Cell[48678, 1960, 440, 15, 38, "IndexSubentry",
      CellTags->"Cytoplasmic inheritance"]},
  "CytoplasmicLoci"->{
    Cell[49121, 1977, 283, 11, 23, "Index",
      CellTags->"CytoplasmicLoci"],
    Cell[49407, 1990, 453, 15, 38, "IndexSubentry",
      CellTags->"CytoplasmicLoci"]},
  "dAlleleFrequencyPermutations"->{
    Cell[49863, 2007, 307, 10, 23, "Index",
      CellTags->"dAlleleFrequencyPermutations"]},
  "Data"->{
    Cell[50173, 2019, 235, 10, 23, "Index",
      CellTags->"Data"],
    Cell[50411, 2031, 423, 15, 38, "IndexSubentry",
      CellTags->"Data"]},
  "Datasets"->{
    Cell[50837, 2048, 259, 11, 23, "Index",
      CellTags->"Datasets"]},
  "Dawson 2000"->{
    Cell[51099, 2061, 368, 14, 23, "Index",
      CellTags->"Dawson 2000"]},
  "Death"->{
    Cell[51470, 2077, 262, 10, 23, "Index",
      CellTags->"Death"]},
  "DeathTime"->{
    Cell[51735, 2089, 258, 10, 23, "Index",
      CellTags->"DeathTime"]},
  "DefineContext"->{
    Cell[51996, 2101, 274, 10, 23, "Index",
      CellTags->"DefineContext"]},
  "DegreesOfFreedom"->{
    Cell[52273, 2113, 271, 10, 23, "Index",
      CellTags->"DegreesOfFreedom"]},
  "DeletedMutations"->{
    Cell[52547, 2125, 279, 10, 23, "Index",
      CellTags->"DeletedMutations"]},
  "DeleteGenealogy"->{
    Cell[52829, 2137, 280, 10, 23, "Index",
      CellTags->"DeleteGenealogy"]},
  "DeleteNullLineages"->{
    Cell[53112, 2149, 321, 11, 23, "Index",
      CellTags->"DeleteNullLineages"],
    Cell[53436, 2162, 311, 9, 23, "IndexSubentry",
      CellTags->"DeleteNullLineages"]},
  "Deme"->{
    Cell[53750, 2173, 322, 14, 23, "Index",
      CellTags->"Deme"]},
  "DemeSize"->{
    Cell[54075, 2189, 614, 20, 23, "Index",
      CellTags->"DemeSize"],
    Cell[54692, 2211, 3026, 86, 142, "IndexSubentry",
      CellTags->"DemeSize"]},
  "Dempster et al 1977"->{
    Cell[57721, 2299, 264, 10, 23, "Index",
      CellTags->"Dempster et al 1977"]},
  "Density"->{
    Cell[57988, 2311, 252, 10, 23, "Index",
      CellTags->"Density"]},
  "Descendants"->{
    Cell[58243, 2323, 270, 10, 23, "Index",
      CellTags->"Descendants"],
    Cell[58516, 2335, 436, 15, 38, "IndexSubentry",
      CellTags->"Descendants"]},
  "Dicytonuclear associations"->{
    Cell[58955, 2352, 296, 10, 23, "Index",
      CellTags->"Dicytonuclear associations"]},
  "Diploid"->{
    Cell[59254, 2364, 304, 11, 23, "Index",
      CellTags->"Diploid"]},
  "DiploidConstraints"->{
    Cell[59561, 2377, 277, 10, 23, "Index",
      CellTags->"DiploidConstraints"]},
  "DiploidFrequencies"->{
    Cell[59841, 2389, 297, 10, 23, "Index",
      CellTags->"DiploidFrequencies"]},
  "DiploidGenotypeFrequency"->{
    Cell[60141, 2401, 332, 11, 23, "Index",
      CellTags->"DiploidGenotypeFrequency"]},
  "DiploidGenotypeFrequencyList"->{
    Cell[60476, 2414, 305, 10, 23, "Index",
      CellTags->"DiploidGenotypeFrequencyList"]},
  "DiploidGenotypeFrequencyReduced"->{
    Cell[60784, 2426, 316, 10, 23, "Index",
      CellTags->"DiploidGenotypeFrequencyReduced"]},
  "DiploidGenotypeFrequencyTable"->{
    Cell[61103, 2438, 310, 10, 23, "Index",
      CellTags->"DiploidGenotypeFrequencyTable"]},
  "DiploidIndividuals"->{
    Cell[61416, 2450, 297, 10, 23, "Index",
      CellTags->"DiploidIndividuals"]},
  "DiploidPhenotype"->{
    Cell[61716, 2462, 275, 10, 23, "Index",
      CellTags->"DiploidPhenotype"]},
  "DiploidPsi"->{
    Cell[61994, 2474, 402, 14, 23, "Index",
      CellTags->"DiploidPsi"]},
  "DiploidRepresentations"->{
    Cell[62399, 2490, 309, 10, 23, "Index",
      CellTags->"DiploidRepresentations"]},
  "DiploidSource"->{
    Cell[62711, 2502, 414, 14, 23, "Index",
      CellTags->"DiploidSource"]},
  "DiploidSubsets"->{
    Cell[63128, 2518, 259, 10, 23, "Index",
      CellTags->"DiploidSubsets"]},
  "DiploidTypes"->{
    Cell[63390, 2530, 257, 10, 23, "Index",
      CellTags->"DiploidTypes"]},
  "Disequilibrium"->{
    Cell[63650, 2542, 283, 11, 23, "Index",
      CellTags->"Disequilibrium"],
    Cell[63936, 2555, 919, 29, 53, "IndexSubentry",
      CellTags->"Disequilibrium"]},
  "DisequilibriumMean"->{
    Cell[64858, 2586, 339, 11, 23, "Index",
      CellTags->"DisequilibriumMean"],
    Cell[65200, 2599, 744, 23, 53, "IndexSubentry",
      CellTags->"DisequilibriumMean"]},
  "DisequilibriumTable"->{
    Cell[65947, 2624, 347, 12, 23, "Index",
      CellTags->"DisequilibriumTable"],
    Cell[66297, 2638, 748, 23, 53, "IndexSubentry",
      CellTags->"DisequilibriumTable"]},
  "Dispersal"->{
    Cell[67048, 2663, 299, 11, 23, "Index",
      CellTags->"Dispersal"]},
  "DistanceSquared"->{
    Cell[67350, 2676, 276, 10, 23, "Index",
      CellTags->"DistanceSquared"]},
  "Distribution"->{
    Cell[67629, 2688, 241, 10, 23, "Index",
      CellTags->"Distribution"]},
  "DivideZero"->{
    Cell[67873, 2700, 237, 10, 23, "Index",
      CellTags->"DivideZero"]},
  "DoReplicates"->{
    Cell[68113, 2712, 277, 10, 23, "Index",
      CellTags->"DoReplicates"]},
  "DoubleCline"->{
    Cell[68393, 2724, 353, 12, 23, "Index",
      CellTags->"DoubleCline"],
    Cell[68749, 2738, 772, 23, 53, "IndexSubentry",
      CellTags->"DoubleCline"]},
  "DrawSamples"->{
    Cell[69524, 2763, 262, 10, 23, "Index",
      CellTags->"DrawSamples"]},
  "DropOptions"->{
    Cell[69789, 2775, 260, 10, 23, "Index",
      CellTags->"DropOptions"]},
  "Edwards 1972"->{
    Cell[70052, 2787, 243, 10, 23, "Index",
      CellTags->"Edwards 1972"]},
  "EmptySets"->{
    Cell[70298, 2799, 272, 11, 23, "Index",
      CellTags->"EmptySets"]},
  "Epistasis"->{
    Cell[70573, 2812, 270, 11, 23, "Index",
      CellTags->"Epistasis"]},
  "EquivalentSexes"->{
    Cell[70846, 2825, 300, 11, 23, "Index",
      CellTags->"EquivalentSexes"]},
  "ErrorBound"->{
    Cell[71149, 2838, 267, 10, 23, "Index",
      CellTags->"ErrorBound"]},
  "EstimateFamilyMoments"->{
    Cell[71419, 2850, 298, 10, 23, "Index",
      CellTags->"EstimateFamilyMoments"]},
  "EstimateMoments"->{
    Cell[71720, 2862, 274, 10, 23, "Index",
      CellTags->"EstimateMoments"]},
  "Estimating D"->{
    Cell[71997, 2874, 269, 11, 23, "Index",
      CellTags->"Estimating D"],
    Cell[72269, 2887, 2407, 92, 218, "IndexSubentry",
      CellTags->"Estimating D"]},
  "ExactEigenvalues"->{
    Cell[74679, 2981, 293, 10, 23, "Index",
      CellTags->"ExactEigenvalues"]},
  "ExactIntersection"->{
    Cell[74975, 2993, 459, 15, 23, "Index",
      CellTags->"ExactIntersection"]},
  "ExactProbability"->{
    Cell[75437, 3010, 269, 10, 23, "Index",
      CellTags->"ExactProbability"]},
  "Expectation"->{
    Cell[75709, 3022, 252, 11, 23, "Index",
      CellTags->"Expectation"],
    Cell[75964, 3035, 572, 16, 38, "IndexSubentry",
      CellTags->"Expectation"]},
  "ExponentialF"->{
    Cell[76539, 3053, 329, 11, 23, "Index",
      CellTags->"ExponentialF"],
    Cell[76871, 3066, 877, 26, 53, "IndexSubentry",
      CellTags->"ExponentialF"]},
  "ExtantIndividuals"->{
    Cell[77751, 3094, 270, 10, 23, "Index",
      CellTags->"ExtantIndividuals"]},
  "ExtractContexts"->{
    Cell[78024, 3106, 321, 11, 23, "Index",
      CellTags->"ExtractContexts"]},
  "ExtractExtant"->{
    Cell[78348, 3119, 242, 10, 23, "Index",
      CellTags->"ExtractExtant"]},
  "ExtractGenealogy"->{
    Cell[78593, 3131, 424, 14, 23, "Index",
      CellTags->"ExtractGenealogy"]},
  "ExtractGenes"->{
    Cell[79020, 3147, 314, 11, 23, "Index",
      CellTags->"ExtractGenes"]},
  "ExtractInformation"->{
    Cell[79337, 3160, 285, 10, 23, "Index",
      CellTags->"ExtractInformation"],
    Cell[79625, 3172, 301, 9, 23, "IndexSubentry",
      CellTags->"ExtractInformation"]},
  "ExtractLabel"->{
    Cell[79929, 3183, 306, 11, 23, "Index",
      CellTags->"ExtractLabel"]},
  "ExtractLineagesEndingAtT"->{
    Cell[80238, 3196, 342, 11, 23, "Index",
      CellTags->"ExtractLineagesEndingAtT"]},
  "ExtractLineagesStartingAtT"->{
    Cell[80583, 3209, 353, 12, 23, "Index",
      CellTags->"ExtractLineagesStartingAtT"]},
  "ExtractRepeat"->{
    Cell[80939, 3223, 260, 10, 23, "Index",
      CellTags->"ExtractRepeat"]},
  "ExtractSubMatrix"->{
    Cell[81202, 3235, 279, 10, 23, "Index",
      CellTags->"ExtractSubMatrix"]},
  "FamilyAlleleFrequencyEstimate"->{
    Cell[81484, 3247, 327, 11, 23, "Index",
      CellTags->"FamilyAlleleFrequencyEstimate"]},
  "FamilyEffects"->{
    Cell[81814, 3260, 274, 10, 23, "Index",
      CellTags->"FamilyEffects"]},
  "FamilyM"->{
    Cell[82091, 3272, 256, 10, 23, "Index",
      CellTags->"FamilyM"]},
  "FamilyProbability"->{
    Cell[82350, 3284, 264, 10, 23, "Index",
      CellTags->"FamilyProbability"]},
  "Family structure"->{
    Cell[82617, 3296, 291, 11, 23, "Index",
      CellTags->"Family structure"]},
  "Fecundity"->{
    Cell[82911, 3309, 258, 10, 23, "Index",
      CellTags->"Fecundity"]},
  "FindHyperlinks"->{
    Cell[83172, 3321, 249, 10, 23, "Index",
      CellTags->"FindHyperlinks"]},
  "FindIndexTag"->{
    Cell[83424, 3333, 243, 10, 23, "Index",
      CellTags->"FindIndexTag"]},
  "FindMLE"->{
    Cell[83670, 3345, 238, 10, 23, "Index",
      CellTags->"FindMLE"]},
  "FindNode"->{
    Cell[83911, 3357, 253, 10, 23, "Index",
      CellTags->"FindNode"]},
  "FindPosition"->{
    Cell[84167, 3369, 239, 10, 23, "Index",
      CellTags->"FindPosition"]},
  "FindTags"->{
    Cell[84409, 3381, 249, 10, 23, "Index",
      CellTags->"FindTags"]},
  "Fitness"->{
    Cell[84661, 3393, 316, 11, 23, "Index",
      CellTags->"Fitness"],
    Cell[84980, 3406, 618, 21, 53, "IndexSubentry",
      CellTags->"Fitness"]},
  "FitnessSet"->{
    Cell[85601, 3429, 305, 11, 23, "Index",
      CellTags->"FitnessSet"]},
  "FitnessTable"->{
    Cell[85909, 3442, 295, 11, 23, "Index",
      CellTags->"FitnessTable"],
    Cell[86207, 3455, 475, 15, 38, "IndexSubentry",
      CellTags->"FitnessTable"]},
  "FixedEnds"->{
    Cell[86685, 3472, 300, 11, 23, "Index",
      CellTags->"FixedEnds"],
    Cell[86988, 3485, 1296, 37, 67, "IndexSubentry",
      CellTags->"FixedEnds"]},
  "Flatten"->{
    Cell[88287, 3524, 278, 10, 23, "Index",
      CellTags->"Flatten"]},
  "FlattenList"->{
    Cell[88568, 3536, 274, 10, 23, "Index",
      CellTags->"FlattenList"],
    Cell[88845, 3548, 277, 9, 23, "IndexSubentry",
      CellTags->"FlattenList"]},
  "FourierNormalised"->{
    Cell[89125, 3559, 274, 10, 23, "Index",
      CellTags->"FourierNormalised"]},
  "FourierNormalisedTable"->{
    Cell[89402, 3571, 289, 10, 23, "Index",
      CellTags->"FourierNormalisedTable"]},
  "FrequencyRepresentations"->{
    Cell[89694, 3583, 315, 10, 23, "Index",
      CellTags->"FrequencyRepresentations"]},
  "FromBaake"->{
    Cell[90012, 3595, 254, 10, 23, "Index",
      CellTags->"FromBaake"]},
  "FromBennett"->{
    Cell[90269, 3607, 260, 10, 23, "Index",
      CellTags->"FromBennett"]},
  "FromBennettExpression"->{
    Cell[90532, 3619, 290, 10, 23, "Index",
      CellTags->"FromBennettExpression"]},
  "FullContext"->{
    Cell[90825, 3631, 262, 10, 23, "Index",
      CellTags->"FullContext"]},
  "FullGenotypeFrequencyReduced"->{
    Cell[91090, 3643, 307, 10, 23, "Index",
      CellTags->"FullGenotypeFrequencyReduced"]},
  "FullGenotypeFrequencyTable"->{
    Cell[91400, 3655, 301, 10, 23, "Index",
      CellTags->"FullGenotypeFrequencyTable"]},
  "FullOutput"->{
    Cell[91704, 3667, 257, 10, 23, "Index",
      CellTags->"FullOutput"]},
  "Function"->{
    Cell[91964, 3679, 241, 10, 23, "Index",
      CellTags->"Function"]},
  "Gametes"->{
    Cell[92208, 3691, 286, 11, 23, "Index",
      CellTags->"Gametes"],
    Cell[92497, 3704, 1087, 36, 68, "IndexSubentry",
      CellTags->"Gametes"]},
  "GameteTable"->{
    Cell[93587, 3742, 298, 11, 23, "Index",
      CellTags->"GameteTable"],
    Cell[93888, 3755, 440, 15, 38, "IndexSubentry",
      CellTags->"GameteTable"]},
  "GaussianLogLikelihood"->{
    Cell[94331, 3772, 290, 10, 23, "Index",
      CellTags->"GaussianLogLikelihood"]},
  "GaussianMLE"->{
    Cell[94624, 3784, 260, 10, 23, "Index",
      CellTags->"GaussianMLE"]},
  "Genealogies"->{
    Cell[94887, 3796, 270, 11, 23, "Index",
      CellTags->"Genealogies"],
    Cell[95160, 3809, 929, 33, 83, "IndexSubentry",
      CellTags->"Genealogies"]},
  "Genealogy"->{
    Cell[96092, 3844, 412, 15, 23, "Index",
      CellTags->"Genealogy"]},
  "GenealogyToMatrix"->{
    Cell[96507, 3861, 276, 10, 23, "Index",
      CellTags->"GenealogyToMatrix"]},
  "GeneralizedTransform"->{
    Cell[96786, 3873, 265, 10, 23, "Index",
      CellTags->"GeneralizedTransform"]},
  "Generating functions"->{
    Cell[97054, 3885, 283, 11, 23, "Index",
      CellTags->"Generating functions"],
    Cell[97340, 3898, 437, 15, 38, "IndexSubentry",
      CellTags->"Generating functions"]},
  "Genes and contexts"->{
    Cell[97780, 3915, 277, 10, 23, "Index",
      CellTags->"Genes and contexts"]},
  "Genome"->{
    Cell[98060, 3927, 334, 12, 23, "Index",
      CellTags->"Genome"]},
  "Genotype"->{
    Cell[98397, 3941, 287, 11, 23, "Index",
      CellTags->"Genotype"],
    Cell[98687, 3954, 566, 19, 38, "IndexSubentry",
      CellTags->"Genotype"]},
  "Genotype frequencies"->{
    Cell[99256, 3975, 299, 11, 23, "Index",
      CellTags->"Genotype frequencies"]},
  "Genotype frequency"->{
    Cell[99558, 3988, 321, 11, 23, "Index",
      CellTags->"Genotype frequency"]},
  "GenotypeFrequency"->{
    Cell[99882, 4001, 292, 10, 23, "Index",
      CellTags->"GenotypeFrequency"]},
  "GenotypeFrequencyArguments"->{
    Cell[100177, 4013, 301, 10, 23, "Index",
      CellTags->"GenotypeFrequencyArguments"]},
  "GenotypeFrequencyConvert"->{
    Cell[100481, 4025, 303, 10, 23, "Index",
      CellTags->"GenotypeFrequencyConvert"]},
  "GenotypeFrequencyTable"->{
    Cell[100787, 4037, 307, 10, 23, "Index",
      CellTags->"GenotypeFrequencyTable"]},
  "GenotypePosition"->{
    Cell[101097, 4049, 281, 10, 23, "Index",
      CellTags->"GenotypePosition"]},
  "GenotypeProbability"->{
    Cell[101381, 4061, 288, 10, 23, "Index",
      CellTags->"GenotypeProbability"],
    Cell[101672, 4073, 286, 9, 23, "IndexSubentry",
      CellTags->"GenotypeProbability"]},
  "Genotypes"->{
    Cell[101961, 4084, 256, 11, 23, "Index",
      CellTags->"Genotypes"]},
  "GlobalContinuumVariables"->{
    Cell[102220, 4097, 291, 10, 23, "Index",
      CellTags->"GlobalContinuumVariables"]},
  "Gnew"->{
    Cell[102514, 4109, 452, 16, 23, "Index",
      CellTags->"Gnew"]},
  "Goodman et al 1999"->{
    Cell[102969, 4127, 261, 10, 23, "Index",
      CellTags->"Goodman et al 1999"]},
  "Graphs"->{
    Cell[103233, 4139, 274, 11, 23, "Index",
      CellTags->"Graphs"]},
  "Griffiths-Tavare"->{
    Cell[103510, 4152, 399, 14, 23, "Index",
      CellTags->"Griffiths-Tavare"],
    Cell[103912, 4168, 833, 26, 53, "IndexSubentry",
      CellTags->"Griffiths-Tavare"]},
  "Guiasu & Shenitzer 1985"->{
    Cell[104748, 4196, 276, 10, 23, "Index",
      CellTags->"Guiasu & Shenitzer 1985"]},
  "HaploidConstraints"->{
    Cell[105027, 4208, 277, 10, 23, "Index",
      CellTags->"HaploidConstraints"]},
  "HaploidFrequencies"->{
    Cell[105307, 4220, 297, 10, 23, "Index",
      CellTags->"HaploidFrequencies"]},
  "HaploidGenotypeFrequency"->{
    Cell[105607, 4232, 332, 11, 23, "Index",
      CellTags->"HaploidGenotypeFrequency"]},
  "HaploidIndividuals"->{
    Cell[105942, 4245, 297, 10, 23, "Index",
      CellTags->"HaploidIndividuals"]},
  "HaploidRepresentations"->{
    Cell[106242, 4257, 309, 10, 23, "Index",
      CellTags->"HaploidRepresentations"]},
  "Haploids"->{
    Cell[106554, 4269, 259, 11, 23, "Index",
      CellTags->"Haploids"]},
  "HaploidSource"->{
    Cell[106816, 4282, 414, 14, 23, "Index",
      CellTags->"HaploidSource"]},
  "HaploidSubsets"->{
    Cell[107233, 4298, 259, 10, 23, "Index",
      CellTags->"HaploidSubsets"]},
  "HaploidTypes"->{
    Cell[107495, 4310, 257, 10, 23, "Index",
      CellTags->"HaploidTypes"]},
  "Help browser"->{
    Cell[107755, 4322, 314, 11, 23, "Index",
      CellTags->"Help browser"]},
  "Help Browser"->{
    Cell[108072, 4335, 281, 10, 23, "Index",
      CellTags->"Help Browser"],
    Cell[108356, 4347, 291, 9, 23, "IndexSubentry",
      CellTags->"Help Browser"]},
  "Hermaphrodites"->{
    Cell[108650, 4358, 432, 15, 23, "Index",
      CellTags->"Hermaphrodites"]},
  "HeterozygoteB"->{
    Cell[109085, 4375, 284, 10, 23, "Index",
      CellTags->"HeterozygoteB"]},
  "Hill 1974a"->{
    Cell[109372, 4387, 237, 10, 23, "Index",
      CellTags->"Hill 1974a"]},
  "Hill 1974b"->{
    Cell[109612, 4399, 237, 10, 23, "Index",
      CellTags->"Hill 1974b"]},
  "Hill 1974c"->{
    Cell[109852, 4411, 237, 10, 23, "Index",
      CellTags->"Hill 1974c"]},
  "Hudson 1990"->{
    Cell[110092, 4423, 413, 14, 23, "Index",
      CellTags->"Hudson 1990"]},
  "Hypergeometric model"->{
    Cell[110508, 4439, 303, 10, 23, "Index",
      CellTags->"Hypergeometric model"]},
  "Hyperlinks"->{
    Cell[110814, 4451, 256, 11, 23, "Index",
      CellTags->"Hyperlinks"],
    Cell[111073, 4464, 621, 22, 53, "IndexSubentry",
      CellTags->"Hyperlinks"]},
  "IncidenceMatrix"->{
    Cell[111697, 4488, 270, 10, 23, "Index",
      CellTags->"IncidenceMatrix"]},
  "Index"->{
    Cell[111970, 4500, 290, 11, 23, "Index",
      CellTags->"Index"]},
  "Individual"->{
    Cell[112263, 4513, 237, 10, 23, "Index",
      CellTags->"Individual"]},
  "IndividualContinuumVariables"->{
    Cell[112503, 4525, 303, 10, 23, "Index",
      CellTags->"IndividualContinuumVariables"]},
  "IndividualRepresentations"->{
    Cell[112809, 4537, 323, 11, 23, "Index",
      CellTags->"IndividualRepresentations"]},
  "Individuals"->{
    Cell[113135, 4550, 264, 10, 23, "Index",
      CellTags->"Individuals"]},
  "InferParentalGenotypes"->{
    Cell[113402, 4562, 301, 10, 23, "Index",
      CellTags->"InferParentalGenotypes"]},
  "Infinite sites mutation"->{
    Cell[113706, 4574, 275, 10, 23, "Index",
      CellTags->"Infinite sites mutation"]},
  "InformationFunction"->{
    Cell[113984, 4586, 338, 11, 23, "Index",
      CellTags->"InformationFunction"],
    Cell[114325, 4599, 501, 15, 38, "IndexSubentry",
      CellTags->"InformationFunction"]},
  "InitialiseContinuum"->{
    Cell[114829, 4616, 272, 10, 23, "Index",
      CellTags->"InitialiseContinuum"]},
  "InitialiseCovariance"->{
    Cell[115104, 4628, 263, 10, 23, "Index",
      CellTags->"InitialiseCovariance"]},
  "InitialiseDemes"->{
    Cell[115370, 4640, 414, 14, 23, "Index",
      CellTags->"InitialiseDemes"]},
  "InitialStep"->{
    Cell[115787, 4656, 254, 10, 23, "Index",
      CellTags->"InitialStep"]},
  "InitialStepReduced"->{
    Cell[116044, 4668, 277, 10, 23, "Index",
      CellTags->"InitialStepReduced"]},
  "InternalNodes"->{
    Cell[116324, 4680, 270, 10, 23, "Index",
      CellTags->"InternalNodes"]},
  "IntervalCombine"->{
    Cell[116597, 4692, 268, 10, 23, "Index",
      CellTags->"IntervalCombine"]},
  "IntervalPosition"->{
    Cell[116868, 4704, 271, 10, 23, "Index",
      CellTags->"IntervalPosition"]},
  "InverseFourierNormalised"->{
    Cell[117142, 4716, 295, 10, 23, "Index",
      CellTags->"InverseFourierNormalised"]},
  "InverseFourierNormalisedTable"->{
    Cell[117440, 4728, 310, 10, 23, "Index",
      CellTags->"InverseFourierNormalisedTable"]},
  "Island model"->{
    Cell[117753, 4740, 476, 15, 23, "Index",
      CellTags->"Island model"],
    Cell[118232, 4757, 795, 25, 53, "IndexSubentry",
      CellTags->"Island model"]},
  "IterateContinuum"->{
    Cell[119030, 4784, 295, 10, 23, "Index",
      CellTags->"IterateContinuum"]},
  "IterateExact"->{
    Cell[119328, 4796, 264, 11, 23, "Index",
      CellTags->"IterateExact"],
    Cell[119595, 4809, 1753, 53, 128, "IndexSubentry",
      CellTags->"IterateExact"]},
  "Join"->{
    Cell[121351, 4864, 328, 14, 23, "Index",
      CellTags->"Join"]},
  "Junctions"->{
    Cell[121682, 4880, 295, 11, 23, "Index",
      CellTags->"Junctions"]},
  "JunctionStyle"->{
    Cell[121980, 4893, 307, 11, 23, "Index",
      CellTags->"JunctionStyle"]},
  "Juveniles"->{
    Cell[122290, 4906, 417, 15, 23, "Index",
      CellTags->"Juveniles"]},
  "Kirkpatrick and Barton 1997"->{
    Cell[122710, 4923, 310, 10, 23, "Index",
      CellTags->"Kirkpatrick and Barton 1997"]},
  "Kirkpatrick and Servedio 1998"->{
    Cell[123023, 4935, 316, 10, 23, "Index",
      CellTags->"Kirkpatrick and Servedio 1998"]},
  "Kirkpatrick et al."->{
    Cell[123342, 4947, 392, 14, 23, "Index",
      CellTags->"Kirkpatrick et al."],
    Cell[123737, 4963, 3891, 138, 285, "IndexSubentry",
      CellTags->"Kirkpatrick et al."]},
  "Kirkpatrick et al. 1983"->{
    Cell[127631, 5103, 275, 10, 15, "Index",
      CellTags->"Kirkpatrick et al. 1983"]},
  "Kruuk 1997"->{
    Cell[127909, 5115, 237, 10, 15, "Index",
      CellTags->"Kruuk 1997"]},
  "LeafEvents"->{
    Cell[128149, 5127, 298, 11, 15, "Index",
      CellTags->"LeafEvents"]},
  "LeafLabels"->{
    Cell[128450, 5140, 257, 10, 15, "Index",
      CellTags->"LeafLabels"]},
  "LeafOffset"->{
    Cell[128710, 5152, 257, 10, 15, "Index",
      CellTags->"LeafOffset"]},
  "Leaves"->{
    Cell[128970, 5164, 249, 10, 15, "Index",
      CellTags->"Leaves"],
    Cell[129222, 5176, 275, 9, 15, "IndexSubentry",
      CellTags->"Leaves"]},
  "Life cycle"->{
    Cell[129500, 5187, 229, 10, 15, "Index",
      CellTags->"Life cycle"],
    Cell[129732, 5199, 3070, 111, 180, "IndexSubentry",
      CellTags->"Life cycle"]},
  "LineagesPresent"->{
    Cell[132805, 5312, 313, 11, 15, "Index",
      CellTags->"LineagesPresent"]},
  "Li & Nei 1974"->{
    Cell[133121, 5325, 246, 10, 15, "Index",
      CellTags->"Li & Nei 1974"]},
  "Linkage"->{
    Cell[133370, 5337, 480, 18, 15, "Index",
      CellTags->"Linkage"],
    Cell[133853, 5357, 451, 15, 30, "IndexSubentry",
      CellTags->"Linkage"]},
  "Linkage disequilibrium"->{
    Cell[134307, 5374, 307, 10, 15, "Index",
      CellTags->"Linkage disequilibrium"]},
  "LinkedRecombination"->{
    Cell[134617, 5386, 270, 10, 15, "Index",
      CellTags->"LinkedRecombination"]},
  "ListToGenealogy"->{
    Cell[134890, 5398, 280, 10, 15, "Index",
      CellTags->"ListToGenealogy"]},
  "ListToMatrix"->{
    Cell[135173, 5410, 291, 10, 15, "Index",
      CellTags->"ListToMatrix"]},
  "Location"->{
    Cell[135467, 5422, 255, 10, 15, "Index",
      CellTags->"Location"]},
  "Locations"->{
    Cell[135725, 5434, 232, 10, 15, "Index",
      CellTags->"Locations"]},
  "LocusNames"->{
    Cell[135960, 5446, 253, 10, 23, "Index",
      CellTags->"LocusNames"]},
  "LogLikelihoodDisequilibrium"->{
    Cell[136216, 5458, 288, 10, 23, "Index",
      CellTags->"LogLikelihoodDisequilibrium"]},
  "LogLikelihoodDisequilibriumReduced"->{
    Cell[136507, 5470, 325, 10, 23, "Index",
      CellTags->"LogLikelihoodDisequilibriumReduced"]},
  "LogLikelihoodTest"->{
    Cell[136835, 5482, 270, 10, 23, "Index",
      CellTags->"LogLikelihoodTest"]},
  "Log-linear models"->{
    Cell[137108, 5494, 397, 14, 23, "Index",
      CellTags->"Log-linear models"]},
  "Long et al 1995"->{
    Cell[137508, 5510, 252, 10, 23, "Index",
      CellTags->"Long et al 1995"]},
  "LowerOffDiagonal"->{
    Cell[137763, 5522, 269, 10, 23, "Index",
      CellTags->"LowerOffDiagonal"]},
  "MacCallum 1994"->{
    Cell[138035, 5534, 249, 10, 23, "Index",
      CellTags->"MacCallum 1994"]},
  "MacCallum et al. 1998"->{
    Cell[138287, 5546, 269, 10, 23, "Index",
      CellTags->"MacCallum et al. 1998"]},
  "MakeCline"->{
    Cell[138559, 5558, 320, 11, 23, "Index",
      CellTags->"MakeCline"],
    Cell[138882, 5571, 691, 21, 53, "IndexSubentry",
      CellTags->"MakeCline"]},
  "MakeDiploid"->{
    Cell[139576, 5594, 296, 11, 23, "Index",
      CellTags->"MakeDiploid"],
    Cell[139875, 5607, 474, 15, 38, "IndexSubentry",
      CellTags->"MakeDiploid"]},
  "MakeDistanceList"->{
    Cell[140352, 5624, 279, 10, 23, "Index",
      CellTags->"MakeDistanceList"]},
  "MakeDistances"->{
    Cell[140634, 5636, 270, 10, 23, "Index",
      CellTags->"MakeDistances"]},
  "MakeFitnessSet"->{
    Cell[140907, 5648, 243, 10, 23, "Index",
      CellTags->"MakeFitnessSet"],
    Cell[141153, 5660, 255, 9, 23, "IndexSubentry",
      CellTags->"MakeFitnessSet"]},
  "MakeGenealogy"->{
    Cell[141411, 5671, 262, 10, 23, "Index",
      CellTags->"MakeGenealogy"]},
  "MakeGenealogyPlot"->{
    Cell[141676, 5683, 278, 10, 23, "Index",
      CellTags->"MakeGenealogyPlot"]},
  "MakeHaploid"->{
    Cell[141957, 5695, 296, 11, 23, "Index",
      CellTags->"MakeHaploid"],
    Cell[142256, 5708, 474, 15, 38, "IndexSubentry",
      CellTags->"MakeHaploid"]},
  "MakeIndividuals"->{
    Cell[142733, 5725, 322, 11, 23, "Index",
      CellTags->"MakeIndividuals"],
    Cell[143058, 5738, 666, 21, 53, "IndexSubentry",
      CellTags->"MakeIndividuals"]},
  "MakeOneWayTable"->{
    Cell[143727, 5761, 270, 10, 23, "Index",
      CellTags->"MakeOneWayTable"]},
  "MakePairwiseTable"->{
    Cell[144000, 5773, 268, 10, 23, "Index",
      CellTags->"MakePairwiseTable"]},
  "MakePopulation"->{
    Cell[144271, 5785, 327, 11, 23, "Index",
      CellTags->"MakePopulation"],
    Cell[144601, 5798, 711, 22, 45, "IndexSubentry",
      CellTags->"MakePopulation"]},
  "MakeSelectionCoefficient"->{
    Cell[145315, 5822, 398, 14, 15, "Index",
      CellTags->"MakeSelectionCoefficient"],
    Cell[145716, 5838, 423, 15, 30, "IndexSubentry",
      CellTags->"MakeSelectionCoefficient"]},
  "Mangel & Hilborn 1996"->{
    Cell[146142, 5855, 270, 10, 15, "Index",
      CellTags->"Mangel & Hilborn 1996"]},
  "MapLength"->{
    Cell[146415, 5867, 295, 11, 15, "Index",
      CellTags->"MapLength"]},
  "MapPosition"->{
    Cell[146713, 5880, 298, 11, 15, "Index",
      CellTags->"MapPosition"],
    Cell[147014, 5893, 284, 9, 15, "IndexSubentry",
      CellTags->"MapPosition"]},
  "Marginal fitness"->{
    Cell[147301, 5904, 316, 11, 15, "Index",
      CellTags->"Marginal fitness"],
    Cell[147620, 5917, 642, 21, 45, "IndexSubentry",
      CellTags->"Marginal fitness"]},
  "MarginalTable"->{
    Cell[148265, 5940, 256, 10, 15, "Index",
      CellTags->"MarginalTable"]},
  "MarginalW"->{
    Cell[148524, 5952, 302, 11, 15, "Index",
      CellTags->"MarginalW"],
    Cell[148829, 5965, 636, 21, 45, "IndexSubentry",
      CellTags->"MarginalW"]},
  "MaternalLoci"->{
    Cell[149468, 5988, 277, 11, 15, "Index",
      CellTags->"MaternalLoci"],
    Cell[149748, 6001, 450, 15, 30, "IndexSubentry",
      CellTags->"MaternalLoci"]},
  "MatrixGamma"->{
    Cell[150201, 6018, 254, 10, 15, "Index",
      CellTags->"MatrixGamma"]},
  "MatrixToGenealogy"->{
    Cell[150458, 6030, 280, 10, 15, "Index",
      CellTags->"MatrixToGenealogy"]},
  "MatrixToList"->{
    Cell[150741, 6042, 291, 10, 15, "Index",
      CellTags->"MatrixToList"]},
  "MeanContribution"->{
    Cell[151035, 6054, 314, 11, 15, "Index",
      CellTags->"MeanContribution"]},
  "Mean fitness"->{
    Cell[151352, 6067, 400, 14, 15, "Index",
      CellTags->"Mean fitness"],
    Cell[151755, 6083, 461, 15, 30, "IndexSubentry",
      CellTags->"Mean fitness"]},
  "MeanW"->{
    Cell[152219, 6100, 290, 11, 15, "Index",
      CellTags->"MeanW"],
    Cell[152512, 6113, 620, 21, 45, "IndexSubentry",
      CellTags->"MeanW"]},
  "Meiosis"->{
    Cell[153135, 6136, 234, 10, 15, "Index",
      CellTags->"Meiosis"],
    Cell[153372, 6148, 264, 9, 15, "IndexSubentry",
      CellTags->"Meiosis"]},
  "MethodC"->{
    Cell[153639, 6159, 256, 10, 15, "Index",
      CellTags->"MethodC"]},
  "MethodP"->{
    Cell[153898, 6171, 256, 10, 15, "Index",
      CellTags->"MethodP"]},
  "Metropolis algorithm"->{
    Cell[154157, 6183, 271, 11, 15, "Index",
      CellTags->"Metropolis algorithm"]},
  "MetropolisDisequilibrium"->{
    Cell[154431, 6196, 295, 10, 15, "Index",
      CellTags->"MetropolisDisequilibrium"]},
  "MetropolisDisequilibriumReduced"->{
    Cell[154729, 6208, 316, 10, 15, "Index",
      CellTags->"MetropolisDisequilibriumReduced"]},
  "Metropolis et al. 1954"->{
    Cell[155048, 6220, 272, 10, 15, "Index",
      CellTags->"Metropolis et al. 1954"]},
  "MFromC"->{
    Cell[155323, 6232, 382, 14, 15, "Index",
      CellTags->"MFromC"]},
  "Migrate"->{
    Cell[155708, 6248, 226, 10, 15, "Index",
      CellTags->"Migrate"]},
  "MigrateExact"->{
    Cell[155937, 6260, 311, 11, 15, "Index",
      CellTags->"MigrateExact"],
    Cell[156251, 6273, 646, 21, 45, "IndexSubentry",
      CellTags->"MigrateExact"]},
  "Migration"->{
    Cell[156900, 6296, 298, 11, 15, "Index",
      CellTags->"Migration"],
    Cell[157201, 6309, 2405, 85, 195, "IndexSubentry",
      CellTags->"Migration"]},
  "MigrationOrder"->{
    Cell[159609, 6396, 491, 15, 15, "Index",
      CellTags->"MigrationOrder"],
    Cell[160103, 6413, 524, 16, 30, "IndexSubentry",
      CellTags->"MigrationOrder"]},
  "MigrationRate"->{
    Cell[160630, 6431, 308, 11, 15, "Index",
      CellTags->"MigrationRate"]},
  "MigrationSet"->{
    Cell[160941, 6444, 311, 11, 15, "Index",
      CellTags->"MigrationSet"]},
  "MissingCombination"->{
    Cell[161255, 6457, 299, 10, 15, "Index",
      CellTags->"MissingCombination"]},
  "Missing data"->{
    Cell[161557, 6469, 323, 11, 15, "Index",
      CellTags->"Missing data"],
    Cell[161883, 6482, 468, 15, 30, "IndexSubentry",
      CellTags->"Missing data"]},
  "MissingData"->{
    Cell[162354, 6499, 312, 11, 15, "Index",
      CellTags->"MissingData"],
    Cell[162669, 6512, 300, 9, 15, "IndexSubentry",
      CellTags->"MissingData"]},
  "Moment"->{
    Cell[162972, 6523, 352, 14, 15, "Index",
      CellTags->"Moment"]},
  "MomentAfterMigration"->{
    Cell[163327, 6539, 305, 10, 15, "Index",
      CellTags->"MomentAfterMigration"]},
  "MomentAfterRecombination"->{
    Cell[163635, 6551, 332, 11, 15, "Index",
      CellTags->"MomentAfterRecombination"]},
  "MomentEquilibrium"->{
    Cell[163970, 6564, 258, 10, 15, "Index",
      CellTags->"MomentEquilibrium"]},
  "MomentGeneratingFunction"->{
    Cell[164231, 6576, 315, 11, 15, "Index",
      CellTags->"MomentGeneratingFunction"],
    Cell[164549, 6589, 582, 21, 45, "IndexSubentry",
      CellTags->"MomentGeneratingFunction"]},
  "MomentLimits"->{
    Cell[165134, 6612, 267, 10, 15, "Index",
      CellTags->"MomentLimits"]},
  "MomentNew"->{
    Cell[165404, 6624, 232, 10, 15, "Index",
      CellTags->"MomentNew"]},
  "MomentReduced"->{
    Cell[165639, 6636, 262, 10, 15, "Index",
      CellTags->"MomentReduced"]},
  "Moments"->{
    Cell[165904, 6648, 222, 10, 15, "Index",
      CellTags->"Moments"],
    Cell[166129, 6660, 1552, 53, 120, "IndexSubentry",
      CellTags->"Moments"]},
  "MomentsFromG"->{
    Cell[167684, 6715, 289, 10, 15, "Index",
      CellTags->"MomentsFromG"]},
  "MomentSimple"->{
    Cell[167976, 6727, 269, 10, 15, "Index",
      CellTags->"MomentSimple"]},
  "MonteCarloGriffithsTavare"->{
    Cell[168248, 6739, 302, 10, 15, "Index",
      CellTags->"MonteCarloGriffithsTavare"]},
  "MonteCarloProbability"->{
    Cell[168553, 6751, 302, 10, 15, "Index",
      CellTags->"MonteCarloProbability"]},
  "Mortality"->{
    Cell[168858, 6763, 258, 10, 15, "Index",
      CellTags->"Mortality"]},
  "MostRecentCommonAncestor"->{
    Cell[169119, 6775, 299, 10, 15, "Index",
      CellTags->"MostRecentCommonAncestor"]},
  "MToC"->{
    Cell[169421, 6787, 374, 14, 15, "Index",
      CellTags->"MToC"]},
  "MToCEquations"->{
    Cell[169798, 6803, 410, 14, 15, "Index",
      CellTags->"MToCEquations"]},
  "Muddle"->{
    Cell[170211, 6819, 263, 10, 15, "Index",
      CellTags->"Muddle"]},
  "Multilocus algebra"->{
    Cell[170477, 6831, 295, 11, 15, "Index",
      CellTags->"Multilocus algebra"],
    Cell[170775, 6844, 1010, 36, 60, "IndexSubentry",
      CellTags->"Multilocus algebra"]},
  "Multilocus MS"->{
    Cell[171788, 6882, 408, 15, 15, "Index",
      CellTags->"Multilocus MS"]},
  "Multilocus notation"->{
    Cell[172199, 6899, 264, 11, 15, "Index",
      CellTags->"Multilocus notation"]},
  "Multinomial sampling"->{
    Cell[172466, 6912, 344, 12, 15, "Index",
      CellTags->"Multinomial sampling"]},
  "MultinomialSamplingProbability"->{
    Cell[172813, 6926, 332, 11, 15, "Index",
      CellTags->"MultinomialSamplingProbability"]},
  "Multiple alleles"->{
    Cell[173148, 6939, 289, 11, 15, "Index",
      CellTags->"Multiple alleles"],
    Cell[173440, 6952, 694, 27, 60, "IndexSubentry",
      CellTags->"Multiple alleles"]},
  "Multiple arguments"->{
    Cell[174137, 6981, 297, 11, 15, "Index",
      CellTags->"Multiple arguments"]},
  "Multiplicative models"->{
    Cell[174437, 6994, 336, 11, 15, "Index",
      CellTags->"Multiplicative models"]},
  "MUS"->{
    Cell[174776, 7007, 302, 11, 15, "Index",
      CellTags->"MUS"],
    Cell[175081, 7020, 667, 21, 45, "IndexSubentry",
      CellTags->"MUS"]},
  "Mutate"->{
    Cell[175751, 7043, 287, 11, 15, "Index",
      CellTags->"Mutate"],
    Cell[176041, 7056, 607, 21, 45, "IndexSubentry",
      CellTags->"Mutate"]},
  "MutateCompiled"->{
    Cell[176651, 7079, 724, 22, 15, "Index",
      CellTags->"MutateCompiled"]},
  "Mutation"->{
    Cell[177378, 7103, 263, 11, 15, "Index",
      CellTags->"Mutation"],
    Cell[177644, 7116, 1083, 33, 59, "IndexSubentry",
      CellTags->"Mutation"]},
  "MutationInterval"->{
    Cell[178730, 7151, 275, 10, 15, "Index",
      CellTags->"MutationInterval"]},
  "MutationLabels"->{
    Cell[179008, 7163, 297, 10, 15, "Index",
      CellTags->"MutationLabels"]},
  "MutationOrigin"->{
    Cell[179308, 7175, 269, 10, 23, "Index",
      CellTags->"MutationOrigin"]},
  "MutationRate"->{
    Cell[179580, 7187, 261, 10, 23, "Index",
      CellTags->"MutationRate"]},
  "Mutations"->{
    Cell[179844, 7199, 293, 11, 23, "Index",
      CellTags->"Mutations"],
    Cell[180140, 7212, 772, 27, 68, "IndexSubentry",
      CellTags->"Mutations"]},
  "MVariables"->{
    Cell[180915, 7241, 398, 14, 23, "Index",
      CellTags->"MVariables"]},
  "Negative binomial"->{
    Cell[181316, 7257, 293, 11, 23, "Index",
      CellTags->"Negative binomial"],
    Cell[181612, 7270, 828, 27, 68, "IndexSubentry",
      CellTags->"Negative binomial"]},
  "NegativeBinomialLogLikelihood"->{
    Cell[182443, 7299, 339, 11, 23, "Index",
      CellTags->"NegativeBinomialLogLikelihood"]},
  "NegativeBinomialMLE"->{
    Cell[182785, 7312, 302, 10, 23, "Index",
      CellTags->"NegativeBinomialMLE"]},
  "NegativeHypergeometricDistribution"->{
    Cell[183090, 7324, 368, 11, 23, "Index",
      CellTags->"NegativeHypergeometricDistribution"]},
  "NeighbourArray"->{
    Cell[183461, 7337, 273, 10, 23, "Index",
      CellTags->"NeighbourArray"]},
  "Neighbours"->{
    Cell[183737, 7349, 261, 10, 23, "Index",
      CellTags->"Neighbours"]},
  "NetCovariance"->{
    Cell[184001, 7361, 280, 10, 23, "Index",
      CellTags->"NetCovariance"]},
  "NetFecundity"->{
    Cell[184284, 7373, 255, 10, 23, "Index",
      CellTags->"NetFecundity"]},
  "NetMortality"->{
    Cell[184542, 7385, 255, 10, 23, "Index",
      CellTags->"NetMortality"]},
  "NetRecombination"->{
    Cell[184800, 7397, 384, 14, 23, "Index",
      CellTags->"NetRecombination"],
    Cell[185187, 7413, 438, 15, 38, "IndexSubentry",
      CellTags->"NetRecombination"]},
  "Neutral marker"->{
    Cell[185628, 7430, 285, 11, 23, "Index",
      CellTags->"Neutral marker"]},
  "NeutralRepresentations"->{
    Cell[185916, 7443, 309, 10, 23, "Index",
      CellTags->"NeutralRepresentations"]},
  "NewGametes"->{
    Cell[186228, 7455, 309, 11, 23, "Index",
      CellTags->"NewGametes"],
    Cell[186540, 7468, 1653, 52, 98, "IndexSubentry",
      CellTags->"NewGametes"]},
  "NewS"->{
    Cell[188196, 7522, 249, 10, 23, "Index",
      CellTags->"NewS"]},
  "Node"->{
    Cell[188448, 7534, 380, 14, 23, "Index",
      CellTags->"Node"]},
  "NodeFunction"->{
    Cell[188831, 7550, 404, 14, 23, "Index",
      CellTags->"NodeFunction"],
    Cell[189238, 7566, 275, 9, 23, "IndexSubentry",
      CellTags->"NodeFunction"]},
  "NodeLabels"->{
    Cell[189516, 7577, 257, 10, 23, "Index",
      CellTags->"NodeLabels"]},
  "NodeOffset"->{
    Cell[189776, 7589, 257, 10, 23, "Index",
      CellTags->"NodeOffset"]},
  "Nodes"->{
    Cell[190036, 7601, 246, 10, 23, "Index",
      CellTags->"Nodes"]},
  "NonMendelian"->{
    Cell[190285, 7613, 263, 10, 23, "Index",
      CellTags->"NonMendelian"],
    Cell[190551, 7625, 366, 13, 23, "IndexSubentry",
      CellTags->"NonMendelian"]},
  "NonNeutralRepresentations"->{
    Cell[190920, 7640, 323, 11, 23, "Index",
      CellTags->"NonNeutralRepresentations"]},
  "NonSymmetricRepresentations"->{
    Cell[191246, 7653, 331, 11, 23, "Index",
      CellTags->"NonSymmetricRepresentations"]},
  "Normalisation"->{
    Cell[191580, 7666, 284, 10, 23, "Index",
      CellTags->"Normalisation"]},
  "Normalised"->{
    Cell[191867, 7678, 275, 10, 23, "Index",
      CellTags->"Normalised"]},
  "Notation"->{
    Cell[192145, 7690, 287, 11, 23, "Index",
      CellTags->"Notation"],
    Cell[192435, 7703, 727, 27, 68, "IndexSubentry",
      CellTags->"Notation"]},
  "Notation Package"->{
    Cell[193165, 7732, 253, 10, 23, "Index",
      CellTags->"Notation Package"]},
  "NullAllele"->{
    Cell[193421, 7744, 310, 11, 23, "Index",
      CellTags->"NullAllele"],
    Cell[193734, 7757, 299, 9, 23, "IndexSubentry",
      CellTags->"NullAllele"]},
  "Null alleles"->{
    Cell[194036, 7768, 312, 11, 23, "Index",
      CellTags->"Null alleles"],
    Cell[194351, 7781, 304, 9, 23, "IndexSubentry",
      CellTags->"Null alleles"]},
  "Null lineages"->{
    Cell[194658, 7792, 304, 11, 23, "Index",
      CellTags->"Null lineages"]},
  "NullLineages"->{
    Cell[194965, 7805, 304, 11, 23, "Index",
      CellTags->"NullLineages"]},
  "NullRecombinationEvents"->{
    Cell[195272, 7818, 337, 11, 23, "Index",
      CellTags->"NullRecombinationEvents"]},
  "NumberedLink"->{
    Cell[195612, 7831, 261, 10, 23, "Index",
      CellTags->"NumberedLink"]},
  "Numbering"->{
    Cell[195876, 7843, 271, 11, 23, "Index",
      CellTags->"Numbering"],
    Cell[196150, 7856, 560, 21, 53, "IndexSubentry",
      CellTags->"Numbering"]},
  "NumberOfCoalescences"->{
    Cell[196713, 7879, 318, 11, 23, "Index",
      CellTags->"NumberOfCoalescences"]},
  "NumberOfGenes"->{
    Cell[197034, 7892, 266, 10, 23, "Index",
      CellTags->"NumberOfGenes"],
    Cell[197303, 7904, 917, 28, 68, "IndexSubentry",
      CellTags->"NumberOfGenes"]},
  "NumberOfGenesTable"->{
    Cell[198223, 7934, 281, 10, 23, "Index",
      CellTags->"NumberOfGenesTable"]},
  "NumberOfIndividuals"->{
    Cell[198507, 7946, 416, 14, 23, "Index",
      CellTags->"NumberOfIndividuals"]},
  "NumberOfIndividualsTable"->{
    Cell[198926, 7962, 299, 10, 23, "Index",
      CellTags->"NumberOfIndividualsTable"]},
  "NumberOfLineages"->{
    Cell[199228, 7974, 279, 10, 23, "Index",
      CellTags->"NumberOfLineages"]},
  "NumberOfLoci"->{
    Cell[199510, 7986, 263, 10, 23, "Index",
      CellTags->"NumberOfLoci"]},
  "NumberOfMutations"->{
    Cell[199776, 7998, 278, 10, 23, "Index",
      CellTags->"NumberOfMutations"]},
  "NumberOfPossibleCoalescences"->{
    Cell[200057, 8010, 317, 10, 23, "Index",
      CellTags->"NumberOfPossibleCoalescences"]},
  "NumberOfSamplePartitions"->{
    Cell[200377, 8022, 287, 10, 23, "Index",
      CellTags->"NumberOfSamplePartitions"]},
  "NumberOfSetPartitions"->{
    Cell[200667, 8034, 278, 10, 23, "Index",
      CellTags->"NumberOfSetPartitions"]},
  "NumericalModel"->{
    Cell[200948, 8046, 327, 11, 23, "Index",
      CellTags->"NumericalModel"],
    Cell[201278, 8059, 294, 9, 23, "IndexSubentry",
      CellTags->"NumericalModel"]},
  "Numerical models"->{
    Cell[201575, 8070, 301, 11, 23, "Index",
      CellTags->"Numerical models"],
    Cell[201879, 8083, 1267, 43, 98, "IndexSubentry",
      CellTags->"Numerical models"]},
  "Observable genotype"->{
    Cell[203149, 8128, 420, 14, 23, "Index",
      CellTags->"Observable genotype"]},
  "Obsolete"->{
    Cell[203572, 8144, 250, 11, 23, "Index",
      CellTags->"Obsolete"],
    Cell[203825, 8157, 3402, 121, 293, "IndexSubentry",
      CellTags->"Obsolete"]},
  "Offspring"->{
    Cell[207230, 8280, 258, 10, 23, "Index",
      CellTags->"Offspring"]},
  "Ordered"->{
    Cell[207491, 8292, 266, 11, 23, "Index",
      CellTags->"Ordered"]},
  "Orive & Barton 1999"->{
    Cell[207760, 8305, 264, 10, 23, "Index",
      CellTags->"Orive & Barton 1999"]},
  "OtherSex"->{
    Cell[208027, 8317, 247, 10, 23, "Index",
      CellTags->"OtherSex"]},
  "Packages"->{
    Cell[208277, 8329, 275, 11, 23, "Index",
      CellTags->"Packages"],
    Cell[208555, 8342, 839, 31, 68, "IndexSubentry",
      CellTags->"Packages"]},
  "PackageSaver"->{
    Cell[209397, 8375, 235, 10, 23, "Index",
      CellTags->"PackageSaver"]},
  "ParentalGenotypes"->{
    Cell[209635, 8387, 272, 10, 23, "Index",
      CellTags->"ParentalGenotypes"]},
  "Partitions"->{
    Cell[209910, 8399, 262, 11, 23, "Index",
      CellTags->"Partitions"],
    Cell[210175, 8412, 426, 15, 38, "IndexSubentry",
      CellTags->"Partitions"]},
  "PartitionSet"->{
    Cell[210604, 8429, 251, 10, 23, "Index",
      CellTags->"PartitionSet"]},
  "Paternal inheritance"->{
    Cell[210858, 8441, 414, 14, 23, "Index",
      CellTags->"Paternal inheritance"]},
  "PaternalLoci"->{
    Cell[211275, 8457, 277, 11, 23, "Index",
      CellTags->"PaternalLoci"],
    Cell[211555, 8470, 444, 15, 38, "IndexSubentry",
      CellTags->"PaternalLoci"]},
  "PatternFree"->{
    Cell[212002, 8487, 274, 10, 23, "Index",
      CellTags->"PatternFree"]},
  "Permutations"->{
    Cell[212279, 8499, 281, 11, 23, "Index",
      CellTags->"Permutations"]},
  "Permutations in defining coefficients"->{
    Cell[212563, 8512, 325, 11, 23, "Index",
      CellTags->"Permutations in defining coefficients"]},
  "Phenotypes"->{
    Cell[212891, 8525, 269, 11, 23, "Index",
      CellTags->"Phenotypes"]},
  "Phipps & Brill 1995"->{
    Cell[213163, 8538, 264, 10, 23, "Index",
      CellTags->"Phipps & Brill 1995"]},
  "Ploidy"->{
    Cell[213430, 8550, 245, 10, 23, "Index",
      CellTags->"Ploidy"]},
  "PloidyWeightList"->{
    Cell[213678, 8562, 271, 10, 23, "Index",
      CellTags->"PloidyWeightList"]},
  "PlotGenealogy"->{
    Cell[213952, 8574, 266, 10, 23, "Index",
      CellTags->"PlotGenealogy"]},
  "PlotLogL"->{
    Cell[214221, 8586, 247, 10, 23, "Index",
      CellTags->"PlotLogL"]},
  "PlotSegments"->{
    Cell[214471, 8598, 300, 11, 23, "Index",
      CellTags->"PlotSegments"]},
  "Plotting"->{
    Cell[214774, 8611, 279, 11, 23, "Index",
      CellTags->"Plotting"]},
  "PopulationDisequilibrium"->{
    Cell[215056, 8624, 346, 11, 23, "Index",
      CellTags->"PopulationDisequilibrium"]},
  "PopulationExpectation"->{
    Cell[215405, 8637, 274, 10, 23, "Index",
      CellTags->"PopulationExpectation"],
    Cell[215682, 8649, 271, 9, 23, "IndexSubentry",
      CellTags->"PopulationExpectation"]},
  "PopulationRepresentations"->{
    Cell[215956, 8660, 323, 11, 23, "Index",
      CellTags->"PopulationRepresentations"]},
  "Position"->{
    Cell[216282, 8673, 380, 14, 23, "Index",
      CellTags->"Position"],
    Cell[216665, 8689, 442, 15, 38, "IndexSubentry",
      CellTags->"Position"]},
  "PositionsList"->{
    Cell[217110, 8706, 270, 10, 23, "Index",
      CellTags->"PositionsList"]},
  "PositionsMatrix"->{
    Cell[217383, 8718, 276, 10, 23, "Index",
      CellTags->"PositionsMatrix"]},
  "PossibleCoalescenceOrder"->{
    Cell[217662, 8730, 305, 10, 23, "Index",
      CellTags->"PossibleCoalescenceOrder"]},
  "PossibleDiploidGenotypes"->{
    Cell[217970, 8742, 303, 10, 23, "Index",
      CellTags->"PossibleDiploidGenotypes"]},
  "PossibleGenotypes"->{
    Cell[218276, 8754, 272, 10, 23, "Index",
      CellTags->"PossibleGenotypes"]},
  "PossibleRootings"->{
    Cell[218551, 8766, 273, 10, 23, "Index",
      CellTags->"PossibleRootings"]},
  "PowerF"->{
    Cell[218827, 8778, 311, 11, 23, "Index",
      CellTags->"PowerF"],
    Cell[219141, 8791, 871, 27, 68, "IndexSubentry",
      CellTags->"PowerF"]},
  "PresentOneWayTable"->{
    Cell[220015, 8820, 279, 10, 23, "Index",
      CellTags->"PresentOneWayTable"]},
  "PresentPairwiseTable"->{
    Cell[220297, 8832, 277, 10, 23, "Index",
      CellTags->"PresentPairwiseTable"]},
  "PresentResults"->{
    Cell[220577, 8844, 265, 10, 23, "Index",
      CellTags->"PresentResults"]},
  "Principal components"->{
    Cell[220845, 8856, 317, 11, 23, "Index",
      CellTags->"Principal components"]},
  "PrintDetails"->{
    Cell[221165, 8869, 273, 10, 23, "Index",
      CellTags->"PrintDetails"],
    Cell[221441, 8881, 321, 10, 23, "IndexSubentry",
      CellTags->"PrintDetails"]},
  "Problems"->{
    Cell[221765, 8893, 275, 11, 23, "Index",
      CellTags->"Problems"],
    Cell[222043, 8906, 587, 18, 23, "IndexSubentry",
      CellTags->"Problems"]},
  "Products"->{
    Cell[222633, 8926, 250, 11, 23, "Index",
      CellTags->"Products"]},
  "ProductSum"->{
    Cell[222886, 8939, 237, 10, 23, "Index",
      CellTags->"ProductSum"],
    Cell[223126, 8951, 249, 9, 23, "IndexSubentry",
      CellTags->"ProductSum"]},
  "QLE"->{
    Cell[223378, 8962, 263, 11, 23, "Index",
      CellTags->"QLE"],
    Cell[223644, 8975, 258, 9, 23, "IndexSubentry",
      CellTags->"QLE"]},
  "Quasi-linkage equilibrium"->{
    Cell[223905, 8986, 310, 11, 23, "Index",
      CellTags->"Quasi-linkage equilibrium"]},
  "RandomBottleneckedGenealogy"->{
    Cell[224218, 8999, 312, 10, 23, "Index",
      CellTags->"RandomBottleneckedGenealogy"]},
  "RandomCoalescenceOrder"->{
    Cell[224533, 9011, 299, 10, 23, "Index",
      CellTags->"RandomCoalescenceOrder"]},
  "RandomCoalescenceTimes"->{
    Cell[224835, 9023, 326, 11, 23, "Index",
      CellTags->"RandomCoalescenceTimes"],
    Cell[225164, 9036, 300, 9, 23, "IndexSubentry",
      CellTags->"RandomCoalescenceTimes"]},
  "RandomCum"->{
    Cell[225467, 9047, 288, 10, 23, "Index",
      CellTags->"RandomCum"]},
  "Random drift"->{
    Cell[225758, 9059, 330, 12, 23, "Index",
      CellTags->"Random drift"],
    Cell[226091, 9073, 2349, 77, 158, "IndexSubentry",
      CellTags->"Random drift"]},
  "RandomDrift"->{
    Cell[228443, 9152, 286, 11, 23, "Index",
      CellTags->"RandomDrift"],
    Cell[228732, 9165, 956, 27, 38, "IndexSubentry",
      CellTags->"RandomDrift"]},
  "RandomFamilies"->{
    Cell[229691, 9194, 259, 10, 23, "Index",
      CellTags->"RandomFamilies"]},
  "RandomFamily"->{
    Cell[229953, 9206, 261, 10, 23, "Index",
      CellTags->"RandomFamily"],
    Cell[230217, 9218, 273, 9, 23, "IndexSubentry",
      CellTags->"RandomFamily"]},
  "Random genealogies"->{
    Cell[230493, 9229, 299, 11, 23, "Index",
      CellTags->"Random genealogies"]},
  "RandomGenealogy"->{
    Cell[230795, 9242, 270, 10, 23, "Index",
      CellTags->"RandomGenealogy"],
    Cell[231068, 9254, 286, 9, 23, "IndexSubentry",
      CellTags->"RandomGenealogy"]},
  "RandomList"->{
    Cell[231357, 9265, 241, 10, 23, "Index",
      CellTags->"RandomList"],
    Cell[231601, 9277, 259, 9, 23, "IndexSubentry",
      CellTags->"RandomList"]},
  "Random lists"->{
    Cell[231863, 9288, 259, 11, 23, "Index",
      CellTags->"Random lists"]},
  "RandomMating"->{
    Cell[232125, 9301, 289, 10, 15, "Index",
      CellTags->"RandomMating"]},
  "RandomMultinomial"->{
    Cell[232417, 9313, 286, 10, 15, "Index",
      CellTags->"RandomMultinomial"]},
  "RandomPreviousFamily"->{
    Cell[232706, 9325, 277, 10, 15, "Index",
      CellTags->"RandomPreviousFamily"]},
  "Random sampling"->{
    Cell[232986, 9337, 288, 10, 15, "Index",
      CellTags->"Random sampling"],
    Cell[233277, 9349, 415, 15, 30, "IndexSubentry",
      CellTags->"Random sampling"]},
  "RandomSet"->{
    Cell[233695, 9366, 236, 10, 15, "Index",
      CellTags->"RandomSet"]},
  "Random union"->{
    Cell[233934, 9378, 371, 14, 15, "Index",
      CellTags->"Random union"],
    Cell[234308, 9394, 306, 9, 15, "IndexSubentry",
      CellTags->"Random union"]},
  "RandomUnion"->{
    Cell[234617, 9405, 244, 10, 15, "Index",
      CellTags->"RandomUnion"]},
  "RandomUnionMethod"->{
    Cell[234864, 9417, 276, 10, 15, "Index",
      CellTags->"RandomUnionMethod"]},
  "RandomUnionObsolete"->{
    Cell[235143, 9429, 260, 10, 15, "Index",
      CellTags->"RandomUnionObsolete"]},
  "Random walk"->{
    Cell[235406, 9441, 256, 11, 15, "Index",
      CellTags->"Random walk"]},
  "RecombinantLineages"->{
    Cell[235665, 9454, 325, 11, 15, "Index",
      CellTags->"RecombinantLineages"]},
  "Recombination"->{
    Cell[235993, 9467, 378, 14, 15, "Index",
      CellTags->"Recombination"],
    Cell[236374, 9483, 1122, 39, 90, "IndexSubentry",
      CellTags->"Recombination"]},
  "RecombinationEvents"->{
    Cell[237499, 9524, 325, 11, 15, "Index",
      CellTags->"RecombinationEvents"]},
  "RecombinationRate"->{
    Cell[237827, 9537, 321, 11, 15, "Index",
      CellTags->"RecombinationRate"]},
  "RecombinationSet"->{
    Cell[238151, 9550, 450, 15, 15, "Index",
      CellTags->"RecombinationSet"]},
  "Recombined"->{
    Cell[238604, 9567, 283, 10, 15, "Index",
      CellTags->"Recombined"]},
  "RecombineLineage"->{
    Cell[238890, 9579, 293, 10, 15, "Index",
      CellTags->"RecombineLineage"]},
  "ReducedData"->{
    Cell[239186, 9591, 262, 10, 15, "Index",
      CellTags->"ReducedData"]},
  "ReferencePoint"->{
    Cell[239451, 9603, 316, 11, 15, "Index",
      CellTags->"ReferencePoint"]},
  "ReferencePointMean"->{
    Cell[239770, 9616, 273, 10, 15, "Index",
      CellTags->"ReferencePointMean"],
    Cell[240046, 9628, 1125, 37, 45, "IndexSubentry",
      CellTags->"ReferencePointMean"]},
  "ReferencePointSame"->{
    Cell[241174, 9667, 273, 10, 15, "Index",
      CellTags->"ReferencePointSame"]},
  "ReferencePointZero"->{
    Cell[241450, 9679, 273, 10, 15, "Index",
      CellTags->"ReferencePointZero"]},
  "References"->{
    Cell[241726, 9691, 289, 11, 15, "Index",
      CellTags->"References"]},
  "Reference values"->{
    Cell[242018, 9704, 400, 14, 15, "Index",
      CellTags->"Reference values"],
    Cell[242421, 9720, 472, 15, 30, "IndexSubentry",
      CellTags->"Reference values"]},
  "RemoveTag"->{
    Cell[242896, 9737, 238, 10, 15, "Index",
      CellTags->"RemoveTag"]},
  "Repeat"->{
    Cell[243137, 9749, 239, 10, 15, "Index",
      CellTags->"Repeat"]},
  "Replace"->{
    Cell[243379, 9761, 232, 10, 15, "Index",
      CellTags->"Replace"]},
  "ReplaceAllSpecial"->{
    Cell[243614, 9773, 262, 11, 15, "Index",
      CellTags->"ReplaceAllSpecial"]},
  "ReplaceRepeatedSpecial"->{
    Cell[243879, 9786, 278, 11, 15, "Index",
      CellTags->"ReplaceRepeatedSpecial"]},
  "Representations"->{
    Cell[244160, 9799, 311, 11, 23, "Index",
      CellTags->"Representations"],
    Cell[244474, 9812, 308, 10, 23, "IndexSubentry",
      CellTags->"Representations"]},
  "Reproduction"->{
    Cell[244785, 9824, 286, 11, 23, "Index",
      CellTags->"Reproduction"]},
  "Reverse"->{
    Cell[245074, 9837, 222, 10, 23, "Index",
      CellTags->"Reverse"]},
  "Root"->{
    Cell[245299, 9849, 401, 15, 23, "Index",
      CellTags->"Root"]},
  "RootedGenealogy"->{
    Cell[245703, 9866, 280, 10, 23, "Index",
      CellTags->"RootedGenealogy"]},
  "RootEvents"->{
    Cell[245986, 9878, 298, 11, 23, "Index",
      CellTags->"RootEvents"]},
  "Rootings"->{
    Cell[246287, 9891, 289, 11, 23, "Index",
      CellTags->"Rootings"]},
  "Rules"->{
    Cell[246579, 9904, 244, 10, 23, "Index",
      CellTags->"Rules"],
    Cell[246826, 9916, 234, 9, 23, "IndexSubentry",
      CellTags->"Rules"]},
  "SampleCovariance"->{
    Cell[247063, 9927, 251, 10, 23, "Index",
      CellTags->"SampleCovariance"]},
  "SampleIndividuals"->{
    Cell[247317, 9939, 278, 10, 23, "Index",
      CellTags->"SampleIndividuals"]},
  "SamplePartition"->{
    Cell[247598, 9951, 260, 10, 23, "Index",
      CellTags->"SamplePartition"]},
  "Sampling"->{
    Cell[247861, 9963, 261, 11, 23, "Index",
      CellTags->"Sampling"]},
  "Scripts and faces"->{
    Cell[248125, 9976, 319, 11, 23, "Index",
      CellTags->"Scripts and faces"]},
  "Segments"->{
    Cell[248447, 9989, 292, 11, 23, "Index",
      CellTags->"Segments"]},
  "SegmentStyle"->{
    Cell[248742, 10002, 304, 11, 23, "Index",
      CellTags->"SegmentStyle"]},
  "SegregationRatio"->{
    Cell[249049, 10015, 414, 14, 23, "Index",
      CellTags->"SegregationRatio"]},
  "SelectContext"->{
    Cell[249466, 10031, 321, 11, 23, "Index",
      CellTags->"SelectContext"]},
  "SelectIndividuals"->{
    Cell[249790, 10044, 272, 10, 23, "Index",
      CellTags->"SelectIndividuals"]},
  "Selection"->{
    Cell[250065, 10056, 232, 10, 23, "Index",
      CellTags->"Selection"],
    Cell[250300, 10068, 1704, 61, 143, "IndexSubentry",
      CellTags->"Selection"]},
  "SelectionCoefficient"->{
    Cell[252007, 10131, 437, 15, 23, "Index",
      CellTags->"SelectionCoefficient"]},
  "Selection coefficients"->{
    Cell[252447, 10148, 327, 11, 23, "Index",
      CellTags->"Selection coefficients"],
    Cell[252777, 10161, 519, 19, 38, "IndexSubentry",
      CellTags->"Selection coefficients"]},
  "SelectionExact"->{
    Cell[253299, 10182, 317, 11, 23, "Index",
      CellTags->"SelectionExact"],
    Cell[253619, 10195, 658, 21, 53, "IndexSubentry",
      CellTags->"SelectionExact"]},
  "Selection on diploids"->{
    Cell[254280, 10218, 290, 11, 23, "Index",
      CellTags->"Selection on diploids"],
    Cell[254573, 10231, 888, 33, 83, "IndexSubentry",
      CellTags->"Selection on diploids"]},
  "SelectionRate"->{
    Cell[255464, 10266, 304, 11, 23, "Index",
      CellTags->"SelectionRate"]},
  "SelectLoci"->{
    Cell[255771, 10279, 251, 10, 23, "Index",
      CellTags->"SelectLoci"]},
  "Selfing"->{
    Cell[256025, 10291, 217, 10, 23, "Index",
      CellTags->"Selfing"]},
  "Separate"->{
    Cell[256245, 10303, 235, 10, 23, "Index",
      CellTags->"Separate"]},
  "Servedio"->{
    Cell[256483, 10315, 258, 11, 23, "Index",
      CellTags->"Servedio"]},
  "Set"->{
    Cell[256744, 10328, 339, 12, 23, "Index",
      CellTags->"Set"],
    Cell[257086, 10342, 323, 10, 23, "IndexSubentry",
      CellTags->"Set"]},
  "Set manipulation"->{
    Cell[257412, 10354, 293, 11, 23, "Index",
      CellTags->"Set manipulation"]},
  "SetOfCombinations"->{
    Cell[257708, 10367, 270, 10, 23, "Index",
      CellTags->"SetOfCombinations"]},
  "SetPartition"->{
    Cell[257981, 10379, 251, 10, 23, "Index",
      CellTags->"SetPartition"]},
  "Sets of loci"->{
    Cell[258235, 10391, 304, 11, 23, "Index",
      CellTags->"Sets of loci"]},
  "Sex"->{
    Cell[258542, 10404, 216, 10, 23, "Index",
      CellTags->"Sex"]},
  "Sex linkage"->{
    Cell[258761, 10416, 394, 14, 23, "Index",
      CellTags->"Sex linkage"],
    Cell[259158, 10432, 236, 9, 23, "IndexSubentry",
      CellTags->"Sex linkage"]},
  "SexOfOrigin"->{
    Cell[259397, 10443, 240, 10, 23, "Index",
      CellTags->"SexOfOrigin"]},
  "Sexual selection"->{
    Cell[259640, 10455, 267, 10, 23, "Index",
      CellTags->"Sexual selection"],
    Cell[259910, 10467, 1209, 45, 113, "IndexSubentry",
      CellTags->"Sexual selection"]},
  "ShortContext"->{
    Cell[261122, 10514, 265, 10, 23, "Index",
      CellTags->"ShortContext"]},
  "SigmaMatrix"->{
    Cell[261390, 10526, 278, 10, 23, "Index",
      CellTags->"SigmaMatrix"]},
  "SignMask"->{
    Cell[261671, 10538, 247, 10, 23, "Index",
      CellTags->"SignMask"]},
  "SimplifyAddUp"->{
    Cell[261921, 10550, 236, 10, 23, "Index",
      CellTags->"SimplifyAddUp"]},
  "SimplifyAddUpQ"->{
    Cell[262160, 10562, 239, 10, 23, "Index",
      CellTags->"SimplifyAddUpQ"]},
  "SimplifyFamilies"->{
    Cell[262402, 10574, 261, 10, 23, "Index",
      CellTags->"SimplifyFamilies"]},
  "Simulating individuals"->{
    Cell[262666, 10586, 335, 11, 23, "Index",
      CellTags->"Simulating individuals"],
    Cell[263004, 10599, 503, 15, 38, "IndexSubentry",
      CellTags->"Simulating individuals"]},
  "SizeOfGenealogyPlot"->{
    Cell[263510, 10616, 284, 10, 23, "Index",
      CellTags->"SizeOfGenealogyPlot"]},
  "Slatkin & Excoffier 1996"->{
    Cell[263797, 10628, 279, 10, 23, "Index",
      CellTags->"Slatkin & Excoffier 1996"]},
  "SlowChange"->{
    Cell[264079, 10640, 239, 10, 23, "Index",
      CellTags->"SlowChange"]},
  "SortByClass"->{
    Cell[264321, 10652, 274, 10, 23, "Index",
      CellTags->"SortByClass"],
    Cell[264598, 10664, 284, 9, 23, "IndexSubentry",
      CellTags->"SortByClass"]},
  "SortByHead"->{
    Cell[264885, 10675, 231, 10, 23, "Index",
      CellTags->"SortByHead"]},
  "SpatialCovariance"->{
    Cell[265119, 10687, 254, 10, 23, "Index",
      CellTags->"SpatialCovariance"]},
  "Spatially varying selection"->{
    Cell[265376, 10699, 323, 11, 23, "Index",
      CellTags->"Spatially varying selection"]},
  "Special notation"->{
    Cell[265702, 10712, 268, 10, 23, "Index",
      CellTags->"Special notation"]},
  "SplitSet"->{
    Cell[265973, 10724, 239, 10, 23, "Index",
      CellTags->"SplitSet"]},
  "Stabilising selection"->{
    Cell[266215, 10736, 301, 11, 23, "Index",
      CellTags->"Stabilising selection"],
    Cell[266519, 10749, 1135, 40, 98, "IndexSubentry",
      CellTags->"Stabilising selection"]},
  "Stability"->{
    Cell[267657, 10791, 411, 15, 23, "Index",
      CellTags->"Stability"],
    Cell[268071, 10808, 275, 9, 23, "IndexSubentry",
      CellTags->"Stability"]},
  "StabilityDirect"->{
    Cell[268349, 10819, 320, 11, 23, "Index",
      CellTags->"StabilityDirect"],
    Cell[268672, 10832, 280, 9, 23, "IndexSubentry",
      CellTags->"StabilityDirect"]},
  "StabilityK"->{
    Cell[268955, 10843, 422, 14, 23, "Index",
      CellTags->"StabilityK"]},
  "StabilityKTable"->{
    Cell[269380, 10859, 313, 11, 23, "Index",
      CellTags->"StabilityKTable"]},
  "StabilityMatrix"->{
    Cell[269696, 10872, 282, 10, 23, "Index",
      CellTags->"StabilityMatrix"]},
  "Stage"->{
    Cell[269981, 10884, 293, 11, 23, "Index",
      CellTags->"Stage"]},
  "Stages"->{
    Cell[270277, 10897, 225, 10, 23, "Index",
      CellTags->"Stages"],
    Cell[270505, 10909, 288, 9, 23, "IndexSubentry",
      CellTags->"Stages"]},
  "StandardPartition"->{
    Cell[270796, 10920, 266, 10, 23, "Index",
      CellTags->"StandardPartition"]},
  "StandardPartitionQ"->{
    Cell[271065, 10932, 269, 10, 23, "Index",
      CellTags->"StandardPartitionQ"]},
  "StartingStepSize"->{
    Cell[271337, 10944, 285, 10, 23, "Index",
      CellTags->"StartingStepSize"]},
  "Stepping-stone migration"->{
    Cell[271625, 10956, 357, 12, 23, "Index",
      CellTags->"Stepping-stone migration"]},
  "Stepping-stone model"->{
    Cell[271985, 10970, 347, 12, 23, "Index",
      CellTags->"Stepping-stone model"],
    Cell[272335, 10984, 501, 16, 38, "IndexSubentry",
      CellTags->"Stepping-stone model"]},
  "StoreExact"->{
    Cell[272839, 11002, 323, 11, 23, "Index",
      CellTags->"StoreExact"],
    Cell[273165, 11015, 1518, 45, 113, "IndexSubentry",
      CellTags->"StoreExact"]},
  "StoreResults"->{
    Cell[274686, 11062, 450, 15, 23, "Index",
      CellTags->"StoreResults"],
    Cell[275139, 11079, 813, 24, 38, "IndexSubentry",
      CellTags->"StoreResults"]},
  "StructuredArray"->{
    Cell[275955, 11105, 264, 10, 23, "Index",
      CellTags->"StructuredArray"]},
  "StructuredInitialParameters"->{
    Cell[276222, 11117, 304, 10, 23, "Index",
      CellTags->"StructuredInitialParameters"]},
  "StructuredLogLikelihood"->{
    Cell[276529, 11129, 327, 11, 23, "Index",
      CellTags->"StructuredLogLikelihood"]},
  "StructuredMLE"->{
    Cell[276859, 11142, 434, 14, 23, "Index",
      CellTags->"StructuredMLE"]},
  "StructuredModel"->{
    Cell[277296, 11158, 264, 10, 23, "Index",
      CellTags->"StructuredModel"]},
  "StructuredModelReduce"->{
    Cell[277563, 11170, 288, 10, 23, "Index",
      CellTags->"StructuredModelReduce"]},
  "Structured models"->{
    Cell[277854, 11182, 262, 11, 23, "Index",
      CellTags->"Structured models"],
    Cell[278119, 11195, 272, 9, 23, "IndexSubentry",
      CellTags->"Structured models"]},
  "StructuredParameter"->{
    Cell[278394, 11206, 286, 10, 23, "Index",
      CellTags->"StructuredParameter"]},
  "StructuredVariance"->{
    Cell[278683, 11218, 332, 11, 23, "Index",
      CellTags->"StructuredVariance"]},
  "Style sheets"->{
    Cell[279018, 11231, 248, 11, 23, "Index",
      CellTags->"Style sheets"]},
  "Subdivide"->{
    Cell[279269, 11244, 272, 10, 23, "Index",
      CellTags->"Subdivide"]},
  "Subscripts"->{
    Cell[279544, 11256, 309, 11, 23, "Index",
      CellTags->"Subscripts"]},
  "Subsets"->{
    Cell[279856, 11269, 222, 10, 23, "Index",
      CellTags->"Subsets"],
    Cell[280081, 11281, 366, 15, 38, "IndexSubentry",
      CellTags->"Subsets"]},
  "Sums"->{
    Cell[280450, 11298, 234, 11, 23, "Index",
      CellTags->"Sums"]},
  "SwapStates"->{
    Cell[280687, 11311, 255, 10, 23, "Index",
      CellTags->"SwapStates"]},
  "Symmetric cline"->{
    Cell[280945, 11323, 344, 11, 23, "Index",
      CellTags->"Symmetric cline"],
    Cell[281292, 11336, 317, 9, 23, "IndexSubentry",
      CellTags->"Symmetric cline"]},
  "SymmetricDiploidFrequencies"->{
    Cell[281612, 11347, 331, 11, 23, "Index",
      CellTags->"SymmetricDiploidFrequencies"]},
  "SymmetricHaploidFrequencies"->{
    Cell[281946, 11360, 331, 11, 23, "Index",
      CellTags->"SymmetricHaploidFrequencies"]},
  "Symmetric model"->{
    Cell[282280, 11373, 431, 15, 23, "Index",
      CellTags->"Symmetric model"],
    Cell[282714, 11390, 1473, 49, 113, "IndexSubentry",
      CellTags->"Symmetric model"]},
  "SymmetricNeutralDiploidFrequencies"->{
    Cell[284190, 11441, 477, 15, 23, "Index",
      CellTags->"SymmetricNeutralDiploidFrequencies"]},
  "SymmetricNeutralHaploidFrequencies"->{
    Cell[284670, 11458, 477, 15, 23, "Index",
      CellTags->"SymmetricNeutralHaploidFrequencies"]},
  "SymmetricRecombination"->{
    Cell[285150, 11475, 279, 10, 23, "Index",
      CellTags->"SymmetricRecombination"]},
  "SymmetricRepresentations"->{
    Cell[285432, 11487, 315, 10, 23, "Index",
      CellTags->"SymmetricRepresentations"]},
  "SymmetricSexes"->{
    Cell[285750, 11499, 259, 10, 23, "Index",
      CellTags->"SymmetricSexes"]},
  "Symmetrise"->{
    Cell[286012, 11511, 356, 14, 23, "Index",
      CellTags->"Symmetrise"]},
  "T"->{
    Cell[286371, 11527, 234, 11, 23, "Index",
      CellTags->"T"]},
  "Table"->{
    Cell[286608, 11540, 277, 11, 23, "Index",
      CellTags->"Table"]},
  "Tag"->{
    Cell[286888, 11553, 220, 10, 23, "Index",
      CellTags->"Tag"]},
  "Tags"->{
    Cell[287111, 11565, 260, 11, 23, "Index",
      CellTags->"Tags"],
    Cell[287374, 11578, 295, 10, 23, "IndexSubentry",
      CellTags->"Tags"]},
  "TakeAway"->{
    Cell[287672, 11590, 390, 12, 23, "Index",
      CellTags->"TakeAway"]},
  "TakeOptions"->{
    Cell[288065, 11604, 260, 10, 23, "Index",
      CellTags->"TakeOptions"]},
  "Time"->{
    Cell[288328, 11616, 237, 11, 23, "Index",
      CellTags->"Time"]},
  "TimesOfEvents"->{
    Cell[288568, 11629, 307, 11, 23, "Index",
      CellTags->"TimesOfEvents"]},
  "TimespanOfJunction"->{
    Cell[288878, 11642, 322, 11, 23, "Index",
      CellTags->"TimespanOfJunction"]},
  "TimespanOfLineage"->{
    Cell[289203, 11655, 319, 11, 23, "Index",
      CellTags->"TimespanOfLineage"]},
  "TimesUp"->{
    Cell[289525, 11668, 346, 14, 23, "Index",
      CellTags->"TimesUp"],
    Cell[289874, 11684, 375, 15, 38, "IndexSubentry",
      CellTags->"TimesUp"]},
  "ToBaake"->{
    Cell[290252, 11701, 248, 10, 23, "Index",
      CellTags->"ToBaake"]},
  "ToBennett"->{
    Cell[290503, 11713, 254, 10, 23, "Index",
      CellTags->"ToBennett"]},
  "ToBennettExpression"->{
    Cell[290760, 11725, 284, 10, 23, "Index",
      CellTags->"ToBennettExpression"]},
  "ToCumulants"->{
    Cell[291047, 11737, 260, 10, 23, "Index",
      CellTags->"ToCumulants"]},
  "ToMoments"->{
    Cell[291310, 11749, 254, 10, 23, "Index",
      CellTags->"ToMoments"]},
  "ToPopulationCumulants"->{
    Cell[291567, 11761, 296, 10, 23, "Index",
      CellTags->"ToPopulationCumulants"]},
  "ToPopulationMoments"->{
    Cell[291866, 11773, 290, 10, 23, "Index",
      CellTags->"ToPopulationMoments"]},
  "TotalLength"->{
    Cell[292159, 11785, 286, 10, 23, "Index",
      CellTags->"TotalLength"]},
  "TotalNumber"->{
    Cell[292448, 11797, 252, 10, 23, "Index",
      CellTags->"TotalNumber"]},
  "Trait"->{
    Cell[292703, 11809, 339, 12, 23, "Index",
      CellTags->"Trait"]},
  "TransformedRange"->{
    Cell[293045, 11823, 271, 10, 23, "Index",
      CellTags->"TransformedRange"]},
  "TransformInformation"->{
    Cell[293319, 11835, 291, 10, 23, "Index",
      CellTags->"TransformInformation"]},
  "TransmissionRule"->{
    Cell[293613, 11847, 269, 10, 15, "Index",
      CellTags->"TransmissionRule"]},
  "Transmission rules"->{
    Cell[293885, 11859, 300, 11, 15, "Index",
      CellTags->"Transmission rules"],
    Cell[294188, 11872, 647, 21, 45, "IndexSubentry",
      CellTags->"Transmission rules"]},
  "TriDiagonalMatrix"->{
    Cell[294838, 11895, 272, 10, 15, "Index",
      CellTags->"TriDiagonalMatrix"]},
  "TruncationSelection"->{
    Cell[295113, 11907, 352, 12, 15, "Index",
      CellTags->"TruncationSelection"],
    Cell[295468, 11921, 318, 9, 15, "IndexSubentry",
      CellTags->"TruncationSelection"]},
  "Turelli and Barton 1994"->{
    Cell[295789, 11932, 298, 10, 15, "Index",
      CellTags->"Turelli and Barton 1994"]},
  "Turelli & Barton 1994"->{
    Cell[296090, 11944, 270, 10, 15, "Index",
      CellTags->"Turelli & Barton 1994"]},
  "Two alleles"->{
    Cell[296363, 11956, 240, 10, 15, "Index",
      CellTags->"Two alleles"],
    Cell[296606, 11968, 360, 13, 15, "IndexSubentry",
      CellTags->"Two alleles"]},
  "UMS"->{
    Cell[296969, 11983, 302, 11, 15, "Index",
      CellTags->"UMS"],
    Cell[297274, 11996, 667, 21, 45, "IndexSubentry",
      CellTags->"UMS"]},
  "UnionOfGametes"->{
    Cell[297944, 12019, 261, 10, 15, "Index",
      CellTags->"UnionOfGametes"]},
  "UnlinkedRecombination"->{
    Cell[298208, 12031, 276, 10, 15, "Index",
      CellTags->"UnlinkedRecombination"]},
  "UnrootedGenealogy"->{
    Cell[298487, 12043, 286, 10, 15, "Index",
      CellTags->"UnrootedGenealogy"]},
  "UpperOffDiagonal"->{
    Cell[298776, 12055, 269, 10, 15, "Index",
      CellTags->"UpperOffDiagonal"]},
  "USM"->{
    Cell[299048, 12067, 302, 11, 15, "Index",
      CellTags->"USM"],
    Cell[299353, 12080, 667, 21, 45, "IndexSubentry",
      CellTags->"USM"]},
  "ValidMatrixQ"->{
    Cell[300023, 12103, 281, 10, 15, "Index",
      CellTags->"ValidMatrixQ"]},
  "VarianceComponents"->{
    Cell[300307, 12115, 332, 11, 15, "Index",
      CellTags->"VarianceComponents"],
    Cell[300642, 12128, 263, 9, 15, "IndexSubentry",
      CellTags->"VarianceComponents"]},
  "Versions"->{
    Cell[300908, 12139, 253, 11, 15, "Index",
      CellTags->"Versions"]},
  "Wiuf & Hein 1999"->{
    Cell[301164, 12152, 428, 14, 15, "Index",
      CellTags->"Wiuf & Hein 1999"]},
  "WLinkedLoci"->{
    Cell[301595, 12168, 260, 11, 15, "Index",
      CellTags->"WLinkedLoci"],
    Cell[301858, 12181, 441, 15, 30, "IndexSubentry",
      CellTags->"WLinkedLoci"]},
  "Wright-Fisher sampling"->{
    Cell[302302, 12198, 277, 10, 15, "Index",
      CellTags->"Wright-Fisher sampling"]},
  "X"->{
    Cell[302582, 12210, 247, 11, 15, "Index",
      CellTags->"X"]},
  "XLinkedLoci"->{
    Cell[302832, 12223, 260, 11, 15, "Index",
      CellTags->"XLinkedLoci"],
    Cell[303095, 12236, 441, 15, 30, "IndexSubentry",
      CellTags->"XLinkedLoci"]},
  "YLinkedLoci"->{
    Cell[303539, 12253, 260, 11, 15, "Index",
      CellTags->"YLinkedLoci"],
    Cell[303802, 12266, 441, 15, 30, "IndexSubentry",
      CellTags->"YLinkedLoci"]},
  "ZLinkedLoci"->{
    Cell[304246, 12283, 260, 11, 15, "Index",
      CellTags->"ZLinkedLoci"],
    Cell[304509, 12296, 441, 15, 30, "IndexSubentry",
      CellTags->"ZLinkedLoci"]},
  "Zygotes"->{
    Cell[304953, 12313, 411, 15, 15, "Index",
      CellTags->"Zygotes"]},
  "\[GothicA]"->{
    Cell[305367, 12330, 427, 15, 15, "Index",
      CellTags->"\[GothicA]"]},
  "\[GothicCapitalA]"->{
    Cell[305797, 12347, 419, 15, 15, "Index",
      CellTags->"\[GothicCapitalA]"]},
  "\[GothicCapitalC]"->{
    Cell[306219, 12364, 340, 11, 15, "Index",
      CellTags->"\[GothicCapitalC]"]},
  "\[GothicCapitalD]"->{
    Cell[306562, 12377, 612, 19, 15, "Index",
      CellTags->"\[GothicCapitalD]"]},
  "\!\(\(\[GothicCapitalG]\^\[RawStar]\)\)"->{
    Cell[307177, 12398, 494, 16, 15, "Index",
      CellTags->"\!\(\(\[GothicCapitalG]\^\[RawStar]\)\)"]},
  "\[GothicCapitalG]"->{
    Cell[307674, 12416, 421, 15, 15, "Index",
      CellTags->"\[GothicCapitalG]"]},
  "\[GothicCapitalH]"->{
    Cell[308098, 12433, 435, 15, 15, "Index",
      CellTags->"\[GothicCapitalH]"]},
  "\[GothicCapitalJ]"->{
    Cell[308536, 12450, 425, 15, 15, "Index",
      CellTags->"\[GothicCapitalJ]"]},
  "\[GothicK]"->{
    Cell[308964, 12467, 320, 11, 15, "Index",
      CellTags->"\[GothicK]"]},
  "\[GothicCapitalK]"->{
    Cell[309287, 12480, 377, 11, 15, "Index",
      CellTags->"\[GothicCapitalK]"]},
  "\[GothicM]"->{
    Cell[309667, 12493, 308, 11, 15, "Index",
      CellTags->"\[GothicM]"]},
  "\[GothicP]"->{
    Cell[309978, 12506, 308, 11, 15, "Index",
      CellTags->"\[GothicP]"]},
  "\[GothicP]\[GothicQ]"->{
    Cell[310289, 12519, 369, 12, 15, "Index",
      CellTags->"\[GothicP]\[GothicQ]"]},
  "\[GothicQ]"->{
    Cell[310661, 12533, 308, 11, 15, "Index",
      CellTags->"\[GothicQ]"]},
  "\[GothicR]"->{
    Cell[310972, 12546, 314, 11, 15, "Index",
      CellTags->"\[GothicR]"]},
  "\[GothicS]"->{
    Cell[311289, 12559, 301, 11, 15, "Index",
      CellTags->"\[GothicS]"]},
  "\[GothicCapitalZ]"->{
    Cell[311593, 12572, 421, 15, 15, "Index",
      CellTags->"\[GothicCapitalZ]"]},
  "\[DoubleStruckCapitalG]"->{
    Cell[312017, 12589, 348, 11, 15, "Index",
      CellTags->"\[DoubleStruckCapitalG]"]},
  "\[DoubleStruckCapitalM]"->{
    Cell[312368, 12602, 322, 11, 15, "Index",
      CellTags->"\[DoubleStruckCapitalM]"]},
  "\[DoubleStruckCapitalR]"->{
    Cell[312693, 12615, 457, 15, 15, "Index",
      CellTags->"\[DoubleStruckCapitalR]"]},
  "\[DoubleStruckCapitalW]"->{
    Cell[313153, 12632, 318, 11, 15, "Index",
      CellTags->"\[DoubleStruckCapitalW]"]},
  "\[DoubleStruckCapitalZ]"->{
    Cell[313474, 12645, 358, 12, 15, "Index",
      CellTags->"\[DoubleStruckCapitalZ]"]},
  "\[Gamma]"->{
    Cell[313835, 12659, 310, 11, 15, "Index",
      CellTags->"\[Gamma]"]},
  "\[Zeta]"->{
    Cell[314148, 12672, 304, 11, 15, "Index",
      CellTags->"\[Zeta]"]},
  "\[CapitalMu]"->{
    Cell[314455, 12685, 307, 11, 15, "Index",
      CellTags->"\[CapitalMu]"]},
  "\[Chi]"->{
    Cell[314765, 12698, 312, 11, 15, "Index",
      CellTags->"\[Chi]"]},
  "\[Sampi]"->{
    Cell[315080, 12711, 296, 11, 15, "Index",
      CellTags->"\[Sampi]"]},
  "$MetropolisAdjustment"->{
    Cell[315379, 12724, 290, 10, 15, "Index",
      CellTags->"$MetropolisAdjustment"]},
  "\[WeierstrassP]"->{
    Cell[315672, 12736, 317, 11, 15, "Index",
      CellTags->"\[WeierstrassP]"]},
  "\[LeftDoubleBracketingBar] \[RightDoubleBracketingBar]"->{
    Cell[315992, 12749, 449, 12, 15, "Index",
      CellTags->"\[LeftDoubleBracketingBar] \[RightDoubleBracketingBar]"]},
  "\[CircleDot]"->{
    Cell[316444, 12763, 320, 11, 15, "Index",
      CellTags->"\[CircleDot]"]},
  "\[Backslash]"->{
    Cell[316767, 12776, 394, 12, 15, "Index",
      CellTags->"\[Backslash]"]},
  "\[Wedge]"->{
    Cell[317164, 12790, 450, 15, 15, "Index",
      CellTags->"\[Wedge]"]},
  "\[CirclePlus]"->{
    Cell[317617, 12807, 319, 11, 15, "Index",
      CellTags->"\[CirclePlus]"]}
  }
*)

(*CellTagsIndex
CellTagsIndex->{
  {"MasterIndexHeading", 318782, 12841},
  {"|.", 318878, 12844},
  {"\\\\", 318955, 12847},
  {"<>", 319032, 12850},
  {"||.", 319108, 12853},
  {"AddAncestors", 319194, 12856},
  {"AddCoalescentLineage", 319298, 12859},
  {"AddDescendants", 319404, 12862},
  {"AddGenealogy", 319502, 12865},
  {"Additive models", 319601, 12868},
  {"Additive selection", 319706, 12871},
  {"AddMutation", 319896, 12876},
  {"AddNode", 319986, 12879},
  {"AddRecombinantLineages", 320087, 12882},
  {"AddTag", 320187, 12885},
  {"AddUp", 320270, 12888},
  {"AdmixtureFrequency", 320441, 12893},
  {"Admixture models", 320547, 12896},
  {"Adults", 320728, 12901},
  {"Allele frequencies", 320824, 12904},
  {"AlleleFrequencies", 321019, 12909},
  {"AlleleFrequency", 321123, 12912},
  {"AlleleFrequencyMean", 321230, 12915},
  {"AlleleFrequencyP", 321429, 12920},
  {"AlleleFrequencyPermutations", 321545, 12923},
  {"AlleleFrequencyPQ", 321662, 12926},
  {"AlleleFrequencyQ", 321768, 12929},
  {"AlleleFrequencyTable", 321877, 12932},
  {"AllelicDeviation", 322079, 12937},
  {"AllelicState", 322180, 12940},
  {"AllEvents", 322274, 12943},
  {"AllSets", 322363, 12946},
  {"Ancestors", 322452, 12949},
  {"AncestralGraphPattern", 322635, 12954},
  {"Ancestral graphs", 322745, 12957},
  {"AncestralLineage", 322938, 12962},
  {"AncestralLineagePattern", 323050, 12965},
  {"Ancestry", 323154, 12968},
  {"Arbitrary sets of loci", 323257, 12971},
  {"Arnold 1996", 323363, 12974},
  {"Asmussen and Orive 2000", 323470, 12977},
  {"Asmussen et al. 1987", 323586, 12980},
  {"B", 323680, 12983},
  {"Baake 2001", 323764, 12986},
  {"BackgroundStyle", 323862, 12989},
  {"Barrier", 323957, 12992},
  {"BarrierStrength", 324052, 12995},
  {"Barton 1986", 324151, 12998},
  {"Barton 1995", 324246, 13001},
  {"Barton 2000", 324341, 13004},
  {"Barton and Turelli 1991", 324448, 13007},
  {"Barton & Gale 1993", 324562, 13010},
  {"Barton & Shpak 1999", 324672, 13013},
  {"Barton & Turelli 1991", 324785, 13016},
  {"Bennett 1954", 324891, 13019},
  {"BennettB", 324984, 13022},
  {"BennettC", 325073, 13025},
  {"BennettExpansion", 325170, 13028},
  {"Biallelic", 325268, 13031},
  {"BiallelicMutation", 325449, 13036},
  {"Binary integers", 325644, 13041},
  {"Birth", 325738, 13044},
  {"BirthTime", 325826, 13047},
  {"Boundary conditions", 325928, 13050},
  {"Box", 326024, 13053},
  {"Boxes", 326106, 13056},
  {"Browser categories", 326203, 13059},
  {"Bugs", 326299, 13062},
  {"ChangeContext", 326469, 13067},
  {"ChangeSex", 326565, 13070},
  {"ClassToGenotypes", 326664, 13073},
  {"Cline", 326759, 13076},
  {"ClineGradient", 326931, 13081},
  {"ClineWidth", 327028, 13084},
  {"CoalesceLineages", 327211, 13089},
  {"CoalescenceDistribution", 327324, 13092},
  {"CoalescenceEvents", 327438, 13095},
  {"Coalescence times", 327546, 13098},
  {"CoalescentLineages", 327655, 13101},
  {"Coalescing lineages", 327766, 13104},
  {"CollapseGenealogy", 327876, 13107},
  {"Combinations", 327979, 13110},
  {"Combine", 328072, 13113},
  {"CompareLogL", 328164, 13116},
  {"Compiled", 328257, 13119},
  {"Compiling", 328349, 13122},
  {"CondenseGenealogy", 328450, 13125},
  {"CondenseMatrix", 328555, 13128},
  {"ConfigurationSet", 328659, 13131},
  {"ConstrainedIntervals", 328769, 13134},
  {"ConstructMutateList", 328882, 13137},
  {"ConstructMutateMatrix", 328996, 13140},
  {"ContextComponentQ", 329108, 13143},
  {"ContextPosition", 329214, 13146},
  {"ContextStageQ", 329316, 13149},
  {"ContextStructure", 329419, 13152},
  {"Continuous populations", 329531, 13155},
  {"ContinuumVariables", 329740, 13160},
  {"ConvertData", 329843, 13163},
  {"ConvertHyperlinkToAddOnsLink", 329956, 13166},
  {"Converting", 330068, 13169},
  {"CountHeterozygotes", 330170, 13172},
  {"Covariance", 330272, 13175},
  {"CovarianceMidPoints", 330375, 13178},
  {"Crow and Kimura 1970", 330488, 13181},
  {"Cumulant", 330590, 13184},
  {"CumulantDisequilibrium", 330694, 13187},
  {"CumulantEquilibrium", 330809, 13190},
  {"CumulantPopulationDisequilibrium", 330934, 13193},
  {"CumulantReduced", 331055, 13196},
  {"Cumulants", 331153, 13199},
  {"Cytoplasmic inheritance", 331259, 13202},
  {"CytoplasmicLoci", 331467, 13207},
  {"dAlleleFrequencyPermutations", 331672, 13212},
  {"Data", 331778, 13215},
  {"Datasets", 331941, 13220},
  {"Dawson 2000", 332034, 13223},
  {"Death", 332124, 13226},
  {"DeathTime", 332212, 13229},
  {"DefineContext", 332308, 13232},
  {"DegreesOfFreedom", 332411, 13235},
  {"DeletedMutations", 332517, 13238},
  {"DeleteGenealogy", 332622, 13241},
  {"DeleteNullLineages", 332729, 13244},
  {"Deme", 332915, 13249},
  {"DemeSize", 333001, 13252},
  {"Dempster et al 1977", 333185, 13257},
  {"Density", 333285, 13260},
  {"Descendants", 333377, 13263},
  {"Dicytonuclear associations", 333572, 13268},
  {"Diploid", 333679, 13271},
  {"DiploidConstraints", 333778, 13274},
  {"DiploidFrequencies", 333888, 13277},
  {"DiploidGenotypeFrequency", 334004, 13280},
  {"DiploidGenotypeFrequencyList", 334130, 13283},
  {"DiploidGenotypeFrequencyReduced", 334263, 13286},
  {"DiploidGenotypeFrequencyTable", 334397, 13289},
  {"DiploidIndividuals", 334518, 13292},
  {"DiploidPhenotype", 334626, 13295},
  {"DiploidPsi", 334726, 13298},
  {"DiploidRepresentations", 334832, 13301},
  {"DiploidSource", 334941, 13304},
  {"DiploidSubsets", 335042, 13307},
  {"DiploidTypes", 335142, 13310},
  {"Disequilibrium", 335242, 13313},
  {"DisequilibriumMean", 335435, 13318},
  {"DisequilibriumTable", 335637, 13323},
  {"Dispersal", 335831, 13328},
  {"DistanceSquared", 335929, 13331},
  {"Distribution", 336030, 13334},
  {"DivideZero", 336126, 13337},
  {"DoReplicates", 336222, 13340},
  {"DoubleCline", 336319, 13343},
  {"DrawSamples", 336499, 13348},
  {"DropOptions", 336595, 13351},
  {"Edwards 1972", 336692, 13354},
  {"EmptySets", 336787, 13357},
  {"Epistasis", 336879, 13360},
  {"EquivalentSexes", 336977, 13363},
  {"ErrorBound", 337076, 13366},
  {"EstimateFamilyMoments", 337181, 13369},
  {"EstimateMoments", 337291, 13372},
  {"Estimating D", 337392, 13375},
  {"ExactEigenvalues", 337581, 13380},
  {"ExactIntersection", 337688, 13383},
  {"ExactProbability", 337795, 13386},
  {"Expectation", 337896, 13389},
  {"ExponentialF", 338077, 13394},
  {"ExtantIndividuals", 338265, 13399},
  {"ExtractContexts", 338371, 13402},
  {"ExtractExtant", 338473, 13405},
  {"ExtractGenealogy", 338576, 13408},
  {"ExtractGenes", 338678, 13411},
  {"ExtractInformation", 338782, 13414},
  {"ExtractLabel", 338976, 13419},
  {"ExtractLineagesEndingAtT", 339086, 13422},
  {"ExtractLineagesStartingAtT", 339210, 13425},
  {"ExtractRepeat", 339323, 13428},
  {"ExtractSubMatrix", 339426, 13431},
  {"FamilyAlleleFrequencyEstimate", 339545, 13434},
  {"FamilyEffects", 339661, 13437},
  {"FamilyM", 339755, 13440},
  {"FamilyProbability", 339853, 13443},
  {"Family structure", 339960, 13446},
  {"Fecundity", 340059, 13449},
  {"FindHyperlinks", 340156, 13452},
  {"FindIndexTag", 340256, 13455},
  {"FindMLE", 340349, 13458},
  {"FindNode", 340438, 13461},
  {"FindPosition", 340532, 13464},
  {"FindTags", 340626, 13467},
  {"Fitness", 340715, 13470},
  {"FitnessSet", 340886, 13475},
  {"FitnessTable", 340982, 13478},
  {"FixedEnds", 341162, 13483},
  {"Flatten", 341335, 13488},
  {"FlattenList", 341427, 13491},
  {"FourierNormalised", 341612, 13496},
  {"FourierNormalisedTable", 341725, 13499},
  {"FrequencyRepresentations", 341845, 13502},
  {"FromBaake", 341952, 13505},
  {"FromBennett", 342046, 13508},
  {"FromBennettExpression", 342152, 13511},
  {"FullContext", 342258, 13514},
  {"FullGenotypeFrequencyReduced", 342371, 13517},
  {"FullGenotypeFrequencyTable", 342499, 13520},
  {"FullOutput", 342609, 13523},
  {"Function", 342701, 13526},
  {"Gametes", 342790, 13529},
  {"GameteTable", 342963, 13534},
  {"GaussianLogLikelihood", 343153, 13539},
  {"GaussianMLE", 343259, 13542},
  {"Genealogies", 343355, 13545},
  {"Genealogy", 343533, 13550},
  {"GenealogyToMatrix", 343633, 13553},
  {"GeneralizedTransform", 343744, 13556},
  {"Generating functions", 343858, 13559},
  {"Genes and contexts", 344063, 13564},
  {"Genome", 344161, 13567},
  {"Genotype", 344249, 13570},
  {"Genotype frequencies", 344432, 13575},
  {"Genotype frequency", 344544, 13578},
  {"GenotypeFrequency", 344653, 13581},
  {"GenotypeFrequencyArguments", 344770, 13584},
  {"GenotypeFrequencyConvert", 344895, 13587},
  {"GenotypeFrequencyTable", 345016, 13590},
  {"GenotypePosition", 345129, 13593},
  {"GenotypeProbability", 345239, 13596},
  {"Genotypes", 345434, 13601},
  {"GlobalContinuumVariables", 345542, 13604},
  {"Gnew", 345645, 13607},
  {"Goodman et al 1999", 345742, 13610},
  {"Graphs", 345841, 13613},
  {"Griffiths-Tavare", 345938, 13616},
  {"Guiasu & Shenitzer 1985", 346142, 13621},
  {"HaploidConstraints", 346258, 13624},
  {"HaploidFrequencies", 346369, 13627},
  {"HaploidGenotypeFrequency", 346486, 13630},
  {"HaploidIndividuals", 346603, 13633},
  {"HaploidRepresentations", 346718, 13636},
  {"Haploids", 346823, 13639},
  {"HaploidSource", 346919, 13642},
  {"HaploidSubsets", 347021, 13645},
  {"HaploidTypes", 347122, 13648},
  {"Help browser", 347221, 13651},
  {"Help Browser", 347320, 13654},
  {"Hermaphrodites", 347506, 13659},
  {"HeterozygoteB", 347608, 13662},
  {"Hill 1974a", 347706, 13665},
  {"Hill 1974b", 347801, 13668},
  {"Hill 1974c", 347896, 13671},
  {"Hudson 1990", 347992, 13674},
  {"Hypergeometric model", 348098, 13677},
  {"Hyperlinks", 348203, 13680},
  {"IncidenceMatrix", 348387, 13685},
  {"Index", 348482, 13688},
  {"Individual", 348572, 13691},
  {"IndividualContinuumVariables", 348685, 13694},
  {"IndividualRepresentations", 348813, 13697},
  {"Individuals", 348924, 13700},
  {"InferParentalGenotypes", 349032, 13703},
  {"Infinite sites mutation", 349152, 13706},
  {"InformationFunction", 349269, 13709},
  {"InitialiseContinuum", 349475, 13714},
  {"InitialiseCovariance", 349589, 13717},
  {"InitialiseDemes", 349699, 13720},
  {"InitialStep", 349800, 13723},
  {"InitialStepReduced", 349904, 13726},
  {"InternalNodes", 350010, 13729},
  {"IntervalCombine", 350113, 13732},
  {"IntervalPosition", 350219, 13735},
  {"InverseFourierNormalised", 350334, 13738},
  {"InverseFourierNormalisedTable", 350462, 13741},
  {"Island model", 350578, 13744},
  {"IterateContinuum", 350767, 13749},
  {"IterateExact", 350870, 13752},
  {"Join", 351049, 13757},
  {"Junctions", 351137, 13760},
  {"JunctionStyle", 351234, 13763},
  {"Juveniles", 351331, 13766},
  {"Kirkpatrick and Barton 1997", 351442, 13769},
  {"Kirkpatrick and Servedio 1998", 351573, 13772},
  {"Kirkpatrick et al.", 351695, 13775},
  {"Kirkpatrick et al. 1983", 351906, 13780},
  {"Kruuk 1997", 352014, 13783},
  {"LeafEvents", 352109, 13786},
  {"LeafLabels", 352204, 13789},
  {"LeafOffset", 352299, 13792},
  {"Leaves", 352390, 13795},
  {"Life cycle", 352560, 13800},
  {"LineagesPresent", 352747, 13805},
  {"Li & Nei 1974", 352850, 13808},
  {"Linkage", 352945, 13811},
  {"Linkage disequilibrium", 353130, 13816},
  {"LinkedRecombination", 353246, 13819},
  {"ListToGenealogy", 353355, 13822},
  {"ListToMatrix", 353457, 13825},
  {"Location", 353552, 13828},
  {"Locations", 353644, 13831},
  {"LocusNames", 353738, 13834},
  {"LogLikelihoodDisequilibrium", 353850, 13837},
  {"LogLikelihoodDisequilibriumReduced", 353986, 13840},
  {"LogLikelihoodTest", 354112, 13843},
  {"Log-linear models", 354221, 13846},
  {"Long et al 1995", 354328, 13849},
  {"LowerOffDiagonal", 354434, 13852},
  {"MacCallum 1994", 354539, 13855},
  {"MacCallum et al. 1998", 354649, 13858},
  {"MakeCline", 354754, 13861},
  {"MakeDiploid", 354932, 13866},
  {"MakeDistanceList", 355119, 13871},
  {"MakeDistances", 355223, 13874},
  {"MakeFitnessSet", 355325, 13877},
  {"MakeGenealogy", 355514, 13882},
  {"MakeGenealogyPlot", 355619, 13885},
  {"MakeHaploid", 355722, 13888},
  {"MakeIndividuals", 355908, 13893},
  {"MakeOneWayTable", 356102, 13898},
  {"MakePairwiseTable", 356209, 13901},
  {"MakePopulation", 356315, 13904},
  {"MakeSelectionCoefficient", 356516, 13909},
  {"Mangel & Hilborn 1996", 356734, 13914},
  {"MapLength", 356839, 13917},
  {"MapPosition", 356934, 13920},
  {"Marginal fitness", 357120, 13925},
  {"MarginalTable", 357314, 13930},
  {"MarginalW", 357411, 13933},
  {"MaternalLoci", 357590, 13938},
  {"MatrixGamma", 357774, 13943},
  {"MatrixToGenealogy", 357877, 13946},
  {"MatrixToList", 357981, 13949},
  {"MeanContribution", 358084, 13952},
  {"Mean fitness", 358187, 13955},
  {"MeanW", 358365, 13960},
  {"Meiosis", 358531, 13965},
  {"MethodC", 358700, 13970},
  {"MethodP", 358789, 13973},
  {"Metropolis algorithm", 358891, 13976},
  {"MetropolisDisequilibrium", 359010, 13979},
  {"MetropolisDisequilibriumReduced", 359140, 13982},
  {"Metropolis et al. 1954", 359268, 13985},
  {"MFromC", 359371, 13988},
  {"Migrate", 359459, 13991},
  {"MigrateExact", 359553, 13994},
  {"Migration", 359735, 13999},
  {"MigrationOrder", 359918, 14004},
  {"MigrationRate", 360108, 14009},
  {"MigrationSet", 360208, 14012},
  {"MissingCombination", 360313, 14015},
  {"Missing data", 360418, 14018},
  {"MissingData", 360602, 14023},
  {"Moment", 360778, 14028},
  {"MomentAfterMigration", 360879, 14031},
  {"MomentAfterRecombination", 360998, 14034},
  {"MomentEquilibrium", 361114, 14037},
  {"MomentGeneratingFunction", 361230, 14040},
  {"MomentLimits", 361439, 14045},
  {"MomentNew", 361535, 14048},
  {"MomentReduced", 361632, 14051},
  {"Moments", 361727, 14054},
  {"MomentsFromG", 361904, 14059},
  {"MomentSimple", 362003, 14062},
  {"MonteCarloGriffithsTavare", 362115, 14065},
  {"MonteCarloProbability", 362236, 14068},
  {"Mortality", 362341, 14071},
  {"MostRecentCommonAncestor", 362449, 14074},
  {"MToC", 362552, 14077},
  {"MToCEquations", 362644, 14080},
  {"Muddle", 362738, 14083},
  {"Multilocus algebra", 362837, 14086},
  {"Multilocus MS", 363036, 14091},
  {"Multilocus notation", 363143, 14094},
  {"Multinomial sampling", 363257, 14097},
  {"MultinomialSamplingProbability", 363382, 14100},
  {"Multiple alleles", 363503, 14103},
  {"Multiple arguments", 363702, 14108},
  {"Multiplicative models", 363816, 14111},
  {"MUS", 363915, 14114},
  {"Mutate", 364076, 14119},
  {"MutateCompiled", 364251, 14124},
  {"Mutation", 364348, 14127},
  {"MutationInterval", 364530, 14132},
  {"MutationLabels", 364635, 14135},
  {"MutationOrigin", 364738, 14138},
  {"MutationRate", 364839, 14141},
  {"Mutations", 364935, 14144},
  {"MVariables", 365112, 14149},
  {"Negative binomial", 365214, 14152},
  {"NegativeBinomialLogLikelihood", 365426, 14157},
  {"NegativeBinomialMLE", 365549, 14160},
  {"NegativeHypergeometricDistribution", 365677, 14163},
  {"NeighbourArray", 365800, 14166},
  {"Neighbours", 365899, 14169},
  {"NetCovariance", 365997, 14172},
  {"NetFecundity", 366097, 14175},
  {"NetMortality", 366196, 14178},
  {"NetRecombination", 366299, 14181},
  {"Neutral marker", 366494, 14186},
  {"NeutralRepresentations", 366605, 14189},
  {"NewGametes", 366712, 14192},
  {"NewS", 366886, 14197},
  {"Node", 366969, 14200},
  {"NodeFunction", 367060, 14203},
  {"NodeLabels", 367242, 14208},
  {"NodeOffset", 367337, 14211},
  {"Nodes", 367427, 14214},
  {"NonMendelian", 367519, 14217},
  {"NonNeutralRepresentations", 367717, 14222},
  {"NonSymmetricRepresentations", 367844, 14225},
  {"Normalisation", 367959, 14228},
  {"Normalised", 368057, 14231},
  {"Notation", 368150, 14234},
  {"Notation Package", 368331, 14239},
  {"NullAllele", 368432, 14242},
  {"Null alleles", 368612, 14247},
  {"Null lineages", 368797, 14252},
  {"NullLineages", 368897, 14255},
  {"NullRecombinationEvents", 369007, 14258},
  {"NumberedLink", 369117, 14261},
  {"Numbering", 369213, 14264},
  {"NumberOfCoalescences", 369400, 14269},
  {"NumberOfGenes", 369508, 14272},
  {"NumberOfGenesTable", 369701, 14277},
  {"NumberOfIndividuals", 369813, 14280},
  {"NumberOfIndividualsTable", 369931, 14283},
  {"NumberOfLineages", 370046, 14286},
  {"NumberOfLoci", 370149, 14289},
  {"NumberOfMutations", 370253, 14292},
  {"NumberOfPossibleCoalescences", 370373, 14295},
  {"NumberOfSamplePartitions", 370500, 14298},
  {"NumberOfSetPartitions", 370620, 14301},
  {"NumericalModel", 370730, 14304},
  {"Numerical models", 370922, 14309},
  {"Observable genotype", 371123, 14314},
  {"Obsolete", 371225, 14317},
  {"Offspring", 371402, 14322},
  {"Ordered", 371493, 14325},
  {"Orive & Barton 1999", 371594, 14328},
  {"OtherSex", 371696, 14331},
  {"Packages", 371787, 14334},
  {"PackageSaver", 371964, 14339},
  {"ParentalGenotypes", 372068, 14342},
  {"Partitions", 372170, 14345},
  {"PartitionSet", 372351, 14350},
  {"Paternal inheritance", 372458, 14353},
  {"PaternalLoci", 372565, 14356},
  {"PatternFree", 372749, 14361},
  {"Permutations", 372847, 14364},
  {"Permutations in defining coefficients", 372971, 14367},
  {"Phenotypes", 373093, 14370},
  {"Phipps & Brill 1995", 373197, 14373},
  {"Ploidy", 373297, 14376},
  {"PloidyWeightList", 373394, 14379},
  {"PlotGenealogy", 373498, 14382},
  {"PlotLogL", 373594, 14385},
  {"PlotSegments", 373689, 14388},
  {"Plotting", 373784, 14391},
  {"PopulationDisequilibrium", 373891, 14394},
  {"PopulationExpectation", 374011, 14397},
  {"PopulationRepresentations", 374226, 14402},
  {"Position", 374334, 14405},
  {"PositionsList", 374512, 14410},
  {"PositionsMatrix", 374615, 14413},
  {"PossibleCoalescenceOrder", 374729, 14416},
  {"PossibleDiploidGenotypes", 374852, 14419},
  {"PossibleGenotypes", 374968, 14422},
  {"PossibleRootings", 375076, 14425},
  {"PowerF", 375173, 14428},
  {"PresentOneWayTable", 375352, 14433},
  {"PresentPairwiseTable", 375465, 14436},
  {"PresentResults", 375574, 14439},
  {"Principal components", 375683, 14442},
  {"PrintDetails", 375790, 14445},
  {"Problems", 375971, 14450},
  {"Products", 376144, 14455},
  {"ProductSum", 376237, 14458},
  {"QLE", 376408, 14463},
  {"Quasi-linkage equilibrium", 376587, 14468},
  {"RandomBottleneckedGenealogy", 376714, 14471},
  {"RandomCoalescenceOrder", 376838, 14474},
  {"RandomCoalescenceTimes", 376957, 14477},
  {"RandomCum", 377158, 14482},
  {"Random drift", 377254, 14485},
  {"RandomDrift", 377440, 14490},
  {"RandomFamilies", 377625, 14495},
  {"RandomFamily", 377726, 14498},
  {"Random genealogies", 377916, 14503},
  {"RandomGenealogy", 378024, 14506},
  {"RandomList", 378212, 14511},
  {"Random lists", 378392, 14516},
  {"RandomMating", 378491, 14519},
  {"RandomMultinomial", 378595, 14522},
  {"RandomPreviousFamily", 378707, 14525},
  {"Random sampling", 378817, 14528},
  {"RandomSet", 379005, 14533},
  {"Random union", 379101, 14536},
  {"RandomUnion", 379284, 14541},
  {"RandomUnionMethod", 379387, 14544},
  {"RandomUnionObsolete", 379498, 14547},
  {"Random walk", 379603, 14550},
  {"RecombinantLineages", 379708, 14553},
  {"Recombination", 379815, 14556},
  {"RecombinationEvents", 380010, 14561},
  {"RecombinationRate", 380121, 14564},
  {"RecombinationSet", 380229, 14567},
  {"Recombined", 380330, 14570},
  {"RecombineLineage", 380431, 14573},
  {"ReducedData", 380533, 14576},
  {"ReferencePoint", 380633, 14579},
  {"ReferencePointMean", 380740, 14582},
  {"ReferencePointSame", 380944, 14587},
  {"ReferencePointZero", 381055, 14590},
  {"References", 381158, 14593},
  {"Reference values", 381259, 14596},
  {"RemoveTag", 381449, 14601},
  {"Repeat", 381539, 14604},
  {"Replace", 381627, 14607},
  {"ReplaceAllSpecial", 381726, 14610},
  {"ReplaceRepeatedSpecial", 381840, 14613},
  {"Representations", 381952, 14616},
  {"Reproduction", 382143, 14621},
  {"Reverse", 382237, 14624},
  {"Root", 382323, 14627},
  {"RootedGenealogy", 382417, 14630},
  {"RootEvents", 382517, 14633},
  {"Rootings", 382610, 14636},
  {"Rules", 382698, 14639},
  {"SampleCovariance", 382872, 14644},
  {"SampleIndividuals", 382980, 14647},
  {"SamplePartition", 383087, 14650},
  {"Sampling", 383185, 14653},
  {"Scripts and faces", 383285, 14656},
  {"Segments", 383385, 14659},
  {"SegmentStyle", 383480, 14662},
  {"SegregationRatio", 383584, 14665},
  {"SelectContext", 383689, 14668},
  {"SelectIndividuals", 383795, 14671},
  {"Selection", 383897, 14674},
  {"SelectionCoefficient", 384088, 14679},
  {"Selection coefficients", 384206, 14682},
  {"SelectionExact", 384415, 14687},
  {"Selection on diploids", 384615, 14692},
  {"SelectionRate", 384821, 14697},
  {"SelectLoci", 384920, 14700},
  {"Selfing", 385013, 14703},
  {"Separate", 385104, 14706},
  {"Servedio", 385196, 14709},
  {"Set", 385283, 14712},
  {"Set manipulation", 385456, 14717},
  {"SetOfCombinations", 385565, 14720},
  {"SetPartition", 385670, 14723},
  {"Sets of loci", 385770, 14726},
  {"Sex", 385861, 14729},
  {"Sex linkage", 385951, 14732},
  {"SexOfOrigin", 386134, 14737},
  {"Sexual selection", 386237, 14740},
  {"ShortContext", 386434, 14745},
  {"SigmaMatrix", 386533, 14748},
  {"SignMask", 386628, 14751},
  {"SimplifyAddUp", 386725, 14754},
  {"SimplifyAddUpQ", 386828, 14757},
  {"SimplifyFamilies", 386934, 14760},
  {"Simulating individuals", 387048, 14763},
  {"SizeOfGenealogyPlot", 387262, 14768},
  {"Slatkin & Excoffier 1996", 387381, 14771},
  {"SlowChange", 387491, 14774},
  {"SortByClass", 387588, 14777},
  {"SortByHead", 387770, 14782},
  {"SpatialCovariance", 387873, 14785},
  {"Spatially varying selection", 387993, 14788},
  {"Special notation", 388112, 14791},
  {"SplitSet", 388212, 14794},
  {"Stabilising selection", 388317, 14797},
  {"Stability", 388520, 14802},
  {"StabilityDirect", 388703, 14807},
  {"StabilityK", 388893, 14812},
  {"StabilityKTable", 388994, 14815},
  {"StabilityMatrix", 389100, 14818},
  {"Stage", 389196, 14821},
  {"Stages", 389283, 14824},
  {"StandardPartition", 389462, 14829},
  {"StandardPartitionQ", 389573, 14832},
  {"StartingStepSize", 389683, 14835},
  {"Stepping-stone migration", 389799, 14838},
  {"Stepping-stone model", 389919, 14841},
  {"StoreExact", 390120, 14846},
  {"StoreResults", 390305, 14851},
  {"StructuredArray", 390495, 14856},
  {"StructuredInitialParameters", 390613, 14859},
  {"StructuredLogLikelihood", 390739, 14862},
  {"StructuredMLE", 390851, 14865},
  {"StructuredModel", 390955, 14868},
  {"StructuredModelReduce", 391067, 14871},
  {"Structured models", 391181, 14874},
  {"StructuredParameter", 391384, 14879},
  {"StructuredVariance", 391497, 14882},
  {"Style sheets", 391603, 14885},
  {"Subdivide", 391700, 14888},
  {"Subscripts", 391795, 14891},
  {"Subsets", 391888, 14894},
  {"Sums", 392057, 14899},
  {"SwapStates", 392147, 14902},
  {"Symmetric cline", 392248, 14905},
  {"SymmetricDiploidFrequencies", 392455, 14910},
  {"SymmetricHaploidFrequencies", 392585, 14913},
  {"Symmetric model", 392703, 14916},
  {"SymmetricNeutralDiploidFrequencies", 392920, 14921},
  {"SymmetricNeutralHaploidFrequencies", 393064, 14924},
  {"SymmetricRecombination", 393196, 14927},
  {"SymmetricRepresentations", 393318, 14930},
  {"SymmetricSexes", 393432, 14933},
  {"Symmetrise", 393532, 14936},
  {"T", 393619, 14939},
  {"Table", 393701, 14942},
  {"Tag", 393785, 14945},
  {"Tags", 393868, 14948},
  {"TakeAway", 394035, 14953},
  {"TakeOptions", 394130, 14956},
  {"Time", 394221, 14959},
  {"TimesOfEvents", 394314, 14962},
  {"TimespanOfJunction", 394421, 14965},
  {"TimespanOfLineage", 394532, 14968},
  {"TimesUp", 394632, 14971},
  {"ToBaake", 394804, 14976},
  {"ToBennett", 394896, 14979},
  {"ToBennettExpression", 395000, 14982},
  {"ToCumulants", 395106, 14985},
  {"ToMoments", 395202, 14988},
  {"ToPopulationCumulants", 395308, 14991},
  {"ToPopulationMoments", 395424, 14994},
  {"TotalLength", 395530, 14997},
  {"TotalNumber", 395628, 15000},
  {"Trait", 395720, 15003},
  {"TransformedRange", 395817, 15006},
  {"TransformInformation", 395929, 15009},
  {"TransmissionRule", 396041, 15012},
  {"Transmission rules", 396151, 15015},
  {"TriDiagonalMatrix", 396355, 15020},
  {"TruncationSelection", 396467, 15023},
  {"Turelli and Barton 1994", 396678, 15028},
  {"Turelli & Barton 1994", 396798, 15031},
  {"Two alleles", 396906, 15034},
  {"UMS", 397082, 15039},
  {"UnionOfGametes", 397253, 15044},
  {"UnlinkedRecombination", 397364, 15047},
  {"UnrootedGenealogy", 397478, 15050},
  {"UpperOffDiagonal", 397587, 15053},
  {"USM", 397682, 15056},
  {"ValidMatrixQ", 397851, 15061},
  {"VarianceComponents", 397957, 15064},
  {"Versions", 398151, 15069},
  {"Wiuf & Hein 1999", 398251, 15072},
  {"WLinkedLoci", 398354, 15075},
  {"Wright-Fisher sampling", 398549, 15080},
  {"X", 398648, 15083},
  {"XLinkedLoci", 398736, 15086},
  {"YLinkedLoci", 398920, 15091},
  {"ZLinkedLoci", 399104, 15096},
  {"Zygotes", 399284, 15101},
  {"\[GothicA]", 399377, 15104},
  {"\[GothicCapitalA]", 399480, 15107},
  {"\[GothicCapitalC]", 399590, 15110},
  {"\[GothicCapitalD]", 399700, 15113},
  {"\!\(\(\[GothicCapitalG]\^\[RawStar]\)\)", 399832, 15116},
  {"\[GothicCapitalG]", 399964, 15119},
  {"\[GothicCapitalH]", 400074, 15122},
  {"\[GothicCapitalJ]", 400184, 15125},
  {"\[GothicK]", 400287, 15128},
  {"\[GothicCapitalK]", 400390, 15131},
  {"\[GothicM]", 400493, 15134},
  {"\[GothicP]", 400589, 15137},
  {"\[GothicP]\[GothicQ]", 400695, 15140},
  {"\[GothicQ]", 400801, 15143},
  {"\[GothicR]", 400897, 15146},
  {"\[GothicS]", 400993, 15149},
  {"\[GothicCapitalZ]", 401096, 15152},
  {"\[DoubleStruckCapitalG]", 401212, 15155},
  {"\[DoubleStruckCapitalM]", 401334, 15158},
  {"\[DoubleStruckCapitalR]", 401456, 15161},
  {"\[DoubleStruckCapitalW]", 401578, 15164},
  {"\[DoubleStruckCapitalZ]", 401700, 15167},
  {"\[Gamma]", 401807, 15170},
  {"\[Zeta]", 401898, 15173},
  {"\[CapitalMu]", 401993, 15176},
  {"\[Chi]", 402087, 15179},
  {"\[Sampi]", 402177, 15182},
  {"$MetropolisAdjustment", 402282, 15185},
  {"\[WeierstrassP]", 402394, 15188},
  {"\[LeftDoubleBracketingBar] \[RightDoubleBracketingBar]", 402539, 15191},
  {"\[CircleDot]", 402681, 15194},
  {"\[Backslash]", 402781, 15197},
  {"\[Wedge]", 402877, 15200},
  {"\[CirclePlus]", 402974, 15203}
  }
*)

(*NotebookFileOutline
Notebook[{
Cell[1717, 49, 79, 1, 41, "IndexSection",
  CellTags->"MasterIndexHeading"],
Cell[1799, 52, 247, 11, 15, "Index",
  CellTags->"|."],
Cell[2049, 65, 233, 11, 15, "Index",
  CellTags->"\\\\"],
Cell[2285, 78, 243, 11, 15, "Index",
  CellTags->"<>"],
Cell[2531, 91, 254, 11, 15, "Index",
  CellTags->"||."],
Cell[2788, 104, 296, 11, 15, "Index",
  CellTags->"AddAncestors"],
Cell[3087, 117, 331, 11, 15, "Index",
  CellTags->"AddCoalescentLineage"],
Cell[3421, 130, 302, 11, 15, "Index",
  CellTags->"AddDescendants"],
Cell[3726, 143, 271, 10, 15, "Index",
  CellTags->"AddGenealogy"],
Cell[4000, 155, 272, 10, 15, "Index",
  CellTags->"Additive models"],
Cell[4275, 167, 303, 11, 15, "Index",
  CellTags->"Additive selection"],
Cell[4581, 180, 713, 27, 60, "IndexSubentry",
  CellTags->"Additive selection"],
Cell[5297, 209, 268, 10, 15, "Index",
  CellTags->"AddMutation"],
Cell[5568, 221, 256, 10, 15, "Index",
  CellTags->"AddNode"],
Cell[5827, 233, 337, 11, 15, "Index",
  CellTags->"AddRecombinantLineages"],
Cell[6167, 246, 229, 10, 15, "Index",
  CellTags->"AddTag"],
Cell[6399, 258, 334, 14, 15, "Index",
  CellTags->"AddUp"],
Cell[6736, 274, 492, 21, 45, "IndexSubentry",
  CellTags->"AddUp"],
Cell[7231, 297, 261, 10, 15, "Index",
  CellTags->"AdmixtureFrequency"],
Cell[7495, 309, 352, 14, 15, "Index",
  CellTags->"Admixture models"],
Cell[7850, 325, 843, 33, 75, "IndexSubentry",
  CellTags->"Admixture models"],
Cell[8696, 360, 408, 15, 15, "Index",
  CellTags->"Adults"],
Cell[9107, 377, 326, 11, 15, "Index",
  CellTags->"Allele frequencies"],
Cell[9436, 390, 287, 9, 15, "IndexSubentry",
  CellTags->"Allele frequencies"],
Cell[9726, 401, 472, 15, 15, "Index",
  CellTags->"AlleleFrequencies"],
Cell[10201, 418, 286, 10, 15, "Index",
  CellTags->"AlleleFrequency"],
Cell[10490, 430, 298, 10, 15, "Index",
  CellTags->"AlleleFrequencyMean"],
Cell[10791, 442, 959, 30, 60, "IndexSubentry",
  CellTags->"AlleleFrequencyMean"],
Cell[11753, 474, 314, 11, 23, "Index",
  CellTags->"AlleleFrequencyP"],
Cell[12070, 487, 304, 10, 23, "Index",
  CellTags->"AlleleFrequencyPermutations"],
Cell[12377, 499, 366, 12, 23, "Index",
  CellTags->"AlleleFrequencyPQ"],
Cell[12746, 513, 314, 11, 23, "Index",
  CellTags->"AlleleFrequencyQ"],
Cell[13063, 526, 301, 10, 23, "Index",
  CellTags->"AlleleFrequencyTable"],
Cell[13367, 538, 1143, 36, 83, "IndexSubentry",
  CellTags->"AlleleFrequencyTable"],
Cell[14513, 576, 313, 11, 23, "Index",
  CellTags->"AllelicDeviation"],
Cell[14829, 589, 258, 11, 23, "Index",
  CellTags->"AllelicState"],
Cell[15090, 602, 295, 11, 23, "Index",
  CellTags->"AllEvents"],
Cell[15388, 615, 258, 10, 23, "Index",
  CellTags->"AllSets"],
Cell[15649, 627, 273, 11, 23, "Index",
  CellTags->"Ancestors"],
Cell[15925, 640, 273, 9, 23, "IndexSubentry",
  CellTags->"Ancestors"],
Cell[16201, 651, 308, 10, 23, "Index",
  CellTags->"AncestralGraphPattern"],
Cell[16512, 663, 293, 11, 23, "Index",
  CellTags->"Ancestral graphs"],
Cell[16808, 676, 926, 33, 83, "IndexSubentry",
  CellTags->"Ancestral graphs"],
Cell[17737, 711, 293, 10, 23, "Index",
  CellTags->"AncestralLineage"],
Cell[18033, 723, 314, 10, 23, "Index",
  CellTags->"AncestralLineagePattern"],
Cell[18350, 735, 255, 10, 23, "Index",
  CellTags->"Ancestry"],
Cell[18608, 747, 334, 11, 23, "Index",
  CellTags->"Arbitrary sets of loci"],
Cell[18945, 760, 240, 10, 23, "Index",
  CellTags->"Arnold 1996"],
Cell[19188, 772, 414, 14, 23, "Index",
  CellTags->"Asmussen and Orive 2000"],
Cell[19605, 788, 266, 10, 23, "Index",
  CellTags->"Asmussen et al. 1987"],
Cell[19874, 800, 256, 10, 23, "Index",
  CellTags->"B"],
Cell[20133, 812, 363, 14, 23, "Index",
  CellTags->"Baake 2001"],
Cell[20499, 828, 313, 11, 23, "Index",
  CellTags->"BackgroundStyle"],
Cell[20815, 841, 276, 11, 23, "Index",
  CellTags->"Barrier"],
Cell[21094, 854, 276, 10, 23, "Index",
  CellTags->"BarrierStrength"],
Cell[21373, 866, 240, 10, 23, "Index",
  CellTags->"Barton 1986"],
Cell[21616, 878, 262, 10, 23, "Index",
  CellTags->"Barton 1995"],
Cell[21881, 890, 240, 10, 23, "Index",
  CellTags->"Barton 2000"],
Cell[22124, 902, 298, 10, 23, "Index",
  CellTags->"Barton and Turelli 1991"],
Cell[22425, 914, 261, 10, 23, "Index",
  CellTags->"Barton & Gale 1993"],
Cell[22689, 926, 264, 10, 23, "Index",
  CellTags->"Barton & Shpak 1999"],
Cell[22956, 938, 270, 10, 23, "Index",
  CellTags->"Barton & Turelli 1991"],
Cell[23229, 950, 243, 10, 23, "Index",
  CellTags->"Bennett 1954"],
Cell[23475, 962, 251, 10, 23, "Index",
  CellTags->"BennettB"],
Cell[23729, 974, 251, 10, 23, "Index",
  CellTags->"BennettC"],
Cell[23983, 986, 275, 10, 23, "Index",
  CellTags->"BennettExpansion"],
Cell[24261, 998, 236, 10, 23, "Index",
  CellTags->"Biallelic"],
Cell[24500, 1010, 358, 13, 23, "IndexSubentry",
  CellTags->"Biallelic"],
Cell[24861, 1025, 276, 10, 23, "Index",
  CellTags->"BiallelicMutation"],
Cell[25140, 1037, 268, 9, 23, "IndexSubentry",
  CellTags->"BiallelicMutation"],
Cell[25411, 1048, 266, 10, 23, "Index",
  CellTags->"Binary integers"],
Cell[25680, 1060, 262, 10, 23, "Index",
  CellTags->"Birth"],
Cell[25945, 1072, 258, 10, 23, "Index",
  CellTags->"BirthTime"],
Cell[26206, 1084, 447, 15, 23, "Index",
  CellTags->"Boundary conditions"],
Cell[26656, 1101, 240, 10, 23, "Index",
  CellTags->"Box"],
Cell[26899, 1113, 246, 10, 23, "Index",
  CellTags->"Boxes"],
Cell[27148, 1125, 293, 10, 23, "Index",
  CellTags->"Browser categories"],
Cell[27444, 1137, 239, 11, 23, "Index",
  CellTags->"Bugs"],
Cell[27686, 1150, 1583, 63, 158, "IndexSubentry",
  CellTags->"Bugs"],
Cell[29272, 1215, 318, 11, 23, "Index",
  CellTags->"ChangeContext"],
Cell[29593, 1228, 238, 10, 23, "Index",
  CellTags->"ChangeSex"],
Cell[29834, 1240, 289, 10, 23, "Index",
  CellTags->"ClassToGenotypes"],
Cell[30126, 1252, 253, 11, 23, "Index",
  CellTags->"Cline"],
Cell[30382, 1265, 2662, 78, 113, "IndexSubentry",
  CellTags->"Cline"],
Cell[33047, 1345, 325, 11, 23, "Index",
  CellTags->"ClineGradient"],
Cell[33375, 1358, 323, 11, 15, "Index",
  CellTags->"ClineWidth"],
Cell[33701, 1371, 695, 21, 45, "IndexSubentry",
  CellTags->"ClineWidth"],
Cell[34399, 1394, 293, 10, 15, "Index",
  CellTags->"CoalesceLineages"],
Cell[34695, 1406, 329, 11, 15, "Index",
  CellTags->"CoalescenceDistribution"],
Cell[35027, 1419, 319, 11, 15, "Index",
  CellTags->"CoalescenceEvents"],
Cell[35349, 1432, 325, 11, 15, "Index",
  CellTags->"Coalescence times"],
Cell[35677, 1445, 322, 11, 15, "Index",
  CellTags->"CoalescentLineages"],
Cell[36002, 1458, 326, 11, 15, "Index",
  CellTags->"Coalescing lineages"],
Cell[36331, 1471, 282, 10, 15, "Index",
  CellTags->"CollapseGenealogy"],
Cell[36616, 1483, 274, 11, 15, "Index",
  CellTags->"Combinations"],
Cell[36893, 1496, 232, 10, 15, "Index",
  CellTags->"Combine"],
Cell[37128, 1508, 256, 10, 15, "Index",
  CellTags->"CompareLogL"],
Cell[37387, 1520, 1075, 31, 30, "Index",
  CellTags->"Compiled"],
Cell[38465, 1553, 1073, 31, 30, "Index",
  CellTags->"Compiling"],
Cell[39541, 1586, 286, 10, 15, "Index",
  CellTags->"CondenseGenealogy"],
Cell[39830, 1598, 271, 10, 15, "Index",
  CellTags->"CondenseMatrix"],
Cell[40104, 1610, 267, 10, 15, "Index",
  CellTags->"ConfigurationSet"],
Cell[40374, 1622, 289, 10, 15, "Index",
  CellTags->"ConstrainedIntervals"],
Cell[40666, 1634, 754, 22, 15, "Index",
  CellTags->"ConstructMutateList"],
Cell[41423, 1658, 442, 14, 15, "Index",
  CellTags->"ConstructMutateMatrix"],
Cell[41868, 1674, 286, 10, 15, "Index",
  CellTags->"ContextComponentQ"],
Cell[42157, 1686, 280, 10, 15, "Index",
  CellTags->"ContextPosition"],
Cell[42440, 1698, 274, 10, 15, "Index",
  CellTags->"ContextStageQ"],
Cell[42717, 1710, 283, 10, 15, "Index",
  CellTags->"ContextStructure"],
Cell[43003, 1722, 312, 11, 15, "Index",
  CellTags->"Continuous populations"],
Cell[43318, 1735, 665, 27, 60, "IndexSubentry",
  CellTags->"Continuous populations"],
Cell[43986, 1764, 273, 10, 15, "Index",
  CellTags->"ContinuumVariables"],
Cell[44262, 1776, 260, 10, 15, "Index",
  CellTags->"ConvertData"],
Cell[44525, 1788, 291, 10, 15, "Index",
  CellTags->"ConvertHyperlinkToAddOnsLink"],
Cell[44819, 1800, 427, 15, 15, "Index",
  CellTags->"Converting"],
Cell[45249, 1817, 287, 10, 15, "Index",
  CellTags->"CountHeterozygotes"],
Cell[45539, 1829, 292, 11, 15, "Index",
  CellTags->"Covariance"],
Cell[45834, 1842, 260, 10, 15, "Index",
  CellTags->"CovarianceMidPoints"],
Cell[46097, 1854, 289, 10, 15, "Index",
  CellTags->"Crow and Kimura 1970"],
Cell[46389, 1866, 253, 10, 23, "Index",
  CellTags->"Cumulant"],
Cell[46645, 1878, 332, 11, 23, "Index",
  CellTags->"CumulantDisequilibrium"],
Cell[46980, 1891, 264, 10, 23, "Index",
  CellTags->"CumulantEquilibrium"],
Cell[47247, 1903, 392, 11, 23, "Index",
  CellTags->"CumulantPopulationDisequilibrium"],
Cell[47642, 1916, 268, 10, 23, "Index",
  CellTags->"CumulantReduced"],
Cell[47913, 1928, 333, 14, 23, "Index",
  CellTags->"Cumulants"],
Cell[48249, 1944, 426, 14, 23, "Index",
  CellTags->"Cytoplasmic inheritance"],
Cell[48678, 1960, 440, 15, 38, "IndexSubentry",
  CellTags->"Cytoplasmic inheritance"],
Cell[49121, 1977, 283, 11, 23, "Index",
  CellTags->"CytoplasmicLoci"],
Cell[49407, 1990, 453, 15, 38, "IndexSubentry",
  CellTags->"CytoplasmicLoci"],
Cell[49863, 2007, 307, 10, 23, "Index",
  CellTags->"dAlleleFrequencyPermutations"],
Cell[50173, 2019, 235, 10, 23, "Index",
  CellTags->"Data"],
Cell[50411, 2031, 423, 15, 38, "IndexSubentry",
  CellTags->"Data"],
Cell[50837, 2048, 259, 11, 23, "Index",
  CellTags->"Datasets"],
Cell[51099, 2061, 368, 14, 23, "Index",
  CellTags->"Dawson 2000"],
Cell[51470, 2077, 262, 10, 23, "Index",
  CellTags->"Death"],
Cell[51735, 2089, 258, 10, 23, "Index",
  CellTags->"DeathTime"],
Cell[51996, 2101, 274, 10, 23, "Index",
  CellTags->"DefineContext"],
Cell[52273, 2113, 271, 10, 23, "Index",
  CellTags->"DegreesOfFreedom"],
Cell[52547, 2125, 279, 10, 23, "Index",
  CellTags->"DeletedMutations"],
Cell[52829, 2137, 280, 10, 23, "Index",
  CellTags->"DeleteGenealogy"],
Cell[53112, 2149, 321, 11, 23, "Index",
  CellTags->"DeleteNullLineages"],
Cell[53436, 2162, 311, 9, 23, "IndexSubentry",
  CellTags->"DeleteNullLineages"],
Cell[53750, 2173, 322, 14, 23, "Index",
  CellTags->"Deme"],
Cell[54075, 2189, 614, 20, 23, "Index",
  CellTags->"DemeSize"],
Cell[54692, 2211, 3026, 86, 142, "IndexSubentry",
  CellTags->"DemeSize"],
Cell[57721, 2299, 264, 10, 23, "Index",
  CellTags->"Dempster et al 1977"],
Cell[57988, 2311, 252, 10, 23, "Index",
  CellTags->"Density"],
Cell[58243, 2323, 270, 10, 23, "Index",
  CellTags->"Descendants"],
Cell[58516, 2335, 436, 15, 38, "IndexSubentry",
  CellTags->"Descendants"],
Cell[58955, 2352, 296, 10, 23, "Index",
  CellTags->"Dicytonuclear associations"],
Cell[59254, 2364, 304, 11, 23, "Index",
  CellTags->"Diploid"],
Cell[59561, 2377, 277, 10, 23, "Index",
  CellTags->"DiploidConstraints"],
Cell[59841, 2389, 297, 10, 23, "Index",
  CellTags->"DiploidFrequencies"],
Cell[60141, 2401, 332, 11, 23, "Index",
  CellTags->"DiploidGenotypeFrequency"],
Cell[60476, 2414, 305, 10, 23, "Index",
  CellTags->"DiploidGenotypeFrequencyList"],
Cell[60784, 2426, 316, 10, 23, "Index",
  CellTags->"DiploidGenotypeFrequencyReduced"],
Cell[61103, 2438, 310, 10, 23, "Index",
  CellTags->"DiploidGenotypeFrequencyTable"],
Cell[61416, 2450, 297, 10, 23, "Index",
  CellTags->"DiploidIndividuals"],
Cell[61716, 2462, 275, 10, 23, "Index",
  CellTags->"DiploidPhenotype"],
Cell[61994, 2474, 402, 14, 23, "Index",
  CellTags->"DiploidPsi"],
Cell[62399, 2490, 309, 10, 23, "Index",
  CellTags->"DiploidRepresentations"],
Cell[62711, 2502, 414, 14, 23, "Index",
  CellTags->"DiploidSource"],
Cell[63128, 2518, 259, 10, 23, "Index",
  CellTags->"DiploidSubsets"],
Cell[63390, 2530, 257, 10, 23, "Index",
  CellTags->"DiploidTypes"],
Cell[63650, 2542, 283, 11, 23, "Index",
  CellTags->"Disequilibrium"],
Cell[63936, 2555, 919, 29, 53, "IndexSubentry",
  CellTags->"Disequilibrium"],
Cell[64858, 2586, 339, 11, 23, "Index",
  CellTags->"DisequilibriumMean"],
Cell[65200, 2599, 744, 23, 53, "IndexSubentry",
  CellTags->"DisequilibriumMean"],
Cell[65947, 2624, 347, 12, 23, "Index",
  CellTags->"DisequilibriumTable"],
Cell[66297, 2638, 748, 23, 53, "IndexSubentry",
  CellTags->"DisequilibriumTable"],
Cell[67048, 2663, 299, 11, 23, "Index",
  CellTags->"Dispersal"],
Cell[67350, 2676, 276, 10, 23, "Index",
  CellTags->"DistanceSquared"],
Cell[67629, 2688, 241, 10, 23, "Index",
  CellTags->"Distribution"],
Cell[67873, 2700, 237, 10, 23, "Index",
  CellTags->"DivideZero"],
Cell[68113, 2712, 277, 10, 23, "Index",
  CellTags->"DoReplicates"],
Cell[68393, 2724, 353, 12, 23, "Index",
  CellTags->"DoubleCline"],
Cell[68749, 2738, 772, 23, 53, "IndexSubentry",
  CellTags->"DoubleCline"],
Cell[69524, 2763, 262, 10, 23, "Index",
  CellTags->"DrawSamples"],
Cell[69789, 2775, 260, 10, 23, "Index",
  CellTags->"DropOptions"],
Cell[70052, 2787, 243, 10, 23, "Index",
  CellTags->"Edwards 1972"],
Cell[70298, 2799, 272, 11, 23, "Index",
  CellTags->"EmptySets"],
Cell[70573, 2812, 270, 11, 23, "Index",
  CellTags->"Epistasis"],
Cell[70846, 2825, 300, 11, 23, "Index",
  CellTags->"EquivalentSexes"],
Cell[71149, 2838, 267, 10, 23, "Index",
  CellTags->"ErrorBound"],
Cell[71419, 2850, 298, 10, 23, "Index",
  CellTags->"EstimateFamilyMoments"],
Cell[71720, 2862, 274, 10, 23, "Index",
  CellTags->"EstimateMoments"],
Cell[71997, 2874, 269, 11, 23, "Index",
  CellTags->"Estimating D"],
Cell[72269, 2887, 2407, 92, 218, "IndexSubentry",
  CellTags->"Estimating D"],
Cell[74679, 2981, 293, 10, 23, "Index",
  CellTags->"ExactEigenvalues"],
Cell[74975, 2993, 459, 15, 23, "Index",
  CellTags->"ExactIntersection"],
Cell[75437, 3010, 269, 10, 23, "Index",
  CellTags->"ExactProbability"],
Cell[75709, 3022, 252, 11, 23, "Index",
  CellTags->"Expectation"],
Cell[75964, 3035, 572, 16, 38, "IndexSubentry",
  CellTags->"Expectation"],
Cell[76539, 3053, 329, 11, 23, "Index",
  CellTags->"ExponentialF"],
Cell[76871, 3066, 877, 26, 53, "IndexSubentry",
  CellTags->"ExponentialF"],
Cell[77751, 3094, 270, 10, 23, "Index",
  CellTags->"ExtantIndividuals"],
Cell[78024, 3106, 321, 11, 23, "Index",
  CellTags->"ExtractContexts"],
Cell[78348, 3119, 242, 10, 23, "Index",
  CellTags->"ExtractExtant"],
Cell[78593, 3131, 424, 14, 23, "Index",
  CellTags->"ExtractGenealogy"],
Cell[79020, 3147, 314, 11, 23, "Index",
  CellTags->"ExtractGenes"],
Cell[79337, 3160, 285, 10, 23, "Index",
  CellTags->"ExtractInformation"],
Cell[79625, 3172, 301, 9, 23, "IndexSubentry",
  CellTags->"ExtractInformation"],
Cell[79929, 3183, 306, 11, 23, "Index",
  CellTags->"ExtractLabel"],
Cell[80238, 3196, 342, 11, 23, "Index",
  CellTags->"ExtractLineagesEndingAtT"],
Cell[80583, 3209, 353, 12, 23, "Index",
  CellTags->"ExtractLineagesStartingAtT"],
Cell[80939, 3223, 260, 10, 23, "Index",
  CellTags->"ExtractRepeat"],
Cell[81202, 3235, 279, 10, 23, "Index",
  CellTags->"ExtractSubMatrix"],
Cell[81484, 3247, 327, 11, 23, "Index",
  CellTags->"FamilyAlleleFrequencyEstimate"],
Cell[81814, 3260, 274, 10, 23, "Index",
  CellTags->"FamilyEffects"],
Cell[82091, 3272, 256, 10, 23, "Index",
  CellTags->"FamilyM"],
Cell[82350, 3284, 264, 10, 23, "Index",
  CellTags->"FamilyProbability"],
Cell[82617, 3296, 291, 11, 23, "Index",
  CellTags->"Family structure"],
Cell[82911, 3309, 258, 10, 23, "Index",
  CellTags->"Fecundity"],
Cell[83172, 3321, 249, 10, 23, "Index",
  CellTags->"FindHyperlinks"],
Cell[83424, 3333, 243, 10, 23, "Index",
  CellTags->"FindIndexTag"],
Cell[83670, 3345, 238, 10, 23, "Index",
  CellTags->"FindMLE"],
Cell[83911, 3357, 253, 10, 23, "Index",
  CellTags->"FindNode"],
Cell[84167, 3369, 239, 10, 23, "Index",
  CellTags->"FindPosition"],
Cell[84409, 3381, 249, 10, 23, "Index",
  CellTags->"FindTags"],
Cell[84661, 3393, 316, 11, 23, "Index",
  CellTags->"Fitness"],
Cell[84980, 3406, 618, 21, 53, "IndexSubentry",
  CellTags->"Fitness"],
Cell[85601, 3429, 305, 11, 23, "Index",
  CellTags->"FitnessSet"],
Cell[85909, 3442, 295, 11, 23, "Index",
  CellTags->"FitnessTable"],
Cell[86207, 3455, 475, 15, 38, "IndexSubentry",
  CellTags->"FitnessTable"],
Cell[86685, 3472, 300, 11, 23, "Index",
  CellTags->"FixedEnds"],
Cell[86988, 3485, 1296, 37, 67, "IndexSubentry",
  CellTags->"FixedEnds"],
Cell[88287, 3524, 278, 10, 23, "Index",
  CellTags->"Flatten"],
Cell[88568, 3536, 274, 10, 23, "Index",
  CellTags->"FlattenList"],
Cell[88845, 3548, 277, 9, 23, "IndexSubentry",
  CellTags->"FlattenList"],
Cell[89125, 3559, 274, 10, 23, "Index",
  CellTags->"FourierNormalised"],
Cell[89402, 3571, 289, 10, 23, "Index",
  CellTags->"FourierNormalisedTable"],
Cell[89694, 3583, 315, 10, 23, "Index",
  CellTags->"FrequencyRepresentations"],
Cell[90012, 3595, 254, 10, 23, "Index",
  CellTags->"FromBaake"],
Cell[90269, 3607, 260, 10, 23, "Index",
  CellTags->"FromBennett"],
Cell[90532, 3619, 290, 10, 23, "Index",
  CellTags->"FromBennettExpression"],
Cell[90825, 3631, 262, 10, 23, "Index",
  CellTags->"FullContext"],
Cell[91090, 3643, 307, 10, 23, "Index",
  CellTags->"FullGenotypeFrequencyReduced"],
Cell[91400, 3655, 301, 10, 23, "Index",
  CellTags->"FullGenotypeFrequencyTable"],
Cell[91704, 3667, 257, 10, 23, "Index",
  CellTags->"FullOutput"],
Cell[91964, 3679, 241, 10, 23, "Index",
  CellTags->"Function"],
Cell[92208, 3691, 286, 11, 23, "Index",
  CellTags->"Gametes"],
Cell[92497, 3704, 1087, 36, 68, "IndexSubentry",
  CellTags->"Gametes"],
Cell[93587, 3742, 298, 11, 23, "Index",
  CellTags->"GameteTable"],
Cell[93888, 3755, 440, 15, 38, "IndexSubentry",
  CellTags->"GameteTable"],
Cell[94331, 3772, 290, 10, 23, "Index",
  CellTags->"GaussianLogLikelihood"],
Cell[94624, 3784, 260, 10, 23, "Index",
  CellTags->"GaussianMLE"],
Cell[94887, 3796, 270, 11, 23, "Index",
  CellTags->"Genealogies"],
Cell[95160, 3809, 929, 33, 83, "IndexSubentry",
  CellTags->"Genealogies"],
Cell[96092, 3844, 412, 15, 23, "Index",
  CellTags->"Genealogy"],
Cell[96507, 3861, 276, 10, 23, "Index",
  CellTags->"GenealogyToMatrix"],
Cell[96786, 3873, 265, 10, 23, "Index",
  CellTags->"GeneralizedTransform"],
Cell[97054, 3885, 283, 11, 23, "Index",
  CellTags->"Generating functions"],
Cell[97340, 3898, 437, 15, 38, "IndexSubentry",
  CellTags->"Generating functions"],
Cell[97780, 3915, 277, 10, 23, "Index",
  CellTags->"Genes and contexts"],
Cell[98060, 3927, 334, 12, 23, "Index",
  CellTags->"Genome"],
Cell[98397, 3941, 287, 11, 23, "Index",
  CellTags->"Genotype"],
Cell[98687, 3954, 566, 19, 38, "IndexSubentry",
  CellTags->"Genotype"],
Cell[99256, 3975, 299, 11, 23, "Index",
  CellTags->"Genotype frequencies"],
Cell[99558, 3988, 321, 11, 23, "Index",
  CellTags->"Genotype frequency"],
Cell[99882, 4001, 292, 10, 23, "Index",
  CellTags->"GenotypeFrequency"],
Cell[100177, 4013, 301, 10, 23, "Index",
  CellTags->"GenotypeFrequencyArguments"],
Cell[100481, 4025, 303, 10, 23, "Index",
  CellTags->"GenotypeFrequencyConvert"],
Cell[100787, 4037, 307, 10, 23, "Index",
  CellTags->"GenotypeFrequencyTable"],
Cell[101097, 4049, 281, 10, 23, "Index",
  CellTags->"GenotypePosition"],
Cell[101381, 4061, 288, 10, 23, "Index",
  CellTags->"GenotypeProbability"],
Cell[101672, 4073, 286, 9, 23, "IndexSubentry",
  CellTags->"GenotypeProbability"],
Cell[101961, 4084, 256, 11, 23, "Index",
  CellTags->"Genotypes"],
Cell[102220, 4097, 291, 10, 23, "Index",
  CellTags->"GlobalContinuumVariables"],
Cell[102514, 4109, 452, 16, 23, "Index",
  CellTags->"Gnew"],
Cell[102969, 4127, 261, 10, 23, "Index",
  CellTags->"Goodman et al 1999"],
Cell[103233, 4139, 274, 11, 23, "Index",
  CellTags->"Graphs"],
Cell[103510, 4152, 399, 14, 23, "Index",
  CellTags->"Griffiths-Tavare"],
Cell[103912, 4168, 833, 26, 53, "IndexSubentry",
  CellTags->"Griffiths-Tavare"],
Cell[104748, 4196, 276, 10, 23, "Index",
  CellTags->"Guiasu & Shenitzer 1985"],
Cell[105027, 4208, 277, 10, 23, "Index",
  CellTags->"HaploidConstraints"],
Cell[105307, 4220, 297, 10, 23, "Index",
  CellTags->"HaploidFrequencies"],
Cell[105607, 4232, 332, 11, 23, "Index",
  CellTags->"HaploidGenotypeFrequency"],
Cell[105942, 4245, 297, 10, 23, "Index",
  CellTags->"HaploidIndividuals"],
Cell[106242, 4257, 309, 10, 23, "Index",
  CellTags->"HaploidRepresentations"],
Cell[106554, 4269, 259, 11, 23, "Index",
  CellTags->"Haploids"],
Cell[106816, 4282, 414, 14, 23, "Index",
  CellTags->"HaploidSource"],
Cell[107233, 4298, 259, 10, 23, "Index",
  CellTags->"HaploidSubsets"],
Cell[107495, 4310, 257, 10, 23, "Index",
  CellTags->"HaploidTypes"],
Cell[107755, 4322, 314, 11, 23, "Index",
  CellTags->"Help browser"],
Cell[108072, 4335, 281, 10, 23, "Index",
  CellTags->"Help Browser"],
Cell[108356, 4347, 291, 9, 23, "IndexSubentry",
  CellTags->"Help Browser"],
Cell[108650, 4358, 432, 15, 23, "Index",
  CellTags->"Hermaphrodites"],
Cell[109085, 4375, 284, 10, 23, "Index",
  CellTags->"HeterozygoteB"],
Cell[109372, 4387, 237, 10, 23, "Index",
  CellTags->"Hill 1974a"],
Cell[109612, 4399, 237, 10, 23, "Index",
  CellTags->"Hill 1974b"],
Cell[109852, 4411, 237, 10, 23, "Index",
  CellTags->"Hill 1974c"],
Cell[110092, 4423, 413, 14, 23, "Index",
  CellTags->"Hudson 1990"],
Cell[110508, 4439, 303, 10, 23, "Index",
  CellTags->"Hypergeometric model"],
Cell[110814, 4451, 256, 11, 23, "Index",
  CellTags->"Hyperlinks"],
Cell[111073, 4464, 621, 22, 53, "IndexSubentry",
  CellTags->"Hyperlinks"],
Cell[111697, 4488, 270, 10, 23, "Index",
  CellTags->"IncidenceMatrix"],
Cell[111970, 4500, 290, 11, 23, "Index",
  CellTags->"Index"],
Cell[112263, 4513, 237, 10, 23, "Index",
  CellTags->"Individual"],
Cell[112503, 4525, 303, 10, 23, "Index",
  CellTags->"IndividualContinuumVariables"],
Cell[112809, 4537, 323, 11, 23, "Index",
  CellTags->"IndividualRepresentations"],
Cell[113135, 4550, 264, 10, 23, "Index",
  CellTags->"Individuals"],
Cell[113402, 4562, 301, 10, 23, "Index",
  CellTags->"InferParentalGenotypes"],
Cell[113706, 4574, 275, 10, 23, "Index",
  CellTags->"Infinite sites mutation"],
Cell[113984, 4586, 338, 11, 23, "Index",
  CellTags->"InformationFunction"],
Cell[114325, 4599, 501, 15, 38, "IndexSubentry",
  CellTags->"InformationFunction"],
Cell[114829, 4616, 272, 10, 23, "Index",
  CellTags->"InitialiseContinuum"],
Cell[115104, 4628, 263, 10, 23, "Index",
  CellTags->"InitialiseCovariance"],
Cell[115370, 4640, 414, 14, 23, "Index",
  CellTags->"InitialiseDemes"],
Cell[115787, 4656, 254, 10, 23, "Index",
  CellTags->"InitialStep"],
Cell[116044, 4668, 277, 10, 23, "Index",
  CellTags->"InitialStepReduced"],
Cell[116324, 4680, 270, 10, 23, "Index",
  CellTags->"InternalNodes"],
Cell[116597, 4692, 268, 10, 23, "Index",
  CellTags->"IntervalCombine"],
Cell[116868, 4704, 271, 10, 23, "Index",
  CellTags->"IntervalPosition"],
Cell[117142, 4716, 295, 10, 23, "Index",
  CellTags->"InverseFourierNormalised"],
Cell[117440, 4728, 310, 10, 23, "Index",
  CellTags->"InverseFourierNormalisedTable"],
Cell[117753, 4740, 476, 15, 23, "Index",
  CellTags->"Island model"],
Cell[118232, 4757, 795, 25, 53, "IndexSubentry",
  CellTags->"Island model"],
Cell[119030, 4784, 295, 10, 23, "Index",
  CellTags->"IterateContinuum"],
Cell[119328, 4796, 264, 11, 23, "Index",
  CellTags->"IterateExact"],
Cell[119595, 4809, 1753, 53, 128, "IndexSubentry",
  CellTags->"IterateExact"],
Cell[121351, 4864, 328, 14, 23, "Index",
  CellTags->"Join"],
Cell[121682, 4880, 295, 11, 23, "Index",
  CellTags->"Junctions"],
Cell[121980, 4893, 307, 11, 23, "Index",
  CellTags->"JunctionStyle"],
Cell[122290, 4906, 417, 15, 23, "Index",
  CellTags->"Juveniles"],
Cell[122710, 4923, 310, 10, 23, "Index",
  CellTags->"Kirkpatrick and Barton 1997"],
Cell[123023, 4935, 316, 10, 23, "Index",
  CellTags->"Kirkpatrick and Servedio 1998"],
Cell[123342, 4947, 392, 14, 23, "Index",
  CellTags->"Kirkpatrick et al."],
Cell[123737, 4963, 3891, 138, 285, "IndexSubentry",
  CellTags->"Kirkpatrick et al."],
Cell[127631, 5103, 275, 10, 15, "Index",
  CellTags->"Kirkpatrick et al. 1983"],
Cell[127909, 5115, 237, 10, 15, "Index",
  CellTags->"Kruuk 1997"],
Cell[128149, 5127, 298, 11, 15, "Index",
  CellTags->"LeafEvents"],
Cell[128450, 5140, 257, 10, 15, "Index",
  CellTags->"LeafLabels"],
Cell[128710, 5152, 257, 10, 15, "Index",
  CellTags->"LeafOffset"],
Cell[128970, 5164, 249, 10, 15, "Index",
  CellTags->"Leaves"],
Cell[129222, 5176, 275, 9, 15, "IndexSubentry",
  CellTags->"Leaves"],
Cell[129500, 5187, 229, 10, 15, "Index",
  CellTags->"Life cycle"],
Cell[129732, 5199, 3070, 111, 180, "IndexSubentry",
  CellTags->"Life cycle"],
Cell[132805, 5312, 313, 11, 15, "Index",
  CellTags->"LineagesPresent"],
Cell[133121, 5325, 246, 10, 15, "Index",
  CellTags->"Li & Nei 1974"],
Cell[133370, 5337, 480, 18, 15, "Index",
  CellTags->"Linkage"],
Cell[133853, 5357, 451, 15, 30, "IndexSubentry",
  CellTags->"Linkage"],
Cell[134307, 5374, 307, 10, 15, "Index",
  CellTags->"Linkage disequilibrium"],
Cell[134617, 5386, 270, 10, 15, "Index",
  CellTags->"LinkedRecombination"],
Cell[134890, 5398, 280, 10, 15, "Index",
  CellTags->"ListToGenealogy"],
Cell[135173, 5410, 291, 10, 15, "Index",
  CellTags->"ListToMatrix"],
Cell[135467, 5422, 255, 10, 15, "Index",
  CellTags->"Location"],
Cell[135725, 5434, 232, 10, 15, "Index",
  CellTags->"Locations"],
Cell[135960, 5446, 253, 10, 23, "Index",
  CellTags->"LocusNames"],
Cell[136216, 5458, 288, 10, 23, "Index",
  CellTags->"LogLikelihoodDisequilibrium"],
Cell[136507, 5470, 325, 10, 23, "Index",
  CellTags->"LogLikelihoodDisequilibriumReduced"],
Cell[136835, 5482, 270, 10, 23, "Index",
  CellTags->"LogLikelihoodTest"],
Cell[137108, 5494, 397, 14, 23, "Index",
  CellTags->"Log-linear models"],
Cell[137508, 5510, 252, 10, 23, "Index",
  CellTags->"Long et al 1995"],
Cell[137763, 5522, 269, 10, 23, "Index",
  CellTags->"LowerOffDiagonal"],
Cell[138035, 5534, 249, 10, 23, "Index",
  CellTags->"MacCallum 1994"],
Cell[138287, 5546, 269, 10, 23, "Index",
  CellTags->"MacCallum et al. 1998"],
Cell[138559, 5558, 320, 11, 23, "Index",
  CellTags->"MakeCline"],
Cell[138882, 5571, 691, 21, 53, "IndexSubentry",
  CellTags->"MakeCline"],
Cell[139576, 5594, 296, 11, 23, "Index",
  CellTags->"MakeDiploid"],
Cell[139875, 5607, 474, 15, 38, "IndexSubentry",
  CellTags->"MakeDiploid"],
Cell[140352, 5624, 279, 10, 23, "Index",
  CellTags->"MakeDistanceList"],
Cell[140634, 5636, 270, 10, 23, "Index",
  CellTags->"MakeDistances"],
Cell[140907, 5648, 243, 10, 23, "Index",
  CellTags->"MakeFitnessSet"],
Cell[141153, 5660, 255, 9, 23, "IndexSubentry",
  CellTags->"MakeFitnessSet"],
Cell[141411, 5671, 262, 10, 23, "Index",
  CellTags->"MakeGenealogy"],
Cell[141676, 5683, 278, 10, 23, "Index",
  CellTags->"MakeGenealogyPlot"],
Cell[141957, 5695, 296, 11, 23, "Index",
  CellTags->"MakeHaploid"],
Cell[142256, 5708, 474, 15, 38, "IndexSubentry",
  CellTags->"MakeHaploid"],
Cell[142733, 5725, 322, 11, 23, "Index",
  CellTags->"MakeIndividuals"],
Cell[143058, 5738, 666, 21, 53, "IndexSubentry",
  CellTags->"MakeIndividuals"],
Cell[143727, 5761, 270, 10, 23, "Index",
  CellTags->"MakeOneWayTable"],
Cell[144000, 5773, 268, 10, 23, "Index",
  CellTags->"MakePairwiseTable"],
Cell[144271, 5785, 327, 11, 23, "Index",
  CellTags->"MakePopulation"],
Cell[144601, 5798, 711, 22, 45, "IndexSubentry",
  CellTags->"MakePopulation"],
Cell[145315, 5822, 398, 14, 15, "Index",
  CellTags->"MakeSelectionCoefficient"],
Cell[145716, 5838, 423, 15, 30, "IndexSubentry",
  CellTags->"MakeSelectionCoefficient"],
Cell[146142, 5855, 270, 10, 15, "Index",
  CellTags->"Mangel & Hilborn 1996"],
Cell[146415, 5867, 295, 11, 15, "Index",
  CellTags->"MapLength"],
Cell[146713, 5880, 298, 11, 15, "Index",
  CellTags->"MapPosition"],
Cell[147014, 5893, 284, 9, 15, "IndexSubentry",
  CellTags->"MapPosition"],
Cell[147301, 5904, 316, 11, 15, "Index",
  CellTags->"Marginal fitness"],
Cell[147620, 5917, 642, 21, 45, "IndexSubentry",
  CellTags->"Marginal fitness"],
Cell[148265, 5940, 256, 10, 15, "Index",
  CellTags->"MarginalTable"],
Cell[148524, 5952, 302, 11, 15, "Index",
  CellTags->"MarginalW"],
Cell[148829, 5965, 636, 21, 45, "IndexSubentry",
  CellTags->"MarginalW"],
Cell[149468, 5988, 277, 11, 15, "Index",
  CellTags->"MaternalLoci"],
Cell[149748, 6001, 450, 15, 30, "IndexSubentry",
  CellTags->"MaternalLoci"],
Cell[150201, 6018, 254, 10, 15, "Index",
  CellTags->"MatrixGamma"],
Cell[150458, 6030, 280, 10, 15, "Index",
  CellTags->"MatrixToGenealogy"],
Cell[150741, 6042, 291, 10, 15, "Index",
  CellTags->"MatrixToList"],
Cell[151035, 6054, 314, 11, 15, "Index",
  CellTags->"MeanContribution"],
Cell[151352, 6067, 400, 14, 15, "Index",
  CellTags->"Mean fitness"],
Cell[151755, 6083, 461, 15, 30, "IndexSubentry",
  CellTags->"Mean fitness"],
Cell[152219, 6100, 290, 11, 15, "Index",
  CellTags->"MeanW"],
Cell[152512, 6113, 620, 21, 45, "IndexSubentry",
  CellTags->"MeanW"],
Cell[153135, 6136, 234, 10, 15, "Index",
  CellTags->"Meiosis"],
Cell[153372, 6148, 264, 9, 15, "IndexSubentry",
  CellTags->"Meiosis"],
Cell[153639, 6159, 256, 10, 15, "Index",
  CellTags->"MethodC"],
Cell[153898, 6171, 256, 10, 15, "Index",
  CellTags->"MethodP"],
Cell[154157, 6183, 271, 11, 15, "Index",
  CellTags->"Metropolis algorithm"],
Cell[154431, 6196, 295, 10, 15, "Index",
  CellTags->"MetropolisDisequilibrium"],
Cell[154729, 6208, 316, 10, 15, "Index",
  CellTags->"MetropolisDisequilibriumReduced"],
Cell[155048, 6220, 272, 10, 15, "Index",
  CellTags->"Metropolis et al. 1954"],
Cell[155323, 6232, 382, 14, 15, "Index",
  CellTags->"MFromC"],
Cell[155708, 6248, 226, 10, 15, "Index",
  CellTags->"Migrate"],
Cell[155937, 6260, 311, 11, 15, "Index",
  CellTags->"MigrateExact"],
Cell[156251, 6273, 646, 21, 45, "IndexSubentry",
  CellTags->"MigrateExact"],
Cell[156900, 6296, 298, 11, 15, "Index",
  CellTags->"Migration"],
Cell[157201, 6309, 2405, 85, 195, "IndexSubentry",
  CellTags->"Migration"],
Cell[159609, 6396, 491, 15, 15, "Index",
  CellTags->"MigrationOrder"],
Cell[160103, 6413, 524, 16, 30, "IndexSubentry",
  CellTags->"MigrationOrder"],
Cell[160630, 6431, 308, 11, 15, "Index",
  CellTags->"MigrationRate"],
Cell[160941, 6444, 311, 11, 15, "Index",
  CellTags->"MigrationSet"],
Cell[161255, 6457, 299, 10, 15, "Index",
  CellTags->"MissingCombination"],
Cell[161557, 6469, 323, 11, 15, "Index",
  CellTags->"Missing data"],
Cell[161883, 6482, 468, 15, 30, "IndexSubentry",
  CellTags->"Missing data"],
Cell[162354, 6499, 312, 11, 15, "Index",
  CellTags->"MissingData"],
Cell[162669, 6512, 300, 9, 15, "IndexSubentry",
  CellTags->"MissingData"],
Cell[162972, 6523, 352, 14, 15, "Index",
  CellTags->"Moment"],
Cell[163327, 6539, 305, 10, 15, "Index",
  CellTags->"MomentAfterMigration"],
Cell[163635, 6551, 332, 11, 15, "Index",
  CellTags->"MomentAfterRecombination"],
Cell[163970, 6564, 258, 10, 15, "Index",
  CellTags->"MomentEquilibrium"],
Cell[164231, 6576, 315, 11, 15, "Index",
  CellTags->"MomentGeneratingFunction"],
Cell[164549, 6589, 582, 21, 45, "IndexSubentry",
  CellTags->"MomentGeneratingFunction"],
Cell[165134, 6612, 267, 10, 15, "Index",
  CellTags->"MomentLimits"],
Cell[165404, 6624, 232, 10, 15, "Index",
  CellTags->"MomentNew"],
Cell[165639, 6636, 262, 10, 15, "Index",
  CellTags->"MomentReduced"],
Cell[165904, 6648, 222, 10, 15, "Index",
  CellTags->"Moments"],
Cell[166129, 6660, 1552, 53, 120, "IndexSubentry",
  CellTags->"Moments"],
Cell[167684, 6715, 289, 10, 15, "Index",
  CellTags->"MomentsFromG"],
Cell[167976, 6727, 269, 10, 15, "Index",
  CellTags->"MomentSimple"],
Cell[168248, 6739, 302, 10, 15, "Index",
  CellTags->"MonteCarloGriffithsTavare"],
Cell[168553, 6751, 302, 10, 15, "Index",
  CellTags->"MonteCarloProbability"],
Cell[168858, 6763, 258, 10, 15, "Index",
  CellTags->"Mortality"],
Cell[169119, 6775, 299, 10, 15, "Index",
  CellTags->"MostRecentCommonAncestor"],
Cell[169421, 6787, 374, 14, 15, "Index",
  CellTags->"MToC"],
Cell[169798, 6803, 410, 14, 15, "Index",
  CellTags->"MToCEquations"],
Cell[170211, 6819, 263, 10, 15, "Index",
  CellTags->"Muddle"],
Cell[170477, 6831, 295, 11, 15, "Index",
  CellTags->"Multilocus algebra"],
Cell[170775, 6844, 1010, 36, 60, "IndexSubentry",
  CellTags->"Multilocus algebra"],
Cell[171788, 6882, 408, 15, 15, "Index",
  CellTags->"Multilocus MS"],
Cell[172199, 6899, 264, 11, 15, "Index",
  CellTags->"Multilocus notation"],
Cell[172466, 6912, 344, 12, 15, "Index",
  CellTags->"Multinomial sampling"],
Cell[172813, 6926, 332, 11, 15, "Index",
  CellTags->"MultinomialSamplingProbability"],
Cell[173148, 6939, 289, 11, 15, "Index",
  CellTags->"Multiple alleles"],
Cell[173440, 6952, 694, 27, 60, "IndexSubentry",
  CellTags->"Multiple alleles"],
Cell[174137, 6981, 297, 11, 15, "Index",
  CellTags->"Multiple arguments"],
Cell[174437, 6994, 336, 11, 15, "Index",
  CellTags->"Multiplicative models"],
Cell[174776, 7007, 302, 11, 15, "Index",
  CellTags->"MUS"],
Cell[175081, 7020, 667, 21, 45, "IndexSubentry",
  CellTags->"MUS"],
Cell[175751, 7043, 287, 11, 15, "Index",
  CellTags->"Mutate"],
Cell[176041, 7056, 607, 21, 45, "IndexSubentry",
  CellTags->"Mutate"],
Cell[176651, 7079, 724, 22, 15, "Index",
  CellTags->"MutateCompiled"],
Cell[177378, 7103, 263, 11, 15, "Index",
  CellTags->"Mutation"],
Cell[177644, 7116, 1083, 33, 59, "IndexSubentry",
  CellTags->"Mutation"],
Cell[178730, 7151, 275, 10, 15, "Index",
  CellTags->"MutationInterval"],
Cell[179008, 7163, 297, 10, 15, "Index",
  CellTags->"MutationLabels"],
Cell[179308, 7175, 269, 10, 23, "Index",
  CellTags->"MutationOrigin"],
Cell[179580, 7187, 261, 10, 23, "Index",
  CellTags->"MutationRate"],
Cell[179844, 7199, 293, 11, 23, "Index",
  CellTags->"Mutations"],
Cell[180140, 7212, 772, 27, 68, "IndexSubentry",
  CellTags->"Mutations"],
Cell[180915, 7241, 398, 14, 23, "Index",
  CellTags->"MVariables"],
Cell[181316, 7257, 293, 11, 23, "Index",
  CellTags->"Negative binomial"],
Cell[181612, 7270, 828, 27, 68, "IndexSubentry",
  CellTags->"Negative binomial"],
Cell[182443, 7299, 339, 11, 23, "Index",
  CellTags->"NegativeBinomialLogLikelihood"],
Cell[182785, 7312, 302, 10, 23, "Index",
  CellTags->"NegativeBinomialMLE"],
Cell[183090, 7324, 368, 11, 23, "Index",
  CellTags->"NegativeHypergeometricDistribution"],
Cell[183461, 7337, 273, 10, 23, "Index",
  CellTags->"NeighbourArray"],
Cell[183737, 7349, 261, 10, 23, "Index",
  CellTags->"Neighbours"],
Cell[184001, 7361, 280, 10, 23, "Index",
  CellTags->"NetCovariance"],
Cell[184284, 7373, 255, 10, 23, "Index",
  CellTags->"NetFecundity"],
Cell[184542, 7385, 255, 10, 23, "Index",
  CellTags->"NetMortality"],
Cell[184800, 7397, 384, 14, 23, "Index",
  CellTags->"NetRecombination"],
Cell[185187, 7413, 438, 15, 38, "IndexSubentry",
  CellTags->"NetRecombination"],
Cell[185628, 7430, 285, 11, 23, "Index",
  CellTags->"Neutral marker"],
Cell[185916, 7443, 309, 10, 23, "Index",
  CellTags->"NeutralRepresentations"],
Cell[186228, 7455, 309, 11, 23, "Index",
  CellTags->"NewGametes"],
Cell[186540, 7468, 1653, 52, 98, "IndexSubentry",
  CellTags->"NewGametes"],
Cell[188196, 7522, 249, 10, 23, "Index",
  CellTags->"NewS"],
Cell[188448, 7534, 380, 14, 23, "Index",
  CellTags->"Node"],
Cell[188831, 7550, 404, 14, 23, "Index",
  CellTags->"NodeFunction"],
Cell[189238, 7566, 275, 9, 23, "IndexSubentry",
  CellTags->"NodeFunction"],
Cell[189516, 7577, 257, 10, 23, "Index",
  CellTags->"NodeLabels"],
Cell[189776, 7589, 257, 10, 23, "Index",
  CellTags->"NodeOffset"],
Cell[190036, 7601, 246, 10, 23, "Index",
  CellTags->"Nodes"],
Cell[190285, 7613, 263, 10, 23, "Index",
  CellTags->"NonMendelian"],
Cell[190551, 7625, 366, 13, 23, "IndexSubentry",
  CellTags->"NonMendelian"],
Cell[190920, 7640, 323, 11, 23, "Index",
  CellTags->"NonNeutralRepresentations"],
Cell[191246, 7653, 331, 11, 23, "Index",
  CellTags->"NonSymmetricRepresentations"],
Cell[191580, 7666, 284, 10, 23, "Index",
  CellTags->"Normalisation"],
Cell[191867, 7678, 275, 10, 23, "Index",
  CellTags->"Normalised"],
Cell[192145, 7690, 287, 11, 23, "Index",
  CellTags->"Notation"],
Cell[192435, 7703, 727, 27, 68, "IndexSubentry",
  CellTags->"Notation"],
Cell[193165, 7732, 253, 10, 23, "Index",
  CellTags->"Notation Package"],
Cell[193421, 7744, 310, 11, 23, "Index",
  CellTags->"NullAllele"],
Cell[193734, 7757, 299, 9, 23, "IndexSubentry",
  CellTags->"NullAllele"],
Cell[194036, 7768, 312, 11, 23, "Index",
  CellTags->"Null alleles"],
Cell[194351, 7781, 304, 9, 23, "IndexSubentry",
  CellTags->"Null alleles"],
Cell[194658, 7792, 304, 11, 23, "Index",
  CellTags->"Null lineages"],
Cell[194965, 7805, 304, 11, 23, "Index",
  CellTags->"NullLineages"],
Cell[195272, 7818, 337, 11, 23, "Index",
  CellTags->"NullRecombinationEvents"],
Cell[195612, 7831, 261, 10, 23, "Index",
  CellTags->"NumberedLink"],
Cell[195876, 7843, 271, 11, 23, "Index",
  CellTags->"Numbering"],
Cell[196150, 7856, 560, 21, 53, "IndexSubentry",
  CellTags->"Numbering"],
Cell[196713, 7879, 318, 11, 23, "Index",
  CellTags->"NumberOfCoalescences"],
Cell[197034, 7892, 266, 10, 23, "Index",
  CellTags->"NumberOfGenes"],
Cell[197303, 7904, 917, 28, 68, "IndexSubentry",
  CellTags->"NumberOfGenes"],
Cell[198223, 7934, 281, 10, 23, "Index",
  CellTags->"NumberOfGenesTable"],
Cell[198507, 7946, 416, 14, 23, "Index",
  CellTags->"NumberOfIndividuals"],
Cell[198926, 7962, 299, 10, 23, "Index",
  CellTags->"NumberOfIndividualsTable"],
Cell[199228, 7974, 279, 10, 23, "Index",
  CellTags->"NumberOfLineages"],
Cell[199510, 7986, 263, 10, 23, "Index",
  CellTags->"NumberOfLoci"],
Cell[199776, 7998, 278, 10, 23, "Index",
  CellTags->"NumberOfMutations"],
Cell[200057, 8010, 317, 10, 23, "Index",
  CellTags->"NumberOfPossibleCoalescences"],
Cell[200377, 8022, 287, 10, 23, "Index",
  CellTags->"NumberOfSamplePartitions"],
Cell[200667, 8034, 278, 10, 23, "Index",
  CellTags->"NumberOfSetPartitions"],
Cell[200948, 8046, 327, 11, 23, "Index",
  CellTags->"NumericalModel"],
Cell[201278, 8059, 294, 9, 23, "IndexSubentry",
  CellTags->"NumericalModel"],
Cell[201575, 8070, 301, 11, 23, "Index",
  CellTags->"Numerical models"],
Cell[201879, 8083, 1267, 43, 98, "IndexSubentry",
  CellTags->"Numerical models"],
Cell[203149, 8128, 420, 14, 23, "Index",
  CellTags->"Observable genotype"],
Cell[203572, 8144, 250, 11, 23, "Index",
  CellTags->"Obsolete"],
Cell[203825, 8157, 3402, 121, 293, "IndexSubentry",
  CellTags->"Obsolete"],
Cell[207230, 8280, 258, 10, 23, "Index",
  CellTags->"Offspring"],
Cell[207491, 8292, 266, 11, 23, "Index",
  CellTags->"Ordered"],
Cell[207760, 8305, 264, 10, 23, "Index",
  CellTags->"Orive & Barton 1999"],
Cell[208027, 8317, 247, 10, 23, "Index",
  CellTags->"OtherSex"],
Cell[208277, 8329, 275, 11, 23, "Index",
  CellTags->"Packages"],
Cell[208555, 8342, 839, 31, 68, "IndexSubentry",
  CellTags->"Packages"],
Cell[209397, 8375, 235, 10, 23, "Index",
  CellTags->"PackageSaver"],
Cell[209635, 8387, 272, 10, 23, "Index",
  CellTags->"ParentalGenotypes"],
Cell[209910, 8399, 262, 11, 23, "Index",
  CellTags->"Partitions"],
Cell[210175, 8412, 426, 15, 38, "IndexSubentry",
  CellTags->"Partitions"],
Cell[210604, 8429, 251, 10, 23, "Index",
  CellTags->"PartitionSet"],
Cell[210858, 8441, 414, 14, 23, "Index",
  CellTags->"Paternal inheritance"],
Cell[211275, 8457, 277, 11, 23, "Index",
  CellTags->"PaternalLoci"],
Cell[211555, 8470, 444, 15, 38, "IndexSubentry",
  CellTags->"PaternalLoci"],
Cell[212002, 8487, 274, 10, 23, "Index",
  CellTags->"PatternFree"],
Cell[212279, 8499, 281, 11, 23, "Index",
  CellTags->"Permutations"],
Cell[212563, 8512, 325, 11, 23, "Index",
  CellTags->"Permutations in defining coefficients"],
Cell[212891, 8525, 269, 11, 23, "Index",
  CellTags->"Phenotypes"],
Cell[213163, 8538, 264, 10, 23, "Index",
  CellTags->"Phipps & Brill 1995"],
Cell[213430, 8550, 245, 10, 23, "Index",
  CellTags->"Ploidy"],
Cell[213678, 8562, 271, 10, 23, "Index",
  CellTags->"PloidyWeightList"],
Cell[213952, 8574, 266, 10, 23, "Index",
  CellTags->"PlotGenealogy"],
Cell[214221, 8586, 247, 10, 23, "Index",
  CellTags->"PlotLogL"],
Cell[214471, 8598, 300, 11, 23, "Index",
  CellTags->"PlotSegments"],
Cell[214774, 8611, 279, 11, 23, "Index",
  CellTags->"Plotting"],
Cell[215056, 8624, 346, 11, 23, "Index",
  CellTags->"PopulationDisequilibrium"],
Cell[215405, 8637, 274, 10, 23, "Index",
  CellTags->"PopulationExpectation"],
Cell[215682, 8649, 271, 9, 23, "IndexSubentry",
  CellTags->"PopulationExpectation"],
Cell[215956, 8660, 323, 11, 23, "Index",
  CellTags->"PopulationRepresentations"],
Cell[216282, 8673, 380, 14, 23, "Index",
  CellTags->"Position"],
Cell[216665, 8689, 442, 15, 38, "IndexSubentry",
  CellTags->"Position"],
Cell[217110, 8706, 270, 10, 23, "Index",
  CellTags->"PositionsList"],
Cell[217383, 8718, 276, 10, 23, "Index",
  CellTags->"PositionsMatrix"],
Cell[217662, 8730, 305, 10, 23, "Index",
  CellTags->"PossibleCoalescenceOrder"],
Cell[217970, 8742, 303, 10, 23, "Index",
  CellTags->"PossibleDiploidGenotypes"],
Cell[218276, 8754, 272, 10, 23, "Index",
  CellTags->"PossibleGenotypes"],
Cell[218551, 8766, 273, 10, 23, "Index",
  CellTags->"PossibleRootings"],
Cell[218827, 8778, 311, 11, 23, "Index",
  CellTags->"PowerF"],
Cell[219141, 8791, 871, 27, 68, "IndexSubentry",
  CellTags->"PowerF"],
Cell[220015, 8820, 279, 10, 23, "Index",
  CellTags->"PresentOneWayTable"],
Cell[220297, 8832, 277, 10, 23, "Index",
  CellTags->"PresentPairwiseTable"],
Cell[220577, 8844, 265, 10, 23, "Index",
  CellTags->"PresentResults"],
Cell[220845, 8856, 317, 11, 23, "Index",
  CellTags->"Principal components"],
Cell[221165, 8869, 273, 10, 23, "Index",
  CellTags->"PrintDetails"],
Cell[221441, 8881, 321, 10, 23, "IndexSubentry",
  CellTags->"PrintDetails"],
Cell[221765, 8893, 275, 11, 23, "Index",
  CellTags->"Problems"],
Cell[222043, 8906, 587, 18, 23, "IndexSubentry",
  CellTags->"Problems"],
Cell[222633, 8926, 250, 11, 23, "Index",
  CellTags->"Products"],
Cell[222886, 8939, 237, 10, 23, "Index",
  CellTags->"ProductSum"],
Cell[223126, 8951, 249, 9, 23, "IndexSubentry",
  CellTags->"ProductSum"],
Cell[223378, 8962, 263, 11, 23, "Index",
  CellTags->"QLE"],
Cell[223644, 8975, 258, 9, 23, "IndexSubentry",
  CellTags->"QLE"],
Cell[223905, 8986, 310, 11, 23, "Index",
  CellTags->"Quasi-linkage equilibrium"],
Cell[224218, 8999, 312, 10, 23, "Index",
  CellTags->"RandomBottleneckedGenealogy"],
Cell[224533, 9011, 299, 10, 23, "Index",
  CellTags->"RandomCoalescenceOrder"],
Cell[224835, 9023, 326, 11, 23, "Index",
  CellTags->"RandomCoalescenceTimes"],
Cell[225164, 9036, 300, 9, 23, "IndexSubentry",
  CellTags->"RandomCoalescenceTimes"],
Cell[225467, 9047, 288, 10, 23, "Index",
  CellTags->"RandomCum"],
Cell[225758, 9059, 330, 12, 23, "Index",
  CellTags->"Random drift"],
Cell[226091, 9073, 2349, 77, 158, "IndexSubentry",
  CellTags->"Random drift"],
Cell[228443, 9152, 286, 11, 23, "Index",
  CellTags->"RandomDrift"],
Cell[228732, 9165, 956, 27, 38, "IndexSubentry",
  CellTags->"RandomDrift"],
Cell[229691, 9194, 259, 10, 23, "Index",
  CellTags->"RandomFamilies"],
Cell[229953, 9206, 261, 10, 23, "Index",
  CellTags->"RandomFamily"],
Cell[230217, 9218, 273, 9, 23, "IndexSubentry",
  CellTags->"RandomFamily"],
Cell[230493, 9229, 299, 11, 23, "Index",
  CellTags->"Random genealogies"],
Cell[230795, 9242, 270, 10, 23, "Index",
  CellTags->"RandomGenealogy"],
Cell[231068, 9254, 286, 9, 23, "IndexSubentry",
  CellTags->"RandomGenealogy"],
Cell[231357, 9265, 241, 10, 23, "Index",
  CellTags->"RandomList"],
Cell[231601, 9277, 259, 9, 23, "IndexSubentry",
  CellTags->"RandomList"],
Cell[231863, 9288, 259, 11, 23, "Index",
  CellTags->"Random lists"],
Cell[232125, 9301, 289, 10, 15, "Index",
  CellTags->"RandomMating"],
Cell[232417, 9313, 286, 10, 15, "Index",
  CellTags->"RandomMultinomial"],
Cell[232706, 9325, 277, 10, 15, "Index",
  CellTags->"RandomPreviousFamily"],
Cell[232986, 9337, 288, 10, 15, "Index",
  CellTags->"Random sampling"],
Cell[233277, 9349, 415, 15, 30, "IndexSubentry",
  CellTags->"Random sampling"],
Cell[233695, 9366, 236, 10, 15, "Index",
  CellTags->"RandomSet"],
Cell[233934, 9378, 371, 14, 15, "Index",
  CellTags->"Random union"],
Cell[234308, 9394, 306, 9, 15, "IndexSubentry",
  CellTags->"Random union"],
Cell[234617, 9405, 244, 10, 15, "Index",
  CellTags->"RandomUnion"],
Cell[234864, 9417, 276, 10, 15, "Index",
  CellTags->"RandomUnionMethod"],
Cell[235143, 9429, 260, 10, 15, "Index",
  CellTags->"RandomUnionObsolete"],
Cell[235406, 9441, 256, 11, 15, "Index",
  CellTags->"Random walk"],
Cell[235665, 9454, 325, 11, 15, "Index",
  CellTags->"RecombinantLineages"],
Cell[235993, 9467, 378, 14, 15, "Index",
  CellTags->"Recombination"],
Cell[236374, 9483, 1122, 39, 90, "IndexSubentry",
  CellTags->"Recombination"],
Cell[237499, 9524, 325, 11, 15, "Index",
  CellTags->"RecombinationEvents"],
Cell[237827, 9537, 321, 11, 15, "Index",
  CellTags->"RecombinationRate"],
Cell[238151, 9550, 450, 15, 15, "Index",
  CellTags->"RecombinationSet"],
Cell[238604, 9567, 283, 10, 15, "Index",
  CellTags->"Recombined"],
Cell[238890, 9579, 293, 10, 15, "Index",
  CellTags->"RecombineLineage"],
Cell[239186, 9591, 262, 10, 15, "Index",
  CellTags->"ReducedData"],
Cell[239451, 9603, 316, 11, 15, "Index",
  CellTags->"ReferencePoint"],
Cell[239770, 9616, 273, 10, 15, "Index",
  CellTags->"ReferencePointMean"],
Cell[240046, 9628, 1125, 37, 45, "IndexSubentry",
  CellTags->"ReferencePointMean"],
Cell[241174, 9667, 273, 10, 15, "Index",
  CellTags->"ReferencePointSame"],
Cell[241450, 9679, 273, 10, 15, "Index",
  CellTags->"ReferencePointZero"],
Cell[241726, 9691, 289, 11, 15, "Index",
  CellTags->"References"],
Cell[242018, 9704, 400, 14, 15, "Index",
  CellTags->"Reference values"],
Cell[242421, 9720, 472, 15, 30, "IndexSubentry",
  CellTags->"Reference values"],
Cell[242896, 9737, 238, 10, 15, "Index",
  CellTags->"RemoveTag"],
Cell[243137, 9749, 239, 10, 15, "Index",
  CellTags->"Repeat"],
Cell[243379, 9761, 232, 10, 15, "Index",
  CellTags->"Replace"],
Cell[243614, 9773, 262, 11, 15, "Index",
  CellTags->"ReplaceAllSpecial"],
Cell[243879, 9786, 278, 11, 15, "Index",
  CellTags->"ReplaceRepeatedSpecial"],
Cell[244160, 9799, 311, 11, 23, "Index",
  CellTags->"Representations"],
Cell[244474, 9812, 308, 10, 23, "IndexSubentry",
  CellTags->"Representations"],
Cell[244785, 9824, 286, 11, 23, "Index",
  CellTags->"Reproduction"],
Cell[245074, 9837, 222, 10, 23, "Index",
  CellTags->"Reverse"],
Cell[245299, 9849, 401, 15, 23, "Index",
  CellTags->"Root"],
Cell[245703, 9866, 280, 10, 23, "Index",
  CellTags->"RootedGenealogy"],
Cell[245986, 9878, 298, 11, 23, "Index",
  CellTags->"RootEvents"],
Cell[246287, 9891, 289, 11, 23, "Index",
  CellTags->"Rootings"],
Cell[246579, 9904, 244, 10, 23, "Index",
  CellTags->"Rules"],
Cell[246826, 9916, 234, 9, 23, "IndexSubentry",
  CellTags->"Rules"],
Cell[247063, 9927, 251, 10, 23, "Index",
  CellTags->"SampleCovariance"],
Cell[247317, 9939, 278, 10, 23, "Index",
  CellTags->"SampleIndividuals"],
Cell[247598, 9951, 260, 10, 23, "Index",
  CellTags->"SamplePartition"],
Cell[247861, 9963, 261, 11, 23, "Index",
  CellTags->"Sampling"],
Cell[248125, 9976, 319, 11, 23, "Index",
  CellTags->"Scripts and faces"],
Cell[248447, 9989, 292, 11, 23, "Index",
  CellTags->"Segments"],
Cell[248742, 10002, 304, 11, 23, "Index",
  CellTags->"SegmentStyle"],
Cell[249049, 10015, 414, 14, 23, "Index",
  CellTags->"SegregationRatio"],
Cell[249466, 10031, 321, 11, 23, "Index",
  CellTags->"SelectContext"],
Cell[249790, 10044, 272, 10, 23, "Index",
  CellTags->"SelectIndividuals"],
Cell[250065, 10056, 232, 10, 23, "Index",
  CellTags->"Selection"],
Cell[250300, 10068, 1704, 61, 143, "IndexSubentry",
  CellTags->"Selection"],
Cell[252007, 10131, 437, 15, 23, "Index",
  CellTags->"SelectionCoefficient"],
Cell[252447, 10148, 327, 11, 23, "Index",
  CellTags->"Selection coefficients"],
Cell[252777, 10161, 519, 19, 38, "IndexSubentry",
  CellTags->"Selection coefficients"],
Cell[253299, 10182, 317, 11, 23, "Index",
  CellTags->"SelectionExact"],
Cell[253619, 10195, 658, 21, 53, "IndexSubentry",
  CellTags->"SelectionExact"],
Cell[254280, 10218, 290, 11, 23, "Index",
  CellTags->"Selection on diploids"],
Cell[254573, 10231, 888, 33, 83, "IndexSubentry",
  CellTags->"Selection on diploids"],
Cell[255464, 10266, 304, 11, 23, "Index",
  CellTags->"SelectionRate"],
Cell[255771, 10279, 251, 10, 23, "Index",
  CellTags->"SelectLoci"],
Cell[256025, 10291, 217, 10, 23, "Index",
  CellTags->"Selfing"],
Cell[256245, 10303, 235, 10, 23, "Index",
  CellTags->"Separate"],
Cell[256483, 10315, 258, 11, 23, "Index",
  CellTags->"Servedio"],
Cell[256744, 10328, 339, 12, 23, "Index",
  CellTags->"Set"],
Cell[257086, 10342, 323, 10, 23, "IndexSubentry",
  CellTags->"Set"],
Cell[257412, 10354, 293, 11, 23, "Index",
  CellTags->"Set manipulation"],
Cell[257708, 10367, 270, 10, 23, "Index",
  CellTags->"SetOfCombinations"],
Cell[257981, 10379, 251, 10, 23, "Index",
  CellTags->"SetPartition"],
Cell[258235, 10391, 304, 11, 23, "Index",
  CellTags->"Sets of loci"],
Cell[258542, 10404, 216, 10, 23, "Index",
  CellTags->"Sex"],
Cell[258761, 10416, 394, 14, 23, "Index",
  CellTags->"Sex linkage"],
Cell[259158, 10432, 236, 9, 23, "IndexSubentry",
  CellTags->"Sex linkage"],
Cell[259397, 10443, 240, 10, 23, "Index",
  CellTags->"SexOfOrigin"],
Cell[259640, 10455, 267, 10, 23, "Index",
  CellTags->"Sexual selection"],
Cell[259910, 10467, 1209, 45, 113, "IndexSubentry",
  CellTags->"Sexual selection"],
Cell[261122, 10514, 265, 10, 23, "Index",
  CellTags->"ShortContext"],
Cell[261390, 10526, 278, 10, 23, "Index",
  CellTags->"SigmaMatrix"],
Cell[261671, 10538, 247, 10, 23, "Index",
  CellTags->"SignMask"],
Cell[261921, 10550, 236, 10, 23, "Index",
  CellTags->"SimplifyAddUp"],
Cell[262160, 10562, 239, 10, 23, "Index",
  CellTags->"SimplifyAddUpQ"],
Cell[262402, 10574, 261, 10, 23, "Index",
  CellTags->"SimplifyFamilies"],
Cell[262666, 10586, 335, 11, 23, "Index",
  CellTags->"Simulating individuals"],
Cell[263004, 10599, 503, 15, 38, "IndexSubentry",
  CellTags->"Simulating individuals"],
Cell[263510, 10616, 284, 10, 23, "Index",
  CellTags->"SizeOfGenealogyPlot"],
Cell[263797, 10628, 279, 10, 23, "Index",
  CellTags->"Slatkin & Excoffier 1996"],
Cell[264079, 10640, 239, 10, 23, "Index",
  CellTags->"SlowChange"],
Cell[264321, 10652, 274, 10, 23, "Index",
  CellTags->"SortByClass"],
Cell[264598, 10664, 284, 9, 23, "IndexSubentry",
  CellTags->"SortByClass"],
Cell[264885, 10675, 231, 10, 23, "Index",
  CellTags->"SortByHead"],
Cell[265119, 10687, 254, 10, 23, "Index",
  CellTags->"SpatialCovariance"],
Cell[265376, 10699, 323, 11, 23, "Index",
  CellTags->"Spatially varying selection"],
Cell[265702, 10712, 268, 10, 23, "Index",
  CellTags->"Special notation"],
Cell[265973, 10724, 239, 10, 23, "Index",
  CellTags->"SplitSet"],
Cell[266215, 10736, 301, 11, 23, "Index",
  CellTags->"Stabilising selection"],
Cell[266519, 10749, 1135, 40, 98, "IndexSubentry",
  CellTags->"Stabilising selection"],
Cell[267657, 10791, 411, 15, 23, "Index",
  CellTags->"Stability"],
Cell[268071, 10808, 275, 9, 23, "IndexSubentry",
  CellTags->"Stability"],
Cell[268349, 10819, 320, 11, 23, "Index",
  CellTags->"StabilityDirect"],
Cell[268672, 10832, 280, 9, 23, "IndexSubentry",
  CellTags->"StabilityDirect"],
Cell[268955, 10843, 422, 14, 23, "Index",
  CellTags->"StabilityK"],
Cell[269380, 10859, 313, 11, 23, "Index",
  CellTags->"StabilityKTable"],
Cell[269696, 10872, 282, 10, 23, "Index",
  CellTags->"StabilityMatrix"],
Cell[269981, 10884, 293, 11, 23, "Index",
  CellTags->"Stage"],
Cell[270277, 10897, 225, 10, 23, "Index",
  CellTags->"Stages"],
Cell[270505, 10909, 288, 9, 23, "IndexSubentry",
  CellTags->"Stages"],
Cell[270796, 10920, 266, 10, 23, "Index",
  CellTags->"StandardPartition"],
Cell[271065, 10932, 269, 10, 23, "Index",
  CellTags->"StandardPartitionQ"],
Cell[271337, 10944, 285, 10, 23, "Index",
  CellTags->"StartingStepSize"],
Cell[271625, 10956, 357, 12, 23, "Index",
  CellTags->"Stepping-stone migration"],
Cell[271985, 10970, 347, 12, 23, "Index",
  CellTags->"Stepping-stone model"],
Cell[272335, 10984, 501, 16, 38, "IndexSubentry",
  CellTags->"Stepping-stone model"],
Cell[272839, 11002, 323, 11, 23, "Index",
  CellTags->"StoreExact"],
Cell[273165, 11015, 1518, 45, 113, "IndexSubentry",
  CellTags->"StoreExact"],
Cell[274686, 11062, 450, 15, 23, "Index",
  CellTags->"StoreResults"],
Cell[275139, 11079, 813, 24, 38, "IndexSubentry",
  CellTags->"StoreResults"],
Cell[275955, 11105, 264, 10, 23, "Index",
  CellTags->"StructuredArray"],
Cell[276222, 11117, 304, 10, 23, "Index",
  CellTags->"StructuredInitialParameters"],
Cell[276529, 11129, 327, 11, 23, "Index",
  CellTags->"StructuredLogLikelihood"],
Cell[276859, 11142, 434, 14, 23, "Index",
  CellTags->"StructuredMLE"],
Cell[277296, 11158, 264, 10, 23, "Index",
  CellTags->"StructuredModel"],
Cell[277563, 11170, 288, 10, 23, "Index",
  CellTags->"StructuredModelReduce"],
Cell[277854, 11182, 262, 11, 23, "Index",
  CellTags->"Structured models"],
Cell[278119, 11195, 272, 9, 23, "IndexSubentry",
  CellTags->"Structured models"],
Cell[278394, 11206, 286, 10, 23, "Index",
  CellTags->"StructuredParameter"],
Cell[278683, 11218, 332, 11, 23, "Index",
  CellTags->"StructuredVariance"],
Cell[279018, 11231, 248, 11, 23, "Index",
  CellTags->"Style sheets"],
Cell[279269, 11244, 272, 10, 23, "Index",
  CellTags->"Subdivide"],
Cell[279544, 11256, 309, 11, 23, "Index",
  CellTags->"Subscripts"],
Cell[279856, 11269, 222, 10, 23, "Index",
  CellTags->"Subsets"],
Cell[280081, 11281, 366, 15, 38, "IndexSubentry",
  CellTags->"Subsets"],
Cell[280450, 11298, 234, 11, 23, "Index",
  CellTags->"Sums"],
Cell[280687, 11311, 255, 10, 23, "Index",
  CellTags->"SwapStates"],
Cell[280945, 11323, 344, 11, 23, "Index",
  CellTags->"Symmetric cline"],
Cell[281292, 11336, 317, 9, 23, "IndexSubentry",
  CellTags->"Symmetric cline"],
Cell[281612, 11347, 331, 11, 23, "Index",
  CellTags->"SymmetricDiploidFrequencies"],
Cell[281946, 11360, 331, 11, 23, "Index",
  CellTags->"SymmetricHaploidFrequencies"],
Cell[282280, 11373, 431, 15, 23, "Index",
  CellTags->"Symmetric model"],
Cell[282714, 11390, 1473, 49, 113, "IndexSubentry",
  CellTags->"Symmetric model"],
Cell[284190, 11441, 477, 15, 23, "Index",
  CellTags->"SymmetricNeutralDiploidFrequencies"],
Cell[284670, 11458, 477, 15, 23, "Index",
  CellTags->"SymmetricNeutralHaploidFrequencies"],
Cell[285150, 11475, 279, 10, 23, "Index",
  CellTags->"SymmetricRecombination"],
Cell[285432, 11487, 315, 10, 23, "Index",
  CellTags->"SymmetricRepresentations"],
Cell[285750, 11499, 259, 10, 23, "Index",
  CellTags->"SymmetricSexes"],
Cell[286012, 11511, 356, 14, 23, "Index",
  CellTags->"Symmetrise"],
Cell[286371, 11527, 234, 11, 23, "Index",
  CellTags->"T"],
Cell[286608, 11540, 277, 11, 23, "Index",
  CellTags->"Table"],
Cell[286888, 11553, 220, 10, 23, "Index",
  CellTags->"Tag"],
Cell[287111, 11565, 260, 11, 23, "Index",
  CellTags->"Tags"],
Cell[287374, 11578, 295, 10, 23, "IndexSubentry",
  CellTags->"Tags"],
Cell[287672, 11590, 390, 12, 23, "Index",
  CellTags->"TakeAway"],
Cell[288065, 11604, 260, 10, 23, "Index",
  CellTags->"TakeOptions"],
Cell[288328, 11616, 237, 11, 23, "Index",
  CellTags->"Time"],
Cell[288568, 11629, 307, 11, 23, "Index",
  CellTags->"TimesOfEvents"],
Cell[288878, 11642, 322, 11, 23, "Index",
  CellTags->"TimespanOfJunction"],
Cell[289203, 11655, 319, 11, 23, "Index",
  CellTags->"TimespanOfLineage"],
Cell[289525, 11668, 346, 14, 23, "Index",
  CellTags->"TimesUp"],
Cell[289874, 11684, 375, 15, 38, "IndexSubentry",
  CellTags->"TimesUp"],
Cell[290252, 11701, 248, 10, 23, "Index",
  CellTags->"ToBaake"],
Cell[290503, 11713, 254, 10, 23, "Index",
  CellTags->"ToBennett"],
Cell[290760, 11725, 284, 10, 23, "Index",
  CellTags->"ToBennettExpression"],
Cell[291047, 11737, 260, 10, 23, "Index",
  CellTags->"ToCumulants"],
Cell[291310, 11749, 254, 10, 23, "Index",
  CellTags->"ToMoments"],
Cell[291567, 11761, 296, 10, 23, "Index",
  CellTags->"ToPopulationCumulants"],
Cell[291866, 11773, 290, 10, 23, "Index",
  CellTags->"ToPopulationMoments"],
Cell[292159, 11785, 286, 10, 23, "Index",
  CellTags->"TotalLength"],
Cell[292448, 11797, 252, 10, 23, "Index",
  CellTags->"TotalNumber"],
Cell[292703, 11809, 339, 12, 23, "Index",
  CellTags->"Trait"],
Cell[293045, 11823, 271, 10, 23, "Index",
  CellTags->"TransformedRange"],
Cell[293319, 11835, 291, 10, 23, "Index",
  CellTags->"TransformInformation"],
Cell[293613, 11847, 269, 10, 15, "Index",
  CellTags->"TransmissionRule"],
Cell[293885, 11859, 300, 11, 15, "Index",
  CellTags->"Transmission rules"],
Cell[294188, 11872, 647, 21, 45, "IndexSubentry",
  CellTags->"Transmission rules"],
Cell[294838, 11895, 272, 10, 15, "Index",
  CellTags->"TriDiagonalMatrix"],
Cell[295113, 11907, 352, 12, 15, "Index",
  CellTags->"TruncationSelection"],
Cell[295468, 11921, 318, 9, 15, "IndexSubentry",
  CellTags->"TruncationSelection"],
Cell[295789, 11932, 298, 10, 15, "Index",
  CellTags->"Turelli and Barton 1994"],
Cell[296090, 11944, 270, 10, 15, "Index",
  CellTags->"Turelli & Barton 1994"],
Cell[296363, 11956, 240, 10, 15, "Index",
  CellTags->"Two alleles"],
Cell[296606, 11968, 360, 13, 15, "IndexSubentry",
  CellTags->"Two alleles"],
Cell[296969, 11983, 302, 11, 15, "Index",
  CellTags->"UMS"],
Cell[297274, 11996, 667, 21, 45, "IndexSubentry",
  CellTags->"UMS"],
Cell[297944, 12019, 261, 10, 15, "Index",
  CellTags->"UnionOfGametes"],
Cell[298208, 12031, 276, 10, 15, "Index",
  CellTags->"UnlinkedRecombination"],
Cell[298487, 12043, 286, 10, 15, "Index",
  CellTags->"UnrootedGenealogy"],
Cell[298776, 12055, 269, 10, 15, "Index",
  CellTags->"UpperOffDiagonal"],
Cell[299048, 12067, 302, 11, 15, "Index",
  CellTags->"USM"],
Cell[299353, 12080, 667, 21, 45, "IndexSubentry",
  CellTags->"USM"],
Cell[300023, 12103, 281, 10, 15, "Index",
  CellTags->"ValidMatrixQ"],
Cell[300307, 12115, 332, 11, 15, "Index",
  CellTags->"VarianceComponents"],
Cell[300642, 12128, 263, 9, 15, "IndexSubentry",
  CellTags->"VarianceComponents"],
Cell[300908, 12139, 253, 11, 15, "Index",
  CellTags->"Versions"],
Cell[301164, 12152, 428, 14, 15, "Index",
  CellTags->"Wiuf & Hein 1999"],
Cell[301595, 12168, 260, 11, 15, "Index",
  CellTags->"WLinkedLoci"],
Cell[301858, 12181, 441, 15, 30, "IndexSubentry",
  CellTags->"WLinkedLoci"],
Cell[302302, 12198, 277, 10, 15, "Index",
  CellTags->"Wright-Fisher sampling"],
Cell[302582, 12210, 247, 11, 15, "Index",
  CellTags->"X"],
Cell[302832, 12223, 260, 11, 15, "Index",
  CellTags->"XLinkedLoci"],
Cell[303095, 12236, 441, 15, 30, "IndexSubentry",
  CellTags->"XLinkedLoci"],
Cell[303539, 12253, 260, 11, 15, "Index",
  CellTags->"YLinkedLoci"],
Cell[303802, 12266, 441, 15, 30, "IndexSubentry",
  CellTags->"YLinkedLoci"],
Cell[304246, 12283, 260, 11, 15, "Index",
  CellTags->"ZLinkedLoci"],
Cell[304509, 12296, 441, 15, 30, "IndexSubentry",
  CellTags->"ZLinkedLoci"],
Cell[304953, 12313, 411, 15, 15, "Index",
  CellTags->"Zygotes"],
Cell[305367, 12330, 427, 15, 15, "Index",
  CellTags->"\[GothicA]"],
Cell[305797, 12347, 419, 15, 15, "Index",
  CellTags->"\[GothicCapitalA]"],
Cell[306219, 12364, 340, 11, 15, "Index",
  CellTags->"\[GothicCapitalC]"],
Cell[306562, 12377, 612, 19, 15, "Index",
  CellTags->"\[GothicCapitalD]"],
Cell[307177, 12398, 494, 16, 15, "Index",
  CellTags->"\!\(\(\[GothicCapitalG]\^\[RawStar]\)\)"],
Cell[307674, 12416, 421, 15, 15, "Index",
  CellTags->"\[GothicCapitalG]"],
Cell[308098, 12433, 435, 15, 15, "Index",
  CellTags->"\[GothicCapitalH]"],
Cell[308536, 12450, 425, 15, 15, "Index",
  CellTags->"\[GothicCapitalJ]"],
Cell[308964, 12467, 320, 11, 15, "Index",
  CellTags->"\[GothicK]"],
Cell[309287, 12480, 377, 11, 15, "Index",
  CellTags->"\[GothicCapitalK]"],
Cell[309667, 12493, 308, 11, 15, "Index",
  CellTags->"\[GothicM]"],
Cell[309978, 12506, 308, 11, 15, "Index",
  CellTags->"\[GothicP]"],
Cell[310289, 12519, 369, 12, 15, "Index",
  CellTags->"\[GothicP]\[GothicQ]"],
Cell[310661, 12533, 308, 11, 15, "Index",
  CellTags->"\[GothicQ]"],
Cell[310972, 12546, 314, 11, 15, "Index",
  CellTags->"\[GothicR]"],
Cell[311289, 12559, 301, 11, 15, "Index",
  CellTags->"\[GothicS]"],
Cell[311593, 12572, 421, 15, 15, "Index",
  CellTags->"\[GothicCapitalZ]"],
Cell[312017, 12589, 348, 11, 15, "Index",
  CellTags->"\[DoubleStruckCapitalG]"],
Cell[312368, 12602, 322, 11, 15, "Index",
  CellTags->"\[DoubleStruckCapitalM]"],
Cell[312693, 12615, 457, 15, 15, "Index",
  CellTags->"\[DoubleStruckCapitalR]"],
Cell[313153, 12632, 318, 11, 15, "Index",
  CellTags->"\[DoubleStruckCapitalW]"],
Cell[313474, 12645, 358, 12, 15, "Index",
  CellTags->"\[DoubleStruckCapitalZ]"],
Cell[313835, 12659, 310, 11, 15, "Index",
  CellTags->"\[Gamma]"],
Cell[314148, 12672, 304, 11, 15, "Index",
  CellTags->"\[Zeta]"],
Cell[314455, 12685, 307, 11, 15, "Index",
  CellTags->"\[CapitalMu]"],
Cell[314765, 12698, 312, 11, 15, "Index",
  CellTags->"\[Chi]"],
Cell[315080, 12711, 296, 11, 15, "Index",
  CellTags->"\[Sampi]"],
Cell[315379, 12724, 290, 10, 15, "Index",
  CellTags->"$MetropolisAdjustment"],
Cell[315672, 12736, 317, 11, 15, "Index",
  CellTags->"\[WeierstrassP]"],
Cell[315992, 12749, 449, 12, 15, "Index",
  CellTags->"\[LeftDoubleBracketingBar] \[RightDoubleBracketingBar]"],
Cell[316444, 12763, 320, 11, 15, "Index",
  CellTags->"\[CircleDot]"],
Cell[316767, 12776, 394, 12, 15, "Index",
  CellTags->"\[Backslash]"],
Cell[317164, 12790, 450, 15, 15, "Index",
  CellTags->"\[Wedge]"],
Cell[317617, 12807, 319, 11, 15, "Index",
  CellTags->"\[CirclePlus]"]
}
]
*)




(***********************************************************************
End of Mathematica Notebook file.
***********************************************************************)

