(***********************************************************************

                    Mathematica-Compatible Notebook

This notebook can be used on any computer system with Mathematica 4.0,
MathReader 4.0, or any compatible application. The data for the notebook 
starts with the line containing stars above.

To get the notebook into a Mathematica-compatible application, do one of 
the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing the 
word CacheID, otherwise Mathematica-compatible applications may try to 
use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
***********************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[      8070,        237]*)
(*NotebookOutlinePosition[      9246,        275]*)
(*  CellTagsIndexPosition[      9142,        268]*)
(*WindowFrame->Normal*)



Notebook[{
Cell["Cumulants", "SubsectionIcon"],

Cell[TextData[Cell[BoxData[
    FormBox[GridBox[{
          {
            
            FormBox[\(\[GothicCapitalD]\_\[DoubleStruckCapitalU] /. 
                ToCumulants[]\),
              
              "TraditionalForm"], \(transforms\ linkage\ disequilibria, \ \
\[GothicCapitalD], \ to\ cumulants, \ \(\(\[GothicK]\)\(.\)\)\)},
          {
            FormBox[\(\[GothicK]\_\[DoubleStruckCapitalU] /. ToMoments[]\),
              "TraditionalForm"], \(transforms\ cumulants, \ \[GothicK], \ 
            to\ linkage\ disequilibria, \ \(\(\[GothicCapitalD]\)\(.\)\(\ \
\)\)\)}
          }], TraditionalForm]]]], "DefinitionBox",
  CellTags->{"ToCumulants", "ToMoments"}],

Cell["\<\
Associations among genes-in-context can be described by cumulants \
rather than by linkage disequilibria (i.e., by moments of allelic deviations, \
\[Zeta]).  ToCumulants[] and ToMoments[] convert between these \
representations.  \
\>", "Text"],

Cell["\<\
This transforms an expression involving linkage disequilibria into \
one involving cumulants:\
\>", "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\[GothicCapitalD]\_{\[DoubleStruckI], \[DoubleStruckJ], \
\[DoubleStruckK]} /. ToCumulants[]\)], "Input",
  CellLabel->"In[16]:=  (16:11:56 on 4/5/00)"],

Cell[BoxData[
    \(\[GothicK]\_{\[DoubleStruckI]}\ \[GothicK]\_{\[DoubleStruckJ]}\ \
\[GothicK]\_{\[DoubleStruckK]} + \[GothicK]\_{\[DoubleStruckK]}\ \
\[GothicK]\_{\[DoubleStruckI], \[DoubleStruckJ]} + \[GothicK]\_{\
\[DoubleStruckJ]}\ \[GothicK]\_{\[DoubleStruckI], \[DoubleStruckK]} + \
\[GothicK]\_{\[DoubleStruckI]}\ \[GothicK]\_{\[DoubleStruckJ], \
\[DoubleStruckK]} + \[GothicK]\_{\[DoubleStruckI], \[DoubleStruckJ], \
\[DoubleStruckK]}\)], "Output",
  CellLabel->"Out[16]=  (16:11:56 on 4/5/00)"]
}, Open  ]],

Cell["This transforms the expression back:", "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[
    \(% /. ToMoments[] // Simplify\)], "Input",
  CellLabel->"In[17]:=  (16:11:59 on 4/5/00)"],

Cell[BoxData[
    \(\[GothicCapitalD]\_{\[DoubleStruckI], \[DoubleStruckJ], \
\[DoubleStruckK]}\)], "Output",
  CellLabel->"Out[17]=  (16:11:59 on 4/5/00)"]
}, Open  ]],

Cell[TextData[{
  "ToMoments[] and ToCumulants[] just call Moments[] and Cumulants[], which \
are defined in ",
  ButtonBox["Utilities`Cumulants`",
    ButtonData:>{"Cumulants", None},
    ButtonStyle->"AddOnsLink",
    ButtonNote->"Utilities`Cumulants`"],
  "."
}], "Text"],

Cell[TextData[{
  "Weak selection takes a particularly simple form when represented in terms \
of cumulants, particularly when selection acts on additive quantitative \
traits.  However, recombination and migration are more complicated.  For \
details, see Turelli & Barton (",
  ButtonBox["1994",
    ButtonData:>{"Multilocus references", "Turelli and Barton 1994"},
    ButtonStyle->"AddOnsLink",
    ButtonNote->"1994"],
  ")"
}], "Text"],

Cell[TextData[{
  "Linkage disequilibria amongst a set of genes-in-context, \
\[DoubleStruckCapitalU], are defined as moments: ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          
          FormBox[\(\(\[GothicCapitalD]\_\(\(\[DoubleStruckCapitalU]\)\(\ \
\)\)\)\(\[Congruent]\)\),
            
            "TraditionalForm"], \(\[LeftAngleBracket]\[Product]\+\(\
\[DoubleStruckI] \[Element] \
\[DoubleStruckCapitalU]\)\[Zeta]\_\[DoubleStruckI]\[RightAngleBracket]\)}], 
        TraditionalForm]]],
  ".  These can be derived from a moment generating function, ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          RowBox[{"G", "[", 
            FormBox[\(\[Omega]\+_\),
              "TraditionalForm"], "]"}], 
          "\[Congruent]", \(\[LeftAngleBracket]Exp[\[Omega]\+_ . \[Zeta]\+_]\
\[RightAngleBracket]\)}], TraditionalForm]]],
  ": ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          
          FormBox[\(\[GothicCapitalD]\_\(\(\[DoubleStruckCapitalU]\)\(\ \
\)\)\),
            "TraditionalForm"], 
          "=", \(\[PartialD]\_\[DoubleStruckCapitalU] G[0\+_]\)}], 
        TraditionalForm]]],
  ", where ",
  Cell[BoxData[
      \(TraditionalForm\`\(\(\[PartialD]\_\[DoubleStruckCapitalU]\)\(\ \
\)\)\)]],
  "denotes the derivative with respect to the set of ",
  Cell[BoxData[
      \(TraditionalForm\`\[Omega]\_\[DoubleStruckI]\)]],
  " for \[DoubleStruckI]\[Element]\[DoubleStruckCapitalU]."
}], "Text"],

Cell[TextData[{
  "The cumulants are derived in the same way from the cumulant generating \
function, which is just ",
  Cell[BoxData[
      \(TraditionalForm\`Log[G[\[Omega]\+_]]\)]],
  ": ",
  Cell[BoxData[
      \(TraditionalForm\`\(\(\[GothicK]\_\[DoubleStruckCapitalU]\)\(=\)\)\)]],\

  Cell[BoxData[
      \(TraditionalForm\`\[PartialD]\_\[DoubleStruckCapitalU] Log[
          G[0\+_]]\)]],
  "."
}], "Text"],

Cell[TextData[Cell[BoxData[
    FormBox[GridBox[{
          {
            
            FormBox[\(d[{\[DoubleStruckI], \[DoubleStruckJ], \
\[DoubleStruckK]}] /. ToCumulants[d, c]\),
              "TraditionalForm"], \(transforms\ moments, \ d, \ 
            to\ cumulants, \ \(\(c\)\(.\)\)\)},
          {
            
            FormBox[\(c[{\[DoubleStruckI], \[DoubleStruckJ], \
\[DoubleStruckK]}] /. ToMoments[c, d]\),
              "TraditionalForm"], \(transforms\ cumulants, \ c, \ 
            to\ moments, \ \(\(d\)\(.\)\)\)}
          }], TraditionalForm]]]], "DefinitionBox"],

Cell["The rules can work with arbitrary symbols:", "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[
    \(d[{\[DoubleStruckI], \[DoubleStruckJ], \[DoubleStruckK]}] /. 
      ToCumulants[d, c]\)], "Input",
  CellLabel->"In[22]:=  (16:15:26 on 4/5/00)"],

Cell[BoxData[
    \(c[{\[DoubleStruckI]}]\ c[{\[DoubleStruckJ]}]\ c[{\[DoubleStruckK]}] + 
      c[{\[DoubleStruckK]}]\ c[{\[DoubleStruckI], \[DoubleStruckJ]}] + 
      c[{\[DoubleStruckJ]}]\ c[{\[DoubleStruckI], \[DoubleStruckK]}] + 
      c[{\[DoubleStruckI]}]\ c[{\[DoubleStruckJ], \[DoubleStruckK]}] + 
      c[{\[DoubleStruckI], \[DoubleStruckJ], \[DoubleStruckK]}]\)], "Output",
  CellLabel->"Out[22]=  (16:15:26 on 4/5/00)"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(% /. ToMoments[c, d] // Simplify\)], "Input",
  CellLabel->"In[23]:=  (16:15:33 on 4/5/00)"],

Cell[BoxData[
    \(d[{\[DoubleStruckI], \[DoubleStruckJ], \[DoubleStruckK]}]\)], "Output",
  CellLabel->"Out[23]=  (16:15:33 on 4/5/00)"]
}, Open  ]]
},
FrontEndVersion->"4.0 for Macintosh",
ScreenRectangle->{{0, 1152}, {0, 748}},
WindowSize->{520, 626},
WindowMargins->{{245, Automatic}, {Automatic, 46}},
StyleDefinitions -> "HelpBrowser.nb",
MacintoshSystemPageSetup->"\<\
00h0001804P000000b02<?oaonl3>@91H`85N0?N0@00005X0FP000003j0:l001
0@00I00100000@0200000BL?00400000000000000000010000000000000@0?ne
oj/@7@]500P1000000000000000001T1\>"
]


(***********************************************************************
Cached data follows.  If you edit this Notebook file directly, not using
Mathematica, you must remove the line containing CacheID at the top of 
the file.  The cache data will then be recreated when you save this file 
from within Mathematica.
***********************************************************************)

(*CellTagsOutline
CellTagsIndex->{
  "ToCumulants"->{
    Cell[1755, 51, 675, 15, 56, "DefinitionBox",
      CellTags->{"ToCumulants", "ToMoments"}]},
  "ToMoments"->{
    Cell[1755, 51, 675, 15, 56, "DefinitionBox",
      CellTags->{"ToCumulants", "ToMoments"}]}
  }
*)

(*CellTagsIndex
CellTagsIndex->{
  {"ToCumulants", 8906, 258},
  {"ToMoments", 9020, 261}
  }
*)

(*NotebookFileOutline
Notebook[{
Cell[1717, 49, 35, 0, 36, "SubsectionIcon"],
Cell[1755, 51, 675, 15, 56, "DefinitionBox",
  CellTags->{"ToCumulants", "ToMoments"}],
Cell[2433, 68, 255, 5, 50, "Text"],
Cell[2691, 75, 124, 3, 42, "MathCaption"],

Cell[CellGroupData[{
Cell[2840, 82, 172, 3, 39, "Input"],
Cell[3015, 87, 505, 8, 34, "Output"]
}, Open  ]],
Cell[3535, 98, 59, 0, 28, "MathCaption"],

Cell[CellGroupData[{
Cell[3619, 102, 108, 2, 38, "Input"],
Cell[3730, 106, 156, 3, 34, "Output"]
}, Open  ]],
Cell[3901, 112, 274, 8, 38, "Text"],
Cell[4178, 122, 441, 10, 51, "Text"],
Cell[4622, 134, 1444, 41, 53, "Text"],
Cell[6069, 177, 414, 13, 36, "Text"],
Cell[6486, 192, 586, 14, 56, "DefinitionBox"],
Cell[7075, 208, 65, 0, 28, "MathCaption"],

Cell[CellGroupData[{
Cell[7165, 212, 165, 3, 39, "Input"],
Cell[7333, 217, 431, 6, 70, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[7801, 228, 112, 2, 70, "Input"],
Cell[7916, 232, 138, 2, 70, "Output"]
}, Open  ]]
}
]
*)




(***********************************************************************
End of Mathematica Notebook file.
***********************************************************************)

