(***********************************************************************

                    Mathematica-Compatible Notebook

This notebook can be used on any computer system with Mathematica 4.0,
MathReader 4.0, or any compatible application. The data for the notebook 
starts with the line containing stars above.

To get the notebook into a Mathematica-compatible application, do one of 
the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing the 
word CacheID, otherwise Mathematica-compatible applications may try to 
use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
***********************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[     22044,        509]*)
(*NotebookOutlinePosition[     23776,        559]*)
(*  CellTagsIndexPosition[     23519,        549]*)
(*WindowFrame->Normal*)



Notebook[{
Cell["Random drift", "SubsectionIcon"],

Cell["\<\
\tThe notation extends to describe random variation.  This might be \
due to the random genetic drift which is inevitable in a finite population.  \
However, other sources of random variation - for example, random variation in \
selection coefficients - can be described in a similar way.  This section \
introduces the general description of a stochastic distribution of \
populations.\
\>", "Text"],

Cell["Describing a distribution of populations", "SubsubsectionIcon",
  CellTags->"Describing a distribution"],

Cell[TextData[{
  "\tA population consists of a collection of genes, each in a particular \
context and a particular allelic state.  The population can be described \
either by listing all the allelic states, ",
  Cell[BoxData[
      \(TraditionalForm\`{X\_\(\[DoubleStruckI]\_1\), \ \(X\_\(\
\[DoubleStruckI]\_2\)\) \[Ellipsis]}\)]],
  ", or by the means ",
  Cell[BoxData[
      \(TraditionalForm\`\(\[GothicM]\_\(\[DoubleStruckI]\_1\)\) \
\[Ellipsis]\)]],
  ", and linkage disequilibria, ",
  Cell[BoxData[
      \(TraditionalForm\`\(\[GothicCapitalD]\_\[DoubleStruckCapitalU]\) \
\[Ellipsis]\)]],
  ".  Note that the population can be structured by sex, deme\[Ellipsis] etc. \
 Random fluctuations generate a probability distrinbution of allelic states, \
",
  Cell[BoxData[
      \(TraditionalForm\`{X\_\(\[DoubleStruckI]\_1\), \ \(X\_\(\
\[DoubleStruckI]\_2\)\) \[Ellipsis]}\)]],
  ", or equivalently, a distribution of the \[GothicM], \[GothicCapitalD]. \
This distribution can be described by moments such as ",
  Cell[BoxData[
      \(TraditionalForm\`\[LeftDoubleBracketingBar]\(\[GothicCapitalD]\_\
\[DoubleStruckCapitalU]\) \(\[GothicCapitalD]\_\[DoubleStruckCapitalV]\) \
\[WeierstrassP]\_\[DoubleStruckI]\[RightDoubleBracketingBar]\)]],
  ", where ",
  Cell[BoxData[
      \(TraditionalForm\`\[LeftDoubleBracketingBar]\ \
\[RightDoubleBracketingBar]\)]],
  " denotes an expectation over the probability distribution (entered as \
\[AliasIndicator]l||\[AliasIndicator] \[AliasIndicator]r||\[AliasIndicator]). \
(Note that this expectation over the ",
  StyleBox["distribution",
    FontSlant->"Italic"],
  " of populations is distinct from the expectation over the distribution of \
allelic states within any one population, denoted \[LeftAngleBracket] \
\[RightAngleBracket]).  Such moments are denoted by ",
  Cell[BoxData[
      \(TraditionalForm\`\[LeftDoubleBracketingBar]\(\[GothicCapitalD]\_\
\[DoubleStruckCapitalU]\) \(\[GothicCapitalD]\_\[DoubleStruckCapitalV]\) \(\
\[Ellipsis]\[WeierstrassP]\_\[DoubleStruckI]\) \(\[WeierstrassP]\_\
\[DoubleStruckJ]\) \[Ellipsis]\[RightDoubleBracketingBar]\)]],
  "=",
  Cell[BoxData[
      \(TraditionalForm\`\[GothicCapitalC]\_\({{\[DoubleStruckCapitalU]}, {\
\[DoubleStruckCapitalV]}, \[Ellipsis]}, {{\[DoubleStruckI]}, \
{\[DoubleStruckJ]} \[Ellipsis]}\)\)]],
  ".  (\[GothicCapitalC], entered as \[AliasIndicator]goC\[AliasIndicator], \
stands for 'covariance').  The reference points ",
  Cell[BoxData[
      \(TraditionalForm\`\[WeierstrassP]\_\[DoubleStruckI]\)]],
  " may also fluctuate, and so associations involving these are also included \
in \[GothicCapitalC]. Since ",
  Cell[BoxData[
      \(TraditionalForm\`\[GothicM]\_\[DoubleStruckI] = \[WeierstrassP]\_\
\[DoubleStruckI] + \[GothicCapitalD]\_{\[DoubleStruckI]}\)]],
  ",  fluctuations in mean contribution can be described in the same \
foemalism."
}], "Text"],

Cell[TextData[{
  "\tThere might be other sources of random fluctuation: for example, \
fluctuations in selection coefficient, ",
  Cell[BoxData[
      \(TraditionalForm\`\[GothicA]\_\[DoubleStruckCapitalU]\)]],
  ".  The joint distribution of the \[GothicCapitalD], \[WeierstrassP] and \
\[GothicA] can be described by moments such as ",
  Cell[BoxData[
      \(TraditionalForm\`\(\(\[LeftDoubleBracketingBar]\(\[GothicCapitalD]\_\
\[DoubleStruckCapitalU]\) \(\[GothicCapitalD]\_\[DoubleStruckCapitalV]\) \(\
\[Ellipsis]\[WeierstrassP]\_\[DoubleStruckI]\) \(\[WeierstrassP]\_\
\[DoubleStruckJ]\) \[Ellipsis]\[GothicA]\_\(\[DoubleStruckCapitalA]\ \
\[Ellipsis]\)\[RightDoubleBracketingBar]\)\(=\)\)\)]],
  Cell[BoxData[
      \(TraditionalForm\`\[GothicCapitalC]\_\({{\[DoubleStruckCapitalU]}, {\
\[DoubleStruckCapitalV]}, \[Ellipsis]}, {{\[DoubleStruckI]}, \
{\[DoubleStruckJ]} \[Ellipsis]}, {{\[DoubleStruckCapitalA]}, \
\[Ellipsis]}\)\)]],
  ".  "
}], "Text"],

Cell["Equations for the moments", "SubsubsectionIcon",
  CellTags->"Equations for the moments"],

Cell[TextData[{
  "\tIn general, the evolution of the distribution of populations can only be \
described by following the whole distribution.  However, in certain cases, \
the process can be described just by following the moments of the \
distribution, \[GothicCapitalC].  If the evolutionary processes are linear \
(for example, mutation or migration ), then a set of closed equations for the \
moments can be found (see Crow and Kimura, ",
  ButtonBox["1970",
    ButtonData:>{"Multilocus references", "Crow and Kimura 1970"},
    ButtonStyle->"AddOnsLink",
    ButtonNote->"1970"],
  "). Even though the rate of increase of variance as a result of random \
drift is nonlinear in allele frequency ",
  Cell[BoxData[
      \(TraditionalForm\`\((\(\(~\)\(p\)\)\[VeryThinSpace]q\)\)]],
  "), drift can also be described by closed equations for the moments.  If \
selection is weak, then its effects can be approximated as a polynomial in \
\[GothicM], \[GothicCapitalD]. Equations can then be written down for the \
moments: however, these are not closed.  Nevertheless, it is helpful to \
derive the mean and variance of fluctuations produced over some small \
interval, because the diffusion approximation to the distribution of \
\[GothicM], \[GothicCapitalD] can then be applied."
}], "Text"],

Cell["Cumulants and moments", "SubsubsectionIcon",
  CellTags->"Cumulants and moments"],

Cell["\<\
\tIt may be helpful to work not with the moments of the \
\[GothicCapitalD], \[WeierstrassP],\[Ellipsis] but with their cumulants. For \
example, expressions for the effects random sampling are simpler when derived \
in terms of the moments. Cumulants for the distribution across populations \
are denoted by \[GothicCapitalK]; they whould be distinguished from cumulants \
of the distribution of allelic states within populations, denoted by \
\[GothicK].  It is straightforward to convert between moments and \
cumulants.\
\>", "Text"],

Cell["Changing reference points", "SubsubsectionIcon",
  CellTags->"Changing reference points"],

Cell["\<\
\tWhen a set of genes moves between contexts, their reference \
points also change. As a consequence, linkage disequilibria change:\
\>", \
"Text"],

Cell[BoxData[
    \(\[GothicCapitalD]\_\[DoubleStruckCapitalA]\[CirclePlus]{\
\[DoubleStruckCapitalA] \[LeftArrow] \[DoubleStruckCapitalB]} = \[Sum]\+\(\
\[DoubleStruckCapitalC] \[Subset] \
\[DoubleStruckCapitalB]\)\(\[GothicCapitalD]\_\(\[DoubleStruckCapitalB]\
\[Backslash]\[DoubleStruckCapitalC]\)\) \(\[Product]\+\(\[DoubleStruckJ] \
\[Element] \[DoubleStruckCapitalC]\)\((\[WeierstrassP]\_\[DoubleStruckJ] - \
\[WeierstrassP]\_\[DoubleStruckI])\)\)\)], "NumberedEquation"],

Cell["\<\
where \[DoubleStruckI]\[Element]\[DoubleStruckCapitalA] is the \
present gene-in-context corresponding to the previous \[DoubleStruckJ]\
\[Element]\[DoubleStruckCapitalB].  In the same way, associations between \
linkage disequilibria also change:\
\>", "Text"],

Cell[BoxData[
    \(\[GothicCapitalC]\_\({{\[DoubleStruckCapitalA]\_1}, {\
\[DoubleStruckCapitalA]\_2}, \[Ellipsis]}, \[Ellipsis]\)\[CirclePlus]{\
\[DoubleStruckCapitalA] \[LeftArrow] \[DoubleStruckCapitalB]} = \(\
\[LeftDoubleBracketingBar]\((\[GothicCapitalD]\_\(\[DoubleStruckCapitalA]\_1\)\
\[CirclePlus]{\[DoubleStruckCapitalA] \[LeftArrow] \
\[DoubleStruckCapitalB]})\) \
\((\[GothicCapitalD]\_\(\[DoubleStruckCapitalA]\_2\)\[CirclePlus]{\
\[DoubleStruckCapitalA] \[LeftArrow] \[DoubleStruckCapitalB]})\) \[Ellipsis]\
\[RightDoubleBracketingBar]\[IndentingNewLine] = \(\[LeftDoubleBracketingBar]\
\((\[Sum]\+\(\[DoubleStruckCapitalC]\_1 \[Subset] \
\[DoubleStruckCapitalB]\_1\)\(\[GothicCapitalD]\_{\[DoubleStruckCapitalB]\_1\
\[Backslash]\[DoubleStruckCapitalC]\_1}\) \(\[Product]\+\(\[DoubleStruckJ]\_1 \
\[Element] \[DoubleStruckCapitalC]\_1\)\((\[WeierstrassP]\_\(\[DoubleStruckJ]\
\_1\) - \[WeierstrassP]\_\(\[DoubleStruckI]\_1\))\)\))\) \((\[Sum]\+\(\
\[DoubleStruckCapitalC]\_2 \[Subset] \[DoubleStruckCapitalB]\_2\)\(\
\[GothicCapitalD]\_\(\[DoubleStruckCapitalB]\_2\[Backslash]\
\[DoubleStruckCapitalC]\_2\)\) \(\[Product]\+\(\[DoubleStruckJ]\_2 \[Element] \
\[DoubleStruckCapitalC]\_2\)\((\[WeierstrassP]\_\(\[DoubleStruckJ]\_2\) - \
\[WeierstrassP]\_\(\[DoubleStruckI]\_2\))\)\))\) \[Ellipsis]\
\[RightDoubleBracketingBar]\[IndentingNewLine] = \(\[LeftDoubleBracketingBar]\
\((\[Sum]\+\(\[DoubleStruckCapitalC]\_1 \[Subset] \
\[DoubleStruckCapitalB]\_1\)\(\[GothicCapitalD]\_{\[DoubleStruckCapitalB]\_1\
\[Backslash]\[DoubleStruckCapitalC]\_1}\) \(\[Sum]\+\(\[DoubleStruckCapitalD]\
\_1 \[Subset] \[DoubleStruckCapitalC]\_1\)\[Product]\+\(\[DoubleStruckJ]\_1 \
\[Element] \
\[DoubleStruckCapitalD]\_1\)\(\[WeierstrassP]\_\(\[DoubleStruckJ]\_1\)\) \(\
\[Product]\+\(\[DoubleStruckJ]\_1 \[Element] \[DoubleStruckCapitalC]\_1\
\[Backslash]\[DoubleStruckCapitalD]\_1\)\((\(-\[WeierstrassP]\_\(\
\[DoubleStruckI]\_2\)\))\)\)\))\) \((\[Sum]\+\(\[DoubleStruckCapitalC]\_2 \
\[Subset] \[DoubleStruckCapitalB]\_2\)\(\[GothicCapitalD]\_\(\
\[DoubleStruckCapitalB]\_2\[Backslash]\[DoubleStruckCapitalC]\_2\)\) \(\[Sum]\
\+\(\[DoubleStruckCapitalD]\_2 \[Subset] \[DoubleStruckCapitalC]\_2\)\
\[Product]\+\(\[DoubleStruckJ]\_2 \[Element] \[DoubleStruckCapitalD]\_2\)\(\
\[WeierstrassP]\_\(\[DoubleStruckJ]\_2\)\) \
\(\[Product]\+\(\[DoubleStruckJ]\_2 \[Element] \[DoubleStruckCapitalC]\_2\
\[Backslash]\[DoubleStruckCapitalD]\_2\)\((\(-\[WeierstrassP]\_\(\
\[DoubleStruckI]\_2\)\))\)\)\))\) \[Ellipsis]\[RightDoubleBracketingBar]\
\[IndentingNewLine] = \[Sum]\+\(\[DoubleStruckCapitalC]\_1 \[Subset] \
\[DoubleStruckCapitalB]\_1\)\(\[Sum]\+\(\[DoubleStruckCapitalD]\_1 \[Subset] \
\[DoubleStruckCapitalC]\_1\)\(\[Sum]\+\(\[DoubleStruckCapitalC]\_2 \[Subset] \
\[DoubleStruckCapitalB]\_2\)\(\[Sum]\+\(\[DoubleStruckCapitalD]\_2 \[Subset] \
\[DoubleStruckCapitalC]\_2\)\[Ellipsis]\[GothicCapitalC]\_\(\(\(\(\({{\
\[DoubleStruckCapitalB]\_1\[Backslash]\[DoubleStruckCapitalC]\_1}, {\
\[DoubleStruckCapitalB]\_2\[Backslash]\[DoubleStruckCapitalC]\_2}, \
\[Ellipsis]}, {\[DoubleStruckCapitalD]\_1, \((\[DoubleStruckCapitalC]\_1\
\[Backslash]\[DoubleStruckCapitalD]\_1)\)\[CirclePlus]{\[DoubleStruckCapitalA]\
 \[LeftArrow] \[DoubleStruckCapitalB]}\)\(]\)\), \[DoubleStruckCapitalD]\_2, \
\[DoubleStruckCapitalC]\_2\[Backslash]\[DoubleStruckCapitalD]\_2\[CirclePlus]{\
\[DoubleStruckCapitalA] \[LeftArrow] \[DoubleStruckCapitalB]} \
\[Ellipsis]\)\(}\)\) \((\(-1\))\)\^k\)\)\)\)\)\)\)\)], "NumberedEquation"],

Cell[TextData[{
  "Here, the \[GothicCapitalC] involve associations between \[GothicCapitalD] \
and \[WeierstrassP].  These may be determined by defining the reference \
points.  For example, if the reference points equal current allele \
frequencies ",
  Cell[BoxData[
      \(TraditionalForm\`\((\(~\)\(\[GothicCapitalD]\_{\[DoubleStruckI]}\))\)\
\)]],
  ", then the \[GothicCapitalC] convert back to involve only associations \
between \[GothicCapitalD].  Associations with other random variables can be \
inherited in the same way as above."
}], "Text"],

Cell["Random sampling", "SubsubsectionIcon",
  CellTags->"Random sampling"],

Cell[TextData[{
  "The hardest problem is to find a general algorithm for calculating the \
moments of \[GothicCapitalD], \[GothicM] after sampling.  It is reasonable to \
restrict attention to Wright-Fisher sampling of ",
  Cell[BoxData[
      \(TraditionalForm\`2  N\)]],
  " items from an infinite population of (say) juveniles.  Even then, the \
general case is difficult."
}], "Text"],

Cell[TextData[{
  "\tFirst, consider second moments.  Let the disequilibria before sampling \
be ",
  Cell[BoxData[
      \(TraditionalForm\`\[GothicCapitalD]\_\[DoubleStruckCapitalU]\)]],
  ", and after sampling, ",
  Cell[BoxData[
      \(TraditionalForm\`\(\(\[GothicCapitalD]\_\(\[DoubleStruckCapitalU]\^*\)\
\)\(.\)\)\)]],
  "  Then, the covariance between ",
  Cell[BoxData[
      \(TraditionalForm\`\[GothicCapitalD]\_\(\[DoubleStruckCapitalU]\^*\)\)]]\
,
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`\[GothicCapitalD]\_\(\[DoubleStruckCapitalV]\^*\)\)]]\
,
  " after sampling is just:"
}], "Text"],

Cell[BoxData[
    \(TextForm\`\[GothicCapitalK]\_\({{\(\[DoubleStruckCapitalU]\^*\)}, {\(\
\[DoubleStruckCapitalV]\^*\)}}, {}\) = \(\[GothicCapitalC]\_\({{\(\
\[DoubleStruckCapitalU]\^*\)}, {\(\[DoubleStruckCapitalV]\^*\)}}, {}\) - \(\
\[GothicCapitalC]\_\({{\(\[DoubleStruckCapitalU]\^*\)}}, {}\)\) \
\[GothicCapitalC]\_\({{\(\[DoubleStruckCapitalV]\^*\)}}, {}\) = \(\
\[LeftDoubleBracketingBar]\(\[GothicCapitalD]\_\(\[DoubleStruckCapitalU]\^*\)\
\) \[GothicCapitalD]\_\(\[DoubleStruckCapitalV]\^*\)\
\[RightDoubleBracketingBar] - \[LeftDoubleBracketingBar]\[GothicCapitalD]\_\(\
\[DoubleStruckCapitalU]\^*\)\[RightDoubleBracketingBar] \
\[LeftDoubleBracketingBar]\[GothicCapitalD]\_\(\[DoubleStruckCapitalV]\^*\)\
\[RightDoubleBracketingBar] = \(1\/\(2  
                  N\)\) \((\[GothicCapitalD]\_\(\[DoubleStruckCapitalU]\[Vee]\
\[DoubleStruckCapitalV]\) - \(\[GothicCapitalD]\_\[DoubleStruckCapitalU]\) \
\[GothicCapitalD]\_\[DoubleStruckCapitalV])\)\)\)\)], "NumberedEquation"],

Cell["\<\
Here, the disequilibria before sampling are taken as fixed.  If in \
fact they follow a distribution, we have:\
\>", "Text"],

Cell[BoxData[
    \(TextForm\`\[GothicCapitalK]\_\({{\(\[DoubleStruckCapitalU]\^*\)}, {\(\
\[DoubleStruckCapitalV]\^*\)}}, {}\) = \(\(1\/\(2  
                N\)\) \[LeftDoubleBracketingBar]\[GothicCapitalD]\_\(\
\[DoubleStruckCapitalU]\[Vee]\[DoubleStruckCapitalV]\) - \
\(\[GothicCapitalD]\_\[DoubleStruckCapitalU]\) \[GothicCapitalD]\_\
\[DoubleStruckCapitalV]\[RightDoubleBracketingBar] = \(1\/\(2  
                N\)\) \((\[GothicCapitalC]\_\({{\[DoubleStruckCapitalU]\[Vee]\
\[DoubleStruckCapitalV]}}, {}\) - \[GothicCapitalC]\_\({{\
\[DoubleStruckCapitalU]}, {\[DoubleStruckCapitalV]}}, {}\))\)\)\)], \
"NumberedEquation"],

Cell["\<\
Thus, we have a relation between the \[GothicCapitalC] (or the \
\[GothicCapitalK]) before and after sampling.  Moreover, the relation is \
closed, since second moments after sampling depend on second moments \
before.\
\>", "Text"],

Cell["\<\
\tHere, the reference points have been taken as fixed: for example, \
we might define associations after sampling relative to the reference points \
before sampling.  The change in reference point is treated separately, and \
will require an extension to ChangeContext to act on \[GothicCapitalC] as \
well as on \[GothicCapitalD], and hence to allow for random variation in the \
reference points.\
\>", "Text"],

Cell[TextData[{
  "\tSuppose we have multinomial sampling of 2N items in states ",
  Cell[BoxData[
      \(TraditionalForm\`\[Zeta]\+_\)]],
  ", from a population with frequencies ",
  Cell[BoxData[
      \(TraditionalForm\`g[\[Zeta]\+_]\)]],
  ". We assume, in general,  a continuous distribution of ",
  Cell[BoxData[
      \(TraditionalForm\`\[Zeta]\+_\)]],
  ", and sample ",
  Cell[BoxData[
      \(TraditionalForm\`n[\[Zeta]\+_]\)]],
  " items in state ",
  Cell[BoxData[
      \(TraditionalForm\`\[Zeta]\+_\)]],
  ".  (For a continuous ",
  Cell[BoxData[
      \(TraditionalForm\`\[Zeta]\+_\)]],
  ", ",
  Cell[BoxData[
      \(TraditionalForm\`n\)]],
  " is a series of delta functions).  The ",
  Cell[BoxData[
      \(TraditionalForm\`k\)]],
  "'th moment of the sampled numbers is \[LeftDoubleBracketingBar]",
  Cell[BoxData[
      \(TraditionalForm\`\(\(n[\[Zeta]\+_\_1] \[Ellipsis]n[\[Zeta]\+_\_k]\)\(\
\[RightDoubleBracketingBar]\)\)\)]],
  ".  Since the linkage disequilibria \[GothicCapitalD] are linear functions \
of the ",
  Cell[BoxData[
      \(TraditionalForm\`n\+_\)]],
  ", it is straightforward to relate the ",
  Cell[BoxData[
      \(\[LeftDoubleBracketingBar]\(\[GothicCapitalD]\_\(\
\[DoubleStruckCapitalU]\_1\%*\)\) \(\[GothicCapitalD]\_\(\
\[DoubleStruckCapitalU]\_2\%*\)\) \[Ellipsis]\[GothicCapitalD]\_\(\
\[DoubleStruckCapitalU]\_k\%*\)\[RightDoubleBracketingBar]\)]],
  " to the \[LeftDoubleBracketingBar]",
  Cell[BoxData[
      \(TraditionalForm\`\(\(n[\[Zeta]\+_\_1] \[Ellipsis]n[\[Zeta]\+_\_k]\)\(\
\[RightDoubleBracketingBar]\)\)\)]],
  ":"
}], "Text"],

Cell[BoxData[
    FormBox[
      RowBox[{\(\[LeftDoubleBracketingBar]\(\[GothicCapitalD]\_\(\
\[DoubleStruckCapitalU]\_1\%*\)\) \(\[GothicCapitalD]\_\(\
\[DoubleStruckCapitalU]\_2\%*\)\) \[Ellipsis]\[GothicCapitalD]\_\(\
\[DoubleStruckCapitalU]\_k\%*\)\[RightDoubleBracketingBar]\), "=", 
        RowBox[{\(\((2  N)\)\^\(-k\)\), 
          RowBox[{"\[Integral]", 
            RowBox[{"\[Ellipsis]", 
              RowBox[{"\[Integral]", " ", 
                
                RowBox[{\(\[Zeta]\+_\_\(\[DoubleStruckCapitalU]\_1\%*\)\), 
                  "\[Ellipsis]", \
\(\[Zeta]\+_\_\(\[DoubleStruckCapitalU]\_k\%*\)\), 
                  RowBox[{"\[LeftDoubleBracketingBar]", 
                    RowBox[{
                      
                      FormBox[\(\(n[\[Zeta]\+_\_1] \
\[Ellipsis]n[\[Zeta]\+_\_k]\)\(\[RightDoubleBracketingBar]\)\),
                        "TraditionalForm"], \(\[DifferentialD]\[Zeta]\+_\_1\),
                       "\[Ellipsis]", \
\(\[DifferentialD]\[Zeta]\+_\_k\)}]}]}]}]}]}]}]}], 
      TextForm]], "NumberedEquation"],

Cell[TextData[{
  "It is easy to show (for example, by considering the generating function \
for the ",
  Cell[BoxData[
      \(TraditionalForm\`n\+_\)]],
  ") that the k'th moment of the ",
  Cell[BoxData[
      \(TraditionalForm\`n\+_\)]],
  " is related to the number of ways of sampling ",
  Cell[BoxData[
      \(TraditionalForm\`k\)]],
  " objects with replacement, from an urn with 2N elements.  The total number \
is ",
  Cell[BoxData[
      \(TraditionalForm\`\((2  N)\)\^k\)]],
  "; the number of samples of ",
  Cell[BoxData[
      \(TraditionalForm\`k\)]],
  " distinct elements is 2N(2N-1)\[Ellipsis](2N-k+1); the number of samples \
with elements 1 and 2 the same, and the rest distinct is \
(2N-1)\[Ellipsis](2N-k+1); and so on.  Denote a sample with elements {1,2,3} \
identical, and {8,9} identical, by ",
  Cell[BoxData[
      \(TraditionalForm\`P = {{1, 2, 3}, {8, 9}}\)]],
  ".   The number of ways of choosing a sample of type ",
  Cell[BoxData[
      \(TraditionalForm\`P\)]],
  " is ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          FormBox[
            RowBox[{
              RowBox[{
                SubscriptBox[
                  FormBox["\[ScriptCapitalN]",
                    "TraditionalForm"], "P"], 
                "=", \(2 \( 
                    N \((2  N - 1)\)\) \(\[Ellipsis] \((2  N - m\_P + 
                        1)\)\)\)}], ",", " ", "where", " "}],
            "TraditionalForm"], \(m\_P\)}], TraditionalForm]]],
  " is the number of elementds in ",
  Cell[BoxData[
      \(TraditionalForm\`P\)]],
  "; ",
  Cell[BoxData[
      \(TraditionalForm\`\[Sum]\+P \[ScriptCapitalN]\_P = \((2  N)\)\^k\)]],
  ". Thus:"
}], "Text"],

Cell[TextData[{
  " ",
  Cell[BoxData[
      FormBox[
        RowBox[{\(\[LeftDoubleBracketingBar]\(\[GothicCapitalD]\_\(\
\[DoubleStruckCapitalU]\_1\%*\)\) \(\[GothicCapitalD]\_\(\
\[DoubleStruckCapitalU]\_2\%*\)\) \[Ellipsis]\[GothicCapitalD]\_\(\
\[DoubleStruckCapitalU]\_k\%*\)\[RightDoubleBracketingBar]\), "=", 
          RowBox[{\(\[Sum]\+P\), 
            RowBox[{
              RowBox[{"(", GridBox[{
                    {\(2  N\)},
                    {"m"}
                    }], ")"}], \(F\_P[\[GothicCapitalD]]\)}]}]}], 
        TraditionalForm]]]
}], "NumberedEquation"],

Cell[TextData[{
  "where ",
  Cell[BoxData[
      \(TraditionalForm\`F\_P[\[GothicCapitalD]]\)]],
  " is constructed by joining sets ",
  Cell[BoxData[
      \(TraditionalForm\`\[DoubleStruckCapitalU]\_i\)]],
  "in a way which corresponds to the structure ",
  Cell[BoxData[
      \(TraditionalForm\`\(\(P\)\(.\)\)\)]],
  "  "
}], "Text"]
},
FrontEndVersion->"4.0 for Macintosh",
ScreenRectangle->{{0, 1152}, {0, 748}},
WindowSize->{520, 626},
WindowMargins->{{245, Automatic}, {Automatic, 46}},
StyleDefinitions -> "HelpBrowser.nb",
MacintoshSystemPageSetup->"\<\
00h0001804P000000b02<?oaonl3>@91H`85N0?N0@00005X0FP000003j0:l001
0@00I00100000@0200000BL?00400000000000000000010000000000000@0?ne
oj/@7@]500P1000000000000000001T1\>"
]


(***********************************************************************
Cached data follows.  If you edit this Notebook file directly, not using
Mathematica, you must remove the line containing CacheID at the top of 
the file.  The cache data will then be recreated when you save this file 
from within Mathematica.
***********************************************************************)

(*CellTagsOutline
CellTagsIndex->{
  "Describing a distribution"->{
    Cell[2171, 60, 110, 1, 24, "SubsubsectionIcon",
      CellTags->"Describing a distribution"]},
  "Equations for the moments"->{
    Cell[6142, 146, 95, 1, 24, "SubsubsectionIcon",
      CellTags->"Equations for the moments"]},
  "Cumulants and moments"->{
    Cell[7540, 173, 87, 1, 24, "SubsubsectionIcon",
      CellTags->"Cumulants and moments"]},
  "Changing reference points"->{
    Cell[8180, 187, 95, 1, 70, "SubsubsectionIcon",
      CellTags->"Changing reference points"]},
  "Random sampling"->{
    Cell[13260, 277, 75, 1, 70, "SubsubsectionIcon",
      CellTags->"Random sampling"]}
  }
*)

(*CellTagsIndex
CellTagsIndex->{
  {"Describing a distribution", 22894, 530},
  {"Equations for the moments", 23026, 533},
  {"Cumulants and moments", 23154, 536},
  {"Changing reference points", 23282, 539},
  {"Random sampling", 23404, 542}
  }
*)

(*NotebookFileOutline
Notebook[{
Cell[1717, 49, 38, 0, 36, "SubsectionIcon"],
Cell[1758, 51, 410, 7, 64, "Text"],
Cell[2171, 60, 110, 1, 24, "SubsubsectionIcon",
  CellTags->"Describing a distribution"],
Cell[2284, 63, 2890, 60, 167, "Text"],
Cell[5177, 125, 962, 19, 50, "Text"],
Cell[6142, 146, 95, 1, 24, "SubsubsectionIcon",
  CellTags->"Equations for the moments"],
Cell[6240, 149, 1297, 22, 150, "Text"],
Cell[7540, 173, 87, 1, 24, "SubsubsectionIcon",
  CellTags->"Cumulants and moments"],
Cell[7630, 176, 547, 9, 78, "Text"],
Cell[8180, 187, 95, 1, 70, "SubsubsectionIcon",
  CellTags->"Changing reference points"],
Cell[8278, 190, 157, 4, 70, "Text"],
Cell[8438, 196, 477, 7, 70, "NumberedEquation"],
Cell[8918, 205, 271, 5, 70, "Text"],
Cell[9192, 212, 3505, 50, 70, "NumberedEquation"],
Cell[12700, 264, 557, 11, 70, "Text"],
Cell[13260, 277, 75, 1, 70, "SubsubsectionIcon",
  CellTags->"Random sampling"],
Cell[13338, 280, 389, 8, 70, "Text"],
Cell[13730, 290, 612, 18, 70, "Text"],
Cell[14345, 310, 987, 14, 70, "NumberedEquation"],
Cell[15335, 326, 134, 3, 70, "Text"],
Cell[15472, 331, 632, 10, 70, "NumberedEquation"],
Cell[16107, 343, 242, 5, 70, "Text"],
Cell[16352, 350, 422, 7, 70, "Text"],
Cell[16777, 359, 1592, 44, 70, "Text"],
Cell[18372, 405, 1057, 22, 70, "NumberedEquation"],
Cell[19432, 429, 1679, 48, 70, "Text"],
Cell[21114, 479, 585, 15, 70, "NumberedEquation"],
Cell[21702, 496, 338, 11, 70, "Text"]
}
]
*)




(***********************************************************************
End of Mathematica Notebook file.
***********************************************************************)

