(***********************************************************************

                    Mathematica-Compatible Notebook

This notebook can be used on any computer system with Mathematica 4.0,
MathReader 4.0, or any compatible application. The data for the notebook 
starts with the line containing stars above.

To get the notebook into a Mathematica-compatible application, do one of 
the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing the 
word CacheID, otherwise Mathematica-compatible applications may try to 
use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
***********************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[     17909,        552]*)
(*NotebookOutlinePosition[     19423,        598]*)
(*  CellTagsIndexPosition[     19221,        589]*)
(*WindowFrame->Normal*)



Notebook[{
Cell["Full diploid genotypes & observed genotypes", "SubsectionIcon"],

Cell[TextData[Cell[BoxData[
    FormBox[GridBox[{
          {\(PossibleDiploidGenotypes[{0, 1, 
                0}]\), \(gives\ the\ list\ of\ actual\ genotypes, \ {{{0, 1, 
                  0}, {0, 0, 0}}, {{{0, 0, 0}, {0, 1, 0}}}, \ 
              consistent\ with\ this\ diploid\ \(\(genotype\)\(.\)\)\)}
          }], TraditionalForm]]]], "DefinitionBox",
  CellTags->"PossibleDiploidGenotypes"],

Cell["\<\
These are the set of full diploid genotypes that could generate the \
observed genotype {1,1,2}:\
\>", "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[
    \(pdg = PossibleDiploidGenotypes[{1, 1, 2}]; pdg // TableForm\)], "Input",\

  CellLabel->"In[103]:="],

Cell[BoxData[
    InterpretationBox[GridBox[{
          {GridBox[{
                {"1"},
                {"1"},
                {"1"}
                },
              RowSpacings->0.25,
              ColumnSpacings->1,
              RowAlignments->Baseline,
              ColumnAlignments->{Left}], GridBox[{
                {"0"},
                {"0"},
                {"1"}
                },
              RowSpacings->0.25,
              ColumnSpacings->1,
              RowAlignments->Baseline,
              ColumnAlignments->{Left}]},
          {GridBox[{
                {"0"},
                {"1"},
                {"1"}
                },
              RowSpacings->0.25,
              ColumnSpacings->1,
              RowAlignments->Baseline,
              ColumnAlignments->{Left}], GridBox[{
                {"1"},
                {"0"},
                {"1"}
                },
              RowSpacings->0.25,
              ColumnSpacings->1,
              RowAlignments->Baseline,
              ColumnAlignments->{Left}]},
          {GridBox[{
                {"1"},
                {"0"},
                {"1"}
                },
              RowSpacings->0.25,
              ColumnSpacings->1,
              RowAlignments->Baseline,
              ColumnAlignments->{Left}], GridBox[{
                {"0"},
                {"1"},
                {"1"}
                },
              RowSpacings->0.25,
              ColumnSpacings->1,
              RowAlignments->Baseline,
              ColumnAlignments->{Left}]},
          {GridBox[{
                {"0"},
                {"0"},
                {"1"}
                },
              RowSpacings->0.25,
              ColumnSpacings->1,
              RowAlignments->Baseline,
              ColumnAlignments->{Left}], GridBox[{
                {"1"},
                {"1"},
                {"1"}
                },
              RowSpacings->0.25,
              ColumnSpacings->1,
              RowAlignments->Baseline,
              ColumnAlignments->{Left}]}
          },
        RowSpacings->1,
        ColumnSpacings->3,
        RowAlignments->Baseline,
        ColumnAlignments->{Left}],
      TableForm[ {{{1, 1, 1}, {0, 0, 1}}, {{0, 1, 1}, {1, 0, 1}}, {{1, 0, 
        1}, {0, 1, 1}}, {{0, 0, 1}, {1, 1, 1}}}]]], "Output",
  CellLabel->"Out[103]//TableForm="]
}, Open  ]],

Cell["\<\
Here, {1,1,2} indicates heterozygotes at the first two loci, and a \
{1,1} homozygote at the third locus.\
\>", "Text"],

Cell[TextData[{
  "Note: ",
  StyleBox["this function is a special case of ",
    FontWeight->"Plain"],
  ButtonBox["PossibleGenotypes[]",
    ButtonData:>{"Diploid genotypes", "PossibleGenotypes"},
    ButtonStyle->"AddOnsLink",
    ButtonNote->"PossibleGenotypes[]"],
  StyleBox[", which allows for multiple alleles. ",
    FontWeight->"Plain"]
}], "Text",
  FontWeight->"Bold"],

Cell[TextData[Cell[BoxData[
    FormBox[GridBox[{
          {\(GenotypeFrequencyConvert[gM, \ 
              n]\), \(converts\ the\ 2\^\(\(n\)\(\ \)\)\[Times]2\^n\ matrix\ \
of\ full\ diploid\ genotype\ frequencies\ to\ the\ 3\^n\ vector\ of\ observed\
\ diploid\ frequencies\)},
          {\(\(GenotypeFrequencyConvert[n]\)[
              gM]\), \(is\ a\ compiled\ \(\(version\)\(.\)\)\)}
          }], TraditionalForm]]]], "DefinitionBox",
  CellTags->"GenotypeFrequencyConvert"],

Cell["\<\
This is a list of the 8 haploid genotype frequencies for a \
population in LE with allele frequencies {0.2,0.3,0.4}:\
\>", "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[
    \(n = 3; 
    gf = \(HaploidGenotypeFrequency[#, 
            Array[0 &, 2\^n - n - 1], {0.2, 0.3, 0.4}] &\) /@ 
        HaploidTypes[n]\)], "Input",
  CellLabel->"In[221]:="],

Cell[BoxData[
    \({0.33599999999999997`, 0.22399999999999998`, 0.144`, 0.096`, 
      0.08399999999999999`, 0.055999999999999994`, 0.036`, 
      0.024`}\)], "Output",
  CellLabel->"Out[221]="]
}, Open  ]],

Cell["These are the diploid frequencies, assuming HW:", "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[
    \(df = Outer[Times, gf, gf]; df // MatrixForm\)], "Input",
  CellLabel->"In[222]:="],

Cell[BoxData[
    TagBox[
      RowBox[{"(", "\[NoBreak]", GridBox[{
            {"0.11289599999999998`", "0.07526399999999998`", 
              "0.04838399999999999`", "0.032256`", "0.028223999999999996`", 
              "0.018815999999999996`", "0.012095999999999997`", "0.008064`"},
            {"0.07526399999999998`", "0.05017599999999999`", 
              "0.03225599999999999`", "0.021504`", "0.018815999999999996`", 
              "0.012543999999999998`", "0.008063999999999998`", "0.005376`"},
            {"0.04838399999999999`", "0.03225599999999999`", 
              "0.020735999999999997`", "0.013824`", "0.012095999999999997`", 
              "0.008063999999999998`", "0.005183999999999999`", "0.003456`"},
            {"0.032256`", "0.021504`", "0.013824`", "0.009216`", "0.008064`", 
              "0.005376`", "0.003456`", "0.002304`"},
            {"0.028223999999999996`", "0.018815999999999996`", 
              "0.012095999999999997`", "0.008064`", "0.007055999999999999`", 
              "0.004703999999999999`", "0.0030239999999999993`", 
              "0.002016`"},
            {"0.018815999999999996`", "0.012543999999999998`", 
              "0.008063999999999998`", "0.005376`", "0.004703999999999999`", 
              "0.0031359999999999995`", "0.0020159999999999996`", 
              "0.001344`"},
            {"0.012095999999999997`", "0.008063999999999998`", 
              "0.005183999999999999`", "0.003456`", "0.0030239999999999993`", 
              "0.0020159999999999996`", "0.0012959999999999998`", 
              "0.000864`"},
            {"0.008064`", "0.005376`", "0.003456`", "0.002304`", "0.002016`", 
              "0.001344`", "0.000864`", "0.000576`"}
            }], "\[NoBreak]", ")"}],
      (MatrixForm[ #]&)]], "Output",
  CellLabel->"Out[222]//MatrixForm="]
}, Open  ]],

Cell[TextData[{
  "This converts the ",
  Cell[BoxData[
      \(TraditionalForm\`2\^3\[Times]2\^3\)]],
  "matrix to a ",
  Cell[BoxData[
      \(TraditionalForm\`3\^3\)]],
  "long list of observed genotype frequencies:"
}], "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[
    \(GenotypeFrequencyConvert[df, 3]\)], "Input",
  CellLabel->"In[225]:="],

Cell[BoxData[
    \({0.`\ Second, {0.11289599999999998`, 0.15052799999999997`, 
        0.05017599999999999`, 0.09676799999999998`, 0.12902399999999997`, 
        0.043008`, 0.020735999999999997`, 0.027648`, 0.009216`, 
        0.05644799999999999`, 0.07526399999999998`, 0.025087999999999996`, 
        0.04838399999999999`, 0.06451199999999999`, 0.021504`, 
        0.010367999999999999`, 0.013824`, 0.004608`, 0.007055999999999999`, 
        0.009407999999999998`, 0.0031359999999999995`, 0.006047999999999999`, 
        0.008063999999999998`, 0.002688`, 0.0012959999999999998`, 0.001728`, 
        0.000576`}}\)], "Output",
  CellLabel->"Out[225]="]
}, Open  ]],

Cell["These are in the same order as in DiploidTypes[].", "Text"],

Cell[TextData[{
  Cell[BoxData[
      \(TraditionalForm\`\(GenotypeFrequencyConvert[n]\)[df]\)]],
  " is a compiled version, which uses ",
  Cell[BoxData[
      \(TraditionalForm\`PositionsMatrix[n] . Flatten[gM]\)]],
  ".  It is not necessarily faster ,a nd uses much more memory.  (See next \
section). "
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(GenotypeFrequencyConvert[3]\)[df]\)], "Input",
  CellLabel->"In[226]:="],

Cell[BoxData[
    \({0.`\ Second, {0.11289599999999998`, 0.15052799999999997`, 
        0.05017599999999999`, 0.09676799999999998`, 0.12902399999999997`, 
        0.043008`, 0.020735999999999997`, 0.027648`, 0.009216`, 
        0.05644799999999999`, 0.07526399999999998`, 0.025087999999999996`, 
        0.04838399999999999`, 0.06451199999999999`, 0.021504`, 
        0.010367999999999999`, 0.013824`, 0.004608`, 0.007055999999999999`, 
        0.009407999999999998`, 0.0031359999999999995`, 0.006047999999999999`, 
        0.008063999999999998`, 0.002688`, 0.0012959999999999998`, 0.001728`, 
        0.000576`}}\)], "Output",
  CellLabel->"Out[226]="]
}, Open  ]],

Cell[TextData[Cell[BoxData[
    FormBox[GridBox[{
          {\(PositionsList[
              n]\), \(gives\ the\ positions\ in\ the\ matrix\ of\ genotype\ \
frequencies\ of\ the\ elements\ needed\ to\ give\ the\ diploid\ \
\(\(frequencies\)\(.\)\)\)},
          {\(PositionsList[X, 
              n]\), \(gives\ the\ position\ of\ the\ diploid\ genotype\ \(\(X\
\)\(.\)\)\)},
          {GridBox[{
                {\(PositionsList[j, n]\), \(gives\ the\ position\ of\ the\ j' 
                    th\ diploid\ genotype\)}
                }], "\[Placeholder]"}
          }], TraditionalForm]]]], "DefinitionBox",
  CellTags->"PositionsList"],

Cell["\<\
The observed diploid genotype {1,2,1} can be produced in four ways; \
however, two of these are equivalent if there is symmetry across the sexes:\
\
\>", "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[
    \(PossibleDiploidGenotypes[{1, 2, 1}]\)], "Input",
  CellLabel->"In[13]:="],

Cell[BoxData[
    \({{{1, 1, 0}, {0, 1, 1}}, {{0, 1, 0}, {1, 1, 1}}, {{1, 1, 1}, {0, 1, 
          0}}, {{0, 1, 1}, {1, 1, 0}}}\)], "Output",
  CellLabel->"Out[13]="]
}, Closed]],

Cell[TextData[{
  "This gives the positions of the two distinct possible genotypes in the ",
  Cell[BoxData[
      \(TraditionalForm\`2\^3\[Times]2\^3\)]],
  "matrix of genotype frequencies:"
}], "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[
    \(PositionsList[{1, 2, 1}, 3]\)], "Input",
  CellLabel->"In[12]:="],

Cell[BoxData[
    \({{3, 8}, {4, 7}}\)], "Output",
  CellLabel->"Out[12]="]
}, Closed]],

Cell["\<\
This gives the positions of all the 27 possible diploid \
genotypes:\
\>", "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[
    \(PositionsList[3]\)], "Input",
  CellLabel->"In[14]:="],

Cell[BoxData[
    \({{{1, 1}}, {{1, 2}}, {{2, 2}}, {{1, 3}}, {{1, 4}, {2, 3}}, {{2, 
          4}}, {{3, 3}}, {{3, 4}}, {{4, 4}}, {{1, 5}}, {{1, 6}, {2, 5}}, {{2, 
          6}}, {{1, 7}, {3, 5}}, {{1, 8}, {2, 7}, {3, 6}, {4, 5}}, {{2, 
          8}, {4, 6}}, {{3, 7}}, {{3, 8}, {4, 7}}, {{4, 8}}, {{5, 5}}, {{5, 
          6}}, {{6, 6}}, {{5, 7}}, {{5, 8}, {6, 7}}, {{6, 8}}, {{7, 7}}, {{7, 
          8}}, {{8, 8}}}\)], "Output",
  CellLabel->"Out[14]="]
}, Closed]],

Cell["PositionsList[] is used by GenotypeFrequencyConvert[].", "Text"],

Cell[TextData[Cell[BoxData[
    FormBox[
      RowBox[{GridBox[{
            {\(PositionsMatrix[n]\), \(is\ a\ 3\^n\[Times]\(2\^\(2  n\)\) 
                array\ of\ 0, \ 1, \ 
              2  \[Ellipsis]\ which\ correpsonds\ to\ PositionsList[n]\)}
            }], " "}], TraditionalForm]]]], "DefinitionBox",
  CellTags->"PositionsMatrix"],

Cell["\<\
Each row gives the vector which must multiply the flattened matrix \
of full genotype frequencies to give the observed diploid frequencies.  \
\
\>", "Text"],

Cell["For 2 loci, this is a 9\[Times]16 array:", "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[
    \(PositionsMatrix[2] // MatrixForm\)], "Input",
  CellLabel->"In[193]:="],

Cell[BoxData[
    TagBox[
      RowBox[{"(", "\[NoBreak]", GridBox[{
            {"1", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", 
              "0", "0", "0"},
            {"0", "2", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", 
              "0", "0", "0"},
            {"0", "0", "0", "0", "0", "1", "0", "0", "0", "0", "0", "0", "0", 
              "0", "0", "0"},
            {"0", "0", "2", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", 
              "0", "0", "0"},
            {"0", "0", "0", "2", "0", "0", "2", "0", "0", "0", "0", "0", "0", 
              "0", "0", "0"},
            {"0", "0", "0", "0", "0", "0", "0", "2", "0", "0", "0", "0", "0", 
              "0", "0", "0"},
            {"0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "1", "0", "0", 
              "0", "0", "0"},
            {"0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "2", "0", 
              "0", "0", "0"},
            {"0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", 
              "0", "0", "1"}
            }], "\[NoBreak]", ")"}],
      (MatrixForm[ #]&)]], "Output",
  CellLabel->"Out[193]//MatrixForm="]
}, Open  ]],

Cell["\<\
These are a full set of diploid frequencies for 6 loci, assuming \
HW:\
\>", "MathCaption"],

Cell[BoxData[{
    \(n = 6; 
    gf = \(HaploidGenotypeFrequency[#, 
            Array[0 &, 2\^n - n - 1], {0.2, 0.3, 0.4, 0.2, 0.3, 0.4}] &\) /@ 
        HaploidTypes[n]; \), "\n", 
    \(df = Outer[Times, gf, gf]; \)}], "Input",
  CellLabel->"In[207]:="],

Cell[TextData[{
  "This converts the ",
  Cell[BoxData[
      \(TraditionalForm\`2\^3\[Times]2\^3\)]],
  "matrix to a ",
  Cell[BoxData[
      \(TraditionalForm\`3\^3\)]],
  "long list of observed genotype frequencies:"
}], "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[
    \(Timing[obs2 = PositionsMatrix[6] . Flatten[df]; ]\)], "Input",
  CellLabel->"In[212]:="],

Cell[BoxData[
    \({0.9166666666667425`\ Second, Null}\)], "Output",
  CellLabel->"Out[212]="]
}, Open  ]],

Cell[TextData[{
  "For this case, using ",
  Cell[BoxData[
      \(TraditionalForm\`PositionsMatrix[n] . Flatten[df]\)]],
  " is much ",
  StyleBox["slower",
    FontSlant->"Italic"],
  " than using ",
  Cell[BoxData[
      \(TraditionalForm\`GenotypeFrequencyConvert[n]\)]],
  ":"
}], "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[
    \(Timing[obs = GenotypeFrequencyConvert[df, 6]; ]\)], "Input",
  CellLabel->"In[209]:="],

Cell[BoxData[
    \({0.049999999999954525`\ Second, Null}\)], "Output",
  CellLabel->"Out[209]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(Union[obs - obs2]\)], "Input",
  CellLabel->"In[214]:="],

Cell[BoxData[
    \({0.`}\)], "Output",
  CellLabel->"Out[214]="]
}, Open  ]],

Cell["\<\
However, less symmetrical arrays are much faster to calculate.  \
This example is for diploid frequencies that involve some linkage \
disequilibrium:\
\>", "MathCaption"],

Cell[BoxData[
    RowBox[{
      RowBox[{"dl", "=", 
        RowBox[{\(DiploidGenotypeFrequencyList[6]\), "[", 
          
          RowBox[{\({0.2, 0.3, 0.4, 0.2, 0.3, 0.4}\), 
            ",", \({1, 1, 1, 1, 1, 1}\), ",", 
            RowBox[{"(", GridBox[{
                  {"1", "0", "0.02", "0", "0", "0", "0"},
                  {"0", "0.01", "0", "0", "0", "0", "0"},
                  {"0.02", "0", "0", "0", "0", "0", "0"},
                  {"0", "0", "0", "0", "0", "0", "0"},
                  {"0", "0", "0", "0", "0", "0", "0"},
                  {"0", "0", "0", "0", "0", "0", "0"},
                  {"0", "0", "0", "0", "0", "0", "0"}
                  }], ")"}]}], "]"}]}], ";"}]], "Input"],

Cell[CellGroupData[{

Cell[BoxData[
    \(Timing[obs = GenotypeFrequencyConvert[dl, 6]; ]\)], "Input",
  CellLabel->"In[216]:="],

Cell[BoxData[
    \({3.099999999999909`\ Second, Null}\)], "Output",
  CellLabel->"Out[216]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(Timing[obs2 = PositionsMatrix[6] . Flatten[dl]; ]\)], "Input",
  CellLabel->"In[217]:="],

Cell[BoxData[
    \({0.933333333333394`\ Second, Null}\)], "Output",
  CellLabel->"Out[217]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(Union[obs - obs2]\)], "Input",
  CellLabel->"In[218]:="],

Cell[BoxData[
    \({0.`}\)], "Output",
  CellLabel->"Out[218]="]
}, Open  ]]
},
FrontEndVersion->"4.0 for Macintosh",
ScreenRectangle->{{0, 1152}, {0, 748}},
WindowSize->{520, 626},
WindowMargins->{{245, Automatic}, {Automatic, 46}},
StyleDefinitions -> "HelpBrowser.nb",
MacintoshSystemPageSetup->"\<\
00h0001804P000000b02<?oaonl3>@91H`85N0?N0@00005X0FP000003j0:l001
0@00I00100000@0200000BL?00400000000000000000010000000000000@0?ne
oj/@7@]500P1000000000000000001T1\>"
]


(***********************************************************************
Cached data follows.  If you edit this Notebook file directly, not using
Mathematica, you must remove the line containing CacheID at the top of 
the file.  The cache data will then be recreated when you save this file 
from within Mathematica.
***********************************************************************)

(*CellTagsOutline
CellTagsIndex->{
  "PossibleDiploidGenotypes"->{
    Cell[1789, 51, 400, 7, 68, "DefinitionBox",
      CellTags->"PossibleDiploidGenotypes"]},
  "GenotypeFrequencyConvert"->{
    Cell[5339, 170, 481, 9, 86, "DefinitionBox",
      CellTags->"GenotypeFrequencyConvert"]},
  "PositionsList"->{
    Cell[10624, 303, 638, 14, 70, "DefinitionBox",
      CellTags->"PositionsList"]},
  "PositionsMatrix"->{
    Cell[12903, 378, 343, 7, 70, "DefinitionBox",
      CellTags->"PositionsMatrix"]}
  }
*)

(*CellTagsIndex
CellTagsIndex->{
  {"PossibleDiploidGenotypes", 18758, 573},
  {"GenotypeFrequencyConvert", 18884, 576},
  {"PositionsList", 19000, 579},
  {"PositionsMatrix", 19109, 582}
  }
*)

(*NotebookFileOutline
Notebook[{
Cell[1717, 49, 69, 0, 36, "SubsectionIcon"],
Cell[1789, 51, 400, 7, 68, "DefinitionBox",
  CellTags->"PossibleDiploidGenotypes"],
Cell[2192, 60, 127, 3, 42, "MathCaption"],

Cell[CellGroupData[{
Cell[2344, 67, 120, 3, 42, "Input"],
Cell[2467, 72, 2342, 77, 175, "Output"]
}, Open  ]],
Cell[4824, 152, 129, 3, 22, "Text"],
Cell[4956, 157, 380, 11, 38, "Text"],
Cell[5339, 170, 481, 9, 86, "DefinitionBox",
  CellTags->"GenotypeFrequencyConvert"],
Cell[5823, 181, 147, 3, 42, "MathCaption"],

Cell[CellGroupData[{
Cell[5995, 188, 193, 5, 58, "Input"],
Cell[6191, 195, 195, 4, 20, "Output"]
}, Open  ]],
Cell[6401, 202, 70, 0, 22, "MathCaption"],

Cell[CellGroupData[{
Cell[6496, 206, 102, 2, 27, "Input"],
Cell[6601, 210, 1808, 30, 149, "Output"]
}, Open  ]],
Cell[8424, 243, 238, 8, 70, "MathCaption"],

Cell[CellGroupData[{
Cell[8687, 255, 90, 2, 70, "Input"],
Cell[8780, 259, 653, 10, 70, "Output"]
}, Open  ]],
Cell[9448, 272, 65, 0, 70, "Text"],
Cell[9516, 274, 318, 8, 70, "Text"],

Cell[CellGroupData[{
Cell[9859, 286, 94, 2, 70, "Input"],
Cell[9956, 290, 653, 10, 70, "Output"]
}, Open  ]],
Cell[10624, 303, 638, 14, 70, "DefinitionBox",
  CellTags->"PositionsList"],
Cell[11265, 319, 178, 4, 70, "MathCaption"],

Cell[CellGroupData[{
Cell[11468, 327, 93, 2, 70, "Input"],
Cell[11564, 331, 166, 3, 70, "Output"]
}, Closed]],
Cell[11745, 337, 210, 5, 70, "MathCaption"],

Cell[CellGroupData[{
Cell[11980, 346, 85, 2, 70, "Input"],
Cell[12068, 350, 75, 2, 70, "Output"]
}, Closed]],
Cell[12158, 355, 99, 3, 70, "MathCaption"],

Cell[CellGroupData[{
Cell[12282, 362, 74, 2, 70, "Input"],
Cell[12359, 366, 456, 7, 70, "Output"]
}, Closed]],
Cell[12830, 376, 70, 0, 70, "Text"],
Cell[12903, 378, 343, 7, 70, "DefinitionBox",
  CellTags->"PositionsMatrix"],
Cell[13249, 387, 167, 4, 70, "Text"],
Cell[13419, 393, 63, 0, 70, "MathCaption"],

Cell[CellGroupData[{
Cell[13507, 397, 91, 2, 70, "Input"],
Cell[13601, 401, 1160, 23, 70, "Output"]
}, Open  ]],
Cell[14776, 427, 101, 3, 70, "MathCaption"],
Cell[14880, 432, 256, 6, 70, "Input"],
Cell[15139, 440, 238, 8, 70, "MathCaption"],

Cell[CellGroupData[{
Cell[15402, 452, 108, 2, 70, "Input"],
Cell[15513, 456, 95, 2, 70, "Output"]
}, Open  ]],
Cell[15623, 461, 300, 11, 70, "MathCaption"],

Cell[CellGroupData[{
Cell[15948, 476, 106, 2, 70, "Input"],
Cell[16057, 480, 97, 2, 70, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[16191, 487, 76, 2, 70, "Input"],
Cell[16270, 491, 65, 2, 70, "Output"]
}, Open  ]],
Cell[16350, 496, 180, 4, 70, "MathCaption"],
Cell[16533, 502, 709, 15, 70, "Input"],

Cell[CellGroupData[{
Cell[17267, 521, 106, 2, 70, "Input"],
Cell[17376, 525, 94, 2, 70, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[17507, 532, 108, 2, 70, "Input"],
Cell[17618, 536, 94, 2, 70, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[17749, 543, 76, 2, 70, "Input"],
Cell[17828, 547, 65, 2, 70, "Output"]
}, Open  ]]
}
]
*)




(***********************************************************************
End of Mathematica Notebook file.
***********************************************************************)

