(***********************************************************************

                    Mathematica-Compatible Notebook

This notebook can be used on any computer system with Mathematica 4.0,
MathReader 4.0, or any compatible application. The data for the notebook 
starts with the line containing stars above.

To get the notebook into a Mathematica-compatible application, do one of 
the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing the 
word CacheID, otherwise Mathematica-compatible applications may try to 
use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
***********************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[     44467,       1076]*)
(*NotebookOutlinePosition[     45526,       1110]*)
(*  CellTagsIndexPosition[     45435,       1104]*)
(*WindowFrame->Normal*)



Notebook[{

Cell[CellGroupData[{
Cell["Estimating the matrix of cumulants or moments", "SubsectionIcon"],

Cell[TextData[{
  "The state of a population can be represented in terms of within-genome \
moments involving a set of ",
  Cell[BoxData[
      \(TraditionalForm\`j\)]],
  ">2 loci, and between-genome moments involving ",
  Cell[BoxData[
      \(TraditionalForm\`j\ loci\ from\ one\ genome, \ and\ k\)]],
  " from the other.  More compactly, one can write a matrix of moments ",
  Cell[BoxData[
      \(TraditionalForm\`c\_\(j, k\)\)]],
  "  ",
  Cell[BoxData[
      \(TraditionalForm\`\((j, k = 0  \[Ellipsis]\ n)\)\)]],
  "; necessarily, ",
  Cell[BoxData[
      \(TraditionalForm\`c\_\(0, 0\) = \(1\ and\ c\_\(1, 0\) = \(c\_\(0, 1\) \
= 0. \)\)\)]],
  "  It The simplest matrix is for a population in Hardy-Weinberg proportions \
and linkage equilibrium:"
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(cc = Array[0 &, {5, 5}]; 
    cc\[LeftDoubleBracket]1, 1\[RightDoubleBracket] = 1; 
    cc // MatrixForm\)], "Input",
  CellLabel->"In[4]:="],

Cell["", "Output"]
}, Closed]],

Cell["\<\
In this simplest case, the matrices of moments and cumulants are \
identical.  In general, however, the matrix of cumulants is preferable: with \
random union of gametes, between-genome cumulants are zero, whereas the \
between-genome moments are not.  The default for MetropolisDisequilibrium[] \
is therefore to fit the matrix of cumulants.\
\>", "Text"],

Cell[TextData[Cell[BoxData[
    FormBox[GridBox[{
          {
            RowBox[{"MetropolisDisequilibrium", "[", 
              RowBox[{"site", ",", "   ", "T", ",", 
                RowBox[{"{", 
                  RowBox[{
                    StyleBox["ntries",
                      FontSlant->"Italic"], ",", 
                    StyleBox["nprint",
                      FontSlant->"Italic"]}], "}"}], 
                ",", \(\({Log[
                      L], {{{p\_1,  .. }}, {{{\[Delta]\_1,  .. }}, {{c\_\(0, \
0\),  ... }}, {{{\[CapitalDelta]p\_1, \[Ellipsis]}}, \
{{\[CapitalDelta]\[Delta]p\_1, \[Ellipsis]}}, {{\[CapitalDelta]c\_\(0, 0\), \
\[Ellipsis]}, \[Ellipsis]}}\)\(]\)\)}]}], \(applies\ the\ Metropolis\ \
algorithm, \ 
            using\ temperature\ T\ and\ \ a\ matrix\ of\ cumulants . \ \ The\ \
list\ \ {{{\[CapitalDelta]p\_1, \[Ellipsis]}}, {{\[CapitalDelta]\[Delta]p\_1, \
\[Ellipsis]}}, {{\[CapitalDelta]c\_\(0, 0\), \[Ellipsis]}, \[Ellipsis]}}\ \
gives\ the\ initial\ step\ sizes; \ to\ fix\ some\ variables, \ 
            set\ entries\ to\ 0. \ It\ is\ essential\ that\ \
\[CapitalDelta]c\_\(0, 0\), \ \[CapitalDelta]c\_\(0, 1\), \ \
\[CapitalDelta]c\_\(1, 0\)\ are\ zero . \ \ Returns\ a\ list\ of\ the\ same\ \
form\ as\ its\ \(\(argument\)\(.\)\)\)}
          }], TraditionalForm]]]], "DefinitionBox",
  CellTags->"MetropolisDisequilibrium"],

Cell[TextData[{
  "This takes the initial step size for the allele frequencies as  ",
  Cell[BoxData[
      \(0.05 \@\( pl \((1 - pl)\)\)\)]],
  ", and for the matrix of cumulants from InitialStep[]. (Not ideal, since \
InitialStep[] gives bounds on moments; however, the two are equivalent for \
HWLE, as assumed for the initial state here).  The divergences are fixed at \
\[Delta]p=1 for all loci by setting the corresponding step sizes to zero.  \
Note that the lists of allele frequencies and divergences must appear within \
double brackets.  First, run at ",
  Cell[BoxData[
      \(TraditionalForm\`T = 1\)]],
  " for 500 cycles:"
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(pl = \(\(AlleleFrequencyTable[1063, 4] // Transpose\) // N\) // 
        Last; \[Delta]p = {1, 1, 1, 1};\), "\n", 
    \(\(is = InitialStep[pl, \[Delta]p, cc];\)\), "\n", 
    \(\(met = {L, {{pl}, {{1, 1, 1, 1}}, 
            cc}, {{0.05 \@\( pl \((1 - pl)\)\)}, {{0, 0, 0, 0}}, 
            is}};\)\), "\n", 
    \(MetropolisDisequilibrium[1063, 1, {500, 100}, met]\)}], "Input",
  CellLabel->"In[61]:="],

Cell["", "Print"],

Cell["", "Print"],

Cell["", "Print"],

Cell["", "Print"],

Cell["", "Print"],

Cell["", "Output"]
}, Closed]],

Cell["\<\
This gives a random walk which approaches the optimum.  Next, run \
for 500 cycles at T=0.5, and then climb uphill to the MLE for 200 \
cycles:\
\>", "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(met = 
        MetropolisDisequilibrium[1063, 0.5, {500, 100}, met];\)\), "\n", 
    \(met = MetropolisDisequilibrium[1063, 0, {200, 100}, met]\)}], "Input",
  CellLabel->"In[62]:="],

Cell["", "Print"],

Cell["", "Print"],

Cell["", "Print"],

Cell["", "Print"],

Cell["", "Print"],

Cell["", "Print"],

Cell["", "Print"],

Cell["", "Output"]
}, Closed]],

Cell[TextData[{
  "The maximum likelihood is -30.91.  This is associated with ",
  Cell[BoxData[
      \(TraditionalForm\`3\^4 - 1 - 4 - \)]],
  "13=63 ",
  StyleBox["d.f",
    FontSlant->"Italic"],
  ". (since there are ",
  Cell[BoxData[
      \(TraditionalForm\`\(\(3\^4\) \(observed\)\(\ \)\)\)]],
  "genotype frequencies, 4 allele frequencies, and 13 cumulants).  The \
maximum likelihood is distributed approximately as ",
  Cell[BoxData[
      \(TraditionalForm\`1\/2\)]],
  Cell[BoxData[
      \(TraditionalForm\`\[Chi]\_63\%2\)]],
  "; hence, this model fits adequately."
}], "Text"],

Cell["This is the MLE for the matrix of cumulants:", "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[
    \(met\[LeftDoubleBracket]2, 3\[RightDoubleBracket] // 
      MatrixForm\)], "Input",
  CellLabel->"In[65]:="],

Cell[BoxData[
    TagBox[
      RowBox[{"(", GridBox[{
            {"1", "0", 
              "0.0348831558912528016`", \(-0.00848239094186541464`\), \
\(-0.00118471820488195401`\)},
            {"0", 
              "0.0464456459785946584`", \(-0.00434131417169414302`\), \
\(-0.00377906809035033974`\), "0.00160125855735155582`"},
            {
              "0.0348831558912528016`", \(-0.00434131417169414302`\), \
\(-0.00312112782592878845`\), "0.00174985792243318432`", 
              "0.000899555896628374007`"},
            {\(-0.00848239094186541464`\), \(-0.00377906809035033974`\), 
              "0.00174985792243318432`", 
              "0.000849144007797611344`", \(-0.00136684662823027913`\)},
            {\(-0.00118471820488195401`\), "0.00160125855735155582`", 
              "0.000899555896628374007`", \(-0.00136684662823027913`\), \
\(-0.000749940890586429542`\)}
            }], ")"}],
      (MatrixForm[ #]&)]], "Output",
  CellLabel->"Out[65]//MatrixForm="]
}, Open  ]],

Cell["This compares the actual with the MLE allele frequencies:", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \({\(\(pTable[1063, 4] // Transpose\) // N\) // Last, 
        met\[LeftDoubleBracket]2, 1, 1\[RightDoubleBracket]} // 
      TableForm\)], "Input",
  CellLabel->"In[64]:="],

Cell[BoxData[
    TagBox[GridBox[{
          {"0.391891891891891894`", "0.175675675675675684`", 
            "0.324324324324324342`", "0.310810810810810789`"},
          {"0.39180756298013236`", "0.243477996110357652`", 
            "0.316077775415606554`", "0.261447954153204831`"}
          },
        RowSpacings->1,
        ColumnSpacings->3,
        RowAlignments->Baseline,
        ColumnAlignments->{Left}],
      (TableForm[ #]&)]], "Output",
  CellLabel->"Out[64]//TableForm="]
}, Open  ]],

Cell["\<\
Note that there may be multiple optima.  These can be found by \
\"annealing\": that is, by cooling down from a high temperature sufficiently \
slowly.  However, there can be no guarantee that the global optimum has been \
found.\
\>", "Text"],

Cell[TextData[{
  "This fits divergences as well as allele frequencies.  Note that because \
the divergences and moments can each be multiplied/divided by an arbitrary \
factor, the geometric mean of \[Delta]p is held fixed at 1.  The divergences \
represent the ",
  StyleBox["relative",
    FontSlant->"Italic"],
  " strength of associations involving each locus, and so they contribute \
only ",
  StyleBox["nloci",
    FontSlant->"Italic"],
  "-1 degrees of freedom:"
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(met = {L, {{pl}, {{1, 1, 1, 1}}, 
            cc}, {{0.05 \@\( pl \((1 - pl)\)\)}, {{1, 1, 1, 1}/10}, 
            is}};\)\), "\n", 
    \(met = MetropolisDisequilibrium[1063, 1, {1000, 100}, met]\)}], "Input",
  CellLabel->"In[67]:="],

Cell[BoxData[
    InterpretationBox[\(100\[InvisibleSpace]"\t"\[InvisibleSpace]"T="\
\[InvisibleSpace]1\[InvisibleSpace]"\t"\[InvisibleSpace]"log(L)="\
\[InvisibleSpace]\(-40.6076896888670013`\)\[InvisibleSpace]"\t"\
\[InvisibleSpace]"% accepted="\[InvisibleSpace]0.562380952380952425`\),
      SequenceForm[ 
      100, "\t", "T=", 1, "\t", "log(L)=", -40.607689688866998, "\t", 
        "% accepted=", 0.56238095238095243],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\(200\[InvisibleSpace]"\t"\[InvisibleSpace]"T="\
\[InvisibleSpace]1\[InvisibleSpace]"\t"\[InvisibleSpace]"log(L)="\
\[InvisibleSpace]\(-37.7029383140758778`\)\[InvisibleSpace]"\t"\
\[InvisibleSpace]"% accepted="\[InvisibleSpace]0.535476190476190438`\),
      SequenceForm[ 
      200, "\t", "T=", 1, "\t", "log(L)=", -37.70293831407588, "\t", 
        "% accepted=", 0.53547619047619044],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\(300\[InvisibleSpace]"\t"\[InvisibleSpace]"T="\
\[InvisibleSpace]1\[InvisibleSpace]"\t"\[InvisibleSpace]"log(L)="\
\[InvisibleSpace]\(-39.8727748777711799`\)\[InvisibleSpace]"\t"\
\[InvisibleSpace]"% accepted="\[InvisibleSpace]0.523650793650793744`\),
      SequenceForm[ 
      300, "\t", "T=", 1, "\t", "log(L)=", -39.872774877771178, "\t", 
        "% accepted=", 0.5236507936507937],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\(400\[InvisibleSpace]"\t"\[InvisibleSpace]"T="\
\[InvisibleSpace]1\[InvisibleSpace]"\t"\[InvisibleSpace]"log(L)="\
\[InvisibleSpace]\(-32.6725070746110457`\)\[InvisibleSpace]"\t"\
\[InvisibleSpace]"% accepted="\[InvisibleSpace]0.514880952380952372`\),
      SequenceForm[ 
      400, "\t", "T=", 1, "\t", "log(L)=", -32.672507074611048, "\t", 
        "% accepted=", 0.51488095238095233],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\(500\[InvisibleSpace]"\t"\[InvisibleSpace]"T="\
\[InvisibleSpace]1\[InvisibleSpace]"\t"\[InvisibleSpace]"log(L)="\
\[InvisibleSpace]\(-35.4080123798148349`\)\[InvisibleSpace]"\t"\
\[InvisibleSpace]"% accepted="\[InvisibleSpace]0.510571428571428587`\),
      SequenceForm[ 
      500, "\t", "T=", 1, "\t", "log(L)=", -35.408012379814835, "\t", 
        "% accepted=", 0.51057142857142856],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\(600\[InvisibleSpace]"\t"\[InvisibleSpace]"T="\
\[InvisibleSpace]1\[InvisibleSpace]"\t"\[InvisibleSpace]"log(L)="\
\[InvisibleSpace]\(-40.8175856437256623`\)\[InvisibleSpace]"\t"\
\[InvisibleSpace]"% accepted="\[InvisibleSpace]0.510634920634920685`\),
      SequenceForm[ 
      600, "\t", "T=", 1, "\t", "log(L)=", -40.817585643725664, "\t", 
        "% accepted=", 0.51063492063492066],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\(700\[InvisibleSpace]"\t"\[InvisibleSpace]"T="\
\[InvisibleSpace]1\[InvisibleSpace]"\t"\[InvisibleSpace]"log(L)="\
\[InvisibleSpace]\(-39.7271980165046745`\)\[InvisibleSpace]"\t"\
\[InvisibleSpace]"% accepted="\[InvisibleSpace]0.507346938775510203`\),
      SequenceForm[ 
      700, "\t", "T=", 1, "\t", "log(L)=", -39.727198016504673, "\t", 
        "% accepted=", 0.50734693877551018],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\(800\[InvisibleSpace]"\t"\[InvisibleSpace]"T="\
\[InvisibleSpace]1\[InvisibleSpace]"\t"\[InvisibleSpace]"log(L)="\
\[InvisibleSpace]\(-37.2658692622204634`\)\[InvisibleSpace]"\t"\
\[InvisibleSpace]"% accepted="\[InvisibleSpace]0.507023809523809543`\),
      SequenceForm[ 
      800, "\t", "T=", 1, "\t", "log(L)=", -37.265869262220463, "\t", 
        "% accepted=", 0.50702380952380954],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\(900\[InvisibleSpace]"\t"\[InvisibleSpace]"T="\
\[InvisibleSpace]1\[InvisibleSpace]"\t"\[InvisibleSpace]"log(L)="\
\[InvisibleSpace]\(-34.2450165730608935`\)\[InvisibleSpace]"\t"\
\[InvisibleSpace]"% accepted="\[InvisibleSpace]0.507037037037037041`\),
      SequenceForm[ 
      900, "\t", "T=", 1, "\t", "log(L)=", -34.245016573060894, "\t", 
        "% accepted=", 0.50703703703703706],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\(1000\[InvisibleSpace]"\t"\[InvisibleSpace]"T="\
\[InvisibleSpace]1\[InvisibleSpace]"\t"\[InvisibleSpace]"log(L)="\
\[InvisibleSpace]\(-37.3403182356351504`\)\[InvisibleSpace]"\t"\
\[InvisibleSpace]"% accepted="\[InvisibleSpace]0.507190476190476147`\),
      SequenceForm[ 
      1000, "\t", "T=", 1, "\t", "log(L)=", -37.340318235635152, "\t", 
        "% accepted=", 0.50719047619047619],
      Editable->False]], "Print"],

Cell[BoxData[
    \({\(-37.3403182356351504`\), {{{0.47348157656411729`, 
            0.351586679360483778`, 0.376428724593274388`, 
            0.349853670534854943`}}, {{0.918165224204630092`, 
            1.1755167191817577`, 0.899588373735796764`, 
            1.02992717166806491`}}, {{1, 0, 0.0248398667762627223`, 
            0.00131921777699386844`, \(-0.00249017025979333794`\)}, {0, 
            0.024945594328837255`, \(-0.00582922369274581342`\), 
            0.00156053177201856918`, 
            0.00146171865164862868`}, {0.0248398667762627223`, \
\(-0.00582922369274581342`\), 0.00185458962349334104`, 
            0.00203944549942698483`, \(-0.000445270707802515541`\)}, \
{0.00131921777699386844`, 0.00156053177201856918`, 
            0.00203944549942698483`, \(-0.00084939630347647963`\), \
\(-0.000713691875205951564`\)}, {\(-0.00249017025979333794`\), 
            0.00146171865164862868`, \(-0.000445270707802515541`\), \
\(-0.000713691875205951564`\), 
            0.000673813314742838009`}}}, {{{0.102631952789983671`, 
            0.0286804549375380446`, 0.0888209001352526605`, 
            0.0645528148938098755`}}, {{0.227207318080335385`, 
            0.465899067638059616`, 0.251753261030842567`, 
            0.205054604567502662`}}, {{0, 0, 0.0327544231718888978`, 
            0.0169545603960927726`, 0.00885436203186386094`}, {0, 
            0.0074927817582775571`, 0.00225197467170609`, 
            0.00116568197160866771`, 
            0.000608766606123186893`}, {0.0130105258767139186`, 
            0.00149400600795529854`, 0.000974231625722358707`, 
            0.000221950683285274896`, 
            0.000115911687305102417`}, {0.00548536902841874418`, 
            0.00143115165980453529`, 0.000410745886590805131`, 
            0.000505040756177181293`, 
            0.0000510919569156866781`}, {0.00650876972628101846`, 
            0.00188161819873316815`, 0.000540031470438015137`, 
            0.000397565166450256768`, 
            0.000529809086083294911`}}}}\)], "Output",
  CellLabel->"Out[67]="]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(met = 
        MetropolisDisequilibrium[1063, 0.5, {500, 100}, met];\)\), "\n", 
    \(met = MetropolisDisequilibrium[1063, 0, {200, 100}, met]\)}], "Input",
  CellLabel->"In[68]:="],

Cell[BoxData[
    InterpretationBox[
      RowBox[{
      "100", "\[InvisibleSpace]", "\<\"\\t\"\>", 
        "\[InvisibleSpace]", "\<\"T=\"\>", "\[InvisibleSpace]", 
        StyleBox["0.5`",
          StyleBoxAutoDelete->True,
          PrintPrecision->1], "\[InvisibleSpace]", "\<\"\\t\"\>", 
        "\[InvisibleSpace]", "\<\"log(L)=\"\>", 
        "\[InvisibleSpace]", \(-32.1980282116034866`\), 
        "\[InvisibleSpace]", "\<\"\\t\"\>", 
        "\[InvisibleSpace]", "\<\"% accepted=\"\>", "\[InvisibleSpace]", 
        "0.465714285714285658`"}],
      SequenceForm[ 
      100, "\t", "T=", 0.5, "\t", "log(L)=", -32.198028211603486, "\t", 
        "% accepted=", 0.46571428571428569],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      RowBox[{
      "200", "\[InvisibleSpace]", "\<\"\\t\"\>", 
        "\[InvisibleSpace]", "\<\"T=\"\>", "\[InvisibleSpace]", 
        StyleBox["0.5`",
          StyleBoxAutoDelete->True,
          PrintPrecision->1], "\[InvisibleSpace]", "\<\"\\t\"\>", 
        "\[InvisibleSpace]", "\<\"log(L)=\"\>", 
        "\[InvisibleSpace]", \(-32.5645919258438709`\), 
        "\[InvisibleSpace]", "\<\"\\t\"\>", 
        "\[InvisibleSpace]", "\<\"% accepted=\"\>", "\[InvisibleSpace]", 
        "0.484285714285714252`"}],
      SequenceForm[ 
      200, "\t", "T=", 0.5, "\t", "log(L)=", -32.564591925843871, "\t", 
        "% accepted=", 0.48428571428571426],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      RowBox[{
      "300", "\[InvisibleSpace]", "\<\"\\t\"\>", 
        "\[InvisibleSpace]", "\<\"T=\"\>", "\[InvisibleSpace]", 
        StyleBox["0.5`",
          StyleBoxAutoDelete->True,
          PrintPrecision->1], "\[InvisibleSpace]", "\<\"\\t\"\>", 
        "\[InvisibleSpace]", "\<\"log(L)=\"\>", 
        "\[InvisibleSpace]", \(-31.8605478798016017`\), 
        "\[InvisibleSpace]", "\<\"\\t\"\>", 
        "\[InvisibleSpace]", "\<\"% accepted=\"\>", "\[InvisibleSpace]", 
        "0.48523809523809529`"}],
      SequenceForm[ 
      300, "\t", "T=", 0.5, "\t", "log(L)=", -31.860547879801601, "\t", 
        "% accepted=", 0.48523809523809525],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      RowBox[{
      "400", "\[InvisibleSpace]", "\<\"\\t\"\>", 
        "\[InvisibleSpace]", "\<\"T=\"\>", "\[InvisibleSpace]", 
        StyleBox["0.5`",
          StyleBoxAutoDelete->True,
          PrintPrecision->1], "\[InvisibleSpace]", "\<\"\\t\"\>", 
        "\[InvisibleSpace]", "\<\"log(L)=\"\>", 
        "\[InvisibleSpace]", \(-31.8594774624974386`\), 
        "\[InvisibleSpace]", "\<\"\\t\"\>", 
        "\[InvisibleSpace]", "\<\"% accepted=\"\>", "\[InvisibleSpace]", 
        "0.483095238095238066`"}],
      SequenceForm[ 
      400, "\t", "T=", 0.5, "\t", "log(L)=", -31.859477462497438, "\t", 
        "% accepted=", 0.48309523809523808],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      RowBox[{
      "500", "\[InvisibleSpace]", "\<\"\\t\"\>", 
        "\[InvisibleSpace]", "\<\"T=\"\>", "\[InvisibleSpace]", 
        StyleBox["0.5`",
          StyleBoxAutoDelete->True,
          PrintPrecision->1], "\[InvisibleSpace]", "\<\"\\t\"\>", 
        "\[InvisibleSpace]", "\<\"log(L)=\"\>", 
        "\[InvisibleSpace]", \(-30.1854295250635962`\), 
        "\[InvisibleSpace]", "\<\"\\t\"\>", 
        "\[InvisibleSpace]", "\<\"% accepted=\"\>", "\[InvisibleSpace]", 
        "0.488190476190476196`"}],
      SequenceForm[ 
      500, "\t", "T=", 0.5, "\t", "log(L)=", -30.185429525063597, "\t", 
        "% accepted=", 0.48819047619047617],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\(100\[InvisibleSpace]"\t"\[InvisibleSpace]"T="\
\[InvisibleSpace]0\[InvisibleSpace]"\t"\[InvisibleSpace]"log(L)="\
\[InvisibleSpace]\(-28.685338338294315`\)\[InvisibleSpace]"\t"\
\[InvisibleSpace]"% accepted="\[InvisibleSpace]0.03`\),
      SequenceForm[ 
      100, "\t", "T=", 0, "\t", "log(L)=", -28.685338338294315, "\t", 
        "% accepted=", 0.029999999999999999],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\(200\[InvisibleSpace]"\t"\[InvisibleSpace]"T="\
\[InvisibleSpace]0\[InvisibleSpace]"\t"\[InvisibleSpace]"log(L)="\
\[InvisibleSpace]\(-28.6850575081196002`\)\[InvisibleSpace]"\t"\
\[InvisibleSpace]"% accepted="\[InvisibleSpace]0.0233333333333333348`\),
      SequenceForm[ 
      200, "\t", "T=", 0, "\t", "log(L)=", -28.685057508119598, "\t", 
        "% accepted=", 0.023333333333333334],
      Editable->False]], "Print"],

Cell[BoxData[
    \({\(-28.6850575081196002`\), {{{0.390390605348663566`, 
            0.208007258609680345`, 0.318936294126488473`, 
            0.285489655988208479`}}, {{0.660856410211681222`, 
            1.03096594063395996`, 1.01230748603514486`, 
            1.44989357906142357`}}, {{1, 0, 0.0426802526741708199`, 
            0.0147445916948643258`, 0.00433171626652595609`}, {0, 
            0.0172915443129167112`, \(-0.0053791914549089137`\), \
\(-0.00137792452584942126`\), \(-0.000413587630217213941`\)}, \
{0.0426802526741708199`, \(-0.0053791914549089137`\), \
\(-0.00305741278715596287`\), 0.000129946644686282674`, 
            0.000433754620414950853`}, {0.0147445916948643258`, \
\(-0.00137792452584942126`\), 0.000129946644686282674`, 
            0.000415869293901140935`, \(-0.000105812757757355746`\)}, \
{0.00433171626652595609`, \(-0.000413587630217213941`\), 
            0.000433754620414950853`, \(-0.000105812757757355746`\), \
\(-0.000418783559201235355`\)}}}, {{{9.05688294816907557`*^-6, 
            1.23427710320220707`*^-6, 7.07389392671620598`*^-6, 
            2.50720030570098062`*^-6}}, {{5.28362778648818931`*^-6, 
            6.4869088315629142`*^-6, 0.0000108343220644020487`, 
            0.0000120047889910272043`}}, {{0, 0, 0.0327544231718888978`, 
            0.0169545603960927726`, 0.00885436203186386094`}, {0, 
            1.28083921257059717`*^-7, 0.00225197467170609`, 
            0.00116568197160866771`, 
            0.000608766606123186893`}, {2.00721361059749003`*^-7, 
            2.82980601367498252`*^-8, 4.64559825254834812`*^-8, 
            0.000221950683285274896`, 
            0.000115911687305102417`}, {1.27560364087601318`*^-7, 
            2.71075320435858468`*^-8, 1.05836607968609719`*^-8, 
            1.77030250683347967`*^-8, 
            0.0000510919569156866781`}, {1.67711018507319824`*^-7, 
            2.61985622183601885`*^-8, 1.54182309993538257`*^-8, 
            1.71094071920760431`*^-8, 
            2.52638089290915957`*^-8}}}}\)], "Output",
  CellLabel->"Out[69]="]
}, Open  ]],

Cell[TextData[{
  "The log(likelihood) is increased by 30.91-28.69 = 2.22 by an additional 3 \
degrees of freedom; this is not significant when compared with the asymptotic \
",
  Cell[BoxData[
      \(TraditionalForm\`\(1\/2\) \[Chi]\_3\%2\)]],
  "distribution."
}], "Text"],

Cell["\<\
Note that because the algorithm holds the geometric mean of the \
\[Delta]p fixed at 1, care may be needed to fix individual divergences.  For \
example, if all but one were fixed (\[CapitalDelta]\[Delta]p={0,0,0,1}, say), \
no change would be possible.\
\>", "Text"],

Cell[TextData[Cell[BoxData[
    FormBox[GridBox[{
          {
            RowBox[{"MetropolisDisequilibrium", "[", 
              RowBox[{"site", ",", "   ", "T", ",", 
                RowBox[{"{", 
                  RowBox[{
                    StyleBox["ntries",
                      FontSlant->"Italic"], ",", 
                    StyleBox["nprint",
                      FontSlant->"Italic"]}], "}"}], 
                ",", \(\({Log[
                      L], {{{p\_1,  .. }}, {{{\[Delta]\_1,  .. }}, {{c\_\(0, \
0\),  ... }}, {{{\[CapitalDelta]p\_1, \[Ellipsis]}}, \
{{\[CapitalDelta]\[Delta]p\_1, \[Ellipsis]}}, {{\[CapitalDelta]c\_\(0, 0\), \
\[Ellipsis]}, \[Ellipsis]}}, Cumulant \[Rule] False\)\(]\)\)}]}], 
            RowBox[{\(applies\ the\ Metropolis\ algorithm\), ",", " ", 
              RowBox[{
                RowBox[{
                "using", " ", "temperature", " ", "T", " ", "and", "  ", "a", 
                  " ", "matrix", " ", "of", " ", 
                  RowBox[{
                    StyleBox["moments",
                      FontWeight->"Bold"], ".", "  ", "The"}], " ", "list", 
                  "  ", \({{{\[CapitalDelta]p\_1, \[Ellipsis]}}, {{\
\[CapitalDelta]\[Delta]p\_1, \[Ellipsis]}}, {{\[CapitalDelta]c\_\(0, 0\), \
\[Ellipsis]}, \[Ellipsis]}}\), " ", "gives", " ", "the", " ", "initial", " ", 
                  "step", " ", "sizes"}], ";", 
                " ", \(to\ fix\ some\ variables\)}], ",", 
              " ", \(set\ entries\ to\ 0. \ It\ is\ essential\ that\ \
\[CapitalDelta]c\_\(0, 0\)\), ",", " ", \(\[CapitalDelta]c\_\(0, 1\)\), ",", 
              " ", \(\[CapitalDelta]c\_\(1, 0\)\ are\ zero . \ \ Returns\ a\ \
list\ of\ the\ same\ form\ as\ its\ \(\(argument\)\(.\)\)\)}]}
          }], TraditionalForm]]]], "DefinitionBox"],

Cell["This finds a best fitting matrix of moments: ", "Text"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(met = {L, {{pl}, {{1, 1, 1, 1}}, 
            cc}, {{0.05 \@\( pl \((1 - pl)\)\)}, {{0, 0, 0, 0}}, 
            is}};\)\), "\n", 
    \(MetropolisDisequilibrium[1063, 1, {1000, 100}, met, 
      Cumulant \[Rule] False]\)}], "Input",
  CellLabel->"In[51]:="],

Cell[BoxData[
    InterpretationBox[\(100\[InvisibleSpace]"\t"\[InvisibleSpace]"T="\
\[InvisibleSpace]1\[InvisibleSpace]"\t"\[InvisibleSpace]"log(L)="\
\[InvisibleSpace]\(-34.8874857845214592`\)\[InvisibleSpace]"\t"\
\[InvisibleSpace]"% accepted="\[InvisibleSpace]0.567647058823529349`\),
      SequenceForm[ 
      100, "\t", "T=", 1, "\t", "log(L)=", -34.887485784521459, "\t", 
        "% accepted=", 0.56764705882352939],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\(200\[InvisibleSpace]"\t"\[InvisibleSpace]"T="\
\[InvisibleSpace]1\[InvisibleSpace]"\t"\[InvisibleSpace]"log(L)="\
\[InvisibleSpace]\(-37.5945080117452334`\)\[InvisibleSpace]"\t"\
\[InvisibleSpace]"% accepted="\[InvisibleSpace]0.539117647058823479`\),
      SequenceForm[ 
      200, "\t", "T=", 1, "\t", "log(L)=", -37.594508011745233, "\t", 
        "% accepted=", 0.53911764705882348],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\(300\[InvisibleSpace]"\t"\[InvisibleSpace]"T="\
\[InvisibleSpace]1\[InvisibleSpace]"\t"\[InvisibleSpace]"log(L)="\
\[InvisibleSpace]\(-35.6739508024388385`\)\[InvisibleSpace]"\t"\
\[InvisibleSpace]"% accepted="\[InvisibleSpace]0.519411764705882372`\),
      SequenceForm[ 
      300, "\t", "T=", 1, "\t", "log(L)=", -35.673950802438839, "\t", 
        "% accepted=", 0.51941176470588235],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\(400\[InvisibleSpace]"\t"\[InvisibleSpace]"T="\
\[InvisibleSpace]1\[InvisibleSpace]"\t"\[InvisibleSpace]"log(L)="\
\[InvisibleSpace]\(-34.9664917223159932`\)\[InvisibleSpace]"\t"\
\[InvisibleSpace]"% accepted="\[InvisibleSpace]0.518676470588235272`\),
      SequenceForm[ 
      400, "\t", "T=", 1, "\t", "log(L)=", -34.966491722315993, "\t", 
        "% accepted=", 0.51867647058823529],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\(500\[InvisibleSpace]"\t"\[InvisibleSpace]"T="\
\[InvisibleSpace]1\[InvisibleSpace]"\t"\[InvisibleSpace]"log(L)="\
\[InvisibleSpace]\(-37.9579600951929885`\)\[InvisibleSpace]"\t"\
\[InvisibleSpace]"% accepted="\[InvisibleSpace]0.512941176470588189`\),
      SequenceForm[ 
      500, "\t", "T=", 1, "\t", "log(L)=", -37.957960095192988, "\t", 
        "% accepted=", 0.51294117647058823],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\(600\[InvisibleSpace]"\t"\[InvisibleSpace]"T="\
\[InvisibleSpace]1\[InvisibleSpace]"\t"\[InvisibleSpace]"log(L)="\
\[InvisibleSpace]\(-34.3782751896929728`\)\[InvisibleSpace]"\t"\
\[InvisibleSpace]"% accepted="\[InvisibleSpace]0.514019607843137293`\),
      SequenceForm[ 
      600, "\t", "T=", 1, "\t", "log(L)=", -34.378275189692971, "\t", 
        "% accepted=", 0.51401960784313727],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\(700\[InvisibleSpace]"\t"\[InvisibleSpace]"T="\
\[InvisibleSpace]1\[InvisibleSpace]"\t"\[InvisibleSpace]"log(L)="\
\[InvisibleSpace]\(-41.3135049952159327`\)\[InvisibleSpace]"\t"\
\[InvisibleSpace]"% accepted="\[InvisibleSpace]0.507226890756302584`\),
      SequenceForm[ 
      700, "\t", "T=", 1, "\t", "log(L)=", -41.313504995215936, "\t", 
        "% accepted=", 0.50722689075630256],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\(800\[InvisibleSpace]"\t"\[InvisibleSpace]"T="\
\[InvisibleSpace]1\[InvisibleSpace]"\t"\[InvisibleSpace]"log(L)="\
\[InvisibleSpace]\(-36.4805407167965523`\)\[InvisibleSpace]"\t"\
\[InvisibleSpace]"% accepted="\[InvisibleSpace]0.504117647058823514`\),
      SequenceForm[ 
      800, "\t", "T=", 1, "\t", "log(L)=", -36.480540716796554, "\t", 
        "% accepted=", 0.50411764705882356],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\(900\[InvisibleSpace]"\t"\[InvisibleSpace]"T="\
\[InvisibleSpace]1\[InvisibleSpace]"\t"\[InvisibleSpace]"log(L)="\
\[InvisibleSpace]\(-36.8281360189607465`\)\[InvisibleSpace]"\t"\
\[InvisibleSpace]"% accepted="\[InvisibleSpace]0.508235294117647029`\),
      SequenceForm[ 
      900, "\t", "T=", 1, "\t", "log(L)=", -36.828136018960748, "\t", 
        "% accepted=", 0.50823529411764701],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\(1000\[InvisibleSpace]"\t"\[InvisibleSpace]"T="\
\[InvisibleSpace]1\[InvisibleSpace]"\t"\[InvisibleSpace]"log(L)="\
\[InvisibleSpace]\(-36.0672756933450378`\)\[InvisibleSpace]"\t"\
\[InvisibleSpace]"% accepted="\[InvisibleSpace]0.506705882352941205`\),
      SequenceForm[ 
      1000, "\t", "T=", 1, "\t", "log(L)=", -36.067275693345039, "\t", 
        "% accepted=", 0.50670588235294123],
      Editable->False]], "Print"],

Cell[BoxData[
    \({\(-36.0672756933450378`\), {{{0.359747849116320494`, 
            0.240153809857558897`, 0.312394027183865929`, 
            0.347555711920778964`}}, {{1.`, 1.`, 1.`, 1.`}}, {{1, 0, 
            0.0625147146295861233`, 0.00799222617429319104`, 
            0.00985232143515941949`}, {0, 
            0.0484652161891140575`, \(-0.00096536552400486979`\), 
            0.00399481980303892036`, 
            0.000689352162866580897`}, {0.0625147146295861233`, \
\(-0.00096536552400486979`\), 0.00154040911523028345`, 
            0.0000690037156704670984`, 
            0.000481073273664572731`}, {0.00799222617429319104`, 
            0.00399481980303892036`, 0.0000690037156704670984`, 
            0.000934885157460607629`, 
            0.000705535879212368488`}, {0.00985232143515941949`, 
            0.000689352162866580897`, 0.000481073273664572731`, 
            0.000705535879212368488`, 
            0.000703066582331114631`}}}, {{{0.0680881343839696473`, 
            0.0258841105811280769`, 0.0801608623720655089`, 
            0.132368519317693777`}}, {{0, 0, 0, 0}}, {{0, 0, 
            0.0327544231718888978`, 0.0169545603960927726`, 
            0.00885436203186386094`}, {0, 0.0138662753400016637`, 
            0.00225197467170609`, 0.00116568197160866771`, 
            0.000608766606123186893`}, {0.0130105258767139186`, 
            0.00183424744494630829`, 0.00119610085953589596`, 
            0.000221950683285274896`, 
            0.000115911687305102417`}, {0.00673459415249268555`, 
            0.00143115165980453573`, 0.000334555091790001979`, 
            0.000505040756177181293`, 
            0.0000510919569156866781`}, {0.00981092745912893171`, 
            0.00138316227914117151`, 0.000540031470438015137`, 
            0.000193882584245690932`, 
            0.000389458362759272436`}}}}\)], "Output",
  CellLabel->"Out[51]="]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    \(met = 
      MetropolisDisequilibrium[1063, 0.5, {400, 100}, met, 
        Cumulant \[Rule] False]\)], "Input",
  CellLabel->"In[52]:="],

Cell[BoxData[
    InterpretationBox[
      RowBox[{
      "100", "\[InvisibleSpace]", "\<\"\\t\"\>", 
        "\[InvisibleSpace]", "\<\"T=\"\>", "\[InvisibleSpace]", 
        StyleBox["0.5`",
          StyleBoxAutoDelete->True,
          PrintPrecision->1], "\[InvisibleSpace]", "\<\"\\t\"\>", 
        "\[InvisibleSpace]", "\<\"log(L)=\"\>", 
        "\[InvisibleSpace]", \(-34.5944781293352709`\), 
        "\[InvisibleSpace]", "\<\"\\t\"\>", 
        "\[InvisibleSpace]", "\<\"% accepted=\"\>", "\[InvisibleSpace]", 
        "0.54294117647058826`"}],
      SequenceForm[ 
      100, "\t", "T=", 0.5, "\t", "log(L)=", -34.594478129335272, "\t", 
        "% accepted=", 0.54294117647058826],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      RowBox[{
      "200", "\[InvisibleSpace]", "\<\"\\t\"\>", 
        "\[InvisibleSpace]", "\<\"T=\"\>", "\[InvisibleSpace]", 
        StyleBox["0.5`",
          StyleBoxAutoDelete->True,
          PrintPrecision->1], "\[InvisibleSpace]", "\<\"\\t\"\>", 
        "\[InvisibleSpace]", "\<\"log(L)=\"\>", 
        "\[InvisibleSpace]", \(-31.6158811323765842`\), 
        "\[InvisibleSpace]", "\<\"\\t\"\>", 
        "\[InvisibleSpace]", "\<\"% accepted=\"\>", "\[InvisibleSpace]", 
        "0.498529411764705887`"}],
      SequenceForm[ 
      200, "\t", "T=", 0.5, "\t", "log(L)=", -31.615881132376586, "\t", 
        "% accepted=", 0.49852941176470589],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      RowBox[{
      "300", "\[InvisibleSpace]", "\<\"\\t\"\>", 
        "\[InvisibleSpace]", "\<\"T=\"\>", "\[InvisibleSpace]", 
        StyleBox["0.5`",
          StyleBoxAutoDelete->True,
          PrintPrecision->1], "\[InvisibleSpace]", "\<\"\\t\"\>", 
        "\[InvisibleSpace]", "\<\"log(L)=\"\>", 
        "\[InvisibleSpace]", \(-33.071591396585207`\), 
        "\[InvisibleSpace]", "\<\"\\t\"\>", 
        "\[InvisibleSpace]", "\<\"% accepted=\"\>", "\[InvisibleSpace]", 
        "0.510196078431372601`"}],
      SequenceForm[ 
      300, "\t", "T=", 0.5, "\t", "log(L)=", -33.071591396585205, "\t", 
        "% accepted=", 0.5101960784313726],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      RowBox[{
      "400", "\[InvisibleSpace]", "\<\"\\t\"\>", 
        "\[InvisibleSpace]", "\<\"T=\"\>", "\[InvisibleSpace]", 
        StyleBox["0.5`",
          StyleBoxAutoDelete->True,
          PrintPrecision->1], "\[InvisibleSpace]", "\<\"\\t\"\>", 
        "\[InvisibleSpace]", "\<\"log(L)=\"\>", 
        "\[InvisibleSpace]", \(-34.0678517556048898`\), 
        "\[InvisibleSpace]", "\<\"\\t\"\>", 
        "\[InvisibleSpace]", "\<\"% accepted=\"\>", "\[InvisibleSpace]", 
        "0.51205882352941181`"}],
      SequenceForm[ 
      400, "\t", "T=", 0.5, "\t", "log(L)=", -34.067851755604892, "\t", 
        "% accepted=", 0.51205882352941179],
      Editable->False]], "Print"],

Cell[BoxData[
    \({\(-34.0678517556048898`\), {{{0.435726700131239752`, 
            0.28519688235434879`, 0.39719138452015489`, 
            0.386171198268343918`}}, {{1.`, 1.`, 1.`, 1.`}}, {{1, 0, 
            0.0449360345142077743`, 0.0090514892744114288`, 
            0.0119215212956977545`}, {0, 
            0.0184251220625993852`, \(-0.00776579268800193212`\), 
            0.00226508521521576478`, \(-0.000778457197590442184`\)}, \
{0.0449360345142077743`, \(-0.00776579268800193212`\), 
            0.00415150137006830277`, 0.000419881209102399566`, 
            0.000584725434302016733`}, {0.0090514892744114288`, 
            0.00226508521521576478`, 0.000419881209102399566`, 
            0.000809283806931463978`, 
            0.000363573008836251432`}, {0.0119215212956977545`, \
\(-0.000778457197590442184`\), 0.000584725434302016733`, 
            0.000363573008836251432`, \(-0.000213073758373785704`\)}}}, \
{{{0.0554582110065831734`, 0.0139867402626877467`, 0.0652915234074371753`, 
            0.0474522507454563502`}}, {{0, 0, 0, 0}}, {{0, 0, 
            0.0327544231718888978`, 0.0169545603960927726`, 
            0.00885436203186386094`}, {0, 0.0101929865556086363`, 
            0.00225197467170609`, 0.00116568197160866771`, 
            0.000608766606123186893`}, {0.0144160951542536501`, 
            0.00203240714121474574`, 0.00146849807418407873`, 
            0.000221950683285274896`, 
            0.000115911687305102417`}, {0.00403225028987615274`, 
            0.00105202797937682235`, 0.000370698162648201723`, 
            0.000687044385359466769`, 
            0.0000510919569156866781`}, {0.0072119332147158115`, 
            0.00112659432112472868`, 0.000291811452706468443`, 
            0.000263752854191937124`, 
            0.000351486172390243467`}}}}\)], "Output",
  CellLabel->"Out[52]="]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    \(met = 
      MetropolisDisequilibrium[1063, 0, {200, 100}, met, 
        Cumulant \[Rule] False]\)], "Input",
  CellLabel->"In[53]:="],

Cell[BoxData[
    InterpretationBox[\(100\[InvisibleSpace]"\t"\[InvisibleSpace]"T="\
\[InvisibleSpace]0\[InvisibleSpace]"\t"\[InvisibleSpace]"log(L)="\
\[InvisibleSpace]\(-30.3982713199267795`\)\[InvisibleSpace]"\t"\
\[InvisibleSpace]"% accepted="\[InvisibleSpace]0.0541176470588235236`\),
      SequenceForm[ 
      100, "\t", "T=", 0, "\t", "log(L)=", -30.398271319926778, "\t", 
        "% accepted=", 0.054117647058823527],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\(200\[InvisibleSpace]"\t"\[InvisibleSpace]"T="\
\[InvisibleSpace]0\[InvisibleSpace]"\t"\[InvisibleSpace]"log(L)="\
\[InvisibleSpace]\(-30.3981665307794068`\)\[InvisibleSpace]"\t"\
\[InvisibleSpace]"% accepted="\[InvisibleSpace]0.0347058823529411775`\),
      SequenceForm[ 
      200, "\t", "T=", 0, "\t", "log(L)=", -30.398166530779406, "\t", 
        "% accepted=", 0.034705882352941177],
      Editable->False]], "Print"],

Cell[BoxData[
    \({\(-30.3981665307794068`\), {{{0.412534575556825355`, 
            0.272130479408745618`, 0.342925808326470082`, 
            0.284239086971650056`}}, {{1.`, 1.`, 1.`, 1.`}}, {{1, 0, 
            0.0419310565195045814`, \(-0.000835721482844586383`\), 
            0.0066957961251218343`}, {0, 
            0.0318576159111084944`, \(-0.00846981856617565576`\), 
            0.00313323746518757051`, \(-0.00109473258648173388`\)}, \
{0.0419310565195045814`, \(-0.00846981856617565576`\), 
            0.0018743563725245437`, 0.000300351905725602463`, 
            0.000695832181956220097`}, {\(-0.000835721482844586383`\), 
            0.00313323746518757051`, 0.000300351905725602463`, 
            0.000811871754980219506`, 
            0.000359755812627826143`}, {0.0066957961251218343`, \
\(-0.00109473258648173388`\), 0.000695832181956220097`, 
            0.000359755812627826143`, \(-0.000133753916159789953`\)}}}, \
{{{4.41681520260015059`*^-6, 7.39007294943301218`*^-7, 
            0.0000106627616411680925`, 7.74942921577025067`*^-6}}, {{0, 0, 0, 
            0}}, {{0, 0, 0.0327544231718888978`, 0.0169545603960927726`, 
            0.00885436203186386094`}, {0, 8.11792107274557928`*^-7, 
            0.00225197467170609`, 0.00116568197160866771`, 
            0.000608766606123186893`}, {6.87427760390292696`*^-7, 
            1.31840398336774833`*^-7, 1.16954450951823041`*^-7, 
            0.000221950683285274896`, 
            0.000115911687305102417`}, {3.55830887948312657`*^-7, 
            6.82440959047079687`*^-8, 1.76766457909276164`*^-8, 
            4.45679429106403723`*^-8, 
            0.0000510919569156866781`}, {3.81051707275696074`*^-7, 
            6.59557347279159955`*^-8, 1.70839124646579794`*^-8, 
            1.5441239990848623`*^-8, 2.79931400876361191`*^-8}}}}\)], "Output",\

  CellLabel->"Out[53]="]
}, Closed]],

Cell["\<\
The log likelihood is -30.40, slightly higher than was acheived in \
the run above.\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(met\[LeftDoubleBracket]2, 3\[RightDoubleBracket] // 
      MatrixForm\)], "Input",
  CellLabel->"In[54]:="],

Cell[BoxData[
    TagBox[
      RowBox[{"(", GridBox[{
            {"1", "0", 
              "0.0419310565195045814`", \(-0.000835721482844586383`\), 
              "0.0066957961251218343`"},
            {"0", "0.0318576159111084944`", \(-0.00846981856617565576`\), 
              "0.00313323746518757051`", \(-0.00109473258648173388`\)},
            {"0.0419310565195045814`", \(-0.00846981856617565576`\), 
              "0.0018743563725245437`", "0.000300351905725602463`", 
              "0.000695832181956220097`"},
            {\(-0.000835721482844586383`\), "0.00313323746518757051`", 
              "0.000300351905725602463`", "0.000811871754980219506`", 
              "0.000359755812627826143`"},
            {"0.0066957961251218343`", \(-0.00109473258648173388`\), 
              "0.000695832181956220097`", 
              "0.000359755812627826143`", \(-0.000133753916159789953`\)}
            }], ")"}],
      (MatrixForm[ #]&)]], "Output",
  CellLabel->"Out[54]//MatrixForm="]
}, Open  ]],

Cell["The corresponding matrix of cumulants is:", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(Cumulant[4]\)[met\[LeftDoubleBracket]2, 3\[RightDoubleBracket]] // 
      MatrixForm\)], "Input",
  CellLabel->"In[56]:="],

Cell[BoxData[
    TagBox[
      RowBox[{"(", GridBox[{
            {"0.`", "0.`", 
              "0.0419310565195045814`", \(-0.000835721482844586383`\), 
              "0.001421155622596173`"},
            {"0.`", 
              "0.0318576159111084944`", \(-0.00846981856617565576`\), \
\(-0.000874233014848505618`\), "0.00114265443560432933`"},
            {
              "0.0419310565195045814`", \(-0.00846981856617565576`\), \
\(-0.00191367251139676941`\), "0.00301980927379010344`", 
              "0.000149917656530512433`"},
            {\(-0.000835721482844586383`\), \(-0.000874233014848505618`\), 
              "0.00301980927379010299`", 
              "0.000236055713928698462`", \(-0.00107788859655930813`\)},
            {"0.001421155622596173`", "0.00114265443560432933`", 
              "0.000149917656530512521`", \(-0.0010778885965593079`\), 
              "0.000442453217844865953`"}
            }], ")"}],
      (MatrixForm[ #]&)]], "Output",
  CellLabel->"Out[56]//MatrixForm="]
}, Open  ]],

Cell["This differs slightly from the estimate in the run above.", "Text"],

Cell[TextData[{
  "If all the moments are fitted, the two methods are equivalent.  However, \
if some elements are fixed, then they are not.  For example, one might want \
to test random union of gametes, which corresponds to setting between-genome \
",
  StyleBox["cumulants",
    FontSlant->"Italic"],
  " to zero.  Between-genome ",
  StyleBox["moments",
    FontSlant->"Italic"],
  " will then not necessarily be zero."
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{\(Moment[3]\), "[", 
        RowBox[{"(", GridBox[{
              {"1", "0", "0.02", "0.005"},
              {"0", "0", "0", "0"},
              {"0.02", "0", "0", "0"},
              {"0.005", "0", "0", "0"}
              }], ")"}], "]"}], "//", "MatrixForm"}]], "Input",
  CellLabel->"In[73]:="],

Cell[BoxData[
    TagBox[
      RowBox[{"(", GridBox[{
            {"1.`", "0.`", "0.02`", "0.005`"},
            {"0.`", "0.`", "0.`", "0.`"},
            {"0.02`", "0.`", "0.0004`", "0.0001`"},
            {"0.005`", "0.`", "0.0001`", "0.000025`"}
            }], ")"}],
      (MatrixForm[ #]&)]], "Output",
  CellLabel->"Out[73]//MatrixForm="]
}, Open  ]]
}, Open  ]]
},
FrontEndVersion->"4.0 for Macintosh",
ScreenRectangle->{{0, 1024}, {0, 748}},
WindowSize->{956, 721},
WindowMargins->{{-2, Automatic}, {Automatic, 1}},
StyleDefinitions -> "HelpBrowser.nb",
MacintoshSystemPageSetup->"\<\
00<0001804P000000`d26_oRon@3:`8f0dL5N`?N0080001804P000000`d26P01
0000I00000400@410?l00BL?00400@00000000000000000201T1T0000000@000
00000000004000000000000000010000\>"
]


(***********************************************************************
Cached data follows.  If you edit this Notebook file directly, not using
Mathematica, you must remove the line containing CacheID at the top of 
the file.  The cache data will then be recreated when you save this file 
from within Mathematica.
***********************************************************************)

(*CellTagsOutline
CellTagsIndex->{
  "MetropolisDisequilibrium"->{
    Cell[3174, 94, 1372, 26, 80, "DefinitionBox",
      CellTags->"MetropolisDisequilibrium"]}
  }
*)

(*CellTagsIndex
CellTagsIndex->{
  {"MetropolisDisequilibrium", 45314, 1097}
  }
*)

(*NotebookFileOutline
Notebook[{

Cell[CellGroupData[{
Cell[1739, 51, 71, 0, 36, "SubsectionIcon"],
Cell[1813, 53, 770, 20, 50, "Text"],

Cell[CellGroupData[{
Cell[2608, 77, 161, 4, 27, "Input"],
Cell[2772, 83, 18, 0, 94, "Output"]
}, Closed]],
Cell[2805, 86, 366, 6, 32, "Text"],
Cell[3174, 94, 1372, 26, 80, "DefinitionBox",
  CellTags->"MetropolisDisequilibrium"],
Cell[4549, 122, 650, 13, 54, "Text"],

Cell[CellGroupData[{
Cell[5224, 139, 426, 8, 75, "Input"],
Cell[5653, 149, 17, 0, 20, "Print"],
Cell[5673, 151, 17, 0, 20, "Print"],
Cell[5693, 153, 17, 0, 20, "Print"],
Cell[5713, 155, 17, 0, 20, "Print"],
Cell[5733, 157, 17, 0, 20, "Print"],
Cell[5753, 159, 18, 0, 125, "Output"]
}, Closed]],
Cell[5786, 162, 174, 4, 18, "MathCaption"],

Cell[CellGroupData[{
Cell[5985, 170, 205, 4, 42, "Input"],
Cell[6193, 176, 17, 0, 20, "Print"],
Cell[6213, 178, 17, 0, 20, "Print"],
Cell[6233, 180, 17, 0, 20, "Print"],
Cell[6253, 182, 17, 0, 20, "Print"],
Cell[6273, 184, 17, 0, 20, "Print"],
Cell[6293, 186, 17, 0, 20, "Print"],
Cell[6313, 188, 17, 0, 20, "Print"],
Cell[6333, 190, 18, 0, 150, "Output"]
}, Closed]],
Cell[6366, 193, 592, 17, 48, "Text"],
Cell[6961, 212, 67, 0, 28, "MathCaption"],

Cell[CellGroupData[{
Cell[7053, 216, 127, 3, 27, "Input"],
Cell[7183, 221, 979, 21, 83, "Output"]
}, Open  ]],
Cell[8177, 245, 73, 0, 22, "Text"],

Cell[CellGroupData[{
Cell[8275, 249, 191, 4, 27, "Input"],
Cell[8469, 255, 486, 12, 35, "Output"]
}, Open  ]],
Cell[8970, 270, 253, 5, 50, "Text"],
Cell[9226, 277, 483, 12, 52, "Text"],

Cell[CellGroupData[{
Cell[9734, 293, 258, 5, 45, "Input"],
Cell[9995, 300, 459, 8, 20, "Print"],
Cell[10457, 310, 458, 8, 20, "Print"],
Cell[10918, 320, 458, 8, 20, "Print"],
Cell[11379, 330, 459, 8, 20, "Print"],
Cell[11841, 340, 459, 8, 20, "Print"],
Cell[12303, 350, 459, 8, 20, "Print"],
Cell[12765, 360, 459, 8, 20, "Print"],
Cell[13227, 370, 459, 8, 20, "Print"],
Cell[13689, 380, 459, 8, 20, "Print"],
Cell[14151, 390, 461, 8, 20, "Print"],
Cell[14615, 400, 2050, 35, 155, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[16702, 440, 205, 4, 38, "Input"],
Cell[16910, 446, 727, 16, 20, "Print"],
Cell[17640, 464, 727, 16, 20, "Print"],
Cell[18370, 482, 726, 16, 20, "Print"],
Cell[19099, 500, 727, 16, 20, "Print"],
Cell[19829, 518, 727, 16, 20, "Print"],
Cell[20559, 536, 443, 8, 20, "Print"],
Cell[21005, 546, 461, 8, 20, "Print"],
Cell[21469, 556, 2054, 34, 106, "Output"]
}, Open  ]],
Cell[23538, 593, 275, 7, 36, "Text"],
Cell[23816, 602, 277, 5, 36, "Text"],
Cell[24096, 609, 1784, 33, 80, "DefinitionBox"],
Cell[25883, 644, 61, 0, 22, "Text"],

Cell[CellGroupData[{
Cell[25969, 648, 280, 6, 45, "Input"],
Cell[26252, 656, 459, 8, 20, "Print"],
Cell[26714, 666, 459, 8, 20, "Print"],
Cell[27176, 676, 459, 8, 20, "Print"],
Cell[27638, 686, 459, 8, 20, "Print"],
Cell[28100, 696, 459, 8, 20, "Print"],
Cell[28562, 706, 459, 8, 20, "Print"],
Cell[29024, 716, 459, 8, 20, "Print"],
Cell[29486, 726, 459, 8, 20, "Print"],
Cell[29948, 736, 459, 8, 20, "Print"],
Cell[30410, 746, 461, 8, 20, "Print"],
Cell[30874, 756, 1881, 33, 125, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[32792, 794, 156, 4, 23, "Input"],
Cell[32951, 800, 726, 16, 20, "Print"],
Cell[33680, 818, 727, 16, 20, "Print"],
Cell[34410, 836, 725, 16, 20, "Print"],
Cell[35138, 854, 726, 16, 20, "Print"],
Cell[35867, 872, 1840, 31, 125, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[37744, 908, 154, 4, 23, "Input"],
Cell[37901, 914, 461, 8, 20, "Print"],
Cell[38365, 924, 461, 8, 20, "Print"],
Cell[38829, 934, 1861, 31, 150, "Output"]
}, Closed]],
Cell[40705, 968, 107, 3, 18, "Text"],

Cell[CellGroupData[{
Cell[40837, 975, 127, 3, 27, "Input"],
Cell[40967, 980, 989, 19, 83, "Output"]
}, Open  ]],
Cell[41971, 1002, 57, 0, 22, "Text"],

Cell[CellGroupData[{
Cell[42053, 1006, 144, 3, 27, "Input"],
Cell[42200, 1011, 1001, 21, 83, "Output"]
}, Open  ]],
Cell[43216, 1035, 73, 0, 22, "Text"],
Cell[43292, 1037, 435, 11, 38, "Text"],

Cell[CellGroupData[{
Cell[43752, 1052, 338, 9, 76, "Input"],
Cell[44093, 1063, 346, 9, 67, "Output"]
}, Open  ]]
}, Open  ]]
}
]
*)




(***********************************************************************
End of Mathematica Notebook file.
***********************************************************************)

