(***********************************************************************

                    Mathematica-Compatible Notebook

This notebook can be used on any computer system with Mathematica 4.0,
MathReader 4.0, or any compatible application. The data for the notebook 
starts with the line containing stars above.

To get the notebook into a Mathematica-compatible application, do one of 
the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing the 
word CacheID, otherwise Mathematica-compatible applications may try to 
use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
***********************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[     53635,       1682]*)
(*NotebookOutlinePosition[     54519,       1710]*)
(*  CellTagsIndexPosition[     54475,       1706]*)
(*WindowFrame->Normal*)



Notebook[{
Cell["\<\
An example: site 1063 has 37 toads, scored for 4 biallelic \
loci\
\>", "SubsectionIcon"],

Cell["This loads the packages:", "MathCaption"],

Cell[BoxData[
    \(<< Multilocus`EstimatingD`; << 
      Multilocus`DataManipulation`; \)], "Input",
  CellLabel->"In[1]:="],

Cell[TextData[{
  "It can be most convenient to enter the data in this compact form (see ",
  Cell[BoxData[
      FormBox[
        ButtonBox["Multilocus`DataManipulation`",
          ButtonData:>{"Notation for genetic data", None},
          ButtonStyle->"AddOnsLink",
          ButtonNote->"Multilocus`DataManipulation`"], TraditionalForm]]],
  "):"
}], "MathCaption"],

Cell[BoxData[
    RowBox[{
      RowBox[{\(rawdata[1063]\), "=", 
        TagBox[
          RowBox[{"(", GridBox[{
                {"1", "0", "0", "0"},
                {"0", "0", "0", "0"},
                {"0", "0", "0", "0"},
                {"2", "0", "1", "0"},
                {"0", "0", "0", "0"},
                {"1", "0", "1", "2"},
                {"1", "0", "0", "2"},
                {"2", "0", "1", "0"},
                {"0", "1", "2", "1"},
                {"1", "1", "1", "2"},
                {"0", "0", "0", "0"},
                {"2", "1", "0", "1"},
                {"0", "1", "2", "2"},
                {"0", "0", "1", "0"},
                {"2", "1", "1", "1"},
                {"1", "0", "0", "2"},
                {"0", "1", "1", "0"},
                {"0", "0", "0", "0"},
                {"1", "1", "0", "1"},
                {"1", "0", "1", "1"},
                {"0", "0", "1", "0"},
                {"1", "1", "1", "1"},
                {"0", "0", "0", "0"},
                {"1", "0", "0", "0"},
                {"0", "0", "0", "0"},
                {"2", "1", "1", "1"},
                {"0", "0", "0", "0"},
                {"0", "1", "2", "1"},
                {"0", "2", "2", "1"},
                {"2", "0", "1", "0"},
                {"2", "1", "1", "2"},
                {"0", "0", "0", "0"},
                {"2", "0", "1", "0"},
                {"1", "0", "0", "1"},
                {"1", "0", "0", "0"},
                {"1", "0", "2", "1"},
                {"1", "0", "0", "0"}
                }], ")"}],
          (MatrixForm[ #]&)]}], ";"}]], "Input",
  CellLabel->"In[2]:="],

Cell["\<\
It can then be converted into the standard form, which in principle \
allows for multiple alleles:\
\>", "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[
    \(Data[1063] = ConvertData[rawdata[1063]]; 
    Data[1063] // MatrixForm\)], "Input",
  CellLabel->"In[3]:="],

Cell[BoxData[
    InterpretationBox[
      RowBox[{"(", GridBox[{
            {
              RowBox[{"(", GridBox[{
                    {"0"},
                    {"1"}
                    }], ")"}], 
              RowBox[{"(", GridBox[{
                    {"0"},
                    {"0"}
                    }], ")"}], 
              RowBox[{"(", GridBox[{
                    {"0"},
                    {"0"}
                    }], ")"}], 
              RowBox[{"(", GridBox[{
                    {"0"},
                    {"0"}
                    }], ")"}]},
            {
              RowBox[{"(", GridBox[{
                    {"0"},
                    {"0"}
                    }], ")"}], 
              RowBox[{"(", GridBox[{
                    {"0"},
                    {"0"}
                    }], ")"}], 
              RowBox[{"(", GridBox[{
                    {"0"},
                    {"0"}
                    }], ")"}], 
              RowBox[{"(", GridBox[{
                    {"0"},
                    {"0"}
                    }], ")"}]},
            {
              RowBox[{"(", GridBox[{
                    {"0"},
                    {"0"}
                    }], ")"}], 
              RowBox[{"(", GridBox[{
                    {"0"},
                    {"0"}
                    }], ")"}], 
              RowBox[{"(", GridBox[{
                    {"0"},
                    {"0"}
                    }], ")"}], 
              RowBox[{"(", GridBox[{
                    {"0"},
                    {"0"}
                    }], ")"}]},
            {
              RowBox[{"(", GridBox[{
                    {"1"},
                    {"1"}
                    }], ")"}], 
              RowBox[{"(", GridBox[{
                    {"0"},
                    {"0"}
                    }], ")"}], 
              RowBox[{"(", GridBox[{
                    {"0"},
                    {"1"}
                    }], ")"}], 
              RowBox[{"(", GridBox[{
                    {"0"},
                    {"0"}
                    }], ")"}]},
            {
              RowBox[{"(", GridBox[{
                    {"0"},
                    {"0"}
                    }], ")"}], 
              RowBox[{"(", GridBox[{
                    {"0"},
                    {"0"}
                    }], ")"}], 
              RowBox[{"(", GridBox[{
                    {"0"},
                    {"0"}
                    }], ")"}], 
              RowBox[{"(", GridBox[{
                    {"0"},
                    {"0"}
                    }], ")"}]},
            {
              RowBox[{"(", GridBox[{
                    {"0"},
                    {"1"}
                    }], ")"}], 
              RowBox[{"(", GridBox[{
                    {"0"},
                    {"0"}
                    }], ")"}], 
              RowBox[{"(", GridBox[{
                    {"0"},
                    {"1"}
                    }], ")"}], 
              RowBox[{"(", GridBox[{
                    {"1"},
                    {"1"}
                    }], ")"}]},
            {
              RowBox[{"(", GridBox[{
                    {"0"},
                    {"1"}
                    }], ")"}], 
              RowBox[{"(", GridBox[{
                    {"0"},
                    {"0"}
                    }], ")"}], 
              RowBox[{"(", GridBox[{
                    {"0"},
                    {"0"}
                    }], ")"}], 
              RowBox[{"(", GridBox[{
                    {"1"},
                    {"1"}
                    }], ")"}]},
            {
              RowBox[{"(", GridBox[{
                    {"1"},
                    {"1"}
                    }], ")"}], 
              RowBox[{"(", GridBox[{
                    {"0"},
                    {"0"}
                    }], ")"}], 
              RowBox[{"(", GridBox[{
                    {"0"},
                    {"1"}
                    }], ")"}], 
              RowBox[{"(", GridBox[{
                    {"0"},
                    {"0"}
                    }], ")"}]},
            {
              RowBox[{"(", GridBox[{
                    {"0"},
                    {"0"}
                    }], ")"}], 
              RowBox[{"(", GridBox[{
                    {"0"},
                    {"1"}
                    }], ")"}], 
              RowBox[{"(", GridBox[{
                    {"1"},
                    {"1"}
                    }], ")"}], 
              RowBox[{"(", GridBox[{
                    {"0"},
                    {"1"}
                    }], ")"}]},
            {
              RowBox[{"(", GridBox[{
                    {"0"},
                    {"1"}
                    }], ")"}], 
              RowBox[{"(", GridBox[{
                    {"0"},
                    {"1"}
                    }], ")"}], 
              RowBox[{"(", GridBox[{
                    {"0"},
                    {"1"}
                    }], ")"}], 
              RowBox[{"(", GridBox[{
                    {"1"},
                    {"1"}
                    }], ")"}]},
            {
              RowBox[{"(", GridBox[{
                    {"0"},
                    {"0"}
                    }], ")"}], 
              RowBox[{"(", GridBox[{
                    {"0"},
                    {"0"}
                    }], ")"}], 
              RowBox[{"(", GridBox[{
                    {"0"},
                    {"0"}
                    }], ")"}], 
              RowBox[{"(", GridBox[{
                    {"0"},
                    {"0"}
                    }], ")"}]},
            {
              RowBox[{"(", GridBox[{
                    {"1"},
                    {"1"}
                    }], ")"}], 
              RowBox[{"(", GridBox[{
                    {"0"},
                    {"1"}
                    }], ")"}], 
              RowBox[{"(", GridBox[{
                    {"0"},
                    {"0"}
                    }], ")"}], 
              RowBox[{"(", GridBox[{
                    {"0"},
                    {"1"}
                    }], ")"}]},
            {
              RowBox[{"(", GridBox[{
                    {"0"},
                    {"0"}
                    }], ")"}], 
              RowBox[{"(", GridBox[{
                    {"0"},
                    {"1"}
                    }], ")"}], 
              RowBox[{"(", GridBox[{
                    {"1"},
                    {"1"}
                    }], ")"}], 
              RowBox[{"(", GridBox[{
                    {"1"},
                    {"1"}
                    }], ")"}]},
            {
              RowBox[{"(", GridBox[{
                    {"0"},
                    {"0"}
                    }], ")"}], 
              RowBox[{"(", GridBox[{
                    {"0"},
                    {"0"}
                    }], ")"}], 
              RowBox[{"(", GridBox[{
                    {"0"},
                    {"1"}
                    }], ")"}], 
              RowBox[{"(", GridBox[{
                    {"0"},
                    {"0"}
                    }], ")"}]},
            {
              RowBox[{"(", GridBox[{
                    {"1"},
                    {"1"}
                    }], ")"}], 
              RowBox[{"(", GridBox[{
                    {"0"},
                    {"1"}
                    }], ")"}], 
              RowBox[{"(", GridBox[{
                    {"0"},
                    {"1"}
                    }], ")"}], 
              RowBox[{"(", GridBox[{
                    {"0"},
                    {"1"}
                    }], ")"}]},
            {
              RowBox[{"(", GridBox[{
                    {"0"},
                    {"1"}
                    }], ")"}], 
              RowBox[{"(", GridBox[{
                    {"0"},
                    {"0"}
                    }], ")"}], 
              RowBox[{"(", GridBox[{
                    {"0"},
                    {"0"}
                    }], ")"}], 
              RowBox[{"(", GridBox[{
                    {"1"},
                    {"1"}
                    }], ")"}]},
            {
              RowBox[{"(", GridBox[{
                    {"0"},
                    {"0"}
                    }], ")"}], 
              RowBox[{"(", GridBox[{
                    {"0"},
                    {"1"}
                    }], ")"}], 
              RowBox[{"(", GridBox[{
                    {"0"},
                    {"1"}
                    }], ")"}], 
              RowBox[{"(", GridBox[{
                    {"0"},
                    {"0"}
                    }], ")"}]},
            {
              RowBox[{"(", GridBox[{
                    {"0"},
                    {"0"}
                    }], ")"}], 
              RowBox[{"(", GridBox[{
                    {"0"},
                    {"0"}
                    }], ")"}], 
              RowBox[{"(", GridBox[{
                    {"0"},
                    {"0"}
                    }], ")"}], 
              RowBox[{"(", GridBox[{
                    {"0"},
                    {"0"}
                    }], ")"}]},
            {
              RowBox[{"(", GridBox[{
                    {"0"},
                    {"1"}
                    }], ")"}], 
              RowBox[{"(", GridBox[{
                    {"0"},
                    {"1"}
                    }], ")"}], 
              RowBox[{"(", GridBox[{
                    {"0"},
                    {"0"}
                    }], ")"}], 
              RowBox[{"(", GridBox[{
                    {"0"},
                    {"1"}
                    }], ")"}]},
            {
              RowBox[{"(", GridBox[{
                    {"0"},
                    {"1"}
                    }], ")"}], 
              RowBox[{"(", GridBox[{
                    {"0"},
                    {"0"}
                    }], ")"}], 
              RowBox[{"(", GridBox[{
                    {"0"},
                    {"1"}
                    }], ")"}], 
              RowBox[{"(", GridBox[{
                    {"0"},
                    {"1"}
                    }], ")"}]},
            {
              RowBox[{"(", GridBox[{
                    {"0"},
                    {"0"}
                    }], ")"}], 
              RowBox[{"(", GridBox[{
                    {"0"},
                    {"0"}
                    }], ")"}], 
              RowBox[{"(", GridBox[{
                    {"0"},
                    {"1"}
                    }], ")"}], 
              RowBox[{"(", GridBox[{
                    {"0"},
                    {"0"}
                    }], ")"}]},
            {
              RowBox[{"(", GridBox[{
                    {"0"},
                    {"1"}
                    }], ")"}], 
              RowBox[{"(", GridBox[{
                    {"0"},
                    {"1"}
                    }], ")"}], 
              RowBox[{"(", GridBox[{
                    {"0"},
                    {"1"}
                    }], ")"}], 
              RowBox[{"(", GridBox[{
                    {"0"},
                    {"1"}
                    }], ")"}]},
            {
              RowBox[{"(", GridBox[{
                    {"0"},
                    {"0"}
                    }], ")"}], 
              RowBox[{"(", GridBox[{
                    {"0"},
                    {"0"}
                    }], ")"}], 
              RowBox[{"(", GridBox[{
                    {"0"},
                    {"0"}
                    }], ")"}], 
              RowBox[{"(", GridBox[{
                    {"0"},
                    {"0"}
                    }], ")"}]},
            {
              RowBox[{"(", GridBox[{
                    {"0"},
                    {"1"}
                    }], ")"}], 
              RowBox[{"(", GridBox[{
                    {"0"},
                    {"0"}
                    }], ")"}], 
              RowBox[{"(", GridBox[{
                    {"0"},
                    {"0"}
                    }], ")"}], 
              RowBox[{"(", GridBox[{
                    {"0"},
                    {"0"}
                    }], ")"}]},
            {
              RowBox[{"(", GridBox[{
                    {"0"},
                    {"0"}
                    }], ")"}], 
              RowBox[{"(", GridBox[{
                    {"0"},
                    {"0"}
                    }], ")"}], 
              RowBox[{"(", GridBox[{
                    {"0"},
                    {"0"}
                    }], ")"}], 
              RowBox[{"(", GridBox[{
                    {"0"},
                    {"0"}
                    }], ")"}]},
            {
              RowBox[{"(", GridBox[{
                    {"1"},
                    {"1"}
                    }], ")"}], 
              RowBox[{"(", GridBox[{
                    {"0"},
                    {"1"}
                    }], ")"}], 
              RowBox[{"(", GridBox[{
                    {"0"},
                    {"1"}
                    }], ")"}], 
              RowBox[{"(", GridBox[{
                    {"0"},
                    {"1"}
                    }], ")"}]},
            {
              RowBox[{"(", GridBox[{
                    {"0"},
                    {"0"}
                    }], ")"}], 
              RowBox[{"(", GridBox[{
                    {"0"},
                    {"0"}
                    }], ")"}], 
              RowBox[{"(", GridBox[{
                    {"0"},
                    {"0"}
                    }], ")"}], 
              RowBox[{"(", GridBox[{
                    {"0"},
                    {"0"}
                    }], ")"}]},
            {
              RowBox[{"(", GridBox[{
                    {"0"},
                    {"0"}
                    }], ")"}], 
              RowBox[{"(", GridBox[{
                    {"0"},
                    {"1"}
                    }], ")"}], 
              RowBox[{"(", GridBox[{
                    {"1"},
                    {"1"}
                    }], ")"}], 
              RowBox[{"(", GridBox[{
                    {"0"},
                    {"1"}
                    }], ")"}]},
            {
              RowBox[{"(", GridBox[{
                    {"0"},
                    {"0"}
                    }], ")"}], 
              RowBox[{"(", GridBox[{
                    {"1"},
                    {"1"}
                    }], ")"}], 
              RowBox[{"(", GridBox[{
                    {"1"},
                    {"1"}
                    }], ")"}], 
              RowBox[{"(", GridBox[{
                    {"0"},
                    {"1"}
                    }], ")"}]},
            {
              RowBox[{"(", GridBox[{
                    {"1"},
                    {"1"}
                    }], ")"}], 
              RowBox[{"(", GridBox[{
                    {"0"},
                    {"0"}
                    }], ")"}], 
              RowBox[{"(", GridBox[{
                    {"0"},
                    {"1"}
                    }], ")"}], 
              RowBox[{"(", GridBox[{
                    {"0"},
                    {"0"}
                    }], ")"}]},
            {
              RowBox[{"(", GridBox[{
                    {"1"},
                    {"1"}
                    }], ")"}], 
              RowBox[{"(", GridBox[{
                    {"0"},
                    {"1"}
                    }], ")"}], 
              RowBox[{"(", GridBox[{
                    {"0"},
                    {"1"}
                    }], ")"}], 
              RowBox[{"(", GridBox[{
                    {"1"},
                    {"1"}
                    }], ")"}]},
            {
              RowBox[{"(", GridBox[{
                    {"0"},
                    {"0"}
                    }], ")"}], 
              RowBox[{"(", GridBox[{
                    {"0"},
                    {"0"}
                    }], ")"}], 
              RowBox[{"(", GridBox[{
                    {"0"},
                    {"0"}
                    }], ")"}], 
              RowBox[{"(", GridBox[{
                    {"0"},
                    {"0"}
                    }], ")"}]},
            {
              RowBox[{"(", GridBox[{
                    {"1"},
                    {"1"}
                    }], ")"}], 
              RowBox[{"(", GridBox[{
                    {"0"},
                    {"0"}
                    }], ")"}], 
              RowBox[{"(", GridBox[{
                    {"0"},
                    {"1"}
                    }], ")"}], 
              RowBox[{"(", GridBox[{
                    {"0"},
                    {"0"}
                    }], ")"}]},
            {
              RowBox[{"(", GridBox[{
                    {"0"},
                    {"1"}
                    }], ")"}], 
              RowBox[{"(", GridBox[{
                    {"0"},
                    {"0"}
                    }], ")"}], 
              RowBox[{"(", GridBox[{
                    {"0"},
                    {"0"}
                    }], ")"}], 
              RowBox[{"(", GridBox[{
                    {"0"},
                    {"1"}
                    }], ")"}]},
            {
              RowBox[{"(", GridBox[{
                    {"0"},
                    {"1"}
                    }], ")"}], 
              RowBox[{"(", GridBox[{
                    {"0"},
                    {"0"}
                    }], ")"}], 
              RowBox[{"(", GridBox[{
                    {"0"},
                    {"0"}
                    }], ")"}], 
              RowBox[{"(", GridBox[{
                    {"0"},
                    {"0"}
                    }], ")"}]},
            {
              RowBox[{"(", GridBox[{
                    {"0"},
                    {"1"}
                    }], ")"}], 
              RowBox[{"(", GridBox[{
                    {"0"},
                    {"0"}
                    }], ")"}], 
              RowBox[{"(", GridBox[{
                    {"1"},
                    {"1"}
                    }], ")"}], 
              RowBox[{"(", GridBox[{
                    {"0"},
                    {"1"}
                    }], ")"}]},
            {
              RowBox[{"(", GridBox[{
                    {"0"},
                    {"1"}
                    }], ")"}], 
              RowBox[{"(", GridBox[{
                    {"0"},
                    {"0"}
                    }], ")"}], 
              RowBox[{"(", GridBox[{
                    {"0"},
                    {"0"}
                    }], ")"}], 
              RowBox[{"(", GridBox[{
                    {"0"},
                    {"0"}
                    }], ")"}]}
            }], ")"}],
      MatrixForm[ {{{0, 1}, {0, 0}, {0, 0}, {0, 0}}, {{0, 0}, {0, 0}, {0, 
        0}, {0, 0}}, {{0, 0}, {0, 0}, {0, 0}, {0, 0}}, {{1, 1}, {0, 0}, {0, 
        1}, {0, 0}}, {{0, 0}, {0, 0}, {0, 0}, {0, 0}}, {{0, 1}, {0, 0}, {0, 
        1}, {1, 1}}, {{0, 1}, {0, 0}, {0, 0}, {1, 1}}, {{1, 1}, {0, 0}, {0, 
        1}, {0, 0}}, {{0, 0}, {0, 1}, {1, 1}, {0, 1}}, {{0, 1}, {0, 1}, {0, 
        1}, {1, 1}}, {{0, 0}, {0, 0}, {0, 0}, {0, 0}}, {{1, 1}, {0, 1}, {0, 
        0}, {0, 1}}, {{0, 0}, {0, 1}, {1, 1}, {1, 1}}, {{0, 0}, {0, 0}, {0, 
        1}, {0, 0}}, {{1, 1}, {0, 1}, {0, 1}, {0, 1}}, {{0, 1}, {0, 0}, {0, 
        0}, {1, 1}}, {{0, 0}, {0, 1}, {0, 1}, {0, 0}}, {{0, 0}, {0, 0}, {0, 
        0}, {0, 0}}, {{0, 1}, {0, 1}, {0, 0}, {0, 1}}, {{0, 1}, {0, 0}, {0, 
        1}, {0, 1}}, {{0, 0}, {0, 0}, {0, 1}, {0, 0}}, {{0, 1}, {0, 1}, {0, 
        1}, {0, 1}}, {{0, 0}, {0, 0}, {0, 0}, {0, 0}}, {{0, 1}, {0, 0}, {0, 
        0}, {0, 0}}, {{0, 0}, {0, 0}, {0, 0}, {0, 0}}, {{1, 1}, {0, 1}, {0, 
        1}, {0, 1}}, {{0, 0}, {0, 0}, {0, 0}, {0, 0}}, {{0, 0}, {0, 1}, {1, 
        1}, {0, 1}}, {{0, 0}, {1, 1}, {1, 1}, {0, 1}}, {{1, 1}, {0, 0}, {0, 
        1}, {0, 0}}, {{1, 1}, {0, 1}, {0, 1}, {1, 1}}, {{0, 0}, {0, 0}, {0, 
        0}, {0, 0}}, {{1, 1}, {0, 0}, {0, 1}, {0, 0}}, {{0, 1}, {0, 0}, {0, 
        0}, {0, 1}}, {{0, 1}, {0, 0}, {0, 0}, {0, 0}}, {{0, 1}, {0, 0}, {1, 
        1}, {0, 1}}, {{0, 1}, {0, 0}, {0, 0}, {0, 0}}}]]], "Output",
  CellLabel->"Out[3]//MatrixForm="]
}, Closed]],

Cell["Locus names should be specified:", "MathCaption"],

Cell[BoxData[
    \(LocusNames[
        1063] = {"\<Gpi\>", "\<Mdh\>", "\<Idh\>", "\<Pgi\>"}; \)], "Input",
  CellLabel->"In[123]:=  (9:31:51 on 8/14/00)"],

Cell["These are the numbers of each of the 81 possible genotypes:", \
"MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[
    \(ReducedData[1063, 4, Detail \[Rule] True] // TableForm\)], "Input",
  CellLabel->"In[4]:="],

Cell[BoxData[
    InterpretationBox[GridBox[{
          {"9", GridBox[{
                {"0", "0"},
                {"0", "0"},
                {"0", "0"},
                {"0", "0"}
                },
              RowSpacings->0.25,
              ColumnSpacings->1,
              RowAlignments->Baseline,
              ColumnAlignments->{Left}]},
          {"0", GridBox[{
                {"0", "0"},
                {"0", "0"},
                {"0", "0"},
                {"0", "1"}
                },
              RowSpacings->0.25,
              ColumnSpacings->1,
              RowAlignments->Baseline,
              ColumnAlignments->{Left}]},
          {"0", GridBox[{
                {"0", "0"},
                {"0", "0"},
                {"0", "0"},
                {"1", "1"}
                },
              RowSpacings->0.25,
              ColumnSpacings->1,
              RowAlignments->Baseline,
              ColumnAlignments->{Left}]},
          {"2", GridBox[{
                {"0", "0"},
                {"0", "0"},
                {"0", "1"},
                {"0", "0"}
                },
              RowSpacings->0.25,
              ColumnSpacings->1,
              RowAlignments->Baseline,
              ColumnAlignments->{Left}]},
          {"0", GridBox[{
                {"0", "0"},
                {"0", "0"},
                {"0", "1"},
                {"0", "1"}
                },
              RowSpacings->0.25,
              ColumnSpacings->1,
              RowAlignments->Baseline,
              ColumnAlignments->{Left}]},
          {"0", GridBox[{
                {"0", "0"},
                {"0", "0"},
                {"0", "1"},
                {"1", "1"}
                },
              RowSpacings->0.25,
              ColumnSpacings->1,
              RowAlignments->Baseline,
              ColumnAlignments->{Left}]},
          {"0", GridBox[{
                {"0", "0"},
                {"0", "0"},
                {"1", "1"},
                {"0", "0"}
                },
              RowSpacings->0.25,
              ColumnSpacings->1,
              RowAlignments->Baseline,
              ColumnAlignments->{Left}]},
          {"0", GridBox[{
                {"0", "0"},
                {"0", "0"},
                {"1", "1"},
                {"0", "1"}
                },
              RowSpacings->0.25,
              ColumnSpacings->1,
              RowAlignments->Baseline,
              ColumnAlignments->{Left}]},
          {"0", GridBox[{
                {"0", "0"},
                {"0", "0"},
                {"1", "1"},
                {"1", "1"}
                },
              RowSpacings->0.25,
              ColumnSpacings->1,
              RowAlignments->Baseline,
              ColumnAlignments->{Left}]},
          {"0", GridBox[{
                {"0", "0"},
                {"0", "1"},
                {"0", "0"},
                {"0", "0"}
                },
              RowSpacings->0.25,
              ColumnSpacings->1,
              RowAlignments->Baseline,
              ColumnAlignments->{Left}]},
          {"0", GridBox[{
                {"0", "0"},
                {"0", "1"},
                {"0", "0"},
                {"0", "1"}
                },
              RowSpacings->0.25,
              ColumnSpacings->1,
              RowAlignments->Baseline,
              ColumnAlignments->{Left}]},
          {"0", GridBox[{
                {"0", "0"},
                {"0", "1"},
                {"0", "0"},
                {"1", "1"}
                },
              RowSpacings->0.25,
              ColumnSpacings->1,
              RowAlignments->Baseline,
              ColumnAlignments->{Left}]},
          {"1", GridBox[{
                {"0", "0"},
                {"0", "1"},
                {"0", "1"},
                {"0", "0"}
                },
              RowSpacings->0.25,
              ColumnSpacings->1,
              RowAlignments->Baseline,
              ColumnAlignments->{Left}]},
          {"0", GridBox[{
                {"0", "0"},
                {"0", "1"},
                {"0", "1"},
                {"0", "1"}
                },
              RowSpacings->0.25,
              ColumnSpacings->1,
              RowAlignments->Baseline,
              ColumnAlignments->{Left}]},
          {"0", GridBox[{
                {"0", "0"},
                {"0", "1"},
                {"0", "1"},
                {"1", "1"}
                },
              RowSpacings->0.25,
              ColumnSpacings->1,
              RowAlignments->Baseline,
              ColumnAlignments->{Left}]},
          {"0", GridBox[{
                {"0", "0"},
                {"0", "1"},
                {"1", "1"},
                {"0", "0"}
                },
              RowSpacings->0.25,
              ColumnSpacings->1,
              RowAlignments->Baseline,
              ColumnAlignments->{Left}]},
          {"2", GridBox[{
                {"0", "0"},
                {"0", "1"},
                {"1", "1"},
                {"0", "1"}
                },
              RowSpacings->0.25,
              ColumnSpacings->1,
              RowAlignments->Baseline,
              ColumnAlignments->{Left}]},
          {"1", GridBox[{
                {"0", "0"},
                {"0", "1"},
                {"1", "1"},
                {"1", "1"}
                },
              RowSpacings->0.25,
              ColumnSpacings->1,
              RowAlignments->Baseline,
              ColumnAlignments->{Left}]},
          {"0", GridBox[{
                {"0", "0"},
                {"1", "1"},
                {"0", "0"},
                {"0", "0"}
                },
              RowSpacings->0.25,
              ColumnSpacings->1,
              RowAlignments->Baseline,
              ColumnAlignments->{Left}]},
          {"0", GridBox[{
                {"0", "0"},
                {"1", "1"},
                {"0", "0"},
                {"0", "1"}
                },
              RowSpacings->0.25,
              ColumnSpacings->1,
              RowAlignments->Baseline,
              ColumnAlignments->{Left}]},
          {"0", GridBox[{
                {"0", "0"},
                {"1", "1"},
                {"0", "0"},
                {"1", "1"}
                },
              RowSpacings->0.25,
              ColumnSpacings->1,
              RowAlignments->Baseline,
              ColumnAlignments->{Left}]},
          {"0", GridBox[{
                {"0", "0"},
                {"1", "1"},
                {"0", "1"},
                {"0", "0"}
                },
              RowSpacings->0.25,
              ColumnSpacings->1,
              RowAlignments->Baseline,
              ColumnAlignments->{Left}]},
          {"0", GridBox[{
                {"0", "0"},
                {"1", "1"},
                {"0", "1"},
                {"0", "1"}
                },
              RowSpacings->0.25,
              ColumnSpacings->1,
              RowAlignments->Baseline,
              ColumnAlignments->{Left}]},
          {"0", GridBox[{
                {"0", "0"},
                {"1", "1"},
                {"0", "1"},
                {"1", "1"}
                },
              RowSpacings->0.25,
              ColumnSpacings->1,
              RowAlignments->Baseline,
              ColumnAlignments->{Left}]},
          {"0", GridBox[{
                {"0", "0"},
                {"1", "1"},
                {"1", "1"},
                {"0", "0"}
                },
              RowSpacings->0.25,
              ColumnSpacings->1,
              RowAlignments->Baseline,
              ColumnAlignments->{Left}]},
          {"1", GridBox[{
                {"0", "0"},
                {"1", "1"},
                {"1", "1"},
                {"0", "1"}
                },
              RowSpacings->0.25,
              ColumnSpacings->1,
              RowAlignments->Baseline,
              ColumnAlignments->{Left}]},
          {"0", GridBox[{
                {"0", "0"},
                {"1", "1"},
                {"1", "1"},
                {"1", "1"}
                },
              RowSpacings->0.25,
              ColumnSpacings->1,
              RowAlignments->Baseline,
              ColumnAlignments->{Left}]},
          {"4", GridBox[{
                {"0", "1"},
                {"0", "0"},
                {"0", "0"},
                {"0", "0"}
                },
              RowSpacings->0.25,
              ColumnSpacings->1,
              RowAlignments->Baseline,
              ColumnAlignments->{Left}]},
          {"1", GridBox[{
                {"0", "1"},
                {"0", "0"},
                {"0", "0"},
                {"0", "1"}
                },
              RowSpacings->0.25,
              ColumnSpacings->1,
              RowAlignments->Baseline,
              ColumnAlignments->{Left}]},
          {"2", GridBox[{
                {"0", "1"},
                {"0", "0"},
                {"0", "0"},
                {"1", "1"}
                },
              RowSpacings->0.25,
              ColumnSpacings->1,
              RowAlignments->Baseline,
              ColumnAlignments->{Left}]},
          {"0", GridBox[{
                {"0", "1"},
                {"0", "0"},
                {"0", "1"},
                {"0", "0"}
                },
              RowSpacings->0.25,
              ColumnSpacings->1,
              RowAlignments->Baseline,
              ColumnAlignments->{Left}]},
          {"1", GridBox[{
                {"0", "1"},
                {"0", "0"},
                {"0", "1"},
                {"0", "1"}
                },
              RowSpacings->0.25,
              ColumnSpacings->1,
              RowAlignments->Baseline,
              ColumnAlignments->{Left}]},
          {"1", GridBox[{
                {"0", "1"},
                {"0", "0"},
                {"0", "1"},
                {"1", "1"}
                },
              RowSpacings->0.25,
              ColumnSpacings->1,
              RowAlignments->Baseline,
              ColumnAlignments->{Left}]},
          {"0", GridBox[{
                {"0", "1"},
                {"0", "0"},
                {"1", "1"},
                {"0", "0"}
                },
              RowSpacings->0.25,
              ColumnSpacings->1,
              RowAlignments->Baseline,
              ColumnAlignments->{Left}]},
          {"1", GridBox[{
                {"0", "1"},
                {"0", "0"},
                {"1", "1"},
                {"0", "1"}
                },
              RowSpacings->0.25,
              ColumnSpacings->1,
              RowAlignments->Baseline,
              ColumnAlignments->{Left}]},
          {"0", GridBox[{
                {"0", "1"},
                {"0", "0"},
                {"1", "1"},
                {"1", "1"}
                },
              RowSpacings->0.25,
              ColumnSpacings->1,
              RowAlignments->Baseline,
              ColumnAlignments->{Left}]},
          {"0", GridBox[{
                {"0", "1"},
                {"0", "1"},
                {"0", "0"},
                {"0", "0"}
                },
              RowSpacings->0.25,
              ColumnSpacings->1,
              RowAlignments->Baseline,
              ColumnAlignments->{Left}]},
          {"1", GridBox[{
                {"0", "1"},
                {"0", "1"},
                {"0", "0"},
                {"0", "1"}
                },
              RowSpacings->0.25,
              ColumnSpacings->1,
              RowAlignments->Baseline,
              ColumnAlignments->{Left}]},
          {"0", GridBox[{
                {"0", "1"},
                {"0", "1"},
                {"0", "0"},
                {"1", "1"}
                },
              RowSpacings->0.25,
              ColumnSpacings->1,
              RowAlignments->Baseline,
              ColumnAlignments->{Left}]},
          {"0", GridBox[{
                {"0", "1"},
                {"0", "1"},
                {"0", "1"},
                {"0", "0"}
                },
              RowSpacings->0.25,
              ColumnSpacings->1,
              RowAlignments->Baseline,
              ColumnAlignments->{Left}]},
          {"1", GridBox[{
                {"0", "1"},
                {"0", "1"},
                {"0", "1"},
                {"0", "1"}
                },
              RowSpacings->0.25,
              ColumnSpacings->1,
              RowAlignments->Baseline,
              ColumnAlignments->{Left}]},
          {"1", GridBox[{
                {"0", "1"},
                {"0", "1"},
                {"0", "1"},
                {"1", "1"}
                },
              RowSpacings->0.25,
              ColumnSpacings->1,
              RowAlignments->Baseline,
              ColumnAlignments->{Left}]},
          {"0", GridBox[{
                {"0", "1"},
                {"0", "1"},
                {"1", "1"},
                {"0", "0"}
                },
              RowSpacings->0.25,
              ColumnSpacings->1,
              RowAlignments->Baseline,
              ColumnAlignments->{Left}]},
          {"0", GridBox[{
                {"0", "1"},
                {"0", "1"},
                {"1", "1"},
                {"0", "1"}
                },
              RowSpacings->0.25,
              ColumnSpacings->1,
              RowAlignments->Baseline,
              ColumnAlignments->{Left}]},
          {"0", GridBox[{
                {"0", "1"},
                {"0", "1"},
                {"1", "1"},
                {"1", "1"}
                },
              RowSpacings->0.25,
              ColumnSpacings->1,
              RowAlignments->Baseline,
              ColumnAlignments->{Left}]},
          {"0", GridBox[{
                {"0", "1"},
                {"1", "1"},
                {"0", "0"},
                {"0", "0"}
                },
              RowSpacings->0.25,
              ColumnSpacings->1,
              RowAlignments->Baseline,
              ColumnAlignments->{Left}]},
          {"0", GridBox[{
                {"0", "1"},
                {"1", "1"},
                {"0", "0"},
                {"0", "1"}
                },
              RowSpacings->0.25,
              ColumnSpacings->1,
              RowAlignments->Baseline,
              ColumnAlignments->{Left}]},
          {"0", GridBox[{
                {"0", "1"},
                {"1", "1"},
                {"0", "0"},
                {"1", "1"}
                },
              RowSpacings->0.25,
              ColumnSpacings->1,
              RowAlignments->Baseline,
              ColumnAlignments->{Left}]},
          {"0", GridBox[{
                {"0", "1"},
                {"1", "1"},
                {"0", "1"},
                {"0", "0"}
                },
              RowSpacings->0.25,
              ColumnSpacings->1,
              RowAlignments->Baseline,
              ColumnAlignments->{Left}]},
          {"0", GridBox[{
                {"0", "1"},
                {"1", "1"},
                {"0", "1"},
                {"0", "1"}
                },
              RowSpacings->0.25,
              ColumnSpacings->1,
              RowAlignments->Baseline,
              ColumnAlignments->{Left}]},
          {"0", GridBox[{
                {"0", "1"},
                {"1", "1"},
                {"0", "1"},
                {"1", "1"}
                },
              RowSpacings->0.25,
              ColumnSpacings->1,
              RowAlignments->Baseline,
              ColumnAlignments->{Left}]},
          {"0", GridBox[{
                {"0", "1"},
                {"1", "1"},
                {"1", "1"},
                {"0", "0"}
                },
              RowSpacings->0.25,
              ColumnSpacings->1,
              RowAlignments->Baseline,
              ColumnAlignments->{Left}]},
          {"0", GridBox[{
                {"0", "1"},
                {"1", "1"},
                {"1", "1"},
                {"0", "1"}
                },
              RowSpacings->0.25,
              ColumnSpacings->1,
              RowAlignments->Baseline,
              ColumnAlignments->{Left}]},
          {"0", GridBox[{
                {"0", "1"},
                {"1", "1"},
                {"1", "1"},
                {"1", "1"}
                },
              RowSpacings->0.25,
              ColumnSpacings->1,
              RowAlignments->Baseline,
              ColumnAlignments->{Left}]},
          {"0", GridBox[{
                {"1", "1"},
                {"0", "0"},
                {"0", "0"},
                {"0", "0"}
                },
              RowSpacings->0.25,
              ColumnSpacings->1,
              RowAlignments->Baseline,
              ColumnAlignments->{Left}]},
          {"0", GridBox[{
                {"1", "1"},
                {"0", "0"},
                {"0", "0"},
                {"0", "1"}
                },
              RowSpacings->0.25,
              ColumnSpacings->1,
              RowAlignments->Baseline,
              ColumnAlignments->{Left}]},
          {"0", GridBox[{
                {"1", "1"},
                {"0", "0"},
                {"0", "0"},
                {"1", "1"}
                },
              RowSpacings->0.25,
              ColumnSpacings->1,
              RowAlignments->Baseline,
              ColumnAlignments->{Left}]},
          {"4", GridBox[{
                {"1", "1"},
                {"0", "0"},
                {"0", "1"},
                {"0", "0"}
                },
              RowSpacings->0.25,
              ColumnSpacings->1,
              RowAlignments->Baseline,
              ColumnAlignments->{Left}]},
          {"0", GridBox[{
                {"1", "1"},
                {"0", "0"},
                {"0", "1"},
                {"0", "1"}
                },
              RowSpacings->0.25,
              ColumnSpacings->1,
              RowAlignments->Baseline,
              ColumnAlignments->{Left}]},
          {"0", GridBox[{
                {"1", "1"},
                {"0", "0"},
                {"0", "1"},
                {"1", "1"}
                },
              RowSpacings->0.25,
              ColumnSpacings->1,
              RowAlignments->Baseline,
              ColumnAlignments->{Left}]},
          {"0", GridBox[{
                {"1", "1"},
                {"0", "0"},
                {"1", "1"},
                {"0", "0"}
                },
              RowSpacings->0.25,
              ColumnSpacings->1,
              RowAlignments->Baseline,
              ColumnAlignments->{Left}]},
          {"0", GridBox[{
                {"1", "1"},
                {"0", "0"},
                {"1", "1"},
                {"0", "1"}
                },
              RowSpacings->0.25,
              ColumnSpacings->1,
              RowAlignments->Baseline,
              ColumnAlignments->{Left}]},
          {"0", GridBox[{
                {"1", "1"},
                {"0", "0"},
                {"1", "1"},
                {"1", "1"}
                },
              RowSpacings->0.25,
              ColumnSpacings->1,
              RowAlignments->Baseline,
              ColumnAlignments->{Left}]},
          {"0", GridBox[{
                {"1", "1"},
                {"0", "1"},
                {"0", "0"},
                {"0", "0"}
                },
              RowSpacings->0.25,
              ColumnSpacings->1,
              RowAlignments->Baseline,
              ColumnAlignments->{Left}]},
          {"1", GridBox[{
                {"1", "1"},
                {"0", "1"},
                {"0", "0"},
                {"0", "1"}
                },
              RowSpacings->0.25,
              ColumnSpacings->1,
              RowAlignments->Baseline,
              ColumnAlignments->{Left}]},
          {"0", GridBox[{
                {"1", "1"},
                {"0", "1"},
                {"0", "0"},
                {"1", "1"}
                },
              RowSpacings->0.25,
              ColumnSpacings->1,
              RowAlignments->Baseline,
              ColumnAlignments->{Left}]},
          {"0", GridBox[{
                {"1", "1"},
                {"0", "1"},
                {"0", "1"},
                {"0", "0"}
                },
              RowSpacings->0.25,
              ColumnSpacings->1,
              RowAlignments->Baseline,
              ColumnAlignments->{Left}]},
          {"2", GridBox[{
                {"1", "1"},
                {"0", "1"},
                {"0", "1"},
                {"0", "1"}
                },
              RowSpacings->0.25,
              ColumnSpacings->1,
              RowAlignments->Baseline,
              ColumnAlignments->{Left}]},
          {"1", GridBox[{
                {"1", "1"},
                {"0", "1"},
                {"0", "1"},
                {"1", "1"}
                },
              RowSpacings->0.25,
              ColumnSpacings->1,
              RowAlignments->Baseline,
              ColumnAlignments->{Left}]},
          {"0", GridBox[{
                {"1", "1"},
                {"0", "1"},
                {"1", "1"},
                {"0", "0"}
                },
              RowSpacings->0.25,
              ColumnSpacings->1,
              RowAlignments->Baseline,
              ColumnAlignments->{Left}]},
          {"0", GridBox[{
                {"1", "1"},
                {"0", "1"},
                {"1", "1"},
                {"0", "1"}
                },
              RowSpacings->0.25,
              ColumnSpacings->1,
              RowAlignments->Baseline,
              ColumnAlignments->{Left}]},
          {"0", GridBox[{
                {"1", "1"},
                {"0", "1"},
                {"1", "1"},
                {"1", "1"}
                },
              RowSpacings->0.25,
              ColumnSpacings->1,
              RowAlignments->Baseline,
              ColumnAlignments->{Left}]},
          {"0", GridBox[{
                {"1", "1"},
                {"1", "1"},
                {"0", "0"},
                {"0", "0"}
                },
              RowSpacings->0.25,
              ColumnSpacings->1,
              RowAlignments->Baseline,
              ColumnAlignments->{Left}]},
          {"0", GridBox[{
                {"1", "1"},
                {"1", "1"},
                {"0", "0"},
                {"0", "1"}
                },
              RowSpacings->0.25,
              ColumnSpacings->1,
              RowAlignments->Baseline,
              ColumnAlignments->{Left}]},
          {"0", GridBox[{
                {"1", "1"},
                {"1", "1"},
                {"0", "0"},
                {"1", "1"}
                },
              RowSpacings->0.25,
              ColumnSpacings->1,
              RowAlignments->Baseline,
              ColumnAlignments->{Left}]},
          {"0", GridBox[{
                {"1", "1"},
                {"1", "1"},
                {"0", "1"},
                {"0", "0"}
                },
              RowSpacings->0.25,
              ColumnSpacings->1,
              RowAlignments->Baseline,
              ColumnAlignments->{Left}]},
          {"0", GridBox[{
                {"1", "1"},
                {"1", "1"},
                {"0", "1"},
                {"0", "1"}
                },
              RowSpacings->0.25,
              ColumnSpacings->1,
              RowAlignments->Baseline,
              ColumnAlignments->{Left}]},
          {"0", GridBox[{
                {"1", "1"},
                {"1", "1"},
                {"0", "1"},
                {"1", "1"}
                },
              RowSpacings->0.25,
              ColumnSpacings->1,
              RowAlignments->Baseline,
              ColumnAlignments->{Left}]},
          {"0", GridBox[{
                {"1", "1"},
                {"1", "1"},
                {"1", "1"},
                {"0", "0"}
                },
              RowSpacings->0.25,
              ColumnSpacings->1,
              RowAlignments->Baseline,
              ColumnAlignments->{Left}]},
          {"0", GridBox[{
                {"1", "1"},
                {"1", "1"},
                {"1", "1"},
                {"0", "1"}
                },
              RowSpacings->0.25,
              ColumnSpacings->1,
              RowAlignments->Baseline,
              ColumnAlignments->{Left}]},
          {"0", GridBox[{
                {"1", "1"},
                {"1", "1"},
                {"1", "1"},
                {"1", "1"}
                },
              RowSpacings->0.25,
              ColumnSpacings->1,
              RowAlignments->Baseline,
              ColumnAlignments->{Left}]}
          },
        RowSpacings->1,
        ColumnSpacings->3,
        RowAlignments->Baseline,
        ColumnAlignments->{Left}],
      TableForm[ {{9, {{0, 0}, {0, 0}, {0, 0}, {0, 0}}}, {0, {{0, 0}, {0, 
        0}, {0, 0}, {0, 1}}}, {0, {{0, 0}, {0, 0}, {0, 0}, {1, 1}}}, {2, {{0, 
        0}, {0, 0}, {0, 1}, {0, 0}}}, {0, {{0, 0}, {0, 0}, {0, 1}, {0, 1}}}, {
        0, {{0, 0}, {0, 0}, {0, 1}, {1, 1}}}, {0, {{0, 0}, {0, 0}, {1, 1}, {0,
         0}}}, {0, {{0, 0}, {0, 0}, {1, 1}, {0, 1}}}, {0, {{0, 0}, {0, 0}, {1,
         1}, {1, 1}}}, {0, {{0, 0}, {0, 1}, {0, 0}, {0, 0}}}, {0, {{0, 0}, {0,
         1}, {0, 0}, {0, 1}}}, {0, {{0, 0}, {0, 1}, {0, 0}, {1, 1}}}, {1, {{0,
         0}, {0, 1}, {0, 1}, {0, 0}}}, {0, {{0, 0}, {0, 1}, {0, 1}, {0, 
        1}}}, {0, {{0, 0}, {0, 1}, {0, 1}, {1, 1}}}, {0, {{0, 0}, {0, 1}, {1, 
        1}, {0, 0}}}, {2, {{0, 0}, {0, 1}, {1, 1}, {0, 1}}}, {1, {{0, 0}, {0, 
        1}, {1, 1}, {1, 1}}}, {0, {{0, 0}, {1, 1}, {0, 0}, {0, 0}}}, {0, {{0, 
        0}, {1, 1}, {0, 0}, {0, 1}}}, {0, {{0, 0}, {1, 1}, {0, 0}, {1, 1}}}, {
        0, {{0, 0}, {1, 1}, {0, 1}, {0, 0}}}, {0, {{0, 0}, {1, 1}, {0, 1}, {0,
         1}}}, {0, {{0, 0}, {1, 1}, {0, 1}, {1, 1}}}, {0, {{0, 0}, {1, 1}, {1,
         1}, {0, 0}}}, {1, {{0, 0}, {1, 1}, {1, 1}, {0, 1}}}, {0, {{0, 0}, {1,
         1}, {1, 1}, {1, 1}}}, {4, {{0, 1}, {0, 0}, {0, 0}, {0, 0}}}, {1, {{0,
         1}, {0, 0}, {0, 0}, {0, 1}}}, {2, {{0, 1}, {0, 0}, {0, 0}, {1, 
        1}}}, {0, {{0, 1}, {0, 0}, {0, 1}, {0, 0}}}, {1, {{0, 1}, {0, 0}, {0, 
        1}, {0, 1}}}, {1, {{0, 1}, {0, 0}, {0, 1}, {1, 1}}}, {0, {{0, 1}, {0, 
        0}, {1, 1}, {0, 0}}}, {1, {{0, 1}, {0, 0}, {1, 1}, {0, 1}}}, {0, {{0, 
        1}, {0, 0}, {1, 1}, {1, 1}}}, {0, {{0, 1}, {0, 1}, {0, 0}, {0, 0}}}, {
        1, {{0, 1}, {0, 1}, {0, 0}, {0, 1}}}, {0, {{0, 1}, {0, 1}, {0, 0}, {1,
         1}}}, {0, {{0, 1}, {0, 1}, {0, 1}, {0, 0}}}, {1, {{0, 1}, {0, 1}, {0,
         1}, {0, 1}}}, {1, {{0, 1}, {0, 1}, {0, 1}, {1, 1}}}, {0, {{0, 1}, {0,
         1}, {1, 1}, {0, 0}}}, {0, {{0, 1}, {0, 1}, {1, 1}, {0, 1}}}, {0, {{0,
         1}, {0, 1}, {1, 1}, {1, 1}}}, {0, {{0, 1}, {1, 1}, {0, 0}, {0, 
        0}}}, {0, {{0, 1}, {1, 1}, {0, 0}, {0, 1}}}, {0, {{0, 1}, {1, 1}, {0, 
        0}, {1, 1}}}, {0, {{0, 1}, {1, 1}, {0, 1}, {0, 0}}}, {0, {{0, 1}, {1, 
        1}, {0, 1}, {0, 1}}}, {0, {{0, 1}, {1, 1}, {0, 1}, {1, 1}}}, {0, {{0, 
        1}, {1, 1}, {1, 1}, {0, 0}}}, {0, {{0, 1}, {1, 1}, {1, 1}, {0, 1}}}, {
        0, {{0, 1}, {1, 1}, {1, 1}, {1, 1}}}, {0, {{1, 1}, {0, 0}, {0, 0}, {0,
         0}}}, {0, {{1, 1}, {0, 0}, {0, 0}, {0, 1}}}, {0, {{1, 1}, {0, 0}, {0,
         0}, {1, 1}}}, {4, {{1, 1}, {0, 0}, {0, 1}, {0, 0}}}, {0, {{1, 1}, {0,
         0}, {0, 1}, {0, 1}}}, {0, {{1, 1}, {0, 0}, {0, 1}, {1, 1}}}, {0, {{1,
         1}, {0, 0}, {1, 1}, {0, 0}}}, {0, {{1, 1}, {0, 0}, {1, 1}, {0, 
        1}}}, {0, {{1, 1}, {0, 0}, {1, 1}, {1, 1}}}, {0, {{1, 1}, {0, 1}, {0, 
        0}, {0, 0}}}, {1, {{1, 1}, {0, 1}, {0, 0}, {0, 1}}}, {0, {{1, 1}, {0, 
        1}, {0, 0}, {1, 1}}}, {0, {{1, 1}, {0, 1}, {0, 1}, {0, 0}}}, {2, {{1, 
        1}, {0, 1}, {0, 1}, {0, 1}}}, {1, {{1, 1}, {0, 1}, {0, 1}, {1, 1}}}, {
        0, {{1, 1}, {0, 1}, {1, 1}, {0, 0}}}, {0, {{1, 1}, {0, 1}, {1, 1}, {0,
         1}}}, {0, {{1, 1}, {0, 1}, {1, 1}, {1, 1}}}, {0, {{1, 1}, {1, 1}, {0,
         0}, {0, 0}}}, {0, {{1, 1}, {1, 1}, {0, 0}, {0, 1}}}, {0, {{1, 1}, {1,
         1}, {0, 0}, {1, 1}}}, {0, {{1, 1}, {1, 1}, {0, 1}, {0, 0}}}, {0, {{1,
         1}, {1, 1}, {0, 1}, {0, 1}}}, {0, {{1, 1}, {1, 1}, {0, 1}, {1, 
        1}}}, {0, {{1, 1}, {1, 1}, {1, 1}, {0, 0}}}, {0, {{1, 1}, {1, 1}, {1, 
        1}, {0, 1}}}, {0, {{1, 1}, {1, 1}, {1, 1}, {1, 1}}}}]]], "Output",
  CellLabel->"Out[4]//TableForm="]
}, Closed]],

Cell["These are the allele frequencies:", "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[
    \(pl = \(\(AlleleFrequencyTable[1063, 4] // N\) // Transpose\) // 
        Last\)], "Input",
  CellLabel->"In[5]:="],

Cell[BoxData[
    \({0.391891891891891894`, 0.175675675675675684`, 0.324324324324324342`, 
      0.310810810810810789`}\)], "Output",
  CellLabel->"Out[5]="]
}, Open  ]]
},
FrontEndVersion->"4.0 for Macintosh",
ScreenRectangle->{{0, 1152}, {0, 748}},
WindowSize->{897, 637},
WindowMargins->{{Automatic, 102}, {Automatic, 11}},
StyleDefinitions -> "HelpBrowser.nb",
MacintoshSystemPageSetup->"\<\
00h0001804P000000b02<?oaonl3>@91H`85N0?N0@00005X0FP000003j0:l001
0@00I00100000@0200000BL?00400000000000000000010000000000000@0?ne
oj/@7@]500P1000000000000000001T1\>"
]


(***********************************************************************
Cached data follows.  If you edit this Notebook file directly, not using
Mathematica, you must remove the line containing CacheID at the top of 
the file.  The cache data will then be recreated when you save this file 
from within Mathematica.
***********************************************************************)

(*CellTagsOutline
CellTagsIndex->{}
*)

(*CellTagsIndex
CellTagsIndex->{}
*)

(*NotebookFileOutline
Notebook[{
Cell[1717, 49, 99, 3, 36, "SubsectionIcon"],
Cell[1819, 54, 47, 0, 28, "MathCaption"],
Cell[1869, 56, 125, 3, 26, "Input"],
Cell[1997, 61, 369, 9, 28, "MathCaption"],
Cell[2369, 72, 1619, 44, 600, "Input"],
Cell[3991, 118, 129, 3, 28, "MathCaption"],

Cell[CellGroupData[{
Cell[4145, 125, 127, 3, 26, "Input"],
Cell[4275, 130, 20150, 652, 70, "Output"]
}, Closed]],
Cell[24440, 785, 55, 0, 18, "MathCaption"],
Cell[24498, 787, 155, 3, 38, "Input"],
Cell[24656, 792, 84, 1, 28, "MathCaption"],

Cell[CellGroupData[{
Cell[24765, 797, 111, 2, 26, "Input"],
Cell[24879, 801, 28350, 863, 70, "Output"]
}, Closed]],
Cell[53244, 1667, 56, 0, 18, "MathCaption"],

Cell[CellGroupData[{
Cell[53325, 1671, 134, 3, 26, "Input"],
Cell[53462, 1676, 157, 3, 20, "Output"]
}, Open  ]]
}
]
*)




(***********************************************************************
End of Mathematica Notebook file.
***********************************************************************)

