(***********************************************************************

                    Mathematica-Compatible Notebook

This notebook can be used on any computer system with Mathematica 4.0,
MathReader 4.0, or any compatible application. The data for the notebook 
starts with the line containing stars above.

To get the notebook into a Mathematica-compatible application, do one of 
the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing the 
word CacheID, otherwise Mathematica-compatible applications may try to 
use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
***********************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[      8445,        257]*)
(*NotebookOutlinePosition[      9510,        291]*)
(*  CellTagsIndexPosition[      9418,        285]*)
(*WindowFrame->Normal*)



Notebook[{

Cell[CellGroupData[{
Cell["Log likelihood: LogLikelihoodDisequilibrium[]", "SubsectionIcon"],

Cell[TextData[Cell[BoxData[
    FormBox[GridBox[{
          {
            RowBox[{
              FormBox[
                RowBox[{"LogLikelihoodDisequilibrium", "[", 
                  RowBox[{
                    StyleBox["site",
                      FontSlant->"Italic"], ",", " ", "p", ",", " ", 
                    "\[Delta]p", ",", "  ", "c"}]}],
                "TraditionalForm"], 
              "]"}], \(gives\ an\ expression\ for\ the\ log\ likelihood\ in\ \
terms\ of\ the\ matrix\ of\ moments, \ c\_\(j, k\)\)}
          }], TraditionalForm]]]], "DefinitionBox",
  CellTags->"LogLikelihoodDisequilibrium"],

Cell["\<\
These are the allele frequencies, estimated directly from the \
sample:\
\>", "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[
    \(pl = \(Transpose[AlleleFrequencyTable[1063, 4]] // N\) // 
        Last\)], "Input",
  CellLabel->"In[4]:="],

Cell["", "Output"]
}, Closed]],

Cell["\<\
This gives a complicated expression for the log likelihood as a \
function of the symmetric matrix of moments:\
\>", "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"LogLikelihoodDisequilibrium", "[", 
      RowBox[{"1063", ",", "pl", ",", \({1, 1, 1, 1}\), ",", 
        RowBox[{"(", GridBox[{
              {"1", "0", \(c\_\(2, 0\)\), \(c\_\(3, 0\)\), \(c\_\(4, 0\)\)},
              {
                "0", \(c\_\(1, 1\)\), \(c\_\(2, 1\)\), \(c\_\(3, 
                    1\)\), \(c\_\(4, 1\)\)},
              {\(c\_\(2, 0\)\), \(c\_\(2, 1\)\), \(c\_\(2, 2\)\), \(c\_\(3, 
                    2\)\), \(c\_\(4, 2\)\)},
              {\(c\_\(3, 0\)\), \(c\_\(3, 1\)\), \(c\_\(3, 2\)\), \(c\_\(3, 
                    3\)\), \(c\_\(4, 3\)\)},
              {\(c\_\(4, 0\)\), \(c\_\(4, 1\)\), \(c\_\(4, 2\)\), \(c\_\(4, 
                    3\)\), \(c\_\(4, 4\)\)}
              }], ")"}]}], "]"}]], "Input",
  CellLabel->"In[25]:="],

Cell["", "Output"]
}, Closed]],

Cell[TextData[Cell[BoxData[
    FormBox[GridBox[{
          {
            RowBox[{
              RowBox[{
                FormBox[
                  RowBox[{"LogLikelihoodDisequilibrium", "[", 
                    RowBox[{
                      StyleBox["site",
                        FontSlant->"Italic"], ",", " ", "p", ",", " ", 
                      "\[Delta]p", ",", "  ", "c"}]}],
                  "TraditionalForm"], ",", \(Compiled \[Rule] True\)}], 
              "]"}], \(is\ a\ compiled\ \(\(version\)\(.\)\)\)}
          }], TraditionalForm]]]], "DefinitionBox"],

Cell["The compiled version is much faster for numerical arguments:", \
"MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"Timing", "[", 
      RowBox[{"LogLikelihoodDisequilibrium", "[", 
        RowBox[{"1063", ",", "pl", ",", \({1, 1, 1, 1}\), ",", 
          RowBox[{"(", GridBox[{
                {"1", "0", "0.02", "0", "0"},
                {"0", "0.01", "0", "0", "0"},
                {"0.02", "0", "0", "0", "0"},
                {"0", "0", "0", "0", "0"},
                {"0", "0", "0", "0", "0"}
                }], ")"}], ",", \(Compiled \[Rule] True\)}], "]"}], 
      "]"}]], "Input",
  CellLabel->"In[26]:="],

Cell["", "Output"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"Timing", "[", 
      RowBox[{"LogLikelihoodDisequilibrium", "[", 
        RowBox[{"1063", ",", "pl", ",", \({1, 1, 1, 1}\), ",", 
          RowBox[{"(", GridBox[{
                {"1", "0", "0.02", "0", "0"},
                {"0", "0.01", "0", "0", "0"},
                {"0.02", "0", "0", "0", "0"},
                {"0", "0", "0", "0", "0"},
                {"0", "0", "0", "0", "0"}
                }], ")"}]}], "]"}], "]"}]], "Input",
  CellLabel->"In[27]:="],

Cell["", "Output"]
}, Closed]],

Cell[TextData[{
  "The compiled version checks that the genotype frequencies are \
non-negative; if they are not, it returns ",
  Cell[BoxData[
      \(TraditionalForm\`\(-10\^10\)\)]]
}], "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"LogLikelihoodDisequilibrium", "[", 
      RowBox[{"1063", ",", "pl", ",", \({1, 1, 1, 1}\), ",", 
        RowBox[{"(", GridBox[{
              {"1", "0", "0.02", "0", "0"},
              {"0", "0.2", "0", "0", "0"},
              {"0.02", "0", "0", "0", "0"},
              {"0", "0", "0", "0", "0"},
              {"0", "0", "0", "0", "0"}
              }], ")"}], ",", \(Compiled \[Rule] True\)}], "]"}]], "Input",
  CellLabel->"In[30]:="],

Cell["", "Output"]
}, Closed]],

Cell["The uncompiled version does not include this check:", "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"LogLikelihoodDisequilibrium", "[", 
      RowBox[{"1063", ",", "pl", ",", \({1, 1, 1, 1}\), ",", 
        RowBox[{"(", GridBox[{
              {"1", "0", "0.02", "0", "0"},
              {"0", "0.2", "0", "0", "0"},
              {"0.02", "0", "0", "0", "0"},
              {"0", "0", "0", "0", "0"},
              {"0", "0", "0", "0", "0"}
              }], ")"}]}], "]"}]], "Input",
  CellLabel->"In[29]:="],

Cell["", "Output"]
}, Closed]],

Cell[TextData[Cell[BoxData[
    FormBox[GridBox[{
          {
            RowBox[{
              RowBox[{
                FormBox[
                  RowBox[{"LogLikelihoodDisequilibrium", "[", 
                    RowBox[{
                      StyleBox["site",
                        FontSlant->"Italic"], ",", " ", \({p, \(p\^*\)}\), 
                      ",", " ", \({\[Delta]p, \(\[Delta]p\^*\)}\), ",", "  ", 
                      "c"}]}],
                  "TraditionalForm"], ",", \(Symmetric \[Rule] False\)}], 
              "]"}], \(\(allows\ for\ different\ male\  &\)\ female\ \
\(\(pools\)\(.\)\)\)}
          }], TraditionalForm]]]], "DefinitionBox"],

Cell["\<\
The first element of the second & third arguments give the allele \
frequencies & divergences for the female gamete pool, and the second element \
lists values for the male pool.  \
\>", "Text"],

Cell["Note that now, the matrix of moments need not be symmetric:", \
"MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"LogLikelihoodDisequilibrium", "[", 
      RowBox[{
      "1063", ",", \({pl, pl}\), 
        ",", \({{1, 1, 1, 1}, {0.9, 0.9, 0.9, 0.9}}\), ",", 
        RowBox[{"(", GridBox[{
              {"1", "0", "0.01", "0", "0"},
              {"0", "0.01", "0", "0", "0"},
              {"0.02", "0", "0", "0", "0"},
              {"0", "0", "0", "0", "0"},
              {"0", "0", "0", "0", "0"}
              }], ")"}], ",", \(Symmetric \[Rule] False\)}], "]"}]], "Input",
  CellLabel->"In[31]:="],

Cell[BoxData[
    \(\(-39.047465797948746`\)\)], "Output",
  CellLabel->"Out[31]="]
}, Closed]]
}, Open  ]]
},
FrontEndVersion->"4.0 for Macintosh",
ScreenRectangle->{{0, 1024}, {0, 748}},
WindowSize->{956, 721},
WindowMargins->{{-2, Automatic}, {Automatic, 1}},
StyleDefinitions -> "HelpBrowser.nb",
MacintoshSystemPageSetup->"\<\
00<0001804P000000`d26_oRon@3:`8f0dL5N`?N0080001804P000000`d26P01
0000I00000400@410?l00BL?00400@00000000000000000201T1T0000000@000
00000000004000000000000000010000\>"
]


(***********************************************************************
Cached data follows.  If you edit this Notebook file directly, not using
Mathematica, you must remove the line containing CacheID at the top of 
the file.  The cache data will then be recreated when you save this file 
from within Mathematica.
***********************************************************************)

(*CellTagsOutline
CellTagsIndex->{
  "LogLikelihoodDisequilibrium"->{
    Cell[1813, 53, 618, 14, 38, "DefinitionBox",
      CellTags->"LogLikelihoodDisequilibrium"]}
  }
*)

(*CellTagsIndex
CellTagsIndex->{
  {"LogLikelihoodDisequilibrium", 9295, 278}
  }
*)

(*NotebookFileOutline
Notebook[{

Cell[CellGroupData[{
Cell[1739, 51, 71, 0, 36, "SubsectionIcon"],
Cell[1813, 53, 618, 14, 38, "DefinitionBox",
  CellTags->"LogLikelihoodDisequilibrium"],
Cell[2434, 69, 102, 3, 28, "MathCaption"],

Cell[CellGroupData[{
Cell[2561, 76, 128, 3, 27, "Input"],
Cell[2692, 81, 18, 0, 20, "Output"]
}, Closed]],
Cell[2725, 84, 141, 3, 18, "MathCaption"],

Cell[CellGroupData[{
Cell[2891, 91, 793, 15, 98, "Input"],
Cell[3687, 108, 18, 0, 4040, "Output"]
}, Closed]],
Cell[3720, 111, 577, 13, 33, "DefinitionBox"],
Cell[4300, 126, 85, 1, 28, "MathCaption"],

Cell[CellGroupData[{
Cell[4410, 131, 529, 12, 92, "Input"],
Cell[4942, 145, 18, 0, 20, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[4997, 150, 490, 11, 88, "Input"],
Cell[5490, 163, 18, 0, 20, "Output"]
}, Closed]],
Cell[5523, 166, 203, 5, 20, "MathCaption"],

Cell[CellGroupData[{
Cell[5751, 175, 468, 10, 92, "Input"],
Cell[6222, 187, 18, 0, 20, "Output"]
}, Closed]],
Cell[6255, 190, 74, 0, 18, "MathCaption"],

Cell[CellGroupData[{
Cell[6354, 194, 436, 10, 92, "Input"],
Cell[6793, 206, 18, 0, 20, "Output"]
}, Closed]],
Cell[6826, 209, 667, 15, 33, "DefinitionBox"],
Cell[7496, 226, 204, 4, 22, "Text"],
Cell[7703, 232, 84, 1, 28, "MathCaption"],

Cell[CellGroupData[{
Cell[7812, 237, 519, 12, 92, "Input"],
Cell[8334, 251, 83, 2, 20, "Output"]
}, Closed]]
}, Open  ]]
}
]
*)




(***********************************************************************
End of Mathematica Notebook file.
***********************************************************************)

