(***********************************************************************

                    Mathematica-Compatible Notebook

This notebook can be used on any computer system with Mathematica 4.0,
MathReader 4.0, or any compatible application. The data for the notebook 
starts with the line containing stars above.

To get the notebook into a Mathematica-compatible application, do one of 
the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing the 
word CacheID, otherwise Mathematica-compatible applications may try to 
use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
***********************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[      4709,        121]*)
(*NotebookOutlinePosition[      5758,        155]*)
(*  CellTagsIndexPosition[      5672,        149]*)
(*WindowFrame->Normal*)



Notebook[{
Cell["Estimation using the Metropolis algorithm: Overview", "SubsectionIcon"],

Cell[TextData[{
  "\tThe Metropolis algorithm (Metropolis ",
  StyleBox["et al.",
    FontSlant->"Italic"],
  ", ",
  ButtonBox["1954",
    ButtonData:>{"References", "Metropolis et al 1954"},
    ButtonStyle->"AddOnsLink",
    ButtonNote->"1954"],
  ") generates a random walk with density proportional to the likelihood.  \
This can be used either to find the likelihood surface, or to search for \
maximum likelihood estimates.  The algorithm makes a random change to a set \
of parameters ",
  Cell[BoxData[
      FormBox[
        RowBox[{"(", 
          RowBox[{
            FormBox[\(x\+_\),
              "TraditionalForm"], "\[Rule]", \(x\+_\^*\)}], ")"}], 
        TraditionalForm]]],
  "; if this increases the likelihood, it is accepted, whilst if it decreases \
the likelihood, it is accepted with probability ",
  Cell[BoxData[
      \(TraditionalForm\`\((\(L\^*\)\/L)\)\^T\)]],
  ".  This generates a random sequence with density ",
  Cell[BoxData[
      \(TraditionalForm\`L\^T\)]],
  ". The parameter ",
  Cell[BoxData[
      \(TraditionalForm\`T\)]],
  " is referred to as a \"temperature\".  If it is large, a wide range of \
parameter space is explored: this is appropriate in the initial stages of a \
search, where regions of high likelihood are to be found, and local peaks \
avoided.  If ",
  Cell[BoxData[
      \(TraditionalForm\`T = 1\)]],
  ", then the random walk follows the likelihood surface, and can be used to \
construct support surfaces for arbitrary functions of the parameters. If ",
  Cell[BoxData[
      \(TraditionalForm\`T = 0\)]],
  ", the sequence climbs uphill to a nearby peak. "
}], "Text"],

Cell[TextData[{
  "\t If the temperature is decreased towards zero sufficiently slowly, a \
global optimum will be reached; this is known as \"simulated annealing\" \
(Kirkpatrick ",
  StyleBox["et al",
    FontSlant->"Italic"],
  "., 1984).  However, there is no easy way to know what is \"sufficiently \
slow\".   From a Bayesian point of view, the distribution of random changes \
determines a prior probability for the parameters.  Here, a uniform \
distribution is used, with a certain step size.  The step size is chosen \
initially on the basis of the bounds on the parameter values, such that \
impossible parameter combinations are avoided.  (This is a difficult \
calculation).  It is then adjusted by decreasing by a factor \
$MetropolisAdjustment (by default, 0.95) when changes are rejected, and \
increasing by 1/$MetropolisAdjustment when changes ae rejected.  Random \
changes are tried for each parameter in turn."
}], "Text"],

Cell[TextData[Cell[BoxData[
    FormBox[GridBox[{
          {
            "$MetropolisAdjustment", \(determines\ how\ the\ step\ size\ is\ \
adjusted\ in\ the\ Metropolis\ alhgorithm; \ 
            by\ default, \ \(\(0.95\)\(.\)\)\)}
          }], TraditionalForm]]]], "DefinitionBox",
  CellTags->"$MetropolisAdjustment"]
},
FrontEndVersion->"4.0 for Macintosh",
ScreenRectangle->{{0, 1152}, {0, 748}},
WindowSize->{520, 626},
WindowMargins->{{245, Automatic}, {Automatic, 46}},
StyleDefinitions -> "HelpBrowser.nb",
MacintoshSystemPageSetup->"\<\
00h0001804P000000b02<?oaonl3>@91H`85N0?N0@00005X0FP000003j0:l001
0@00I00100000@0200000BL?00400000000000000000010000000000000@0?ne
oj/@7@]500P1000000000000000001T1\>"
]


(***********************************************************************
Cached data follows.  If you edit this Notebook file directly, not using
Mathematica, you must remove the line containing CacheID at the top of 
the file.  The cache data will then be recreated when you save this file 
from within Mathematica.
***********************************************************************)

(*CellTagsOutline
CellTagsIndex->{
  "$MetropolisAdjustment"->{
    Cell[4382, 112, 323, 7, 52, "DefinitionBox",
      CellTags->"$MetropolisAdjustment"]}
  }
*)

(*CellTagsIndex
CellTagsIndex->{
  {"$MetropolisAdjustment", 5555, 142}
  }
*)

(*NotebookFileOutline
Notebook[{
Cell[1717, 49, 77, 0, 36, "SubsectionIcon"],
Cell[1797, 51, 1636, 41, 158, "Text"],
Cell[3436, 94, 943, 16, 136, "Text"],
Cell[4382, 112, 323, 7, 52, "DefinitionBox",
  CellTags->"$MetropolisAdjustment"]
}
]
*)




(***********************************************************************
End of Mathematica Notebook file.
***********************************************************************)

