(***********************************************************************

                    Mathematica-Compatible Notebook

This notebook can be used on any computer system with Mathematica 4.0,
MathReader 4.0, or any compatible application. The data for the notebook 
starts with the line containing stars above.

To get the notebook into a Mathematica-compatible application, do one of 
the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing the 
word CacheID, otherwise Mathematica-compatible applications may try to 
use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
***********************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[    254531,       5387]*)
(*NotebookOutlinePosition[    257966,       5475]*)
(*  CellTagsIndexPosition[    257345,       5457]*)
(*WindowFrame->Normal*)



Notebook[{

Cell[CellGroupData[{
Cell["Obsolete functions", "SubsectionIcon"],

Cell["This loads the package:", "MathCaption"],

Cell[BoxData[
    \(\(<< Multilocus`EstimatingD`;\)\)], "Input",
  CellLabel->"In[21]:="],

Cell[CellGroupData[{

Cell["Notes", "SubsubsectionIcon"],

Cell[TextData[{
  "The package ",
  StyleBox["Multilocus`EstimatingD`",
    FontSlant->"Italic"],
  " includes many routines that calculate genotype frequencies from a reduced \
set of moments.  Within-genome moments are reduced to a set ",
  Cell[BoxData[
      \(TraditionalForm\`c\_w[2], \[Ellipsis]c\_w[j] \[Ellipsis]\)]],
  ", where ",
  Cell[BoxData[
      \(TraditionalForm\`j\)]],
  " is the number of loci involved; similarly, between-genome moments are \
reduced to a set ",
  Cell[BoxData[
      \(TraditionalForm\`c\_b[2], \[Ellipsis]c\_b[j] \[Ellipsis]\)]],
  ", where ",
  Cell[BoxData[
      \(TraditionalForm\`j\)]],
  " is the total # of loci involved.  These can also be transformed to \
cumulants.  However, this scheme is unsatisfactory: although to a good \
approximation all between-genome moments involving a certain number of loci \
have the same magnitude in admixture models, there are some differences; and \
it may be impossible to produce positive genotype frequencies if these \
differences are not taken into account.  Therefore, it is best to represent \
moments as a matrix, ",
  Cell[BoxData[
      \(TraditionalForm\`c\_\(j, k\)\)]],
  ", where ",
  Cell[BoxData[
      \(TraditionalForm\`j\)]],
  " loci are drawn from one genome, and ",
  Cell[BoxData[
      \(TraditionalForm\`k\)]],
  " from the other.  This gives an exact fit to an admixture model."
}], "Text"],

Cell["\<\
\tThis notebook documents some of the obsolete functions that use \
the reduced set of moments & cumulants.\
\>", "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
Diploid genotype frequencies from reduced cumulants: \
DiploidGenotypeFrequencyReduced[], FullGenotypeFrequencyReduced[]\
\>", \
"SubsubsectionIcon",
  CellTags->{
  "DiploidGenotypeFrequencyReduced", "FullGenotypeFrequencyReduced"}],

Cell[TextData[Cell[BoxData[
    FormBox[GridBox[{
          {
            
            FormBox[\(DiploidGenotypeFrequencyReduced[
                X, \ {k\_w, k\_b}, \ \[Delta]p, \ p, \ S]\),
              
              "TraditionalForm"], \(gives\ the\ frequency\ of\ the\ observed\ \
diploid\ genotype\ using\ the\ simplified\ within - \ and\ between - 
              genome\ cumulants\ k\_w[], \ k\_b[]\)}
          }], TraditionalForm]]]], "DefinitionBox",
  CellTags->"DiploidGenotypeFrequencyReduced"],

Cell["\<\
This expression gives the frequency of this double heterozygote in \
terms of the reduced set of cumulants within- and between-genomes:\
\>", 
  "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(gf = 
      DiploidGenotypeFrequencyReduced[{1, 2, 1}, {k\_w, k\_b}, \[Delta]p, 
        p, {i, j, k}]\)], "Input",
  CellLabel->"In[86]:="],

Cell[BoxData[
    \(p[i]\ p[j]\ p[k]\ p[\(j\^*\)] + p[j]\ p[k]\ p[\(i\^*\)]\ p[\(j\^*\)] - 
      2\ p[i]\ p[j]\ p[k]\ p[\(i\^*\)]\ p[\(j\^*\)] + 
      p[i]\ p[j]\ p[\(j\^*\)]\ p[\(k\^*\)] - 
      2\ p[i]\ p[j]\ p[k]\ p[\(j\^*\)]\ p[\(k\^*\)] + 
      p[j]\ p[\(i\^*\)]\ p[\(j\^*\)]\ p[\(k\^*\)] - 
      2\ p[i]\ p[j]\ p[\(i\^*\)]\ p[\(j\^*\)]\ p[\(k\^*\)] - 
      2\ p[j]\ p[k]\ p[\(i\^*\)]\ p[\(j\^*\)]\ p[\(k\^*\)] + 
      4\ p[i]\ p[j]\ p[k]\ p[\(i\^*\)]\ p[\(j\^*\)]\ p[\(k\^*\)] - 
      2\ p[j]\ p[k]\ p[\(j\^*\)]\ \[Delta]p[i]\ \[Delta]p[\(i\^*\)]\ 
        k\_b[2] - 
      2\ p[j]\ p[\(j\^*\)]\ p[\(k\^*\)]\ \[Delta]p[i]\ \[Delta]p[\(i\^*\)]\ 
        k\_b[2] + 
      4\ p[j]\ p[k]\ p[\(j\^*\)]\ p[\(k\^*\)]\ \[Delta]p[i]\ 
        \[Delta]p[\(i\^*\)]\ k\_b[2] + 
      p[k]\ p[\(j\^*\)]\ \[Delta]p[j]\ \[Delta]p[\(i\^*\)]\ k\_b[2] - 
      2\ p[i]\ p[k]\ p[\(j\^*\)]\ \[Delta]p[j]\ \[Delta]p[\(i\^*\)]\ 
        k\_b[2] + 
      p[\(j\^*\)]\ p[\(k\^*\)]\ \[Delta]p[j]\ \[Delta]p[\(i\^*\)]\ k\_b[2] - 
      2\ p[i]\ p[\(j\^*\)]\ p[\(k\^*\)]\ \[Delta]p[j]\ \[Delta]p[\(i\^*\)]\ 
        k\_b[2] - 
      2\ p[k]\ p[\(j\^*\)]\ p[\(k\^*\)]\ \[Delta]p[j]\ \[Delta]p[\(i\^*\)]\ 
        k\_b[2] + 
      4\ p[i]\ p[k]\ p[\(j\^*\)]\ p[\(k\^*\)]\ \[Delta]p[j]\ 
        \[Delta]p[\(i\^*\)]\ k\_b[2] + 
      p[j]\ p[\(j\^*\)]\ \[Delta]p[k]\ \[Delta]p[\(i\^*\)]\ k\_b[2] - 
      2\ p[i]\ p[j]\ p[\(j\^*\)]\ \[Delta]p[k]\ \[Delta]p[\(i\^*\)]\ 
        k\_b[2] - 
      2\ p[j]\ p[\(j\^*\)]\ p[\(k\^*\)]\ \[Delta]p[k]\ \[Delta]p[\(i\^*\)]\ 
        k\_b[2] + 
      4\ p[i]\ p[j]\ p[\(j\^*\)]\ p[\(k\^*\)]\ \[Delta]p[k]\ 
        \[Delta]p[\(i\^*\)]\ k\_b[2] + 
      p[j]\ p[k]\ \[Delta]p[i]\ \[Delta]p[\(j\^*\)]\ k\_b[2] - 
      2\ p[j]\ p[k]\ p[\(i\^*\)]\ \[Delta]p[i]\ \[Delta]p[\(j\^*\)]\ 
        k\_b[2] + 
      p[j]\ p[\(k\^*\)]\ \[Delta]p[i]\ \[Delta]p[\(j\^*\)]\ k\_b[2] - 
      2\ p[j]\ p[k]\ p[\(k\^*\)]\ \[Delta]p[i]\ \[Delta]p[\(j\^*\)]\ 
        k\_b[2] - 
      2\ p[j]\ p[\(i\^*\)]\ p[\(k\^*\)]\ \[Delta]p[i]\ \[Delta]p[\(j\^*\)]\ 
        k\_b[2] + 
      4\ p[j]\ p[k]\ p[\(i\^*\)]\ p[\(k\^*\)]\ \[Delta]p[i]\ 
        \[Delta]p[\(j\^*\)]\ k\_b[2] + 
      p[i]\ p[k]\ \[Delta]p[j]\ \[Delta]p[\(j\^*\)]\ k\_b[2] + 
      p[k]\ p[\(i\^*\)]\ \[Delta]p[j]\ \[Delta]p[\(j\^*\)]\ k\_b[2] - 
      2\ p[i]\ p[k]\ p[\(i\^*\)]\ \[Delta]p[j]\ \[Delta]p[\(j\^*\)]\ 
        k\_b[2] + 
      p[i]\ p[\(k\^*\)]\ \[Delta]p[j]\ \[Delta]p[\(j\^*\)]\ k\_b[2] - 
      2\ p[i]\ p[k]\ p[\(k\^*\)]\ \[Delta]p[j]\ \[Delta]p[\(j\^*\)]\ 
        k\_b[2] + 
      p[\(i\^*\)]\ p[\(k\^*\)]\ \[Delta]p[j]\ \[Delta]p[\(j\^*\)]\ k\_b[2] - 
      2\ p[i]\ p[\(i\^*\)]\ p[\(k\^*\)]\ \[Delta]p[j]\ \[Delta]p[\(j\^*\)]\ 
        k\_b[2] - 
      2\ p[k]\ p[\(i\^*\)]\ p[\(k\^*\)]\ \[Delta]p[j]\ \[Delta]p[\(j\^*\)]\ 
        k\_b[2] + 
      4\ p[i]\ p[k]\ p[\(i\^*\)]\ p[\(k\^*\)]\ \[Delta]p[j]\ 
        \[Delta]p[\(j\^*\)]\ k\_b[2] + 
      p[i]\ p[j]\ \[Delta]p[k]\ \[Delta]p[\(j\^*\)]\ k\_b[2] + 
      p[j]\ p[\(i\^*\)]\ \[Delta]p[k]\ \[Delta]p[\(j\^*\)]\ k\_b[2] - 
      2\ p[i]\ p[j]\ p[\(i\^*\)]\ \[Delta]p[k]\ \[Delta]p[\(j\^*\)]\ 
        k\_b[2] - 
      2\ p[i]\ p[j]\ p[\(k\^*\)]\ \[Delta]p[k]\ \[Delta]p[\(j\^*\)]\ 
        k\_b[2] - 
      2\ p[j]\ p[\(i\^*\)]\ p[\(k\^*\)]\ \[Delta]p[k]\ \[Delta]p[\(j\^*\)]\ 
        k\_b[2] + 
      4\ p[i]\ p[j]\ p[\(i\^*\)]\ p[\(k\^*\)]\ \[Delta]p[k]\ 
        \[Delta]p[\(j\^*\)]\ k\_b[2] + 
      p[j]\ p[\(j\^*\)]\ \[Delta]p[i]\ \[Delta]p[\(k\^*\)]\ k\_b[2] - 
      2\ p[j]\ p[k]\ p[\(j\^*\)]\ \[Delta]p[i]\ \[Delta]p[\(k\^*\)]\ 
        k\_b[2] - 
      2\ p[j]\ p[\(i\^*\)]\ p[\(j\^*\)]\ \[Delta]p[i]\ \[Delta]p[\(k\^*\)]\ 
        k\_b[2] + 
      4\ p[j]\ p[k]\ p[\(i\^*\)]\ p[\(j\^*\)]\ \[Delta]p[i]\ 
        \[Delta]p[\(k\^*\)]\ k\_b[2] + 
      p[i]\ p[\(j\^*\)]\ \[Delta]p[j]\ \[Delta]p[\(k\^*\)]\ k\_b[2] - 
      2\ p[i]\ p[k]\ p[\(j\^*\)]\ \[Delta]p[j]\ \[Delta]p[\(k\^*\)]\ 
        k\_b[2] + 
      p[\(i\^*\)]\ p[\(j\^*\)]\ \[Delta]p[j]\ \[Delta]p[\(k\^*\)]\ k\_b[2] - 
      2\ p[i]\ p[\(i\^*\)]\ p[\(j\^*\)]\ \[Delta]p[j]\ \[Delta]p[\(k\^*\)]\ 
        k\_b[2] - 
      2\ p[k]\ p[\(i\^*\)]\ p[\(j\^*\)]\ \[Delta]p[j]\ \[Delta]p[\(k\^*\)]\ 
        k\_b[2] + 
      4\ p[i]\ p[k]\ p[\(i\^*\)]\ p[\(j\^*\)]\ \[Delta]p[j]\ 
        \[Delta]p[\(k\^*\)]\ k\_b[2] - 
      2\ p[i]\ p[j]\ p[\(j\^*\)]\ \[Delta]p[k]\ \[Delta]p[\(k\^*\)]\ 
        k\_b[2] - 
      2\ p[j]\ p[\(i\^*\)]\ p[\(j\^*\)]\ \[Delta]p[k]\ \[Delta]p[\(k\^*\)]\ 
        k\_b[2] + 
      4\ p[i]\ p[j]\ p[\(i\^*\)]\ p[\(j\^*\)]\ \[Delta]p[k]\ 
        \[Delta]p[\(k\^*\)]\ k\_b[2] - 
      4\ p[k]\ \[Delta]p[i]\ \[Delta]p[j]\ \[Delta]p[\(i\^*\)]\ 
        \[Delta]p[\(j\^*\)]\ k\_b[2]\^2 - 
      4\ p[\(k\^*\)]\ \[Delta]p[i]\ \[Delta]p[j]\ \[Delta]p[\(i\^*\)]\ 
        \[Delta]p[\(j\^*\)]\ k\_b[2]\^2 + 
      8\ p[k]\ p[\(k\^*\)]\ \[Delta]p[i]\ \[Delta]p[j]\ \[Delta]p[\(i\^*\)]\ 
        \[Delta]p[\(j\^*\)]\ k\_b[2]\^2 - 
      4\ p[j]\ \[Delta]p[i]\ \[Delta]p[k]\ \[Delta]p[\(i\^*\)]\ 
        \[Delta]p[\(j\^*\)]\ k\_b[2]\^2 + 
      8\ p[j]\ p[\(k\^*\)]\ \[Delta]p[i]\ \[Delta]p[k]\ \[Delta]p[\(i\^*\)]\ 
        \[Delta]p[\(j\^*\)]\ k\_b[2]\^2 + 
      2\ \[Delta]p[j]\ \[Delta]p[k]\ \[Delta]p[\(i\^*\)]\ 
        \[Delta]p[\(j\^*\)]\ k\_b[2]\^2 - 
      4\ p[i]\ \[Delta]p[j]\ \[Delta]p[k]\ \[Delta]p[\(i\^*\)]\ 
        \[Delta]p[\(j\^*\)]\ k\_b[2]\^2 - 
      4\ p[\(k\^*\)]\ \[Delta]p[j]\ \[Delta]p[k]\ \[Delta]p[\(i\^*\)]\ 
        \[Delta]p[\(j\^*\)]\ k\_b[2]\^2 + 
      8\ p[i]\ p[\(k\^*\)]\ \[Delta]p[j]\ \[Delta]p[k]\ \[Delta]p[\(i\^*\)]\ 
        \[Delta]p[\(j\^*\)]\ k\_b[2]\^2 - 
      4\ p[\(j\^*\)]\ \[Delta]p[i]\ \[Delta]p[j]\ \[Delta]p[\(i\^*\)]\ 
        \[Delta]p[\(k\^*\)]\ k\_b[2]\^2 + 
      8\ p[k]\ p[\(j\^*\)]\ \[Delta]p[i]\ \[Delta]p[j]\ \[Delta]p[\(i\^*\)]\ 
        \[Delta]p[\(k\^*\)]\ k\_b[2]\^2 + 
      8\ p[j]\ p[\(j\^*\)]\ \[Delta]p[i]\ \[Delta]p[k]\ \[Delta]p[\(i\^*\)]\ 
        \[Delta]p[\(k\^*\)]\ k\_b[2]\^2 - 
      4\ p[\(j\^*\)]\ \[Delta]p[j]\ \[Delta]p[k]\ \[Delta]p[\(i\^*\)]\ 
        \[Delta]p[\(k\^*\)]\ k\_b[2]\^2 + 
      8\ p[i]\ p[\(j\^*\)]\ \[Delta]p[j]\ \[Delta]p[k]\ \[Delta]p[\(i\^*\)]\ 
        \[Delta]p[\(k\^*\)]\ k\_b[2]\^2 + 
      2\ \[Delta]p[i]\ \[Delta]p[j]\ \[Delta]p[\(j\^*\)]\ 
        \[Delta]p[\(k\^*\)]\ k\_b[2]\^2 - 
      4\ p[k]\ \[Delta]p[i]\ \[Delta]p[j]\ \[Delta]p[\(j\^*\)]\ 
        \[Delta]p[\(k\^*\)]\ k\_b[2]\^2 - 
      4\ p[\(i\^*\)]\ \[Delta]p[i]\ \[Delta]p[j]\ \[Delta]p[\(j\^*\)]\ 
        \[Delta]p[\(k\^*\)]\ k\_b[2]\^2 + 
      8\ p[k]\ p[\(i\^*\)]\ \[Delta]p[i]\ \[Delta]p[j]\ \[Delta]p[\(j\^*\)]\ 
        \[Delta]p[\(k\^*\)]\ k\_b[2]\^2 - 
      4\ p[j]\ \[Delta]p[i]\ \[Delta]p[k]\ \[Delta]p[\(j\^*\)]\ 
        \[Delta]p[\(k\^*\)]\ k\_b[2]\^2 + 
      8\ p[j]\ p[\(i\^*\)]\ \[Delta]p[i]\ \[Delta]p[k]\ \[Delta]p[\(j\^*\)]\ 
        \[Delta]p[\(k\^*\)]\ k\_b[2]\^2 - 
      4\ p[i]\ \[Delta]p[j]\ \[Delta]p[k]\ \[Delta]p[\(j\^*\)]\ 
        \[Delta]p[\(k\^*\)]\ k\_b[2]\^2 - 
      4\ p[\(i\^*\)]\ \[Delta]p[j]\ \[Delta]p[k]\ \[Delta]p[\(j\^*\)]\ 
        \[Delta]p[\(k\^*\)]\ k\_b[2]\^2 + 
      8\ p[i]\ p[\(i\^*\)]\ \[Delta]p[j]\ \[Delta]p[k]\ \[Delta]p[\(j\^*\)]\ 
        \[Delta]p[\(k\^*\)]\ k\_b[2]\^2 + 
      24\ \[Delta]p[i]\ \[Delta]p[j]\ \[Delta]p[k]\ \[Delta]p[\(i\^*\)]\ 
        \[Delta]p[\(j\^*\)]\ \[Delta]p[\(k\^*\)]\ k\_b[2]\^3 - 
      2\ p[k]\ p[\(j\^*\)]\ \[Delta]p[i]\ \[Delta]p[j]\ \[Delta]p[\(i\^*\)]\ 
        k\_b[3] - 
      2\ p[\(j\^*\)]\ p[\(k\^*\)]\ \[Delta]p[i]\ \[Delta]p[j]\ 
        \[Delta]p[\(i\^*\)]\ k\_b[3] + 
      4\ p[k]\ p[\(j\^*\)]\ p[\(k\^*\)]\ \[Delta]p[i]\ \[Delta]p[j]\ 
        \[Delta]p[\(i\^*\)]\ k\_b[3] - 
      2\ p[j]\ p[\(j\^*\)]\ \[Delta]p[i]\ \[Delta]p[k]\ \[Delta]p[\(i\^*\)]\ 
        k\_b[3] + 
      4\ p[j]\ p[\(j\^*\)]\ p[\(k\^*\)]\ \[Delta]p[i]\ \[Delta]p[k]\ 
        \[Delta]p[\(i\^*\)]\ k\_b[3] + 
      p[\(j\^*\)]\ \[Delta]p[j]\ \[Delta]p[k]\ \[Delta]p[\(i\^*\)]\ k\_b[3] - 
      2\ p[i]\ p[\(j\^*\)]\ \[Delta]p[j]\ \[Delta]p[k]\ \[Delta]p[\(i\^*\)]\ 
        k\_b[3] - 
      2\ p[\(j\^*\)]\ p[\(k\^*\)]\ \[Delta]p[j]\ \[Delta]p[k]\ 
        \[Delta]p[\(i\^*\)]\ k\_b[3] + 
      4\ p[i]\ p[\(j\^*\)]\ p[\(k\^*\)]\ \[Delta]p[j]\ \[Delta]p[k]\ 
        \[Delta]p[\(i\^*\)]\ k\_b[3] + 
      p[k]\ \[Delta]p[i]\ \[Delta]p[j]\ \[Delta]p[\(j\^*\)]\ k\_b[3] - 
      2\ p[k]\ p[\(i\^*\)]\ \[Delta]p[i]\ \[Delta]p[j]\ \[Delta]p[\(j\^*\)]\ 
        k\_b[3] + 
      p[\(k\^*\)]\ \[Delta]p[i]\ \[Delta]p[j]\ \[Delta]p[\(j\^*\)]\ k\_b[3] - 
      2\ p[k]\ p[\(k\^*\)]\ \[Delta]p[i]\ \[Delta]p[j]\ \[Delta]p[\(j\^*\)]\ 
        k\_b[3] - 
      2\ p[\(i\^*\)]\ p[\(k\^*\)]\ \[Delta]p[i]\ \[Delta]p[j]\ 
        \[Delta]p[\(j\^*\)]\ k\_b[3] + 
      4\ p[k]\ p[\(i\^*\)]\ p[\(k\^*\)]\ \[Delta]p[i]\ \[Delta]p[j]\ 
        \[Delta]p[\(j\^*\)]\ k\_b[3] + 
      p[j]\ \[Delta]p[i]\ \[Delta]p[k]\ \[Delta]p[\(j\^*\)]\ k\_b[3] - 
      2\ p[j]\ p[\(i\^*\)]\ \[Delta]p[i]\ \[Delta]p[k]\ \[Delta]p[\(j\^*\)]\ 
        k\_b[3] - 
      2\ p[j]\ p[\(k\^*\)]\ \[Delta]p[i]\ \[Delta]p[k]\ \[Delta]p[\(j\^*\)]\ 
        k\_b[3] + 
      4\ p[j]\ p[\(i\^*\)]\ p[\(k\^*\)]\ \[Delta]p[i]\ \[Delta]p[k]\ 
        \[Delta]p[\(j\^*\)]\ k\_b[3] + 
      p[i]\ \[Delta]p[j]\ \[Delta]p[k]\ \[Delta]p[\(j\^*\)]\ k\_b[3] + 
      p[\(i\^*\)]\ \[Delta]p[j]\ \[Delta]p[k]\ \[Delta]p[\(j\^*\)]\ k\_b[3] - 
      2\ p[i]\ p[\(i\^*\)]\ \[Delta]p[j]\ \[Delta]p[k]\ \[Delta]p[\(j\^*\)]\ 
        k\_b[3] - 
      2\ p[i]\ p[\(k\^*\)]\ \[Delta]p[j]\ \[Delta]p[k]\ \[Delta]p[\(j\^*\)]\ 
        k\_b[3] - 
      2\ p[\(i\^*\)]\ p[\(k\^*\)]\ \[Delta]p[j]\ \[Delta]p[k]\ 
        \[Delta]p[\(j\^*\)]\ k\_b[3] + 
      4\ p[i]\ p[\(i\^*\)]\ p[\(k\^*\)]\ \[Delta]p[j]\ \[Delta]p[k]\ 
        \[Delta]p[\(j\^*\)]\ k\_b[3] - 
      2\ p[j]\ p[k]\ \[Delta]p[i]\ \[Delta]p[\(i\^*\)]\ \[Delta]p[\(j\^*\)]\ 
        k\_b[3] - 
      2\ p[j]\ p[\(k\^*\)]\ \[Delta]p[i]\ \[Delta]p[\(i\^*\)]\ 
        \[Delta]p[\(j\^*\)]\ k\_b[3] + 
      4\ p[j]\ p[k]\ p[\(k\^*\)]\ \[Delta]p[i]\ \[Delta]p[\(i\^*\)]\ 
        \[Delta]p[\(j\^*\)]\ k\_b[3] + 
      p[k]\ \[Delta]p[j]\ \[Delta]p[\(i\^*\)]\ \[Delta]p[\(j\^*\)]\ k\_b[3] - 
      2\ p[i]\ p[k]\ \[Delta]p[j]\ \[Delta]p[\(i\^*\)]\ \[Delta]p[\(j\^*\)]\ 
        k\_b[3] + 
      p[\(k\^*\)]\ \[Delta]p[j]\ \[Delta]p[\(i\^*\)]\ \[Delta]p[\(j\^*\)]\ 
        k\_b[3] - 
      2\ p[i]\ p[\(k\^*\)]\ \[Delta]p[j]\ \[Delta]p[\(i\^*\)]\ 
        \[Delta]p[\(j\^*\)]\ k\_b[3] - 
      2\ p[k]\ p[\(k\^*\)]\ \[Delta]p[j]\ \[Delta]p[\(i\^*\)]\ 
        \[Delta]p[\(j\^*\)]\ k\_b[3] + 
      4\ p[i]\ p[k]\ p[\(k\^*\)]\ \[Delta]p[j]\ \[Delta]p[\(i\^*\)]\ 
        \[Delta]p[\(j\^*\)]\ k\_b[3] + 
      p[j]\ \[Delta]p[k]\ \[Delta]p[\(i\^*\)]\ \[Delta]p[\(j\^*\)]\ k\_b[3] - 
      2\ p[i]\ p[j]\ \[Delta]p[k]\ \[Delta]p[\(i\^*\)]\ \[Delta]p[\(j\^*\)]\ 
        k\_b[3] - 
      2\ p[j]\ p[\(k\^*\)]\ \[Delta]p[k]\ \[Delta]p[\(i\^*\)]\ 
        \[Delta]p[\(j\^*\)]\ k\_b[3] + 
      4\ p[i]\ p[j]\ p[\(k\^*\)]\ \[Delta]p[k]\ \[Delta]p[\(i\^*\)]\ 
        \[Delta]p[\(j\^*\)]\ k\_b[3] + 
      p[\(j\^*\)]\ \[Delta]p[i]\ \[Delta]p[j]\ \[Delta]p[\(k\^*\)]\ k\_b[3] - 
      2\ p[k]\ p[\(j\^*\)]\ \[Delta]p[i]\ \[Delta]p[j]\ \[Delta]p[\(k\^*\)]\ 
        k\_b[3] - 
      2\ p[\(i\^*\)]\ p[\(j\^*\)]\ \[Delta]p[i]\ \[Delta]p[j]\ 
        \[Delta]p[\(k\^*\)]\ k\_b[3] + 
      4\ p[k]\ p[\(i\^*\)]\ p[\(j\^*\)]\ \[Delta]p[i]\ \[Delta]p[j]\ 
        \[Delta]p[\(k\^*\)]\ k\_b[3] - 
      2\ p[j]\ p[\(j\^*\)]\ \[Delta]p[i]\ \[Delta]p[k]\ \[Delta]p[\(k\^*\)]\ 
        k\_b[3] + 
      4\ p[j]\ p[\(i\^*\)]\ p[\(j\^*\)]\ \[Delta]p[i]\ \[Delta]p[k]\ 
        \[Delta]p[\(k\^*\)]\ k\_b[3] - 
      2\ p[i]\ p[\(j\^*\)]\ \[Delta]p[j]\ \[Delta]p[k]\ \[Delta]p[\(k\^*\)]\ 
        k\_b[3] - 
      2\ p[\(i\^*\)]\ p[\(j\^*\)]\ \[Delta]p[j]\ \[Delta]p[k]\ 
        \[Delta]p[\(k\^*\)]\ k\_b[3] + 
      4\ p[i]\ p[\(i\^*\)]\ p[\(j\^*\)]\ \[Delta]p[j]\ \[Delta]p[k]\ 
        \[Delta]p[\(k\^*\)]\ k\_b[3] - 
      2\ p[j]\ p[\(j\^*\)]\ \[Delta]p[i]\ \[Delta]p[\(i\^*\)]\ 
        \[Delta]p[\(k\^*\)]\ k\_b[3] + 
      4\ p[j]\ p[k]\ p[\(j\^*\)]\ \[Delta]p[i]\ \[Delta]p[\(i\^*\)]\ 
        \[Delta]p[\(k\^*\)]\ k\_b[3] + 
      p[\(j\^*\)]\ \[Delta]p[j]\ \[Delta]p[\(i\^*\)]\ \[Delta]p[\(k\^*\)]\ 
        k\_b[3] - 
      2\ p[i]\ p[\(j\^*\)]\ \[Delta]p[j]\ \[Delta]p[\(i\^*\)]\ 
        \[Delta]p[\(k\^*\)]\ k\_b[3] - 
      2\ p[k]\ p[\(j\^*\)]\ \[Delta]p[j]\ \[Delta]p[\(i\^*\)]\ 
        \[Delta]p[\(k\^*\)]\ k\_b[3] + 
      4\ p[i]\ p[k]\ p[\(j\^*\)]\ \[Delta]p[j]\ \[Delta]p[\(i\^*\)]\ 
        \[Delta]p[\(k\^*\)]\ k\_b[3] - 
      2\ p[j]\ p[\(j\^*\)]\ \[Delta]p[k]\ \[Delta]p[\(i\^*\)]\ 
        \[Delta]p[\(k\^*\)]\ k\_b[3] + 
      4\ p[i]\ p[j]\ p[\(j\^*\)]\ \[Delta]p[k]\ \[Delta]p[\(i\^*\)]\ 
        \[Delta]p[\(k\^*\)]\ k\_b[3] + 
      p[j]\ \[Delta]p[i]\ \[Delta]p[\(j\^*\)]\ \[Delta]p[\(k\^*\)]\ k\_b[3] - 
      2\ p[j]\ p[k]\ \[Delta]p[i]\ \[Delta]p[\(j\^*\)]\ \[Delta]p[\(k\^*\)]\ 
        k\_b[3] - 
      2\ p[j]\ p[\(i\^*\)]\ \[Delta]p[i]\ \[Delta]p[\(j\^*\)]\ 
        \[Delta]p[\(k\^*\)]\ k\_b[3] + 
      4\ p[j]\ p[k]\ p[\(i\^*\)]\ \[Delta]p[i]\ \[Delta]p[\(j\^*\)]\ 
        \[Delta]p[\(k\^*\)]\ k\_b[3] + 
      p[i]\ \[Delta]p[j]\ \[Delta]p[\(j\^*\)]\ \[Delta]p[\(k\^*\)]\ k\_b[3] - 
      2\ p[i]\ p[k]\ \[Delta]p[j]\ \[Delta]p[\(j\^*\)]\ \[Delta]p[\(k\^*\)]\ 
        k\_b[3] + 
      p[\(i\^*\)]\ \[Delta]p[j]\ \[Delta]p[\(j\^*\)]\ \[Delta]p[\(k\^*\)]\ 
        k\_b[3] - 
      2\ p[i]\ p[\(i\^*\)]\ \[Delta]p[j]\ \[Delta]p[\(j\^*\)]\ 
        \[Delta]p[\(k\^*\)]\ k\_b[3] - 
      2\ p[k]\ p[\(i\^*\)]\ \[Delta]p[j]\ \[Delta]p[\(j\^*\)]\ 
        \[Delta]p[\(k\^*\)]\ k\_b[3] + 
      4\ p[i]\ p[k]\ p[\(i\^*\)]\ \[Delta]p[j]\ \[Delta]p[\(j\^*\)]\ 
        \[Delta]p[\(k\^*\)]\ k\_b[3] - 
      2\ p[i]\ p[j]\ \[Delta]p[k]\ \[Delta]p[\(j\^*\)]\ \[Delta]p[\(k\^*\)]\ 
        k\_b[3] - 
      2\ p[j]\ p[\(i\^*\)]\ \[Delta]p[k]\ \[Delta]p[\(j\^*\)]\ 
        \[Delta]p[\(k\^*\)]\ k\_b[3] + 
      4\ p[i]\ p[j]\ p[\(i\^*\)]\ \[Delta]p[k]\ \[Delta]p[\(j\^*\)]\ 
        \[Delta]p[\(k\^*\)]\ k\_b[3] - 
      12\ \[Delta]p[i]\ \[Delta]p[j]\ \[Delta]p[k]\ \[Delta]p[\(i\^*\)]\ 
        \[Delta]p[\(j\^*\)]\ k\_b[2]\ k\_b[3] + 
      24\ p[\(k\^*\)]\ \[Delta]p[i]\ \[Delta]p[j]\ \[Delta]p[k]\ 
        \[Delta]p[\(i\^*\)]\ \[Delta]p[\(j\^*\)]\ k\_b[2]\ k\_b[3] + 
      24\ p[\(j\^*\)]\ \[Delta]p[i]\ \[Delta]p[j]\ \[Delta]p[k]\ 
        \[Delta]p[\(i\^*\)]\ \[Delta]p[\(k\^*\)]\ k\_b[2]\ k\_b[3] - 
      12\ \[Delta]p[i]\ \[Delta]p[j]\ \[Delta]p[k]\ \[Delta]p[\(j\^*\)]\ 
        \[Delta]p[\(k\^*\)]\ k\_b[2]\ k\_b[3] + 
      24\ p[\(i\^*\)]\ \[Delta]p[i]\ \[Delta]p[j]\ \[Delta]p[k]\ 
        \[Delta]p[\(j\^*\)]\ \[Delta]p[\(k\^*\)]\ k\_b[2]\ k\_b[3] - 
      12\ \[Delta]p[i]\ \[Delta]p[j]\ \[Delta]p[\(i\^*\)]\ 
        \[Delta]p[\(j\^*\)]\ \[Delta]p[\(k\^*\)]\ k\_b[2]\ k\_b[3] + 
      24\ p[k]\ \[Delta]p[i]\ \[Delta]p[j]\ \[Delta]p[\(i\^*\)]\ 
        \[Delta]p[\(j\^*\)]\ \[Delta]p[\(k\^*\)]\ k\_b[2]\ k\_b[3] + 
      24\ p[j]\ \[Delta]p[i]\ \[Delta]p[k]\ \[Delta]p[\(i\^*\)]\ 
        \[Delta]p[\(j\^*\)]\ \[Delta]p[\(k\^*\)]\ k\_b[2]\ k\_b[3] - 
      12\ \[Delta]p[j]\ \[Delta]p[k]\ \[Delta]p[\(i\^*\)]\ 
        \[Delta]p[\(j\^*\)]\ \[Delta]p[\(k\^*\)]\ k\_b[2]\ k\_b[3] + 
      24\ p[i]\ \[Delta]p[j]\ \[Delta]p[k]\ \[Delta]p[\(i\^*\)]\ 
        \[Delta]p[\(j\^*\)]\ \[Delta]p[\(k\^*\)]\ k\_b[2]\ k\_b[3] + 
      36\ \[Delta]p[i]\ \[Delta]p[j]\ \[Delta]p[k]\ \[Delta]p[\(i\^*\)]\ 
        \[Delta]p[\(j\^*\)]\ \[Delta]p[\(k\^*\)]\ k\_b[3]\^2 - 
      2\ p[\(j\^*\)]\ \[Delta]p[i]\ \[Delta]p[j]\ \[Delta]p[k]\ 
        \[Delta]p[\(i\^*\)]\ k\_b[4] + 
      4\ p[\(j\^*\)]\ p[\(k\^*\)]\ \[Delta]p[i]\ \[Delta]p[j]\ \[Delta]p[k]\ 
        \[Delta]p[\(i\^*\)]\ k\_b[4] + 
      \[Delta]p[i]\ \[Delta]p[j]\ \[Delta]p[k]\ \[Delta]p[\(j\^*\)]\ 
        k\_b[4] - 
      2\ p[\(i\^*\)]\ \[Delta]p[i]\ \[Delta]p[j]\ \[Delta]p[k]\ 
        \[Delta]p[\(j\^*\)]\ k\_b[4] - 
      2\ p[\(k\^*\)]\ \[Delta]p[i]\ \[Delta]p[j]\ \[Delta]p[k]\ 
        \[Delta]p[\(j\^*\)]\ k\_b[4] + 
      4\ p[\(i\^*\)]\ p[\(k\^*\)]\ \[Delta]p[i]\ \[Delta]p[j]\ \[Delta]p[k]\ 
        \[Delta]p[\(j\^*\)]\ k\_b[4] - 
      2\ p[k]\ \[Delta]p[i]\ \[Delta]p[j]\ \[Delta]p[\(i\^*\)]\ 
        \[Delta]p[\(j\^*\)]\ k\_b[4] - 
      2\ p[\(k\^*\)]\ \[Delta]p[i]\ \[Delta]p[j]\ \[Delta]p[\(i\^*\)]\ 
        \[Delta]p[\(j\^*\)]\ k\_b[4] + 
      4\ p[k]\ p[\(k\^*\)]\ \[Delta]p[i]\ \[Delta]p[j]\ \[Delta]p[\(i\^*\)]\ 
        \[Delta]p[\(j\^*\)]\ k\_b[4] - 
      2\ p[j]\ \[Delta]p[i]\ \[Delta]p[k]\ \[Delta]p[\(i\^*\)]\ 
        \[Delta]p[\(j\^*\)]\ k\_b[4] + 
      4\ p[j]\ p[\(k\^*\)]\ \[Delta]p[i]\ \[Delta]p[k]\ \[Delta]p[\(i\^*\)]\ 
        \[Delta]p[\(j\^*\)]\ k\_b[4] + 
      \[Delta]p[j]\ \[Delta]p[k]\ \[Delta]p[\(i\^*\)]\ \[Delta]p[\(j\^*\)]\ 
        k\_b[4] - 
      2\ p[i]\ \[Delta]p[j]\ \[Delta]p[k]\ \[Delta]p[\(i\^*\)]\ 
        \[Delta]p[\(j\^*\)]\ k\_b[4] - 
      2\ p[\(k\^*\)]\ \[Delta]p[j]\ \[Delta]p[k]\ \[Delta]p[\(i\^*\)]\ 
        \[Delta]p[\(j\^*\)]\ k\_b[4] + 
      4\ p[i]\ p[\(k\^*\)]\ \[Delta]p[j]\ \[Delta]p[k]\ \[Delta]p[\(i\^*\)]\ 
        \[Delta]p[\(j\^*\)]\ k\_b[4] - 
      2\ p[\(j\^*\)]\ \[Delta]p[i]\ \[Delta]p[j]\ \[Delta]p[k]\ 
        \[Delta]p[\(k\^*\)]\ k\_b[4] + 
      4\ p[\(i\^*\)]\ p[\(j\^*\)]\ \[Delta]p[i]\ \[Delta]p[j]\ \[Delta]p[k]\ 
        \[Delta]p[\(k\^*\)]\ k\_b[4] - 
      2\ p[\(j\^*\)]\ \[Delta]p[i]\ \[Delta]p[j]\ \[Delta]p[\(i\^*\)]\ 
        \[Delta]p[\(k\^*\)]\ k\_b[4] + 
      4\ p[k]\ p[\(j\^*\)]\ \[Delta]p[i]\ \[Delta]p[j]\ \[Delta]p[\(i\^*\)]\ 
        \[Delta]p[\(k\^*\)]\ k\_b[4] + 
      4\ p[j]\ p[\(j\^*\)]\ \[Delta]p[i]\ \[Delta]p[k]\ \[Delta]p[\(i\^*\)]\ 
        \[Delta]p[\(k\^*\)]\ k\_b[4] - 
      2\ p[\(j\^*\)]\ \[Delta]p[j]\ \[Delta]p[k]\ \[Delta]p[\(i\^*\)]\ 
        \[Delta]p[\(k\^*\)]\ k\_b[4] + 
      4\ p[i]\ p[\(j\^*\)]\ \[Delta]p[j]\ \[Delta]p[k]\ \[Delta]p[\(i\^*\)]\ 
        \[Delta]p[\(k\^*\)]\ k\_b[4] + 
      \[Delta]p[i]\ \[Delta]p[j]\ \[Delta]p[\(j\^*\)]\ \[Delta]p[\(k\^*\)]\ 
        k\_b[4] - 
      2\ p[k]\ \[Delta]p[i]\ \[Delta]p[j]\ \[Delta]p[\(j\^*\)]\ 
        \[Delta]p[\(k\^*\)]\ k\_b[4] - 
      2\ p[\(i\^*\)]\ \[Delta]p[i]\ \[Delta]p[j]\ \[Delta]p[\(j\^*\)]\ 
        \[Delta]p[\(k\^*\)]\ k\_b[4] + 
      4\ p[k]\ p[\(i\^*\)]\ \[Delta]p[i]\ \[Delta]p[j]\ \[Delta]p[\(j\^*\)]\ 
        \[Delta]p[\(k\^*\)]\ k\_b[4] - 
      2\ p[j]\ \[Delta]p[i]\ \[Delta]p[k]\ \[Delta]p[\(j\^*\)]\ 
        \[Delta]p[\(k\^*\)]\ k\_b[4] + 
      4\ p[j]\ p[\(i\^*\)]\ \[Delta]p[i]\ \[Delta]p[k]\ \[Delta]p[\(j\^*\)]\ 
        \[Delta]p[\(k\^*\)]\ k\_b[4] - 
      2\ p[i]\ \[Delta]p[j]\ \[Delta]p[k]\ \[Delta]p[\(j\^*\)]\ 
        \[Delta]p[\(k\^*\)]\ k\_b[4] - 
      2\ p[\(i\^*\)]\ \[Delta]p[j]\ \[Delta]p[k]\ \[Delta]p[\(j\^*\)]\ 
        \[Delta]p[\(k\^*\)]\ k\_b[4] + 
      4\ p[i]\ p[\(i\^*\)]\ \[Delta]p[j]\ \[Delta]p[k]\ \[Delta]p[\(j\^*\)]\ 
        \[Delta]p[\(k\^*\)]\ k\_b[4] - 
      2\ p[j]\ \[Delta]p[i]\ \[Delta]p[\(i\^*\)]\ \[Delta]p[\(j\^*\)]\ 
        \[Delta]p[\(k\^*\)]\ k\_b[4] + 
      4\ p[j]\ p[k]\ \[Delta]p[i]\ \[Delta]p[\(i\^*\)]\ \[Delta]p[\(j\^*\)]\ 
        \[Delta]p[\(k\^*\)]\ k\_b[4] + 
      \[Delta]p[j]\ \[Delta]p[\(i\^*\)]\ \[Delta]p[\(j\^*\)]\ 
        \[Delta]p[\(k\^*\)]\ k\_b[4] - 
      2\ p[i]\ \[Delta]p[j]\ \[Delta]p[\(i\^*\)]\ \[Delta]p[\(j\^*\)]\ 
        \[Delta]p[\(k\^*\)]\ k\_b[4] - 
      2\ p[k]\ \[Delta]p[j]\ \[Delta]p[\(i\^*\)]\ \[Delta]p[\(j\^*\)]\ 
        \[Delta]p[\(k\^*\)]\ k\_b[4] + 
      4\ p[i]\ p[k]\ \[Delta]p[j]\ \[Delta]p[\(i\^*\)]\ \[Delta]p[\(j\^*\)]\ 
        \[Delta]p[\(k\^*\)]\ k\_b[4] - 
      2\ p[j]\ \[Delta]p[k]\ \[Delta]p[\(i\^*\)]\ \[Delta]p[\(j\^*\)]\ 
        \[Delta]p[\(k\^*\)]\ k\_b[4] + 
      4\ p[i]\ p[j]\ \[Delta]p[k]\ \[Delta]p[\(i\^*\)]\ \[Delta]p[\(j\^*\)]\ 
        \[Delta]p[\(k\^*\)]\ k\_b[4] + 
      36\ \[Delta]p[i]\ \[Delta]p[j]\ \[Delta]p[k]\ \[Delta]p[\(i\^*\)]\ 
        \[Delta]p[\(j\^*\)]\ \[Delta]p[\(k\^*\)]\ k\_b[2]\ k\_b[4] - 
      2\ \[Delta]p[i]\ \[Delta]p[j]\ \[Delta]p[k]\ \[Delta]p[\(i\^*\)]\ 
        \[Delta]p[\(j\^*\)]\ k\_b[5] + 
      4\ p[\(k\^*\)]\ \[Delta]p[i]\ \[Delta]p[j]\ \[Delta]p[k]\ 
        \[Delta]p[\(i\^*\)]\ \[Delta]p[\(j\^*\)]\ k\_b[5] + 
      4\ p[\(j\^*\)]\ \[Delta]p[i]\ \[Delta]p[j]\ \[Delta]p[k]\ 
        \[Delta]p[\(i\^*\)]\ \[Delta]p[\(k\^*\)]\ k\_b[5] - 
      2\ \[Delta]p[i]\ \[Delta]p[j]\ \[Delta]p[k]\ \[Delta]p[\(j\^*\)]\ 
        \[Delta]p[\(k\^*\)]\ k\_b[5] + 
      4\ p[\(i\^*\)]\ \[Delta]p[i]\ \[Delta]p[j]\ \[Delta]p[k]\ 
        \[Delta]p[\(j\^*\)]\ \[Delta]p[\(k\^*\)]\ k\_b[5] - 
      2\ \[Delta]p[i]\ \[Delta]p[j]\ \[Delta]p[\(i\^*\)]\ 
        \[Delta]p[\(j\^*\)]\ \[Delta]p[\(k\^*\)]\ k\_b[5] + 
      4\ p[k]\ \[Delta]p[i]\ \[Delta]p[j]\ \[Delta]p[\(i\^*\)]\ 
        \[Delta]p[\(j\^*\)]\ \[Delta]p[\(k\^*\)]\ k\_b[5] + 
      4\ p[j]\ \[Delta]p[i]\ \[Delta]p[k]\ \[Delta]p[\(i\^*\)]\ 
        \[Delta]p[\(j\^*\)]\ \[Delta]p[\(k\^*\)]\ k\_b[5] - 
      2\ \[Delta]p[j]\ \[Delta]p[k]\ \[Delta]p[\(i\^*\)]\ 
        \[Delta]p[\(j\^*\)]\ \[Delta]p[\(k\^*\)]\ k\_b[5] + 
      4\ p[i]\ \[Delta]p[j]\ \[Delta]p[k]\ \[Delta]p[\(i\^*\)]\ 
        \[Delta]p[\(j\^*\)]\ \[Delta]p[\(k\^*\)]\ k\_b[5] + 
      4\ \[Delta]p[i]\ \[Delta]p[j]\ \[Delta]p[k]\ \[Delta]p[\(i\^*\)]\ 
        \[Delta]p[\(j\^*\)]\ \[Delta]p[\(k\^*\)]\ k\_b[6] + 
      p[k]\ p[\(j\^*\)]\ \[Delta]p[i]\ \[Delta]p[j]\ k\_w[2] - 
      2\ p[k]\ p[\(i\^*\)]\ p[\(j\^*\)]\ \[Delta]p[i]\ \[Delta]p[j]\ 
        k\_w[2] + 
      p[\(j\^*\)]\ p[\(k\^*\)]\ \[Delta]p[i]\ \[Delta]p[j]\ k\_w[2] - 
      2\ p[k]\ p[\(j\^*\)]\ p[\(k\^*\)]\ \[Delta]p[i]\ \[Delta]p[j]\ 
        k\_w[2] - 
      2\ p[\(i\^*\)]\ p[\(j\^*\)]\ p[\(k\^*\)]\ \[Delta]p[i]\ \[Delta]p[j]\ 
        k\_w[2] + 
      4\ p[k]\ p[\(i\^*\)]\ p[\(j\^*\)]\ p[\(k\^*\)]\ \[Delta]p[i]\ 
        \[Delta]p[j]\ k\_w[2] + 
      p[j]\ p[\(j\^*\)]\ \[Delta]p[i]\ \[Delta]p[k]\ k\_w[2] - 
      2\ p[j]\ p[\(i\^*\)]\ p[\(j\^*\)]\ \[Delta]p[i]\ \[Delta]p[k]\ 
        k\_w[2] - 
      2\ p[j]\ p[\(j\^*\)]\ p[\(k\^*\)]\ \[Delta]p[i]\ \[Delta]p[k]\ 
        k\_w[2] + 
      4\ p[j]\ p[\(i\^*\)]\ p[\(j\^*\)]\ p[\(k\^*\)]\ \[Delta]p[i]\ 
        \[Delta]p[k]\ k\_w[2] + 
      p[i]\ p[\(j\^*\)]\ \[Delta]p[j]\ \[Delta]p[k]\ k\_w[2] + 
      p[\(i\^*\)]\ p[\(j\^*\)]\ \[Delta]p[j]\ \[Delta]p[k]\ k\_w[2] - 
      2\ p[i]\ p[\(i\^*\)]\ p[\(j\^*\)]\ \[Delta]p[j]\ \[Delta]p[k]\ 
        k\_w[2] - 
      2\ p[i]\ p[\(j\^*\)]\ p[\(k\^*\)]\ \[Delta]p[j]\ \[Delta]p[k]\ 
        k\_w[2] - 
      2\ p[\(i\^*\)]\ p[\(j\^*\)]\ p[\(k\^*\)]\ \[Delta]p[j]\ \[Delta]p[k]\ 
        k\_w[2] + 
      4\ p[i]\ p[\(i\^*\)]\ p[\(j\^*\)]\ p[\(k\^*\)]\ \[Delta]p[j]\ 
        \[Delta]p[k]\ k\_w[2] + 
      p[j]\ p[k]\ \[Delta]p[\(i\^*\)]\ \[Delta]p[\(j\^*\)]\ k\_w[2] - 
      2\ p[i]\ p[j]\ p[k]\ \[Delta]p[\(i\^*\)]\ \[Delta]p[\(j\^*\)]\ 
        k\_w[2] + 
      p[j]\ p[\(k\^*\)]\ \[Delta]p[\(i\^*\)]\ \[Delta]p[\(j\^*\)]\ k\_w[2] - 
      2\ p[i]\ p[j]\ p[\(k\^*\)]\ \[Delta]p[\(i\^*\)]\ \[Delta]p[\(j\^*\)]\ 
        k\_w[2] - 
      2\ p[j]\ p[k]\ p[\(k\^*\)]\ \[Delta]p[\(i\^*\)]\ \[Delta]p[\(j\^*\)]\ 
        k\_w[2] + 
      4\ p[i]\ p[j]\ p[k]\ p[\(k\^*\)]\ \[Delta]p[\(i\^*\)]\ 
        \[Delta]p[\(j\^*\)]\ k\_w[2] + 
      p[j]\ p[\(j\^*\)]\ \[Delta]p[\(i\^*\)]\ \[Delta]p[\(k\^*\)]\ k\_w[2] - 
      2\ p[i]\ p[j]\ p[\(j\^*\)]\ \[Delta]p[\(i\^*\)]\ \[Delta]p[\(k\^*\)]\ 
        k\_w[2] - 
      2\ p[j]\ p[k]\ p[\(j\^*\)]\ \[Delta]p[\(i\^*\)]\ \[Delta]p[\(k\^*\)]\ 
        k\_w[2] + 
      4\ p[i]\ p[j]\ p[k]\ p[\(j\^*\)]\ \[Delta]p[\(i\^*\)]\ 
        \[Delta]p[\(k\^*\)]\ k\_w[2] + 
      p[i]\ p[j]\ \[Delta]p[\(j\^*\)]\ \[Delta]p[\(k\^*\)]\ k\_w[2] - 
      2\ p[i]\ p[j]\ p[k]\ \[Delta]p[\(j\^*\)]\ \[Delta]p[\(k\^*\)]\ 
        k\_w[2] + 
      p[j]\ p[\(i\^*\)]\ \[Delta]p[\(j\^*\)]\ \[Delta]p[\(k\^*\)]\ k\_w[2] - 
      2\ p[i]\ p[j]\ p[\(i\^*\)]\ \[Delta]p[\(j\^*\)]\ \[Delta]p[\(k\^*\)]\ 
        k\_w[2] - 
      2\ p[j]\ p[k]\ p[\(i\^*\)]\ \[Delta]p[\(j\^*\)]\ \[Delta]p[\(k\^*\)]\ 
        k\_w[2] + 
      4\ p[i]\ p[j]\ p[k]\ p[\(i\^*\)]\ \[Delta]p[\(j\^*\)]\ 
        \[Delta]p[\(k\^*\)]\ k\_w[2] - 
      6\ p[\(j\^*\)]\ \[Delta]p[i]\ \[Delta]p[j]\ \[Delta]p[k]\ 
        \[Delta]p[\(i\^*\)]\ k\_b[2]\ k\_w[2] + 
      12\ p[\(j\^*\)]\ p[\(k\^*\)]\ \[Delta]p[i]\ \[Delta]p[j]\ \[Delta]p[k]\ 
        \[Delta]p[\(i\^*\)]\ k\_b[2]\ k\_w[2] + 
      3\ \[Delta]p[i]\ \[Delta]p[j]\ \[Delta]p[k]\ \[Delta]p[\(j\^*\)]\ 
        k\_b[2]\ k\_w[2] - 
      6\ p[\(i\^*\)]\ \[Delta]p[i]\ \[Delta]p[j]\ \[Delta]p[k]\ 
        \[Delta]p[\(j\^*\)]\ k\_b[2]\ k\_w[2] - 
      6\ p[\(k\^*\)]\ \[Delta]p[i]\ \[Delta]p[j]\ \[Delta]p[k]\ 
        \[Delta]p[\(j\^*\)]\ k\_b[2]\ k\_w[2] + 
      12\ p[\(i\^*\)]\ p[\(k\^*\)]\ \[Delta]p[i]\ \[Delta]p[j]\ \[Delta]p[k]\ 
        \[Delta]p[\(j\^*\)]\ k\_b[2]\ k\_w[2] - 
      6\ p[\(j\^*\)]\ \[Delta]p[i]\ \[Delta]p[j]\ \[Delta]p[k]\ 
        \[Delta]p[\(k\^*\)]\ k\_b[2]\ k\_w[2] + 
      12\ p[\(i\^*\)]\ p[\(j\^*\)]\ \[Delta]p[i]\ \[Delta]p[j]\ \[Delta]p[k]\ 
        \[Delta]p[\(k\^*\)]\ k\_b[2]\ k\_w[2] - 
      6\ p[j]\ \[Delta]p[i]\ \[Delta]p[\(i\^*\)]\ \[Delta]p[\(j\^*\)]\ 
        \[Delta]p[\(k\^*\)]\ k\_b[2]\ k\_w[2] + 
      12\ p[j]\ p[k]\ \[Delta]p[i]\ \[Delta]p[\(i\^*\)]\ \[Delta]p[\(j\^*\)]\ 
        \[Delta]p[\(k\^*\)]\ k\_b[2]\ k\_w[2] + 
      3\ \[Delta]p[j]\ \[Delta]p[\(i\^*\)]\ \[Delta]p[\(j\^*\)]\ 
        \[Delta]p[\(k\^*\)]\ k\_b[2]\ k\_w[2] - 
      6\ p[i]\ \[Delta]p[j]\ \[Delta]p[\(i\^*\)]\ \[Delta]p[\(j\^*\)]\ 
        \[Delta]p[\(k\^*\)]\ k\_b[2]\ k\_w[2] - 
      6\ p[k]\ \[Delta]p[j]\ \[Delta]p[\(i\^*\)]\ \[Delta]p[\(j\^*\)]\ 
        \[Delta]p[\(k\^*\)]\ k\_b[2]\ k\_w[2] + 
      12\ p[i]\ p[k]\ \[Delta]p[j]\ \[Delta]p[\(i\^*\)]\ \[Delta]p[\(j\^*\)]\ 
        \[Delta]p[\(k\^*\)]\ k\_b[2]\ k\_w[2] - 
      6\ p[j]\ \[Delta]p[k]\ \[Delta]p[\(i\^*\)]\ \[Delta]p[\(j\^*\)]\ 
        \[Delta]p[\(k\^*\)]\ k\_b[2]\ k\_w[2] + 
      12\ p[i]\ p[j]\ \[Delta]p[k]\ \[Delta]p[\(i\^*\)]\ \[Delta]p[\(j\^*\)]\ 
        \[Delta]p[\(k\^*\)]\ k\_b[2]\ k\_w[2] - 
      6\ \[Delta]p[i]\ \[Delta]p[j]\ \[Delta]p[k]\ \[Delta]p[\(i\^*\)]\ 
        \[Delta]p[\(j\^*\)]\ k\_b[3]\ k\_w[2] + 
      12\ p[\(k\^*\)]\ \[Delta]p[i]\ \[Delta]p[j]\ \[Delta]p[k]\ 
        \[Delta]p[\(i\^*\)]\ \[Delta]p[\(j\^*\)]\ k\_b[3]\ k\_w[2] + 
      12\ p[\(j\^*\)]\ \[Delta]p[i]\ \[Delta]p[j]\ \[Delta]p[k]\ 
        \[Delta]p[\(i\^*\)]\ \[Delta]p[\(k\^*\)]\ k\_b[3]\ k\_w[2] - 
      6\ \[Delta]p[i]\ \[Delta]p[j]\ \[Delta]p[k]\ \[Delta]p[\(j\^*\)]\ 
        \[Delta]p[\(k\^*\)]\ k\_b[3]\ k\_w[2] + 
      12\ p[\(i\^*\)]\ \[Delta]p[i]\ \[Delta]p[j]\ \[Delta]p[k]\ 
        \[Delta]p[\(j\^*\)]\ \[Delta]p[\(k\^*\)]\ k\_b[3]\ k\_w[2] - 
      6\ \[Delta]p[i]\ \[Delta]p[j]\ \[Delta]p[\(i\^*\)]\ 
        \[Delta]p[\(j\^*\)]\ \[Delta]p[\(k\^*\)]\ k\_b[3]\ k\_w[2] + 
      12\ p[k]\ \[Delta]p[i]\ \[Delta]p[j]\ \[Delta]p[\(i\^*\)]\ 
        \[Delta]p[\(j\^*\)]\ \[Delta]p[\(k\^*\)]\ k\_b[3]\ k\_w[2] + 
      12\ p[j]\ \[Delta]p[i]\ \[Delta]p[k]\ \[Delta]p[\(i\^*\)]\ 
        \[Delta]p[\(j\^*\)]\ \[Delta]p[\(k\^*\)]\ k\_b[3]\ k\_w[2] - 
      6\ \[Delta]p[j]\ \[Delta]p[k]\ \[Delta]p[\(i\^*\)]\ 
        \[Delta]p[\(j\^*\)]\ \[Delta]p[\(k\^*\)]\ k\_b[3]\ k\_w[2] + 
      12\ p[i]\ \[Delta]p[j]\ \[Delta]p[k]\ \[Delta]p[\(i\^*\)]\ 
        \[Delta]p[\(j\^*\)]\ \[Delta]p[\(k\^*\)]\ k\_b[3]\ k\_w[2] + 
      24\ \[Delta]p[i]\ \[Delta]p[j]\ \[Delta]p[k]\ \[Delta]p[\(i\^*\)]\ 
        \[Delta]p[\(j\^*\)]\ \[Delta]p[\(k\^*\)]\ k\_b[4]\ k\_w[2] - 
      2\ p[k]\ \[Delta]p[i]\ \[Delta]p[j]\ \[Delta]p[\(i\^*\)]\ 
        \[Delta]p[\(j\^*\)]\ k\_w[2]\^2 - 
      2\ p[\(k\^*\)]\ \[Delta]p[i]\ \[Delta]p[j]\ \[Delta]p[\(i\^*\)]\ 
        \[Delta]p[\(j\^*\)]\ k\_w[2]\^2 + 
      4\ p[k]\ p[\(k\^*\)]\ \[Delta]p[i]\ \[Delta]p[j]\ \[Delta]p[\(i\^*\)]\ 
        \[Delta]p[\(j\^*\)]\ k\_w[2]\^2 - 
      2\ p[j]\ \[Delta]p[i]\ \[Delta]p[k]\ \[Delta]p[\(i\^*\)]\ 
        \[Delta]p[\(j\^*\)]\ k\_w[2]\^2 + 
      4\ p[j]\ p[\(k\^*\)]\ \[Delta]p[i]\ \[Delta]p[k]\ \[Delta]p[\(i\^*\)]\ 
        \[Delta]p[\(j\^*\)]\ k\_w[2]\^2 + 
      \[Delta]p[j]\ \[Delta]p[k]\ \[Delta]p[\(i\^*\)]\ \[Delta]p[\(j\^*\)]\ 
        k\_w[2]\^2 - 
      2\ p[i]\ \[Delta]p[j]\ \[Delta]p[k]\ \[Delta]p[\(i\^*\)]\ 
        \[Delta]p[\(j\^*\)]\ k\_w[2]\^2 - 
      2\ p[\(k\^*\)]\ \[Delta]p[j]\ \[Delta]p[k]\ \[Delta]p[\(i\^*\)]\ 
        \[Delta]p[\(j\^*\)]\ k\_w[2]\^2 + 
      4\ p[i]\ p[\(k\^*\)]\ \[Delta]p[j]\ \[Delta]p[k]\ \[Delta]p[\(i\^*\)]\ 
        \[Delta]p[\(j\^*\)]\ k\_w[2]\^2 - 
      2\ p[\(j\^*\)]\ \[Delta]p[i]\ \[Delta]p[j]\ \[Delta]p[\(i\^*\)]\ 
        \[Delta]p[\(k\^*\)]\ k\_w[2]\^2 + 
      4\ p[k]\ p[\(j\^*\)]\ \[Delta]p[i]\ \[Delta]p[j]\ \[Delta]p[\(i\^*\)]\ 
        \[Delta]p[\(k\^*\)]\ k\_w[2]\^2 + 
      4\ p[j]\ p[\(j\^*\)]\ \[Delta]p[i]\ \[Delta]p[k]\ \[Delta]p[\(i\^*\)]\ 
        \[Delta]p[\(k\^*\)]\ k\_w[2]\^2 - 
      2\ p[\(j\^*\)]\ \[Delta]p[j]\ \[Delta]p[k]\ \[Delta]p[\(i\^*\)]\ 
        \[Delta]p[\(k\^*\)]\ k\_w[2]\^2 + 
      4\ p[i]\ p[\(j\^*\)]\ \[Delta]p[j]\ \[Delta]p[k]\ \[Delta]p[\(i\^*\)]\ 
        \[Delta]p[\(k\^*\)]\ k\_w[2]\^2 + 
      \[Delta]p[i]\ \[Delta]p[j]\ \[Delta]p[\(j\^*\)]\ \[Delta]p[\(k\^*\)]\ 
        k\_w[2]\^2 - 
      2\ p[k]\ \[Delta]p[i]\ \[Delta]p[j]\ \[Delta]p[\(j\^*\)]\ 
        \[Delta]p[\(k\^*\)]\ k\_w[2]\^2 - 
      2\ p[\(i\^*\)]\ \[Delta]p[i]\ \[Delta]p[j]\ \[Delta]p[\(j\^*\)]\ 
        \[Delta]p[\(k\^*\)]\ k\_w[2]\^2 + 
      4\ p[k]\ p[\(i\^*\)]\ \[Delta]p[i]\ \[Delta]p[j]\ \[Delta]p[\(j\^*\)]\ 
        \[Delta]p[\(k\^*\)]\ k\_w[2]\^2 - 
      2\ p[j]\ \[Delta]p[i]\ \[Delta]p[k]\ \[Delta]p[\(j\^*\)]\ 
        \[Delta]p[\(k\^*\)]\ k\_w[2]\^2 + 
      4\ p[j]\ p[\(i\^*\)]\ \[Delta]p[i]\ \[Delta]p[k]\ \[Delta]p[\(j\^*\)]\ 
        \[Delta]p[\(k\^*\)]\ k\_w[2]\^2 - 
      2\ p[i]\ \[Delta]p[j]\ \[Delta]p[k]\ \[Delta]p[\(j\^*\)]\ 
        \[Delta]p[\(k\^*\)]\ k\_w[2]\^2 - 
      2\ p[\(i\^*\)]\ \[Delta]p[j]\ \[Delta]p[k]\ \[Delta]p[\(j\^*\)]\ 
        \[Delta]p[\(k\^*\)]\ k\_w[2]\^2 + 
      4\ p[i]\ p[\(i\^*\)]\ \[Delta]p[j]\ \[Delta]p[k]\ \[Delta]p[\(j\^*\)]\ 
        \[Delta]p[\(k\^*\)]\ k\_w[2]\^2 + 
      36\ \[Delta]p[i]\ \[Delta]p[j]\ \[Delta]p[k]\ \[Delta]p[\(i\^*\)]\ 
        \[Delta]p[\(j\^*\)]\ \[Delta]p[\(k\^*\)]\ k\_b[2]\ k\_w[2]\^2 + 
      p[\(j\^*\)]\ \[Delta]p[i]\ \[Delta]p[j]\ \[Delta]p[k]\ k\_w[3] - 
      2\ p[\(i\^*\)]\ p[\(j\^*\)]\ \[Delta]p[i]\ \[Delta]p[j]\ \[Delta]p[k]\ 
        k\_w[3] - 
      2\ p[\(j\^*\)]\ p[\(k\^*\)]\ \[Delta]p[i]\ \[Delta]p[j]\ \[Delta]p[k]\ 
        k\_w[3] + 
      4\ p[\(i\^*\)]\ p[\(j\^*\)]\ p[\(k\^*\)]\ \[Delta]p[i]\ \[Delta]p[j]\ 
        \[Delta]p[k]\ k\_w[3] + 
      p[j]\ \[Delta]p[\(i\^*\)]\ \[Delta]p[\(j\^*\)]\ \[Delta]p[\(k\^*\)]\ 
        k\_w[3] - 
      2\ p[i]\ p[j]\ \[Delta]p[\(i\^*\)]\ \[Delta]p[\(j\^*\)]\ 
        \[Delta]p[\(k\^*\)]\ k\_w[3] - 
      2\ p[j]\ p[k]\ \[Delta]p[\(i\^*\)]\ \[Delta]p[\(j\^*\)]\ 
        \[Delta]p[\(k\^*\)]\ k\_w[3] + 
      4\ p[i]\ p[j]\ p[k]\ \[Delta]p[\(i\^*\)]\ \[Delta]p[\(j\^*\)]\ 
        \[Delta]p[\(k\^*\)]\ k\_w[3] - 
      2\ \[Delta]p[i]\ \[Delta]p[j]\ \[Delta]p[k]\ \[Delta]p[\(i\^*\)]\ 
        \[Delta]p[\(j\^*\)]\ k\_w[2]\ k\_w[3] + 
      4\ p[\(k\^*\)]\ \[Delta]p[i]\ \[Delta]p[j]\ \[Delta]p[k]\ 
        \[Delta]p[\(i\^*\)]\ \[Delta]p[\(j\^*\)]\ k\_w[2]\ k\_w[3] + 
      4\ p[\(j\^*\)]\ \[Delta]p[i]\ \[Delta]p[j]\ \[Delta]p[k]\ 
        \[Delta]p[\(i\^*\)]\ \[Delta]p[\(k\^*\)]\ k\_w[2]\ k\_w[3] - 
      2\ \[Delta]p[i]\ \[Delta]p[j]\ \[Delta]p[k]\ \[Delta]p[\(j\^*\)]\ 
        \[Delta]p[\(k\^*\)]\ k\_w[2]\ k\_w[3] + 
      4\ p[\(i\^*\)]\ \[Delta]p[i]\ \[Delta]p[j]\ \[Delta]p[k]\ 
        \[Delta]p[\(j\^*\)]\ \[Delta]p[\(k\^*\)]\ k\_w[2]\ k\_w[3] - 
      2\ \[Delta]p[i]\ \[Delta]p[j]\ \[Delta]p[\(i\^*\)]\ 
        \[Delta]p[\(j\^*\)]\ \[Delta]p[\(k\^*\)]\ k\_w[2]\ k\_w[3] + 
      4\ p[k]\ \[Delta]p[i]\ \[Delta]p[j]\ \[Delta]p[\(i\^*\)]\ 
        \[Delta]p[\(j\^*\)]\ \[Delta]p[\(k\^*\)]\ k\_w[2]\ k\_w[3] + 
      4\ p[j]\ \[Delta]p[i]\ \[Delta]p[k]\ \[Delta]p[\(i\^*\)]\ 
        \[Delta]p[\(j\^*\)]\ \[Delta]p[\(k\^*\)]\ k\_w[2]\ k\_w[3] - 
      2\ \[Delta]p[j]\ \[Delta]p[k]\ \[Delta]p[\(i\^*\)]\ 
        \[Delta]p[\(j\^*\)]\ \[Delta]p[\(k\^*\)]\ k\_w[2]\ k\_w[3] + 
      4\ p[i]\ \[Delta]p[j]\ \[Delta]p[k]\ \[Delta]p[\(i\^*\)]\ 
        \[Delta]p[\(j\^*\)]\ \[Delta]p[\(k\^*\)]\ k\_w[2]\ k\_w[3] + 
      4\ \[Delta]p[i]\ \[Delta]p[j]\ \[Delta]p[k]\ \[Delta]p[\(i\^*\)]\ 
        \[Delta]p[\(j\^*\)]\ \[Delta]p[\(k\^*\)]\ k\_w[3]\^2\)], "Output",
  CellLabel->"Out[86]="]
}, Closed]],

Cell[TextData[
"This is a slightly simpler version which assumes that the loci are \
diagnostic (\[Delta]p=1) and that allele frequencies are the same across the \
male & female gamete pools:"], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(gf /. {\[Delta]p[_] -> 1, p[\(i_\^*\)] :> p[i]}\)], "Input",
  CellLabel->"In[87]:="],

Cell[BoxData[
    \(4\ p[i]\ p[j]\^2\ p[k] - 4\ p[i]\^2\ p[j]\^2\ p[k] - 
      4\ p[i]\ p[j]\^2\ p[k]\^2 + 4\ p[i]\^2\ p[j]\^2\ p[k]\^2 + 
      4\ p[i]\ p[j]\ k\_b[2] - 4\ p[i]\^2\ p[j]\ k\_b[2] + 
      2\ p[j]\^2\ k\_b[2] - 8\ p[i]\ p[j]\^2\ k\_b[2] + 
      4\ p[i]\^2\ p[j]\^2\ k\_b[2] + 4\ p[i]\ p[k]\ k\_b[2] - 
      4\ p[i]\^2\ p[k]\ k\_b[2] + 4\ p[j]\ p[k]\ k\_b[2] - 
      16\ p[i]\ p[j]\ p[k]\ k\_b[2] + 8\ p[i]\^2\ p[j]\ p[k]\ k\_b[2] - 
      8\ p[j]\^2\ p[k]\ k\_b[2] + 8\ p[i]\ p[j]\^2\ p[k]\ k\_b[2] - 
      4\ p[i]\ p[k]\^2\ k\_b[2] + 4\ p[i]\^2\ p[k]\^2\ k\_b[2] - 
      4\ p[j]\ p[k]\^2\ k\_b[2] + 8\ p[i]\ p[j]\ p[k]\^2\ k\_b[2] + 
      4\ p[j]\^2\ p[k]\^2\ k\_b[2] + 4\ k\_b[2]\^2 - 16\ p[i]\ k\_b[2]\^2 + 
      8\ p[i]\^2\ k\_b[2]\^2 - 16\ p[j]\ k\_b[2]\^2 + 
      16\ p[i]\ p[j]\ k\_b[2]\^2 + 8\ p[j]\^2\ k\_b[2]\^2 - 
      16\ p[k]\ k\_b[2]\^2 + 16\ p[i]\ p[k]\ k\_b[2]\^2 + 
      16\ p[j]\ p[k]\ k\_b[2]\^2 + 8\ p[k]\^2\ k\_b[2]\^2 + 24\ k\_b[2]\^3 + 
      4\ p[i]\ k\_b[3] - 4\ p[i]\^2\ k\_b[3] + 6\ p[j]\ k\_b[3] - 
      20\ p[i]\ p[j]\ k\_b[3] + 8\ p[i]\^2\ p[j]\ k\_b[3] - 
      8\ p[j]\^2\ k\_b[3] + 8\ p[i]\ p[j]\^2\ k\_b[3] + 4\ p[k]\ k\_b[3] - 
      16\ p[i]\ p[k]\ k\_b[3] + 8\ p[i]\^2\ p[k]\ k\_b[3] - 
      20\ p[j]\ p[k]\ k\_b[3] + 24\ p[i]\ p[j]\ p[k]\ k\_b[3] + 
      8\ p[j]\^2\ p[k]\ k\_b[3] - 4\ p[k]\^2\ k\_b[3] + 
      8\ p[i]\ p[k]\^2\ k\_b[3] + 8\ p[j]\ p[k]\^2\ k\_b[3] - 
      48\ k\_b[2]\ k\_b[3] + 48\ p[i]\ k\_b[2]\ k\_b[3] + 
      48\ p[j]\ k\_b[2]\ k\_b[3] + 48\ p[k]\ k\_b[2]\ k\_b[3] + 
      36\ k\_b[3]\^2 + 4\ k\_b[4] - 12\ p[i]\ k\_b[4] + 4\ p[i]\^2\ k\_b[4] - 
      16\ p[j]\ k\_b[4] + 16\ p[i]\ p[j]\ k\_b[4] + 4\ p[j]\^2\ k\_b[4] - 
      12\ p[k]\ k\_b[4] + 16\ p[i]\ p[k]\ k\_b[4] + 16\ p[j]\ p[k]\ k\_b[4] + 
      4\ p[k]\^2\ k\_b[4] + 36\ k\_b[2]\ k\_b[4] - 8\ k\_b[5] + 
      8\ p[i]\ k\_b[5] + 8\ p[j]\ k\_b[5] + 8\ p[k]\ k\_b[5] + 4\ k\_b[6] + 
      4\ p[i]\ p[j]\ k\_w[2] - 4\ p[i]\^2\ p[j]\ k\_w[2] + 
      2\ p[j]\^2\ k\_w[2] - 4\ p[i]\ p[j]\^2\ k\_w[2] + 
      4\ p[j]\ p[k]\ k\_w[2] - 16\ p[i]\ p[j]\ p[k]\ k\_w[2] + 
      8\ p[i]\^2\ p[j]\ p[k]\ k\_w[2] - 4\ p[j]\^2\ p[k]\ k\_w[2] + 
      8\ p[i]\ p[j]\^2\ p[k]\ k\_w[2] - 4\ p[j]\ p[k]\^2\ k\_w[2] + 
      8\ p[i]\ p[j]\ p[k]\^2\ k\_w[2] + 6\ k\_b[2]\ k\_w[2] - 
      12\ p[i]\ k\_b[2]\ k\_w[2] - 24\ p[j]\ k\_b[2]\ k\_w[2] + 
      24\ p[i]\ p[j]\ k\_b[2]\ k\_w[2] - 12\ p[k]\ k\_b[2]\ k\_w[2] + 
      24\ p[i]\ p[k]\ k\_b[2]\ k\_w[2] + 24\ p[j]\ p[k]\ k\_b[2]\ k\_w[2] - 
      24\ k\_b[3]\ k\_w[2] + 24\ p[i]\ k\_b[3]\ k\_w[2] + 
      24\ p[j]\ k\_b[3]\ k\_w[2] + 24\ p[k]\ k\_b[3]\ k\_w[2] + 
      24\ k\_b[4]\ k\_w[2] + 2\ k\_w[2]\^2 - 8\ p[i]\ k\_w[2]\^2 + 
      4\ p[i]\^2\ k\_w[2]\^2 - 8\ p[j]\ k\_w[2]\^2 + 
      8\ p[i]\ p[j]\ k\_w[2]\^2 + 4\ p[j]\^2\ k\_w[2]\^2 - 
      8\ p[k]\ k\_w[2]\^2 + 8\ p[i]\ p[k]\ k\_w[2]\^2 + 
      8\ p[j]\ p[k]\ k\_w[2]\^2 + 4\ p[k]\^2\ k\_w[2]\^2 + 
      36\ k\_b[2]\ k\_w[2]\^2 + 2\ p[j]\ k\_w[3] - 4\ p[i]\ p[j]\ k\_w[3] - 
      4\ p[j]\ p[k]\ k\_w[3] + 8\ p[i]\ p[j]\ p[k]\ k\_w[3] - 
      8\ k\_w[2]\ k\_w[3] + 8\ p[i]\ k\_w[2]\ k\_w[3] + 
      8\ p[j]\ k\_w[2]\ k\_w[3] + 8\ p[k]\ k\_w[2]\ k\_w[3] + 
      4\ k\_w[3]\^2\)], "Output",
  CellLabel->"Out[87]="]
}, Closed]],

Cell["\<\
DiploidGenotypeFrequencyReduced[] applies \
FullGenotypeFrequencyReduced[] to PossibleDiploidGenotypes[].\
\>", "Text"],

Cell[TextData[{
  "FullGenotypeFrequencyReduced[X, k, \[Delta]p, ",
  Cell[BoxData[
      FormBox[GridBox[{
            {\(\(p, 
                S\)\(]\)\), \(gives\ the\ frequency\ of\ the\ haploid\ \
genotype\ X\ in\ terms\ of\ the\ reduced\ set\ of\ cumulants\ \
\(\(k\)\(.\)\)\)}
            }], TraditionalForm]]],
  " ",
  Cell[BoxData[
      FormBox[GridBox[{
            {\(FullGenotypeFrequencyReduced[{X, \(X\^*\)}, \ {k\_w, 
                  k\_b}, \ \[Delta]p, \ p, \ 
                S]\), \(gives\ the\ frequnecy\ of\ the\ full\ diploid\ \
genotype\ \(\({X, \(X\^*\)}\)\(.\)\)\)}
            }], TraditionalForm]]]
}], "DefinitionBox",
  CellTags->"FullGenotypeFrequencyReduced"],

Cell[CellGroupData[{

Cell[BoxData[
    \(FullGenotypeFrequencyReduced[{0, 1, 0}, k, \[Delta]p, p, {i, j, k}]\)], 
  "Input",
  CellLabel->"In[92]:="],

Cell[BoxData[
    \(p[j] - p[i]\ p[j] - p[j]\ p[k] + p[i]\ p[j]\ p[k] - 
      k[2]\ \[Delta]p[i]\ \[Delta]p[j] + 
      k[2]\ p[k]\ \[Delta]p[i]\ \[Delta]p[j] + 
      k[2]\ p[j]\ \[Delta]p[i]\ \[Delta]p[k] - 
      k[2]\ \[Delta]p[j]\ \[Delta]p[k] + 
      k[2]\ p[i]\ \[Delta]p[j]\ \[Delta]p[k] + 
      k[3]\ \[Delta]p[i]\ \[Delta]p[j]\ \[Delta]p[k]\)], "Output",
  CellLabel->"Out[92]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(gf = 
      FullGenotypeFrequencyReduced[{{0, 1, 0}, {0, 0, 1}}, {k\_w, k\_b}, 
        \[Delta]p, p, {i, j, k}]\)], "Input",
  CellLabel->"In[94]:="],

Cell[BoxData[
    \(p[j]\ p[\(k\^*\)] - p[i]\ p[j]\ p[\(k\^*\)] - p[j]\ p[k]\ p[\(k\^*\)] + 
      p[i]\ p[j]\ p[k]\ p[\(k\^*\)] - p[j]\ p[\(i\^*\)]\ p[\(k\^*\)] + 
      p[i]\ p[j]\ p[\(i\^*\)]\ p[\(k\^*\)] + 
      p[j]\ p[k]\ p[\(i\^*\)]\ p[\(k\^*\)] - 
      p[i]\ p[j]\ p[k]\ p[\(i\^*\)]\ p[\(k\^*\)] - 
      p[j]\ p[\(j\^*\)]\ p[\(k\^*\)] + p[i]\ p[j]\ p[\(j\^*\)]\ p[\(k\^*\)] + 
      p[j]\ p[k]\ p[\(j\^*\)]\ p[\(k\^*\)] - 
      p[i]\ p[j]\ p[k]\ p[\(j\^*\)]\ p[\(k\^*\)] + 
      p[j]\ p[\(i\^*\)]\ p[\(j\^*\)]\ p[\(k\^*\)] - 
      p[i]\ p[j]\ p[\(i\^*\)]\ p[\(j\^*\)]\ p[\(k\^*\)] - 
      p[j]\ p[k]\ p[\(i\^*\)]\ p[\(j\^*\)]\ p[\(k\^*\)] + 
      p[i]\ p[j]\ p[k]\ p[\(i\^*\)]\ p[\(j\^*\)]\ p[\(k\^*\)] + 
      p[j]\ p[\(k\^*\)]\ \[Delta]p[i]\ \[Delta]p[\(i\^*\)]\ k\_b[2] - 
      p[j]\ p[k]\ p[\(k\^*\)]\ \[Delta]p[i]\ \[Delta]p[\(i\^*\)]\ k\_b[2] - 
      p[j]\ p[\(j\^*\)]\ p[\(k\^*\)]\ \[Delta]p[i]\ \[Delta]p[\(i\^*\)]\ 
        k\_b[2] + 
      p[j]\ p[k]\ p[\(j\^*\)]\ p[\(k\^*\)]\ \[Delta]p[i]\ 
        \[Delta]p[\(i\^*\)]\ k\_b[2] - 
      p[\(k\^*\)]\ \[Delta]p[j]\ \[Delta]p[\(i\^*\)]\ k\_b[2] + 
      p[i]\ p[\(k\^*\)]\ \[Delta]p[j]\ \[Delta]p[\(i\^*\)]\ k\_b[2] + 
      p[k]\ p[\(k\^*\)]\ \[Delta]p[j]\ \[Delta]p[\(i\^*\)]\ k\_b[2] - 
      p[i]\ p[k]\ p[\(k\^*\)]\ \[Delta]p[j]\ \[Delta]p[\(i\^*\)]\ k\_b[2] + 
      p[\(j\^*\)]\ p[\(k\^*\)]\ \[Delta]p[j]\ \[Delta]p[\(i\^*\)]\ k\_b[2] - 
      p[i]\ p[\(j\^*\)]\ p[\(k\^*\)]\ \[Delta]p[j]\ \[Delta]p[\(i\^*\)]\ 
        k\_b[2] - 
      p[k]\ p[\(j\^*\)]\ p[\(k\^*\)]\ \[Delta]p[j]\ \[Delta]p[\(i\^*\)]\ 
        k\_b[2] + 
      p[i]\ p[k]\ p[\(j\^*\)]\ p[\(k\^*\)]\ \[Delta]p[j]\ 
        \[Delta]p[\(i\^*\)]\ k\_b[2] + 
      p[j]\ p[\(k\^*\)]\ \[Delta]p[k]\ \[Delta]p[\(i\^*\)]\ k\_b[2] - 
      p[i]\ p[j]\ p[\(k\^*\)]\ \[Delta]p[k]\ \[Delta]p[\(i\^*\)]\ k\_b[2] - 
      p[j]\ p[\(j\^*\)]\ p[\(k\^*\)]\ \[Delta]p[k]\ \[Delta]p[\(i\^*\)]\ 
        k\_b[2] + 
      p[i]\ p[j]\ p[\(j\^*\)]\ p[\(k\^*\)]\ \[Delta]p[k]\ 
        \[Delta]p[\(i\^*\)]\ k\_b[2] + 
      p[j]\ p[\(k\^*\)]\ \[Delta]p[i]\ \[Delta]p[\(j\^*\)]\ k\_b[2] - 
      p[j]\ p[k]\ p[\(k\^*\)]\ \[Delta]p[i]\ \[Delta]p[\(j\^*\)]\ k\_b[2] - 
      p[j]\ p[\(i\^*\)]\ p[\(k\^*\)]\ \[Delta]p[i]\ \[Delta]p[\(j\^*\)]\ 
        k\_b[2] + 
      p[j]\ p[k]\ p[\(i\^*\)]\ p[\(k\^*\)]\ \[Delta]p[i]\ 
        \[Delta]p[\(j\^*\)]\ k\_b[2] - 
      p[\(k\^*\)]\ \[Delta]p[j]\ \[Delta]p[\(j\^*\)]\ k\_b[2] + 
      p[i]\ p[\(k\^*\)]\ \[Delta]p[j]\ \[Delta]p[\(j\^*\)]\ k\_b[2] + 
      p[k]\ p[\(k\^*\)]\ \[Delta]p[j]\ \[Delta]p[\(j\^*\)]\ k\_b[2] - 
      p[i]\ p[k]\ p[\(k\^*\)]\ \[Delta]p[j]\ \[Delta]p[\(j\^*\)]\ k\_b[2] + 
      p[\(i\^*\)]\ p[\(k\^*\)]\ \[Delta]p[j]\ \[Delta]p[\(j\^*\)]\ k\_b[2] - 
      p[i]\ p[\(i\^*\)]\ p[\(k\^*\)]\ \[Delta]p[j]\ \[Delta]p[\(j\^*\)]\ 
        k\_b[2] - 
      p[k]\ p[\(i\^*\)]\ p[\(k\^*\)]\ \[Delta]p[j]\ \[Delta]p[\(j\^*\)]\ 
        k\_b[2] + 
      p[i]\ p[k]\ p[\(i\^*\)]\ p[\(k\^*\)]\ \[Delta]p[j]\ 
        \[Delta]p[\(j\^*\)]\ k\_b[2] + 
      p[j]\ p[\(k\^*\)]\ \[Delta]p[k]\ \[Delta]p[\(j\^*\)]\ k\_b[2] - 
      p[i]\ p[j]\ p[\(k\^*\)]\ \[Delta]p[k]\ \[Delta]p[\(j\^*\)]\ k\_b[2] - 
      p[j]\ p[\(i\^*\)]\ p[\(k\^*\)]\ \[Delta]p[k]\ \[Delta]p[\(j\^*\)]\ 
        k\_b[2] + 
      p[i]\ p[j]\ p[\(i\^*\)]\ p[\(k\^*\)]\ \[Delta]p[k]\ 
        \[Delta]p[\(j\^*\)]\ k\_b[2] - 
      p[j]\ \[Delta]p[i]\ \[Delta]p[\(k\^*\)]\ k\_b[2] + 
      p[j]\ p[k]\ \[Delta]p[i]\ \[Delta]p[\(k\^*\)]\ k\_b[2] + 
      p[j]\ p[\(i\^*\)]\ \[Delta]p[i]\ \[Delta]p[\(k\^*\)]\ k\_b[2] - 
      p[j]\ p[k]\ p[\(i\^*\)]\ \[Delta]p[i]\ \[Delta]p[\(k\^*\)]\ k\_b[2] + 
      p[j]\ p[\(j\^*\)]\ \[Delta]p[i]\ \[Delta]p[\(k\^*\)]\ k\_b[2] - 
      p[j]\ p[k]\ p[\(j\^*\)]\ \[Delta]p[i]\ \[Delta]p[\(k\^*\)]\ k\_b[2] - 
      p[j]\ p[\(i\^*\)]\ p[\(j\^*\)]\ \[Delta]p[i]\ \[Delta]p[\(k\^*\)]\ 
        k\_b[2] + 
      p[j]\ p[k]\ p[\(i\^*\)]\ p[\(j\^*\)]\ \[Delta]p[i]\ 
        \[Delta]p[\(k\^*\)]\ k\_b[2] + 
      \[Delta]p[j]\ \[Delta]p[\(k\^*\)]\ k\_b[2] - 
      p[i]\ \[Delta]p[j]\ \[Delta]p[\(k\^*\)]\ k\_b[2] - 
      p[k]\ \[Delta]p[j]\ \[Delta]p[\(k\^*\)]\ k\_b[2] + 
      p[i]\ p[k]\ \[Delta]p[j]\ \[Delta]p[\(k\^*\)]\ k\_b[2] - 
      p[\(i\^*\)]\ \[Delta]p[j]\ \[Delta]p[\(k\^*\)]\ k\_b[2] + 
      p[i]\ p[\(i\^*\)]\ \[Delta]p[j]\ \[Delta]p[\(k\^*\)]\ k\_b[2] + 
      p[k]\ p[\(i\^*\)]\ \[Delta]p[j]\ \[Delta]p[\(k\^*\)]\ k\_b[2] - 
      p[i]\ p[k]\ p[\(i\^*\)]\ \[Delta]p[j]\ \[Delta]p[\(k\^*\)]\ k\_b[2] - 
      p[\(j\^*\)]\ \[Delta]p[j]\ \[Delta]p[\(k\^*\)]\ k\_b[2] + 
      p[i]\ p[\(j\^*\)]\ \[Delta]p[j]\ \[Delta]p[\(k\^*\)]\ k\_b[2] + 
      p[k]\ p[\(j\^*\)]\ \[Delta]p[j]\ \[Delta]p[\(k\^*\)]\ k\_b[2] - 
      p[i]\ p[k]\ p[\(j\^*\)]\ \[Delta]p[j]\ \[Delta]p[\(k\^*\)]\ k\_b[2] + 
      p[\(i\^*\)]\ p[\(j\^*\)]\ \[Delta]p[j]\ \[Delta]p[\(k\^*\)]\ k\_b[2] - 
      p[i]\ p[\(i\^*\)]\ p[\(j\^*\)]\ \[Delta]p[j]\ \[Delta]p[\(k\^*\)]\ 
        k\_b[2] - 
      p[k]\ p[\(i\^*\)]\ p[\(j\^*\)]\ \[Delta]p[j]\ \[Delta]p[\(k\^*\)]\ 
        k\_b[2] + 
      p[i]\ p[k]\ p[\(i\^*\)]\ p[\(j\^*\)]\ \[Delta]p[j]\ 
        \[Delta]p[\(k\^*\)]\ k\_b[2] - 
      p[j]\ \[Delta]p[k]\ \[Delta]p[\(k\^*\)]\ k\_b[2] + 
      p[i]\ p[j]\ \[Delta]p[k]\ \[Delta]p[\(k\^*\)]\ k\_b[2] + 
      p[j]\ p[\(i\^*\)]\ \[Delta]p[k]\ \[Delta]p[\(k\^*\)]\ k\_b[2] - 
      p[i]\ p[j]\ p[\(i\^*\)]\ \[Delta]p[k]\ \[Delta]p[\(k\^*\)]\ k\_b[2] + 
      p[j]\ p[\(j\^*\)]\ \[Delta]p[k]\ \[Delta]p[\(k\^*\)]\ k\_b[2] - 
      p[i]\ p[j]\ p[\(j\^*\)]\ \[Delta]p[k]\ \[Delta]p[\(k\^*\)]\ k\_b[2] - 
      p[j]\ p[\(i\^*\)]\ p[\(j\^*\)]\ \[Delta]p[k]\ \[Delta]p[\(k\^*\)]\ 
        k\_b[2] + 
      p[i]\ p[j]\ p[\(i\^*\)]\ p[\(j\^*\)]\ \[Delta]p[k]\ 
        \[Delta]p[\(k\^*\)]\ k\_b[2] - 
      2\ p[\(k\^*\)]\ \[Delta]p[i]\ \[Delta]p[j]\ \[Delta]p[\(i\^*\)]\ 
        \[Delta]p[\(j\^*\)]\ k\_b[2]\^2 + 
      2\ p[k]\ p[\(k\^*\)]\ \[Delta]p[i]\ \[Delta]p[j]\ \[Delta]p[\(i\^*\)]\ 
        \[Delta]p[\(j\^*\)]\ k\_b[2]\^2 + 
      2\ p[j]\ p[\(k\^*\)]\ \[Delta]p[i]\ \[Delta]p[k]\ \[Delta]p[\(i\^*\)]\ 
        \[Delta]p[\(j\^*\)]\ k\_b[2]\^2 - 
      2\ p[\(k\^*\)]\ \[Delta]p[j]\ \[Delta]p[k]\ \[Delta]p[\(i\^*\)]\ 
        \[Delta]p[\(j\^*\)]\ k\_b[2]\^2 + 
      2\ p[i]\ p[\(k\^*\)]\ \[Delta]p[j]\ \[Delta]p[k]\ \[Delta]p[\(i\^*\)]\ 
        \[Delta]p[\(j\^*\)]\ k\_b[2]\^2 + 
      2\ \[Delta]p[i]\ \[Delta]p[j]\ \[Delta]p[\(i\^*\)]\ 
        \[Delta]p[\(k\^*\)]\ k\_b[2]\^2 - 
      2\ p[k]\ \[Delta]p[i]\ \[Delta]p[j]\ \[Delta]p[\(i\^*\)]\ 
        \[Delta]p[\(k\^*\)]\ k\_b[2]\^2 - 
      2\ p[\(j\^*\)]\ \[Delta]p[i]\ \[Delta]p[j]\ \[Delta]p[\(i\^*\)]\ 
        \[Delta]p[\(k\^*\)]\ k\_b[2]\^2 + 
      2\ p[k]\ p[\(j\^*\)]\ \[Delta]p[i]\ \[Delta]p[j]\ \[Delta]p[\(i\^*\)]\ 
        \[Delta]p[\(k\^*\)]\ k\_b[2]\^2 - 
      2\ p[j]\ \[Delta]p[i]\ \[Delta]p[k]\ \[Delta]p[\(i\^*\)]\ 
        \[Delta]p[\(k\^*\)]\ k\_b[2]\^2 + 
      2\ p[j]\ p[\(j\^*\)]\ \[Delta]p[i]\ \[Delta]p[k]\ \[Delta]p[\(i\^*\)]\ 
        \[Delta]p[\(k\^*\)]\ k\_b[2]\^2 + 
      2\ \[Delta]p[j]\ \[Delta]p[k]\ \[Delta]p[\(i\^*\)]\ 
        \[Delta]p[\(k\^*\)]\ k\_b[2]\^2 - 
      2\ p[i]\ \[Delta]p[j]\ \[Delta]p[k]\ \[Delta]p[\(i\^*\)]\ 
        \[Delta]p[\(k\^*\)]\ k\_b[2]\^2 - 
      2\ p[\(j\^*\)]\ \[Delta]p[j]\ \[Delta]p[k]\ \[Delta]p[\(i\^*\)]\ 
        \[Delta]p[\(k\^*\)]\ k\_b[2]\^2 + 
      2\ p[i]\ p[\(j\^*\)]\ \[Delta]p[j]\ \[Delta]p[k]\ \[Delta]p[\(i\^*\)]\ 
        \[Delta]p[\(k\^*\)]\ k\_b[2]\^2 + 
      2\ \[Delta]p[i]\ \[Delta]p[j]\ \[Delta]p[\(j\^*\)]\ 
        \[Delta]p[\(k\^*\)]\ k\_b[2]\^2 - 
      2\ p[k]\ \[Delta]p[i]\ \[Delta]p[j]\ \[Delta]p[\(j\^*\)]\ 
        \[Delta]p[\(k\^*\)]\ k\_b[2]\^2 - 
      2\ p[\(i\^*\)]\ \[Delta]p[i]\ \[Delta]p[j]\ \[Delta]p[\(j\^*\)]\ 
        \[Delta]p[\(k\^*\)]\ k\_b[2]\^2 + 
      2\ p[k]\ p[\(i\^*\)]\ \[Delta]p[i]\ \[Delta]p[j]\ \[Delta]p[\(j\^*\)]\ 
        \[Delta]p[\(k\^*\)]\ k\_b[2]\^2 - 
      2\ p[j]\ \[Delta]p[i]\ \[Delta]p[k]\ \[Delta]p[\(j\^*\)]\ 
        \[Delta]p[\(k\^*\)]\ k\_b[2]\^2 + 
      2\ p[j]\ p[\(i\^*\)]\ \[Delta]p[i]\ \[Delta]p[k]\ \[Delta]p[\(j\^*\)]\ 
        \[Delta]p[\(k\^*\)]\ k\_b[2]\^2 + 
      2\ \[Delta]p[j]\ \[Delta]p[k]\ \[Delta]p[\(j\^*\)]\ 
        \[Delta]p[\(k\^*\)]\ k\_b[2]\^2 - 
      2\ p[i]\ \[Delta]p[j]\ \[Delta]p[k]\ \[Delta]p[\(j\^*\)]\ 
        \[Delta]p[\(k\^*\)]\ k\_b[2]\^2 - 
      2\ p[\(i\^*\)]\ \[Delta]p[j]\ \[Delta]p[k]\ \[Delta]p[\(j\^*\)]\ 
        \[Delta]p[\(k\^*\)]\ k\_b[2]\^2 + 
      2\ p[i]\ p[\(i\^*\)]\ \[Delta]p[j]\ \[Delta]p[k]\ \[Delta]p[\(j\^*\)]\ 
        \[Delta]p[\(k\^*\)]\ k\_b[2]\^2 + 
      6\ \[Delta]p[i]\ \[Delta]p[j]\ \[Delta]p[k]\ \[Delta]p[\(i\^*\)]\ 
        \[Delta]p[\(j\^*\)]\ \[Delta]p[\(k\^*\)]\ k\_b[2]\^3 + 
      p[\(k\^*\)]\ \[Delta]p[i]\ \[Delta]p[j]\ \[Delta]p[\(i\^*\)]\ k\_b[3] - 
      p[k]\ p[\(k\^*\)]\ \[Delta]p[i]\ \[Delta]p[j]\ \[Delta]p[\(i\^*\)]\ 
        k\_b[3] - 
      p[\(j\^*\)]\ p[\(k\^*\)]\ \[Delta]p[i]\ \[Delta]p[j]\ 
        \[Delta]p[\(i\^*\)]\ k\_b[3] + 
      p[k]\ p[\(j\^*\)]\ p[\(k\^*\)]\ \[Delta]p[i]\ \[Delta]p[j]\ 
        \[Delta]p[\(i\^*\)]\ k\_b[3] - 
      p[j]\ p[\(k\^*\)]\ \[Delta]p[i]\ \[Delta]p[k]\ \[Delta]p[\(i\^*\)]\ 
        k\_b[3] + 
      p[j]\ p[\(j\^*\)]\ p[\(k\^*\)]\ \[Delta]p[i]\ \[Delta]p[k]\ 
        \[Delta]p[\(i\^*\)]\ k\_b[3] + 
      p[\(k\^*\)]\ \[Delta]p[j]\ \[Delta]p[k]\ \[Delta]p[\(i\^*\)]\ k\_b[3] - 
      p[i]\ p[\(k\^*\)]\ \[Delta]p[j]\ \[Delta]p[k]\ \[Delta]p[\(i\^*\)]\ 
        k\_b[3] - 
      p[\(j\^*\)]\ p[\(k\^*\)]\ \[Delta]p[j]\ \[Delta]p[k]\ 
        \[Delta]p[\(i\^*\)]\ k\_b[3] + 
      p[i]\ p[\(j\^*\)]\ p[\(k\^*\)]\ \[Delta]p[j]\ \[Delta]p[k]\ 
        \[Delta]p[\(i\^*\)]\ k\_b[3] + 
      p[\(k\^*\)]\ \[Delta]p[i]\ \[Delta]p[j]\ \[Delta]p[\(j\^*\)]\ k\_b[3] - 
      p[k]\ p[\(k\^*\)]\ \[Delta]p[i]\ \[Delta]p[j]\ \[Delta]p[\(j\^*\)]\ 
        k\_b[3] - 
      p[\(i\^*\)]\ p[\(k\^*\)]\ \[Delta]p[i]\ \[Delta]p[j]\ 
        \[Delta]p[\(j\^*\)]\ k\_b[3] + 
      p[k]\ p[\(i\^*\)]\ p[\(k\^*\)]\ \[Delta]p[i]\ \[Delta]p[j]\ 
        \[Delta]p[\(j\^*\)]\ k\_b[3] - 
      p[j]\ p[\(k\^*\)]\ \[Delta]p[i]\ \[Delta]p[k]\ \[Delta]p[\(j\^*\)]\ 
        k\_b[3] + 
      p[j]\ p[\(i\^*\)]\ p[\(k\^*\)]\ \[Delta]p[i]\ \[Delta]p[k]\ 
        \[Delta]p[\(j\^*\)]\ k\_b[3] + 
      p[\(k\^*\)]\ \[Delta]p[j]\ \[Delta]p[k]\ \[Delta]p[\(j\^*\)]\ k\_b[3] - 
      p[i]\ p[\(k\^*\)]\ \[Delta]p[j]\ \[Delta]p[k]\ \[Delta]p[\(j\^*\)]\ 
        k\_b[3] - 
      p[\(i\^*\)]\ p[\(k\^*\)]\ \[Delta]p[j]\ \[Delta]p[k]\ 
        \[Delta]p[\(j\^*\)]\ k\_b[3] + 
      p[i]\ p[\(i\^*\)]\ p[\(k\^*\)]\ \[Delta]p[j]\ \[Delta]p[k]\ 
        \[Delta]p[\(j\^*\)]\ k\_b[3] - 
      p[j]\ p[\(k\^*\)]\ \[Delta]p[i]\ \[Delta]p[\(i\^*\)]\ 
        \[Delta]p[\(j\^*\)]\ k\_b[3] + 
      p[j]\ p[k]\ p[\(k\^*\)]\ \[Delta]p[i]\ \[Delta]p[\(i\^*\)]\ 
        \[Delta]p[\(j\^*\)]\ k\_b[3] + 
      p[\(k\^*\)]\ \[Delta]p[j]\ \[Delta]p[\(i\^*\)]\ \[Delta]p[\(j\^*\)]\ 
        k\_b[3] - 
      p[i]\ p[\(k\^*\)]\ \[Delta]p[j]\ \[Delta]p[\(i\^*\)]\ 
        \[Delta]p[\(j\^*\)]\ k\_b[3] - 
      p[k]\ p[\(k\^*\)]\ \[Delta]p[j]\ \[Delta]p[\(i\^*\)]\ 
        \[Delta]p[\(j\^*\)]\ k\_b[3] + 
      p[i]\ p[k]\ p[\(k\^*\)]\ \[Delta]p[j]\ \[Delta]p[\(i\^*\)]\ 
        \[Delta]p[\(j\^*\)]\ k\_b[3] - 
      p[j]\ p[\(k\^*\)]\ \[Delta]p[k]\ \[Delta]p[\(i\^*\)]\ 
        \[Delta]p[\(j\^*\)]\ k\_b[3] + 
      p[i]\ p[j]\ p[\(k\^*\)]\ \[Delta]p[k]\ \[Delta]p[\(i\^*\)]\ 
        \[Delta]p[\(j\^*\)]\ k\_b[3] - 
      \[Delta]p[i]\ \[Delta]p[j]\ \[Delta]p[\(k\^*\)]\ k\_b[3] + 
      p[k]\ \[Delta]p[i]\ \[Delta]p[j]\ \[Delta]p[\(k\^*\)]\ k\_b[3] + 
      p[\(i\^*\)]\ \[Delta]p[i]\ \[Delta]p[j]\ \[Delta]p[\(k\^*\)]\ k\_b[3] - 
      p[k]\ p[\(i\^*\)]\ \[Delta]p[i]\ \[Delta]p[j]\ \[Delta]p[\(k\^*\)]\ 
        k\_b[3] + 
      p[\(j\^*\)]\ \[Delta]p[i]\ \[Delta]p[j]\ \[Delta]p[\(k\^*\)]\ k\_b[3] - 
      p[k]\ p[\(j\^*\)]\ \[Delta]p[i]\ \[Delta]p[j]\ \[Delta]p[\(k\^*\)]\ 
        k\_b[3] - 
      p[\(i\^*\)]\ p[\(j\^*\)]\ \[Delta]p[i]\ \[Delta]p[j]\ 
        \[Delta]p[\(k\^*\)]\ k\_b[3] + 
      p[k]\ p[\(i\^*\)]\ p[\(j\^*\)]\ \[Delta]p[i]\ \[Delta]p[j]\ 
        \[Delta]p[\(k\^*\)]\ k\_b[3] + 
      p[j]\ \[Delta]p[i]\ \[Delta]p[k]\ \[Delta]p[\(k\^*\)]\ k\_b[3] - 
      p[j]\ p[\(i\^*\)]\ \[Delta]p[i]\ \[Delta]p[k]\ \[Delta]p[\(k\^*\)]\ 
        k\_b[3] - 
      p[j]\ p[\(j\^*\)]\ \[Delta]p[i]\ \[Delta]p[k]\ \[Delta]p[\(k\^*\)]\ 
        k\_b[3] + 
      p[j]\ p[\(i\^*\)]\ p[\(j\^*\)]\ \[Delta]p[i]\ \[Delta]p[k]\ 
        \[Delta]p[\(k\^*\)]\ k\_b[3] - 
      \[Delta]p[j]\ \[Delta]p[k]\ \[Delta]p[\(k\^*\)]\ k\_b[3] + 
      p[i]\ \[Delta]p[j]\ \[Delta]p[k]\ \[Delta]p[\(k\^*\)]\ k\_b[3] + 
      p[\(i\^*\)]\ \[Delta]p[j]\ \[Delta]p[k]\ \[Delta]p[\(k\^*\)]\ k\_b[3] - 
      p[i]\ p[\(i\^*\)]\ \[Delta]p[j]\ \[Delta]p[k]\ \[Delta]p[\(k\^*\)]\ 
        k\_b[3] + 
      p[\(j\^*\)]\ \[Delta]p[j]\ \[Delta]p[k]\ \[Delta]p[\(k\^*\)]\ k\_b[3] - 
      p[i]\ p[\(j\^*\)]\ \[Delta]p[j]\ \[Delta]p[k]\ \[Delta]p[\(k\^*\)]\ 
        k\_b[3] - 
      p[\(i\^*\)]\ p[\(j\^*\)]\ \[Delta]p[j]\ \[Delta]p[k]\ 
        \[Delta]p[\(k\^*\)]\ k\_b[3] + 
      p[i]\ p[\(i\^*\)]\ p[\(j\^*\)]\ \[Delta]p[j]\ \[Delta]p[k]\ 
        \[Delta]p[\(k\^*\)]\ k\_b[3] + 
      p[j]\ \[Delta]p[i]\ \[Delta]p[\(i\^*\)]\ \[Delta]p[\(k\^*\)]\ k\_b[3] - 
      p[j]\ p[k]\ \[Delta]p[i]\ \[Delta]p[\(i\^*\)]\ \[Delta]p[\(k\^*\)]\ 
        k\_b[3] - 
      p[j]\ p[\(j\^*\)]\ \[Delta]p[i]\ \[Delta]p[\(i\^*\)]\ 
        \[Delta]p[\(k\^*\)]\ k\_b[3] + 
      p[j]\ p[k]\ p[\(j\^*\)]\ \[Delta]p[i]\ \[Delta]p[\(i\^*\)]\ 
        \[Delta]p[\(k\^*\)]\ k\_b[3] - 
      \[Delta]p[j]\ \[Delta]p[\(i\^*\)]\ \[Delta]p[\(k\^*\)]\ k\_b[3] + 
      p[i]\ \[Delta]p[j]\ \[Delta]p[\(i\^*\)]\ \[Delta]p[\(k\^*\)]\ k\_b[3] + 
      p[k]\ \[Delta]p[j]\ \[Delta]p[\(i\^*\)]\ \[Delta]p[\(k\^*\)]\ k\_b[3] - 
      p[i]\ p[k]\ \[Delta]p[j]\ \[Delta]p[\(i\^*\)]\ \[Delta]p[\(k\^*\)]\ 
        k\_b[3] + 
      p[\(j\^*\)]\ \[Delta]p[j]\ \[Delta]p[\(i\^*\)]\ \[Delta]p[\(k\^*\)]\ 
        k\_b[3] - 
      p[i]\ p[\(j\^*\)]\ \[Delta]p[j]\ \[Delta]p[\(i\^*\)]\ 
        \[Delta]p[\(k\^*\)]\ k\_b[3] - 
      p[k]\ p[\(j\^*\)]\ \[Delta]p[j]\ \[Delta]p[\(i\^*\)]\ 
        \[Delta]p[\(k\^*\)]\ k\_b[3] + 
      p[i]\ p[k]\ p[\(j\^*\)]\ \[Delta]p[j]\ \[Delta]p[\(i\^*\)]\ 
        \[Delta]p[\(k\^*\)]\ k\_b[3] + 
      p[j]\ \[Delta]p[k]\ \[Delta]p[\(i\^*\)]\ \[Delta]p[\(k\^*\)]\ k\_b[3] - 
      p[i]\ p[j]\ \[Delta]p[k]\ \[Delta]p[\(i\^*\)]\ \[Delta]p[\(k\^*\)]\ 
        k\_b[3] - 
      p[j]\ p[\(j\^*\)]\ \[Delta]p[k]\ \[Delta]p[\(i\^*\)]\ 
        \[Delta]p[\(k\^*\)]\ k\_b[3] + 
      p[i]\ p[j]\ p[\(j\^*\)]\ \[Delta]p[k]\ \[Delta]p[\(i\^*\)]\ 
        \[Delta]p[\(k\^*\)]\ k\_b[3] + 
      p[j]\ \[Delta]p[i]\ \[Delta]p[\(j\^*\)]\ \[Delta]p[\(k\^*\)]\ k\_b[3] - 
      p[j]\ p[k]\ \[Delta]p[i]\ \[Delta]p[\(j\^*\)]\ \[Delta]p[\(k\^*\)]\ 
        k\_b[3] - 
      p[j]\ p[\(i\^*\)]\ \[Delta]p[i]\ \[Delta]p[\(j\^*\)]\ 
        \[Delta]p[\(k\^*\)]\ k\_b[3] + 
      p[j]\ p[k]\ p[\(i\^*\)]\ \[Delta]p[i]\ \[Delta]p[\(j\^*\)]\ 
        \[Delta]p[\(k\^*\)]\ k\_b[3] - 
      \[Delta]p[j]\ \[Delta]p[\(j\^*\)]\ \[Delta]p[\(k\^*\)]\ k\_b[3] + 
      p[i]\ \[Delta]p[j]\ \[Delta]p[\(j\^*\)]\ \[Delta]p[\(k\^*\)]\ k\_b[3] + 
      p[k]\ \[Delta]p[j]\ \[Delta]p[\(j\^*\)]\ \[Delta]p[\(k\^*\)]\ k\_b[3] - 
      p[i]\ p[k]\ \[Delta]p[j]\ \[Delta]p[\(j\^*\)]\ \[Delta]p[\(k\^*\)]\ 
        k\_b[3] + 
      p[\(i\^*\)]\ \[Delta]p[j]\ \[Delta]p[\(j\^*\)]\ \[Delta]p[\(k\^*\)]\ 
        k\_b[3] - 
      p[i]\ p[\(i\^*\)]\ \[Delta]p[j]\ \[Delta]p[\(j\^*\)]\ 
        \[Delta]p[\(k\^*\)]\ k\_b[3] - 
      p[k]\ p[\(i\^*\)]\ \[Delta]p[j]\ \[Delta]p[\(j\^*\)]\ 
        \[Delta]p[\(k\^*\)]\ k\_b[3] + 
      p[i]\ p[k]\ p[\(i\^*\)]\ \[Delta]p[j]\ \[Delta]p[\(j\^*\)]\ 
        \[Delta]p[\(k\^*\)]\ k\_b[3] + 
      p[j]\ \[Delta]p[k]\ \[Delta]p[\(j\^*\)]\ \[Delta]p[\(k\^*\)]\ k\_b[3] - 
      p[i]\ p[j]\ \[Delta]p[k]\ \[Delta]p[\(j\^*\)]\ \[Delta]p[\(k\^*\)]\ 
        k\_b[3] - 
      p[j]\ p[\(i\^*\)]\ \[Delta]p[k]\ \[Delta]p[\(j\^*\)]\ 
        \[Delta]p[\(k\^*\)]\ k\_b[3] + 
      p[i]\ p[j]\ p[\(i\^*\)]\ \[Delta]p[k]\ \[Delta]p[\(j\^*\)]\ 
        \[Delta]p[\(k\^*\)]\ k\_b[3] + 
      6\ p[\(k\^*\)]\ \[Delta]p[i]\ \[Delta]p[j]\ \[Delta]p[k]\ 
        \[Delta]p[\(i\^*\)]\ \[Delta]p[\(j\^*\)]\ k\_b[2]\ k\_b[3] - 
      6\ \[Delta]p[i]\ \[Delta]p[j]\ \[Delta]p[k]\ \[Delta]p[\(i\^*\)]\ 
        \[Delta]p[\(k\^*\)]\ k\_b[2]\ k\_b[3] + 
      6\ p[\(j\^*\)]\ \[Delta]p[i]\ \[Delta]p[j]\ \[Delta]p[k]\ 
        \[Delta]p[\(i\^*\)]\ \[Delta]p[\(k\^*\)]\ k\_b[2]\ k\_b[3] - 
      6\ \[Delta]p[i]\ \[Delta]p[j]\ \[Delta]p[k]\ \[Delta]p[\(j\^*\)]\ 
        \[Delta]p[\(k\^*\)]\ k\_b[2]\ k\_b[3] + 
      6\ p[\(i\^*\)]\ \[Delta]p[i]\ \[Delta]p[j]\ \[Delta]p[k]\ 
        \[Delta]p[\(j\^*\)]\ \[Delta]p[\(k\^*\)]\ k\_b[2]\ k\_b[3] - 
      6\ \[Delta]p[i]\ \[Delta]p[j]\ \[Delta]p[\(i\^*\)]\ 
        \[Delta]p[\(j\^*\)]\ \[Delta]p[\(k\^*\)]\ k\_b[2]\ k\_b[3] + 
      6\ p[k]\ \[Delta]p[i]\ \[Delta]p[j]\ \[Delta]p[\(i\^*\)]\ 
        \[Delta]p[\(j\^*\)]\ \[Delta]p[\(k\^*\)]\ k\_b[2]\ k\_b[3] + 
      6\ p[j]\ \[Delta]p[i]\ \[Delta]p[k]\ \[Delta]p[\(i\^*\)]\ 
        \[Delta]p[\(j\^*\)]\ \[Delta]p[\(k\^*\)]\ k\_b[2]\ k\_b[3] - 
      6\ \[Delta]p[j]\ \[Delta]p[k]\ \[Delta]p[\(i\^*\)]\ 
        \[Delta]p[\(j\^*\)]\ \[Delta]p[\(k\^*\)]\ k\_b[2]\ k\_b[3] + 
      6\ p[i]\ \[Delta]p[j]\ \[Delta]p[k]\ \[Delta]p[\(i\^*\)]\ 
        \[Delta]p[\(j\^*\)]\ \[Delta]p[\(k\^*\)]\ k\_b[2]\ k\_b[3] + 
      9\ \[Delta]p[i]\ \[Delta]p[j]\ \[Delta]p[k]\ \[Delta]p[\(i\^*\)]\ 
        \[Delta]p[\(j\^*\)]\ \[Delta]p[\(k\^*\)]\ k\_b[3]\^2 - 
      p[\(k\^*\)]\ \[Delta]p[i]\ \[Delta]p[j]\ \[Delta]p[k]\ 
        \[Delta]p[\(i\^*\)]\ k\_b[4] + 
      p[\(j\^*\)]\ p[\(k\^*\)]\ \[Delta]p[i]\ \[Delta]p[j]\ \[Delta]p[k]\ 
        \[Delta]p[\(i\^*\)]\ k\_b[4] - 
      p[\(k\^*\)]\ \[Delta]p[i]\ \[Delta]p[j]\ \[Delta]p[k]\ 
        \[Delta]p[\(j\^*\)]\ k\_b[4] + 
      p[\(i\^*\)]\ p[\(k\^*\)]\ \[Delta]p[i]\ \[Delta]p[j]\ \[Delta]p[k]\ 
        \[Delta]p[\(j\^*\)]\ k\_b[4] - 
      p[\(k\^*\)]\ \[Delta]p[i]\ \[Delta]p[j]\ \[Delta]p[\(i\^*\)]\ 
        \[Delta]p[\(j\^*\)]\ k\_b[4] + 
      p[k]\ p[\(k\^*\)]\ \[Delta]p[i]\ \[Delta]p[j]\ \[Delta]p[\(i\^*\)]\ 
        \[Delta]p[\(j\^*\)]\ k\_b[4] + 
      p[j]\ p[\(k\^*\)]\ \[Delta]p[i]\ \[Delta]p[k]\ \[Delta]p[\(i\^*\)]\ 
        \[Delta]p[\(j\^*\)]\ k\_b[4] - 
      p[\(k\^*\)]\ \[Delta]p[j]\ \[Delta]p[k]\ \[Delta]p[\(i\^*\)]\ 
        \[Delta]p[\(j\^*\)]\ k\_b[4] + 
      p[i]\ p[\(k\^*\)]\ \[Delta]p[j]\ \[Delta]p[k]\ \[Delta]p[\(i\^*\)]\ 
        \[Delta]p[\(j\^*\)]\ k\_b[4] + 
      \[Delta]p[i]\ \[Delta]p[j]\ \[Delta]p[k]\ \[Delta]p[\(k\^*\)]\ 
        k\_b[4] - 
      p[\(i\^*\)]\ \[Delta]p[i]\ \[Delta]p[j]\ \[Delta]p[k]\ 
        \[Delta]p[\(k\^*\)]\ k\_b[4] - 
      p[\(j\^*\)]\ \[Delta]p[i]\ \[Delta]p[j]\ \[Delta]p[k]\ 
        \[Delta]p[\(k\^*\)]\ k\_b[4] + 
      p[\(i\^*\)]\ p[\(j\^*\)]\ \[Delta]p[i]\ \[Delta]p[j]\ \[Delta]p[k]\ 
        \[Delta]p[\(k\^*\)]\ k\_b[4] + 
      \[Delta]p[i]\ \[Delta]p[j]\ \[Delta]p[\(i\^*\)]\ \[Delta]p[\(k\^*\)]\ 
        k\_b[4] - 
      p[k]\ \[Delta]p[i]\ \[Delta]p[j]\ \[Delta]p[\(i\^*\)]\ 
        \[Delta]p[\(k\^*\)]\ k\_b[4] - 
      p[\(j\^*\)]\ \[Delta]p[i]\ \[Delta]p[j]\ \[Delta]p[\(i\^*\)]\ 
        \[Delta]p[\(k\^*\)]\ k\_b[4] + 
      p[k]\ p[\(j\^*\)]\ \[Delta]p[i]\ \[Delta]p[j]\ \[Delta]p[\(i\^*\)]\ 
        \[Delta]p[\(k\^*\)]\ k\_b[4] - 
      p[j]\ \[Delta]p[i]\ \[Delta]p[k]\ \[Delta]p[\(i\^*\)]\ 
        \[Delta]p[\(k\^*\)]\ k\_b[4] + 
      p[j]\ p[\(j\^*\)]\ \[Delta]p[i]\ \[Delta]p[k]\ \[Delta]p[\(i\^*\)]\ 
        \[Delta]p[\(k\^*\)]\ k\_b[4] + 
      \[Delta]p[j]\ \[Delta]p[k]\ \[Delta]p[\(i\^*\)]\ \[Delta]p[\(k\^*\)]\ 
        k\_b[4] - 
      p[i]\ \[Delta]p[j]\ \[Delta]p[k]\ \[Delta]p[\(i\^*\)]\ 
        \[Delta]p[\(k\^*\)]\ k\_b[4] - 
      p[\(j\^*\)]\ \[Delta]p[j]\ \[Delta]p[k]\ \[Delta]p[\(i\^*\)]\ 
        \[Delta]p[\(k\^*\)]\ k\_b[4] + 
      p[i]\ p[\(j\^*\)]\ \[Delta]p[j]\ \[Delta]p[k]\ \[Delta]p[\(i\^*\)]\ 
        \[Delta]p[\(k\^*\)]\ k\_b[4] + 
      \[Delta]p[i]\ \[Delta]p[j]\ \[Delta]p[\(j\^*\)]\ \[Delta]p[\(k\^*\)]\ 
        k\_b[4] - 
      p[k]\ \[Delta]p[i]\ \[Delta]p[j]\ \[Delta]p[\(j\^*\)]\ 
        \[Delta]p[\(k\^*\)]\ k\_b[4] - 
      p[\(i\^*\)]\ \[Delta]p[i]\ \[Delta]p[j]\ \[Delta]p[\(j\^*\)]\ 
        \[Delta]p[\(k\^*\)]\ k\_b[4] + 
      p[k]\ p[\(i\^*\)]\ \[Delta]p[i]\ \[Delta]p[j]\ \[Delta]p[\(j\^*\)]\ 
        \[Delta]p[\(k\^*\)]\ k\_b[4] - 
      p[j]\ \[Delta]p[i]\ \[Delta]p[k]\ \[Delta]p[\(j\^*\)]\ 
        \[Delta]p[\(k\^*\)]\ k\_b[4] + 
      p[j]\ p[\(i\^*\)]\ \[Delta]p[i]\ \[Delta]p[k]\ \[Delta]p[\(j\^*\)]\ 
        \[Delta]p[\(k\^*\)]\ k\_b[4] + 
      \[Delta]p[j]\ \[Delta]p[k]\ \[Delta]p[\(j\^*\)]\ \[Delta]p[\(k\^*\)]\ 
        k\_b[4] - 
      p[i]\ \[Delta]p[j]\ \[Delta]p[k]\ \[Delta]p[\(j\^*\)]\ 
        \[Delta]p[\(k\^*\)]\ k\_b[4] - 
      p[\(i\^*\)]\ \[Delta]p[j]\ \[Delta]p[k]\ \[Delta]p[\(j\^*\)]\ 
        \[Delta]p[\(k\^*\)]\ k\_b[4] + 
      p[i]\ p[\(i\^*\)]\ \[Delta]p[j]\ \[Delta]p[k]\ \[Delta]p[\(j\^*\)]\ 
        \[Delta]p[\(k\^*\)]\ k\_b[4] - 
      p[j]\ \[Delta]p[i]\ \[Delta]p[\(i\^*\)]\ \[Delta]p[\(j\^*\)]\ 
        \[Delta]p[\(k\^*\)]\ k\_b[4] + 
      p[j]\ p[k]\ \[Delta]p[i]\ \[Delta]p[\(i\^*\)]\ \[Delta]p[\(j\^*\)]\ 
        \[Delta]p[\(k\^*\)]\ k\_b[4] + 
      \[Delta]p[j]\ \[Delta]p[\(i\^*\)]\ \[Delta]p[\(j\^*\)]\ 
        \[Delta]p[\(k\^*\)]\ k\_b[4] - 
      p[i]\ \[Delta]p[j]\ \[Delta]p[\(i\^*\)]\ \[Delta]p[\(j\^*\)]\ 
        \[Delta]p[\(k\^*\)]\ k\_b[4] - 
      p[k]\ \[Delta]p[j]\ \[Delta]p[\(i\^*\)]\ \[Delta]p[\(j\^*\)]\ 
        \[Delta]p[\(k\^*\)]\ k\_b[4] + 
      p[i]\ p[k]\ \[Delta]p[j]\ \[Delta]p[\(i\^*\)]\ \[Delta]p[\(j\^*\)]\ 
        \[Delta]p[\(k\^*\)]\ k\_b[4] - 
      p[j]\ \[Delta]p[k]\ \[Delta]p[\(i\^*\)]\ \[Delta]p[\(j\^*\)]\ 
        \[Delta]p[\(k\^*\)]\ k\_b[4] + 
      p[i]\ p[j]\ \[Delta]p[k]\ \[Delta]p[\(i\^*\)]\ \[Delta]p[\(j\^*\)]\ 
        \[Delta]p[\(k\^*\)]\ k\_b[4] + 
      9\ \[Delta]p[i]\ \[Delta]p[j]\ \[Delta]p[k]\ \[Delta]p[\(i\^*\)]\ 
        \[Delta]p[\(j\^*\)]\ \[Delta]p[\(k\^*\)]\ k\_b[2]\ k\_b[4] + 
      p[\(k\^*\)]\ \[Delta]p[i]\ \[Delta]p[j]\ \[Delta]p[k]\ 
        \[Delta]p[\(i\^*\)]\ \[Delta]p[\(j\^*\)]\ k\_b[5] - 
      \[Delta]p[i]\ \[Delta]p[j]\ \[Delta]p[k]\ \[Delta]p[\(i\^*\)]\ 
        \[Delta]p[\(k\^*\)]\ k\_b[5] + 
      p[\(j\^*\)]\ \[Delta]p[i]\ \[Delta]p[j]\ \[Delta]p[k]\ 
        \[Delta]p[\(i\^*\)]\ \[Delta]p[\(k\^*\)]\ k\_b[5] - 
      \[Delta]p[i]\ \[Delta]p[j]\ \[Delta]p[k]\ \[Delta]p[\(j\^*\)]\ 
        \[Delta]p[\(k\^*\)]\ k\_b[5] + 
      p[\(i\^*\)]\ \[Delta]p[i]\ \[Delta]p[j]\ \[Delta]p[k]\ 
        \[Delta]p[\(j\^*\)]\ \[Delta]p[\(k\^*\)]\ k\_b[5] - 
      \[Delta]p[i]\ \[Delta]p[j]\ \[Delta]p[\(i\^*\)]\ \[Delta]p[\(j\^*\)]\ 
        \[Delta]p[\(k\^*\)]\ k\_b[5] + 
      p[k]\ \[Delta]p[i]\ \[Delta]p[j]\ \[Delta]p[\(i\^*\)]\ 
        \[Delta]p[\(j\^*\)]\ \[Delta]p[\(k\^*\)]\ k\_b[5] + 
      p[j]\ \[Delta]p[i]\ \[Delta]p[k]\ \[Delta]p[\(i\^*\)]\ 
        \[Delta]p[\(j\^*\)]\ \[Delta]p[\(k\^*\)]\ k\_b[5] - 
      \[Delta]p[j]\ \[Delta]p[k]\ \[Delta]p[\(i\^*\)]\ \[Delta]p[\(j\^*\)]\ 
        \[Delta]p[\(k\^*\)]\ k\_b[5] + 
      p[i]\ \[Delta]p[j]\ \[Delta]p[k]\ \[Delta]p[\(i\^*\)]\ 
        \[Delta]p[\(j\^*\)]\ \[Delta]p[\(k\^*\)]\ k\_b[5] + 
      \[Delta]p[i]\ \[Delta]p[j]\ \[Delta]p[k]\ \[Delta]p[\(i\^*\)]\ 
        \[Delta]p[\(j\^*\)]\ \[Delta]p[\(k\^*\)]\ k\_b[6] - 
      p[\(k\^*\)]\ \[Delta]p[i]\ \[Delta]p[j]\ k\_w[2] + 
      p[k]\ p[\(k\^*\)]\ \[Delta]p[i]\ \[Delta]p[j]\ k\_w[2] + 
      p[\(i\^*\)]\ p[\(k\^*\)]\ \[Delta]p[i]\ \[Delta]p[j]\ k\_w[2] - 
      p[k]\ p[\(i\^*\)]\ p[\(k\^*\)]\ \[Delta]p[i]\ \[Delta]p[j]\ k\_w[2] + 
      p[\(j\^*\)]\ p[\(k\^*\)]\ \[Delta]p[i]\ \[Delta]p[j]\ k\_w[2] - 
      p[k]\ p[\(j\^*\)]\ p[\(k\^*\)]\ \[Delta]p[i]\ \[Delta]p[j]\ k\_w[2] - 
      p[\(i\^*\)]\ p[\(j\^*\)]\ p[\(k\^*\)]\ \[Delta]p[i]\ \[Delta]p[j]\ 
        k\_w[2] + 
      p[k]\ p[\(i\^*\)]\ p[\(j\^*\)]\ p[\(k\^*\)]\ \[Delta]p[i]\ 
        \[Delta]p[j]\ k\_w[2] + 
      p[j]\ p[\(k\^*\)]\ \[Delta]p[i]\ \[Delta]p[k]\ k\_w[2] - 
      p[j]\ p[\(i\^*\)]\ p[\(k\^*\)]\ \[Delta]p[i]\ \[Delta]p[k]\ k\_w[2] - 
      p[j]\ p[\(j\^*\)]\ p[\(k\^*\)]\ \[Delta]p[i]\ \[Delta]p[k]\ k\_w[2] + 
      p[j]\ p[\(i\^*\)]\ p[\(j\^*\)]\ p[\(k\^*\)]\ \[Delta]p[i]\ 
        \[Delta]p[k]\ k\_w[2] - 
      p[\(k\^*\)]\ \[Delta]p[j]\ \[Delta]p[k]\ k\_w[2] + 
      p[i]\ p[\(k\^*\)]\ \[Delta]p[j]\ \[Delta]p[k]\ k\_w[2] + 
      p[\(i\^*\)]\ p[\(k\^*\)]\ \[Delta]p[j]\ \[Delta]p[k]\ k\_w[2] - 
      p[i]\ p[\(i\^*\)]\ p[\(k\^*\)]\ \[Delta]p[j]\ \[Delta]p[k]\ k\_w[2] + 
      p[\(j\^*\)]\ p[\(k\^*\)]\ \[Delta]p[j]\ \[Delta]p[k]\ k\_w[2] - 
      p[i]\ p[\(j\^*\)]\ p[\(k\^*\)]\ \[Delta]p[j]\ \[Delta]p[k]\ k\_w[2] - 
      p[\(i\^*\)]\ p[\(j\^*\)]\ p[\(k\^*\)]\ \[Delta]p[j]\ \[Delta]p[k]\ 
        k\_w[2] + 
      p[i]\ p[\(i\^*\)]\ p[\(j\^*\)]\ p[\(k\^*\)]\ \[Delta]p[j]\ 
        \[Delta]p[k]\ k\_w[2] + 
      p[j]\ p[\(k\^*\)]\ \[Delta]p[\(i\^*\)]\ \[Delta]p[\(j\^*\)]\ k\_w[2] - 
      p[i]\ p[j]\ p[\(k\^*\)]\ \[Delta]p[\(i\^*\)]\ \[Delta]p[\(j\^*\)]\ 
        k\_w[2] - 
      p[j]\ p[k]\ p[\(k\^*\)]\ \[Delta]p[\(i\^*\)]\ \[Delta]p[\(j\^*\)]\ 
        k\_w[2] + 
      p[i]\ p[j]\ p[k]\ p[\(k\^*\)]\ \[Delta]p[\(i\^*\)]\ 
        \[Delta]p[\(j\^*\)]\ k\_w[2] - 
      p[j]\ \[Delta]p[\(i\^*\)]\ \[Delta]p[\(k\^*\)]\ k\_w[2] + 
      p[i]\ p[j]\ \[Delta]p[\(i\^*\)]\ \[Delta]p[\(k\^*\)]\ k\_w[2] + 
      p[j]\ p[k]\ \[Delta]p[\(i\^*\)]\ \[Delta]p[\(k\^*\)]\ k\_w[2] - 
      p[i]\ p[j]\ p[k]\ \[Delta]p[\(i\^*\)]\ \[Delta]p[\(k\^*\)]\ k\_w[2] + 
      p[j]\ p[\(j\^*\)]\ \[Delta]p[\(i\^*\)]\ \[Delta]p[\(k\^*\)]\ k\_w[2] - 
      p[i]\ p[j]\ p[\(j\^*\)]\ \[Delta]p[\(i\^*\)]\ \[Delta]p[\(k\^*\)]\ 
        k\_w[2] - 
      p[j]\ p[k]\ p[\(j\^*\)]\ \[Delta]p[\(i\^*\)]\ \[Delta]p[\(k\^*\)]\ 
        k\_w[2] + 
      p[i]\ p[j]\ p[k]\ p[\(j\^*\)]\ \[Delta]p[\(i\^*\)]\ 
        \[Delta]p[\(k\^*\)]\ k\_w[2] - 
      p[j]\ \[Delta]p[\(j\^*\)]\ \[Delta]p[\(k\^*\)]\ k\_w[2] + 
      p[i]\ p[j]\ \[Delta]p[\(j\^*\)]\ \[Delta]p[\(k\^*\)]\ k\_w[2] + 
      p[j]\ p[k]\ \[Delta]p[\(j\^*\)]\ \[Delta]p[\(k\^*\)]\ k\_w[2] - 
      p[i]\ p[j]\ p[k]\ \[Delta]p[\(j\^*\)]\ \[Delta]p[\(k\^*\)]\ k\_w[2] + 
      p[j]\ p[\(i\^*\)]\ \[Delta]p[\(j\^*\)]\ \[Delta]p[\(k\^*\)]\ k\_w[2] - 
      p[i]\ p[j]\ p[\(i\^*\)]\ \[Delta]p[\(j\^*\)]\ \[Delta]p[\(k\^*\)]\ 
        k\_w[2] - 
      p[j]\ p[k]\ p[\(i\^*\)]\ \[Delta]p[\(j\^*\)]\ \[Delta]p[\(k\^*\)]\ 
        k\_w[2] + 
      p[i]\ p[j]\ p[k]\ p[\(i\^*\)]\ \[Delta]p[\(j\^*\)]\ 
        \[Delta]p[\(k\^*\)]\ k\_w[2] - 
      3\ p[\(k\^*\)]\ \[Delta]p[i]\ \[Delta]p[j]\ \[Delta]p[k]\ 
        \[Delta]p[\(i\^*\)]\ k\_b[2]\ k\_w[2] + 
      3\ p[\(j\^*\)]\ p[\(k\^*\)]\ \[Delta]p[i]\ \[Delta]p[j]\ \[Delta]p[k]\ 
        \[Delta]p[\(i\^*\)]\ k\_b[2]\ k\_w[2] - 
      3\ p[\(k\^*\)]\ \[Delta]p[i]\ \[Delta]p[j]\ \[Delta]p[k]\ 
        \[Delta]p[\(j\^*\)]\ k\_b[2]\ k\_w[2] + 
      3\ p[\(i\^*\)]\ p[\(k\^*\)]\ \[Delta]p[i]\ \[Delta]p[j]\ \[Delta]p[k]\ 
        \[Delta]p[\(j\^*\)]\ k\_b[2]\ k\_w[2] + 
      3\ \[Delta]p[i]\ \[Delta]p[j]\ \[Delta]p[k]\ \[Delta]p[\(k\^*\)]\ 
        k\_b[2]\ k\_w[2] - 
      3\ p[\(i\^*\)]\ \[Delta]p[i]\ \[Delta]p[j]\ \[Delta]p[k]\ 
        \[Delta]p[\(k\^*\)]\ k\_b[2]\ k\_w[2] - 
      3\ p[\(j\^*\)]\ \[Delta]p[i]\ \[Delta]p[j]\ \[Delta]p[k]\ 
        \[Delta]p[\(k\^*\)]\ k\_b[2]\ k\_w[2] + 
      3\ p[\(i\^*\)]\ p[\(j\^*\)]\ \[Delta]p[i]\ \[Delta]p[j]\ \[Delta]p[k]\ 
        \[Delta]p[\(k\^*\)]\ k\_b[2]\ k\_w[2] - 
      3\ p[j]\ \[Delta]p[i]\ \[Delta]p[\(i\^*\)]\ \[Delta]p[\(j\^*\)]\ 
        \[Delta]p[\(k\^*\)]\ k\_b[2]\ k\_w[2] + 
      3\ p[j]\ p[k]\ \[Delta]p[i]\ \[Delta]p[\(i\^*\)]\ \[Delta]p[\(j\^*\)]\ 
        \[Delta]p[\(k\^*\)]\ k\_b[2]\ k\_w[2] + 
      3\ \[Delta]p[j]\ \[Delta]p[\(i\^*\)]\ \[Delta]p[\(j\^*\)]\ 
        \[Delta]p[\(k\^*\)]\ k\_b[2]\ k\_w[2] - 
      3\ p[i]\ \[Delta]p[j]\ \[Delta]p[\(i\^*\)]\ \[Delta]p[\(j\^*\)]\ 
        \[Delta]p[\(k\^*\)]\ k\_b[2]\ k\_w[2] - 
      3\ p[k]\ \[Delta]p[j]\ \[Delta]p[\(i\^*\)]\ \[Delta]p[\(j\^*\)]\ 
        \[Delta]p[\(k\^*\)]\ k\_b[2]\ k\_w[2] + 
      3\ p[i]\ p[k]\ \[Delta]p[j]\ \[Delta]p[\(i\^*\)]\ \[Delta]p[\(j\^*\)]\ 
        \[Delta]p[\(k\^*\)]\ k\_b[2]\ k\_w[2] - 
      3\ p[j]\ \[Delta]p[k]\ \[Delta]p[\(i\^*\)]\ \[Delta]p[\(j\^*\)]\ 
        \[Delta]p[\(k\^*\)]\ k\_b[2]\ k\_w[2] + 
      3\ p[i]\ p[j]\ \[Delta]p[k]\ \[Delta]p[\(i\^*\)]\ \[Delta]p[\(j\^*\)]\ 
        \[Delta]p[\(k\^*\)]\ k\_b[2]\ k\_w[2] + 
      3\ p[\(k\^*\)]\ \[Delta]p[i]\ \[Delta]p[j]\ \[Delta]p[k]\ 
        \[Delta]p[\(i\^*\)]\ \[Delta]p[\(j\^*\)]\ k\_b[3]\ k\_w[2] - 
      3\ \[Delta]p[i]\ \[Delta]p[j]\ \[Delta]p[k]\ \[Delta]p[\(i\^*\)]\ 
        \[Delta]p[\(k\^*\)]\ k\_b[3]\ k\_w[2] + 
      3\ p[\(j\^*\)]\ \[Delta]p[i]\ \[Delta]p[j]\ \[Delta]p[k]\ 
        \[Delta]p[\(i\^*\)]\ \[Delta]p[\(k\^*\)]\ k\_b[3]\ k\_w[2] - 
      3\ \[Delta]p[i]\ \[Delta]p[j]\ \[Delta]p[k]\ \[Delta]p[\(j\^*\)]\ 
        \[Delta]p[\(k\^*\)]\ k\_b[3]\ k\_w[2] + 
      3\ p[\(i\^*\)]\ \[Delta]p[i]\ \[Delta]p[j]\ \[Delta]p[k]\ 
        \[Delta]p[\(j\^*\)]\ \[Delta]p[\(k\^*\)]\ k\_b[3]\ k\_w[2] - 
      3\ \[Delta]p[i]\ \[Delta]p[j]\ \[Delta]p[\(i\^*\)]\ 
        \[Delta]p[\(j\^*\)]\ \[Delta]p[\(k\^*\)]\ k\_b[3]\ k\_w[2] + 
      3\ p[k]\ \[Delta]p[i]\ \[Delta]p[j]\ \[Delta]p[\(i\^*\)]\ 
        \[Delta]p[\(j\^*\)]\ \[Delta]p[\(k\^*\)]\ k\_b[3]\ k\_w[2] + 
      3\ p[j]\ \[Delta]p[i]\ \[Delta]p[k]\ \[Delta]p[\(i\^*\)]\ 
        \[Delta]p[\(j\^*\)]\ \[Delta]p[\(k\^*\)]\ k\_b[3]\ k\_w[2] - 
      3\ \[Delta]p[j]\ \[Delta]p[k]\ \[Delta]p[\(i\^*\)]\ 
        \[Delta]p[\(j\^*\)]\ \[Delta]p[\(k\^*\)]\ k\_b[3]\ k\_w[2] + 
      3\ p[i]\ \[Delta]p[j]\ \[Delta]p[k]\ \[Delta]p[\(i\^*\)]\ 
        \[Delta]p[\(j\^*\)]\ \[Delta]p[\(k\^*\)]\ k\_b[3]\ k\_w[2] + 
      6\ \[Delta]p[i]\ \[Delta]p[j]\ \[Delta]p[k]\ \[Delta]p[\(i\^*\)]\ 
        \[Delta]p[\(j\^*\)]\ \[Delta]p[\(k\^*\)]\ k\_b[4]\ k\_w[2] - 
      p[\(k\^*\)]\ \[Delta]p[i]\ \[Delta]p[j]\ \[Delta]p[\(i\^*\)]\ 
        \[Delta]p[\(j\^*\)]\ k\_w[2]\^2 + 
      p[k]\ p[\(k\^*\)]\ \[Delta]p[i]\ \[Delta]p[j]\ \[Delta]p[\(i\^*\)]\ 
        \[Delta]p[\(j\^*\)]\ k\_w[2]\^2 + 
      p[j]\ p[\(k\^*\)]\ \[Delta]p[i]\ \[Delta]p[k]\ \[Delta]p[\(i\^*\)]\ 
        \[Delta]p[\(j\^*\)]\ k\_w[2]\^2 - 
      p[\(k\^*\)]\ \[Delta]p[j]\ \[Delta]p[k]\ \[Delta]p[\(i\^*\)]\ 
        \[Delta]p[\(j\^*\)]\ k\_w[2]\^2 + 
      p[i]\ p[\(k\^*\)]\ \[Delta]p[j]\ \[Delta]p[k]\ \[Delta]p[\(i\^*\)]\ 
        \[Delta]p[\(j\^*\)]\ k\_w[2]\^2 + 
      \[Delta]p[i]\ \[Delta]p[j]\ \[Delta]p[\(i\^*\)]\ \[Delta]p[\(k\^*\)]\ 
        k\_w[2]\^2 - 
      p[k]\ \[Delta]p[i]\ \[Delta]p[j]\ \[Delta]p[\(i\^*\)]\ 
        \[Delta]p[\(k\^*\)]\ k\_w[2]\^2 - 
      p[\(j\^*\)]\ \[Delta]p[i]\ \[Delta]p[j]\ \[Delta]p[\(i\^*\)]\ 
        \[Delta]p[\(k\^*\)]\ k\_w[2]\^2 + 
      p[k]\ p[\(j\^*\)]\ \[Delta]p[i]\ \[Delta]p[j]\ \[Delta]p[\(i\^*\)]\ 
        \[Delta]p[\(k\^*\)]\ k\_w[2]\^2 - 
      p[j]\ \[Delta]p[i]\ \[Delta]p[k]\ \[Delta]p[\(i\^*\)]\ 
        \[Delta]p[\(k\^*\)]\ k\_w[2]\^2 + 
      p[j]\ p[\(j\^*\)]\ \[Delta]p[i]\ \[Delta]p[k]\ \[Delta]p[\(i\^*\)]\ 
        \[Delta]p[\(k\^*\)]\ k\_w[2]\^2 + 
      \[Delta]p[j]\ \[Delta]p[k]\ \[Delta]p[\(i\^*\)]\ \[Delta]p[\(k\^*\)]\ 
        k\_w[2]\^2 - 
      p[i]\ \[Delta]p[j]\ \[Delta]p[k]\ \[Delta]p[\(i\^*\)]\ 
        \[Delta]p[\(k\^*\)]\ k\_w[2]\^2 - 
      p[\(j\^*\)]\ \[Delta]p[j]\ \[Delta]p[k]\ \[Delta]p[\(i\^*\)]\ 
        \[Delta]p[\(k\^*\)]\ k\_w[2]\^2 + 
      p[i]\ p[\(j\^*\)]\ \[Delta]p[j]\ \[Delta]p[k]\ \[Delta]p[\(i\^*\)]\ 
        \[Delta]p[\(k\^*\)]\ k\_w[2]\^2 + 
      \[Delta]p[i]\ \[Delta]p[j]\ \[Delta]p[\(j\^*\)]\ \[Delta]p[\(k\^*\)]\ 
        k\_w[2]\^2 - 
      p[k]\ \[Delta]p[i]\ \[Delta]p[j]\ \[Delta]p[\(j\^*\)]\ 
        \[Delta]p[\(k\^*\)]\ k\_w[2]\^2 - 
      p[\(i\^*\)]\ \[Delta]p[i]\ \[Delta]p[j]\ \[Delta]p[\(j\^*\)]\ 
        \[Delta]p[\(k\^*\)]\ k\_w[2]\^2 + 
      p[k]\ p[\(i\^*\)]\ \[Delta]p[i]\ \[Delta]p[j]\ \[Delta]p[\(j\^*\)]\ 
        \[Delta]p[\(k\^*\)]\ k\_w[2]\^2 - 
      p[j]\ \[Delta]p[i]\ \[Delta]p[k]\ \[Delta]p[\(j\^*\)]\ 
        \[Delta]p[\(k\^*\)]\ k\_w[2]\^2 + 
      p[j]\ p[\(i\^*\)]\ \[Delta]p[i]\ \[Delta]p[k]\ \[Delta]p[\(j\^*\)]\ 
        \[Delta]p[\(k\^*\)]\ k\_w[2]\^2 + 
      \[Delta]p[j]\ \[Delta]p[k]\ \[Delta]p[\(j\^*\)]\ \[Delta]p[\(k\^*\)]\ 
        k\_w[2]\^2 - 
      p[i]\ \[Delta]p[j]\ \[Delta]p[k]\ \[Delta]p[\(j\^*\)]\ 
        \[Delta]p[\(k\^*\)]\ k\_w[2]\^2 - 
      p[\(i\^*\)]\ \[Delta]p[j]\ \[Delta]p[k]\ \[Delta]p[\(j\^*\)]\ 
        \[Delta]p[\(k\^*\)]\ k\_w[2]\^2 + 
      p[i]\ p[\(i\^*\)]\ \[Delta]p[j]\ \[Delta]p[k]\ \[Delta]p[\(j\^*\)]\ 
        \[Delta]p[\(k\^*\)]\ k\_w[2]\^2 + 
      9\ \[Delta]p[i]\ \[Delta]p[j]\ \[Delta]p[k]\ \[Delta]p[\(i\^*\)]\ 
        \[Delta]p[\(j\^*\)]\ \[Delta]p[\(k\^*\)]\ k\_b[2]\ k\_w[2]\^2 + 
      p[\(k\^*\)]\ \[Delta]p[i]\ \[Delta]p[j]\ \[Delta]p[k]\ k\_w[3] - 
      p[\(i\^*\)]\ p[\(k\^*\)]\ \[Delta]p[i]\ \[Delta]p[j]\ \[Delta]p[k]\ 
        k\_w[3] - 
      p[\(j\^*\)]\ p[\(k\^*\)]\ \[Delta]p[i]\ \[Delta]p[j]\ \[Delta]p[k]\ 
        k\_w[3] + 
      p[\(i\^*\)]\ p[\(j\^*\)]\ p[\(k\^*\)]\ \[Delta]p[i]\ \[Delta]p[j]\ 
        \[Delta]p[k]\ k\_w[3] + 
      p[j]\ \[Delta]p[\(i\^*\)]\ \[Delta]p[\(j\^*\)]\ \[Delta]p[\(k\^*\)]\ 
        k\_w[3] - 
      p[i]\ p[j]\ \[Delta]p[\(i\^*\)]\ \[Delta]p[\(j\^*\)]\ 
        \[Delta]p[\(k\^*\)]\ k\_w[3] - 
      p[j]\ p[k]\ \[Delta]p[\(i\^*\)]\ \[Delta]p[\(j\^*\)]\ 
        \[Delta]p[\(k\^*\)]\ k\_w[3] + 
      p[i]\ p[j]\ p[k]\ \[Delta]p[\(i\^*\)]\ \[Delta]p[\(j\^*\)]\ 
        \[Delta]p[\(k\^*\)]\ k\_w[3] + 
      p[\(k\^*\)]\ \[Delta]p[i]\ \[Delta]p[j]\ \[Delta]p[k]\ 
        \[Delta]p[\(i\^*\)]\ \[Delta]p[\(j\^*\)]\ k\_w[2]\ k\_w[3] - 
      \[Delta]p[i]\ \[Delta]p[j]\ \[Delta]p[k]\ \[Delta]p[\(i\^*\)]\ 
        \[Delta]p[\(k\^*\)]\ k\_w[2]\ k\_w[3] + 
      p[\(j\^*\)]\ \[Delta]p[i]\ \[Delta]p[j]\ \[Delta]p[k]\ 
        \[Delta]p[\(i\^*\)]\ \[Delta]p[\(k\^*\)]\ k\_w[2]\ k\_w[3] - 
      \[Delta]p[i]\ \[Delta]p[j]\ \[Delta]p[k]\ \[Delta]p[\(j\^*\)]\ 
        \[Delta]p[\(k\^*\)]\ k\_w[2]\ k\_w[3] + 
      p[\(i\^*\)]\ \[Delta]p[i]\ \[Delta]p[j]\ \[Delta]p[k]\ 
        \[Delta]p[\(j\^*\)]\ \[Delta]p[\(k\^*\)]\ k\_w[2]\ k\_w[3] - 
      \[Delta]p[i]\ \[Delta]p[j]\ \[Delta]p[\(i\^*\)]\ \[Delta]p[\(j\^*\)]\ 
        \[Delta]p[\(k\^*\)]\ k\_w[2]\ k\_w[3] + 
      p[k]\ \[Delta]p[i]\ \[Delta]p[j]\ \[Delta]p[\(i\^*\)]\ 
        \[Delta]p[\(j\^*\)]\ \[Delta]p[\(k\^*\)]\ k\_w[2]\ k\_w[3] + 
      p[j]\ \[Delta]p[i]\ \[Delta]p[k]\ \[Delta]p[\(i\^*\)]\ 
        \[Delta]p[\(j\^*\)]\ \[Delta]p[\(k\^*\)]\ k\_w[2]\ k\_w[3] - 
      \[Delta]p[j]\ \[Delta]p[k]\ \[Delta]p[\(i\^*\)]\ \[Delta]p[\(j\^*\)]\ 
        \[Delta]p[\(k\^*\)]\ k\_w[2]\ k\_w[3] + 
      p[i]\ \[Delta]p[j]\ \[Delta]p[k]\ \[Delta]p[\(i\^*\)]\ 
        \[Delta]p[\(j\^*\)]\ \[Delta]p[\(k\^*\)]\ k\_w[2]\ k\_w[3] + 
      \[Delta]p[i]\ \[Delta]p[j]\ \[Delta]p[k]\ \[Delta]p[\(i\^*\)]\ 
        \[Delta]p[\(j\^*\)]\ \[Delta]p[\(k\^*\)]\ k\_w[3]\^2\)], "Output",
  CellLabel->"Out[94]="]
}, Closed]],

Cell[TextData[
"This is a slightly simpler version which assumes that the loci are \
diagnostic (\[Delta]p=1) and that allele frequencies are the same across the \
male & female gamete pools:"], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(gf /. {\[Delta]p[_] -> 1, p[\(i_\^*\)] :> p[i]}\)], "Input",
  CellLabel->"In[96]:="],

Cell[BoxData[
    \(p[j]\ p[k] - 2\ p[i]\ p[j]\ p[k] + p[i]\^2\ p[j]\ p[k] - 
      p[j]\^2\ p[k] + 2\ p[i]\ p[j]\^2\ p[k] - p[i]\^2\ p[j]\^2\ p[k] - 
      p[j]\ p[k]\^2 + 2\ p[i]\ p[j]\ p[k]\^2 - p[i]\^2\ p[j]\ p[k]\^2 + 
      p[j]\^2\ p[k]\^2 - 2\ p[i]\ p[j]\^2\ p[k]\^2 + 
      p[i]\^2\ p[j]\^2\ p[k]\^2 + k\_b[2] - 2\ p[i]\ k\_b[2] + 
      p[i]\^2\ k\_b[2] - 3\ p[j]\ k\_b[2] + 5\ p[i]\ p[j]\ k\_b[2] - 
      2\ p[i]\^2\ p[j]\ k\_b[2] + 2\ p[j]\^2\ k\_b[2] - 
      3\ p[i]\ p[j]\^2\ k\_b[2] + p[i]\^2\ p[j]\^2\ k\_b[2] - 
      3\ p[k]\ k\_b[2] + 5\ p[i]\ p[k]\ k\_b[2] - 2\ p[i]\^2\ p[k]\ k\_b[2] + 
      7\ p[j]\ p[k]\ k\_b[2] - 8\ p[i]\ p[j]\ p[k]\ k\_b[2] + 
      2\ p[i]\^2\ p[j]\ p[k]\ k\_b[2] - 3\ p[j]\^2\ p[k]\ k\_b[2] + 
      2\ p[i]\ p[j]\^2\ p[k]\ k\_b[2] + 2\ p[k]\^2\ k\_b[2] - 
      3\ p[i]\ p[k]\^2\ k\_b[2] + p[i]\^2\ p[k]\^2\ k\_b[2] - 
      3\ p[j]\ p[k]\^2\ k\_b[2] + 2\ p[i]\ p[j]\ p[k]\^2\ k\_b[2] + 
      p[j]\^2\ p[k]\^2\ k\_b[2] + 8\ k\_b[2]\^2 - 8\ p[i]\ k\_b[2]\^2 + 
      2\ p[i]\^2\ k\_b[2]\^2 - 8\ p[j]\ k\_b[2]\^2 + 
      4\ p[i]\ p[j]\ k\_b[2]\^2 + 2\ p[j]\^2\ k\_b[2]\^2 - 
      8\ p[k]\ k\_b[2]\^2 + 4\ p[i]\ p[k]\ k\_b[2]\^2 + 
      4\ p[j]\ p[k]\ k\_b[2]\^2 + 2\ p[k]\^2\ k\_b[2]\^2 + 6\ k\_b[2]\^3 - 
      4\ k\_b[3] + 6\ p[i]\ k\_b[3] - 2\ p[i]\^2\ k\_b[3] + 
      8\ p[j]\ k\_b[3] - 9\ p[i]\ p[j]\ k\_b[3] + 2\ p[i]\^2\ p[j]\ k\_b[3] - 
      3\ p[j]\^2\ k\_b[3] + 2\ p[i]\ p[j]\^2\ k\_b[3] + 8\ p[k]\ k\_b[3] - 
      9\ p[i]\ p[k]\ k\_b[3] + 2\ p[i]\^2\ p[k]\ k\_b[3] - 
      10\ p[j]\ p[k]\ k\_b[3] + 6\ p[i]\ p[j]\ p[k]\ k\_b[3] + 
      2\ p[j]\^2\ p[k]\ k\_b[3] - 3\ p[k]\^2\ k\_b[3] + 
      2\ p[i]\ p[k]\^2\ k\_b[3] + 2\ p[j]\ p[k]\^2\ k\_b[3] - 
      24\ k\_b[2]\ k\_b[3] + 12\ p[i]\ k\_b[2]\ k\_b[3] + 
      12\ p[j]\ k\_b[2]\ k\_b[3] + 12\ p[k]\ k\_b[2]\ k\_b[3] + 
      9\ k\_b[3]\^2 + 6\ k\_b[4] - 6\ p[i]\ k\_b[4] + p[i]\^2\ k\_b[4] - 
      7\ p[j]\ k\_b[4] + 4\ p[i]\ p[j]\ k\_b[4] + p[j]\^2\ k\_b[4] - 
      7\ p[k]\ k\_b[4] + 4\ p[i]\ p[k]\ k\_b[4] + 4\ p[j]\ p[k]\ k\_b[4] + 
      p[k]\^2\ k\_b[4] + 9\ k\_b[2]\ k\_b[4] - 4\ k\_b[5] + 
      2\ p[i]\ k\_b[5] + 2\ p[j]\ k\_b[5] + 2\ p[k]\ k\_b[5] + k\_b[6] - 
      2\ p[j]\ k\_w[2] + 3\ p[i]\ p[j]\ k\_w[2] - p[i]\^2\ p[j]\ k\_w[2] + 
      p[j]\^2\ k\_w[2] - p[i]\ p[j]\^2\ k\_w[2] - 2\ p[k]\ k\_w[2] + 
      3\ p[i]\ p[k]\ k\_w[2] - p[i]\^2\ p[k]\ k\_w[2] + 
      6\ p[j]\ p[k]\ k\_w[2] - 8\ p[i]\ p[j]\ p[k]\ k\_w[2] + 
      2\ p[i]\^2\ p[j]\ p[k]\ k\_w[2] - 2\ p[j]\^2\ p[k]\ k\_w[2] + 
      2\ p[i]\ p[j]\^2\ p[k]\ k\_w[2] + p[k]\^2\ k\_w[2] - 
      p[i]\ p[k]\^2\ k\_w[2] - 2\ p[j]\ p[k]\^2\ k\_w[2] + 
      2\ p[i]\ p[j]\ p[k]\^2\ k\_w[2] + 6\ k\_b[2]\ k\_w[2] - 
      6\ p[i]\ k\_b[2]\ k\_w[2] - 9\ p[j]\ k\_b[2]\ k\_w[2] + 
      6\ p[i]\ p[j]\ k\_b[2]\ k\_w[2] - 9\ p[k]\ k\_b[2]\ k\_w[2] + 
      6\ p[i]\ p[k]\ k\_b[2]\ k\_w[2] + 6\ p[j]\ p[k]\ k\_b[2]\ k\_w[2] - 
      12\ k\_b[3]\ k\_w[2] + 6\ p[i]\ k\_b[3]\ k\_w[2] + 
      6\ p[j]\ k\_b[3]\ k\_w[2] + 6\ p[k]\ k\_b[3]\ k\_w[2] + 
      6\ k\_b[4]\ k\_w[2] + 4\ k\_w[2]\^2 - 4\ p[i]\ k\_w[2]\^2 + 
      p[i]\^2\ k\_w[2]\^2 - 4\ p[j]\ k\_w[2]\^2 + 2\ p[i]\ p[j]\ k\_w[2]\^2 + 
      p[j]\^2\ k\_w[2]\^2 - 4\ p[k]\ k\_w[2]\^2 + 2\ p[i]\ p[k]\ k\_w[2]\^2 + 
      2\ p[j]\ p[k]\ k\_w[2]\^2 + p[k]\^2\ k\_w[2]\^2 + 
      9\ k\_b[2]\ k\_w[2]\^2 + p[j]\ k\_w[3] - p[i]\ p[j]\ k\_w[3] + 
      p[k]\ k\_w[3] - p[i]\ p[k]\ k\_w[3] - 2\ p[j]\ p[k]\ k\_w[3] + 
      2\ p[i]\ p[j]\ p[k]\ k\_w[3] - 4\ k\_w[2]\ k\_w[3] + 
      2\ p[i]\ k\_w[2]\ k\_w[3] + 2\ p[j]\ k\_w[2]\ k\_w[3] + 
      2\ p[k]\ k\_w[2]\ k\_w[3] + k\_w[3]\^2\)], "Output",
  CellLabel->"Out[96]="]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["\<\
Fast calculation of full diploid genotype frequencies from reduced \
cumulants: FullGenotypeFrequencyTable[]\
\>", "SubsubsectionIcon"],

Cell[TextData[Cell[BoxData[
    FormBox[GridBox[{
          {\(FullGenotypeFrequencyTable[{{0, 1, 0}, {1, 0, 1}}, {k\_w, \ 
                k\_b}, \[Delta]p, p, {i, j, k}]\), 
            RowBox[{" ", 
              
              RowBox[{\(gives\ the\ diploid\ genotype\ frequency\ in\ terms\ \
of\ cumulants\ k\_w[2] .. \), ",", " ", 
                
                RowBox[{\(k\_b[2] . \ \ Assumes\), " ", "symmetry", " ", 
                  "across", " ", "the", " ", "sexes", " ", 
                  RowBox[{
                    
                    FormBox[\((i . e . \ p[\(i\^*\)] = 
                          p[i], \ \[Delta]p[\(i\^*\)] = \[Delta]p[i])\),
                      "TraditionalForm"], ":"}]}]}]}]}
          }], TraditionalForm]]]], "DefinitionBox",
  CellTags->"FullGenotypeFrequencyTable"],

Cell[TextData[
"This method works by storing the general expression \n  for \
{{1,1,1},{1,1,1}} in terms of dummy variables $p, $\[Delta]p, and then \
permuting it to give other genotype frequencies.  "], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(Timing[
      gft = FullGenotypeFrequencyTable[{{0, 1, 0}, {1, 0, 1}}, {k\_w, \ 
            k\_b}, \[Delta]p, \ p, {i, j, k}]; ]\)], "Input",
  CellLabel->"In[111]:="],

Cell[BoxData[
    \({1.70000000000072759`\ Second, Null}\)], "Output",
  CellLabel->"Out[111]="]
}, Open  ]],

Cell["\<\
Once the standard expression has been stored, subsequent \
calculations are fast:\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(Timing[
      gft = FullGenotypeFrequencyTable[{{1, 0, 0}, {0, 1, 1}}, {k\_w, \ 
            k\_b}, \[Delta]p, \ p, {i, j, k}]; ]\)], "Input",
  CellLabel->"In[123]:="],

Cell[BoxData[
    \({0.0499999999992724042`\ Second, Null}\)], "Output",
  CellLabel->"Out[123]="]
}, Open  ]],

Cell[TextData[{
  "FullGenotypeFrequencyTable[] is equivalent to \
FullGenotypeFrequencyReduced[], but much faster. It assumes symmetry across \
the sexes ",
  Cell[BoxData[
      \(TraditionalForm
      \`\((i . e . \ p[\(i\^*\)] = p[i], \ \[Delta]p[\(i\^*\)] = \[Delta]p[i])
        \)\)]],
  ":"
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(Timing[
      gfr = FullGenotypeFrequencyReduced[{{0, 1, 0}, {1, 0, 1}}, {k\_w, \ 
            k\_b}, \[Delta]p, \ p, {i, j, k}]; ]\)], "Input",
  CellLabel->"In[112]:="],

Cell[BoxData[
    \({27.2000000000007258`\ Second, Null}\)], "Output",
  CellLabel->"Out[112]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(\((gft - gfr)\) /. {p[\(i_\^*\)] :> p[i], 
          \[Delta]p[\(j_\^*\)] :> \[Delta]p[j]} // Expand\)], "Input",
  CellLabel->"In[122]:="],

Cell[BoxData[
    \(0\)], "Output",
  CellLabel->"Out[122]="]
}, Open  ]],

Cell[TextData[Cell[BoxData[
    FormBox[GridBox[{
          {
            \(FullGenotypeFrequencyTable[{{0, 1, 0}, {1, 0, 1}}, {k\_w, \ 
                k\_b}, \[Delta]p, p]\), 
            RowBox[{
            \(uses\ compiled\ code; \ 
              must\ have\ numerical\ values\ for\ the\ k\_w\), ",", " ", 
              \(k\_b\), ",", " ", 
              RowBox[{"and", " ", 
                StyleBox["functions",
                  FontSlant->"Italic"], " ", "that", " ", "return", " ", 
                "numerical", " ", "values", " ", "for", " ", "\[Delta]p"}], 
              ",", " ", "p"}]}
          }], TraditionalForm]]]], "DefinitionBox"],

Cell[CellGroupData[{

Cell[BoxData[
    \(pp[1] = 0.2; pp[2] = 0.3; pp[3] = 0.4; \n
    Timing[gfc = 
        FullGenotypeFrequencyTable[{{0, 1, 0}, {1, 0, 1}}, {{0.01, 0.001}, {
              0.005, 0.001, 0, 0.0001, 0.0001}}, 1&, \ pp]]\)], "Input",
  CellLabel->"In[132]:="],

Cell[BoxData[
    \({0.`\ Second, 0.00735224999999999972`}\)], "Output",
  CellLabel->"Out[133]="]
}, Open  ]],

Cell[TextData["Note that p, \[Delta]p must be supplied as functions."], "Text"],

Cell["It is slower to use the symbolic expression:", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(Timing[
      FullGenotypeFrequencyTable[{{0, 1, 0}, {1, 0, 1}}, {k\_w, \ k\_b}, 1&, 
          \ pp, {1, 2, 3}] /. {k\_w[2] \[Rule] 0.01, k\_w[3] \[Rule] 0.001, 
          k\_b[2] \[Rule] 0.005, k\_b[3] \[Rule] 0.001, k\_b[4] \[Rule] 0, 
          k\_b[5] \[Rule] 0.0001, k\_b[6] \[Rule] 0.0001}]\)], "Input",
  CellLabel->"In[136]:="],

Cell[BoxData[
    \({0.0166666666664241347`\ Second, 0.00735224999999999795`}\)], "Output",
  CellLabel->"Out[136]="]
}, Open  ]],

Cell[TextData[Cell[BoxData[
    FormBox[GridBox[{
          {
            FormBox[
              RowBox[{
                RowBox[{"DiploidGenotypeFrequencyTable", "[", 
                  StyleBox["nloci",
                    FontSlant->"Italic"], "]"}], "[", \(p\_1, \[Ellipsis], 
                \(p\_1\%*\), \[Ellipsis], \[Delta]\[VeryThinSpace]p\_1, 
                \[Ellipsis], \[Delta]\[VeryThinSpace]\(p\_1\%*\), 
                \[Ellipsis], k\_w[2], \[Ellipsis], k\_b[2] \[Ellipsis]\), 
                "]"}],
              "TraditionalForm"], 
            \(is\ a\ compiled\ version\ for\ the\ frequency\ of
                \ {{1, 1,  ... }, {\[Ellipsis]}} which\ requires\ 7  nloci - 
              2\ numerical\ \(arguments . \)\)}
          }], TraditionalForm]]]], "DefinitionBox"],

Cell[TextData[{
  " ",
  "FullGenotypeFrequencyTable",
  "[3] is the compiled code which generates the frequncy of {{1,1,...},{\
\[Ellipsis]}}.  This is used by ",
  Cell[BoxData[
      \(DiploidGenotypeFrequencyTable[{{0, 1, 0}, {1, 0, 1}}, {k\_w, \ 
          k\_b}, \[Delta]p, p]\)],
    FontFamily->"Times",
    CellTags->"DiploidGenotypeFrequencyTable"],
  ":"
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{" ", 
      RowBox[{
        FormBox[\(FullGenotypeFrequencyTable[3]\),
          "TraditionalForm"], "[", \(0.2, 0.3, 0.4, 0.2, 0.3, 0.4, 1, 1, 1, 
        1, 1, 1, 0.01, 0.001, 0.005, 0.001, 0, 0.0001, 0.0001\), "]"}]}]], 
  "Input",
  CellLabel->"In[126]:="],

Cell[BoxData[
    \(0.00248274999999999801`\)], "Output",
  CellLabel->"Out[126]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(FullGenotypeFrequencyTable[{{1, 1, 1}, {1, 1, 1}}, {k\_w, \ k\_b}, 
          \[Delta]p, \ p, {i, j, k}] /. {p[\(i_\^*\)] :> p[i], 
          \[Delta]p[\(j_\^*\)] :> \[Delta]p[j]}\) /. {p[i] \[Rule] 0.2, 
        p[j] \[Rule] 0.3, p[k] \[Rule] 0.4, \[Delta]p[_] \[Rule] 1, 
        k\_w[2] \[Rule] 0.01, k\_w[3] \[Rule] 0.001, k\_b[2] \[Rule] 0.005, 
        k\_b[3] \[Rule] 0.001, k\_b[4] \[Rule] 0, k\_b[5] \[Rule] 0.0001, 
        k\_b[6] \[Rule] 0.0001}\)], "Input",
  CellLabel->"In[127]:="],

Cell[BoxData[
    \(0.00248275000000000067`\)], "Output",
  CellLabel->"Out[127]="]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["\<\
Fast calculation of observed diploid genotype frequencies from \
reduced cumulants: DiploidGenotypeFrequencyTable[]\
\>", "SubsubsectionIcon"],

Cell[TextData[Cell[BoxData[
    FormBox[GridBox[{
          {
            RowBox[{
              RowBox[{
                
                FormBox[
                  \(DiploidGenotypeFrequencyTable[{0, 2, 0}, {k\_w, \ k\_b}
                      \),
                  "TraditionalForm"], ",", "\[Delta]p", ",", "p", ",", "S"}], 
              "]"}], \(gives\ the\ diploid\ genotype\ frequency\ in\ terms\ of
              \ the\ reduced\ set\ of\ cumulants\ k\_w[2] \[Ellipsis], 
            k\_b[2] \[Ellipsis]\)},
          {
            RowBox[{
              RowBox[{
                
                FormBox[
                  \(DiploidGenotypeFrequencyTable[{0, 2, 0}, {k\_w, \ k\_b}
                      \),
                  "TraditionalForm"], ",", "\[Delta]p", ",", "p"}], "]"}], 
            \(is\ a\ compiled\ \(version . \)\)}
          }], TraditionalForm]]]], "DefinitionBox"],

Cell[TextData[{
  "This is the double heterozygote frequency, assuming \[Delta]p=1 at both \
loci ",
  Cell[BoxData[
      \(TraditionalForm\`i\)]],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`j\)]],
  ":"
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(DiploidGenotypeFrequencyTable[{1, 1}, {k\_w, k\_b}, 1&, p, {i, j}]\)], 
  "Input",
  CellLabel->"In[179]:="],

Cell[BoxData[
    \(4\ \((1 - p[i])\)\ p[i]\ \((1 - p[j])\)\ p[j] - 
      4\ \((1 - p[i])\)\ p[i]\ k\_b[2] + 
      2\ \((1 - p[i])\)\ \((1 - p[j])\)\ k\_b[2] - 
      2\ p[i]\ \((1 - p[j])\)\ k\_b[2] - 2\ \((1 - p[i])\)\ p[j]\ k\_b[2] + 
      2\ p[i]\ p[j]\ k\_b[2] - 4\ \((1 - p[j])\)\ p[j]\ k\_b[2] + 
      8\ k\_b[2]\^2 - 4\ \((1 - p[i])\)\ k\_b[3] + 4\ p[i]\ k\_b[3] - 
      4\ \((1 - p[j])\)\ k\_b[3] + 4\ p[j]\ k\_b[3] + 4\ k\_b[4] + 
      2\ \((1 - p[i])\)\ \((1 - p[j])\)\ k\_w[2] - 
      2\ p[i]\ \((1 - p[j])\)\ k\_w[2] - 2\ \((1 - p[i])\)\ p[j]\ k\_w[2] + 
      2\ p[i]\ p[j]\ k\_w[2] + 4\ k\_w[2]\^2\)], "Output",
  CellLabel->"Out[179]="]
}, Open  ]],

Cell["This is a compiled version:", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(pp[1] = 0.2; pp[2] = 0.3; pp[3] = 0.4; \n
    DiploidGenotypeFrequencyTable[{1, 1, 
        2}, {{0.01, 0.001}, {0.005, 0.001, 0, 0.0001, 0.0001}}, 1&, pp]\)], 
  "Input",
  CellLabel->"In[181]:="],

Cell[BoxData[
    \(0.0262710000000000132`\)], "Output",
  CellLabel->"Out[182]="]
}, Open  ]],

Cell[TextData[{
  "The cumulants are given as lists of numerical values; ",
  Cell[BoxData[
      \(TraditionalForm\`\(\ \[Delta]\[VeryThinSpace]p\)\)]],
  ", ",
  Cell[BoxData[
      \(TraditionalForm\`p\)]],
  " are given as numerical functions."
}], "Text"],

Cell[TextData[Cell[BoxData[
    FormBox[GridBox[{
          {
            \(\(DiploidGenotypeFrequencyTable[{0, 2, 0}, \[Delta]p]\)[
              p[1] \[Ellipsis]k\_w[2] \[Ellipsis]k\_b[2] \[Ellipsis]]\), 
            \(is\ fully\ \(compiled . \)\)},
          {
            RowBox[{
              RowBox[{"DiploidGenotypeFrequencyTable", "[", 
                RowBox[{
                  StyleBox["nloci",
                    FontSlant->"Italic"], ",", "\[Delta]p"}], "]"}], "[", 
              \(p[1] \[Ellipsis]k\_w[2] \[Ellipsis]k\_b[2] \[Ellipsis]\), 
              "]"}], \(is\ fully\ compiled, \ 
            and\ returns\ the\ complete\ vector\ of\ genotype\ 
              \(frequencies . \)\)}
          }], TraditionalForm]]]], "DefinitionBox"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(DiploidGenotypeFrequencyTable[{1, 1, 2}, 1&]\)[0.2, 0.3, 0.4, 0.01, 
      0.001, 0.005, 0.001, 0, 0.0001, 0.0001]\)], "Input",
  CellLabel->"In[183]:="],

Cell[BoxData[
    \(0.0262709999999999999`\)], "Output",
  CellLabel->"Out[183]="]
}, Open  ]],

Cell["This is the complete set of genotype frequencies:", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(DiploidGenotypeFrequencyTable[3, 1&]\)[0.2, 0.3, 0.4, 0.01, 0.001, 
      0.005, 0.001, 0, 0.0001, 0.0001]\)], "Input",
  CellLabel->"In[190]:="],

Cell[BoxData[
    \({0.131362750000000039`, 0.156134500000000038`, 0.045702750000000023`, 
      0.0981045000000000122`, 0.120270999999999994`, 0.0402245000000000096`, 
      0.0176827500000000021`, 0.0252945000000000019`, 0.0102227500000000048`, 
      0.0543144999999999988`, 0.0669510000000000005`, 0.0233345000000000091`, 
      0.0419110000000000049`, 0.0626179999999999914`, 0.0262709999999999999`, 
      0.00947450000000000258`, 0.017031000000000005`, 
      0.00809450000000000358`, 0.00512274999999999991`, 
      0.00831450000000000244`, 0.00376275000000000092`, 
      0.00538450000000000095`, 0.0103110000000000012`, 
      0.00490450000000000052`, 0.00164274999999999993`, 
      0.00307450000000000045`, 0.00248275000000000023`}\)], "Output",
  CellLabel->"Out[190]="]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["Functions used internally: GenotypeFrequencyArguments[]", 
  "SubsubsectionIcon"],

Cell[TextData[Cell[BoxData[
    FormBox[GridBox[{
          {
            \(\(GenotypeFrequencyArguments[nloci]\)[p1,  .. , q1,  .. , 
              cw[2], \( ..  cb[2]\) .. ]\), 
            \(lists\ all\ the\ arguments\ that\ must\ be\ supplied\ to\ 
              \(GenotypeFrequencyTable[nloci, 1&]\)[]\ to\ give\ the\ genotype
              \ \(frequencies . \)\)}
          }], TraditionalForm]]]], "DefinitionBox"],

Cell[TextData[{
  "This lists the array of permuted arguments that must be supplied to \
GenotypeFrequencyTable[nloci,1&] to generate the array of ",
  Cell[BoxData[
      \(TraditionalForm\`2\^6\)]],
  "genotype frequencies with n=3 loci:"
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{" ", 
      RowBox[{
        RowBox[{
          FormBox["GenotypeFrequencyArguments",
            "TraditionalForm"], "[", "3", "]"}], "[", \(0.2, 0.3, 0.4, 0.8, 
        0.7, 0.6, 0, 0, 0, 0, 0, 0, 0\), "]"}]}]], "Input",
  CellLabel->"In[2]:=",
  CellTags->"GenotypeFrequencyArguments"],

Cell[BoxData[
    \({{0.8`, 0.7`, 0.6`, 0.8`, 0.7`, 0.6`, \(-1.`\), \(-1.`\), \(-1.`\), 
        \(-1.`\), \(-1.`\), \(-1.`\), 0.`, 0.`, 0.`, 0.`, 0.`, 0.`, 0.`}, {
        0.8`, 0.7`, 0.6`, 0.8`, 0.7`, 0.4`, \(-1.`\), \(-1.`\), \(-1.`\), 
        \(-1.`\), \(-1.`\), 1.`, 0.`, 0.`, 0.`, 0.`, 0.`, 0.`, 0.`}, {0.8`, 
        0.7`, 0.6`, 0.8`, 0.3`, 0.6`, \(-1.`\), \(-1.`\), \(-1.`\), \(-1.`\), 
        1.`, \(-1.`\), 0.`, 0.`, 0.`, 0.`, 0.`, 0.`, 0.`}, {0.8`, 0.7`, 0.6`, 
        0.8`, 0.3`, 0.4`, \(-1.`\), \(-1.`\), \(-1.`\), \(-1.`\), 1.`, 1.`, 
        0.`, 0.`, 0.`, 0.`, 0.`, 0.`, 0.`}, {0.8`, 0.7`, 0.6`, 0.2`, 0.7`, 
        0.6`, \(-1.`\), \(-1.`\), \(-1.`\), 1.`, \(-1.`\), \(-1.`\), 0.`, 
        0.`, 0.`, 0.`, 0.`, 0.`, 0.`}, {0.8`, 0.7`, 0.6`, 0.2`, 0.7`, 0.4`, 
        \(-1.`\), \(-1.`\), \(-1.`\), 1.`, \(-1.`\), 1.`, 0.`, 0.`, 0.`, 0.`, 
        0.`, 0.`, 0.`}, {0.8`, 0.7`, 0.6`, 0.2`, 0.3`, 0.6`, \(-1.`\), 
        \(-1.`\), \(-1.`\), 1.`, 1.`, \(-1.`\), 0.`, 0.`, 0.`, 0.`, 0.`, 0.`, 
        0.`}, {0.8`, 0.7`, 0.6`, 0.2`, 0.3`, 0.4`, \(-1.`\), \(-1.`\), 
        \(-1.`\), 1.`, 1.`, 1.`, 0.`, 0.`, 0.`, 0.`, 0.`, 0.`, 0.`}, {0.8`, 
        0.7`, 0.4`, 0.8`, 0.7`, 0.6`, \(-1.`\), \(-1.`\), 1.`, \(-1.`\), 
        \(-1.`\), \(-1.`\), 0.`, 0.`, 0.`, 0.`, 0.`, 0.`, 0.`}, {0.8`, 0.7`, 
        0.4`, 0.8`, 0.7`, 0.4`, \(-1.`\), \(-1.`\), 1.`, \(-1.`\), \(-1.`\), 
        1.`, 0.`, 0.`, 0.`, 0.`, 0.`, 0.`, 0.`}, {0.8`, 0.7`, 0.4`, 0.8`, 
        0.3`, 0.6`, \(-1.`\), \(-1.`\), 1.`, \(-1.`\), 1.`, \(-1.`\), 0.`, 
        0.`, 0.`, 0.`, 0.`, 0.`, 0.`}, {0.8`, 0.7`, 0.4`, 0.8`, 0.3`, 0.4`, 
        \(-1.`\), \(-1.`\), 1.`, \(-1.`\), 1.`, 1.`, 0.`, 0.`, 0.`, 0.`, 0.`, 
        0.`, 0.`}, {0.8`, 0.7`, 0.4`, 0.2`, 0.7`, 0.6`, \(-1.`\), \(-1.`\), 
        1.`, 1.`, \(-1.`\), \(-1.`\), 0.`, 0.`, 0.`, 0.`, 0.`, 0.`, 0.`}, {
        0.8`, 0.7`, 0.4`, 0.2`, 0.7`, 0.4`, \(-1.`\), \(-1.`\), 1.`, 1.`, 
        \(-1.`\), 1.`, 0.`, 0.`, 0.`, 0.`, 0.`, 0.`, 0.`}, {0.8`, 0.7`, 0.4`, 
        0.2`, 0.3`, 0.6`, \(-1.`\), \(-1.`\), 1.`, 1.`, 1.`, \(-1.`\), 0.`, 
        0.`, 0.`, 0.`, 0.`, 0.`, 0.`}, {0.8`, 0.7`, 0.4`, 0.2`, 0.3`, 0.4`, 
        \(-1.`\), \(-1.`\), 1.`, 1.`, 1.`, 1.`, 0.`, 0.`, 0.`, 0.`, 0.`, 0.`, 
        0.`}, {0.8`, 0.3`, 0.6`, 0.8`, 0.7`, 0.6`, \(-1.`\), 1.`, \(-1.`\), 
        \(-1.`\), \(-1.`\), \(-1.`\), 0.`, 0.`, 0.`, 0.`, 0.`, 0.`, 0.`}, {
        0.8`, 0.3`, 0.6`, 0.8`, 0.7`, 0.4`, \(-1.`\), 1.`, \(-1.`\), 
        \(-1.`\), \(-1.`\), 1.`, 0.`, 0.`, 0.`, 0.`, 0.`, 0.`, 0.`}, {0.8`, 
        0.3`, 0.6`, 0.8`, 0.3`, 0.6`, \(-1.`\), 1.`, \(-1.`\), \(-1.`\), 1.`, 
        \(-1.`\), 0.`, 0.`, 0.`, 0.`, 0.`, 0.`, 0.`}, {0.8`, 0.3`, 0.6`, 
        0.8`, 0.3`, 0.4`, \(-1.`\), 1.`, \(-1.`\), \(-1.`\), 1.`, 1.`, 0.`, 
        0.`, 0.`, 0.`, 0.`, 0.`, 0.`}, {0.8`, 0.3`, 0.6`, 0.2`, 0.7`, 0.6`, 
        \(-1.`\), 1.`, \(-1.`\), 1.`, \(-1.`\), \(-1.`\), 0.`, 0.`, 0.`, 0.`, 
        0.`, 0.`, 0.`}, {0.8`, 0.3`, 0.6`, 0.2`, 0.7`, 0.4`, \(-1.`\), 1.`, 
        \(-1.`\), 1.`, \(-1.`\), 1.`, 0.`, 0.`, 0.`, 0.`, 0.`, 0.`, 0.`}, {
        0.8`, 0.3`, 0.6`, 0.2`, 0.3`, 0.6`, \(-1.`\), 1.`, \(-1.`\), 1.`, 
        1.`, \(-1.`\), 0.`, 0.`, 0.`, 0.`, 0.`, 0.`, 0.`}, {0.8`, 0.3`, 0.6`, 
        0.2`, 0.3`, 0.4`, \(-1.`\), 1.`, \(-1.`\), 1.`, 1.`, 1.`, 0.`, 0.`, 
        0.`, 0.`, 0.`, 0.`, 0.`}, {0.8`, 0.3`, 0.4`, 0.8`, 0.7`, 0.6`, 
        \(-1.`\), 1.`, 1.`, \(-1.`\), \(-1.`\), \(-1.`\), 0.`, 0.`, 0.`, 0.`, 
        0.`, 0.`, 0.`}, {0.8`, 0.3`, 0.4`, 0.8`, 0.7`, 0.4`, \(-1.`\), 1.`, 
        1.`, \(-1.`\), \(-1.`\), 1.`, 0.`, 0.`, 0.`, 0.`, 0.`, 0.`, 0.`}, {
        0.8`, 0.3`, 0.4`, 0.8`, 0.3`, 0.6`, \(-1.`\), 1.`, 1.`, \(-1.`\), 
        1.`, \(-1.`\), 0.`, 0.`, 0.`, 0.`, 0.`, 0.`, 0.`}, {0.8`, 0.3`, 0.4`, 
        0.8`, 0.3`, 0.4`, \(-1.`\), 1.`, 1.`, \(-1.`\), 1.`, 1.`, 0.`, 0.`, 
        0.`, 0.`, 0.`, 0.`, 0.`}, {0.8`, 0.3`, 0.4`, 0.2`, 0.7`, 0.6`, 
        \(-1.`\), 1.`, 1.`, 1.`, \(-1.`\), \(-1.`\), 0.`, 0.`, 0.`, 0.`, 0.`, 
        0.`, 0.`}, {0.8`, 0.3`, 0.4`, 0.2`, 0.7`, 0.4`, \(-1.`\), 1.`, 1.`, 
        1.`, \(-1.`\), 1.`, 0.`, 0.`, 0.`, 0.`, 0.`, 0.`, 0.`}, {0.8`, 0.3`, 
        0.4`, 0.2`, 0.3`, 0.6`, \(-1.`\), 1.`, 1.`, 1.`, 1.`, \(-1.`\), 0.`, 
        0.`, 0.`, 0.`, 0.`, 0.`, 0.`}, {0.8`, 0.3`, 0.4`, 0.2`, 0.3`, 0.4`, 
        \(-1.`\), 1.`, 1.`, 1.`, 1.`, 1.`, 0.`, 0.`, 0.`, 0.`, 0.`, 0.`, 
        0.`}, {0.2`, 0.7`, 0.6`, 0.8`, 0.7`, 0.6`, 1.`, \(-1.`\), \(-1.`\), 
        \(-1.`\), \(-1.`\), \(-1.`\), 0.`, 0.`, 0.`, 0.`, 0.`, 0.`, 0.`}, {
        0.2`, 0.7`, 0.6`, 0.8`, 0.7`, 0.4`, 1.`, \(-1.`\), \(-1.`\), 
        \(-1.`\), \(-1.`\), 1.`, 0.`, 0.`, 0.`, 0.`, 0.`, 0.`, 0.`}, {0.2`, 
        0.7`, 0.6`, 0.8`, 0.3`, 0.6`, 1.`, \(-1.`\), \(-1.`\), \(-1.`\), 1.`, 
        \(-1.`\), 0.`, 0.`, 0.`, 0.`, 0.`, 0.`, 0.`}, {0.2`, 0.7`, 0.6`, 
        0.8`, 0.3`, 0.4`, 1.`, \(-1.`\), \(-1.`\), \(-1.`\), 1.`, 1.`, 0.`, 
        0.`, 0.`, 0.`, 0.`, 0.`, 0.`}, {0.2`, 0.7`, 0.6`, 0.2`, 0.7`, 0.6`, 
        1.`, \(-1.`\), \(-1.`\), 1.`, \(-1.`\), \(-1.`\), 0.`, 0.`, 0.`, 0.`, 
        0.`, 0.`, 0.`}, {0.2`, 0.7`, 0.6`, 0.2`, 0.7`, 0.4`, 1.`, \(-1.`\), 
        \(-1.`\), 1.`, \(-1.`\), 1.`, 0.`, 0.`, 0.`, 0.`, 0.`, 0.`, 0.`}, {
        0.2`, 0.7`, 0.6`, 0.2`, 0.3`, 0.6`, 1.`, \(-1.`\), \(-1.`\), 1.`, 
        1.`, \(-1.`\), 0.`, 0.`, 0.`, 0.`, 0.`, 0.`, 0.`}, {0.2`, 0.7`, 0.6`, 
        0.2`, 0.3`, 0.4`, 1.`, \(-1.`\), \(-1.`\), 1.`, 1.`, 1.`, 0.`, 0.`, 
        0.`, 0.`, 0.`, 0.`, 0.`}, {0.2`, 0.7`, 0.4`, 0.8`, 0.7`, 0.6`, 1.`, 
        \(-1.`\), 1.`, \(-1.`\), \(-1.`\), \(-1.`\), 0.`, 0.`, 0.`, 0.`, 0.`, 
        0.`, 0.`}, {0.2`, 0.7`, 0.4`, 0.8`, 0.7`, 0.4`, 1.`, \(-1.`\), 1.`, 
        \(-1.`\), \(-1.`\), 1.`, 0.`, 0.`, 0.`, 0.`, 0.`, 0.`, 0.`}, {0.2`, 
        0.7`, 0.4`, 0.8`, 0.3`, 0.6`, 1.`, \(-1.`\), 1.`, \(-1.`\), 1.`, 
        \(-1.`\), 0.`, 0.`, 0.`, 0.`, 0.`, 0.`, 0.`}, {0.2`, 0.7`, 0.4`, 
        0.8`, 0.3`, 0.4`, 1.`, \(-1.`\), 1.`, \(-1.`\), 1.`, 1.`, 0.`, 0.`, 
        0.`, 0.`, 0.`, 0.`, 0.`}, {0.2`, 0.7`, 0.4`, 0.2`, 0.7`, 0.6`, 1.`, 
        \(-1.`\), 1.`, 1.`, \(-1.`\), \(-1.`\), 0.`, 0.`, 0.`, 0.`, 0.`, 0.`, 
        0.`}, {0.2`, 0.7`, 0.4`, 0.2`, 0.7`, 0.4`, 1.`, \(-1.`\), 1.`, 1.`, 
        \(-1.`\), 1.`, 0.`, 0.`, 0.`, 0.`, 0.`, 0.`, 0.`}, {0.2`, 0.7`, 0.4`, 
        0.2`, 0.3`, 0.6`, 1.`, \(-1.`\), 1.`, 1.`, 1.`, \(-1.`\), 0.`, 0.`, 
        0.`, 0.`, 0.`, 0.`, 0.`}, {0.2`, 0.7`, 0.4`, 0.2`, 0.3`, 0.4`, 1.`, 
        \(-1.`\), 1.`, 1.`, 1.`, 1.`, 0.`, 0.`, 0.`, 0.`, 0.`, 0.`, 0.`}, {
        0.2`, 0.3`, 0.6`, 0.8`, 0.7`, 0.6`, 1.`, 1.`, \(-1.`\), \(-1.`\), 
        \(-1.`\), \(-1.`\), 0.`, 0.`, 0.`, 0.`, 0.`, 0.`, 0.`}, {0.2`, 0.3`, 
        0.6`, 0.8`, 0.7`, 0.4`, 1.`, 1.`, \(-1.`\), \(-1.`\), \(-1.`\), 1.`, 
        0.`, 0.`, 0.`, 0.`, 0.`, 0.`, 0.`}, {0.2`, 0.3`, 0.6`, 0.8`, 0.3`, 
        0.6`, 1.`, 1.`, \(-1.`\), \(-1.`\), 1.`, \(-1.`\), 0.`, 0.`, 0.`, 
        0.`, 0.`, 0.`, 0.`}, {0.2`, 0.3`, 0.6`, 0.8`, 0.3`, 0.4`, 1.`, 1.`, 
        \(-1.`\), \(-1.`\), 1.`, 1.`, 0.`, 0.`, 0.`, 0.`, 0.`, 0.`, 0.`}, {
        0.2`, 0.3`, 0.6`, 0.2`, 0.7`, 0.6`, 1.`, 1.`, \(-1.`\), 1.`, 
        \(-1.`\), \(-1.`\), 0.`, 0.`, 0.`, 0.`, 0.`, 0.`, 0.`}, {0.2`, 0.3`, 
        0.6`, 0.2`, 0.7`, 0.4`, 1.`, 1.`, \(-1.`\), 1.`, \(-1.`\), 1.`, 0.`, 
        0.`, 0.`, 0.`, 0.`, 0.`, 0.`}, {0.2`, 0.3`, 0.6`, 0.2`, 0.3`, 0.6`, 
        1.`, 1.`, \(-1.`\), 1.`, 1.`, \(-1.`\), 0.`, 0.`, 0.`, 0.`, 0.`, 0.`, 
        0.`}, {0.2`, 0.3`, 0.6`, 0.2`, 0.3`, 0.4`, 1.`, 1.`, \(-1.`\), 1.`, 
        1.`, 1.`, 0.`, 0.`, 0.`, 0.`, 0.`, 0.`, 0.`}, {0.2`, 0.3`, 0.4`, 
        0.8`, 0.7`, 0.6`, 1.`, 1.`, 1.`, \(-1.`\), \(-1.`\), \(-1.`\), 0.`, 
        0.`, 0.`, 0.`, 0.`, 0.`, 0.`}, {0.2`, 0.3`, 0.4`, 0.8`, 0.7`, 0.4`, 
        1.`, 1.`, 1.`, \(-1.`\), \(-1.`\), 1.`, 0.`, 0.`, 0.`, 0.`, 0.`, 0.`, 
        0.`}, {0.2`, 0.3`, 0.4`, 0.8`, 0.3`, 0.6`, 1.`, 1.`, 1.`, \(-1.`\), 
        1.`, \(-1.`\), 0.`, 0.`, 0.`, 0.`, 0.`, 0.`, 0.`}, {0.2`, 0.3`, 0.4`, 
        0.8`, 0.3`, 0.4`, 1.`, 1.`, 1.`, \(-1.`\), 1.`, 1.`, 0.`, 0.`, 0.`, 
        0.`, 0.`, 0.`, 0.`}, {0.2`, 0.3`, 0.4`, 0.2`, 0.7`, 0.6`, 1.`, 1.`, 
        1.`, 1.`, \(-1.`\), \(-1.`\), 0.`, 0.`, 0.`, 0.`, 0.`, 0.`, 0.`}, {
        0.2`, 0.3`, 0.4`, 0.2`, 0.7`, 0.4`, 1.`, 1.`, 1.`, 1.`, \(-1.`\), 
        1.`, 0.`, 0.`, 0.`, 0.`, 0.`, 0.`, 0.`}, {0.2`, 0.3`, 0.4`, 0.2`, 
        0.3`, 0.6`, 1.`, 1.`, 1.`, 1.`, 1.`, \(-1.`\), 0.`, 0.`, 0.`, 0.`, 
        0.`, 0.`, 0.`}, {0.2`, 0.3`, 0.4`, 0.2`, 0.3`, 0.4`, 1.`, 1.`, 1.`, 
        1.`, 1.`, 1.`, 0.`, 0.`, 0.`, 0.`, 0.`, 0.`, 0.`}}\)], "Output",
  CellLabel->"Out[2]="]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["Moments & cumulants: MomentReduced[], CumulantReduced[]", \
"SubsubsectionIcon"],

Cell[TextData[Cell[BoxData[
    FormBox[GridBox[{
          {\(MomentReduced[{k\_w, 
                k\_b}, {\(\(|\)\(U\)\(|\)\), \(\(|\)\(V\)\(|\)\)}]\), \
\(returns\ an\ expression\ for\ the\ moment\ c[
                  U, \(V\^*\)]\ in\ terms\ of\ the\ cumulants\ within - \ 
              and\ between - genomes\ \(\((k\_w, k\_b)\)\(.\)\)\)},
          {\(\(MomentReduced[
                n]\)[{c\_w[2] \[Ellipsis]c\_b[
                    2] \[Ellipsis]}]\), \(is\ a\ compiled\ version\ that\ \
returns\ the\ matrix\ of\ \(\(moments\)\(.\)\)\)}
          }], TraditionalForm]]]], "DefinitionBox",
  CellTags->"MomentReduced"],

Cell[TextData[{
  "This is an expression for any moment such as ",
  Cell[BoxData[
      \(TraditionalForm\`c[{i, j, \(k\^*\), \(l\^*\)}]\)]],
  ", in terms of the reduced set of cumulants ",
  Cell[BoxData[
      \(TraditionalForm\`k\_w[i]\)]],
  ", ",
  Cell[BoxData[
      \(TraditionalForm\`k\_b[j]\)]],
  ", where ",
  Cell[BoxData[
      \(TraditionalForm\`i\)]],
  ", ",
  Cell[BoxData[
      \(TraditionalForm\`j\)]],
  " are the numbers of loci involved."
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(MomentReduced[{k\_w, k\_b}, {2, 2}]\)], "Input",
  CellLabel->"In[28]:="],

Cell[BoxData[
    \(2\ k\_b[2]\^2 + k\_b[4] + k\_w[2]\^2\)], "Output",
  CellLabel->"Out[28]="]
}, Closed]],

Cell[TextData[{
  "This compiled function gives the matrix of moments ",
  Cell[BoxData[
      \(TraditionalForm\`\(c[U, \(V\^*\)\)\)]],
  "], where |U|, |V| run from ",
  Cell[BoxData[
      \(TraditionalForm\`0  \[Ellipsis]\ n\)]],
  " ",
  Cell[BoxData[
      \(TraditionalForm\`\((n = 3)\)\)]],
  ", and the cumulants are  ",
  Cell[BoxData[
      \(TraditionalForm\`{k\_w[2], k\_w[3]}\)]],
  "={0, 0.01}, and ",
  Cell[BoxData[
      \(TraditionalForm\`{k\_b[2], k\_b[3], k\_b[4], k\_b[5], k\_b[6]}\)]],
  "={0.02, 0.001, 0, 0, 0, 0}."
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(MomentReduced[3]\)[{0, 0.01, 0.02, 0.001, 0, 0, 0}] // MatrixForm\)], 
  "Input",
  CellLabel->"In[26]:="],

Cell[BoxData[
    TagBox[
      RowBox[{"(", GridBox[{
            {"1.`", "0.`", "0.`", "0.01`"},
            {"0.`", "0.02`", "0.001`", "0.`"},
            {"0.`", "0.001`", "0.0008`", "0.000119999999999999996`"},
            {"0.01`", "0.`", "0.000119999999999999996`", 
              "0.000157000000000000028`"}
            }], ")"}],
      (MatrixForm[ #]&)]], "Output",
  CellLabel->"Out[26]//MatrixForm="]
}, Closed]],

Cell[TextData[Cell[BoxData[
    FormBox[GridBox[{
          {\(CumulantReduced[{c\_w, 
                c\_b}, {\(\(|\)\(U\)\(|\)\), \(\(|\)\(V\)\(|\)\)}]\), \
\(returns\ an\ expression\ for\ the\ cumulant\ k[
                  U, \(V\^*\)]\ in\ terms\ of\ the\ moments\ within - \ 
              and\ between - genomes\ \(\((c\_w, c\_b)\)\(.\)\)\)}
          }], TraditionalForm]]]], "DefinitionBox",
  CellTags->"CumulantReduced"],

Cell[TextData[{
  "This is an expression for any cumulant such as ",
  Cell[BoxData[
      \(TraditionalForm\`k[{i, j, \(k\^*\), \(l\^*\)}]\)]],
  ", in terms of the reduced set of moments ",
  Cell[BoxData[
      \(TraditionalForm\`c\_w[i]\)]],
  ", ",
  Cell[BoxData[
      \(TraditionalForm\`c\_b[j]\)]],
  ", where ",
  Cell[BoxData[
      \(TraditionalForm\`i\)]],
  ", ",
  Cell[BoxData[
      \(TraditionalForm\`j\)]],
  " are the numbers of loci involved."
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(CumulantReduced[{c\_w, c\_b}, {2, 2}]\)], "Input",
  CellLabel->"In[27]:="],

Cell[BoxData[
    \(\(-2\)\ c\_b[2]\^2 + c\_b[4] - c\_w[2]\^2\)], "Output",
  CellLabel->"Out[27]="]
}, Closed]],

Cell["No compiled version is implemented", "Text"],

Cell[TextData[Cell[BoxData[
    FormBox[GridBox[{
          {\(MomentReduced[U, {c\_w, c\_b}, \[Delta]p]\), 
            \(returns\ moments\ in\ terms\ of\ the\ within - \ and\ between - 
              genome\ associations\ of\ order\ \(n . \)\)}
          }], TraditionalForm]]]], "DefinitionBox"],

Cell["\<\
In an admixture model, the many moments can be approximated in \
terms of a small number of reduced moments of various orders:\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(MomentReduced[{i, j, k, l}, {cw, cb}, \[Delta]p]\)], "Input",
  CellLabel->"In[83]:="],

Cell[BoxData[
    \(cw[4]\ \[Delta]p[i]\ \[Delta]p[j]\ \[Delta]p[k]\ \[Delta]p[l]\)], 
  "Output",
  CellLabel->"Out[83]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(MomentReduced[{i, j, \(k\^*\), \(l\^*\)}, {cw, cb}, \[Delta]p]\)], 
  "Input",
  CellLabel->"In[84]:="],

Cell[BoxData[
    \(cb[4]\ \[Delta]p[i]\ \[Delta]p[j]\ \[Delta]p[k]\ \[Delta]p[l]\)], 
  "Output",
  CellLabel->"Out[84]="]
}, Open  ]],

Cell["\<\
Each moment is scaled by the magnitude of the allele frequency \
difference at each locus which drives the association.\
\>", "Text"]
}, Closed]],

Cell[CellGroupData[{

Cell["\<\
Constraints on genotype frequencies: HaploidConstraints[], \
DiploidConstraints[]\
\>", "SubsubsectionIcon"],

Cell[TextData[Cell[BoxData[
    FormBox[GridBox[{
          {\(HaploidConstraints[k, \[Delta]p, p, 
              S]\), \(stores\ a\ list\ of\ the\ constraints\ on\ genotype\ \
frequencies, \ 
            in\ terms\ of\ the\ reduced\ set\ of\ cumulants, \ \(\(k[]\)\(.\)\
\)\)}
          }], TraditionalForm]]]], "DefinitionBox",
  CellTags->"HaploidConstraints"],

Cell[TextData[
"Here, the divergence \[Delta]p is assumed 1 at all loci.  These are the \
constraints:"], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(HaploidConstraints[\[Kappa], 1&, p, {i, j, k}] // TableForm\)], "Input",\

  CellLabel->"In[155]:="],

Cell[BoxData[
    InterpretationBox[GridBox[{
          {
            \(1 - p[i] - p[j] + p[i]\ p[j] - p[k] + p[i]\ p[k] + p[j]\ p[k] - 
                p[i]\ p[j]\ p[k] + 3\ \[Kappa][2] - p[i]\ \[Kappa][2] - 
                p[j]\ \[Kappa][2] - p[k]\ \[Kappa][2] - \[Kappa][3] > 0\)},
          {
            \(p[k] - p[i]\ p[k] - p[j]\ p[k] + p[i]\ p[j]\ p[k] - 
                2\ \[Kappa][2] + p[i]\ \[Kappa][2] + p[j]\ \[Kappa][2] + 
                p[k]\ \[Kappa][2] + \[Kappa][3] > 0\)},
          {
            \(p[j] - p[i]\ p[j] - p[j]\ p[k] + p[i]\ p[j]\ p[k] - 
                2\ \[Kappa][2] + p[i]\ \[Kappa][2] + p[j]\ \[Kappa][2] + 
                p[k]\ \[Kappa][2] + \[Kappa][3] > 0\)},
          {
            \(p[j]\ p[k] - p[i]\ p[j]\ p[k] + \[Kappa][2] - 
                p[i]\ \[Kappa][2] - p[j]\ \[Kappa][2] - p[k]\ \[Kappa][2] - 
                \[Kappa][3] > 0\)},
          {
            \(p[i] - p[i]\ p[j] - p[i]\ p[k] + p[i]\ p[j]\ p[k] - 
                2\ \[Kappa][2] + p[i]\ \[Kappa][2] + p[j]\ \[Kappa][2] + 
                p[k]\ \[Kappa][2] + \[Kappa][3] > 0\)},
          {
            \(p[i]\ p[k] - p[i]\ p[j]\ p[k] + \[Kappa][2] - 
                p[i]\ \[Kappa][2] - p[j]\ \[Kappa][2] - p[k]\ \[Kappa][2] - 
                \[Kappa][3] > 0\)},
          {
            \(p[i]\ p[j] - p[i]\ p[j]\ p[k] + \[Kappa][2] - 
                p[i]\ \[Kappa][2] - p[j]\ \[Kappa][2] - p[k]\ \[Kappa][2] - 
                \[Kappa][3] > 0\)},
          {
            \(p[i]\ p[j]\ p[k] + p[i]\ \[Kappa][2] + p[j]\ \[Kappa][2] + 
                p[k]\ \[Kappa][2] + \[Kappa][3] > 0\)}
          },
        RowSpacings->1,
        ColumnSpacings->3,
        RowAlignments->Baseline,
        ColumnAlignments->{Left}],
      TableForm[ {
        Greater[ 
          Plus[ 1, 
            Times[ -1, 
              p[ i]], 
            Times[ -1, 
              p[ j]], 
            Times[ 
              p[ i], 
              p[ j]], 
            Times[ -1, 
              p[ k]], 
            Times[ 
              p[ i], 
              p[ k]], 
            Times[ 
              p[ j], 
              p[ k]], 
            Times[ -1, 
              p[ i], 
              p[ j], 
              p[ k]], 
            Times[ 3, 
              \[Kappa][ 2]], 
            Times[ -1, 
              p[ i], 
              \[Kappa][ 2]], 
            Times[ -1, 
              p[ j], 
              \[Kappa][ 2]], 
            Times[ -1, 
              p[ k], 
              \[Kappa][ 2]], 
            Times[ -1, 
              \[Kappa][ 3]]], 0], 
        Greater[ 
          Plus[ 
            p[ k], 
            Times[ -1, 
              p[ i], 
              p[ k]], 
            Times[ -1, 
              p[ j], 
              p[ k]], 
            Times[ 
              p[ i], 
              p[ j], 
              p[ k]], 
            Times[ -2, 
              \[Kappa][ 2]], 
            Times[ 
              p[ i], 
              \[Kappa][ 2]], 
            Times[ 
              p[ j], 
              \[Kappa][ 2]], 
            Times[ 
              p[ k], 
              \[Kappa][ 2]], 
            \[Kappa][ 3]], 0], 
        Greater[ 
          Plus[ 
            p[ j], 
            Times[ -1, 
              p[ i], 
              p[ j]], 
            Times[ -1, 
              p[ j], 
              p[ k]], 
            Times[ 
              p[ i], 
              p[ j], 
              p[ k]], 
            Times[ -2, 
              \[Kappa][ 2]], 
            Times[ 
              p[ i], 
              \[Kappa][ 2]], 
            Times[ 
              p[ j], 
              \[Kappa][ 2]], 
            Times[ 
              p[ k], 
              \[Kappa][ 2]], 
            \[Kappa][ 3]], 0], 
        Greater[ 
          Plus[ 
            Times[ 
              p[ j], 
              p[ k]], 
            Times[ -1, 
              p[ i], 
              p[ j], 
              p[ k]], 
            \[Kappa][ 2], 
            Times[ -1, 
              p[ i], 
              \[Kappa][ 2]], 
            Times[ -1, 
              p[ j], 
              \[Kappa][ 2]], 
            Times[ -1, 
              p[ k], 
              \[Kappa][ 2]], 
            Times[ -1, 
              \[Kappa][ 3]]], 0], 
        Greater[ 
          Plus[ 
            p[ i], 
            Times[ -1, 
              p[ i], 
              p[ j]], 
            Times[ -1, 
              p[ i], 
              p[ k]], 
            Times[ 
              p[ i], 
              p[ j], 
              p[ k]], 
            Times[ -2, 
              \[Kappa][ 2]], 
            Times[ 
              p[ i], 
              \[Kappa][ 2]], 
            Times[ 
              p[ j], 
              \[Kappa][ 2]], 
            Times[ 
              p[ k], 
              \[Kappa][ 2]], 
            \[Kappa][ 3]], 0], 
        Greater[ 
          Plus[ 
            Times[ 
              p[ i], 
              p[ k]], 
            Times[ -1, 
              p[ i], 
              p[ j], 
              p[ k]], 
            \[Kappa][ 2], 
            Times[ -1, 
              p[ i], 
              \[Kappa][ 2]], 
            Times[ -1, 
              p[ j], 
              \[Kappa][ 2]], 
            Times[ -1, 
              p[ k], 
              \[Kappa][ 2]], 
            Times[ -1, 
              \[Kappa][ 3]]], 0], 
        Greater[ 
          Plus[ 
            Times[ 
              p[ i], 
              p[ j]], 
            Times[ -1, 
              p[ i], 
              p[ j], 
              p[ k]], 
            \[Kappa][ 2], 
            Times[ -1, 
              p[ i], 
              \[Kappa][ 2]], 
            Times[ -1, 
              p[ j], 
              \[Kappa][ 2]], 
            Times[ -1, 
              p[ k], 
              \[Kappa][ 2]], 
            Times[ -1, 
              \[Kappa][ 3]]], 0], 
        Greater[ 
          Plus[ 
            Times[ 
              p[ i], 
              p[ j], 
              p[ k]], 
            Times[ 
              p[ i], 
              \[Kappa][ 2]], 
            Times[ 
              p[ j], 
              \[Kappa][ 2]], 
            Times[ 
              p[ k], 
              \[Kappa][ 2]], 
            \[Kappa][ 3]], 0]}]]], "Output",
  CellLabel->"Out[155]//TableForm="]
}, Open  ]],

Cell[TextData[Cell[BoxData[
    FormBox[GridBox[{
          {\(DiploidConstraints[{k\_w, k\_b}, \[Delta]p, p, 
              S]\), \(stores\ a\ list\ of\ the\ constraints\ on\ the\ \
\(3\^n\) diploid\ genotype\ frequencies, \ 
            in\ terms\ of\ the\ reduced\ set\ of\ cumulants, \ \(\(k[]\)\(.\)\
\)\)},
          {
            RowBox[{"DiploidConstraints", "[", 
              
              RowBox[{\({k\_w, k\_b}\), ",", "\[Delta]p", ",", "p", ",", "S", 
                ",", 
                StyleBox["gft",
                  FontSlant->"Italic"]}], "]"}], 
            RowBox[{
            "stores", " ", "the", " ", "definition", " ", "of", 
              " ", \(DiploidGenotypeFrequencyTable[]\), " ", "in", " ", 
              RowBox[{
                StyleBox["gft",
                  FontSlant->"Italic"], "[", "X", "]"}]}]}
          }], TraditionalForm]]]], "DefinitionBox",
  CellTags->"DiploidConstraints"],

Cell[TextData[{
  "These are the constraints determined by the requiremnt that all ",
  Cell[BoxData[
      \(TraditionalForm\`3\^n\)]],
  " diploid genotype frequencies be positive:"
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(pp[i] = 0.2; pp[j] = 0.3; pp[k] = 0.4; pp[\(i_\^*\)] := pp[i]; \n
    DiploidConstraints[{\[Kappa]\_w, \[Kappa]\_b}, 1&, pp, {i, j}] // 
      TableForm\)], "Input",
  CellLabel->"In[195]:="],

Cell[BoxData[
    InterpretationBox[GridBox[{
          {
            \(\(0.313599999999999923`\[InvisibleSpace]\) + 
                2.25`\ \[Kappa]\_b[2] + 2\ \[Kappa]\_b[2]\^2 - 
                3.`\ \[Kappa]\_b[3] + \[Kappa]\_b[4] + 
                1.11999999999999988`\ \[Kappa]\_w[2] + \[Kappa]\_w[2]\^2 > 0
              \)},
          {
            \(\(0.268799999999999972`\[InvisibleSpace]\) - 
                1.50000000000000044`\ \[Kappa]\_b[2] - 4\ \[Kappa]\_b[2]\^2 + 
                4.`\ \[Kappa]\_b[3] - 2\ \[Kappa]\_b[4] - 
                0.639999999999999857`\ \[Kappa]\_w[2] - 
                2\ \[Kappa]\_w[2]\^2 > 0\)},
          {
            \(\(0.0575999999999999978`\[InvisibleSpace]\) + 
                0.250000000000000088`\ \[Kappa]\_b[2] + 
                2\ \[Kappa]\_b[2]\^2 - 1.`\ \[Kappa]\_b[3] + \[Kappa]\_b[4] - 
                0.479999999999999982`\ \[Kappa]\_w[2] + \[Kappa]\_w[2]\^2 > 0
              \)},
          {
            \(\(0.156799999999999961`\[InvisibleSpace]\) - 
                1.49999999999999955`\ \[Kappa]\_b[2] - 4\ \[Kappa]\_b[2]\^2 + 
                4.`\ \[Kappa]\_b[3] - 2\ \[Kappa]\_b[4] - 
                0.839999999999999857`\ \[Kappa]\_w[2] - 
                2\ \[Kappa]\_w[2]\^2 > 0\)},
          {
            \(\(0.134399999999999986`\[InvisibleSpace]\) - 
                1.`\ \[Kappa]\_b[2] + 8\ \[Kappa]\_b[2]\^2 - 
                4.`\ \[Kappa]\_b[3] + 4\ \[Kappa]\_b[4] + 
                0.479999999999999715`\ \[Kappa]\_w[2] + 
                4\ \[Kappa]\_w[2]\^2 > 0\)},
          {
            \(\(0.0287999999999999989`\[InvisibleSpace]\) + 
                0.5`\ \[Kappa]\_b[2] - 4\ \[Kappa]\_b[2]\^2 + 
                0.`\ \[Kappa]\_b[3] - 2\ \[Kappa]\_b[4] + 
                0.359999999999999964`\ \[Kappa]\_w[2] - 
                2\ \[Kappa]\_w[2]\^2 > 0\)},
          {
            \(\(0.0195999999999999943`\[InvisibleSpace]\) + 
                0.249999999999999955`\ \[Kappa]\_b[2] + 
                2\ \[Kappa]\_b[2]\^2 - 1.`\ \[Kappa]\_b[3] + \[Kappa]\_b[4] - 
                0.279999999999999982`\ \[Kappa]\_w[2] + \[Kappa]\_w[2]\^2 > 0
              \)},
          {
            \(\(0.0167999999999999971`\[InvisibleSpace]\) + 
                0.499999999999999911`\ \[Kappa]\_b[2] - 
                4\ \[Kappa]\_b[2]\^2 + 0.`\ \[Kappa]\_b[3] - 
                2\ \[Kappa]\_b[4] + 0.159999999999999964`\ \[Kappa]\_w[2] - 
                2\ \[Kappa]\_w[2]\^2 > 0\)},
          {
            \(\(0.00359999999999999964`\[InvisibleSpace]\) + 
                0.25`\ \[Kappa]\_b[2] + 2\ \[Kappa]\_b[2]\^2 + 
                1.`\ \[Kappa]\_b[3] + \[Kappa]\_b[4] + 
                0.119999999999999996`\ \[Kappa]\_w[2] + \[Kappa]\_w[2]\^2 > 0
              \)}
          },
        RowSpacings->1,
        ColumnSpacings->3,
        RowAlignments->Baseline,
        ColumnAlignments->{Left}],
      TableForm[ {
        Greater[ 
          Plus[ 0.31359999999999993, 
            Times[ 2.25, 
              Subscript[ \[Kappa], b][ 2]], 
            Times[ 2, 
              Power[ 
                Subscript[ \[Kappa], b][ 2], 2]], 
            Times[ -3.0, 
              Subscript[ \[Kappa], b][ 3]], 
            Subscript[ \[Kappa], b][ 4], 
            Times[ 1.1199999999999999, 
              Subscript[ \[Kappa], w][ 2]], 
            Power[ 
              Subscript[ \[Kappa], w][ 2], 2]], 0], 
        Greater[ 
          Plus[ 0.26879999999999998, 
            Times[ -1.5000000000000004, 
              Subscript[ \[Kappa], b][ 2]], 
            Times[ -4, 
              Power[ 
                Subscript[ \[Kappa], b][ 2], 2]], 
            Times[ 4.0, 
              Subscript[ \[Kappa], b][ 3]], 
            Times[ -2, 
              Subscript[ \[Kappa], b][ 4]], 
            Times[ -0.6399999999999999, 
              Subscript[ \[Kappa], w][ 2]], 
            Times[ -2, 
              Power[ 
                Subscript[ \[Kappa], w][ 2], 2]]], 0], 
        Greater[ 
          Plus[ 0.057599999999999998, 
            Times[ 0.25000000000000011, 
              Subscript[ \[Kappa], b][ 2]], 
            Times[ 2, 
              Power[ 
                Subscript[ \[Kappa], b][ 2], 2]], 
            Times[ -1.0, 
              Subscript[ \[Kappa], b][ 3]], 
            Subscript[ \[Kappa], b][ 4], 
            Times[ -0.47999999999999998, 
              Subscript[ \[Kappa], w][ 2]], 
            Power[ 
              Subscript[ \[Kappa], w][ 2], 2]], 0], 
        Greater[ 
          Plus[ 0.15679999999999997, 
            Times[ -1.4999999999999996, 
              Subscript[ \[Kappa], b][ 2]], 
            Times[ -4, 
              Power[ 
                Subscript[ \[Kappa], b][ 2], 2]], 
            Times[ 4.0, 
              Subscript[ \[Kappa], b][ 3]], 
            Times[ -2, 
              Subscript[ \[Kappa], b][ 4]], 
            Times[ -0.83999999999999986, 
              Subscript[ \[Kappa], w][ 2]], 
            Times[ -2, 
              Power[ 
                Subscript[ \[Kappa], w][ 2], 2]]], 0], 
        Greater[ 
          Plus[ 0.13439999999999999, 
            Times[ -1.0, 
              Subscript[ \[Kappa], b][ 2]], 
            Times[ 8, 
              Power[ 
                Subscript[ \[Kappa], b][ 2], 2]], 
            Times[ -4.0, 
              Subscript[ \[Kappa], b][ 3]], 
            Times[ 4, 
              Subscript[ \[Kappa], b][ 4]], 
            Times[ 0.47999999999999976, 
              Subscript[ \[Kappa], w][ 2]], 
            Times[ 4, 
              Power[ 
                Subscript[ \[Kappa], w][ 2], 2]]], 0], 
        Greater[ 
          Plus[ 0.028799999999999999, 
            Times[ 0.5, 
              Subscript[ \[Kappa], b][ 2]], 
            Times[ -4, 
              Power[ 
                Subscript[ \[Kappa], b][ 2], 2]], 
            Times[ 0.0, 
              Subscript[ \[Kappa], b][ 3]], 
            Times[ -2, 
              Subscript[ \[Kappa], b][ 4]], 
            Times[ 0.35999999999999999, 
              Subscript[ \[Kappa], w][ 2]], 
            Times[ -2, 
              Power[ 
                Subscript[ \[Kappa], w][ 2], 2]]], 0], 
        Greater[ 
          Plus[ 0.019599999999999996, 
            Times[ 0.24999999999999997, 
              Subscript[ \[Kappa], b][ 2]], 
            Times[ 2, 
              Power[ 
                Subscript[ \[Kappa], b][ 2], 2]], 
            Times[ -1.0, 
              Subscript[ \[Kappa], b][ 3]], 
            Subscript[ \[Kappa], b][ 4], 
            Times[ -0.27999999999999997, 
              Subscript[ \[Kappa], w][ 2]], 
            Power[ 
              Subscript[ \[Kappa], w][ 2], 2]], 0], 
        Greater[ 
          Plus[ 0.016799999999999999, 
            Times[ 0.49999999999999994, 
              Subscript[ \[Kappa], b][ 2]], 
            Times[ -4, 
              Power[ 
                Subscript[ \[Kappa], b][ 2], 2]], 
            Times[ 0.0, 
              Subscript[ \[Kappa], b][ 3]], 
            Times[ -2, 
              Subscript[ \[Kappa], b][ 4]], 
            Times[ 0.15999999999999998, 
              Subscript[ \[Kappa], w][ 2]], 
            Times[ -2, 
              Power[ 
                Subscript[ \[Kappa], w][ 2], 2]]], 0], 
        Greater[ 
          Plus[ 0.0035999999999999999, 
            Times[ 0.25, 
              Subscript[ \[Kappa], b][ 2]], 
            Times[ 2, 
              Power[ 
                Subscript[ \[Kappa], b][ 2], 2]], 
            Times[ 1.0, 
              Subscript[ \[Kappa], b][ 3]], 
            Subscript[ \[Kappa], b][ 4], 
            Times[ 0.12, 
              Subscript[ \[Kappa], w][ 2]], 
            Power[ 
              Subscript[ \[Kappa], w][ 2], 2]], 0]}]]], "Output",
  CellLabel->"Out[195]//TableForm="]
}, Open  ]],

Cell[TextData[{
  "It is quickest to store the various expressions for genotype frequencies \
in a table, ",
  StyleBox["gft",
    FontSlant->"Italic"],
  ":"
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(Timing[
      DiploidConstraints[{\[Kappa]\_w, \[Kappa]\_b}, 1&, pp, {j, k, l}, 
        gft]; ]\)], "Input",
  CellLabel->"In[197]:="],

Cell[BoxData[
    \({0.0166666666700621135`\ Second, Null}\)], "Output",
  CellLabel->"Out[197]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(Timing[
      dc = DiploidConstraints[{\[Kappa]\_w, \[Kappa]\_b}, 1&, pp, {j, k, l}, 
          gft]; ]\)], "Input",
  CellLabel->"In[199]:="],

Cell[BoxData[
    \({0.`\ Second, Null}\)], "Output",
  CellLabel->"Out[199]="]
}, Open  ]],

Cell["Here is the first constraint:", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(dc\[LeftDoubleBracket]1\[RightDoubleBracket]\)], "Input",
  CellLabel->"In[200]:="],

Cell[BoxData[
    \(\(0.112895999999999974`\[InvisibleSpace]\) + 
        2.13159999999999971`\ \[Kappa]\_b[2] + 
        8.82000000000000028`\ \[Kappa]\_b[2]\^2 + 
        5.99999999999999911`\ \[Kappa]\_b[2]\^3 - 
        6.13199999999999878`\ \[Kappa]\_b[3] - 
        25.1999999999999957`\ \[Kappa]\_b[2]\ \[Kappa]\_b[3] + 
        9.`\ \[Kappa]\_b[3]\^2 + 7.32999999999999918`\ \[Kappa]\_b[4] + 
        9.`\ \[Kappa]\_b[2]\ \[Kappa]\_b[4] - 
        4.20000000000000017`\ \[Kappa]\_b[5] + 
        0.999999999999999822`\ \[Kappa]\_b[6] + 
        1.41119999999999983`\ \[Kappa]\_w[2] + 
        8.75999999999999978`\ \[Kappa]\_b[2]\ \[Kappa]\_w[2] - 
        12.5999999999999978`\ \[Kappa]\_b[3]\ \[Kappa]\_w[2] + 
        5.99999999999999911`\ \[Kappa]\_b[4]\ \[Kappa]\_w[2] + 
        4.41000000000000014`\ \[Kappa]\_w[2]\^2 + 
        9.`\ \[Kappa]\_b[2]\ \[Kappa]\_w[2]\^2 - 
        0.671999999999999886`\ \[Kappa]\_w[3] - 
        4.20000000000000017`\ \[Kappa]\_w[2]\ \[Kappa]\_w[3] + 
        0.999999999999999822`\ \[Kappa]\_w[3]\^2 > 0\)], "Output",
  CellLabel->"Out[200]="]
}, Open  ]],

Cell["\<\
Here is the expression for the frequency of diploid genotype \
{1,2,1}:\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(gft[{1, 2, 1}]\)], "Input",
  CellLabel->"In[201]:="],

Cell[BoxData[
    \(\(0.0138240000000000007`\[InvisibleSpace]\) + 
      0.242399999999999993`\ \[Kappa]\_b[2] - 
      3.92000000000000028`\ \[Kappa]\_b[2]\^2 + 
      24.0000000000000035`\ \[Kappa]\_b[2]\^3 - 
      0.328000000000000069`\ \[Kappa]\_b[3] - 
      4.79999999999999893`\ \[Kappa]\_b[2]\ \[Kappa]\_b[3] + 
      36.0000000000000008`\ \[Kappa]\_b[3]\^2 - 
      2.68000000000000015`\ \[Kappa]\_b[4] + 
      36.0000000000000008`\ \[Kappa]\_b[2]\ \[Kappa]\_b[4] - 
      0.799999999999999733`\ \[Kappa]\_b[5] + 
      4.00000000000000088`\ \[Kappa]\_b[6] + 
      0.232800000000000029`\ \[Kappa]\_w[2] - 
      2.16000000000000014`\ \[Kappa]\_b[2]\ \[Kappa]\_w[2] - 
      2.39999999999999946`\ \[Kappa]\_b[3]\ \[Kappa]\_w[2] + 
      24.0000000000000035`\ \[Kappa]\_b[4]\ \[Kappa]\_w[2] - 
      1.96000000000000014`\ \[Kappa]\_w[2]\^2 + 
      36.0000000000000008`\ \[Kappa]\_b[2]\ \[Kappa]\_w[2]\^2 + 
      0.0720000000000000106`\ \[Kappa]\_w[3] - 
      0.799999999999999733`\ \[Kappa]\_w[2]\ \[Kappa]\_w[3] + 
      4.00000000000000088`\ \[Kappa]\_w[3]\^2\)], "Output",
  CellLabel->"Out[201]="]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["Log likelihood: LogLikelihoodDisequilibriumReduced[]", \
"SubsubsectionIcon"],

Cell[TextData[Cell[BoxData[
    FormBox[GridBox[{
          {
            RowBox[{
              RowBox[{
                FormBox[
                  RowBox[{"LogLikelihoodDisequilibriumReduced", "[", 
                    RowBox[{
                      StyleBox["site",
                        FontSlant->"Italic"], ",", \({k\_w, k\_b}\)}]}],
                  "TraditionalForm"], ",", "\[Delta]p", ",", "p", ",", "S"}], 
              "]"}], \(gives\ an\ expression\ for\ the\ log\ likelihood\ in\ \
terms\ of\ the\ reduced\ cumulants \(\({k\_w, k\_b}\)\(.\)\)\)},
          {
            RowBox[{
              RowBox[{
                FormBox[
                  RowBox[{"LogLikelihoodDisequilibriumReduced", "[", 
                    RowBox[{
                      StyleBox["site",
                        FontSlant->"Italic"], ",", \({k\_w, k\_b}\)}]}],
                  "TraditionalForm"], ",", "\[Delta]p", ",", "p", ",", "S", 
                ",", "gdt"}], 
              "]"}], \(stores\ the\ definition\ of\ genotype\ frequencies\ \
in\ \ a\ table\ for\ \(\(speed\)\(.\)\)\)}
          }], TraditionalForm]]]], "DefinitionBox",
  CellTags->"LogLikelihoodDisequilibriumReduced"],

Cell["\<\
These are the allele frequencies, estimated directly from the \
sample:\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(pl = \(Transpose[pTable[1063, 4]] // N\) // First\)], "Input",
  CellLabel->"In[261]:="],

Cell[BoxData[
    \({0.608108108108108069`, 0.824324324324324386`, 0.675675675675675613`, 
      0.689189189189189121`}\)], "Output",
  CellLabel->"Out[261]="]
}, Closed]],

Cell["\<\
This is a complicated expression for the log likelihood of the \
reduced set of cumulants, given those allele frequencies:\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(pp[j_] := pl\[LeftDoubleBracket]j\[RightDoubleBracket]; \n\ 
    LogLikelihoodDisequilibriumReduced[1063, {k\_w, k\_b}, 1&, pp, Range[4]]
      \)], "Input",
  CellLabel->"In[262]:="],

Cell[BoxData[
    \(37\ Log[37] + 
      2\ Log[1\/2\ 
            \((\(0.0201100755503774974`\[InvisibleSpace]\) - 
                0.349455417861351591`\ k\_b[2] + 
                5.51979525771798584`\ k\_b[2]\^2 - 
                44.783053323593851`\ k\_b[2]\^3 - 192\ k\_b[2]\^4 + 
                0.815872881324035148`\ k\_b[3] + 
                5.79306260241252068`\ k\_b[2]\ k\_b[3] - 
                747.243243243243249`\ k\_b[2]\^2\ k\_b[3] - 
                121.959094229364484`\ k\_b[3]\^2 - 
                1152\ k\_b[2]\ k\_b[3]\^2 + 4.58207405873881867`\ k\_b[4] - 
                140.22059897735577`\ k\_b[2]\ k\_b[4] - 
                576\ k\_b[2]\^2\ k\_b[4] - 
                622.702702702702559`\ k\_b[3]\ k\_b[4] - 272\ k\_b[4]\^2 - 
                0.681697036700689196`\ k\_b[5] - 
                249.081081081081068`\ k\_b[2]\ k\_b[5] - 
                384\ k\_b[3]\ k\_b[5] - 16.5945945945946`\ k\_b[6] - 
                128\ k\_b[2]\ k\_b[6] - 20.7567567567567579`\ k\_b[7] - 
                8\ k\_b[8] - 0.079318181796833862`\ k\_w[2] + 
                5.46652928963946926`\ k\_b[2]\ k\_w[2] - 
                109.569028487947406`\ k\_b[2]\^2\ k\_w[2] - 
                6.98671352141037971`\ k\_b[3]\ k\_w[2] - 
                747.243243243243249`\ k\_b[2]\ k\_b[3]\ k\_w[2] - 
                576\ k\_b[3]\^2\ k\_w[2] - 
                99.5675675675676252`\ k\_b[4]\ k\_w[2] - 
                768\ k\_b[2]\ k\_b[4]\ k\_w[2] - 
                186.810810810810821`\ k\_b[5]\ k\_w[2] - 
                96\ k\_b[6]\ k\_w[2] + 2.44526083938359573`\ k\_w[2]\^2 - 
                67.1745799853907676`\ k\_b[2]\ k\_w[2]\^2 - 
                576\ k\_b[2]\^2\ k\_w[2]\^2 - 
                373.621621621621624`\ k\_b[3]\ k\_w[2]\^2 - 
                288\ k\_b[4]\ k\_w[2]\^2 - 27.3922571219868515`\ k\_w[2]\^3 - 
                72\ k\_w[2]\^4 + 0.232625822030894457`\ k\_w[3] - 
                6.58882988174441486`\ k\_b[2]\ k\_w[3] - 
                36.5230094959824791`\ k\_b[3]\ k\_w[3] - 
                83.0270270270270316`\ k\_b[4]\ k\_w[3] - 
                64\ k\_b[5]\ k\_w[3] + 
                0.965510433735413897`\ k\_w[2]\ k\_w[3] - 
                249.081081081081068`\ k\_b[2]\ k\_w[2]\ k\_w[3] - 
                384\ k\_b[3]\ k\_w[2]\ k\_w[3] - 
                62.2702702702702648`\ k\_w[2]\^2\ k\_w[3] - 
                7.46384222059897162`\ k\_w[3]\^2 - 128\ k\_b[2]\ k\_w[3]\^2 - 
                0.104878929825132427`\ k\_w[4] - 
                9.13075237399561956`\ k\_w[2]\ k\_w[4] - 
                48\ k\_w[2]\^2\ k\_w[4] - 
                20.7567567567567579`\ k\_w[3]\ k\_w[4] - 8\ k\_w[4]\^2)\)] + 
      Log[\(0.0287370065111191319`\[InvisibleSpace]\) - 
          0.498631769306078176`\ k\_b[2] + 6.97889935816613338`\ k\_b[2]\^2 - 
          44.7830533235938421`\ k\_b[2]\^3 - 192\ k\_b[2]\^4 + 
          0.862692231422558819`\ k\_b[3] + 
          12.7879493810830568`\ k\_b[2]\ k\_b[3] - 
          747.243243243243249`\ k\_b[2]\^2\ k\_b[3] - 
          118.067202337472544`\ k\_b[3]\^2 - 1152\ k\_b[2]\ k\_b[3]\^2 + 
          5.57020901619444597`\ k\_b[4] - 
          135.031409788166545`\ k\_b[2]\ k\_b[4] - 576\ k\_b[2]\^2\ k\_b[4] - 
          622.702702702702559`\ k\_b[3]\ k\_b[4] - 272\ k\_b[4]\^2 + 
          0.80844175073538711`\ k\_b[5] - 
          249.081081081081068`\ k\_b[2]\ k\_b[5] - 384\ k\_b[3]\ k\_b[5] - 
          15.945945945945934`\ k\_b[6] - 128\ k\_b[2]\ k\_b[6] - 
          20.756756756756749`\ k\_b[7] - 8\ k\_b[8] - 
          0.108970022980341907`\ k\_w[2] + 
          6.24227801133413873`\ k\_b[2]\ k\_w[2] - 
          101.785244704163591`\ k\_b[2]\^2\ k\_w[2] - 
          1.54332418612913979`\ k\_b[3]\ k\_w[2] - 
          747.243243243243249`\ k\_b[2]\ k\_b[3]\ k\_w[2] - 
          576\ k\_b[3]\^2\ k\_w[2] - 95.6756756756757376`\ k\_b[4]\ k\_w[2] - 
          768\ k\_b[2]\ k\_b[4]\ k\_w[2] - 
          186.810810810810821`\ k\_b[5]\ k\_w[2] - 96\ k\_b[6]\ k\_w[2] + 
          3.28568490113709721`\ k\_w[2]\^2 - 
          67.1745799853907943`\ k\_b[2]\ k\_w[2]\^2 - 
          576\ k\_b[2]\^2\ k\_w[2]\^2 - 
          373.621621621621624`\ k\_b[3]\ k\_w[2]\^2 - 
          288\ k\_b[4]\ k\_w[2]\^2 - 25.4463111760408988`\ k\_w[2]\^3 - 
          72\ k\_w[2]\^4 + 0.217968063172397252`\ k\_w[3] - 
          5.29153258444711482`\ k\_b[2]\ k\_w[3] - 
          33.9284149013878799`\ k\_b[3]\ k\_w[3] - 
          83.0270270270269961`\ k\_b[4]\ k\_w[3] - 64\ k\_b[5]\ k\_w[3] + 
          2.13132489684716652`\ k\_w[2]\ k\_w[3] - 
          249.081081081081068`\ k\_b[2]\ k\_w[2]\ k\_w[3] - 
          384\ k\_b[3]\ k\_w[2]\ k\_w[3] - 
          62.2702702702702648`\ k\_w[2]\^2\ k\_w[3] - 
          7.46384222059897783`\ k\_w[3]\^2 - 128\ k\_b[2]\ k\_w[3]\^2 - 
          0.0679215926486571586`\ k\_w[4] - 
          8.48210372534697043`\ k\_w[2]\ k\_w[4] - 48\ k\_w[2]\^2\ k\_w[4] - 
          20.756756756756749`\ k\_w[3]\ k\_w[4] - 8\ k\_w[4]\^2] + 
      Log[\(0.00622071670358343897`\[InvisibleSpace]\) + 
          0.140470056106048346`\ k\_b[2] - 2.9220344463469253`\ k\_b[2]\^2 + 
          31.7574872169466804`\ k\_b[2]\^3 - 192\ k\_b[2]\^4 + 
          0.192081755588306073`\ k\_b[3] + 
          8.90482301147021004`\ k\_b[2]\ k\_b[3] - 
          171.243243243243137`\ k\_b[2]\^2\ k\_b[3] + 
          55.7706355003652021`\ k\_b[3]\^2 - 1152\ k\_b[2]\ k\_b[3]\^2 - 
          2.45762743969168084`\ k\_b[4] + 
          58.4821037253469899`\ k\_b[2]\ k\_b[4] - 576\ k\_b[2]\^2\ k\_b[4] - 
          142.70270270270271`\ k\_b[3]\ k\_b[4] - 272\ k\_b[4]\^2 + 
          1.98448265650603872`\ k\_b[5] - 
          57.0810810810810842`\ k\_b[2]\ k\_b[5] - 384\ k\_b[3]\ k\_b[5] + 
          6.64864864864865445`\ k\_b[6] - 128\ k\_b[2]\ k\_b[6] - 
          4.75675675675675879`\ k\_b[7] - 8\ k\_b[8] + 
          0.179430518540529249`\ k\_w[2] - 
          2.98983064955465405`\ k\_b[2]\ k\_w[2] + 
          16.2688093498904384`\ k\_b[2]\^2\ k\_w[2] + 
          7.45448443330110777`\ k\_b[3]\ k\_w[2] - 
          171.243243243243137`\ k\_b[2]\ k\_b[3]\ k\_w[2] - 
          576\ k\_b[3]\^2\ k\_w[2] + 39.8918918918919231`\ k\_b[4]\ k\_w[2] - 
          768\ k\_b[2]\ k\_b[4]\ k\_w[2] - 
          42.8108108108107821`\ k\_b[5]\ k\_w[2] - 96\ k\_b[6]\ k\_w[2] - 
          1.35775181534564093`\ k\_w[2]\^2 + 
          47.6362308254199984`\ k\_b[2]\ k\_w[2]\^2 - 
          576\ k\_b[2]\^2\ k\_w[2]\^2 - 
          85.6216216216215642`\ k\_b[3]\ k\_w[2]\^2 - 
          288\ k\_b[4]\ k\_w[2]\^2 + 4.06720233747260984`\ k\_w[2]\^3 - 
          72\ k\_w[2]\^4 - 0.141386335942726759`\ k\_w[3] + 
          2.00138195171065902`\ k\_b[2]\ k\_w[3] + 
          5.42293644996347445`\ k\_b[3]\ k\_w[3] - 
          19.0270270270270351`\ k\_b[4]\ k\_w[3] - 64\ k\_b[5]\ k\_w[3] + 
          1.48413716857836908`\ k\_w[2]\ k\_w[3] - 
          57.0810810810810842`\ k\_b[2]\ k\_w[2]\ k\_w[3] - 
          384\ k\_b[3]\ k\_w[2]\ k\_w[3] - 
          14.270270270270271`\ k\_w[2]\^2\ k\_w[3] + 
          5.29291453615777829`\ k\_w[3]\^2 - 128\ k\_b[2]\ k\_w[3]\^2 + 
          0.0344218026092742412`\ k\_w[4] + 
          1.35573411249086861`\ k\_w[2]\ k\_w[4] - 48\ k\_w[2]\^2\ k\_w[4] - 
          4.75675675675675879`\ k\_w[3]\ k\_w[4] - 8\ k\_w[4]\^2] + 
      Log[\(0.00276193023041614349`\[InvisibleSpace]\) + 
          0.127781675776094028`\ k\_b[2] - 2.75264665095474736`\ k\_b[2]\^2 + 
          31.7574872169466804`\ k\_b[2]\^3 - 192\ k\_b[2]\^4 + 
          0.00036716970160766138`\ k\_b[3] + 
          10.3511341875111062`\ k\_b[2]\ k\_b[3] - 
          171.243243243243137`\ k\_b[2]\^2\ k\_b[3] + 
          48.6355003652301132`\ k\_b[3]\^2 - 1152\ k\_b[2]\ k\_b[3]\^2 - 
          1.70667488011968915`\ k\_b[4] + 
          48.9685902118334759`\ k\_b[2]\ k\_b[4] - 576\ k\_b[2]\^2\ k\_b[4] - 
          142.70270270270271`\ k\_b[3]\ k\_b[4] - 272\ k\_b[4]\^2 + 
          1.87199178725840535`\ k\_b[5] - 
          57.0810810810810842`\ k\_b[2]\ k\_b[5] - 384\ k\_b[3]\ k\_b[5] + 
          5.45945945945945965`\ k\_b[6] - 128\ k\_b[2]\ k\_b[6] - 
          4.7567567567567579`\ k\_b[7] - 8\ k\_b[8] + 
          0.0753754492574192269`\ k\_w[2] - 
          0.991054663926947654`\ k\_b[2]\ k\_w[2] + 
          1.99853907962015497`\ k\_b[2]\^2\ k\_w[2] + 
          6.05638362979488675`\ k\_b[3]\ k\_w[2] - 
          171.243243243243137`\ k\_b[2]\ k\_b[3]\ k\_w[2] - 
          576\ k\_b[3]\^2\ k\_w[2] + 32.756756756756773`\ k\_b[4]\ k\_w[2] - 
          768\ k\_b[2]\ k\_b[4]\ k\_w[2] - 
          42.8108108108107821`\ k\_b[5]\ k\_w[2] - 96\ k\_b[6]\ k\_w[2] - 
          1.34602496797233461`\ k\_w[2]\^2 + 
          47.6362308254200161`\ k\_b[2]\ k\_w[2]\^2 - 
          576\ k\_b[2]\^2\ k\_w[2]\^2 - 
          85.6216216216215642`\ k\_b[3]\ k\_w[2]\^2 - 
          288\ k\_b[4]\ k\_w[2]\^2 + 0.499634769905038744`\ k\_w[2]\^3 - 
          72\ k\_w[2]\^4 - 0.0480704468595583822`\ k\_w[3] + 
          0.587211024026217565`\ k\_b[2]\ k\_w[3] + 
          0.666179693206719658`\ k\_b[3]\ k\_w[3] - 
          19.0270270270270316`\ k\_b[4]\ k\_w[3] - 64\ k\_b[5]\ k\_w[3] + 
          1.72518903125185101`\ k\_w[2]\ k\_w[3] - 
          57.0810810810810842`\ k\_b[2]\ k\_w[2]\ k\_w[3] - 
          384\ k\_b[3]\ k\_w[2]\ k\_w[3] - 
          14.270270270270271`\ k\_w[2]\^2\ k\_w[3] + 
          5.2929145361577774`\ k\_w[3]\^2 - 128\ k\_b[2]\ k\_w[3]\^2 + 
          0.0100994525016794156`\ k\_w[4] + 
          0.166544923301679919`\ k\_w[2]\ k\_w[4] - 48\ k\_w[2]\^2\ k\_w[4] - 
          4.7567567567567579`\ k\_w[3]\ k\_w[4] - 8\ k\_w[4]\^2] + 
      Log[\(0.00964552301877841244`\[InvisibleSpace]\) - 
          0.0816044917569189465`\ k\_b[2] + 
          0.703927650826156003`\ k\_b[2]\^2 - 
          17.1957633308984654`\ k\_b[2]\^3 - 48\ k\_b[2]\^4 + 
          0.134603982146561618`\ k\_b[3] - 
          1.83223106232602219`\ k\_b[2]\ k\_b[3] - 
          186.810810810810785`\ k\_b[2]\^2\ k\_b[3] - 
          31.7059897735573192`\ k\_b[3]\^2 - 288\ k\_b[2]\ k\_b[3]\^2 + 
          1.34621738740695051`\ k\_b[4] - 
          33.6767713659605494`\ k\_b[2]\ k\_b[4] - 144\ k\_b[2]\^2\ k\_b[4] - 
          155.675675675675684`\ k\_b[3]\ k\_b[4] - 68\ k\_b[4]\^2 + 
          0.514382168874502365`\ k\_b[5] - 
          62.2702702702702737`\ k\_b[2]\ k\_b[5] - 96\ k\_b[3]\ k\_b[5] - 
          3.85135135135134909`\ k\_b[6] - 32\ k\_b[2]\ k\_b[6] - 
          5.1891891891891877`\ k\_b[7] - 2\ k\_b[8] - 
          0.119237635363950399`\ k\_w[2] + 
          2.98276068598161927`\ k\_b[2]\ k\_w[2] - 
          11.8246895544192764`\ k\_b[2]\^2\ k\_w[2] + 
          4.00240854441000237`\ k\_b[3]\ k\_w[2] - 
          186.810810810810785`\ k\_b[2]\ k\_b[3]\ k\_w[2] - 
          144\ k\_b[3]\^2\ k\_w[2] - 23.1081081081081007`\ k\_b[4]\ k\_w[2] - 
          192\ k\_b[2]\ k\_b[4]\ k\_w[2] - 
          46.7027027027026964`\ k\_b[5]\ k\_w[2] - 24\ k\_b[6]\ k\_w[2] + 
          1.06220163315745041`\ k\_w[2]\^2 - 
          25.7936449963476954`\ k\_b[2]\ k\_w[2]\^2 - 
          144\ k\_b[2]\^2\ k\_w[2]\^2 - 
          93.4054054054053928`\ k\_b[3]\ k\_w[2]\^2 - 
          72\ k\_b[4]\ k\_w[2]\^2 - 2.95617238860481901`\ k\_w[2]\^3 - 
          18\ k\_w[2]\^4 + 0.124638203874059239`\ k\_w[3] + 
          3.27901605038201005`\ k\_b[2]\ k\_w[3] - 
          3.94156318480643186`\ k\_b[3]\ k\_w[3] - 
          20.756756756756749`\ k\_b[4]\ k\_w[3] - 16\ k\_b[5]\ k\_w[3] - 
          0.305371843721005076`\ k\_w[2]\ k\_w[3] - 
          62.2702702702702737`\ k\_b[2]\ k\_w[2]\ k\_w[3] - 
          96\ k\_b[3]\ k\_w[2]\ k\_w[3] - 
          15.5675675675675684`\ k\_w[2]\^2\ k\_w[3] - 
          2.86596055514974423`\ k\_w[3]\^2 - 32\ k\_b[2]\ k\_w[3]\^2 + 
          0.236745935914790628`\ k\_w[4] - 
          0.985390796201608054`\ k\_w[2]\ k\_w[4] - 12\ k\_w[2]\^2\ k\_w[4] - 
          5.1891891891891877`\ k\_w[3]\ k\_w[4] - 2\ k\_w[4]\^2] + 
      Log[\(0.0204112651513516096`\[InvisibleSpace]\) - 
          0.099977118300281873`\ k\_b[2] + 1.10005423760285303`\ k\_b[2]\^2 - 
          17.1957633308984654`\ k\_b[2]\^3 - 48\ k\_b[2]\^4 + 
          0.126069496582089879`\ k\_b[3] + 
          1.08230509545338948`\ k\_b[2]\ k\_b[3] - 
          186.810810810810785`\ k\_b[2]\^2\ k\_b[3] - 
          30.0843681519357186`\ k\_b[3]\^2 - 288\ k\_b[2]\ k\_b[3]\^2 + 
          1.68213036393351185`\ k\_b[4] - 
          31.5146092037983782`\ k\_b[2]\ k\_b[4] - 144\ k\_b[2]\^2\ k\_b[4] - 
          155.675675675675684`\ k\_b[3]\ k\_b[4] - 68\ k\_b[4]\^2 + 
          1.07683651511262423`\ k\_b[5] - 
          62.2702702702702737`\ k\_b[2]\ k\_b[5] - 96\ k\_b[3]\ k\_b[5] - 
          3.58108108108107892`\ k\_b[6] - 32\ k\_b[2]\ k\_b[6] - 
          5.1891891891891877`\ k\_b[7] - 2\ k\_b[8] - 
          0.212340557079248748`\ k\_w[2] + 
          3.39630973539626346`\ k\_b[2]\ k\_w[2] - 
          8.5814463111760304`\ k\_b[2]\^2\ k\_w[2] + 
          5.91986654294907932`\ k\_b[3]\ k\_w[2] - 
          186.810810810810785`\ k\_b[2]\ k\_b[3]\ k\_w[2] - 
          144\ k\_b[3]\^2\ k\_w[2] - 21.486486486486469`\ k\_b[4]\ k\_w[2] - 
          192\ k\_b[2]\ k\_b[4]\ k\_w[2] - 
          46.7027027027026964`\ k\_b[5]\ k\_w[2] - 24\ k\_b[6]\ k\_w[2] + 
          1.04556885721130865`\ k\_w[2]\^2 - 
          25.7936449963476999`\ k\_b[2]\ k\_w[2]\^2 - 
          144\ k\_b[2]\^2\ k\_w[2]\^2 - 
          93.4054054054053928`\ k\_b[3]\ k\_w[2]\^2 - 
          72\ k\_b[4]\ k\_w[2]\^2 - 2.1453615777940076`\ k\_w[2]\^3 - 
          18\ k\_w[2]\^4 - 0.00398601784435234662`\ k\_w[3] + 
          3.58580933014826452`\ k\_b[2]\ k\_w[3] - 
          2.86048210372534761`\ k\_b[3]\ k\_w[3] - 
          20.756756756756749`\ k\_b[4]\ k\_w[3] - 16\ k\_b[5]\ k\_w[3] + 
          0.180384182575560316`\ k\_w[2]\ k\_w[3] - 
          62.2702702702702737`\ k\_b[2]\ k\_w[2]\ k\_w[3] - 
          96\ k\_b[3]\ k\_w[2]\ k\_w[3] - 
          15.5675675675675684`\ k\_w[2]\^2\ k\_w[3] - 
          2.86596055514974334`\ k\_w[3]\^2 - 32\ k\_b[2]\ k\_w[3]\^2 + 
          0.16518057946996012`\ k\_w[4] - 
          0.715120525931336903`\ k\_w[2]\ k\_w[4] - 12\ k\_w[2]\^2\ k\_w[4] - 
          5.1891891891891877`\ k\_w[3]\ k\_w[4] - 2\ k\_w[4]\^2] + 
      4\ Log[1\/4\ 
            \((\(0.000483197733008909668`\[InvisibleSpace]\) + 
                0.0289286690490038189`\ k\_b[2] - 
                0.178576840516903878`\ k\_b[2]\^2 + 
                1.93937180423667054`\ k\_b[2]\^3 - 48\ k\_b[2]\^4 - 
                0.0374086544412226817`\ k\_b[3] + 
                2.29852131166958617`\ k\_b[2]\ k\_b[3] - 
                42.8108108108107821`\ k\_b[2]\^2\ k\_b[3] + 
                8.18590211833456038`\ k\_b[3]\^2 - 288\ k\_b[2]\ k\_b[3]\^2 - 
                0.319611882330279817`\ k\_b[4] + 
                9.94485025566107161`\ k\_b[2]\ k\_b[4] - 
                144\ k\_b[2]\^2\ k\_b[4] - 
                35.6756756756756621`\ k\_b[3]\ k\_b[4] - 68\ k\_b[4]\^2 + 
                0.419787574279904163`\ k\_b[5] - 
                14.270270270270271`\ k\_b[2]\ k\_b[5] - 
                96\ k\_b[3]\ k\_b[5] + 1.2027027027027024`\ k\_b[6] - 
                32\ k\_b[2]\ k\_b[6] - 1.18918918918918926`\ k\_b[7] - 
                2\ k\_b[8] + 0.00916837610003335967`\ k\_w[2] - 
                0.690970386215484566`\ k\_b[2]\ k\_w[2] + 
                10.5536888239590931`\ k\_b[2]\^2\ k\_w[2] + 
                1.36946478984462483`\ k\_b[3]\ k\_w[2] - 
                42.8108108108107821`\ k\_b[2]\ k\_b[3]\ k\_w[2] - 
                144\ k\_b[3]\^2\ k\_w[2] + 
                7.21621621621621756`\ k\_b[4]\ k\_w[2] - 
                192\ k\_b[2]\ k\_b[4]\ k\_w[2] - 
                10.7027027027026955`\ k\_b[5]\ k\_w[2] - 
                24\ k\_b[6]\ k\_w[2] - 0.159285741726564822`\ k\_w[2]\^2 + 
                2.90905770635500626`\ k\_b[2]\ k\_w[2]\^2 - 
                144\ k\_b[2]\^2\ k\_w[2]\^2 - 
                21.405405405405391`\ k\_b[3]\ k\_w[2]\^2 - 
                72\ k\_b[4]\ k\_w[2]\^2 + 2.63842220598977306`\ k\_w[2]\^3 - 
                18\ k\_w[2]\^4 + 0.0262671861226494485`\ k\_w[3] + 
                0.146802756006554684`\ k\_b[2]\ k\_w[3] + 
                3.51789627465303045`\ k\_b[3]\ k\_w[3] - 
                4.75675675675675702`\ k\_b[4]\ k\_w[3] - 
                16\ k\_b[5]\ k\_w[3] + 
                0.383086885278265221`\ k\_w[2]\ k\_w[3] - 
                14.270270270270271`\ k\_b[2]\ k\_w[2]\ k\_w[3] - 
                96\ k\_b[3]\ k\_w[2]\ k\_w[3] - 
                3.56756756756756798`\ k\_w[2]\^2\ k\_w[3] + 
                0.323228634039444573`\ k\_w[3]\^2 - 32\ k\_b[2]\ k\_w[3]\^2 - 
                0.0233324404893709713`\ k\_w[4] + 
                0.879474068663257568`\ k\_w[2]\ k\_w[4] - 
                12\ k\_w[2]\^2\ k\_w[4] - 
                1.18918918918918926`\ k\_w[3]\ k\_w[4] - 2\ k\_w[4]\^2)\)] + 
      2\ Log[1\/2\ 
            \((\(0.000734913609136817136`\[InvisibleSpace]\) + 
                0.0412286539633345583`\ k\_b[2] - 
                0.249717740364888962`\ k\_b[2]\^2 + 
                1.93937180423666877`\ k\_b[2]\^3 - 48\ k\_b[2]\^4 - 
                0.045679888876257797`\ k\_b[3] + 
                3.04139932481788122`\ k\_b[2]\ k\_b[3] - 
                42.8108108108108176`\ k\_b[2]\^2\ k\_b[3] + 
                9.32103725346969191`\ k\_b[3]\^2 - 288\ k\_b[2]\ k\_b[3]\^2 - 
                0.422197119137577647`\ k\_b[4] + 
                11.4583637691745821`\ k\_b[2]\ k\_b[4] - 
                144\ k\_b[2]\^2\ k\_b[4] - 
                35.6756756756756754`\ k\_b[3]\ k\_b[4] - 68\ k\_b[4]\^2 + 
                0.474206858428921584`\ k\_b[5] - 
                14.270270270270271`\ k\_b[2]\ k\_b[5] - 
                96\ k\_b[3]\ k\_b[5] + 1.39189189189189077`\ k\_b[6] - 
                32\ k\_b[2]\ k\_b[6] - 1.18918918918918903`\ k\_b[7] - 
                2\ k\_b[8] + 0.0119655061008494323`\ k\_w[2] - 
                0.892014746865397789`\ k\_b[2]\ k\_w[2] + 
                12.8239590942293624`\ k\_b[2]\^2\ k\_w[2] + 
                1.32454148816457095`\ k\_b[3]\ k\_w[2] - 
                42.8108108108108176`\ k\_b[2]\ k\_b[3]\ k\_w[2] - 
                144\ k\_b[3]\^2\ k\_w[2] + 
                8.35135135135135797`\ k\_b[4]\ k\_w[2] - 
                192\ k\_b[2]\ k\_b[4]\ k\_w[2] - 
                10.7027027027027044`\ k\_b[5]\ k\_w[2] - 
                24\ k\_b[6]\ k\_w[2] - 0.175800064668937512`\ k\_w[2]\^2 + 
                2.90905770635500005`\ k\_b[2]\ k\_w[2]\^2 - 
                144\ k\_b[2]\^2\ k\_w[2]\^2 - 
                21.4054054054054088`\ k\_b[3]\ k\_w[2]\^2 - 
                72\ k\_b[4]\ k\_w[2]\^2 + 3.2059897735573406`\ k\_w[2]\^3 - 
                18\ k\_w[2]\^4 + 0.0342189442693614953`\ k\_w[3] - 
                0.13077211616291251`\ k\_b[2]\ k\_w[3] + 
                4.27465303140978747`\ k\_b[3]\ k\_w[3] - 
                4.75675675675675613`\ k\_b[4]\ k\_w[3] - 
                16\ k\_b[5]\ k\_w[3] + 
                0.506899887469648469`\ k\_w[2]\ k\_w[3] - 
                14.270270270270271`\ k\_b[2]\ k\_w[2]\ k\_w[3] - 
                96\ k\_b[3]\ k\_w[2]\ k\_w[3] - 
                3.56756756756756798`\ k\_w[2]\^2\ k\_w[3] + 
                0.323228634039444617`\ k\_w[3]\^2 - 32\ k\_b[2]\ k\_w[3]\^2 - 
                0.0169803981621643025`\ k\_w[4] + 
                1.06866325785244686`\ k\_w[2]\ k\_w[4] - 
                12\ k\_w[2]\^2\ k\_w[4] - 
                1.18918918918918903`\ k\_w[3]\ k\_w[4] - 2\ k\_w[4]\^2)\)] + 
      4\ Log[1\/4\ 
            \((\(0.000149469165410756037`\[InvisibleSpace]\) + 
                0.0224977535908623149`\ k\_b[2] + 
                0.595187793364604278`\ k\_b[2]\^2 - 
                2.92549306062819383`\ k\_b[2]\^3 - 48\ k\_b[2]\^4 - 
                0.174821008555943802`\ k\_b[3] - 
                2.76137642390381587`\ k\_b[2]\ k\_b[3] + 
                101.189189189189177`\ k\_b[2]\^2\ k\_b[3] - 
                7.38166544923301515`\ k\_b[3]\^2 - 288\ k\_b[2]\ k\_b[3]\^2 + 
                0.524735935173125778`\ k\_b[4] - 
                8.37947406866326005`\ k\_b[2]\ k\_b[4] - 
                144\ k\_b[2]\^2\ k\_b[4] + 
                84.3243243243243334`\ k\_b[3]\ k\_b[4] - 68\ k\_b[4]\^2 - 
                0.481235069985983088`\ k\_b[5] + 
                33.7297297297297271`\ k\_b[2]\ k\_b[5] - 
                96\ k\_b[3]\ k\_b[5] - 0.986486486486486846`\ k\_b[6] - 
                32\ k\_b[2]\ k\_b[6] + 2.81081081081081087`\ k\_b[7] - 
                2\ k\_b[8] + 0.0153135555927467548`\ k\_w[2] + 
                0.681426115472469984`\ k\_b[2]\ k\_w[2] - 
                5.98685171658144987`\ k\_b[2]\^2\ k\_w[2] - 
                1.50672220796398903`\ k\_b[3]\ k\_w[2] + 
                101.189189189189177`\ k\_b[2]\ k\_b[3]\ k\_w[2] - 
                144\ k\_b[3]\^2\ k\_w[2] - 
                5.91891891891891397`\ k\_b[4]\ k\_w[2] - 
                192\ k\_b[2]\ k\_b[4]\ k\_w[2] + 
                25.2972972972972964`\ k\_b[5]\ k\_w[2] - 
                24\ k\_b[6]\ k\_w[2] + 0.320567376548759774`\ k\_w[2]\^2 - 
                4.3882395909422982`\ k\_b[2]\ k\_w[2]\^2 - 
                144\ k\_b[2]\^2\ k\_w[2]\^2 + 
                50.5945945945945929`\ k\_b[3]\ k\_w[2]\^2 - 
                72\ k\_b[4]\ k\_w[2]\^2 - 1.49671292914536246`\ k\_w[2]\^3 - 
                18\ k\_w[2]\^4 - 0.0230898995279430074`\ k\_w[3] - 
                0.0840226640080545905`\ k\_b[2]\ k\_w[3] - 
                1.99561723886048358`\ k\_b[3]\ k\_w[3] + 
                11.2432432432432438`\ k\_b[4]\ k\_w[3] - 
                16\ k\_b[5]\ k\_w[3] - 
                0.460229403983969742`\ k\_w[2]\ k\_w[3] + 
                33.7297297297297271`\ k\_b[2]\ k\_w[2]\ k\_w[3] - 
                96\ k\_b[3]\ k\_w[2]\ k\_w[3] + 
                8.43243243243243156`\ k\_w[2]\^2\ k\_w[3] - 
                0.487582176771366349`\ k\_w[3]\^2 - 32\ k\_b[2]\ k\_w[3]\^2 + 
                0.00765782662215252951`\ k\_w[4] - 
                0.498904309715120852`\ k\_w[2]\ k\_w[4] - 
                12\ k\_w[2]\^2\ k\_w[4] + 
                2.81081081081081087`\ k\_w[3]\ k\_w[4] - 2\ k\_w[4]\^2)\)] + 
      2\ Log[1\/2\ 
            \((\(0.000200676194301478005`\[InvisibleSpace]\) + 
                0.0291336418485802806`\ k\_b[2] + 
                0.738466572508978558`\ k\_b[2]\^2 - 
                2.92549306062819436`\ k\_b[2]\^3 - 48\ k\_b[2]\^4 - 
                0.223313040457151723`\ k\_b[3] - 
                3.73654077744654999`\ k\_b[2]\ k\_b[3] + 
                101.189189189189177`\ k\_b[2]\^2\ k\_b[3] - 
                6.57085463842220018`\ k\_b[3]\^2 - 288\ k\_b[2]\ k\_b[3]\^2 + 
                0.675442704762291068`\ k\_b[4] - 
                7.29839298758217669`\ k\_b[2]\ k\_b[4] - 
                144\ k\_b[2]\^2\ k\_b[4] + 
                84.3243243243243334`\ k\_b[3]\ k\_b[4] - 68\ k\_b[4]\^2 - 
                0.709503879335875708`\ k\_b[5] + 
                33.7297297297297271`\ k\_b[2]\ k\_b[5] - 
                96\ k\_b[3]\ k\_b[5] - 0.851351351351352469`\ k\_b[6] - 
                32\ k\_b[2]\ k\_b[6] + 2.81081081081081087`\ k\_b[7] - 
                2\ k\_b[8] + 0.020163027371520501`\ k\_w[2] + 
                0.918628255523404568`\ k\_b[2]\ k\_w[2] - 
                4.36523009495982705`\ k\_b[2]\^2\ k\_w[2] - 
                2.38875288729196366`\ k\_b[3]\ k\_w[2] + 
                101.189189189189177`\ k\_b[2]\ k\_b[3]\ k\_w[2] - 
                144\ k\_b[3]\^2\ k\_w[2] - 
                5.10810810810809901`\ k\_b[4]\ k\_w[2] - 
                192\ k\_b[2]\ k\_b[4]\ k\_w[2] + 
                25.2972972972972964`\ k\_b[5]\ k\_w[2] - 
                24\ k\_b[6]\ k\_w[2] + 0.414342671200606549`\ k\_w[2]\^2 - 
                4.38823959094229376`\ k\_b[2]\ k\_w[2]\^2 - 
                144\ k\_b[2]\^2\ k\_w[2]\^2 + 
                50.5945945945945929`\ k\_b[3]\ k\_w[2]\^2 - 
                72\ k\_b[4]\ k\_w[2]\^2 - 1.09130752373995676`\ k\_w[2]\^3 - 
                18\ k\_w[2]\^4 - 0.0319642038166353881`\ k\_w[3] - 
                0.346988332379128516`\ k\_b[2]\ k\_w[3] - 
                1.45507669831994324`\ k\_b[3]\ k\_w[3] + 
                11.2432432432432438`\ k\_b[4]\ k\_w[3] - 
                16\ k\_b[5]\ k\_w[3] - 
                0.622756796241092303`\ k\_w[2]\ k\_w[3] + 
                33.7297297297297271`\ k\_b[2]\ k\_w[2]\ k\_w[3] - 
                96\ k\_b[3]\ k\_w[2]\ k\_w[3] + 
                8.43243243243243156`\ k\_w[2]\^2\ k\_w[3] - 
                0.487582176771366615`\ k\_w[3]\^2 - 32\ k\_b[2]\ k\_w[3]\^2 + 
                0.0150364616487057372`\ k\_w[4] - 
                0.36376917457998581`\ k\_w[2]\ k\_w[4] - 
                12\ k\_w[2]\^2\ k\_w[4] + 
                2.81081081081081087`\ k\_w[3]\ k\_w[4] - 2\ k\_w[4]\^2)\)] + 
      9\ Log[1\/9\ 
            \((\(0.0000481622866323547249`\[InvisibleSpace]\) + 
                0.0101887288815855203`\ k\_b[2] + 
                0.562078778183944827`\ k\_b[2]\^2 + 
                8.67896274653031518`\ k\_b[2]\^3 + 24\ k\_b[2]\^4 - 
                0.107022131178640433`\ k\_b[3] - 
                7.65108680630959891`\ k\_b[2]\ k\_b[3] - 
                86.5945945945945894`\ k\_b[2]\^2\ k\_b[3] + 
                19.3800219138057023`\ k\_b[3]\^2 + 144\ k\_b[2]\ k\_b[3]\^2 + 
                0.523839167232697722`\ k\_b[4] + 
                21.5005478451424414`\ k\_b[2]\ k\_b[4] + 
                72\ k\_b[2]\^2\ k\_b[4] - 
                72.1621621621621578`\ k\_b[3]\ k\_b[4] + 34\ k\_b[4]\^2 - 
                1.47705960160306393`\ k\_b[5] - 
                28.8648648648648666`\ k\_b[2]\ k\_b[5] + 
                48\ k\_b[3]\ k\_b[5] + 2.50675675675675657`\ k\_b[6] + 
                16\ k\_b[2]\ k\_b[6] - 2.40540540540540526`\ k\_b[7] + 
                k\_b[8] + 0.00735812465576098784`\ k\_w[2] + 
                0.728399334422176192`\ k\_b[2]\ k\_w[2] + 
                12.7231555880204538`\ k\_b[2]\^2\ k\_w[2] - 
                5.03681420646358279`\ k\_b[3]\ k\_w[2] - 
                86.5945945945945894`\ k\_b[2]\ k\_b[3]\ k\_w[2] + 
                72\ k\_b[3]\^2\ k\_w[2] + 
                15.0405405405405412`\ k\_b[4]\ k\_w[2] + 
                96\ k\_b[2]\ k\_b[4]\ k\_w[2] - 
                21.6486486486486473`\ k\_b[5]\ k\_w[2] + 
                12\ k\_b[6]\ k\_w[2] + 0.322678821349926803`\ k\_w[2]\^2 + 
                13.0184441197954714`\ k\_b[2]\ k\_w[2]\^2 + 
                72\ k\_b[2]\^2\ k\_w[2]\^2 - 
                43.2972972972972947`\ k\_b[3]\ k\_w[2]\^2 + 
                36\ k\_b[4]\ k\_w[2]\^2 + 3.18078889700511346`\ k\_w[2]\^3 + 
                9\ k\_w[2]\^4 - 0.0166932859052159372`\ k\_w[3] - 
                0.807513868872524831`\ k\_b[2]\ k\_w[3] + 
                4.24105186267348521`\ k\_b[3]\ k\_w[3] - 
                9.62162162162162104`\ k\_b[4]\ k\_w[3] + 
                8\ k\_b[5]\ k\_w[3] - 
                1.27518113438493263`\ k\_w[2]\ k\_w[3] - 
                28.8648648648648666`\ k\_b[2]\ k\_w[2]\ k\_w[3] + 
                48\ k\_b[3]\ k\_w[2]\ k\_w[3] - 
                7.21621621621621667`\ k\_w[2]\^2\ k\_w[3] + 
                1.44649379108838571`\ k\_w[3]\^2 + 16\ k\_b[2]\ k\_w[3]\^2 + 
                0.0138798107526514534`\ k\_w[4] + 
                1.0602629656683713`\ k\_w[2]\ k\_w[4] + 
                6\ k\_w[2]\^2\ k\_w[4] - 
                2.40540540540540526`\ k\_w[3]\ k\_w[4] + k\_w[4]\^2)\)] + 
      Log[\(0.00188326890036771708`\[InvisibleSpace]\) + 
          0.113929393801356004`\ k\_b[2] - 
          0.103608761467130938`\ k\_b[2]\^2 - 
          11.0138787436084806`\ k\_b[2]\^3 + 96\ k\_b[2]\^4 - 
          0.462180713165820566`\ k\_b[3] + 
          12.5439361933153148`\ k\_b[2]\ k\_b[3] - 
          58.3783783783784393`\ k\_b[2]\^2\ k\_b[3] - 
          24.8042366691015203`\ k\_b[3]\^2 + 576\ k\_b[2]\ k\_b[3]\^2 + 
          0.129846235195374193`\ k\_b[4] - 
          27.5653761869978097`\ k\_b[2]\ k\_b[4] + 288\ k\_b[2]\^2\ k\_b[4] - 
          48.6486486486486313`\ k\_b[3]\ k\_b[4] + 136\ k\_b[4]\^2 + 
          2.25757605669950311`\ k\_b[5] - 
          19.4594594594594667`\ k\_b[2]\ k\_b[5] + 192\ k\_b[3]\ k\_b[5] - 
          3.21621621621621933`\ k\_b[6] + 64\ k\_b[2]\ k\_b[6] - 
          1.62162162162162193`\ k\_b[7] + 4\ k\_b[8] + 
          0.103770764320803321`\ k\_w[2] + 
          0.544951847786823151`\ k\_b[2]\ k\_w[2] - 
          16.5668371073776583`\ k\_b[2]\^2\ k\_w[2] + 
          7.27348824353938461`\ k\_b[3]\ k\_w[2] - 
          58.3783783783784393`\ k\_b[2]\ k\_b[3]\ k\_w[2] + 
          288\ k\_b[3]\^2\ k\_w[2] - 19.2972972972973053`\ k\_b[4]\ k\_w[2] + 
          384\ k\_b[2]\ k\_b[4]\ k\_w[2] - 
          14.5945945945946098`\ k\_b[5]\ k\_w[2] + 48\ k\_b[6]\ k\_w[2] + 
          0.114753348298252078`\ k\_w[2]\^2 - 
          16.5208181154127009`\ k\_b[2]\ k\_w[2]\^2 + 
          288\ k\_b[2]\^2\ k\_w[2]\^2 - 
          29.1891891891892196`\ k\_b[3]\ k\_w[2]\^2 + 
          144\ k\_b[4]\ k\_w[2]\^2 - 4.14170927684441458`\ k\_w[2]\^3 + 
          36\ k\_w[2]\^4 - 0.133058137279359511`\ k\_w[3] + 
          0.667680097921150128`\ k\_b[2]\ k\_w[3] - 
          5.52227903579254864`\ k\_b[3]\ k\_w[3] - 
          6.48648648648648773`\ k\_b[4]\ k\_w[3] + 32\ k\_b[5]\ k\_w[3] + 
          2.09065603221921714`\ k\_w[2]\ k\_w[3] - 
          19.4594594594594667`\ k\_b[2]\ k\_w[2]\ k\_w[3] + 
          192\ k\_b[3]\ k\_w[2]\ k\_w[3] - 
          4.86486486486486668`\ k\_w[2]\^2\ k\_w[3] - 
          1.83564645726807817`\ k\_w[3]\^2 + 64\ k\_b[2]\ k\_w[3]\^2 + 
          0.0555192430106058232`\ k\_w[4] - 
          1.38056975894813716`\ k\_w[2]\ k\_w[4] + 24\ k\_w[2]\^2\ k\_w[4] - 
          1.62162162162162193`\ k\_w[3]\ k\_w[4] + 4\ k\_w[4]\^2] + 
      Log[\(0.000662863255299874509`\[InvisibleSpace]\) + 
          0.0612565181389532842`\ k\_b[2] + 
          0.0402129272778585811`\ k\_b[2]\^2 - 
          11.0138787436084806`\ k\_b[2]\^3 + 96\ k\_b[2]\^4 - 
          0.274918919755329627`\ k\_b[3] + 
          9.12538250449134835`\ k\_b[2]\ k\_b[3] - 
          58.3783783783784304`\ k\_b[2]\^2\ k\_b[3] - 
          19.939371804236682`\ k\_b[3]\^2 + 576\ k\_b[2]\ k\_b[3]\^2 + 
          0.0786153110645233965`\ k\_b[4] - 
          21.0788897005113406`\ k\_b[2]\ k\_b[4] + 288\ k\_b[2]\^2\ k\_b[4] - 
          48.648648648648658`\ k\_b[3]\ k\_b[4] + 136\ k\_b[4]\^2 + 
          1.57459577912463295`\ k\_b[5] - 
          19.4594594594594667`\ k\_b[2]\ k\_b[5] + 192\ k\_b[3]\ k\_b[5] - 
          2.40540540540540614`\ k\_b[6] + 64\ k\_b[2]\ k\_b[6] - 
          1.62162162162162148`\ k\_b[7] + 4\ k\_b[8] + 
          0.039352353643720086`\ k\_w[2] + 
          0.175526542276783441`\ k\_b[2]\ k\_w[2] - 
          6.83710737764791787`\ k\_b[2]\^2\ k\_w[2] + 
          4.88488342250212514`\ k\_b[3]\ k\_w[2] - 
          58.3783783783784304`\ k\_b[2]\ k\_b[3]\ k\_w[2] + 
          288\ k\_b[3]\^2\ k\_w[2] - 14.4324324324324448`\ k\_b[4]\ k\_w[2] + 
          384\ k\_b[2]\ k\_b[4]\ k\_w[2] - 
          14.5945945945946071`\ k\_b[5]\ k\_w[2] + 48\ k\_b[6]\ k\_w[2] + 
          0.0480741782589647215`\ k\_w[2]\^2 - 
          16.5208181154127098`\ k\_b[2]\ k\_w[2]\^2 + 
          288\ k\_b[2]\^2\ k\_w[2]\^2 - 
          29.1891891891892143`\ k\_b[3]\ k\_w[2]\^2 + 
          144\ k\_b[4]\ k\_w[2]\^2 - 1.70927684441197946`\ k\_w[2]\^3 + 
          36\ k\_w[2]\^4 - 0.0357672695257353234`\ k\_w[3] + 
          0.214794780170967092`\ k\_b[2]\ k\_w[3] - 
          2.27903579254930477`\ k\_b[3]\ k\_w[3] - 
          6.48648648648648595`\ k\_b[4]\ k\_w[3] + 32\ k\_b[5]\ k\_w[3] + 
          1.52089708408189183`\ k\_w[2]\ k\_w[3] - 
          19.4594594594594667`\ k\_b[2]\ k\_w[2]\ k\_w[3] + 
          192\ k\_b[3]\ k\_w[2]\ k\_w[3] - 
          4.86486486486486668`\ k\_w[2]\^2\ k\_w[3] - 
          1.83564645726807782`\ k\_w[3]\^2 + 64\ k\_b[2]\ k\_w[3]\^2 + 
          0.00932257154001178101`\ k\_w[4] - 
          0.569758948137326193`\ k\_w[2]\ k\_w[4] + 24\ k\_w[2]\^2\ k\_w[4] - 
          1.62162162162162148`\ k\_w[3]\ k\_w[4] + 4\ k\_w[4]\^2] + 
      2\ Log[1\/2\ 
            \((\(0.0086998835071334728`\[InvisibleSpace]\) + 
                0.00195234546245021114`\ k\_b[2] - 
                0.660357621356971691`\ k\_b[2]\^2 + 
                3.25639152666178866`\ k\_b[2]\^3 + 96\ k\_b[2]\^4 + 
                0.606423985149852207`\ k\_b[3] - 
                15.1814107752749594`\ k\_b[2]\ k\_b[3] + 
                229.621621621621629`\ k\_b[2]\^2\ k\_b[3] + 
                2.11468224981737229`\ k\_b[3]\^2 + 576\ k\_b[2]\ k\_b[3]\^2 - 
                0.318695805749877436`\ k\_b[4] + 
                1.19138056975893746`\ k\_b[2]\ k\_b[4] + 
                288\ k\_b[2]\^2\ k\_b[4] + 
                191.351351351351333`\ k\_b[3]\ k\_b[4] + 136\ k\_b[4]\^2 - 
                3.47872781473949999`\ k\_b[5] + 
                76.5405405405405492`\ k\_b[2]\ k\_b[5] + 
                192\ k\_b[3]\ k\_b[5] + 0.081081081081081141`\ k\_b[6] + 
                64\ k\_b[2]\ k\_b[6] + 6.37837837837837717`\ k\_b[7] + 
                4\ k\_b[8] + 0.0269392640647680448`\ k\_w[2] + 
                0.0344490147858158568`\ k\_b[2]\ k\_w[2] - 
                5.53981008035063382`\ k\_b[2]\^2\ k\_w[2] - 
                13.2816615007995775`\ k\_b[3]\ k\_w[2] + 
                229.621621621621629`\ k\_b[2]\ k\_b[3]\ k\_w[2] + 
                288\ k\_b[3]\^2\ k\_w[2] + 
                0.486486486486502833`\ k\_b[4]\ k\_w[2] + 
                384\ k\_b[2]\ k\_b[4]\ k\_w[2] + 
                57.4054054054054052`\ k\_b[5]\ k\_w[2] + 
                48\ k\_b[6]\ k\_w[2] - 0.720113293361669803`\ k\_w[2]\^2 + 
                4.8845872899926892`\ k\_b[2]\ k\_w[2]\^2 + 
                288\ k\_b[2]\^2\ k\_w[2]\^2 + 
                114.810810810810814`\ k\_b[3]\ k\_w[2]\^2 + 
                144\ k\_b[4]\ k\_w[2]\^2 - 1.38495252008765845`\ k\_w[2]\^3 + 
                36\ k\_w[2]\^4 + 0.168317118101581648`\ k\_w[3] - 
                3.79397074210806728`\ k\_b[2]\ k\_w[3] - 
                1.84660336011687498`\ k\_b[3]\ k\_w[3] + 
                25.5135135135135104`\ k\_b[4]\ k\_w[3] + 
                32\ k\_b[5]\ k\_w[3] - 
                2.53023512921248228`\ k\_w[2]\ k\_w[3] + 
                76.5405405405405492`\ k\_b[2]\ k\_w[2]\ k\_w[3] + 
                192\ k\_b[3]\ k\_w[2]\ k\_w[3] + 
                19.1351351351351368`\ k\_w[2]\^2\ k\_w[3] + 
                0.542731921110298998`\ k\_w[3]\^2 + 64\ k\_b[2]\ k\_w[3]\^2 - 
                0.129978160894394845`\ k\_w[4] - 
                0.461650840029218745`\ k\_w[2]\ k\_w[4] + 
                24\ k\_w[2]\^2\ k\_w[4] + 
                6.37837837837837717`\ k\_w[3]\ k\_w[4] + 4\ k\_w[4]\^2)\)] + 
      Log[\(0.0030621400380700714`\[InvisibleSpace]\) + 
          0.0630954653308477109`\ k\_b[2] - 1.2075512722759667`\ k\_b[2]\^2 + 
          3.25639152666179221`\ k\_b[2]\^3 + 96\ k\_b[2]\^4 + 
          0.372210248976705848`\ k\_b[3] - 
          14.0594239235583522`\ k\_b[2]\ k\_b[3] + 
          229.621621621621629`\ k\_b[2]\^2\ k\_b[3] + 
          6.97954711468224786`\ k\_b[3]\^2 + 576\ k\_b[2]\ k\_b[3]\^2 - 
          0.567881441348953153`\ k\_b[4] + 
          7.67786705624543941`\ k\_b[2]\ k\_b[4] + 288\ k\_b[2]\^2\ k\_b[4] + 
          191.351351351351368`\ k\_b[3]\ k\_b[4] + 136\ k\_b[4]\^2 - 
          2.54008647069275017`\ k\_b[5] + 
          76.5405405405405492`\ k\_b[2]\ k\_b[5] + 192\ k\_b[3]\ k\_b[5] + 
          0.891891891891891219`\ k\_b[6] + 64\ k\_b[2]\ k\_b[6] + 
          6.37837837837837806`\ k\_b[7] + 4\ k\_b[8] - 
          0.015749156499406034`\ k\_w[2] + 
          0.107682584367087219`\ k\_b[2]\ k\_w[2] + 
          4.18991964937910488`\ k\_b[2]\^2\ k\_w[2] - 
          8.21080686237733559`\ k\_b[3]\ k\_w[2] + 
          229.621621621621629`\ k\_b[2]\ k\_b[3]\ k\_w[2] + 
          288\ k\_b[3]\^2\ k\_w[2] + 5.35135135135134376`\ k\_b[4]\ k\_w[2] + 
          384\ k\_b[2]\ k\_b[4]\ k\_w[2] + 
          57.4054054054054052`\ k\_b[5]\ k\_w[2] + 48\ k\_b[6]\ k\_w[2] - 
          0.658961930165017584`\ k\_w[2]\^2 + 
          4.88458728999269453`\ k\_b[2]\ k\_w[2]\^2 + 
          288\ k\_b[2]\^2\ k\_w[2]\^2 + 
          114.810810810810814`\ k\_b[3]\ k\_w[2]\^2 + 
          144\ k\_b[4]\ k\_w[2]\^2 + 1.04747991234477622`\ k\_w[2]\^3 + 
          36\ k\_w[2]\^4 + 0.0540509211206392059`\ k\_w[3] - 
          0.787396600398791335`\ k\_b[2]\ k\_w[3] + 
          1.39663988312637155`\ k\_b[3]\ k\_w[3] + 
          25.5135135135135104`\ k\_b[4]\ k\_w[3] + 32\ k\_b[5]\ k\_w[3] - 
          2.34323732059305145`\ k\_w[2]\ k\_w[3] + 
          76.5405405405405492`\ k\_b[2]\ k\_w[2]\ k\_w[3] + 
          192\ k\_b[3]\ k\_w[2]\ k\_w[3] + 
          19.1351351351351368`\ k\_w[2]\^2\ k\_w[3] + 
          0.54273192111030033`\ k\_w[3]\^2 + 64\ k\_b[2]\ k\_w[3]\^2 - 
          0.0183954313423446222`\ k\_w[4] + 
          0.349159970781592887`\ k\_w[2]\ k\_w[4] + 24\ k\_w[2]\^2\ k\_w[4] + 
          6.37837837837837806`\ k\_w[3]\ k\_w[4] + 4\ k\_w[4]\^2] + 
      Log[\(0.00482641813209060099`\[InvisibleSpace]\) + 
          0.0165999087677862888`\ k\_b[2] - 
          0.686219860513584301`\ k\_b[2]\^2 + 
          3.25639152666178866`\ k\_b[2]\^3 + 96\ k\_b[2]\^4 + 
          0.398981828366097026`\ k\_b[3] - 
          12.5955817029593708`\ k\_b[2]\ k\_b[3] + 
          229.621621621621629`\ k\_b[2]\^2\ k\_b[3] + 
          5.35792549306063037`\ k\_b[3]\^2 + 576\ k\_b[2]\ k\_b[3]\^2 - 
          0.380587500220098959`\ k\_b[4] + 
          5.51570489408324426`\ k\_b[2]\ k\_b[4] + 288\ k\_b[2]\^2\ k\_b[4] + 
          191.351351351351333`\ k\_b[3]\ k\_b[4] + 136\ k\_b[4]\^2 - 
          2.77018143051744392`\ k\_b[5] + 
          76.5405405405405492`\ k\_b[2]\ k\_b[5] + 192\ k\_b[3]\ k\_b[5] + 
          0.621621621621617048`\ k\_b[6] + 64\ k\_b[2]\ k\_b[6] + 
          6.37837837837837895`\ k\_b[7] + 4\ k\_b[8] + 
          0.0135238016330524413`\ k\_w[2] - 
          0.112432709889919602`\ k\_b[2]\ k\_w[2] + 
          0.946676406135855685`\ k\_b[2]\^2\ k\_w[2] - 
          10.3232977316249696`\ k\_b[3]\ k\_w[2] + 
          229.621621621621629`\ k\_b[2]\ k\_b[3]\ k\_w[2] + 
          288\ k\_b[3]\^2\ k\_w[2] + 3.72972972972971827`\ k\_b[4]\ k\_w[2] + 
          384\ k\_b[2]\ k\_b[4]\ k\_w[2] + 
          57.4054054054054052`\ k\_b[5]\ k\_w[2] + 48\ k\_b[6]\ k\_w[2] - 
          0.633543889772542989`\ k\_w[2]\^2 + 
          4.88458728999269808`\ k\_b[2]\ k\_w[2]\^2 + 
          288\ k\_b[2]\^2\ k\_w[2]\^2 + 
          114.810810810810814`\ k\_b[3]\ k\_w[2]\^2 + 
          144\ k\_b[4]\ k\_w[2]\^2 + 0.236669101533963921`\ k\_w[2]\^3 + 
          36\ k\_w[2]\^4 + 0.125367232792902205`\ k\_w[3] - 
          2.68367125343020251`\ k\_b[2]\ k\_w[3] + 
          0.315558802045289077`\ k\_b[3]\ k\_w[3] + 
          25.5135135135135149`\ k\_b[4]\ k\_w[3] + 32\ k\_b[5]\ k\_w[3] - 
          2.09926361715989084`\ k\_w[2]\ k\_w[3] + 
          76.5405405405405492`\ k\_b[2]\ k\_w[2]\ k\_w[3] + 
          192\ k\_b[3]\ k\_w[2]\ k\_w[3] + 
          19.1351351351351368`\ k\_w[2]\^2\ k\_w[3] + 
          0.542731921110300952`\ k\_w[3]\^2 + 64\ k\_b[2]\ k\_w[3]\^2 - 
          0.0968113198385837669`\ k\_w[4] + 
          0.0788897005113222693`\ k\_w[2]\ k\_w[4] + 
          24\ k\_w[2]\^2\ k\_w[4] + 6.37837837837837895`\ k\_w[3]\ k\_w[4] + 
          4\ k\_w[4]\^2] + 
      Log[\(0.00287701065668348299`\[InvisibleSpace]\) + 
          0.0602524219925507864`\ k\_b[2] - 
          1.16923172555612997`\ k\_b[2]\^2 + 
          3.25639152666179132`\ k\_b[2]\^3 + 96\ k\_b[2]\^4 + 
          0.351743624177663161`\ k\_b[3] - 
          13.638678854164643`\ k\_b[2]\ k\_b[3] + 
          229.621621621621629`\ k\_b[2]\^2\ k\_b[3] + 
          7.30387143900657953`\ k\_b[3]\^2 + 576\ k\_b[2]\ k\_b[3]\^2 - 
          0.566973301653376449`\ k\_b[4] + 
          8.11029948867785854`\ k\_b[2]\ k\_b[4] + 288\ k\_b[2]\^2\ k\_b[4] + 
          191.351351351351368`\ k\_b[3]\ k\_b[4] + 136\ k\_b[4]\^2 - 
          2.47361459341006284`\ k\_b[5] + 
          76.5405405405405492`\ k\_b[2]\ k\_b[5] + 192\ k\_b[3]\ k\_b[5] + 
          0.945945945945944188`\ k\_b[6] + 64\ k\_b[2]\ k\_b[6] + 
          6.37837837837837895`\ k\_b[7] + 4\ k\_b[8] - 
          0.0137679600701339022`\ k\_w[2] + 
          0.0529276833740530694`\ k\_b[2]\ k\_w[2] + 
          4.83856829802775401`\ k\_b[2]\^2\ k\_w[2] - 
          8.02234813337807217`\ k\_b[3]\ k\_w[2] + 
          229.621621621621629`\ k\_b[2]\ k\_b[3]\ k\_w[2] + 
          288\ k\_b[3]\^2\ k\_w[2] + 5.67567567567565944`\ k\_b[4]\ k\_w[2] + 
          384\ k\_b[2]\ k\_b[4]\ k\_w[2] + 
          57.4054054054054052`\ k\_b[5]\ k\_w[2] + 48\ k\_b[6]\ k\_w[2] - 
          0.642881934903138052`\ k\_w[2]\^2 + 
          4.88458728999268743`\ k\_b[2]\ k\_w[2]\^2 + 
          288\ k\_b[2]\^2\ k\_w[2]\^2 + 
          114.810810810810814`\ k\_b[3]\ k\_w[2]\^2 + 
          144\ k\_b[4]\ k\_w[2]\^2 + 1.2096420745069385`\ k\_w[2]\^3 + 
          36\ k\_w[2]\^4 + 0.0550931208035906916`\ k\_w[3] - 
          0.802005804197183813`\ k\_b[2]\ k\_w[3] + 
          1.61285609934258644`\ k\_b[3]\ k\_w[3] + 
          25.5135135135135149`\ k\_b[4]\ k\_w[3] + 32\ k\_b[5]\ k\_w[3] - 
          2.27311314236076622`\ k\_w[2]\ k\_w[3] + 
          76.5405405405405492`\ k\_b[2]\ k\_w[2]\ k\_w[3] + 
          192\ k\_b[3]\ k\_w[2]\ k\_w[3] + 
          19.1351351351351368`\ k\_w[2]\^2\ k\_w[3] + 
          0.542731921110298998`\ k\_w[3]\^2 + 64\ k\_b[2]\ k\_w[3]\^2 - 
          0.0194220240416911877`\ k\_w[4] + 
          0.403214024835646611`\ k\_w[2]\ k\_w[4] + 24\ k\_w[2]\^2\ k\_w[4] + 
          6.37837837837837895`\ k\_w[3]\ k\_w[4] + 4\ k\_w[4]\^2] + 
      Log[\(0.0222959533275924393`\[InvisibleSpace]\) - 
          0.381802238588759745`\ k\_b[2] + 1.02145786834748975`\ k\_b[2]\^2 + 
          65.526661796932073`\ k\_b[2]\^3 + 96\ k\_b[2]\^4 - 
          1.43065247199550409`\ k\_b[3] + 
          59.8952875446666421`\ k\_b[2]\ k\_b[3] + 
          517.621621621621663`\ k\_b[2]\^2\ k\_b[3] + 
          152.276844411979546`\ k\_b[3]\^2 + 576\ k\_b[2]\ k\_b[3]\^2 + 
          1.61279887373603862`\ k\_b[4] + 
          170.272461650840023`\ k\_b[2]\ k\_b[4] + 288\ k\_b[2]\^2\ k\_b[4] + 
          431.351351351351386`\ k\_b[3]\ k\_b[4] + 136\ k\_b[4]\^2 + 
          12.2502714548003144`\ k\_b[5] + 
          172.54054054054051`\ k\_b[2]\ k\_b[5] + 192\ k\_b[3]\ k\_b[5] + 
          19.9189189189189193`\ k\_b[6] + 64\ k\_b[2]\ k\_b[6] + 
          14.378378378378378`\ k\_b[7] + 4\ k\_b[8] - 
          0.233328710691849749`\ k\_w[2] + 
          3.30620981868686936`\ k\_b[2]\ k\_w[2] + 
          107.973703433162881`\ k\_b[2]\^2\ k\_w[2] + 
          43.5539849564685166`\ k\_b[3]\ k\_w[2] + 
          517.621621621621663`\ k\_b[2]\ k\_b[3]\ k\_w[2] + 
          288\ k\_b[3]\^2\ k\_w[2] + 119.51351351351349`\ k\_b[4]\ k\_w[2] + 
          384\ k\_b[2]\ k\_b[4]\ k\_w[2] + 
          129.405405405405415`\ k\_b[5]\ k\_w[2] + 48\ k\_b[6]\ k\_w[2] + 
          1.08381737214678963`\ k\_w[2]\^2 + 
          98.2899926953980873`\ k\_b[2]\ k\_w[2]\^2 + 
          288\ k\_b[2]\^2\ k\_w[2]\^2 + 
          258.810810810810831`\ k\_b[3]\ k\_w[2]\^2 + 
          144\ k\_b[4]\ k\_w[2]\^2 + 26.9934258582907204`\ k\_w[2]\^3 + 
          36\ k\_w[2]\^4 - 0.0757647670726376887`\ k\_w[3] + 
          9.07089412275679585`\ k\_b[2]\ k\_w[3] + 
          35.9912344777209636`\ k\_b[3]\ k\_w[3] + 
          57.5135135135135122`\ k\_b[4]\ k\_w[3] + 32\ k\_b[5]\ k\_w[3] + 
          9.98254792411111324`\ k\_w[2]\ k\_w[3] + 
          172.54054054054051`\ k\_b[2]\ k\_w[2]\ k\_w[3] + 
          192\ k\_b[3]\ k\_w[2]\ k\_w[3] + 
          43.1351351351351297`\ k\_w[2]\^2\ k\_w[3] + 
          10.9211102994886788`\ k\_w[3]\^2 + 64\ k\_b[2]\ k\_w[3]\^2 + 
          0.191029479324348336`\ k\_w[4] + 
          8.99780861943024135`\ k\_w[2]\ k\_w[4] + 24\ k\_w[2]\^2\ k\_w[4] + 
          14.378378378378378`\ k\_w[3]\ k\_w[4] + 4\ k\_w[4]\^2] + 
      Log[\(0.0259196529315976542`\[InvisibleSpace]\) - 
          0.202426406973152728`\ k\_b[2] + 1.99639945554303732`\ k\_b[2]\^2 - 
          34.9744338933528542`\ k\_b[2]\^3 + 384\ k\_b[2]\^4 + 
          2.74826054417402065`\ k\_b[3] - 
          80.202633605117235`\ k\_b[2]\ k\_b[3] + 
          918.486486486486697`\ k\_b[2]\^2\ k\_b[3] - 
          9.0547845142439769`\ k\_b[3]\^2 + 2304\ k\_b[2]\ k\_b[3]\^2 - 
          1.92595886906194699`\ k\_b[4] + 
          5.41417092768436702`\ k\_b[2]\ k\_b[4] + 
          1152\ k\_b[2]\^2\ k\_b[4] + 
          765.405405405405225`\ k\_b[3]\ k\_b[4] + 544\ k\_b[4]\^2 - 
          12.4978184905138833`\ k\_b[5] + 
          306.162162162162188`\ k\_b[2]\ k\_b[5] + 768\ k\_b[3]\ k\_b[5] + 
          1.40540540540539504`\ k\_b[6] + 256\ k\_b[2]\ k\_b[6] + 
          25.513513513513506`\ k\_b[7] + 16\ k\_b[8] + 
          0.324605569821688622`\ k\_w[2] - 
          8.77247579050038694`\ k\_b[2]\ k\_w[2] + 
          86.8137326515704543`\ k\_b[2]\^2\ k\_w[2] - 
          34.8855941405247893`\ k\_b[3]\ k\_w[2] + 
          918.486486486486697`\ k\_b[2]\ k\_b[3]\ k\_w[2] + 
          1152\ k\_b[3]\^2\ k\_w[2] + 
          8.43243243243236229`\ k\_b[4]\ k\_w[2] + 
          1536\ k\_b[2]\ k\_b[4]\ k\_w[2] + 
          229.621621621621674`\ k\_b[5]\ k\_w[2] + 192\ k\_b[6]\ k\_w[2] + 
          1.11007058625166088`\ k\_w[2]\^2 - 
          52.4616508400292591`\ k\_b[2]\ k\_w[2]\^2 + 
          1152\ k\_b[2]\^2\ k\_w[2]\^2 + 
          459.243243243243348`\ k\_b[3]\ k\_w[2]\^2 + 
          576\ k\_b[4]\ k\_w[2]\^2 + 21.7034331628926135`\ k\_w[2]\^3 + 
          144\ k\_w[2]\^4 - 0.187590333213894844`\ k\_w[3] + 
          3.47714844135589551`\ k\_b[2]\ k\_w[3] + 
          28.9379108838568388`\ k\_b[3]\ k\_w[3] + 
          102.054054054054033`\ k\_b[4]\ k\_w[3] + 128\ k\_b[5]\ k\_w[3] - 
          13.3671056008528621`\ k\_w[2]\ k\_w[3] + 
          306.162162162162188`\ k\_b[2]\ k\_w[2]\ k\_w[3] + 
          768\ k\_b[3]\ k\_w[2]\ k\_w[3] + 
          76.5405405405405492`\ k\_w[2]\^2\ k\_w[3] - 
          5.82907231555880045`\ k\_w[3]\^2 + 256\ k\_b[2]\ k\_w[3]\^2 + 
          0.0372902861600468682`\ k\_w[4] + 
          7.23447772096420926`\ k\_w[2]\ k\_w[4] + 96\ k\_w[2]\^2\ k\_w[4] + 
          25.513513513513506`\ k\_w[3]\ k\_w[4] + 16\ k\_w[4]\^2]\)], "Output",\

  CellLabel->"Out[274]="]
}, Closed]],

Cell[TextData[
"Note that the allele frequencies are supplied as a function \
pp[1],\[Ellipsis]"], "Text"],

Cell["\<\
This version can be faster, because it stores expresions for \
genotype frequencies:\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(LogLikelihoodDisequilibriumReduced[1063, {k\_w, k\_b}, 1&, pp, 
      Range[4], gdt]\)], "Input",
  CellLabel->"In[278]:="],

Cell[BoxData[
    \(37\ Log[37] + 
      2\ Log[1\/2\ 
            \((\(0.0201100755503774974`\[InvisibleSpace]\) - 
                0.349455417861351591`\ k\_b[2] + 
                5.51979525771798584`\ k\_b[2]\^2 - 
                44.783053323593851`\ k\_b[2]\^3 - 192\ k\_b[2]\^4 + 
                0.815872881324035148`\ k\_b[3] + 
                5.79306260241252068`\ k\_b[2]\ k\_b[3] - 
                747.243243243243249`\ k\_b[2]\^2\ k\_b[3] - 
                121.959094229364484`\ k\_b[3]\^2 - 
                1152\ k\_b[2]\ k\_b[3]\^2 + 4.58207405873881867`\ k\_b[4] - 
                140.22059897735577`\ k\_b[2]\ k\_b[4] - 
                576\ k\_b[2]\^2\ k\_b[4] - 
                622.702702702702559`\ k\_b[3]\ k\_b[4] - 272\ k\_b[4]\^2 - 
                0.681697036700689196`\ k\_b[5] - 
                249.081081081081068`\ k\_b[2]\ k\_b[5] - 
                384\ k\_b[3]\ k\_b[5] - 16.5945945945946`\ k\_b[6] - 
                128\ k\_b[2]\ k\_b[6] - 20.7567567567567579`\ k\_b[7] - 
                8\ k\_b[8] - 0.079318181796833862`\ k\_w[2] + 
                5.46652928963946926`\ k\_b[2]\ k\_w[2] - 
                109.569028487947406`\ k\_b[2]\^2\ k\_w[2] - 
                6.98671352141037971`\ k\_b[3]\ k\_w[2] - 
                747.243243243243249`\ k\_b[2]\ k\_b[3]\ k\_w[2] - 
                576\ k\_b[3]\^2\ k\_w[2] - 
                99.5675675675676252`\ k\_b[4]\ k\_w[2] - 
                768\ k\_b[2]\ k\_b[4]\ k\_w[2] - 
                186.810810810810821`\ k\_b[5]\ k\_w[2] - 
                96\ k\_b[6]\ k\_w[2] + 2.44526083938359573`\ k\_w[2]\^2 - 
                67.1745799853907676`\ k\_b[2]\ k\_w[2]\^2 - 
                576\ k\_b[2]\^2\ k\_w[2]\^2 - 
                373.621621621621624`\ k\_b[3]\ k\_w[2]\^2 - 
                288\ k\_b[4]\ k\_w[2]\^2 - 27.3922571219868515`\ k\_w[2]\^3 - 
                72\ k\_w[2]\^4 + 0.232625822030894457`\ k\_w[3] - 
                6.58882988174441486`\ k\_b[2]\ k\_w[3] - 
                36.5230094959824791`\ k\_b[3]\ k\_w[3] - 
                83.0270270270270316`\ k\_b[4]\ k\_w[3] - 
                64\ k\_b[5]\ k\_w[3] + 
                0.965510433735413897`\ k\_w[2]\ k\_w[3] - 
                249.081081081081068`\ k\_b[2]\ k\_w[2]\ k\_w[3] - 
                384\ k\_b[3]\ k\_w[2]\ k\_w[3] - 
                62.2702702702702648`\ k\_w[2]\^2\ k\_w[3] - 
                7.46384222059897162`\ k\_w[3]\^2 - 128\ k\_b[2]\ k\_w[3]\^2 - 
                0.104878929825132427`\ k\_w[4] - 
                9.13075237399561956`\ k\_w[2]\ k\_w[4] - 
                48\ k\_w[2]\^2\ k\_w[4] - 
                20.7567567567567579`\ k\_w[3]\ k\_w[4] - 8\ k\_w[4]\^2)\)] + 
      Log[\(0.0287370065111191319`\[InvisibleSpace]\) - 
          0.498631769306078176`\ k\_b[2] + 6.97889935816613338`\ k\_b[2]\^2 - 
          44.7830533235938421`\ k\_b[2]\^3 - 192\ k\_b[2]\^4 + 
          0.862692231422558819`\ k\_b[3] + 
          12.7879493810830568`\ k\_b[2]\ k\_b[3] - 
          747.243243243243249`\ k\_b[2]\^2\ k\_b[3] - 
          118.067202337472544`\ k\_b[3]\^2 - 1152\ k\_b[2]\ k\_b[3]\^2 + 
          5.57020901619444597`\ k\_b[4] - 
          135.031409788166545`\ k\_b[2]\ k\_b[4] - 576\ k\_b[2]\^2\ k\_b[4] - 
          622.702702702702559`\ k\_b[3]\ k\_b[4] - 272\ k\_b[4]\^2 + 
          0.80844175073538711`\ k\_b[5] - 
          249.081081081081068`\ k\_b[2]\ k\_b[5] - 384\ k\_b[3]\ k\_b[5] - 
          15.945945945945934`\ k\_b[6] - 128\ k\_b[2]\ k\_b[6] - 
          20.756756756756749`\ k\_b[7] - 8\ k\_b[8] - 
          0.108970022980341907`\ k\_w[2] + 
          6.24227801133413873`\ k\_b[2]\ k\_w[2] - 
          101.785244704163591`\ k\_b[2]\^2\ k\_w[2] - 
          1.54332418612913979`\ k\_b[3]\ k\_w[2] - 
          747.243243243243249`\ k\_b[2]\ k\_b[3]\ k\_w[2] - 
          576\ k\_b[3]\^2\ k\_w[2] - 95.6756756756757376`\ k\_b[4]\ k\_w[2] - 
          768\ k\_b[2]\ k\_b[4]\ k\_w[2] - 
          186.810810810810821`\ k\_b[5]\ k\_w[2] - 96\ k\_b[6]\ k\_w[2] + 
          3.28568490113709721`\ k\_w[2]\^2 - 
          67.1745799853907943`\ k\_b[2]\ k\_w[2]\^2 - 
          576\ k\_b[2]\^2\ k\_w[2]\^2 - 
          373.621621621621624`\ k\_b[3]\ k\_w[2]\^2 - 
          288\ k\_b[4]\ k\_w[2]\^2 - 25.4463111760408988`\ k\_w[2]\^3 - 
          72\ k\_w[2]\^4 + 0.217968063172397252`\ k\_w[3] - 
          5.29153258444711482`\ k\_b[2]\ k\_w[3] - 
          33.9284149013878799`\ k\_b[3]\ k\_w[3] - 
          83.0270270270269961`\ k\_b[4]\ k\_w[3] - 64\ k\_b[5]\ k\_w[3] + 
          2.13132489684716652`\ k\_w[2]\ k\_w[3] - 
          249.081081081081068`\ k\_b[2]\ k\_w[2]\ k\_w[3] - 
          384\ k\_b[3]\ k\_w[2]\ k\_w[3] - 
          62.2702702702702648`\ k\_w[2]\^2\ k\_w[3] - 
          7.46384222059897783`\ k\_w[3]\^2 - 128\ k\_b[2]\ k\_w[3]\^2 - 
          0.0679215926486571586`\ k\_w[4] - 
          8.48210372534697043`\ k\_w[2]\ k\_w[4] - 48\ k\_w[2]\^2\ k\_w[4] - 
          20.756756756756749`\ k\_w[3]\ k\_w[4] - 8\ k\_w[4]\^2] + 
      Log[\(0.00622071670358343897`\[InvisibleSpace]\) + 
          0.140470056106048346`\ k\_b[2] - 2.9220344463469253`\ k\_b[2]\^2 + 
          31.7574872169466804`\ k\_b[2]\^3 - 192\ k\_b[2]\^4 + 
          0.192081755588306073`\ k\_b[3] + 
          8.90482301147021004`\ k\_b[2]\ k\_b[3] - 
          171.243243243243137`\ k\_b[2]\^2\ k\_b[3] + 
          55.7706355003652021`\ k\_b[3]\^2 - 1152\ k\_b[2]\ k\_b[3]\^2 - 
          2.45762743969168084`\ k\_b[4] + 
          58.4821037253469899`\ k\_b[2]\ k\_b[4] - 576\ k\_b[2]\^2\ k\_b[4] - 
          142.70270270270271`\ k\_b[3]\ k\_b[4] - 272\ k\_b[4]\^2 + 
          1.98448265650603872`\ k\_b[5] - 
          57.0810810810810842`\ k\_b[2]\ k\_b[5] - 384\ k\_b[3]\ k\_b[5] + 
          6.64864864864865445`\ k\_b[6] - 128\ k\_b[2]\ k\_b[6] - 
          4.75675675675675879`\ k\_b[7] - 8\ k\_b[8] + 
          0.179430518540529249`\ k\_w[2] - 
          2.98983064955465405`\ k\_b[2]\ k\_w[2] + 
          16.2688093498904384`\ k\_b[2]\^2\ k\_w[2] + 
          7.45448443330110777`\ k\_b[3]\ k\_w[2] - 
          171.243243243243137`\ k\_b[2]\ k\_b[3]\ k\_w[2] - 
          576\ k\_b[3]\^2\ k\_w[2] + 39.8918918918919231`\ k\_b[4]\ k\_w[2] - 
          768\ k\_b[2]\ k\_b[4]\ k\_w[2] - 
          42.8108108108107821`\ k\_b[5]\ k\_w[2] - 96\ k\_b[6]\ k\_w[2] - 
          1.35775181534564093`\ k\_w[2]\^2 + 
          47.6362308254199984`\ k\_b[2]\ k\_w[2]\^2 - 
          576\ k\_b[2]\^2\ k\_w[2]\^2 - 
          85.6216216216215642`\ k\_b[3]\ k\_w[2]\^2 - 
          288\ k\_b[4]\ k\_w[2]\^2 + 4.06720233747260984`\ k\_w[2]\^3 - 
          72\ k\_w[2]\^4 - 0.141386335942726759`\ k\_w[3] + 
          2.00138195171065902`\ k\_b[2]\ k\_w[3] + 
          5.42293644996347445`\ k\_b[3]\ k\_w[3] - 
          19.0270270270270351`\ k\_b[4]\ k\_w[3] - 64\ k\_b[5]\ k\_w[3] + 
          1.48413716857836908`\ k\_w[2]\ k\_w[3] - 
          57.0810810810810842`\ k\_b[2]\ k\_w[2]\ k\_w[3] - 
          384\ k\_b[3]\ k\_w[2]\ k\_w[3] - 
          14.270270270270271`\ k\_w[2]\^2\ k\_w[3] + 
          5.29291453615777829`\ k\_w[3]\^2 - 128\ k\_b[2]\ k\_w[3]\^2 + 
          0.0344218026092742412`\ k\_w[4] + 
          1.35573411249086861`\ k\_w[2]\ k\_w[4] - 48\ k\_w[2]\^2\ k\_w[4] - 
          4.75675675675675879`\ k\_w[3]\ k\_w[4] - 8\ k\_w[4]\^2] + 
      Log[\(0.00276193023041614349`\[InvisibleSpace]\) + 
          0.127781675776094028`\ k\_b[2] - 2.75264665095474736`\ k\_b[2]\^2 + 
          31.7574872169466804`\ k\_b[2]\^3 - 192\ k\_b[2]\^4 + 
          0.00036716970160766138`\ k\_b[3] + 
          10.3511341875111062`\ k\_b[2]\ k\_b[3] - 
          171.243243243243137`\ k\_b[2]\^2\ k\_b[3] + 
          48.6355003652301132`\ k\_b[3]\^2 - 1152\ k\_b[2]\ k\_b[3]\^2 - 
          1.70667488011968915`\ k\_b[4] + 
          48.9685902118334759`\ k\_b[2]\ k\_b[4] - 576\ k\_b[2]\^2\ k\_b[4] - 
          142.70270270270271`\ k\_b[3]\ k\_b[4] - 272\ k\_b[4]\^2 + 
          1.87199178725840535`\ k\_b[5] - 
          57.0810810810810842`\ k\_b[2]\ k\_b[5] - 384\ k\_b[3]\ k\_b[5] + 
          5.45945945945945965`\ k\_b[6] - 128\ k\_b[2]\ k\_b[6] - 
          4.7567567567567579`\ k\_b[7] - 8\ k\_b[8] + 
          0.0753754492574192269`\ k\_w[2] - 
          0.991054663926947654`\ k\_b[2]\ k\_w[2] + 
          1.99853907962015497`\ k\_b[2]\^2\ k\_w[2] + 
          6.05638362979488675`\ k\_b[3]\ k\_w[2] - 
          171.243243243243137`\ k\_b[2]\ k\_b[3]\ k\_w[2] - 
          576\ k\_b[3]\^2\ k\_w[2] + 32.756756756756773`\ k\_b[4]\ k\_w[2] - 
          768\ k\_b[2]\ k\_b[4]\ k\_w[2] - 
          42.8108108108107821`\ k\_b[5]\ k\_w[2] - 96\ k\_b[6]\ k\_w[2] - 
          1.34602496797233461`\ k\_w[2]\^2 + 
          47.6362308254200161`\ k\_b[2]\ k\_w[2]\^2 - 
          576\ k\_b[2]\^2\ k\_w[2]\^2 - 
          85.6216216216215642`\ k\_b[3]\ k\_w[2]\^2 - 
          288\ k\_b[4]\ k\_w[2]\^2 + 0.499634769905038744`\ k\_w[2]\^3 - 
          72\ k\_w[2]\^4 - 0.0480704468595583822`\ k\_w[3] + 
          0.587211024026217565`\ k\_b[2]\ k\_w[3] + 
          0.666179693206719658`\ k\_b[3]\ k\_w[3] - 
          19.0270270270270316`\ k\_b[4]\ k\_w[3] - 64\ k\_b[5]\ k\_w[3] + 
          1.72518903125185101`\ k\_w[2]\ k\_w[3] - 
          57.0810810810810842`\ k\_b[2]\ k\_w[2]\ k\_w[3] - 
          384\ k\_b[3]\ k\_w[2]\ k\_w[3] - 
          14.270270270270271`\ k\_w[2]\^2\ k\_w[3] + 
          5.2929145361577774`\ k\_w[3]\^2 - 128\ k\_b[2]\ k\_w[3]\^2 + 
          0.0100994525016794156`\ k\_w[4] + 
          0.166544923301679919`\ k\_w[2]\ k\_w[4] - 48\ k\_w[2]\^2\ k\_w[4] - 
          4.7567567567567579`\ k\_w[3]\ k\_w[4] - 8\ k\_w[4]\^2] + 
      Log[\(0.00964552301877841244`\[InvisibleSpace]\) - 
          0.0816044917569189465`\ k\_b[2] + 
          0.703927650826156003`\ k\_b[2]\^2 - 
          17.1957633308984654`\ k\_b[2]\^3 - 48\ k\_b[2]\^4 + 
          0.134603982146561618`\ k\_b[3] - 
          1.83223106232602219`\ k\_b[2]\ k\_b[3] - 
          186.810810810810785`\ k\_b[2]\^2\ k\_b[3] - 
          31.7059897735573192`\ k\_b[3]\^2 - 288\ k\_b[2]\ k\_b[3]\^2 + 
          1.34621738740695051`\ k\_b[4] - 
          33.6767713659605494`\ k\_b[2]\ k\_b[4] - 144\ k\_b[2]\^2\ k\_b[4] - 
          155.675675675675684`\ k\_b[3]\ k\_b[4] - 68\ k\_b[4]\^2 + 
          0.514382168874502365`\ k\_b[5] - 
          62.2702702702702737`\ k\_b[2]\ k\_b[5] - 96\ k\_b[3]\ k\_b[5] - 
          3.85135135135134909`\ k\_b[6] - 32\ k\_b[2]\ k\_b[6] - 
          5.1891891891891877`\ k\_b[7] - 2\ k\_b[8] - 
          0.119237635363950399`\ k\_w[2] + 
          2.98276068598161927`\ k\_b[2]\ k\_w[2] - 
          11.8246895544192764`\ k\_b[2]\^2\ k\_w[2] + 
          4.00240854441000237`\ k\_b[3]\ k\_w[2] - 
          186.810810810810785`\ k\_b[2]\ k\_b[3]\ k\_w[2] - 
          144\ k\_b[3]\^2\ k\_w[2] - 23.1081081081081007`\ k\_b[4]\ k\_w[2] - 
          192\ k\_b[2]\ k\_b[4]\ k\_w[2] - 
          46.7027027027026964`\ k\_b[5]\ k\_w[2] - 24\ k\_b[6]\ k\_w[2] + 
          1.06220163315745041`\ k\_w[2]\^2 - 
          25.7936449963476954`\ k\_b[2]\ k\_w[2]\^2 - 
          144\ k\_b[2]\^2\ k\_w[2]\^2 - 
          93.4054054054053928`\ k\_b[3]\ k\_w[2]\^2 - 
          72\ k\_b[4]\ k\_w[2]\^2 - 2.95617238860481901`\ k\_w[2]\^3 - 
          18\ k\_w[2]\^4 + 0.124638203874059239`\ k\_w[3] + 
          3.27901605038201005`\ k\_b[2]\ k\_w[3] - 
          3.94156318480643186`\ k\_b[3]\ k\_w[3] - 
          20.756756756756749`\ k\_b[4]\ k\_w[3] - 16\ k\_b[5]\ k\_w[3] - 
          0.305371843721005076`\ k\_w[2]\ k\_w[3] - 
          62.2702702702702737`\ k\_b[2]\ k\_w[2]\ k\_w[3] - 
          96\ k\_b[3]\ k\_w[2]\ k\_w[3] - 
          15.5675675675675684`\ k\_w[2]\^2\ k\_w[3] - 
          2.86596055514974423`\ k\_w[3]\^2 - 32\ k\_b[2]\ k\_w[3]\^2 + 
          0.236745935914790628`\ k\_w[4] - 
          0.985390796201608054`\ k\_w[2]\ k\_w[4] - 12\ k\_w[2]\^2\ k\_w[4] - 
          5.1891891891891877`\ k\_w[3]\ k\_w[4] - 2\ k\_w[4]\^2] + 
      Log[\(0.0204112651513516096`\[InvisibleSpace]\) - 
          0.099977118300281873`\ k\_b[2] + 1.10005423760285303`\ k\_b[2]\^2 - 
          17.1957633308984654`\ k\_b[2]\^3 - 48\ k\_b[2]\^4 + 
          0.126069496582089879`\ k\_b[3] + 
          1.08230509545338948`\ k\_b[2]\ k\_b[3] - 
          186.810810810810785`\ k\_b[2]\^2\ k\_b[3] - 
          30.0843681519357186`\ k\_b[3]\^2 - 288\ k\_b[2]\ k\_b[3]\^2 + 
          1.68213036393351185`\ k\_b[4] - 
          31.5146092037983782`\ k\_b[2]\ k\_b[4] - 144\ k\_b[2]\^2\ k\_b[4] - 
          155.675675675675684`\ k\_b[3]\ k\_b[4] - 68\ k\_b[4]\^2 + 
          1.07683651511262423`\ k\_b[5] - 
          62.2702702702702737`\ k\_b[2]\ k\_b[5] - 96\ k\_b[3]\ k\_b[5] - 
          3.58108108108107892`\ k\_b[6] - 32\ k\_b[2]\ k\_b[6] - 
          5.1891891891891877`\ k\_b[7] - 2\ k\_b[8] - 
          0.212340557079248748`\ k\_w[2] + 
          3.39630973539626346`\ k\_b[2]\ k\_w[2] - 
          8.5814463111760304`\ k\_b[2]\^2\ k\_w[2] + 
          5.91986654294907932`\ k\_b[3]\ k\_w[2] - 
          186.810810810810785`\ k\_b[2]\ k\_b[3]\ k\_w[2] - 
          144\ k\_b[3]\^2\ k\_w[2] - 21.486486486486469`\ k\_b[4]\ k\_w[2] - 
          192\ k\_b[2]\ k\_b[4]\ k\_w[2] - 
          46.7027027027026964`\ k\_b[5]\ k\_w[2] - 24\ k\_b[6]\ k\_w[2] + 
          1.04556885721130865`\ k\_w[2]\^2 - 
          25.7936449963476999`\ k\_b[2]\ k\_w[2]\^2 - 
          144\ k\_b[2]\^2\ k\_w[2]\^2 - 
          93.4054054054053928`\ k\_b[3]\ k\_w[2]\^2 - 
          72\ k\_b[4]\ k\_w[2]\^2 - 2.1453615777940076`\ k\_w[2]\^3 - 
          18\ k\_w[2]\^4 - 0.00398601784435234662`\ k\_w[3] + 
          3.58580933014826452`\ k\_b[2]\ k\_w[3] - 
          2.86048210372534761`\ k\_b[3]\ k\_w[3] - 
          20.756756756756749`\ k\_b[4]\ k\_w[3] - 16\ k\_b[5]\ k\_w[3] + 
          0.180384182575560316`\ k\_w[2]\ k\_w[3] - 
          62.2702702702702737`\ k\_b[2]\ k\_w[2]\ k\_w[3] - 
          96\ k\_b[3]\ k\_w[2]\ k\_w[3] - 
          15.5675675675675684`\ k\_w[2]\^2\ k\_w[3] - 
          2.86596055514974334`\ k\_w[3]\^2 - 32\ k\_b[2]\ k\_w[3]\^2 + 
          0.16518057946996012`\ k\_w[4] - 
          0.715120525931336903`\ k\_w[2]\ k\_w[4] - 12\ k\_w[2]\^2\ k\_w[4] - 
          5.1891891891891877`\ k\_w[3]\ k\_w[4] - 2\ k\_w[4]\^2] + 
      4\ Log[1\/4\ 
            \((\(0.000483197733008909668`\[InvisibleSpace]\) + 
                0.0289286690490038189`\ k\_b[2] - 
                0.178576840516903878`\ k\_b[2]\^2 + 
                1.93937180423667054`\ k\_b[2]\^3 - 48\ k\_b[2]\^4 - 
                0.0374086544412226817`\ k\_b[3] + 
                2.29852131166958617`\ k\_b[2]\ k\_b[3] - 
                42.8108108108107821`\ k\_b[2]\^2\ k\_b[3] + 
                8.18590211833456038`\ k\_b[3]\^2 - 288\ k\_b[2]\ k\_b[3]\^2 - 
                0.319611882330279817`\ k\_b[4] + 
                9.94485025566107161`\ k\_b[2]\ k\_b[4] - 
                144\ k\_b[2]\^2\ k\_b[4] - 
                35.6756756756756621`\ k\_b[3]\ k\_b[4] - 68\ k\_b[4]\^2 + 
                0.419787574279904163`\ k\_b[5] - 
                14.270270270270271`\ k\_b[2]\ k\_b[5] - 
                96\ k\_b[3]\ k\_b[5] + 1.2027027027027024`\ k\_b[6] - 
                32\ k\_b[2]\ k\_b[6] - 1.18918918918918926`\ k\_b[7] - 
                2\ k\_b[8] + 0.00916837610003335967`\ k\_w[2] - 
                0.690970386215484566`\ k\_b[2]\ k\_w[2] + 
                10.5536888239590931`\ k\_b[2]\^2\ k\_w[2] + 
                1.36946478984462483`\ k\_b[3]\ k\_w[2] - 
                42.8108108108107821`\ k\_b[2]\ k\_b[3]\ k\_w[2] - 
                144\ k\_b[3]\^2\ k\_w[2] + 
                7.21621621621621756`\ k\_b[4]\ k\_w[2] - 
                192\ k\_b[2]\ k\_b[4]\ k\_w[2] - 
                10.7027027027026955`\ k\_b[5]\ k\_w[2] - 
                24\ k\_b[6]\ k\_w[2] - 0.159285741726564822`\ k\_w[2]\^2 + 
                2.90905770635500626`\ k\_b[2]\ k\_w[2]\^2 - 
                144\ k\_b[2]\^2\ k\_w[2]\^2 - 
                21.405405405405391`\ k\_b[3]\ k\_w[2]\^2 - 
                72\ k\_b[4]\ k\_w[2]\^2 + 2.63842220598977306`\ k\_w[2]\^3 - 
                18\ k\_w[2]\^4 + 0.0262671861226494485`\ k\_w[3] + 
                0.146802756006554684`\ k\_b[2]\ k\_w[3] + 
                3.51789627465303045`\ k\_b[3]\ k\_w[3] - 
                4.75675675675675702`\ k\_b[4]\ k\_w[3] - 
                16\ k\_b[5]\ k\_w[3] + 
                0.383086885278265221`\ k\_w[2]\ k\_w[3] - 
                14.270270270270271`\ k\_b[2]\ k\_w[2]\ k\_w[3] - 
                96\ k\_b[3]\ k\_w[2]\ k\_w[3] - 
                3.56756756756756798`\ k\_w[2]\^2\ k\_w[3] + 
                0.323228634039444573`\ k\_w[3]\^2 - 32\ k\_b[2]\ k\_w[3]\^2 - 
                0.0233324404893709713`\ k\_w[4] + 
                0.879474068663257568`\ k\_w[2]\ k\_w[4] - 
                12\ k\_w[2]\^2\ k\_w[4] - 
                1.18918918918918926`\ k\_w[3]\ k\_w[4] - 2\ k\_w[4]\^2)\)] + 
      2\ Log[1\/2\ 
            \((\(0.000734913609136817136`\[InvisibleSpace]\) + 
                0.0412286539633345583`\ k\_b[2] - 
                0.249717740364888962`\ k\_b[2]\^2 + 
                1.93937180423666877`\ k\_b[2]\^3 - 48\ k\_b[2]\^4 - 
                0.045679888876257797`\ k\_b[3] + 
                3.04139932481788122`\ k\_b[2]\ k\_b[3] - 
                42.8108108108108176`\ k\_b[2]\^2\ k\_b[3] + 
                9.32103725346969191`\ k\_b[3]\^2 - 288\ k\_b[2]\ k\_b[3]\^2 - 
                0.422197119137577647`\ k\_b[4] + 
                11.4583637691745821`\ k\_b[2]\ k\_b[4] - 
                144\ k\_b[2]\^2\ k\_b[4] - 
                35.6756756756756754`\ k\_b[3]\ k\_b[4] - 68\ k\_b[4]\^2 + 
                0.474206858428921584`\ k\_b[5] - 
                14.270270270270271`\ k\_b[2]\ k\_b[5] - 
                96\ k\_b[3]\ k\_b[5] + 1.39189189189189077`\ k\_b[6] - 
                32\ k\_b[2]\ k\_b[6] - 1.18918918918918903`\ k\_b[7] - 
                2\ k\_b[8] + 0.0119655061008494323`\ k\_w[2] - 
                0.892014746865397789`\ k\_b[2]\ k\_w[2] + 
                12.8239590942293624`\ k\_b[2]\^2\ k\_w[2] + 
                1.32454148816457095`\ k\_b[3]\ k\_w[2] - 
                42.8108108108108176`\ k\_b[2]\ k\_b[3]\ k\_w[2] - 
                144\ k\_b[3]\^2\ k\_w[2] + 
                8.35135135135135797`\ k\_b[4]\ k\_w[2] - 
                192\ k\_b[2]\ k\_b[4]\ k\_w[2] - 
                10.7027027027027044`\ k\_b[5]\ k\_w[2] - 
                24\ k\_b[6]\ k\_w[2] - 0.175800064668937512`\ k\_w[2]\^2 + 
                2.90905770635500005`\ k\_b[2]\ k\_w[2]\^2 - 
                144\ k\_b[2]\^2\ k\_w[2]\^2 - 
                21.4054054054054088`\ k\_b[3]\ k\_w[2]\^2 - 
                72\ k\_b[4]\ k\_w[2]\^2 + 3.2059897735573406`\ k\_w[2]\^3 - 
                18\ k\_w[2]\^4 + 0.0342189442693614953`\ k\_w[3] - 
                0.13077211616291251`\ k\_b[2]\ k\_w[3] + 
                4.27465303140978747`\ k\_b[3]\ k\_w[3] - 
                4.75675675675675613`\ k\_b[4]\ k\_w[3] - 
                16\ k\_b[5]\ k\_w[3] + 
                0.506899887469648469`\ k\_w[2]\ k\_w[3] - 
                14.270270270270271`\ k\_b[2]\ k\_w[2]\ k\_w[3] - 
                96\ k\_b[3]\ k\_w[2]\ k\_w[3] - 
                3.56756756756756798`\ k\_w[2]\^2\ k\_w[3] + 
                0.323228634039444617`\ k\_w[3]\^2 - 32\ k\_b[2]\ k\_w[3]\^2 - 
                0.0169803981621643025`\ k\_w[4] + 
                1.06866325785244686`\ k\_w[2]\ k\_w[4] - 
                12\ k\_w[2]\^2\ k\_w[4] - 
                1.18918918918918903`\ k\_w[3]\ k\_w[4] - 2\ k\_w[4]\^2)\)] + 
      4\ Log[1\/4\ 
            \((\(0.000149469165410756037`\[InvisibleSpace]\) + 
                0.0224977535908623149`\ k\_b[2] + 
                0.595187793364604278`\ k\_b[2]\^2 - 
                2.92549306062819383`\ k\_b[2]\^3 - 48\ k\_b[2]\^4 - 
                0.174821008555943802`\ k\_b[3] - 
                2.76137642390381587`\ k\_b[2]\ k\_b[3] + 
                101.189189189189177`\ k\_b[2]\^2\ k\_b[3] - 
                7.38166544923301515`\ k\_b[3]\^2 - 288\ k\_b[2]\ k\_b[3]\^2 + 
                0.524735935173125778`\ k\_b[4] - 
                8.37947406866326005`\ k\_b[2]\ k\_b[4] - 
                144\ k\_b[2]\^2\ k\_b[4] + 
                84.3243243243243334`\ k\_b[3]\ k\_b[4] - 68\ k\_b[4]\^2 - 
                0.481235069985983088`\ k\_b[5] + 
                33.7297297297297271`\ k\_b[2]\ k\_b[5] - 
                96\ k\_b[3]\ k\_b[5] - 0.986486486486486846`\ k\_b[6] - 
                32\ k\_b[2]\ k\_b[6] + 2.81081081081081087`\ k\_b[7] - 
                2\ k\_b[8] + 0.0153135555927467548`\ k\_w[2] + 
                0.681426115472469984`\ k\_b[2]\ k\_w[2] - 
                5.98685171658144987`\ k\_b[2]\^2\ k\_w[2] - 
                1.50672220796398903`\ k\_b[3]\ k\_w[2] + 
                101.189189189189177`\ k\_b[2]\ k\_b[3]\ k\_w[2] - 
                144\ k\_b[3]\^2\ k\_w[2] - 
                5.91891891891891397`\ k\_b[4]\ k\_w[2] - 
                192\ k\_b[2]\ k\_b[4]\ k\_w[2] + 
                25.2972972972972964`\ k\_b[5]\ k\_w[2] - 
                24\ k\_b[6]\ k\_w[2] + 0.320567376548759774`\ k\_w[2]\^2 - 
                4.3882395909422982`\ k\_b[2]\ k\_w[2]\^2 - 
                144\ k\_b[2]\^2\ k\_w[2]\^2 + 
                50.5945945945945929`\ k\_b[3]\ k\_w[2]\^2 - 
                72\ k\_b[4]\ k\_w[2]\^2 - 1.49671292914536246`\ k\_w[2]\^3 - 
                18\ k\_w[2]\^4 - 0.0230898995279430074`\ k\_w[3] - 
                0.0840226640080545905`\ k\_b[2]\ k\_w[3] - 
                1.99561723886048358`\ k\_b[3]\ k\_w[3] + 
                11.2432432432432438`\ k\_b[4]\ k\_w[3] - 
                16\ k\_b[5]\ k\_w[3] - 
                0.460229403983969742`\ k\_w[2]\ k\_w[3] + 
                33.7297297297297271`\ k\_b[2]\ k\_w[2]\ k\_w[3] - 
                96\ k\_b[3]\ k\_w[2]\ k\_w[3] + 
                8.43243243243243156`\ k\_w[2]\^2\ k\_w[3] - 
                0.487582176771366349`\ k\_w[3]\^2 - 32\ k\_b[2]\ k\_w[3]\^2 + 
                0.00765782662215252951`\ k\_w[4] - 
                0.498904309715120852`\ k\_w[2]\ k\_w[4] - 
                12\ k\_w[2]\^2\ k\_w[4] + 
                2.81081081081081087`\ k\_w[3]\ k\_w[4] - 2\ k\_w[4]\^2)\)] + 
      2\ Log[1\/2\ 
            \((\(0.000200676194301478005`\[InvisibleSpace]\) + 
                0.0291336418485802806`\ k\_b[2] + 
                0.738466572508978558`\ k\_b[2]\^2 - 
                2.92549306062819436`\ k\_b[2]\^3 - 48\ k\_b[2]\^4 - 
                0.223313040457151723`\ k\_b[3] - 
                3.73654077744654999`\ k\_b[2]\ k\_b[3] + 
                101.189189189189177`\ k\_b[2]\^2\ k\_b[3] - 
                6.57085463842220018`\ k\_b[3]\^2 - 288\ k\_b[2]\ k\_b[3]\^2 + 
                0.675442704762291068`\ k\_b[4] - 
                7.29839298758217669`\ k\_b[2]\ k\_b[4] - 
                144\ k\_b[2]\^2\ k\_b[4] + 
                84.3243243243243334`\ k\_b[3]\ k\_b[4] - 68\ k\_b[4]\^2 - 
                0.709503879335875708`\ k\_b[5] + 
                33.7297297297297271`\ k\_b[2]\ k\_b[5] - 
                96\ k\_b[3]\ k\_b[5] - 0.851351351351352469`\ k\_b[6] - 
                32\ k\_b[2]\ k\_b[6] + 2.81081081081081087`\ k\_b[7] - 
                2\ k\_b[8] + 0.020163027371520501`\ k\_w[2] + 
                0.918628255523404568`\ k\_b[2]\ k\_w[2] - 
                4.36523009495982705`\ k\_b[2]\^2\ k\_w[2] - 
                2.38875288729196366`\ k\_b[3]\ k\_w[2] + 
                101.189189189189177`\ k\_b[2]\ k\_b[3]\ k\_w[2] - 
                144\ k\_b[3]\^2\ k\_w[2] - 
                5.10810810810809901`\ k\_b[4]\ k\_w[2] - 
                192\ k\_b[2]\ k\_b[4]\ k\_w[2] + 
                25.2972972972972964`\ k\_b[5]\ k\_w[2] - 
                24\ k\_b[6]\ k\_w[2] + 0.414342671200606549`\ k\_w[2]\^2 - 
                4.38823959094229376`\ k\_b[2]\ k\_w[2]\^2 - 
                144\ k\_b[2]\^2\ k\_w[2]\^2 + 
                50.5945945945945929`\ k\_b[3]\ k\_w[2]\^2 - 
                72\ k\_b[4]\ k\_w[2]\^2 - 1.09130752373995676`\ k\_w[2]\^3 - 
                18\ k\_w[2]\^4 - 0.0319642038166353881`\ k\_w[3] - 
                0.346988332379128516`\ k\_b[2]\ k\_w[3] - 
                1.45507669831994324`\ k\_b[3]\ k\_w[3] + 
                11.2432432432432438`\ k\_b[4]\ k\_w[3] - 
                16\ k\_b[5]\ k\_w[3] - 
                0.622756796241092303`\ k\_w[2]\ k\_w[3] + 
                33.7297297297297271`\ k\_b[2]\ k\_w[2]\ k\_w[3] - 
                96\ k\_b[3]\ k\_w[2]\ k\_w[3] + 
                8.43243243243243156`\ k\_w[2]\^2\ k\_w[3] - 
                0.487582176771366615`\ k\_w[3]\^2 - 32\ k\_b[2]\ k\_w[3]\^2 + 
                0.0150364616487057372`\ k\_w[4] - 
                0.36376917457998581`\ k\_w[2]\ k\_w[4] - 
                12\ k\_w[2]\^2\ k\_w[4] + 
                2.81081081081081087`\ k\_w[3]\ k\_w[4] - 2\ k\_w[4]\^2)\)] + 
      9\ Log[1\/9\ 
            \((\(0.0000481622866323547249`\[InvisibleSpace]\) + 
                0.0101887288815855203`\ k\_b[2] + 
                0.562078778183944827`\ k\_b[2]\^2 + 
                8.67896274653031518`\ k\_b[2]\^3 + 24\ k\_b[2]\^4 - 
                0.107022131178640433`\ k\_b[3] - 
                7.65108680630959891`\ k\_b[2]\ k\_b[3] - 
                86.5945945945945894`\ k\_b[2]\^2\ k\_b[3] + 
                19.3800219138057023`\ k\_b[3]\^2 + 144\ k\_b[2]\ k\_b[3]\^2 + 
                0.523839167232697722`\ k\_b[4] + 
                21.5005478451424414`\ k\_b[2]\ k\_b[4] + 
                72\ k\_b[2]\^2\ k\_b[4] - 
                72.1621621621621578`\ k\_b[3]\ k\_b[4] + 34\ k\_b[4]\^2 - 
                1.47705960160306393`\ k\_b[5] - 
                28.8648648648648666`\ k\_b[2]\ k\_b[5] + 
                48\ k\_b[3]\ k\_b[5] + 2.50675675675675657`\ k\_b[6] + 
                16\ k\_b[2]\ k\_b[6] - 2.40540540540540526`\ k\_b[7] + 
                k\_b[8] + 0.00735812465576098784`\ k\_w[2] + 
                0.728399334422176192`\ k\_b[2]\ k\_w[2] + 
                12.7231555880204538`\ k\_b[2]\^2\ k\_w[2] - 
                5.03681420646358279`\ k\_b[3]\ k\_w[2] - 
                86.5945945945945894`\ k\_b[2]\ k\_b[3]\ k\_w[2] + 
                72\ k\_b[3]\^2\ k\_w[2] + 
                15.0405405405405412`\ k\_b[4]\ k\_w[2] + 
                96\ k\_b[2]\ k\_b[4]\ k\_w[2] - 
                21.6486486486486473`\ k\_b[5]\ k\_w[2] + 
                12\ k\_b[6]\ k\_w[2] + 0.322678821349926803`\ k\_w[2]\^2 + 
                13.0184441197954714`\ k\_b[2]\ k\_w[2]\^2 + 
                72\ k\_b[2]\^2\ k\_w[2]\^2 - 
                43.2972972972972947`\ k\_b[3]\ k\_w[2]\^2 + 
                36\ k\_b[4]\ k\_w[2]\^2 + 3.18078889700511346`\ k\_w[2]\^3 + 
                9\ k\_w[2]\^4 - 0.0166932859052159372`\ k\_w[3] - 
                0.807513868872524831`\ k\_b[2]\ k\_w[3] + 
                4.24105186267348521`\ k\_b[3]\ k\_w[3] - 
                9.62162162162162104`\ k\_b[4]\ k\_w[3] + 
                8\ k\_b[5]\ k\_w[3] - 
                1.27518113438493263`\ k\_w[2]\ k\_w[3] - 
                28.8648648648648666`\ k\_b[2]\ k\_w[2]\ k\_w[3] + 
                48\ k\_b[3]\ k\_w[2]\ k\_w[3] - 
                7.21621621621621667`\ k\_w[2]\^2\ k\_w[3] + 
                1.44649379108838571`\ k\_w[3]\^2 + 16\ k\_b[2]\ k\_w[3]\^2 + 
                0.0138798107526514534`\ k\_w[4] + 
                1.0602629656683713`\ k\_w[2]\ k\_w[4] + 
                6\ k\_w[2]\^2\ k\_w[4] - 
                2.40540540540540526`\ k\_w[3]\ k\_w[4] + k\_w[4]\^2)\)] + 
      Log[\(0.00188326890036771708`\[InvisibleSpace]\) + 
          0.113929393801356004`\ k\_b[2] - 
          0.103608761467130938`\ k\_b[2]\^2 - 
          11.0138787436084806`\ k\_b[2]\^3 + 96\ k\_b[2]\^4 - 
          0.462180713165820566`\ k\_b[3] + 
          12.5439361933153148`\ k\_b[2]\ k\_b[3] - 
          58.3783783783784393`\ k\_b[2]\^2\ k\_b[3] - 
          24.8042366691015203`\ k\_b[3]\^2 + 576\ k\_b[2]\ k\_b[3]\^2 + 
          0.129846235195374193`\ k\_b[4] - 
          27.5653761869978097`\ k\_b[2]\ k\_b[4] + 288\ k\_b[2]\^2\ k\_b[4] - 
          48.6486486486486313`\ k\_b[3]\ k\_b[4] + 136\ k\_b[4]\^2 + 
          2.25757605669950311`\ k\_b[5] - 
          19.4594594594594667`\ k\_b[2]\ k\_b[5] + 192\ k\_b[3]\ k\_b[5] - 
          3.21621621621621933`\ k\_b[6] + 64\ k\_b[2]\ k\_b[6] - 
          1.62162162162162193`\ k\_b[7] + 4\ k\_b[8] + 
          0.103770764320803321`\ k\_w[2] + 
          0.544951847786823151`\ k\_b[2]\ k\_w[2] - 
          16.5668371073776583`\ k\_b[2]\^2\ k\_w[2] + 
          7.27348824353938461`\ k\_b[3]\ k\_w[2] - 
          58.3783783783784393`\ k\_b[2]\ k\_b[3]\ k\_w[2] + 
          288\ k\_b[3]\^2\ k\_w[2] - 19.2972972972973053`\ k\_b[4]\ k\_w[2] + 
          384\ k\_b[2]\ k\_b[4]\ k\_w[2] - 
          14.5945945945946098`\ k\_b[5]\ k\_w[2] + 48\ k\_b[6]\ k\_w[2] + 
          0.114753348298252078`\ k\_w[2]\^2 - 
          16.5208181154127009`\ k\_b[2]\ k\_w[2]\^2 + 
          288\ k\_b[2]\^2\ k\_w[2]\^2 - 
          29.1891891891892196`\ k\_b[3]\ k\_w[2]\^2 + 
          144\ k\_b[4]\ k\_w[2]\^2 - 4.14170927684441458`\ k\_w[2]\^3 + 
          36\ k\_w[2]\^4 - 0.133058137279359511`\ k\_w[3] + 
          0.667680097921150128`\ k\_b[2]\ k\_w[3] - 
          5.52227903579254864`\ k\_b[3]\ k\_w[3] - 
          6.48648648648648773`\ k\_b[4]\ k\_w[3] + 32\ k\_b[5]\ k\_w[3] + 
          2.09065603221921714`\ k\_w[2]\ k\_w[3] - 
          19.4594594594594667`\ k\_b[2]\ k\_w[2]\ k\_w[3] + 
          192\ k\_b[3]\ k\_w[2]\ k\_w[3] - 
          4.86486486486486668`\ k\_w[2]\^2\ k\_w[3] - 
          1.83564645726807817`\ k\_w[3]\^2 + 64\ k\_b[2]\ k\_w[3]\^2 + 
          0.0555192430106058232`\ k\_w[4] - 
          1.38056975894813716`\ k\_w[2]\ k\_w[4] + 24\ k\_w[2]\^2\ k\_w[4] - 
          1.62162162162162193`\ k\_w[3]\ k\_w[4] + 4\ k\_w[4]\^2] + 
      Log[\(0.000662863255299874509`\[InvisibleSpace]\) + 
          0.0612565181389532842`\ k\_b[2] + 
          0.0402129272778585811`\ k\_b[2]\^2 - 
          11.0138787436084806`\ k\_b[2]\^3 + 96\ k\_b[2]\^4 - 
          0.274918919755329627`\ k\_b[3] + 
          9.12538250449134835`\ k\_b[2]\ k\_b[3] - 
          58.3783783783784304`\ k\_b[2]\^2\ k\_b[3] - 
          19.939371804236682`\ k\_b[3]\^2 + 576\ k\_b[2]\ k\_b[3]\^2 + 
          0.0786153110645233965`\ k\_b[4] - 
          21.0788897005113406`\ k\_b[2]\ k\_b[4] + 288\ k\_b[2]\^2\ k\_b[4] - 
          48.648648648648658`\ k\_b[3]\ k\_b[4] + 136\ k\_b[4]\^2 + 
          1.57459577912463295`\ k\_b[5] - 
          19.4594594594594667`\ k\_b[2]\ k\_b[5] + 192\ k\_b[3]\ k\_b[5] - 
          2.40540540540540614`\ k\_b[6] + 64\ k\_b[2]\ k\_b[6] - 
          1.62162162162162148`\ k\_b[7] + 4\ k\_b[8] + 
          0.039352353643720086`\ k\_w[2] + 
          0.175526542276783441`\ k\_b[2]\ k\_w[2] - 
          6.83710737764791787`\ k\_b[2]\^2\ k\_w[2] + 
          4.88488342250212514`\ k\_b[3]\ k\_w[2] - 
          58.3783783783784304`\ k\_b[2]\ k\_b[3]\ k\_w[2] + 
          288\ k\_b[3]\^2\ k\_w[2] - 14.4324324324324448`\ k\_b[4]\ k\_w[2] + 
          384\ k\_b[2]\ k\_b[4]\ k\_w[2] - 
          14.5945945945946071`\ k\_b[5]\ k\_w[2] + 48\ k\_b[6]\ k\_w[2] + 
          0.0480741782589647215`\ k\_w[2]\^2 - 
          16.5208181154127098`\ k\_b[2]\ k\_w[2]\^2 + 
          288\ k\_b[2]\^2\ k\_w[2]\^2 - 
          29.1891891891892143`\ k\_b[3]\ k\_w[2]\^2 + 
          144\ k\_b[4]\ k\_w[2]\^2 - 1.70927684441197946`\ k\_w[2]\^3 + 
          36\ k\_w[2]\^4 - 0.0357672695257353234`\ k\_w[3] + 
          0.214794780170967092`\ k\_b[2]\ k\_w[3] - 
          2.27903579254930477`\ k\_b[3]\ k\_w[3] - 
          6.48648648648648595`\ k\_b[4]\ k\_w[3] + 32\ k\_b[5]\ k\_w[3] + 
          1.52089708408189183`\ k\_w[2]\ k\_w[3] - 
          19.4594594594594667`\ k\_b[2]\ k\_w[2]\ k\_w[3] + 
          192\ k\_b[3]\ k\_w[2]\ k\_w[3] - 
          4.86486486486486668`\ k\_w[2]\^2\ k\_w[3] - 
          1.83564645726807782`\ k\_w[3]\^2 + 64\ k\_b[2]\ k\_w[3]\^2 + 
          0.00932257154001178101`\ k\_w[4] - 
          0.569758948137326193`\ k\_w[2]\ k\_w[4] + 24\ k\_w[2]\^2\ k\_w[4] - 
          1.62162162162162148`\ k\_w[3]\ k\_w[4] + 4\ k\_w[4]\^2] + 
      2\ Log[1\/2\ 
            \((\(0.0086998835071334728`\[InvisibleSpace]\) + 
                0.00195234546245021114`\ k\_b[2] - 
                0.660357621356971691`\ k\_b[2]\^2 + 
                3.25639152666178866`\ k\_b[2]\^3 + 96\ k\_b[2]\^4 + 
                0.606423985149852207`\ k\_b[3] - 
                15.1814107752749594`\ k\_b[2]\ k\_b[3] + 
                229.621621621621629`\ k\_b[2]\^2\ k\_b[3] + 
                2.11468224981737229`\ k\_b[3]\^2 + 576\ k\_b[2]\ k\_b[3]\^2 - 
                0.318695805749877436`\ k\_b[4] + 
                1.19138056975893746`\ k\_b[2]\ k\_b[4] + 
                288\ k\_b[2]\^2\ k\_b[4] + 
                191.351351351351333`\ k\_b[3]\ k\_b[4] + 136\ k\_b[4]\^2 - 
                3.47872781473949999`\ k\_b[5] + 
                76.5405405405405492`\ k\_b[2]\ k\_b[5] + 
                192\ k\_b[3]\ k\_b[5] + 0.081081081081081141`\ k\_b[6] + 
                64\ k\_b[2]\ k\_b[6] + 6.37837837837837717`\ k\_b[7] + 
                4\ k\_b[8] + 0.0269392640647680448`\ k\_w[2] + 
                0.0344490147858158568`\ k\_b[2]\ k\_w[2] - 
                5.53981008035063382`\ k\_b[2]\^2\ k\_w[2] - 
                13.2816615007995775`\ k\_b[3]\ k\_w[2] + 
                229.621621621621629`\ k\_b[2]\ k\_b[3]\ k\_w[2] + 
                288\ k\_b[3]\^2\ k\_w[2] + 
                0.486486486486502833`\ k\_b[4]\ k\_w[2] + 
                384\ k\_b[2]\ k\_b[4]\ k\_w[2] + 
                57.4054054054054052`\ k\_b[5]\ k\_w[2] + 
                48\ k\_b[6]\ k\_w[2] - 0.720113293361669803`\ k\_w[2]\^2 + 
                4.8845872899926892`\ k\_b[2]\ k\_w[2]\^2 + 
                288\ k\_b[2]\^2\ k\_w[2]\^2 + 
                114.810810810810814`\ k\_b[3]\ k\_w[2]\^2 + 
                144\ k\_b[4]\ k\_w[2]\^2 - 1.38495252008765845`\ k\_w[2]\^3 + 
                36\ k\_w[2]\^4 + 0.168317118101581648`\ k\_w[3] - 
                3.79397074210806728`\ k\_b[2]\ k\_w[3] - 
                1.84660336011687498`\ k\_b[3]\ k\_w[3] + 
                25.5135135135135104`\ k\_b[4]\ k\_w[3] + 
                32\ k\_b[5]\ k\_w[3] - 
                2.53023512921248228`\ k\_w[2]\ k\_w[3] + 
                76.5405405405405492`\ k\_b[2]\ k\_w[2]\ k\_w[3] + 
                192\ k\_b[3]\ k\_w[2]\ k\_w[3] + 
                19.1351351351351368`\ k\_w[2]\^2\ k\_w[3] + 
                0.542731921110298998`\ k\_w[3]\^2 + 64\ k\_b[2]\ k\_w[3]\^2 - 
                0.129978160894394845`\ k\_w[4] - 
                0.461650840029218745`\ k\_w[2]\ k\_w[4] + 
                24\ k\_w[2]\^2\ k\_w[4] + 
                6.37837837837837717`\ k\_w[3]\ k\_w[4] + 4\ k\_w[4]\^2)\)] + 
      Log[\(0.0030621400380700714`\[InvisibleSpace]\) + 
          0.0630954653308477109`\ k\_b[2] - 1.2075512722759667`\ k\_b[2]\^2 + 
          3.25639152666179221`\ k\_b[2]\^3 + 96\ k\_b[2]\^4 + 
          0.372210248976705848`\ k\_b[3] - 
          14.0594239235583522`\ k\_b[2]\ k\_b[3] + 
          229.621621621621629`\ k\_b[2]\^2\ k\_b[3] + 
          6.97954711468224786`\ k\_b[3]\^2 + 576\ k\_b[2]\ k\_b[3]\^2 - 
          0.567881441348953153`\ k\_b[4] + 
          7.67786705624543941`\ k\_b[2]\ k\_b[4] + 288\ k\_b[2]\^2\ k\_b[4] + 
          191.351351351351368`\ k\_b[3]\ k\_b[4] + 136\ k\_b[4]\^2 - 
          2.54008647069275017`\ k\_b[5] + 
          76.5405405405405492`\ k\_b[2]\ k\_b[5] + 192\ k\_b[3]\ k\_b[5] + 
          0.891891891891891219`\ k\_b[6] + 64\ k\_b[2]\ k\_b[6] + 
          6.37837837837837806`\ k\_b[7] + 4\ k\_b[8] - 
          0.015749156499406034`\ k\_w[2] + 
          0.107682584367087219`\ k\_b[2]\ k\_w[2] + 
          4.18991964937910488`\ k\_b[2]\^2\ k\_w[2] - 
          8.21080686237733559`\ k\_b[3]\ k\_w[2] + 
          229.621621621621629`\ k\_b[2]\ k\_b[3]\ k\_w[2] + 
          288\ k\_b[3]\^2\ k\_w[2] + 5.35135135135134376`\ k\_b[4]\ k\_w[2] + 
          384\ k\_b[2]\ k\_b[4]\ k\_w[2] + 
          57.4054054054054052`\ k\_b[5]\ k\_w[2] + 48\ k\_b[6]\ k\_w[2] - 
          0.658961930165017584`\ k\_w[2]\^2 + 
          4.88458728999269453`\ k\_b[2]\ k\_w[2]\^2 + 
          288\ k\_b[2]\^2\ k\_w[2]\^2 + 
          114.810810810810814`\ k\_b[3]\ k\_w[2]\^2 + 
          144\ k\_b[4]\ k\_w[2]\^2 + 1.04747991234477622`\ k\_w[2]\^3 + 
          36\ k\_w[2]\^4 + 0.0540509211206392059`\ k\_w[3] - 
          0.787396600398791335`\ k\_b[2]\ k\_w[3] + 
          1.39663988312637155`\ k\_b[3]\ k\_w[3] + 
          25.5135135135135104`\ k\_b[4]\ k\_w[3] + 32\ k\_b[5]\ k\_w[3] - 
          2.34323732059305145`\ k\_w[2]\ k\_w[3] + 
          76.5405405405405492`\ k\_b[2]\ k\_w[2]\ k\_w[3] + 
          192\ k\_b[3]\ k\_w[2]\ k\_w[3] + 
          19.1351351351351368`\ k\_w[2]\^2\ k\_w[3] + 
          0.54273192111030033`\ k\_w[3]\^2 + 64\ k\_b[2]\ k\_w[3]\^2 - 
          0.0183954313423446222`\ k\_w[4] + 
          0.349159970781592887`\ k\_w[2]\ k\_w[4] + 24\ k\_w[2]\^2\ k\_w[4] + 
          6.37837837837837806`\ k\_w[3]\ k\_w[4] + 4\ k\_w[4]\^2] + 
      Log[\(0.00482641813209060099`\[InvisibleSpace]\) + 
          0.0165999087677862888`\ k\_b[2] - 
          0.686219860513584301`\ k\_b[2]\^2 + 
          3.25639152666178866`\ k\_b[2]\^3 + 96\ k\_b[2]\^4 + 
          0.398981828366097026`\ k\_b[3] - 
          12.5955817029593708`\ k\_b[2]\ k\_b[3] + 
          229.621621621621629`\ k\_b[2]\^2\ k\_b[3] + 
          5.35792549306063037`\ k\_b[3]\^2 + 576\ k\_b[2]\ k\_b[3]\^2 - 
          0.380587500220098959`\ k\_b[4] + 
          5.51570489408324426`\ k\_b[2]\ k\_b[4] + 288\ k\_b[2]\^2\ k\_b[4] + 
          191.351351351351333`\ k\_b[3]\ k\_b[4] + 136\ k\_b[4]\^2 - 
          2.77018143051744392`\ k\_b[5] + 
          76.5405405405405492`\ k\_b[2]\ k\_b[5] + 192\ k\_b[3]\ k\_b[5] + 
          0.621621621621617048`\ k\_b[6] + 64\ k\_b[2]\ k\_b[6] + 
          6.37837837837837895`\ k\_b[7] + 4\ k\_b[8] + 
          0.0135238016330524413`\ k\_w[2] - 
          0.112432709889919602`\ k\_b[2]\ k\_w[2] + 
          0.946676406135855685`\ k\_b[2]\^2\ k\_w[2] - 
          10.3232977316249696`\ k\_b[3]\ k\_w[2] + 
          229.621621621621629`\ k\_b[2]\ k\_b[3]\ k\_w[2] + 
          288\ k\_b[3]\^2\ k\_w[2] + 3.72972972972971827`\ k\_b[4]\ k\_w[2] + 
          384\ k\_b[2]\ k\_b[4]\ k\_w[2] + 
          57.4054054054054052`\ k\_b[5]\ k\_w[2] + 48\ k\_b[6]\ k\_w[2] - 
          0.633543889772542989`\ k\_w[2]\^2 + 
          4.88458728999269808`\ k\_b[2]\ k\_w[2]\^2 + 
          288\ k\_b[2]\^2\ k\_w[2]\^2 + 
          114.810810810810814`\ k\_b[3]\ k\_w[2]\^2 + 
          144\ k\_b[4]\ k\_w[2]\^2 + 0.236669101533963921`\ k\_w[2]\^3 + 
          36\ k\_w[2]\^4 + 0.125367232792902205`\ k\_w[3] - 
          2.68367125343020251`\ k\_b[2]\ k\_w[3] + 
          0.315558802045289077`\ k\_b[3]\ k\_w[3] + 
          25.5135135135135149`\ k\_b[4]\ k\_w[3] + 32\ k\_b[5]\ k\_w[3] - 
          2.09926361715989084`\ k\_w[2]\ k\_w[3] + 
          76.5405405405405492`\ k\_b[2]\ k\_w[2]\ k\_w[3] + 
          192\ k\_b[3]\ k\_w[2]\ k\_w[3] + 
          19.1351351351351368`\ k\_w[2]\^2\ k\_w[3] + 
          0.542731921110300952`\ k\_w[3]\^2 + 64\ k\_b[2]\ k\_w[3]\^2 - 
          0.0968113198385837669`\ k\_w[4] + 
          0.0788897005113222693`\ k\_w[2]\ k\_w[4] + 
          24\ k\_w[2]\^2\ k\_w[4] + 6.37837837837837895`\ k\_w[3]\ k\_w[4] + 
          4\ k\_w[4]\^2] + 
      Log[\(0.00287701065668348299`\[InvisibleSpace]\) + 
          0.0602524219925507864`\ k\_b[2] - 
          1.16923172555612997`\ k\_b[2]\^2 + 
          3.25639152666179132`\ k\_b[2]\^3 + 96\ k\_b[2]\^4 + 
          0.351743624177663161`\ k\_b[3] - 
          13.638678854164643`\ k\_b[2]\ k\_b[3] + 
          229.621621621621629`\ k\_b[2]\^2\ k\_b[3] + 
          7.30387143900657953`\ k\_b[3]\^2 + 576\ k\_b[2]\ k\_b[3]\^2 - 
          0.566973301653376449`\ k\_b[4] + 
          8.11029948867785854`\ k\_b[2]\ k\_b[4] + 288\ k\_b[2]\^2\ k\_b[4] + 
          191.351351351351368`\ k\_b[3]\ k\_b[4] + 136\ k\_b[4]\^2 - 
          2.47361459341006284`\ k\_b[5] + 
          76.5405405405405492`\ k\_b[2]\ k\_b[5] + 192\ k\_b[3]\ k\_b[5] + 
          0.945945945945944188`\ k\_b[6] + 64\ k\_b[2]\ k\_b[6] + 
          6.37837837837837895`\ k\_b[7] + 4\ k\_b[8] - 
          0.0137679600701339022`\ k\_w[2] + 
          0.0529276833740530694`\ k\_b[2]\ k\_w[2] + 
          4.83856829802775401`\ k\_b[2]\^2\ k\_w[2] - 
          8.02234813337807217`\ k\_b[3]\ k\_w[2] + 
          229.621621621621629`\ k\_b[2]\ k\_b[3]\ k\_w[2] + 
          288\ k\_b[3]\^2\ k\_w[2] + 5.67567567567565944`\ k\_b[4]\ k\_w[2] + 
          384\ k\_b[2]\ k\_b[4]\ k\_w[2] + 
          57.4054054054054052`\ k\_b[5]\ k\_w[2] + 48\ k\_b[6]\ k\_w[2] - 
          0.642881934903138052`\ k\_w[2]\^2 + 
          4.88458728999268743`\ k\_b[2]\ k\_w[2]\^2 + 
          288\ k\_b[2]\^2\ k\_w[2]\^2 + 
          114.810810810810814`\ k\_b[3]\ k\_w[2]\^2 + 
          144\ k\_b[4]\ k\_w[2]\^2 + 1.2096420745069385`\ k\_w[2]\^3 + 
          36\ k\_w[2]\^4 + 0.0550931208035906916`\ k\_w[3] - 
          0.802005804197183813`\ k\_b[2]\ k\_w[3] + 
          1.61285609934258644`\ k\_b[3]\ k\_w[3] + 
          25.5135135135135149`\ k\_b[4]\ k\_w[3] + 32\ k\_b[5]\ k\_w[3] - 
          2.27311314236076622`\ k\_w[2]\ k\_w[3] + 
          76.5405405405405492`\ k\_b[2]\ k\_w[2]\ k\_w[3] + 
          192\ k\_b[3]\ k\_w[2]\ k\_w[3] + 
          19.1351351351351368`\ k\_w[2]\^2\ k\_w[3] + 
          0.542731921110298998`\ k\_w[3]\^2 + 64\ k\_b[2]\ k\_w[3]\^2 - 
          0.0194220240416911877`\ k\_w[4] + 
          0.403214024835646611`\ k\_w[2]\ k\_w[4] + 24\ k\_w[2]\^2\ k\_w[4] + 
          6.37837837837837895`\ k\_w[3]\ k\_w[4] + 4\ k\_w[4]\^2] + 
      Log[\(0.0222959533275924393`\[InvisibleSpace]\) - 
          0.381802238588759745`\ k\_b[2] + 1.02145786834748975`\ k\_b[2]\^2 + 
          65.526661796932073`\ k\_b[2]\^3 + 96\ k\_b[2]\^4 - 
          1.43065247199550409`\ k\_b[3] + 
          59.8952875446666421`\ k\_b[2]\ k\_b[3] + 
          517.621621621621663`\ k\_b[2]\^2\ k\_b[3] + 
          152.276844411979546`\ k\_b[3]\^2 + 576\ k\_b[2]\ k\_b[3]\^2 + 
          1.61279887373603862`\ k\_b[4] + 
          170.272461650840023`\ k\_b[2]\ k\_b[4] + 288\ k\_b[2]\^2\ k\_b[4] + 
          431.351351351351386`\ k\_b[3]\ k\_b[4] + 136\ k\_b[4]\^2 + 
          12.2502714548003144`\ k\_b[5] + 
          172.54054054054051`\ k\_b[2]\ k\_b[5] + 192\ k\_b[3]\ k\_b[5] + 
          19.9189189189189193`\ k\_b[6] + 64\ k\_b[2]\ k\_b[6] + 
          14.378378378378378`\ k\_b[7] + 4\ k\_b[8] - 
          0.233328710691849749`\ k\_w[2] + 
          3.30620981868686936`\ k\_b[2]\ k\_w[2] + 
          107.973703433162881`\ k\_b[2]\^2\ k\_w[2] + 
          43.5539849564685166`\ k\_b[3]\ k\_w[2] + 
          517.621621621621663`\ k\_b[2]\ k\_b[3]\ k\_w[2] + 
          288\ k\_b[3]\^2\ k\_w[2] + 119.51351351351349`\ k\_b[4]\ k\_w[2] + 
          384\ k\_b[2]\ k\_b[4]\ k\_w[2] + 
          129.405405405405415`\ k\_b[5]\ k\_w[2] + 48\ k\_b[6]\ k\_w[2] + 
          1.08381737214678963`\ k\_w[2]\^2 + 
          98.2899926953980873`\ k\_b[2]\ k\_w[2]\^2 + 
          288\ k\_b[2]\^2\ k\_w[2]\^2 + 
          258.810810810810831`\ k\_b[3]\ k\_w[2]\^2 + 
          144\ k\_b[4]\ k\_w[2]\^2 + 26.9934258582907204`\ k\_w[2]\^3 + 
          36\ k\_w[2]\^4 - 0.0757647670726376887`\ k\_w[3] + 
          9.07089412275679585`\ k\_b[2]\ k\_w[3] + 
          35.9912344777209636`\ k\_b[3]\ k\_w[3] + 
          57.5135135135135122`\ k\_b[4]\ k\_w[3] + 32\ k\_b[5]\ k\_w[3] + 
          9.98254792411111324`\ k\_w[2]\ k\_w[3] + 
          172.54054054054051`\ k\_b[2]\ k\_w[2]\ k\_w[3] + 
          192\ k\_b[3]\ k\_w[2]\ k\_w[3] + 
          43.1351351351351297`\ k\_w[2]\^2\ k\_w[3] + 
          10.9211102994886788`\ k\_w[3]\^2 + 64\ k\_b[2]\ k\_w[3]\^2 + 
          0.191029479324348336`\ k\_w[4] + 
          8.99780861943024135`\ k\_w[2]\ k\_w[4] + 24\ k\_w[2]\^2\ k\_w[4] + 
          14.378378378378378`\ k\_w[3]\ k\_w[4] + 4\ k\_w[4]\^2] + 
      Log[\(0.0259196529315976542`\[InvisibleSpace]\) - 
          0.202426406973152728`\ k\_b[2] + 1.99639945554303732`\ k\_b[2]\^2 - 
          34.9744338933528542`\ k\_b[2]\^3 + 384\ k\_b[2]\^4 + 
          2.74826054417402065`\ k\_b[3] - 
          80.202633605117235`\ k\_b[2]\ k\_b[3] + 
          918.486486486486697`\ k\_b[2]\^2\ k\_b[3] - 
          9.0547845142439769`\ k\_b[3]\^2 + 2304\ k\_b[2]\ k\_b[3]\^2 - 
          1.92595886906194699`\ k\_b[4] + 
          5.41417092768436702`\ k\_b[2]\ k\_b[4] + 
          1152\ k\_b[2]\^2\ k\_b[4] + 
          765.405405405405225`\ k\_b[3]\ k\_b[4] + 544\ k\_b[4]\^2 - 
          12.4978184905138833`\ k\_b[5] + 
          306.162162162162188`\ k\_b[2]\ k\_b[5] + 768\ k\_b[3]\ k\_b[5] + 
          1.40540540540539504`\ k\_b[6] + 256\ k\_b[2]\ k\_b[6] + 
          25.513513513513506`\ k\_b[7] + 16\ k\_b[8] + 
          0.324605569821688622`\ k\_w[2] - 
          8.77247579050038694`\ k\_b[2]\ k\_w[2] + 
          86.8137326515704543`\ k\_b[2]\^2\ k\_w[2] - 
          34.8855941405247893`\ k\_b[3]\ k\_w[2] + 
          918.486486486486697`\ k\_b[2]\ k\_b[3]\ k\_w[2] + 
          1152\ k\_b[3]\^2\ k\_w[2] + 
          8.43243243243236229`\ k\_b[4]\ k\_w[2] + 
          1536\ k\_b[2]\ k\_b[4]\ k\_w[2] + 
          229.621621621621674`\ k\_b[5]\ k\_w[2] + 192\ k\_b[6]\ k\_w[2] + 
          1.11007058625166088`\ k\_w[2]\^2 - 
          52.4616508400292591`\ k\_b[2]\ k\_w[2]\^2 + 
          1152\ k\_b[2]\^2\ k\_w[2]\^2 + 
          459.243243243243348`\ k\_b[3]\ k\_w[2]\^2 + 
          576\ k\_b[4]\ k\_w[2]\^2 + 21.7034331628926135`\ k\_w[2]\^3 + 
          144\ k\_w[2]\^4 - 0.187590333213894844`\ k\_w[3] + 
          3.47714844135589551`\ k\_b[2]\ k\_w[3] + 
          28.9379108838568388`\ k\_b[3]\ k\_w[3] + 
          102.054054054054033`\ k\_b[4]\ k\_w[3] + 128\ k\_b[5]\ k\_w[3] - 
          13.3671056008528621`\ k\_w[2]\ k\_w[3] + 
          306.162162162162188`\ k\_b[2]\ k\_w[2]\ k\_w[3] + 
          768\ k\_b[3]\ k\_w[2]\ k\_w[3] + 
          76.5405405405405492`\ k\_w[2]\^2\ k\_w[3] - 
          5.82907231555880045`\ k\_w[3]\^2 + 256\ k\_b[2]\ k\_w[3]\^2 + 
          0.0372902861600468682`\ k\_w[4] + 
          7.23447772096420926`\ k\_w[2]\ k\_w[4] + 96\ k\_w[2]\^2\ k\_w[4] + 
          25.513513513513506`\ k\_w[3]\ k\_w[4] + 16\ k\_w[4]\^2]\)], "Output",\

  CellLabel->"Out[278]="]
}, Closed]],

Cell[TextData[Cell[BoxData[
    FormBox[GridBox[{
          {
            RowBox[{
              RowBox[{
                FormBox[
                  RowBox[{"LogLikelihoodDisequilibriumReduced", "[", 
                    RowBox[{
                      StyleBox["site",
                        FontSlant->"Italic"], ",", \({k\_w, k\_b}\)}]}],
                  "TraditionalForm"], ",", "\[Delta]p", ",", "p"}], "]"}], 
            \(is\ a\ fully\ compiled\ \(version . \)\)},
          {
            RowBox[{
              RowBox[{
                FormBox[
                  RowBox[{"LogLikelihoodDisequilibriumReduced", "[", 
                    RowBox[{
                      StyleBox["site",
                        FontSlant->"Italic"], ",", \({k\_w, k\_b}\)}]}],
                  "TraditionalForm"], ",", "p"}], "]"}], 
            \(is\ the\ fastest\ method\ if\ \[Delta]p = 
              1. \ \ Uses\ a\ matrix\ \(method . \)\)}
          }], TraditionalForm]]]], "DefinitionBox"],

Cell["\<\
This gives the log likelihood for numerical values of the \
cumulants:\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(Timing[
      LogLikelihoodDisequilibriumReduced[
        1063, {{0.002, 0.0001, 0}, {0.0005, 0.0001, 0, 0.00001, 0, 0, 0}}, 
        1&, pp]]\)], "Input",
  CellLabel->"In[320]:="],

Cell[BoxData[
    \({0.183333333330665482`\ Second, \(-167.850315101081859`\)}\)], "Output",\

  CellLabel->"Out[320]="]
}, Closed]],

Cell[TextData[
"Note that \[Delta]p, p are still supplied as functions."], "Text"],

Cell[TextData[
"This is a much faster version which can be used if \[Delta]p=1:"], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(Timing[
      LogLikelihoodDisequilibriumReduced[
        1063, {{0.002, 0.0001, 0}, {0.0005, 0.0001, 0, 0.00001, 0, 0, 0}}, 
        pl]]\)], "Input",
  CellLabel->"In[321]:="],

Cell[BoxData[
    \({0.0499999999992724042`\ Second, \(-167.850315101081859`\)}\)], "Output",\

  CellLabel->"Out[321]="]
}, Closed]],

Cell["This is an impossible value:", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(LogLikelihoodDisequilibriumReduced[
      1063, {{0.01, 0.0001, 0}, {0.0005, 0.001, 0, 0.0001, 0, 0, 0}}, pl]\)], 
  "Input",
  CellLabel->"In[322]:="],

Cell[BoxData[
    \(\(-10000000000\)\)], "Output",
  CellLabel->"Out[322]="]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["\<\
Estimating the reduced set of moments: \
MetropolisDisequilibriumReduced[]\
\>", "SubsubsectionIcon"],

Cell[TextData[Cell[BoxData[
    FormBox[GridBox[{
          {
            RowBox[{"MetropolisDisequilibriumReduced", "[", 
              RowBox[{
                StyleBox["site",
                  FontSlant->"Italic"], ",", "T", ",", 
                RowBox[{"{", 
                  RowBox[{
                    StyleBox["ntries",
                      FontSlant->"Italic"], ",", 
                    StyleBox["nprint",
                      FontSlant->"Italic"]}], "}"}], 
                ",", \({L, {{p\_1,  .. }, {c\_w[2],  .. , c\_b[2] .. }}, 
                  step\_0}\)}], 
              "]"}], \(applies\ the\ Metropolis\ algorithm, \ 
            using\ temperature\ T\ to\ optimise\ allele\ frequencies\ and\ \
the\ reduced\ set\ of\ moments . \ \ Assumes\ \[Delta]p = 1. \)}
          }], TraditionalForm]]]], "DefinitionBox",
  CellTags->"MetropolisDisequilibriumReduced"],

Cell["This finds an appropriate initial step size:", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(is = InitialStep[{c\_w, c\_b}, cl, 1&, pp, Range[4]]\)], "Input"],

Cell[BoxData[
    \({{0.0149681649608681155`, 0.00611353626491947643`, 
        0.00735276658888964362`}, {0.00407819560417021964`, 
        0.000316119247231359823`, 0.0000615331547087157382`, 
        0.0000220191513548579864`, 0.0000131373019491736142`, 
        0.000013800071452002709`, 0.0000331947664656281338`}}\)], "Output",
  CellLabel->"Out[330]="]
}, Closed]],

Cell["\<\
This can be slow, since it involves checking the many constraints \
on genotype frequencies.\
\>", "Text"],

Cell["\<\
This applies the Metropolis algorithm 500 times to each parameter, \
printing results every 50 times:\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(MetropolisDisequilibriumReduced[1063, 
      1, {500, 50}, {L0, {pl, cl}, {0.05 \@\( pl \((1 - pl)\)\), is}}]\)], 
  "Input",
  CellLabel->"In[367]:="],

Cell[BoxData[
    InterpretationBox[
      \(50\[InvisibleSpace]"\t"\[InvisibleSpace]"  \
log(L)="\[InvisibleSpace]\(-47.5146049108147394`
          \)\[InvisibleSpace]"\t"\[InvisibleSpace]"% accepted="\
\[InvisibleSpace]0.66714285714285717`\),
      SequenceForm[ 
      50, "\t", "  log(L)=", -47.514604910814739, "\t", "% accepted=", 
        0.66714285714285715],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \(100\[InvisibleSpace]"\t"\[InvisibleSpace]"  log(L)="\[InvisibleSpace]\
\(-37.1854639748204629`
          \)\[InvisibleSpace]"\t"\[InvisibleSpace]"% accepted="\
\[InvisibleSpace]0.577142857142857224`\),
      SequenceForm[ 
      100, "\t", "  log(L)=", -37.185463974820465, "\t", "% accepted=", 
        0.57714285714285718],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \(150\[InvisibleSpace]"\t"\[InvisibleSpace]"  log(L)="\[InvisibleSpace]\
\(-36.0280383719127161`
          \)\[InvisibleSpace]"\t"\[InvisibleSpace]"% accepted="\
\[InvisibleSpace]0.541904761904761933`\),
      SequenceForm[ 
      150, "\t", "  log(L)=", -36.028038371912714, "\t", "% accepted=", 
        0.54190476190476189],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \(200\[InvisibleSpace]"\t"\[InvisibleSpace]"  log(L)="\[InvisibleSpace]\
\(-38.4774719568688094`
          \)\[InvisibleSpace]"\t"\[InvisibleSpace]"% accepted="\
\[InvisibleSpace]0.538571428571428612`\),
      SequenceForm[ 
      200, "\t", "  log(L)=", -38.477471956868811, "\t", "% accepted=", 
        0.53857142857142859],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \(250\[InvisibleSpace]"\t"\[InvisibleSpace]"  log(L)="\[InvisibleSpace]\
\(-40.0026927884897265`
          \)\[InvisibleSpace]"\t"\[InvisibleSpace]"% accepted="\
\[InvisibleSpace]0.534571428571428608`\),
      SequenceForm[ 
      250, "\t", "  log(L)=", -40.002692788489725, "\t", "% accepted=", 
        0.53457142857142859],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \(300\[InvisibleSpace]"\t"\[InvisibleSpace]"  log(L)="\[InvisibleSpace]\
\(-35.4147794013570083`
          \)\[InvisibleSpace]"\t"\[InvisibleSpace]"% accepted="\
\[InvisibleSpace]0.527619047619047698`\),
      SequenceForm[ 
      300, "\t", "  log(L)=", -35.414779401357009, "\t", "% accepted=", 
        0.52761904761904765],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \(350\[InvisibleSpace]"\t"\[InvisibleSpace]"  log(L)="\[InvisibleSpace]\
\(-34.879542770694969`
          \)\[InvisibleSpace]"\t"\[InvisibleSpace]"% accepted="\
\[InvisibleSpace]0.520000000000000017`\),
      SequenceForm[ 
      350, "\t", "  log(L)=", -34.879542770694968, "\t", "% accepted=", 
        0.52000000000000002],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \(400\[InvisibleSpace]"\t"\[InvisibleSpace]"  log(L)="\[InvisibleSpace]\
\(-38.5092300409200749`
          \)\[InvisibleSpace]"\t"\[InvisibleSpace]"% accepted="\
\[InvisibleSpace]0.522321428571428647`\),
      SequenceForm[ 
      400, "\t", "  log(L)=", -38.509230040920073, "\t", "% accepted=", 
        0.5223214285714286],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \(450\[InvisibleSpace]"\t"\[InvisibleSpace]"  log(L)="\[InvisibleSpace]\
\(-34.7139676350833514`
          \)\[InvisibleSpace]"\t"\[InvisibleSpace]"% accepted="\
\[InvisibleSpace]0.51730158730158724`\),
      SequenceForm[ 
      450, "\t", "  log(L)=", -34.71396763508335, "\t", "% accepted=", 
        0.51730158730158726],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \(500\[InvisibleSpace]"\t"\[InvisibleSpace]"  log(L)="\[InvisibleSpace]\
\(-36.2431342235890951`
          \)\[InvisibleSpace]"\t"\[InvisibleSpace]"% accepted="\
\[InvisibleSpace]0.515000000000000035`\),
      SequenceForm[ 
      500, "\t", "  log(L)=", -36.243134223589095, "\t", "% accepted=", 
        0.51500000000000001],
      Editable->False]], "Print"],

Cell[BoxData[
    \({\(-36.2431342235890951`
        \), {{0.400897683943800409`, 0.272532805273218858`, 
          0.285983136405454896`, 0.30739901689860245`}, {
          0.0311819203450341841`, \(-0.00690725866532952093`\), 
          0.00273624074725148203`, 0.0454027394251170868`, 
          0.00265323602083098553`, \(-0.00135036711386097785`\), 
          0.0013310047412268684`, 0.000724048073677643522`, 
          \(-0.00128567141928078898`\), \(-0.000969359039415407863`\)}}, {
        0.086423813754890908`, 0.0831724981624414994`, 
        0.0671280162532022828`, 0.124884097488511192`, 
        0.0149681649608681111`, 0.00931799461197908485`, 
        0.0138355275353042816`, 0.00621581405909193751`, 
        0.00111928536643201281`, 0.000506126401618299137`, 
        0.000276045295559157199`, 0.000251024388381762175`, 
        0.000401902801022229105`, 0.000634277569454349521`}}\)], "Output",
  CellLabel->"Out[367]="]
}, Closed]],

Cell[TextData[{
  "The initial step size for the allele vfrequencies is given (arbitrarily) \
as the list ",
  Cell[BoxData[
      \(0.05 \@\( p\[VeryThinSpace]q\)\)]],
  ", and the step size for the moments is derived from InitialStep[].  These \
lists are flattened internally, so their structure is not crucial.  The first \
four parameters are the allele frequencies; the last ten are the 3 \
within-genome moments ",
  Cell[BoxData[
      \(TraditionalForm\`c\_w\)]],
  ", followed by the 7 between-genome moments, ",
  Cell[BoxData[
      \(TraditionalForm\`c\_b\)]],
  "."
}], "Text"],

Cell[TextData[{
  "With ",
  Cell[BoxData[
      \(TraditionalForm\`\(T = \)\)]],
  "1, a random walk is generated, with density proportional to the \
likelihood.  To find the optimum, set ",
  Cell[BoxData[
      \(TraditionalForm\`T = 0\)]],
  ":"
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(met = MetropolisDisequilibriumReduced[1063, 0, {500, 50}, %]\)], "Input",\

  CellLabel->"In[368]:="],

Cell[BoxData[
    InterpretationBox[
      \(50\[InvisibleSpace]"\t"\[InvisibleSpace]"  \
log(L)="\[InvisibleSpace]\(-31.49374569938439`
          \)\[InvisibleSpace]"\t"\[InvisibleSpace]"% accepted="\
\[InvisibleSpace]0.0957142857142857117`\),
      SequenceForm[ 
      50, "\t", "  log(L)=", -31.493745699384391, "\t", "% accepted=", 
        0.09571428571428571],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \(100\[InvisibleSpace]"\t"\[InvisibleSpace]"  log(L)="\[InvisibleSpace]\
\(-31.4919815738074371`
          \)\[InvisibleSpace]"\t"\[InvisibleSpace]"% accepted="\
\[InvisibleSpace]0.0707142857142857206`\),
      SequenceForm[ 
      100, "\t", "  log(L)=", -31.491981573807436, "\t", "% accepted=", 
        0.070714285714285716],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \(150\[InvisibleSpace]"\t"\[InvisibleSpace]"  log(L)="\[InvisibleSpace]\
\(-31.4919780984689046`
          \)\[InvisibleSpace]"\t"\[InvisibleSpace]"% accepted="\
\[InvisibleSpace]0.0595238095238095255`\),
      SequenceForm[ 
      150, "\t", "  log(L)=", -31.491978098468906, "\t", "% accepted=", 
        0.059523809523809521],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \(200\[InvisibleSpace]"\t"\[InvisibleSpace]"  log(L)="\[InvisibleSpace]\
\(-31.4919780671795024`
          \)\[InvisibleSpace]"\t"\[InvisibleSpace]"% accepted="\
\[InvisibleSpace]0.05`\),
      SequenceForm[ 
      200, "\t", "  log(L)=", -31.491978067179502, "\t", "% accepted=", 
        0.050000000000000003],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \(250\[InvisibleSpace]"\t"\[InvisibleSpace]"  log(L)="\[InvisibleSpace]\
\(-31.4919780668170989`
          \)\[InvisibleSpace]"\t"\[InvisibleSpace]"% accepted="\
\[InvisibleSpace]0.0548571428571428487`\),
      SequenceForm[ 
      250, "\t", "  log(L)=", -31.491978066817097, "\t", "% accepted=", 
        0.054857142857142854],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \(300\[InvisibleSpace]"\t"\[InvisibleSpace]"  log(L)="\[InvisibleSpace]\
\(-31.4919780666483584`
          \)\[InvisibleSpace]"\t"\[InvisibleSpace]"% accepted="\
\[InvisibleSpace]0.0659523809523809667`\),
      SequenceForm[ 
      300, "\t", "  log(L)=", -31.491978066648358, "\t", "% accepted=", 
        0.065952380952380957],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \(350\[InvisibleSpace]"\t"\[InvisibleSpace]"  log(L)="\[InvisibleSpace]\
\(-31.4919780666481008`
          \)\[InvisibleSpace]"\t"\[InvisibleSpace]"% accepted="\
\[InvisibleSpace]0.0581632653061224491`\),
      SequenceForm[ 
      350, "\t", "  log(L)=", -31.491978066648102, "\t", "% accepted=", 
        0.058163265306122446],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \(400\[InvisibleSpace]"\t"\[InvisibleSpace]"  log(L)="\[InvisibleSpace]\
\(-31.4919780666481008`
          \)\[InvisibleSpace]"\t"\[InvisibleSpace]"% accepted="\
\[InvisibleSpace]0.0508928571428571352`\),
      SequenceForm[ 
      400, "\t", "  log(L)=", -31.491978066648102, "\t", "% accepted=", 
        0.050892857142857142],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \(450\[InvisibleSpace]"\t"\[InvisibleSpace]"  log(L)="\[InvisibleSpace]\
\(-31.4919780666481008`
          \)\[InvisibleSpace]"\t"\[InvisibleSpace]"% accepted="\
\[InvisibleSpace]0.0452380952380952372`\),
      SequenceForm[ 
      450, "\t", "  log(L)=", -31.491978066648102, "\t", "% accepted=", 
        0.045238095238095237],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \(500\[InvisibleSpace]"\t"\[InvisibleSpace]"  log(L)="\[InvisibleSpace]\
\(-31.4919780666481008`
          \)\[InvisibleSpace]"\t"\[InvisibleSpace]"% accepted="\
\[InvisibleSpace]0.0407142857142857117`\),
      SequenceForm[ 
      500, "\t", "  log(L)=", -31.491978066648102, "\t", "% accepted=", 
        0.040714285714285717],
      Editable->False]], "Print"],

Cell[BoxData[
    \({\(-31.4919780666481008`
        \), {{0.414205257575556373`, 0.248582578871306481`, 
          0.318679645301361702`, 0.277199354537601072`}, {
          0.0353062937557470135`, \(-0.0108631039824458186`\), 
          0.00147086730090460404`, 0.0541894761686427095`, 
          0.00144635994451325`, \(-0.00153077750136311436`\), 
          0.0016184816582528791`, 0.000716709049169941714`, 
          \(-0.00117616363119727052`\), \(-0.00106068604162464286`\)}}, {
        2.73701801531747079`*^-22, 3.20238957803980017`*^-23, 
        4.93864678806899615`*^-22, 9.04787309569848119`*^-23, 
        8.78401240907697911`*^-24, 4.42926692856394854`*^-24, 
        1.23751384129247887`*^-23, 3.64772755847635954`*^-24, 
        3.49076218211476962`*^-25, 1.57847762074382957`*^-25, 
        3.76326372744373038`*^-25, 2.77194903324007269`*^-25, 
        6.76426040601858513`*^-25, 1.62707885442068711`*^-24}}\)], "Output",
  CellLabel->"Out[368]="]
}, Closed]],

Cell[TextData[{
  "In this example, convergence to ",
  Cell[BoxData[
      \(TraditionalForm\`log[L] = \(-31.49\)\)]],
  " is rapid.  The step size tends to zero as most changes are rejected.  \
Note that the output can be fed directly as the input to the next stage of \
the algorithm."
}], "Text"],

Cell["This compares the actual and MLE allele frequencies:", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \({\(\(pTable[1063, 4] // Transpose\) // N\) // Last, 
        met\[LeftDoubleBracket]2, 1\[RightDoubleBracket]} // TableForm\)], 
  "Input",
  CellLabel->"In[376]:="],

Cell[BoxData[
    TagBox[GridBox[{
          {"0.391891891891891894`", "0.175675675675675684`", 
            "0.324324324324324342`", "0.310810810810810789`"},
          {"0.414205257575556373`", "0.248582578871306481`", 
            "0.318679645301361702`", "0.277199354537601072`"}
          },
        RowSpacings->1,
        ColumnSpacings->3,
        RowAlignments->Baseline,
        ColumnAlignments->{Left}],
      (TableForm[ #]&)]], "Output",
  CellLabel->"Out[376]//TableForm="]
}, Closed]],

Cell[TextData[{
  "In order to fix certain parameters, the step size can be set to zero.  For \
example, fixing allele frequencies at the observed values reduces ",
  Cell[BoxData[
      \(TraditionalForm\`log[L]\)]],
  " by 1.46, with 4 ",
  StyleBox["d.f.",
    FontSlant->"Italic"],
  ":"
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(MetropolisDisequilibriumReduced[1063, 
      1, {500, 50}, {L0, {pl, cl}, {0*\@\(pl \((1 - pl)\)\), is}}]\)], "Input",\

  CellLabel->"In[381]:="],

Cell[BoxData[
    InterpretationBox[
      \(50\[InvisibleSpace]"\t"\[InvisibleSpace]"  \
log(L)="\[InvisibleSpace]\(-34.7927937743234583`
          \)\[InvisibleSpace]"\t"\[InvisibleSpace]"% accepted="\
\[InvisibleSpace]0.613999999999999968`\),
      SequenceForm[ 
      50, "\t", "  log(L)=", -34.792793774323457, "\t", "% accepted=", 
        0.61399999999999999],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \(100\[InvisibleSpace]"\t"\[InvisibleSpace]"  log(L)="\[InvisibleSpace]\
\(-36.0661492823757878`
          \)\[InvisibleSpace]"\t"\[InvisibleSpace]"% accepted="\
\[InvisibleSpace]0.579999999999999982`\),
      SequenceForm[ 
      100, "\t", "  log(L)=", -36.06614928237579, "\t", "% accepted=", 
        0.57999999999999996],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \(150\[InvisibleSpace]"\t"\[InvisibleSpace]"  log(L)="\[InvisibleSpace]\
\(-37.0790994079604008`
          \)\[InvisibleSpace]"\t"\[InvisibleSpace]"% accepted="\
\[InvisibleSpace]0.556666666666666642`\),
      SequenceForm[ 
      150, "\t", "  log(L)=", -37.079099407960399, "\t", "% accepted=", 
        0.55666666666666664],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \(200\[InvisibleSpace]"\t"\[InvisibleSpace]"  log(L)="\[InvisibleSpace]\
\(-36.2522545159232834`
          \)\[InvisibleSpace]"\t"\[InvisibleSpace]"% accepted="\
\[InvisibleSpace]0.54300000000000006`\),
      SequenceForm[ 
      200, "\t", "  log(L)=", -36.252254515923283, "\t", "% accepted=", 
        0.54300000000000004],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \(250\[InvisibleSpace]"\t"\[InvisibleSpace]"  log(L)="\[InvisibleSpace]\
\(-36.448786153128112`
          \)\[InvisibleSpace]"\t"\[InvisibleSpace]"% accepted="\
\[InvisibleSpace]0.529599999999999937`\),
      SequenceForm[ 
      250, "\t", "  log(L)=", -36.448786153128111, "\t", "% accepted=", 
        0.52959999999999996],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \(300\[InvisibleSpace]"\t"\[InvisibleSpace]"  log(L)="\[InvisibleSpace]\
\(-37.1646215694087533`
          \)\[InvisibleSpace]"\t"\[InvisibleSpace]"% accepted="\
\[InvisibleSpace]0.525`\),
      SequenceForm[ 
      300, "\t", "  log(L)=", -37.164621569408752, "\t", "% accepted=", 
        0.52500000000000002],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \(350\[InvisibleSpace]"\t"\[InvisibleSpace]"  log(L)="\[InvisibleSpace]\
\(-34.2731377120366875`
          \)\[InvisibleSpace]"\t"\[InvisibleSpace]"% accepted="\
\[InvisibleSpace]0.516000000000000014`\),
      SequenceForm[ 
      350, "\t", "  log(L)=", -34.273137712036686, "\t", "% accepted=", 
        0.51600000000000001],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \(400\[InvisibleSpace]"\t"\[InvisibleSpace]"  log(L)="\[InvisibleSpace]\
\(-34.0123462578192725`
          \)\[InvisibleSpace]"\t"\[InvisibleSpace]"% accepted="\
\[InvisibleSpace]0.512750000000000039`\),
      SequenceForm[ 
      400, "\t", "  log(L)=", -34.012346257819274, "\t", "% accepted=", 
        0.51275000000000004],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \(450\[InvisibleSpace]"\t"\[InvisibleSpace]"  log(L)="\[InvisibleSpace]\
\(-33.4532992152058739`
          \)\[InvisibleSpace]"\t"\[InvisibleSpace]"% accepted="\
\[InvisibleSpace]0.51200000000000001`\),
      SequenceForm[ 
      450, "\t", "  log(L)=", -33.453299215205874, "\t", "% accepted=", 
        0.51200000000000001],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \(500\[InvisibleSpace]"\t"\[InvisibleSpace]"  log(L)="\[InvisibleSpace]\
\(-34.2785412435068215`
          \)\[InvisibleSpace]"\t"\[InvisibleSpace]"% accepted="\
\[InvisibleSpace]0.514800000000000057`\),
      SequenceForm[ 
      500, "\t", "  log(L)=", -34.278541243506822, "\t", "% accepted=", 
        0.51480000000000004],
      Editable->False]], "Print"],

Cell[BoxData[
    \({\(-34.2785412435068215`
        \), {{0.391891891891891894`, 0.175675675675675657`, 
          0.324324324324324342`, 0.310810810810810878`}, {
          0.0162783225010609022`, \(-0.00387377422742647183`\), 
          \(-0.00561054465614272146`\), 0.0304281126374397903`, 
          0.000297892129669891136`, \(-0.00158216572602476723`\), 
          \(-0.0000338132374402213109`\), 0.000532243117149225231`, 
          \(-0.0000897670877180116733`\), \(-0.000841168941401461367`\)}}, {
        0, 0, 0, 0, 0.0149681649608681066`, 0.00754757563570305833`, 
        0.00595574093700061091`, 0.00947388212024376841`, 
        0.00170596763668954887`, 0.000506126401618299137`, 
        0.000340796661184144822`, 0.000251024388381762086`, 
        0.000325541268828005669`, 0.000273035695688595136`}}\)], "Output",
  CellLabel->"Out[381]="]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    \(MetropolisDisequilibriumReduced[1063, 0, {500, 50}, %]\)], "Input",
  CellLabel->"In[382]:="],

Cell[BoxData[
    InterpretationBox[
      \(50\[InvisibleSpace]"\t"\[InvisibleSpace]"  \
log(L)="\[InvisibleSpace]\(-32.9740032119942716`
          \)\[InvisibleSpace]"\t"\[InvisibleSpace]"% accepted="\
\[InvisibleSpace]0.132000000000000006`\),
      SequenceForm[ 
      50, "\t", "  log(L)=", -32.974003211994273, "\t", "% accepted=", 
        0.13200000000000001],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \(100\[InvisibleSpace]"\t"\[InvisibleSpace]"  log(L)="\[InvisibleSpace]\
\(-32.9480094150547708`
          \)\[InvisibleSpace]"\t"\[InvisibleSpace]"% accepted="\
\[InvisibleSpace]0.146999999999999992`\),
      SequenceForm[ 
      100, "\t", "  log(L)=", -32.94800941505477, "\t", "% accepted=", 
        0.14699999999999999],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \(150\[InvisibleSpace]"\t"\[InvisibleSpace]"  log(L)="\[InvisibleSpace]\
\(-32.9471070138148425`
          \)\[InvisibleSpace]"\t"\[InvisibleSpace]"% accepted="\
\[InvisibleSpace]0.110000000000000008`\),
      SequenceForm[ 
      150, "\t", "  log(L)=", -32.947107013814843, "\t", "% accepted=", 
        0.11],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \(200\[InvisibleSpace]"\t"\[InvisibleSpace]"  log(L)="\[InvisibleSpace]\
\(-32.9471069802356719`
          \)\[InvisibleSpace]"\t"\[InvisibleSpace]"% accepted="\
\[InvisibleSpace]0.0845000000000000106`\),
      SequenceForm[ 
      200, "\t", "  log(L)=", -32.947106980235674, "\t", "% accepted=", 
        0.084500000000000006],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \(250\[InvisibleSpace]"\t"\[InvisibleSpace]"  log(L)="\[InvisibleSpace]\
\(-32.947106980234766`
          \)\[InvisibleSpace]"\t"\[InvisibleSpace]"% accepted="\
\[InvisibleSpace]0.0684000000000000074`\),
      SequenceForm[ 
      250, "\t", "  log(L)=", -32.947106980234764, "\t", "% accepted=", 
        0.068400000000000002],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \(300\[InvisibleSpace]"\t"\[InvisibleSpace]"  log(L)="\[InvisibleSpace]\
\(-32.9471069802315508`
          \)\[InvisibleSpace]"\t"\[InvisibleSpace]"% accepted="\
\[InvisibleSpace]0.062333333333333325`\),
      SequenceForm[ 
      300, "\t", "  log(L)=", -32.947106980231553, "\t", "% accepted=", 
        0.062333333333333331],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \(350\[InvisibleSpace]"\t"\[InvisibleSpace]"  log(L)="\[InvisibleSpace]\
\(-32.9471069802314664`
          \)\[InvisibleSpace]"\t"\[InvisibleSpace]"% accepted="\
\[InvisibleSpace]0.0542857142857142793`\),
      SequenceForm[ 
      350, "\t", "  log(L)=", -32.947106980231467, "\t", "% accepted=", 
        0.054285714285714284],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \(400\[InvisibleSpace]"\t"\[InvisibleSpace]"  log(L)="\[InvisibleSpace]\
\(-32.9471069802314664`
          \)\[InvisibleSpace]"\t"\[InvisibleSpace]"% accepted="\
\[InvisibleSpace]0.0475`\),
      SequenceForm[ 
      400, "\t", "  log(L)=", -32.947106980231467, "\t", "% accepted=", 
        0.047500000000000001],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \(450\[InvisibleSpace]"\t"\[InvisibleSpace]"  log(L)="\[InvisibleSpace]\
\(-32.9471069802314664`
          \)\[InvisibleSpace]"\t"\[InvisibleSpace]"% accepted="\
\[InvisibleSpace]0.0422222222222222232`\),
      SequenceForm[ 
      450, "\t", "  log(L)=", -32.947106980231467, "\t", "% accepted=", 
        0.042222222222222223],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \(500\[InvisibleSpace]"\t"\[InvisibleSpace]"  log(L)="\[InvisibleSpace]\
\(-32.9471069802314664`
          \)\[InvisibleSpace]"\t"\[InvisibleSpace]"% accepted="\
\[InvisibleSpace]0.0379999999999999982`\),
      SequenceForm[ 
      500, "\t", "  log(L)=", -32.947106980231467, "\t", "% accepted=", 
        0.037999999999999999],
      Editable->False]], "Print"],

Cell[BoxData[
    \({\(-32.9471069802314664`
        \), {{0.391891891891891894`, 0.175675675675675657`, 
          0.324324324324324342`, 0.310810810810810878`}, {
          0.0200747341661982581`, \(-0.00620404545061622947`\), 
          0.00612100849678631409`, 0.0309579653729591175`, 
          0.000220088996113644075`, \(-0.00141226379856171817`\), 
          0.000233265145628353476`, 0.000412549893985974414`, 
          \(-0.000137806457347287514`\), \(-0.000607013914856879832`\)}}, {0, 
        0, 0, 0, 7.11505005135235357`*^-24, 3.58770621213679863`*^-24, 
        3.49510460585056748`*^-24, 1.93855198140423503`*^-24, 
        4.30958294088243043`*^-25, 2.40584913998449856`*^-25, 
        2.46907733157583253`*^-25, 1.49590870618501536`*^-24, 
        2.35855176680075384`*^-25, 1.06752643638541289`*^-24}}\)], "Output",
  CellLabel->"Out[382]="]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["Finding the initial step size: InitialStepReduced[]", \
"SubsubsectionIcon"],

Cell[TextData[Cell[BoxData[
    FormBox[GridBox[{
          {
            RowBox[{
              RowBox[{
                RowBox[{
                  FormBox[
                    RowBox[{
                      FormBox[\(\(InitialStepReduced\)\([\)\({c\_w\)\),
                        "TraditionalForm"], ",", \(c\_b\)}],
                    "TraditionalForm"], "}"}], ",", "cl", ",", "\[Delta]p", 
                ",", "p", ",", "S"}], 
              "]"}], \(sets\ a\ sensible\ initial\ step\ size\ for\ the\ \
reduced\ set\ of\ moments, \ c\_w, \ c\_b\)}
          }], TraditionalForm]]]], "DefinitionBox",
  CellTags->"InitialStepReduced"],

Cell[TextData[
"This sets an initial step size for the Metropolis algorithm, \
MetropolisDisequilibrium[].  The allele frequencies at the four loci are \
supplied by the function pp[1],\[Ellipsis]  "], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(pp/@Range[4]\)], "Input",
  CellLabel->"In[329]:="],

Cell[BoxData[
    \({0.608108108108108069`, 0.824324324324324386`, 0.675675675675675613`, 
      0.689189189189189121`}\)], "Output",
  CellLabel->"Out[329]="]
}, Closed]],

Cell["\<\
The initial moments are supplied as a list of numerical \
values:\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(cl\)], "Input",
  CellLabel->"In[328]:="],

Cell[BoxData[
    RowBox[{"{", 
      RowBox[{
        RowBox[{"{", 
          RowBox[{
            StyleBox["0.001`",
              StyleBoxAutoDelete->True,
              PrintPrecision->1], ",", 
            StyleBox["0.0001`",
              StyleBoxAutoDelete->True,
              PrintPrecision->1], ",", "0"}], "}"}], ",", 
        RowBox[{"{", 
          RowBox[{
            StyleBox["0.0005`",
              StyleBoxAutoDelete->True,
              PrintPrecision->1], ",", 
            StyleBox["0.0001`",
              StyleBoxAutoDelete->True,
              PrintPrecision->1], ",", "0", ",", 
            StyleBox["0.00001`",
              StyleBoxAutoDelete->True,
              PrintPrecision->1], ",", "0", ",", "0", ",", "0"}], "}"}]}], 
      "}"}]], "Output",
  CellLabel->"Out[328]="]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    \(InitialStep[{c\_w, c\_b}, cl, 1&, pp, Range[4]]\)], "Input",
  CellLabel->"In[326]:="],

Cell[BoxData[
    \({{0.0149681649608681155`, 0.00611353626491947643`, 
        0.00735276658888964362`}, {0.00407819560417021964`, 
        0.000316119247231359823`, 0.0000615331547087157382`, 
        0.0000220191513548579864`, 0.0000131373019491736142`, 
        0.000013800071452002709`, 0.0000331947664656281338`}}\)], "Output",
  CellLabel->"Out[326]="]
}, Closed]],

Cell["\<\
This is a slow algorithm, because all the constraints on diploid \
genotype frequencies need to be satisfied by any perturbation to the moments.\
\
\>", "Text"]
}, Closed]],

Cell[CellGroupData[{

Cell["Handling intervals: IntervalCombine[], IntervalPosition[]", \
"SubsubsectionIcon"],

Cell[TextData[Cell[BoxData[
    FormBox[GridBox[{
          {\(IntervalCombine[{{x1, y1}, {x2, y2},  .. }, {{X1, Y1}, {X2, 
                  Y2},  .. },  .. ]\), \(\(\ \)\(combines\ the\ lists\ of\ \
intervals\)\)},
          {\(IntervalPosition[{{x\_1, y\_1}, {x\_2, y\_2} \[Ellipsis]}, 
              z]\), \(returns\  - 
              k\ if\ z\ is\ just\ after\ the\ k' th\ interval\ and\  + 
              k\ if\ it\ is\ in\ the\ k' th\ \(\(interval\)\(.\)\)\)}
          }], TraditionalForm]]]], "DefinitionBox",
  CellTags->{"IntervalCombine", "IntervalPosition"}],

Cell["Seems to be broken:", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(IntervalCombine[{{\(-3\), 0}, {2, 4}}, {{\(-4\), \(-1\)}, {5, 6}}]\)], 
  "Input",
  CellLabel->"In[115]:="],

Cell[BoxData[
    \({{\(-3\), \(-1\)}}\)], "Output",
  CellLabel->"Out[115]="]
}, Open  ]],

Cell["\<\
IntervalPosition[] determines in which interval a value lies:\
\>", 
  "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(IntervalPosition[{{\(-3\), 0}, {2, 4}, {5, 6}}, 1]\)], "Input",
  CellLabel->"In[116]:="],

Cell[BoxData[
    \(\(-1\)\)], "Output",
  CellLabel->"Out[116]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(IntervalPosition[{{\(-3\), 0}, {2, 4}, {5, 6}}, 3]\)], "Input",
  CellLabel->"In[117]:="],

Cell[BoxData[
    \(2\)], "Output",
  CellLabel->"Out[117]="]
}, Open  ]]
}, Closed]]
}, Open  ]]
},
FrontEndVersion->"4.0 for Macintosh",
ScreenRectangle->{{0, 1024}, {0, 748}},
WindowSize->{845, 689},
WindowMargins->{{5, Automatic}, {Automatic, 0}},
StyleDefinitions -> "HelpBrowser.nb",
MacintoshSystemPageSetup->"\<\
00<0001804P000000`d26_oQon@3:`8g0dL5N`?P0080001804P000000]P2:001
0000I00000400`<30?l00BL?00400@0000000000000006P801T1T00000000000
00000000004000000000000000000000\>"
]


(***********************************************************************
Cached data follows.  If you edit this Notebook file directly, not using
Mathematica, you must remove the line containing CacheID at the top of 
the file.  The cache data will then be recreated when you save this file 
from within Mathematica.
***********************************************************************)

(*CellTagsOutline
CellTagsIndex->{
  "DiploidGenotypeFrequencyReduced"->{
    Cell[3559, 107, 243, 6, 24, "SubsubsectionIcon",
      CellTags->{
      "DiploidGenotypeFrequencyReduced", "FullGenotypeFrequencyReduced"}],
    Cell[3805, 115, 507, 11, 50, "DefinitionBox",
      CellTags->"DiploidGenotypeFrequencyReduced"]},
  "FullGenotypeFrequencyReduced"->{
    Cell[3559, 107, 243, 6, 24, "SubsubsectionIcon",
      CellTags->{
      "DiploidGenotypeFrequencyReduced", "FullGenotypeFrequencyReduced"}],
    Cell[41076, 794, 694, 18, 65, "DefinitionBox",
      CellTags->"FullGenotypeFrequencyReduced"]},
  "FullGenotypeFrequencyTable"->{
    Cell[81977, 1533, 813, 17, 50, "DefinitionBox",
      CellTags->"FullGenotypeFrequencyTable"]},
  "GenotypeFrequencyArguments"->{
    Cell[94326, 1907, 314, 8, 27, "Input",
      CellTags->"GenotypeFrequencyArguments"]},
  "MomentReduced"->{
    Cell[103390, 2039, 631, 12, 70, "DefinitionBox",
      CellTags->"MomentReduced"]},
  "CumulantReduced"->{
    Cell[105866, 2122, 431, 8, 46, "DefinitionBox",
      CellTags->"CumulantReduced"]},
  "HaploidConstraints"->{
    Cell[108377, 2214, 363, 8, 50, "DefinitionBox",
      CellTags->"HaploidConstraints"]},
  "DiploidConstraints"->{
    Cell[115267, 2465, 929, 21, 70, "DefinitionBox",
      CellTags->"DiploidConstraints"]},
  "LogLikelihoodDisequilibriumReduced"->{
    Cell[127887, 2810, 1186, 26, 54, "DefinitionBox",
      CellTags->"LogLikelihoodDisequilibriumReduced"]},
  "MetropolisDisequilibriumReduced"->{
    Cell[225569, 4567, 884, 19, 52, "DefinitionBox",
      CellTags->"MetropolisDisequilibriumReduced"]},
  "InitialStepReduced"->{
    Cell[250207, 5234, 641, 15, 37, "DefinitionBox",
      CellTags->"InitialStepReduced"]},
  "IntervalCombine"->{
    Cell[253132, 5332, 571, 10, 54, "DefinitionBox",
      CellTags->{"IntervalCombine", "IntervalPosition"}]},
  "IntervalPosition"->{
    Cell[253132, 5332, 571, 10, 54, "DefinitionBox",
      CellTags->{"IntervalCombine", "IntervalPosition"}]}
  }
*)

(*CellTagsIndex
CellTagsIndex->{
  {"DiploidGenotypeFrequencyReduced", 255384, 5408},
  {"FullGenotypeFrequencyReduced", 255669, 5414},
  {"FullGenotypeFrequencyTable", 255950, 5420},
  {"GenotypeFrequencyArguments", 256084, 5423},
  {"MomentReduced", 256196, 5426},
  {"CumulantReduced", 256307, 5429},
  {"HaploidConstraints", 256422, 5432},
  {"DiploidConstraints", 256540, 5435},
  {"LogLikelihoodDisequilibriumReduced", 256675, 5438},
  {"MetropolisDisequilibriumReduced", 256824, 5441},
  {"InitialStepReduced", 256956, 5444},
  {"IntervalCombine", 257072, 5447},
  {"IntervalPosition", 257208, 5450}
  }
*)

(*NotebookFileOutline
Notebook[{

Cell[CellGroupData[{
Cell[1739, 51, 44, 0, 36, "SubsectionIcon"],
Cell[1786, 53, 46, 0, 28, "MathCaption"],
Cell[1835, 55, 89, 2, 27, "Input"],

Cell[CellGroupData[{
Cell[1949, 61, 34, 0, 24, "SubsubsectionIcon"],
Cell[1986, 63, 1402, 34, 94, "Text"],
Cell[3391, 99, 131, 3, 22, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[3559, 107, 243, 6, 24, "SubsubsectionIcon",
  CellTags->{
  "DiploidGenotypeFrequencyReduced", "FullGenotypeFrequencyReduced"}],
Cell[3805, 115, 507, 11, 50, "DefinitionBox",
  CellTags->"DiploidGenotypeFrequencyReduced"],
Cell[4315, 128, 162, 4, 22, "Text"],

Cell[CellGroupData[{
Cell[4502, 136, 160, 4, 27, "Input"],
Cell[4665, 142, 32642, 579, 2266, "Output"]
}, Closed]],
Cell[37322, 724, 202, 3, 18, "Text"],

Cell[CellGroupData[{
Cell[37549, 731, 105, 2, 27, "Input"],
Cell[37657, 735, 3272, 51, 358, "Output"]
}, Closed]],
Cell[40944, 789, 129, 3, 18, "Text"],
Cell[41076, 794, 694, 18, 65, "DefinitionBox",
  CellTags->"FullGenotypeFrequencyReduced"],

Cell[CellGroupData[{
Cell[41795, 816, 128, 3, 27, "Input"],
Cell[41926, 821, 392, 8, 33, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[42355, 834, 170, 4, 27, "Input"],
Cell[42528, 840, 35231, 612, 2431, "Output"]
}, Closed]],
Cell[77774, 1455, 202, 3, 18, "Text"],

Cell[CellGroupData[{
Cell[78001, 1462, 105, 2, 27, "Input"],
Cell[78109, 1466, 3671, 56, 394, "Output"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[81829, 1528, 145, 3, 20, "SubsubsectionIcon"],
Cell[81977, 1533, 813, 17, 50, "DefinitionBox",
  CellTags->"FullGenotypeFrequencyTable"],
Cell[82793, 1552, 212, 3, 44, "Text"],

Cell[CellGroupData[{
Cell[83030, 1559, 188, 4, 27, "Input"],
Cell[83221, 1565, 96, 2, 20, "Output"]
}, Open  ]],
Cell[83332, 1570, 105, 3, 22, "Text"],

Cell[CellGroupData[{
Cell[83462, 1577, 188, 4, 27, "Input"],
Cell[83653, 1583, 98, 2, 20, "Output"]
}, Open  ]],
Cell[83766, 1588, 310, 9, 36, "Text"],

Cell[CellGroupData[{
Cell[84101, 1601, 190, 4, 27, "Input"],
Cell[84294, 1607, 96, 2, 20, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[84427, 1614, 159, 3, 27, "Input"],
Cell[84589, 1619, 61, 2, 20, "Output"]
}, Open  ]],
Cell[84665, 1624, 653, 14, 50, "DefinitionBox"],

Cell[CellGroupData[{
Cell[85343, 1642, 255, 5, 42, "Input"],
Cell[85601, 1649, 98, 2, 20, "Output"]
}, Open  ]],
Cell[85714, 1654, 79, 0, 22, "Text"],
Cell[85796, 1656, 60, 0, 22, "Text"],

Cell[CellGroupData[{
Cell[85881, 1660, 356, 6, 42, "Input"],
Cell[86240, 1668, 117, 2, 20, "Output"]
}, Open  ]],
Cell[86372, 1673, 795, 16, 50, "DefinitionBox"],
Cell[87170, 1691, 377, 11, 36, "Text"],

Cell[CellGroupData[{
Cell[87572, 1706, 287, 7, 27, "Input"],
Cell[87862, 1715, 83, 2, 20, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[87982, 1722, 518, 8, 42, "Input"],
Cell[88503, 1732, 83, 2, 20, "Output"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{
Cell[88635, 1740, 152, 3, 20, "SubsubsectionIcon"],
Cell[88790, 1745, 892, 22, 54, "DefinitionBox"],
Cell[89685, 1769, 225, 9, 22, "Text"],

Cell[CellGroupData[{
Cell[89935, 1782, 128, 3, 27, "Input"],
Cell[90066, 1787, 659, 11, 50, "Output"]
}, Open  ]],
Cell[90740, 1801, 43, 0, 22, "Text"],

Cell[CellGroupData[{
Cell[90808, 1805, 217, 5, 42, "Input"],
Cell[91028, 1812, 82, 2, 20, "Output"]
}, Open  ]],
Cell[91125, 1817, 260, 8, 22, "Text"],
Cell[91388, 1827, 755, 16, 84, "DefinitionBox"],

Cell[CellGroupData[{
Cell[92168, 1847, 175, 3, 27, "Input"],
Cell[92346, 1852, 82, 2, 20, "Output"]
}, Open  ]],
Cell[92443, 1857, 65, 0, 22, "Text"],

Cell[CellGroupData[{
Cell[92533, 1861, 167, 3, 26, "Input"],
Cell[92703, 1866, 783, 12, 50, "Output"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{
Cell[93535, 1884, 87, 1, 20, "SubsubsectionIcon"],
Cell[93625, 1887, 421, 8, 50, "DefinitionBox"],
Cell[94049, 1897, 252, 6, 24, "Text"],

Cell[CellGroupData[{
Cell[94326, 1907, 314, 8, 27, "Input",
  CellTags->"GenotypeFrequencyArguments"],
Cell[94643, 1917, 8609, 113, 965, "Output"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[103301, 2036, 86, 1, 20, "SubsubsectionIcon"],
Cell[103390, 2039, 631, 12, 70, "DefinitionBox",
  CellTags->"MomentReduced"],
Cell[104024, 2053, 476, 17, 22, "Text"],

Cell[CellGroupData[{
Cell[104525, 2074, 93, 2, 27, "Input"],
Cell[104621, 2078, 95, 2, 22, "Output"]
}, Closed]],
Cell[104731, 2083, 552, 17, 32, "Text"],

Cell[CellGroupData[{
Cell[105308, 2104, 128, 3, 27, "Input"],
Cell[105439, 2109, 412, 10, 78, "Output"]
}, Closed]],
Cell[105866, 2122, 431, 8, 46, "DefinitionBox",
  CellTags->"CumulantReduced"],
Cell[106300, 2132, 476, 17, 22, "Text"],

Cell[CellGroupData[{
Cell[106801, 2153, 95, 2, 27, "Input"],
Cell[106899, 2157, 100, 2, 22, "Output"]
}, Closed]],
Cell[107014, 2162, 50, 0, 18, "Text"],
Cell[107067, 2164, 298, 5, 37, "DefinitionBox"],
Cell[107368, 2171, 150, 3, 22, "Text"],

Cell[CellGroupData[{
Cell[107543, 2178, 106, 2, 26, "Input"],
Cell[107652, 2182, 123, 3, 20, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[107812, 2190, 123, 3, 26, "Input"],
Cell[107938, 2195, 123, 3, 20, "Output"]
}, Open  ]],
Cell[108076, 2201, 143, 3, 22, "Text"]
}, Closed]],

Cell[CellGroupData[{
Cell[108256, 2209, 118, 3, 20, "SubsubsectionIcon"],
Cell[108377, 2214, 363, 8, 50, "DefinitionBox",
  CellTags->"HaploidConstraints"],
Cell[108743, 2224, 113, 2, 22, "Text"],

Cell[CellGroupData[{
Cell[108881, 2230, 120, 3, 27, "Input"],
Cell[109004, 2235, 6248, 227, 131, "Output"]
}, Open  ]],
Cell[115267, 2465, 929, 21, 70, "DefinitionBox",
  CellTags->"DiploidConstraints"],
Cell[116199, 2488, 195, 5, 22, "Text"],

Cell[CellGroupData[{
Cell[116419, 2497, 211, 4, 42, "Input"],
Cell[116633, 2503, 7765, 198, 185, "Output"]
}, Open  ]],
Cell[124413, 2704, 170, 6, 24, "Text"],

Cell[CellGroupData[{
Cell[124608, 2714, 155, 4, 26, "Input"],
Cell[124766, 2720, 98, 2, 20, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[124901, 2727, 162, 4, 26, "Input"],
Cell[125066, 2733, 79, 2, 20, "Output"]
}, Open  ]],
Cell[125160, 2738, 45, 0, 22, "Text"],

Cell[CellGroupData[{
Cell[125230, 2742, 103, 2, 26, "Input"],
Cell[125336, 2746, 1091, 20, 71, "Output"]
}, Open  ]],
Cell[126442, 2769, 95, 3, 22, "Text"],

Cell[CellGroupData[{
Cell[126562, 2776, 73, 2, 26, "Input"],
Cell[126638, 2780, 1114, 21, 54, "Output"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{
Cell[127801, 2807, 83, 1, 20, "SubsubsectionIcon"],
Cell[127887, 2810, 1186, 26, 54, "DefinitionBox",
  CellTags->"LogLikelihoodDisequilibriumReduced"],
Cell[129076, 2838, 95, 3, 22, "Text"],

Cell[CellGroupData[{
Cell[129196, 2845, 108, 2, 27, "Input"],
Cell[129307, 2849, 159, 3, 20, "Output"]
}, Closed]],
Cell[129481, 2855, 146, 3, 18, "Text"],

Cell[CellGroupData[{
Cell[129652, 2862, 203, 4, 42, "Input"],
Cell[129858, 2868, 46413, 794, 3354, "Output"]
}, Closed]],
Cell[176286, 3665, 106, 2, 18, "Text"],
Cell[176395, 3669, 108, 3, 22, "Text"],

Cell[CellGroupData[{
Cell[176528, 3676, 143, 3, 27, "Input"],
Cell[176674, 3681, 46413, 794, 4689, "Output"]
}, Closed]],
Cell[223102, 4478, 988, 23, 50, "DefinitionBox"],
Cell[224093, 4503, 94, 3, 22, "Text"],

Cell[CellGroupData[{
Cell[224212, 4510, 201, 5, 42, "Input"],
Cell[224416, 4517, 120, 3, 20, "Output"]
}, Closed]],
Cell[224551, 4523, 82, 1, 18, "Text"],
Cell[224636, 4526, 90, 1, 22, "Text"],

Cell[CellGroupData[{
Cell[224751, 4531, 197, 5, 42, "Input"],
Cell[224951, 4538, 121, 3, 20, "Output"]
}, Closed]],
Cell[225087, 4544, 44, 0, 18, "Text"],

Cell[CellGroupData[{
Cell[225156, 4548, 171, 4, 42, "Input"],
Cell[225330, 4554, 76, 2, 20, "Output"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[225455, 4562, 111, 3, 20, "SubsubsectionIcon"],
Cell[225569, 4567, 884, 19, 52, "DefinitionBox",
  CellTags->"MetropolisDisequilibriumReduced"],
Cell[226456, 4588, 60, 0, 22, "Text"],

Cell[CellGroupData[{
Cell[226541, 4592, 85, 1, 27, "Input"],
Cell[226629, 4595, 359, 6, 35, "Output"]
}, Closed]],
Cell[227003, 4604, 116, 3, 18, "Text"],
Cell[227122, 4609, 125, 3, 22, "Text"],

Cell[CellGroupData[{
Cell[227272, 4616, 171, 4, 30, "Input"],
Cell[227446, 4622, 401, 9, 20, "Print"],
Cell[227850, 4633, 404, 9, 20, "Print"],
Cell[228257, 4644, 404, 9, 20, "Print"],
Cell[228664, 4655, 404, 9, 20, "Print"],
Cell[229071, 4666, 404, 9, 20, "Print"],
Cell[229478, 4677, 404, 9, 20, "Print"],
Cell[229885, 4688, 403, 9, 20, "Print"],
Cell[230291, 4699, 403, 9, 20, "Print"],
Cell[230697, 4710, 402, 9, 20, "Print"],
Cell[231102, 4721, 404, 9, 20, "Print"],
Cell[231509, 4732, 940, 16, 65, "Output"]
}, Closed]],
Cell[232464, 4751, 591, 15, 50, "Text"],
Cell[233058, 4768, 261, 9, 22, "Text"],

Cell[CellGroupData[{
Cell[233344, 4781, 121, 3, 27, "Input"],
Cell[233468, 4786, 401, 9, 20, "Print"],
Cell[233872, 4797, 406, 9, 20, "Print"],
Cell[234281, 4808, 406, 9, 20, "Print"],
Cell[234690, 4819, 389, 9, 20, "Print"],
Cell[235082, 4830, 406, 9, 20, "Print"],
Cell[235491, 4841, 406, 9, 20, "Print"],
Cell[235900, 4852, 406, 9, 20, "Print"],
Cell[236309, 4863, 406, 9, 20, "Print"],
Cell[236718, 4874, 406, 9, 20, "Print"],
Cell[237127, 4885, 406, 9, 20, "Print"],
Cell[237536, 4896, 967, 16, 69, "Output"]
}, Closed]],
Cell[238518, 4915, 300, 7, 32, "Text"],
Cell[238821, 4924, 68, 0, 22, "Text"],

Cell[CellGroupData[{
Cell[238914, 4928, 185, 4, 26, "Input"],
Cell[239102, 4934, 488, 12, 46, "Output"]
}, Closed]],
Cell[239605, 4949, 303, 9, 20, "Text"],

Cell[CellGroupData[{
Cell[239933, 4962, 166, 4, 32, "Input"],
Cell[240102, 4968, 402, 9, 20, "Print"],
Cell[240507, 4979, 403, 9, 20, "Print"],
Cell[240913, 4990, 404, 9, 20, "Print"],
Cell[241320, 5001, 403, 9, 20, "Print"],
Cell[241726, 5012, 403, 9, 20, "Print"],
Cell[242132, 5023, 389, 9, 20, "Print"],
Cell[242524, 5034, 404, 9, 20, "Print"],
Cell[242931, 5045, 404, 9, 20, "Print"],
Cell[243338, 5056, 403, 9, 20, "Print"],
Cell[243744, 5067, 404, 9, 20, "Print"],
Cell[244151, 5078, 858, 14, 65, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[245046, 5097, 113, 2, 22, "Input"],
Cell[245162, 5101, 402, 9, 20, "Print"],
Cell[245567, 5112, 403, 9, 20, "Print"],
Cell[245973, 5123, 389, 9, 20, "Print"],
Cell[246365, 5134, 406, 9, 20, "Print"],
Cell[246774, 5145, 405, 9, 20, "Print"],
Cell[247182, 5156, 405, 9, 20, "Print"],
Cell[247590, 5167, 406, 9, 20, "Print"],
Cell[247999, 5178, 391, 9, 20, "Print"],
Cell[248393, 5189, 406, 9, 20, "Print"],
Cell[248802, 5200, 406, 9, 20, "Print"],
Cell[249211, 5211, 862, 14, 69, "Output"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[250122, 5231, 82, 1, 20, "SubsubsectionIcon"],
Cell[250207, 5234, 641, 15, 37, "DefinitionBox",
  CellTags->"InitialStepReduced"],
Cell[250851, 5251, 209, 3, 22, "Text"],

Cell[CellGroupData[{
Cell[251085, 5258, 71, 2, 27, "Input"],
Cell[251159, 5262, 159, 3, 20, "Output"]
}, Closed]],
Cell[251333, 5268, 89, 3, 18, "Text"],

Cell[CellGroupData[{
Cell[251447, 5275, 61, 2, 27, "Input"],
Cell[251511, 5279, 803, 23, 20, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[252351, 5307, 106, 2, 23, "Input"],
Cell[252460, 5311, 359, 6, 35, "Output"]
}, Closed]],
Cell[252834, 5320, 170, 4, 18, "Text"]
}, Closed]],

Cell[CellGroupData[{
Cell[253041, 5329, 88, 1, 20, "SubsubsectionIcon"],
Cell[253132, 5332, 571, 10, 54, "DefinitionBox",
  CellTags->{"IntervalCombine", "IntervalPosition"}],
Cell[253706, 5344, 35, 0, 22, "Text"],

Cell[CellGroupData[{
Cell[253766, 5348, 128, 3, 27, "Input"],
Cell[253897, 5353, 78, 2, 20, "Output"]
}, Open  ]],
Cell[253990, 5358, 88, 3, 22, "Text"],

Cell[CellGroupData[{
Cell[254103, 5365, 109, 2, 27, "Input"],
Cell[254215, 5369, 66, 2, 20, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[254318, 5376, 109, 2, 27, "Input"],
Cell[254430, 5380, 61, 2, 20, "Output"]
}, Open  ]]
}, Closed]]
}, Open  ]]
}
]
*)




(***********************************************************************
End of Mathematica Notebook file.
***********************************************************************)

