(***********************************************************************

                    Mathematica-Compatible Notebook

This notebook can be used on any computer system with Mathematica 4.0,
MathReader 4.0, or any compatible application. The data for the notebook 
starts with the line containing stars above.

To get the notebook into a Mathematica-compatible application, do one of 
the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing the 
word CacheID, otherwise Mathematica-compatible applications may try to 
use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
***********************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[     12115,        411]*)
(*NotebookOutlinePosition[     17179,        556]*)
(*  CellTagsIndexPosition[     16120,        523]*)
(*WindowFrame->Normal*)



Notebook[{

Cell[CellGroupData[{
Cell["References", "SubsectionIcon"],

Cell[TextData[{
  "Arnold, M. (1996). ",
  StyleBox[" Natural hybridization and introgression",
    FontSlant->"Italic"],
  ". Princeton: Princeton University Press."
}], "Reference",
  CellTags->{"Asmussen et al 1987", "Arnold 1996"}],

Cell[TextData[{
  StyleBox[
  "Asmussen, M. A., J. Arnold and J. C. Avise.  (1987).  Definition and \
properties of disequilibrium statistics for associations between nuclear and \
ctyoplasmic genotypes. ",
    FontColor->RGBColor[0.0901961, 0.00172427, 0]],
  StyleBox["Genetics",
    FontSlant->"Italic",
    FontColor->RGBColor[0.0901961, 0.00172427, 0]],
  StyleBox[" ",
    FontColor->RGBColor[0.0901961, 0.00172427, 0]],
  StyleBox["115",
    FontWeight->"Bold",
    FontColor->RGBColor[0.0901961, 0.00172427, 0]],
  StyleBox[", 755-768.",
    FontColor->RGBColor[0.0901961, 0.00172427, 0]]
}], "Reference",
  CellTags->"Asmussen et al 1987"],

Cell[TextData[{
  "Barton, N.H. (1986).  The effects of linkage and density-dependent \
regulation on gene flow.  ",
  StyleBox["Heredity ",
    FontSlant->"Italic"],
  " ",
  StyleBox["57",
    FontWeight->"Bold"],
  ", 415-426."
}], "Reference",
  CellTags->"Barton 1986"],

Cell[TextData[{
  StyleBox["Barton, N.H",
    FontVariations->{"CompatibilityType"->0}],
  ". (2000). Estimating multilocus linkage disequilibria. ",
  StyleBox["Heredity",
    FontSlant->"Italic"],
  " ",
  StyleBox["84:",
    FontWeight->"Bold"],
  " 373-389."
}], "Text",
  CellMargins->{{6, Inherited}, {Inherited, Inherited}},
  CellTags->"Barton 2000"],

Cell[TextData[{
  "Barton, N.H. and M. Shpak. (1999).  The effects of epistasis on the \
structure of hybrid zones.  ",
  StyleBox["Genet. Res. (Camb.)",
    FontSlant->"Italic"],
  " ",
  StyleBox["75",
    FontWeight->"Bold"],
  ", 179-198."
}], "Reference",
  CellTags->"Barton & Shpak 1999"],

Cell[TextData[{
  "Barton, N.H. and K.S. Gale. (1993). Genetic analysis of hybrid zones. In ",
  
  StyleBox["Hybrid zones and the evolutionary process",
    FontSlant->"Italic"],
  " (ed. R.G. Harrison), pp. 13-45. Oxford: Oxford University Press."
}], "Reference",
  CellTags->"Barton & Gale 1993"],

Cell[TextData[{
  "Barton, N.H. and M. Turelli. (1991).  Natural and sexual selection on many \
loci.  ",
  StyleBox["Genetics",
    FontSlant->"Italic"],
  " ",
  StyleBox["127",
    FontWeight->"Bold"],
  ", 229-255."
}], "Reference",
  CellTags->"Barton & Turelli 1991"],

Cell[TextData[{
  StyleBox[
  "Dempster, A. P., N. M. Laird and D. B. Rubin.  (1977).  Maximum likelihood \
from incomplete data via the EM algorithm. ",
    FontColor->RGBColor[0.0901961, 0.00172427, 0]],
  StyleBox["J. Royal Statist. Soc. B",
    FontSlant->"Italic",
    FontColor->RGBColor[0.0901961, 0.00172427, 0]],
  StyleBox[" ",
    FontColor->RGBColor[0.0901961, 0.00172427, 0]],
  StyleBox["39",
    FontWeight->"Bold",
    FontColor->RGBColor[0.0901961, 0.00172427, 0]],
  StyleBox[", 1-38.",
    FontColor->RGBColor[0.0901961, 0.00172427, 0]]
}], "Reference",
  CellTags->"Dempster et al 1977"],

Cell[TextData[{
  "Edwards, A.W.F. (1972). ",
  StyleBox[" Likelihood",
    FontSlant->"Italic"],
  ". Cambridge Univ. Press. Cambridge."
}], "Reference",
  CellTags->"Edwards 1972"],

Cell[TextData[{
  "Goodman, S.J., N.H. Barton, G. Swanson, K. Abernethy, and J.M. Pemberton. \
(1999).  Introgression through rare hybridisation: a genetic study of a \
hybrid zone between red and sika deer (genus ",
  StyleBox["Cervus",
    FontSlant->"Italic"],
  "), in Argyll, Scotland.  ",
  StyleBox["Genetics",
    FontSlant->"Italic"],
  " ",
  StyleBox["152",
    FontWeight->"Bold"],
  ", 355-371."
}], "Reference",
  CellTags->"Goodman et al 1999"],

Cell[TextData[{
  "Guiasu, S. and A. Shenitzer. (1985).  The principle of maximum entropy.  ",
  
  StyleBox["The Mathematical Intelligencer",
    FontSlant->"Italic"],
  " ",
  StyleBox["7",
    FontWeight->"Bold"],
  ", 42-48."
}], "Reference",
  CellTags->"Guiasu & Shenitzer 1985"],

Cell[TextData[{
  StyleBox["Haber, M. (1984).  Log-linear models for linked loci. ",
    FontColor->RGBColor[0.0901961, 0.00172427, 0]],
  StyleBox["Biometrics",
    FontSlant->"Italic",
    FontColor->RGBColor[0.0901961, 0.00172427, 0]],
  StyleBox[" ",
    FontColor->RGBColor[0.0901961, 0.00172427, 0]],
  StyleBox["40",
    FontWeight->"Bold",
    FontColor->RGBColor[0.0901961, 0.00172427, 0]],
  StyleBox[", 189-198.",
    FontColor->RGBColor[0.0901961, 0.00172427, 0]]
}], "Reference",
  CellTags->"Haber 1984"],

Cell[TextData[{
  StyleBox[
  "Hill, W. G. (1974a).  Estimation of linkage disequilibrium in randomly \
mating populations. Heredity ",
    FontColor->RGBColor[0.0901961, 0.00172427, 0]],
  StyleBox["33",
    FontWeight->"Bold",
    FontColor->RGBColor[0.0901961, 0.00172427, 0]],
  StyleBox[", 229-239.",
    FontColor->RGBColor[0.0901961, 0.00172427, 0]]
}], "Reference",
  CellTags->"Hill 1974a"],

Cell[TextData[{
  StyleBox[
  "Hill, W. G. (1974b).  Disequilibria among several linked neutral genes in \
finite populations  I. Mean change in disequilibria. ",
    FontColor->RGBColor[0.0901961, 0.00172427, 0]],
  StyleBox["Theor. Popul. Biol.",
    FontSlant->"Italic",
    FontColor->RGBColor[0.0901961, 0.00172427, 0]],
  StyleBox[" ",
    FontColor->RGBColor[0.0901961, 0.00172427, 0]],
  StyleBox["5",
    FontWeight->"Bold",
    FontColor->RGBColor[0.0901961, 0.00172427, 0]],
  StyleBox[", 366-392.",
    FontColor->RGBColor[0.0901961, 0.00172427, 0]]
}], "Reference",
  CellTags->"Hill 1974b"],

Cell[TextData[{
  StyleBox[
  "Hill, W. G. (1974c).  Disequilibria among several linked neutral genes in \
finite populations  II. Variances and covariances of disequilibria. ",
    FontColor->RGBColor[0.0901961, 0.00172427, 0]],
  StyleBox["Theor. Popul.  Biol.",
    FontSlant->"Italic",
    FontColor->RGBColor[0.0901961, 0.00172427, 0]],
  StyleBox[" ",
    FontColor->RGBColor[0.0901961, 0.00172427, 0]],
  StyleBox["6",
    FontWeight->"Bold",
    FontColor->RGBColor[0.0901961, 0.00172427, 0]],
  StyleBox[", 143-148.",
    FontColor->RGBColor[0.0901961, 0.00172427, 0]]
}], "Reference",
  CellTags->"Hill 1974c"],

Cell[TextData[{
  "Kirkpatrick, S., C.D. Gelatt, and M.P. Vecchi. (1983).  Optimization by \
simulated annealing.  ",
  StyleBox["Science ",
    FontSlant->"Italic"],
  " ",
  StyleBox["220",
    FontWeight->"Bold"],
  ", 671-680."
}], "Reference",
  CellTags->"Kirkpatrick et al 1983"],

Cell[TextData[{
  "Kruuk, L. (1997). ",
  StyleBox[
  "Barriers to gene flow: a Bombina (fire-bellied toad) hybrid zone and \
multilocus cline theory",
    FontSlant->"Italic"],
  ". Ph.D. thesis, University of Edinburgh."
}], "Reference",
  CellTags->"Kruuk 1997"],

Cell[TextData[{
  "Li, W.H. and M. Nei. (1974).  Stable linkage disequilibrium without \
epistasis in subdivided populations.  ",
  StyleBox["Theor.Pop.Biol. ",
    FontSlant->"Italic"],
  " ",
  StyleBox["6",
    FontWeight->"Bold"],
  ", 173-183."
}], "Reference",
  CellTags->"Li & Nei 1974"],

Cell[TextData[{
  StyleBox[
  "Long, J. C., R. C. Williams and M. Urbanek.  (1995).  An E-M algorithm and \
testing strategy for multiple-locus haplotypes. ",
    FontColor->RGBColor[0.0901961, 0.00172427, 0]],
  StyleBox["Am. J. Hum. Genet",
    FontSlant->"Italic",
    FontColor->RGBColor[0.0901961, 0.00172427, 0]],
  StyleBox[". ",
    FontColor->RGBColor[0.0901961, 0.00172427, 0]],
  StyleBox["56",
    FontWeight->"Bold",
    FontColor->RGBColor[0.0901961, 0.00172427, 0]],
  StyleBox[", 799-810.",
    FontColor->RGBColor[0.0901961, 0.00172427, 0]]
}], "Reference",
  CellTags->"Long et al 1995"],

Cell[TextData[{
  "MacCallum, C.J. (1994). ",
  StyleBox[
  "Adaptation and habitat preference in a hybrid zone between Bombina bombina \
and Bombina variegata in Croatia",
    FontSlant->"Italic"],
  ". Ph.D. thesis, University of Edinburgh."
}], "Reference",
  CellTags->"MacCallum 1994"],

Cell[TextData[{
  "MacCallum, C. J., B. Nurnberger, N. H. Barton, and J. M. Szymura. (1998).  \
Habitat preference in the ",
  StyleBox["Bombina",
    FontSlant->"Italic"],
  " hybrid zone in Croatia.  ",
  StyleBox["Evolution",
    FontSlant->"Italic"],
  " ",
  StyleBox["52",
    FontWeight->"Bold"],
  ", 227-239."
}], "Reference",
  CellTags->"MacCallum et al 1998"],

Cell[TextData[{
  "Mangel, M. and R. Hilborn. (1996). ",
  StyleBox[" The ecological detective",
    FontSlant->"Italic"],
  ". Princeton, NJ: Princeton University Press."
}], "Reference",
  CellTags->"Mangel & Hilborn 1996"],

Cell[TextData[{
  "Metropolis, N., A. Rosenbluth, M. Rosenbluth, A. Teller, and E. Teller.  \
(1954). Equation of state calculations by fast computing machines.  ",
  StyleBox["J. Chem.Phys.",
    FontSlant->"Italic"],
  " ",
  StyleBox["21",
    FontWeight->"Bold"],
  ", 1087-?"
}], "Reference",
  CellTags->"Metropolis et al 1954"],

Cell[TextData[{
  "Orive, M.E. and N.H. Barton. (1999).  Associations between cytoplasmic and \
nuclear loci in hybridizing populations.  ",
  StyleBox["Genetics",
    FontSlant->"Italic"],
  " (in review)"
}], "Reference",
  CellTags->"Orive & Barton 1999"],

Cell[TextData[{
  "Phipps, T. E. and M. H. Brill. (1995).  Bayesian entropy and inference.  ",
  
  StyleBox["Physics Essays",
    FontSlant->"Italic"],
  " ",
  StyleBox["8",
    FontWeight->"Bold"],
  ", 615-625."
}], "Reference",
  CellTags->"Phipps & Brill 1995"],

Cell[TextData[{
  "Slatkin, M. (1972) On treating the chromosome as the unit of selection. ",
  StyleBox["Genetics",
    FontSlant->"Italic"],
  "  72: 157-168."
}], "Text",
  CellTags->"Slatkin 1972"],

Cell[TextData[{
  StyleBox[
  "Slatkin, M., and L. Excoffier.  (1996).  Testing for linkage \
disequilibrium in genotypic data using the Expectation-Maximization \
algorithm. Heredity ",
    FontColor->RGBColor[0.0901961, 0.00172427, 0]],
  StyleBox["76:",
    FontWeight->"Bold",
    FontColor->RGBColor[0.0901961, 0.00172427, 0]],
  StyleBox[" 377-383.",
    FontColor->RGBColor[0.0901961, 0.00172427, 0]]
}], "Reference",
  CellTags->"Slatkin & Excoffier 1996"],

Cell[TextData[{
  "Turelli, M. and N.H. Barton. (1994).  Genetic and statistical analyses of \
strong selection on polygenic traits: what, me normal ?  ",
  StyleBox["Genetics",
    FontSlant->"Italic"],
  " ",
  StyleBox["138",
    FontWeight->"Bold"],
  ", 913-941."
}], "Reference",
  CellTags->"Turelli & Barton 1994"]
}, Open  ]]
},
FrontEndVersion->"4.0 for Macintosh",
ScreenRectangle->{{0, 1152}, {0, 748}},
WindowToolbars->{},
WindowSize->{659, 655},
WindowMargins->{{-2, Automatic}, {Automatic, 1}},
StyleDefinitions -> "HelpBrowser.nb",
MacintoshSystemPageSetup->"\<\
00<0001804P000000`d26_oQon@3:`8g0dL5N`?P0080001804P000000]P2:001
0000I00000400`<30?l00BL?00400@00000000000000060801T1T00000000000
00000000004000000000000000000000\>"
]


(***********************************************************************
Cached data follows.  If you edit this Notebook file directly, not using
Mathematica, you must remove the line containing CacheID at the top of 
the file.  The cache data will then be recreated when you save this file 
from within Mathematica.
***********************************************************************)

(*CellTagsOutline
CellTagsIndex->{
  "Asmussen et al 1987"->{
    Cell[1778, 53, 235, 6, 24, "Reference",
      CellTags->{"Asmussen et al 1987", "Arnold 1996"}],
    Cell[2016, 61, 648, 17, 38, "Reference",
      CellTags->"Asmussen et al 1987"]},
  "Arnold 1996"->{
    Cell[1778, 53, 235, 6, 24, "Reference",
      CellTags->{"Asmussen et al 1987", "Arnold 1996"}]},
  "Barton 1986"->{
    Cell[2667, 80, 274, 10, 24, "Reference",
      CellTags->"Barton 1986"]},
  "Barton 2000"->{
    Cell[2944, 92, 358, 12, 24, "Text",
      CellTags->"Barton 2000"]},
  "Barton & Shpak 1999"->{
    Cell[3305, 106, 295, 10, 24, "Reference",
      CellTags->"Barton & Shpak 1999"]},
  "Barton & Gale 1993"->{
    Cell[3603, 118, 300, 7, 38, "Reference",
      CellTags->"Barton & Gale 1993"]},
  "Barton & Turelli 1991"->{
    Cell[3906, 127, 273, 10, 24, "Reference",
      CellTags->"Barton & Turelli 1991"]},
  "Dempster et al 1977"->{
    Cell[4182, 139, 607, 16, 40, "Reference",
      CellTags->"Dempster et al 1977"]},
  "Edwards 1972"->{
    Cell[4792, 157, 182, 6, 24, "Reference",
      CellTags->"Edwards 1972"]},
  "Goodman et al 1999"->{
    Cell[4977, 165, 459, 14, 38, "Reference",
      CellTags->"Goodman et al 1999"]},
  "Guiasu & Shenitzer 1985"->{
    Cell[5439, 181, 285, 10, 24, "Reference",
      CellTags->"Guiasu & Shenitzer 1985"]},
  "Haber 1984"->{
    Cell[5727, 193, 518, 14, 24, "Reference",
      CellTags->"Haber 1984"]},
  "Hill 1974a"->{
    Cell[6248, 209, 399, 11, 24, "Reference",
      CellTags->"Hill 1974a"]},
  "Hill 1974b"->{
    Cell[6650, 222, 604, 16, 40, "Reference",
      CellTags->"Hill 1974b"]},
  "Hill 1974c"->{
    Cell[7257, 240, 620, 16, 38, "Reference",
      CellTags->"Hill 1974c"]},
  "Kirkpatrick et al 1983"->{
    Cell[7880, 258, 286, 10, 24, "Reference",
      CellTags->"Kirkpatrick et al 1983"]},
  "Kruuk 1997"->{
    Cell[8169, 270, 265, 8, 38, "Reference",
      CellTags->"Kruuk 1997"]},
  "Li & Nei 1974"->{
    Cell[8437, 280, 295, 10, 38, "Reference",
      CellTags->"Li & Nei 1974"]},
  "Long et al 1995"->{
    Cell[8735, 292, 605, 16, 40, "Reference",
      CellTags->"Long et al 1995"]},
  "MacCallum 1994"->{
    Cell[9343, 310, 290, 8, 40, "Reference",
      CellTags->"MacCallum 1994"]},
  "MacCallum et al 1998"->{
    Cell[9636, 320, 371, 13, 40, "Reference",
      CellTags->"MacCallum et al 1998"]},
  "Mangel & Hilborn 1996"->{
    Cell[10010, 335, 225, 6, 24, "Reference",
      CellTags->"Mangel & Hilborn 1996"]},
  "Metropolis et al 1954"->{
    Cell[10238, 343, 334, 10, 38, "Reference",
      CellTags->"Metropolis et al 1954"]},
  "Orive & Barton 1999"->{
    Cell[10575, 355, 258, 7, 38, "Reference",
      CellTags->"Orive & Barton 1999"]},
  "Phipps & Brill 1995"->{
    Cell[10836, 364, 267, 10, 24, "Reference",
      CellTags->"Phipps & Brill 1995"]},
  "Slatkin 1972"->{
    Cell[11106, 376, 201, 6, 24, "Text",
      CellTags->"Slatkin 1972"]},
  "Slatkin & Excoffier 1996"->{
    Cell[11310, 384, 464, 12, 38, "Reference",
      CellTags->"Slatkin & Excoffier 1996"]},
  "Turelli & Barton 1994"->{
    Cell[11777, 398, 322, 10, 40, "Reference",
      CellTags->"Turelli & Barton 1994"]}
  }
*)

(*CellTagsIndex
CellTagsIndex->{
  {"Asmussen et al 1987", 12977, 433},
  {"Arnold 1996", 13183, 438},
  {"Barton 1986", 13304, 441},
  {"Barton 2000", 13401, 444},
  {"Barton & Shpak 1999", 13501, 447},
  {"Barton & Gale 1993", 13614, 450},
  {"Barton & Turelli 1991", 13728, 453},
  {"Dempster et al 1977", 13844, 456},
  {"Edwards 1972", 13951, 459},
  {"Goodman et al 1999", 14056, 462},
  {"Guiasu & Shenitzer 1985", 14173, 465},
  {"Haber 1984", 14282, 468},
  {"Hill 1974a", 14378, 471},
  {"Hill 1974b", 14474, 474},
  {"Hill 1974c", 14570, 477},
  {"Kirkpatrick et al 1983", 14678, 480},
  {"Kruuk 1997", 14786, 483},
  {"Li & Nei 1974", 14884, 486},
  {"Long et al 1995", 14988, 489},
  {"MacCallum 1994", 15093, 492},
  {"MacCallum et al 1998", 15202, 495},
  {"Mangel & Hilborn 1996", 15319, 498},
  {"Metropolis et al 1954", 15437, 501},
  {"Orive & Barton 1999", 15554, 504},
  {"Phipps & Brill 1995", 15668, 507},
  {"Slatkin 1972", 15776, 510},
  {"Slatkin & Excoffier 1996", 15883, 513},
  {"Turelli & Barton 1994", 16005, 516}
  }
*)

(*NotebookFileOutline
Notebook[{

Cell[CellGroupData[{
Cell[1739, 51, 36, 0, 36, "SubsectionIcon"],
Cell[1778, 53, 235, 6, 24, "Reference",
  CellTags->{"Asmussen et al 1987", "Arnold 1996"}],
Cell[2016, 61, 648, 17, 38, "Reference",
  CellTags->"Asmussen et al 1987"],
Cell[2667, 80, 274, 10, 24, "Reference",
  CellTags->"Barton 1986"],
Cell[2944, 92, 358, 12, 24, "Text",
  CellTags->"Barton 2000"],
Cell[3305, 106, 295, 10, 24, "Reference",
  CellTags->"Barton & Shpak 1999"],
Cell[3603, 118, 300, 7, 38, "Reference",
  CellTags->"Barton & Gale 1993"],
Cell[3906, 127, 273, 10, 24, "Reference",
  CellTags->"Barton & Turelli 1991"],
Cell[4182, 139, 607, 16, 40, "Reference",
  CellTags->"Dempster et al 1977"],
Cell[4792, 157, 182, 6, 24, "Reference",
  CellTags->"Edwards 1972"],
Cell[4977, 165, 459, 14, 38, "Reference",
  CellTags->"Goodman et al 1999"],
Cell[5439, 181, 285, 10, 24, "Reference",
  CellTags->"Guiasu & Shenitzer 1985"],
Cell[5727, 193, 518, 14, 24, "Reference",
  CellTags->"Haber 1984"],
Cell[6248, 209, 399, 11, 24, "Reference",
  CellTags->"Hill 1974a"],
Cell[6650, 222, 604, 16, 40, "Reference",
  CellTags->"Hill 1974b"],
Cell[7257, 240, 620, 16, 38, "Reference",
  CellTags->"Hill 1974c"],
Cell[7880, 258, 286, 10, 24, "Reference",
  CellTags->"Kirkpatrick et al 1983"],
Cell[8169, 270, 265, 8, 38, "Reference",
  CellTags->"Kruuk 1997"],
Cell[8437, 280, 295, 10, 38, "Reference",
  CellTags->"Li & Nei 1974"],
Cell[8735, 292, 605, 16, 40, "Reference",
  CellTags->"Long et al 1995"],
Cell[9343, 310, 290, 8, 40, "Reference",
  CellTags->"MacCallum 1994"],
Cell[9636, 320, 371, 13, 40, "Reference",
  CellTags->"MacCallum et al 1998"],
Cell[10010, 335, 225, 6, 24, "Reference",
  CellTags->"Mangel & Hilborn 1996"],
Cell[10238, 343, 334, 10, 38, "Reference",
  CellTags->"Metropolis et al 1954"],
Cell[10575, 355, 258, 7, 38, "Reference",
  CellTags->"Orive & Barton 1999"],
Cell[10836, 364, 267, 10, 24, "Reference",
  CellTags->"Phipps & Brill 1995"],
Cell[11106, 376, 201, 6, 24, "Text",
  CellTags->"Slatkin 1972"],
Cell[11310, 384, 464, 12, 38, "Reference",
  CellTags->"Slatkin & Excoffier 1996"],
Cell[11777, 398, 322, 10, 40, "Reference",
  CellTags->"Turelli & Barton 1994"]
}, Open  ]]
}
]
*)




(***********************************************************************
End of Mathematica Notebook file.
***********************************************************************)

