(***********************************************************************

                    Mathematica-Compatible Notebook

This notebook can be used on any computer system with Mathematica 4.0,
MathReader 4.0, or any compatible application. The data for the notebook 
starts with the line containing stars above.

To get the notebook into a Mathematica-compatible application, do one of 
the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing the 
word CacheID, otherwise Mathematica-compatible applications may try to 
use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
***********************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[    133321,       2367]*)
(*NotebookOutlinePosition[    134203,       2395]*)
(*  CellTagsIndexPosition[    134159,       2391]*)
(*WindowFrame->Normal*)



Notebook[{

Cell[CellGroupData[{
Cell["Analysing replicate samples: an example", "SubsectionIcon"],

Cell[TextData[{
  "\tThe list ",
  StyleBox["metList",
    FontSlant->"Italic"],
  " specifies the \"annealing schedule\": that is, the sequence of \
temperatures at which the Metropolis algorithm is run.  Elements have the \
form ",
  Cell[BoxData[
      \(TraditionalForm\`{T, \ {n\_tries, \ n\_print}}\)]],
  ".  Here, there are 100 tries at T=1; 100 at T=0.5; 100 at T=0.2; and 100 \
at T=0 (i.e., climbing uphill):"
}], "Text"],

Cell[BoxData[
    \(\(metList = {{1, {100, 200}}, {0.5, {100, 200}}, {0.2, {100, 200}}, {
          0, {100, 200}}}; \)\)], "Input",
  CellLabel->"In[98]:="],

Cell[TextData[{
  "By setting ",
  Cell[BoxData[
      \(TraditionalForm\`n\_print > n\_tries, \ 
      printout\ of\ intermediate\ likelihoods\ is\ \(suppressed . \)\)]],
  "  The options MethodP, MethodC  can be set to lists that specify various \
ways of making estimates (see next section).  All combinations are tried, \
with methodP varying slowest.  Thus, in the example below, the various \
MethodC options are tried in order, with allele frequencies fitted to the \
data; then, they are tried with allele frequencies fixed at sample values."
}], "Text"],

Cell["This loads the package:", "MathCaption"],

Cell[BoxData[
    \(\(<< Multilocus`EstimatingD`;\)\)], "Input",
  CellLabel->"In[122]:="],

Cell[CellGroupData[{

Cell[BoxData[
    \(results = 
      DoReplicates[0.2, 0.3, 3, {10, 100}, metList, r, 
        MethodP \[Rule] {Fit, Sample}, 
        MethodC -> {HWLE, Fit, Sample, TrueC2, True}]\)], "Input",
  CellLabel->"In[99]:="],

Cell[BoxData[
    InterpretationBox[
      RowBox[{"\<\"True C: \"\>", "\[InvisibleSpace]", 
        TagBox[
          RowBox[{"(", GridBox[{
                {"1.`", "0.`", "0.0979999999999999893`", 
                  "0.0335999999999999898`"},
                {"0.`", "0.0419999999999999928`", "0.0167999999999999953`", 
                  "0.0155399999999999955`"},
                {"0.0979999999999999893`", "0.0167999999999999953`", 
                  "0.0194599999999999937`", "0.0109199999999999963`"},
                {"0.0335999999999999898`", "0.0155399999999999955`", 
                  "0.0109199999999999963`", "0.00751379999999999448`"}
                }], ")"}],
          (MatrixForm[ #]&)]}],
      SequenceForm[ "True C: ", 
        MatrixForm[ {{1.0, 0.0, 0.09799999999999999, 0.033599999999999991}, {
          0.0, 0.041999999999999996, 0.016799999999999995, 
          0.015539999999999995}, {0.09799999999999999, 0.016799999999999995, 
          0.019459999999999995, 0.010919999999999996}, {0.033599999999999991, 
          0.015539999999999995, 0.010919999999999996, 
          0.0075137999999999958}}]],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \(1\[InvisibleSpace]"\t"\[InvisibleSpace]\(-81.0402830208063207`
          \)\[InvisibleSpace]"\t"\[InvisibleSpace]\(-10.6149873683061746`
          \)\[InvisibleSpace]"\t"\[InvisibleSpace]\(-9.4107440493525587`
          \)\[InvisibleSpace]"\t"\[InvisibleSpace]\(-11.698783896630629`
          \)\[InvisibleSpace]"\t"\[InvisibleSpace]\(-16.8869122718425046`
          \)\[InvisibleSpace]"\t"\[InvisibleSpace]\(-81.040282622112727`
          \)\[InvisibleSpace]"\t"\[InvisibleSpace]\(-11.2960544266208562`
          \)\[InvisibleSpace]"\t"\[InvisibleSpace]\(-10000000000
          \)\[InvisibleSpace]"\t"\[InvisibleSpace]\(-11.3735898499535892`
          \)\[InvisibleSpace]"\t"\[InvisibleSpace]\(-19.2775676400136717`
          \)\),
      SequenceForm[ 
      1, "\t", -81.040283020806328, "\t", -10.614987368306174, 
        "\t", -9.4107440493525587, "\t", -11.69878389663063, 
        "\t", -16.886912271842505, "\t", -81.040282622112727, 
        "\t", -11.296054426620856, "\t", -10000000000, 
        "\t", -11.373589849953589, "\t", -19.277567640013672],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \(2\[InvisibleSpace]"\t"\[InvisibleSpace]\(-47.2331946724676754`
          \)\[InvisibleSpace]"\t"\[InvisibleSpace]\(-6.63143702155190339`
          \)\[InvisibleSpace]"\t"\[InvisibleSpace]\(-6.2545125737053695`
          \)\[InvisibleSpace]"\t"\[InvisibleSpace]\(-7.20292327017091338`
          \)\[InvisibleSpace]"\t"\[InvisibleSpace]\(-11.1143302129758003`
          \)\[InvisibleSpace]"\t"\[InvisibleSpace]\(-47.2331939037314896`
          \)\[InvisibleSpace]"\t"\[InvisibleSpace]\(-6.30214699907077147`
          \)\[InvisibleSpace]"\t"\[InvisibleSpace]\(-6.32576815783022539`
          \)\[InvisibleSpace]"\t"\[InvisibleSpace]\(-7.58493085674638223`
          \)\[InvisibleSpace]"\t"\[InvisibleSpace]\(-11.329991295997559`\)\),
      SequenceForm[ 
      2, "\t", -47.233194672467675, "\t", -6.6314370215519034, 
        "\t", -6.2545125737053695, "\t", -7.2029232701709134, 
        "\t", -11.114330212975801, "\t", -47.23319390373149, 
        "\t", -6.3021469990707715, "\t", -6.3257681578302254, 
        "\t", -7.5849308567463822, "\t", -11.329991295997559],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \(3\[InvisibleSpace]"\t"\[InvisibleSpace]\(-50.4008782681718248`
          \)\[InvisibleSpace]"\t"\[InvisibleSpace]\(-8.17976875242919732`
          \)\[InvisibleSpace]"\t"\[InvisibleSpace]\(-8.18294130824835974`
          \)\[InvisibleSpace]"\t"\[InvisibleSpace]\(-8.71312971206117481`
          \)\[InvisibleSpace]"\t"\[InvisibleSpace]\(-14.8545657890473421`
          \)\[InvisibleSpace]"\t"\[InvisibleSpace]\(-50.4008740451579928`
          \)\[InvisibleSpace]"\t"\[InvisibleSpace]\(-8.61939565663158191`
          \)\[InvisibleSpace]"\t"\[InvisibleSpace]\(-8.62053444788170963`
          \)\[InvisibleSpace]"\t"\[InvisibleSpace]\(-9.34877927174386513`
          \)\[InvisibleSpace]"\t"\[InvisibleSpace]\(-15.8029436951329094`
          \)\),
      SequenceForm[ 
      3, "\t", -50.400878268171823, "\t", -8.1797687524291973, 
        "\t", -8.1829413082483597, "\t", -8.7131297120611748, 
        "\t", -14.854565789047342, "\t", -50.400874045157991, 
        "\t", -8.6193956566315819, "\t", -8.6205344478817096, 
        "\t", -9.3487792717438651, "\t", -15.80294369513291],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \(4\[InvisibleSpace]"\t"\[InvisibleSpace]\(-55.1718350090643561`
          \)\[InvisibleSpace]"\t"\[InvisibleSpace]\(-8.61565248136986383`
          \)\[InvisibleSpace]"\t"\[InvisibleSpace]\(-7.92570622640249666`
          \)\[InvisibleSpace]"\t"\[InvisibleSpace]\(-7.80387318039402089`
          \)\[InvisibleSpace]"\t"\[InvisibleSpace]\(-11.3298083345386535`
          \)\[InvisibleSpace]"\t"\[InvisibleSpace]\(-55.1718345098466933`
          \)\[InvisibleSpace]"\t"\[InvisibleSpace]\(-7.77202076443592204`
          \)\[InvisibleSpace]"\t"\[InvisibleSpace]\(-10000000000
          \)\[InvisibleSpace]"\t"\[InvisibleSpace]\(-8.83694445643476456`
          \)\[InvisibleSpace]"\t"\[InvisibleSpace]\(-13.8625843029471983`
          \)\),
      SequenceForm[ 
      4, "\t", -55.171835009064353, "\t", -8.6156524813698638, 
        "\t", -7.9257062264024967, "\t", -7.8038731803940209, 
        "\t", -11.329808334538654, "\t", -55.17183450984669, 
        "\t", -7.772020764435922, "\t", -10000000000, 
        "\t", -8.8369444564347646, "\t", -13.862584302947198],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \(5\[InvisibleSpace]"\t"\[InvisibleSpace]\(-56.653145174908559`
          \)\[InvisibleSpace]"\t"\[InvisibleSpace]\(-6.9898501247816398`
          \)\[InvisibleSpace]"\t"\[InvisibleSpace]\(-7.0893063318197278`
          \)\[InvisibleSpace]"\t"\[InvisibleSpace]\(-7.13752347759634631`
          \)\[InvisibleSpace]"\t"\[InvisibleSpace]\(-9.652344090723318`
          \)\[InvisibleSpace]"\t"\[InvisibleSpace]\(-56.6531440329453062`
          \)\[InvisibleSpace]"\t"\[InvisibleSpace]\(-7.09685405779896427`
          \)\[InvisibleSpace]"\t"\[InvisibleSpace]\(-7.17603983223926888`
          \)\[InvisibleSpace]"\t"\[InvisibleSpace]\(-7.24092268426261398`
          \)\[InvisibleSpace]"\t"\[InvisibleSpace]\(-9.83770099600332059`
          \)\),
      SequenceForm[ 
      5, "\t", -56.653145174908559, "\t", -6.9898501247816398, 
        "\t", -7.0893063318197278, "\t", -7.1375234775963463, 
        "\t", -9.652344090723318, "\t", -56.653144032945306, 
        "\t", -7.0968540577989643, "\t", -7.1760398322392689, 
        "\t", -7.240922684262614, "\t", -9.8377009960033206],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \(6\[InvisibleSpace]"\t"\[InvisibleSpace]\(-86.7810442537973969`
          \)\[InvisibleSpace]"\t"\[InvisibleSpace]\(-8.07416670967933214`
          \)\[InvisibleSpace]"\t"\[InvisibleSpace]\(-7.82808059153649082`
          \)\[InvisibleSpace]"\t"\[InvisibleSpace]\(-10000000000
          \)\[InvisibleSpace]"\t"\[InvisibleSpace]\(-12.4753100591340171`
          \)\[InvisibleSpace]"\t"\[InvisibleSpace]\(-86.781039109251985`
          \)\[InvisibleSpace]"\t"\[InvisibleSpace]\(-9.31090384218134659`
          \)\[InvisibleSpace]"\t"\[InvisibleSpace]\(-10000000000
          \)\[InvisibleSpace]"\t"\[InvisibleSpace]\(-10000000000
          \)\[InvisibleSpace]"\t"\[InvisibleSpace]\(-13.2743618729947465`
          \)\),
      SequenceForm[ 
      6, "\t", -86.781044253797404, "\t", -8.0741667096793321, 
        "\t", -7.8280805915364908, "\t", -10000000000, 
        "\t", -12.475310059134017, "\t", -86.781039109251992, 
        "\t", -9.3109038421813466, "\t", -10000000000, "\t", -10000000000, 
        "\t", -13.274361872994746],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \(7\[InvisibleSpace]"\t"\[InvisibleSpace]\(-66.2110720376169847`
          \)\[InvisibleSpace]"\t"\[InvisibleSpace]\(-8.45695651968577521`
          \)\[InvisibleSpace]"\t"\[InvisibleSpace]\(-8.53897051195508538`
          \)\[InvisibleSpace]"\t"\[InvisibleSpace]\(-10.578292114366945`
          \)\[InvisibleSpace]"\t"\[InvisibleSpace]\(-14.563927653864197`
          \)\[InvisibleSpace]"\t"\[InvisibleSpace]\(-66.2110719731459784`
          \)\[InvisibleSpace]"\t"\[InvisibleSpace]\(-8.53409258681625715`
          \)\[InvisibleSpace]"\t"\[InvisibleSpace]\(-8.72643250347113053`
          \)\[InvisibleSpace]"\t"\[InvisibleSpace]\(-10.6326067285811509`
          \)\[InvisibleSpace]"\t"\[InvisibleSpace]\(-18.7536535179473276`
          \)\),
      SequenceForm[ 
      7, "\t", -66.211072037616987, "\t", -8.4569565196857752, 
        "\t", -8.5389705119550854, "\t", -10.578292114366945, 
        "\t", -14.563927653864198, "\t", -66.211071973145977, 
        "\t", -8.5340925868162572, "\t", -8.7264325034711305, 
        "\t", -10.632606728581152, "\t", -18.753653517947328],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \(8\[InvisibleSpace]"\t"\[InvisibleSpace]\(-53.8828977192654257`
          \)\[InvisibleSpace]"\t"\[InvisibleSpace]\(-7.48011256427088255`
          \)\[InvisibleSpace]"\t"\[InvisibleSpace]\(-7.62203052000859315`
          \)\[InvisibleSpace]"\t"\[InvisibleSpace]\(-8.30546317556633084`
          \)\[InvisibleSpace]"\t"\[InvisibleSpace]\(-9.55031850973745122`
          \)\[InvisibleSpace]"\t"\[InvisibleSpace]\(-53.8828966305383083`
          \)\[InvisibleSpace]"\t"\[InvisibleSpace]\(-7.68291894693459198`
          \)\[InvisibleSpace]"\t"\[InvisibleSpace]\(-10000000000
          \)\[InvisibleSpace]"\t"\[InvisibleSpace]\(-8.27410868661456788`
          \)\[InvisibleSpace]"\t"\[InvisibleSpace]\(-9.78469947857757915`
          \)\),
      SequenceForm[ 
      8, "\t", -53.882897719265429, "\t", -7.4801125642708826, 
        "\t", -7.6220305200085932, "\t", -8.3054631755663308, 
        "\t", -9.5503185097374512, "\t", -53.882896630538312, 
        "\t", -7.682918946934592, "\t", -10000000000, 
        "\t", -8.2741086866145679, "\t", -9.7846994785775792],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \(9\[InvisibleSpace]"\t"\[InvisibleSpace]\(-42.826940131857949`
          \)\[InvisibleSpace]"\t"\[InvisibleSpace]\(-7.92184503341132995`
          \)\[InvisibleSpace]"\t"\[InvisibleSpace]\(-8.02212685077398646`
          \)\[InvisibleSpace]"\t"\[InvisibleSpace]\(-9.86016471402842853`
          \)\[InvisibleSpace]"\t"\[InvisibleSpace]\(-14.0508261358367008`
          \)\[InvisibleSpace]"\t"\[InvisibleSpace]\(-42.8269400052079696`
          \)\[InvisibleSpace]"\t"\[InvisibleSpace]\(-8.10581383202986671`
          \)\[InvisibleSpace]"\t"\[InvisibleSpace]\(-10000000000
          \)\[InvisibleSpace]"\t"\[InvisibleSpace]\(-10.7788280069684683`
          \)\[InvisibleSpace]"\t"\[InvisibleSpace]\(-18.299523730282317`\)\),
      SequenceForm[ 
      9, "\t", -42.826940131857953, "\t", -7.92184503341133, 
        "\t", -8.0221268507739865, "\t", -9.8601647140284285, 
        "\t", -14.050826135836701, "\t", -42.826940005207973, 
        "\t", -8.1058138320298667, "\t", -10000000000, 
        "\t", -10.778828006968467, "\t", -18.299523730282317],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \(10\[InvisibleSpace]"\t"\[InvisibleSpace]\(-67.2303686689818924`
          \)\[InvisibleSpace]"\t"\[InvisibleSpace]\(-6.27826569942533296`
          \)\[InvisibleSpace]"\t"\[InvisibleSpace]\(-6.61993444697372979`
          \)\[InvisibleSpace]"\t"\[InvisibleSpace]\(-6.86029811339511752`
          \)\[InvisibleSpace]"\t"\[InvisibleSpace]\(-10.261211950912128`
          \)\[InvisibleSpace]"\t"\[InvisibleSpace]\(-67.23036487328363`
          \)\[InvisibleSpace]"\t"\[InvisibleSpace]\(-5.89299619144810549`
          \)\[InvisibleSpace]"\t"\[InvisibleSpace]\(-10000000000
          \)\[InvisibleSpace]"\t"\[InvisibleSpace]\(-7.24690569954157126`
          \)\[InvisibleSpace]"\t"\[InvisibleSpace]\(-10.3164676429810819`
          \)\),
      SequenceForm[ 
      10, "\t", -67.230368668981896, "\t", -6.278265699425333, 
        "\t", -6.6199344469737298, "\t", -6.8602981133951175, 
        "\t", -10.261211950912127, "\t", -67.230364873283634, 
        "\t", -5.8929961914481055, "\t", -10000000000, 
        "\t", -7.2469056995415713, "\t", -10.316467642981081],
      Editable->False]], "Print"],

Cell[BoxData[
    \({{{\(-81.0402830208063207`
            \), {{{0.334972442572081474`, 0.305007936176694194`, 
                0.324992150770084764`}}, {{1.`, 1.`, 1.`}}, {{0.`, 0.`, 0.`, 
                0.`}, {0.`, 0.`, 0.`, 0.`}, {0.`, 0.`, 0.`, 0.`}, {0.`, 0.`, 
                0.`, 0.`}}}, {{{0.00111267850385045252`, 
                0.000441971833570067573`, 0.000215538604705935021`}}, {{0, 0, 
                0}}, {{0, 0, 0, 0}, {0, 0, 0, 0}, {0, 0, 0, 0}, {0, 0, 0, 
                0}}}}, {
          \(-10.6149873683061746`
            \), {{{0.343714422114468565`, 0.343648133753368423`, 
                0.359831067883785093`}}, {{1.`, 1.`, 1.`}}, {{0.`, 0.`, 
                0.1160156173368039`, 0.0090822339974643782`}, {0.`, 
                0.0577367974440041997`, 0.0204512967672010281`, 
                0.00147414648615991854`}, {0.1160156173368039`, 
                0.0204512967672010281`, 0.0027436083700444751`, 
                \(-0.00640074819160594721`\)}, {0.0090822339974643782`, 
                0.00147414648615991854`, \(-0.00640074819160594721`\), 
                \(-0.00981428409895638331`\)}}}, {{{0.000215538604705935021`, 
                0.000194523590747106318`, 0.000194523590747106318`}}, {{0, 0, 
                0}}, {{0, 0, 0.075786435786435744`, 0.03466666666666665`}, {
                0, 0.000031847093666204862`, 0.0181781450872359968`, 
                0.00831515151515151451`}, {0.0000520407364509611536`, 
                5.49388040359628515`*^-6, 3.81373088135670901`*^-6, 
                0.00403878787878788347`}, {0.0000540861852068928605`, 
                0.000011708240753274639`, 3.77277897751290769`*^-6, 
                4.74363388688623732`*^-6}}}}, {
          \(-9.4107440493525587`
            \), {{{0.328880011205099531`, 0.328389326710843576`, 
                0.33036412663793917`}}, {{1.`, 1.`, 1.`}}, {{0.`, 0.`, 
                0.115174999999999982`, 0.0165067499999999451`}, {0.`, 
                0.0630416666666667069`, 0.0274660833333333442`, 
                0.00392939624999999104`}, {0.115174999999999982`, 
                0.0274660833333333442`, 0.00293037069444444817`, 
                \(-0.0100080632083333354`\)}, {0.0165067499999999451`, 
                0.00392939624999999459`, \(-0.0100080632083333354`\), 
                \(-0.0133313346563194423`\)}}}, {{{0.0000203615535304675931`, 
                0.000030691779405864823`, 0.000030691779405864823`}}, {{0, 0, 
                0}}, {{0, 0, 0, 0}, {0, 0, 0, 0}, {0, 0, 0, 0}, {0, 0, 0, 
                0}}}}, {
          \(-11.698783896630629`
            \), {{{0.293444370462245771`, 0.277903181743343674`, 
                0.30126047110182883`}}, {{1.`, 1.`, 1.`}}, {{0.`, 0.`, 
                0.0979999999999999893`, 0.0165507019577741143`}, {0.`, 
                0.0419999999999999928`, 0.0278903262602039792`, 
                0.0108057442666908531`}, {0.0979999999999999893`, 
                0.0278903262602039792`, 0.00994313477025964331`, 
                \(-0.00414091116074435472`\)}, {0.0165507019577741143`, 
                0.0108057442666908531`, \(-0.00414091116074435472`\), 
                \(-0.0131669154507838315`\)}}}, {{{0.000215538604705935021`, 
                0.000142992714093454109`, 0.000215538604705935021`}}, {{0, 0, 
                0}}, {{0, 0, 0, 0.03466666666666665`}, {0, 0, 
                0.0181781450872359968`, 0.00831515151515151451`}, {0, 
                5.49388040359628515`*^-6, 5.1881008755438005`*^-6, 
                0.00403878787878788347`}, {0.0000323833969858550929`, 
                0.000011708240753274639`, 3.07295205705287255`*^-6, 
                2.31335155671896375`*^-6}}}}, {
          \(-16.8869122718425046`
            \), {{{0.283713730508241734`, 0.265546758772819124`, 
                0.289859228999634321`}}, {{1.`, 1.`, 1.`}}, {{0.`, 0.`, 
                0.0979999999999999893`, 0.0335999999999999898`}, {0.`, 
                0.0419999999999999928`, 0.0167999999999999953`, 
                0.00319199999999999706`}, {0.0979999999999999893`, 
                0.0167999999999999953`, 0.00632799999999999762`, 
                \(-0.00154560000000000119`\)}, {0.0335999999999999898`, 
                0.00319199999999999484`, \(-0.00154559999999999941`\), 
                \(-0.00449903999999999726`\)}}}, {{{0.0005426254661275685`, 
                0.000293213144444671947`, 0.0005426254661275685`}}, {{0, 0, 
                0}}, {{0, 0, 0, 0}, {0, 0, 0, 0}, {0, 0, 0, 0}, {0, 0, 0, 
                0}}}}, {
          \(-81.040282622112727`
            \), {{{0.335000000000000008`, 0.304999999999999982`, 0.325`}}, {{
                1.`, 1.`, 1.`}}, {{0.`, 0.`, 0.`, 0.`}, {0.`, 0.`, 0.`, 
                0.`}, {0.`, 0.`, 0.`, 0.`}, {0.`, 0.`, 0.`, 0.`}}}, {{{0, 0, 
                0}}, {{0, 0, 0}}, {{0, 0, 0, 0}, {0, 0, 0, 0}, {0, 0, 0, 0}, {
                0, 0, 0, 0}}}}, {
          \(-11.2960544266208562`
            \), {{{0.335000000000000008`, 0.304999999999999982`, 0.325`}}, {{
                1.`, 1.`, 1.`}}, {{0.`, 0.`, 0.100543023709107015`, 
                0.00710665351660063837`}, {0.`, 0.0573327079715287979`, 
                0.0202563295247031982`, 0.00146177402250841437`}, {
                0.100543023709107015`, 0.0202563295247031982`, 
                0.00174341112719757607`, \(-0.0061941019379679485`\)}, {
                0.00710665351660063837`, 0.00146177402250841437`, 
                \(-0.0061941019379679485`\), 
                \(-0.00799234192592276393`\)}}}, {{{0, 0, 0}}, {{0, 0, 0}}, {{
                0, 0, 0.075786435786435744`, 0.03466666666666665`}, {0, 
                0.000031847093666204862`, 0.0181781450872359968`, 
                0.00831515151515151451`}, {0.000078443071688104542`, 
                8.28114442137601081`*^-6, 4.68226104017827893`*^-6, 
                0.00403878787878788347`}, {0.0000664036466348697285`, 
                0.0000105666872798303645`, 3.07295205705287255`*^-6, 
                7.15026800978844878`*^-6}}}}, {
          \(-10000000000
            \), {{{0.335000000000000008`, 0.304999999999999982`, 0.325`}}, {{
                1.`, 1.`, 1.`}}, {{0.`, 0.`, 0.115174999999999982`, 
                0.0165067499999999451`}, {0.`, 0.0630416666666667069`, 
                0.0274660833333333442`, 0.00392939624999999104`}, {
                0.115174999999999982`, 0.0274660833333333442`, 
                0.00293037069444444817`, \(-0.0100080632083333354`\)}, {
                0.0165067499999999451`, 0.00392939624999999459`, 
                \(-0.0100080632083333354`\), 
                \(-0.0133313346563194423`\)}}}, {{{0, 0, 0}}, {{0, 0, 0}}, {{
                0, 0, 0, 0}, {0, 0, 0, 0}, {0, 0, 0, 0}, {0, 0, 0, 0}}}}, {
          \(-11.3735898499535892`
            \), {{{0.335000000000000008`, 0.304999999999999982`, 0.325`}}, {{
                1.`, 1.`, 1.`}}, {{0.`, 0.`, 0.0979999999999999893`, 
                0.00618943127364203071`}, {0.`, 0.0419999999999999928`, 
                0.022932361805340431`, 0.00728173760045311269`}, {
                0.0979999999999999893`, 0.022932361805340431`, 
                0.00627597166891768942`, \(-0.0041813927566621416`\)}, {
                0.00618943127364203071`, 0.00728173760045311269`, 
                \(-0.0041813927566621416`\), 
                \(-0.0101743227126410151`\)}}}, {{{0, 0, 0}}, {{0, 0, 0}}, {{
                0, 0, 0, 0.03466666666666665`}, {0, 0, 
                0.0181781450872359968`, 0.00831515151515151451`}, {0, 
                0.0000153252333220920355`, 9.60119186075580621`*^-6, 
                0.00403878787878788347`}, {0.0000599292910879699292`, 
                0.0000159275879690631612`, 5.13239096448903087`*^-6, 
                0.0000119422530016002092`}}}}, {
          \(-19.2775676400136717`
            \), {{{0.335000000000000008`, 0.304999999999999982`, 0.325`}}, {{
                1.`, 1.`, 1.`}}, {{0.`, 0.`, 0.0979999999999999893`, 
                0.0335999999999999898`}, {0.`, 0.0419999999999999928`, 
                0.0167999999999999953`, 0.00319199999999999706`}, {
                0.0979999999999999893`, 0.0167999999999999953`, 
                0.00632799999999999762`, \(-0.00154560000000000119`\)}, {
                0.0335999999999999898`, 0.00319199999999999484`, 
                \(-0.00154559999999999941`\), 
                \(-0.00449903999999999726`\)}}}, {{{0, 0, 0}}, {{0, 0, 0}}, {{
                0, 0, 0, 0}, {0, 0, 0, 0}, {0, 0, 0, 0}, {0, 0, 0, 0}}}}}, {{
          \(-47.2331946724676754`
            \), {{{0.3349761821397645`, 0.300027522032565041`, 
                0.320018270289086625`}}, {{1.`, 1.`, 1.`}}, {{0.`, 0.`, 0.`, 
                0.`}, {0.`, 0.`, 0.`, 0.`}, {0.`, 0.`, 0.`, 0.`}, {0.`, 0.`, 
                0.`, 0.`}}}, {{{0.000666201721751758668`, 
                0.000359988820766779804`, 0.000441971833570067573`}}, {{0, 0, 
                0}}, {{0, 0, 0, 0}, {0, 0, 0, 0}, {0, 0, 0, 0}, {0, 0, 0, 
                0}}}}, {
          \(-6.63143702155190339`
            \), {{{0.345678618412862714`, 0.302657113744356598`, 
                0.334539579837766076`}}, {{1.`, 1.`, 1.`}}, {{0.`, 0.`, 
                0.0903289043908231725`, 0.0135794436026988529`}, {0.`, 
                0.0570490138178691807`, 0.03008801081170688`, 
                0.006671939667062448`}, {0.0903289043908231725`, 
                0.03008801081170688`, 0.00684405435336300982`, 
                \(-0.00641523121660070838`\)}, {0.0135794436026988529`, 
                0.006671939667062448`, \(-0.00641523121660070838`\), 
                \(-0.0122339121069574363`\)}}}, {{{0.000398879579796985961`, 
                0.000158440680435960201`, 0.000441971833570067573`}}, {{0, 0, 
                0}}, {{0, 0, 0.075786435786435744`, 0.03466666666666665`}, {
                0, 0.0000653039319834785469`, 0.0181781450872359968`, 
                0.00831515151515151451`}, {0.0000707948721985143514`, 
                0.0000188153661461677419`, 0.0000106384397349094794`, 
                0.00403878787878788347`}, {0.0000664036466348697285`, 
                0.0000176482969186295424`, 7.73625701354496264`*^-6, 
                5.25610402979084589`*^-6}}}}, {
          \(-6.2545125737053695`
            \), {{{0.336861378432761426`, 0.290647207643739502`, 
                0.32080303187052257`}}, {{1.`, 1.`, 1.`}}, {{0.`, 0.`, 
                0.0790749999999999975`, 0.00943899999999998939`}, {0.`, 
                0.0451250000000000017`, 0.0246636666666666659`, 
                0.00786708687500000536`}, {0.0790749999999999975`, 
                0.0246636666666666659`, 0.00705627312499999881`, 
                \(-0.00232876649999999418`\)}, {0.00943899999999998939`, 
                0.00786708687500000536`, \(-0.00232876649999999596`\), 
                \(-0.00817371700140624923`\)}}}, {{{0.000398879579796985961`, 
                0.000175557540649263437`, 0.000293213144444671947`}}, {{0, 0, 
                0}}, {{0, 0, 0, 0}, {0, 0, 0, 0}, {0, 0, 0, 0}, {0, 0, 0, 
                0}}}}, {
          \(-7.20292327017091338`
            \), {{{0.354206643234217644`, 0.323051141145977727`, 
                0.334421507265297535`}}, {{1.`, 1.`, 1.`}}, {{0.`, 0.`, 
                0.0979999999999999893`, 0.0139833892632478452`}, {0.`, 
                0.0419999999999999928`, 0.0250840810146598069`, 
                0.00609958190449934001`}, {0.0979999999999999893`, 
                0.0250840810146598069`, 0.00649899909669548581`, 
                \(-0.00372326922971621732`\)}, {0.0139833892632478452`, 
                0.00609958190449934001`, \(-0.00372326922971621732`\), 
                \(-0.00892000044967092975`\)}}}, {{{0.000215538604705935021`, 
                0.000105112784548557236`, 0.000441971833570067573`}}, {{0, 0, 
                0}}, {{0, 0, 0, 0.03466666666666665`}, {0, 0, 
                0.0181781450872359968`, 0.00831515151515151451`}, {0, 
                0.0000101670729001478021`, 8.66507565433211368`*^-6, 
                0.00403878787878788347`}, {0.0000735774477948695082`, 
                0.0000159275879690631612`, 4.18036451801984298`*^-6, 
                6.45311687883407447`*^-6}}}}, {
          \(-11.1143302129758003`
            \), {{{0.338932482394081402`, 0.306245935617480924`, 
                0.340798746020622989`}}, {{1.`, 1.`, 1.`}}, {{0.`, 0.`, 
                0.0979999999999999893`, 0.0335999999999999898`}, {0.`, 
                0.0419999999999999928`, 0.0167999999999999953`, 
                0.00319199999999999706`}, {0.0979999999999999893`, 
                0.0167999999999999953`, 0.00632799999999999762`, 
                \(-0.00154560000000000119`\)}, {0.0335999999999999898`, 
                0.00319199999999999484`, \(-0.00154559999999999941`\), 
                \(-0.00449903999999999726`\)}}}, {{{0.000398879579796985961`, 
                0.000293213144444671947`, 0.0005426254661275685`}}, {{0, 0, 
                0}}, {{0, 0, 0, 0}, {0, 0, 0, 0}, {0, 0, 0, 0}, {0, 0, 0, 
                0}}}}, {
          \(-47.2331939037314896`
            \), {{{0.335000000000000008`, 0.3`, 0.320000000000000017`}}, {{
                1.`, 1.`, 1.`}}, {{0.`, 0.`, 0.`, 0.`}, {0.`, 0.`, 0.`, 
                0.`}, {0.`, 0.`, 0.`, 0.`}, {0.`, 0.`, 0.`, 0.`}}}, {{{0, 0, 
                0}}, {{0, 0, 0}}, {{0, 0, 0, 0}, {0, 0, 0, 0}, {0, 0, 0, 0}, {
                0, 0, 0, 0}}}}, {
          \(-6.30214699907077147`
            \), {{{0.335000000000000008`, 0.3`, 0.320000000000000017`}}, {{
                1.`, 1.`, 1.`}}, {{0.`, 0.`, 0.0785558153747677678`, 
                0.00573147096965958802`}, {0.`, 0.0421033649445316537`, 
                0.0237282931059138046`, 0.00762599116007571176`}, {
                0.0785558153747677678`, 0.0237282931059138046`, 
                0.00710797136525127548`, \(-0.00138724473393002956`\)}, {
                0.00573147096965958802`, 0.00762599116007571176`, 
                \(-0.00138724473393002956`\), 
                \(-0.00734156326549898352`\)}}}, {{{0, 0, 0}}, {{0, 0, 0}}, {{
                0, 0, 0.075786435786435744`, 0.03466666666666665`}, {0, 
                0.00020184593838263436`, 0.0181781450872359968`, 
                0.00831515151515151451`}, {0.000268650754478678921`, 
                0.0000876606154476825771`, 0.0000447318633614025884`, 
                0.00403878787878788347`}, {0.000342796643268176914`, 
                0.0000669713516702000077`, 0.0000543292723532137245`, 
                0.0000502140579639637518`}}}}, {
          \(-6.32576815783022539`
            \), {{{0.335000000000000008`, 0.3`, 0.320000000000000017`}}, {{
                1.`, 1.`, 1.`}}, {{0.`, 0.`, 0.0790749999999999975`, 
                0.00943899999999998939`}, {0.`, 0.0451250000000000017`, 
                0.0246636666666666659`, 0.00786708687500000536`}, {
                0.0790749999999999975`, 0.0246636666666666659`, 
                0.00705627312499999881`, \(-0.00232876649999999418`\)}, {
                0.00943899999999998939`, 0.00786708687500000536`, 
                \(-0.00232876649999999596`\), 
                \(-0.00817371700140624923`\)}}}, {{{0, 0, 0}}, {{0, 0, 0}}, {{
                0, 0, 0, 0}, {0, 0, 0, 0}, {0, 0, 0, 0}, {0, 0, 0, 0}}}}, {
          \(-7.58493085674638223`
            \), {{{0.335000000000000008`, 0.3`, 0.320000000000000017`}}, {{
                1.`, 1.`, 1.`}}, {{0.`, 0.`, 0.0979999999999999893`, 
                0.0165167282079605293`}, {0.`, 0.0419999999999999928`, 
                0.0264494251958374837`, 0.0057136470497074665`}, {
                0.0979999999999999893`, 0.0264494251958374837`, 
                0.00861681825838658355`, \(-0.00361206487342782711`\)}, {
                0.0165167282079605293`, 0.0057136470497074665`, 
                \(-0.00361206487342782711`\), 
                \(-0.00926016486773587033`\)}}}, {{{0, 0, 0}}, {{0, 0, 0}}, {{
                0, 0, 0, 0.03466666666666665`}, {0, 0, 
                0.0181781450872359968`, 0.00831515151515151451`}, {0, 
                0.0000188153661461677419`, 7.05775827717634474`*^-6, 
                0.00403878787878788347`}, {0.0000903338038165692402`, 
                0.0000195548996328305193`, 6.98197195472432863`*^-6, 
                5.25610402979084589`*^-6}}}}, {
          \(-11.329991295997559`
            \), {{{0.335000000000000008`, 0.3`, 0.320000000000000017`}}, {{
                1.`, 1.`, 1.`}}, {{0.`, 0.`, 0.0979999999999999893`, 
                0.0335999999999999898`}, {0.`, 0.0419999999999999928`, 
                0.0167999999999999953`, 0.00319199999999999706`}, {
                0.0979999999999999893`, 0.0167999999999999953`, 
                0.00632799999999999762`, \(-0.00154560000000000119`\)}, {
                0.0335999999999999898`, 0.00319199999999999484`, 
                \(-0.00154559999999999941`\), 
                \(-0.00449903999999999726`\)}}}, {{{0, 0, 0}}, {{0, 0, 0}}, {{
                0, 0, 0, 0}, {0, 0, 0, 0}, {0, 0, 0, 0}, {0, 0, 0, 0}}}}}, {{
          \(-50.4008782681718248`
            \), {{{0.285050649183066262`, 0.310036861190409807`, 
                0.280068525380044732`}}, {{1.`, 1.`, 1.`}}, {{0.`, 0.`, 0.`, 
                0.`}, {0.`, 0.`, 0.`, 0.`}, {0.`, 0.`, 0.`, 0.`}, {0.`, 0.`, 
                0.`, 0.`}}}, {{{0.000441971833570067573`, 
                0.000441971833570067573`, 0.000666201721751758668`}}, {{0, 0, 
                0}}, {{0, 0, 0, 0}, {0, 0, 0, 0}, {0, 0, 0, 0}, {0, 0, 0, 
                0}}}}, {
          \(-8.17976875242919732`
            \), {{{0.300886771139114816`, 0.301152036547871304`, 
                0.277906275313475426`}}, {{1.`, 1.`, 1.`}}, {{0.`, 0.`, 
                0.0862776904733251015`, 0.0117396092792863715`}, {0.`, 
                0.0323398000187539791`, \(-0.00145730536203688281`\), 
                \(-0.00494133890149735588`\)}, {0.0862776904733251015`, 
                \(-0.00145730536203688281`\), \(-0.000920521221460698946`\), 
                0.00145988112636484634`}, {0.0117396092792863715`, 
                \(-0.00494133890149735588`\), 0.00145988112636484634`, 
                0.0027666309778047724`}}}, {{{0.00136607730615996247`, 
                0.00123288476880936581`, 0.00111267850385045252`}}, {{0, 0, 
                0}}, {{0, 0, 0.075786435786435744`, 0.03466666666666665`}, {
                0, 0.0001821659593903275`, 0.0181781450872359968`, 
                0.00831515151515151451`}, {0.000297673966181361713`, 
                0.000107624239160451629`, 0.000101634067070802935`, 
                0.00403878787878788347`}, {0.000342796643268176914`, 
                0.000206999715209259793`, 0.0000293573703714298304`, 
                0.0000683099060190557771`}}}}, {
          \(-8.18294130824835974`
            \), {{{0.29774543146718333`, 0.298134113439521364`, 
                0.274620556721445252`}}, {{1.`, 1.`, 1.`}}, {{0.`, 0.`, 
                0.086941666666666677`, 0.0127242499999999925`}, {0.`, 
                0.0314249999999999918`, \(-0.00100675000000000314`\), 
                \(-0.00474017312499999832`\)}, {0.086941666666666677`, 
                \(-0.00100675000000000314`\), \(-0.00101191715277777594`\), 
                0.00107983157916666794`}, {0.0127242499999999925`, 
                \(-0.00474017312499999832`\), 0.00107983157916666794`, 
                0.00247004434828124885`}}}, {{{0.000441971833570067573`, 
                0.00048971948318013041`, 0.000238823938732338003`}}, {{0, 0, 
                0}}, {{0, 0, 0, 0}, {0, 0, 0, 0}, {0, 0, 0, 0}, {0, 0, 0, 
                0}}}}, {
          \(-8.71312971206117481`
            \), {{{0.312756973201669463`, 0.311575017194759062`, 
                0.289443693861425455`}}, {{1.`, 1.`, 1.`}}, {{0.`, 0.`, 
                0.0979999999999999893`, 0.0161440249139100222`}, {0.`, 
                0.0419999999999999928`, 0.00201193476983971208`, 
                \(-0.00518496720145436906`\)}, {0.0979999999999999893`, 
                0.00201193476983971208`, \(-0.00117186312420448524`\), 
                0.000906277243071025395`}, {0.0161440249139100222`, 
                \(-0.00518496720145436906`\), 0.000906277243071025395`, 
                0.00280392938252156298`}}}, {{{0.00073817365291053596`, 
                0.000601247053880962134`, 0.0005426254661275685`}}, {{0, 0, 
                0}}, {{0, 0, 0, 0.03466666666666665`}, {0, 0, 
                0.0181781450872359968`, 0.00831515151515151451`}, {0, 
                0.0000524856485848980192`, 0.0000495643915361801568`, 
                0.00403878787878788347`}, {0.000309373970549529575`, 
                0.0000669713516702000077`, 0.0000601986397265526029`, 
                0.0000408996640495107399`}}}}, {
          \(-14.8545657890473421`
            \), {{{0.270549174366387967`, 0.280523094493594591`, 
                0.246811530192880423`}}, {{1.`, 1.`, 1.`}}, {{0.`, 0.`, 
                0.0979999999999999893`, 0.0335999999999999898`}, {0.`, 
                0.0419999999999999928`, 0.0167999999999999953`, 
                0.00319199999999999706`}, {0.0979999999999999893`, 
                0.0167999999999999953`, 0.00632799999999999762`, 
                \(-0.00154560000000000119`\)}, {0.0335999999999999898`, 
                0.00319199999999999484`, \(-0.00154559999999999941`\), 
                \(-0.00449903999999999726`\)}}}, {{{0.00048971948318013041`, 
                0.000441971833570067573`, 0.000264624862861316367`}}, {{0, 0, 
                0}}, {{0, 0, 0, 0}, {0, 0, 0, 0}, {0, 0, 0, 0}, {0, 0, 0, 
                0}}}}, {
          \(-50.4008740451579928`
            \), {{{0.284999999999999964`, 0.310000000000000008`, 
                0.280000000000000035`}}, {{1.`, 1.`, 1.`}}, {{0.`, 0.`, 0.`, 
                0.`}, {0.`, 0.`, 0.`, 0.`}, {0.`, 0.`, 0.`, 0.`}, {0.`, 0.`, 
                0.`, 0.`}}}, {{{0, 0, 0}}, {{0, 0, 0}}, {{0, 0, 0, 0}, {0, 0, 
                0, 0}, {0, 0, 0, 0}, {0, 0, 0, 0}}}}, {
          \(-8.61939565663158191`
            \), {{{0.284999999999999964`, 0.310000000000000008`, 
                0.280000000000000035`}}, {{1.`, 1.`, 1.`}}, {{0.`, 0.`, 
                0.0846582940037768949`, 0.0100559921850441447`}, {0.`, 
                0.0319003920338578117`, \(-0.000823393497660007511`\), 
                \(-0.0055212562355364767`\)}, {0.0846582940037768949`, 
                \(-0.000823393497660007511`\), \(-0.000238949076694748718`\), 
                0.00137138694870856503`}, {0.0100559921850441447`, 
                \(-0.0055212562355364767`\), 0.00137138694870856503`, 
                0.0026870353806215208`}}}, {{{0, 0, 0}}, {{0, 0, 0}}, {{0, 0, 
                0.075786435786435744`, 0.03466666666666665`}, {0, 
                0.000304250410242018975`, 0.0181781450872359968`, 
                0.00831515151515151451`}, {0.000404947966339649578`, 
                0.000047368297847870453`, 0.0000549189933918893657`, 
                0.00403878787878788347`}, {0.00051671101325912474`, 
                0.000152163812012011279`, 0.000073908137262976945`, 
                0.0000556388453894335377`}}}}, {
          \(-8.62053444788170963`
            \), {{{0.284999999999999964`, 0.310000000000000008`, 
                0.280000000000000035`}}, {{1.`, 1.`, 1.`}}, {{0.`, 0.`, 
                0.086941666666666677`, 0.0127242499999999925`}, {0.`, 
                0.0314249999999999918`, \(-0.00100675000000000314`\), 
                \(-0.00474017312499999832`\)}, {0.086941666666666677`, 
                \(-0.00100675000000000314`\), \(-0.00101191715277777594`\), 
                0.00107983157916666794`}, {0.0127242499999999925`, 
                \(-0.00474017312499999832`\), 0.00107983157916666794`, 
                0.00247004434828124885`}}}, {{{0, 0, 0}}, {{0, 0, 0}}, {{0, 
                0, 0, 0}, {0, 0, 0, 0}, {0, 0, 0, 0}, {0, 0, 0, 0}}}}, {
          \(-9.34877927174386513`
            \), {{{0.284999999999999964`, 0.310000000000000008`, 
                0.280000000000000035`}}, {{1.`, 1.`, 1.`}}, {{0.`, 0.`, 
                0.0979999999999999893`, 0.019266505328519214`}, {0.`, 
                0.0419999999999999928`, 0.00314363267050116768`, 
                \(-0.00521199409448597439`\)}, {0.0979999999999999893`, 
                0.00314363267050116768`, \(-0.00171873669078975188`\), 
                0.00007145240712209727`}, {0.019266505328519214`, 
                \(-0.00521199409448597439`\), 0.00007145240712209727`, 
                0.00246384465223507387`}}}, {{{0, 0, 0}}, {{0, 0, 0}}, {{0, 
                0, 0, 0.03466666666666665`}, {0, 0, 0.0181781450872359968`, 
                0.00831515151515151451`}, {0, 0.0000791137054415335327`, 
                0.0000747103785149845656`, 0.00403878787878788347`}, {
                0.000342796643268176914`, 0.0000361886454593945483`, 
                0.0000264950267602154232`, 0.0000616496901821978404`}}}}, {
          \(-15.8029436951329094`
            \), {{{0.284999999999999964`, 0.310000000000000008`, 
                0.280000000000000035`}}, {{1.`, 1.`, 1.`}}, {{0.`, 0.`, 
                0.0979999999999999893`, 0.0335999999999999898`}, {0.`, 
                0.0419999999999999928`, 0.0167999999999999953`, 
                0.00319199999999999706`}, {0.0979999999999999893`, 
                0.0167999999999999953`, 0.00632799999999999762`, 
                \(-0.00154560000000000119`\)}, {0.0335999999999999898`, 
                0.00319199999999999484`, \(-0.00154559999999999941`\), 
                \(-0.00449903999999999726`\)}}}, {{{0, 0, 0}}, {{0, 0, 0}}, {{
                0, 0, 0, 0}, {0, 0, 0, 0}, {0, 0, 0, 0}, {0, 0, 0, 0}}}}}, {{
          \(-55.1718350090643561`
            \), {{{0.265026181135025318`, 0.230009096768770637`, 
                0.270014080578504866`}}, {{1.`, 1.`, 1.`}}, {{0.`, 0.`, 0.`, 
                0.`}, {0.`, 0.`, 0.`, 0.`}, {0.`, 0.`, 0.`, 0.`}, {0.`, 0.`, 
                0.`, 0.`}}}, {{{0.00048971948318013041`, 
                0.000666201721751758668`, 0.00100419234972503357`}}, {{0, 0, 
                0}}, {{0, 0, 0, 0}, {0, 0, 0, 0}, {0, 0, 0, 0}, {0, 0, 0, 
                0}}}}, {
          \(-8.61565248136986383`
            \), {{{0.301161289955527378`, 0.26311794306831433`, 
                0.294752826522583077`}}, {{1.`, 1.`, 1.`}}, {{0.`, 0.`, 
                0.0948555770524755992`, 0.0213015550798299146`}, {0.`, 
                0.0485581102891508464`, 0.019429885037323789`, 
                \(-0.00040266701985071478`\)}, {0.0948555770524755992`, 
                0.019429885037323789`, 0.00668930106867279494`, 
                \(-0.00159807390198784915`\)}, {0.0213015550798299146`, 
                \(-0.00040266701985071478`\), \(-0.00159807390198784915`\), 
                \(-0.00407692420318391057`\)}}}, {{{0.000215538604705935021`, 
                0.000077267555522657183`, 0.000238823938732338003`}}, {{0, 0, 
                0}}, {{0, 0, 0.075786435786435744`, 0.03466666666666665`}, {
                0, 0.0000352876384113073271`, 0.0181781450872359968`, 
                0.00831515151515151451`}, {0.0000520407364509611536`, 
                5.49388040359628515`*^-6, 5.1881008755438005`*^-6, 
                0.00403878787878788347`}, {0.0000599292910879699292`, 
                7.01015623248170793`*^-6, 2.50293865641992008`*^-6, 
                7.92273463688470958`*^-6}}}}, {
          \(-7.92570622640249666`
            \), {{{0.278862942487031029`, 0.261953285903954036`, 
                0.267307120821331078`}}, {{1.`, 1.`, 1.`}}, {{0.`, 0.`, 
                0.0889416666666667055`, 0.0254774999999999973`}, {0.`, 
                0.0379916666666666502`, 0.0230581666666666595`, 
                0.00535031020833333315`}, {0.0889416666666667055`, 
                0.0230581666666666595`, 0.0100259314583333258`, 
                0.0000801008083333356424`}, {0.0254774999999999973`, 
                0.00535031020833333315`, 0.0000801008083333356424`, 
                \(-0.00569617918905902609`\)}}}, {{{0.000324889910742018805`, 
                0.000105112784548557236`, 0.000194523590747106318`}}, {{0, 0, 
                0}}, {{0, 0, 0, 0}, {0, 0, 0, 0}, {0, 0, 0, 0}, {0, 0, 0, 
                0}}}}, {
          \(-7.80387318039402089`
            \), {{{0.286835948641278761`, 0.250310208420569013`, 
                0.279676093809820569`}}, {{1.`, 1.`, 1.`}}, {{0.`, 0.`, 
                0.0979999999999999893`, 0.034601204348289305`}, {0.`, 
                0.0419999999999999928`, 0.0220532104881250212`, 
                0.00348690992492309392`}, {0.0979999999999999893`, 
                0.0220532104881250212`, 0.00843106949844372266`, 
                \(-0.00201707532800528799`\)}, {0.034601204348289305`, 
                0.00348690992492309392`, \(-0.00201707532800528799`\), 
                \(-0.00677161833620465358`\)}}}, {{{0.000293213144444671947`, 
                0.0000948642880550728939`, 0.000158440680435960201`}}, {{0, 
                0, 0}}, {{0, 0, 0, 0.03466666666666665`}, {0, 0, 
                0.0181781450872359968`, 0.00831515151515151451`}, {0, 
                2.18224796020545941`*^-6, 3.44189212042442971`*^-6, 
                0.00403878787878788347`}, {0.0000323833969858550929`, 
                3.78800863631259376`*^-6, 1.49860183024628268`*^-6, 
                3.14702363911547822`*^-6}}}}, {
          \(-11.3298083345386535`
            \), {{{0.305722096599354786`, 0.257991605980748595`, 
                0.299399472403480082`}}, {{1.`, 1.`, 1.`}}, {{0.`, 0.`, 
                0.0979999999999999893`, 0.0335999999999999898`}, {0.`, 
                0.0419999999999999928`, 0.0167999999999999953`, 
                0.00319199999999999706`}, {0.0979999999999999893`, 
                0.0167999999999999953`, 0.00632799999999999762`, 
                \(-0.00154560000000000119`\)}, {0.0335999999999999898`, 
                0.00319199999999999484`, \(-0.00154559999999999941`\), 
                \(-0.00449903999999999726`\)}}}, {{{0.000194523590747106318`, 
                0.000398879579796985961`, 0.000293213144444671947`}}, {{0, 0, 
                0}}, {{0, 0, 0, 0}, {0, 0, 0, 0}, {0, 0, 0, 0}, {0, 0, 0, 
                0}}}}, {
          \(-55.1718345098466933`
            \), {{{0.265000000000000035`, 0.230000000000000026`, 
                0.270000000000000017`}}, {{1.`, 1.`, 1.`}}, {{0.`, 0.`, 0.`, 
                0.`}, {0.`, 0.`, 0.`, 0.`}, {0.`, 0.`, 0.`, 0.`}, {0.`, 0.`, 
                0.`, 0.`}}}, {{{0, 0, 0}}, {{0, 0, 0}}, {{0, 0, 0, 0}, {0, 0, 
                0, 0}, {0, 0, 0, 0}, {0, 0, 0, 0}}}}, {
          \(-7.77202076443592204`
            \), {{{0.265000000000000035`, 0.230000000000000026`, 
                0.270000000000000017`}}, {{1.`, 1.`, 1.`}}, {{0.`, 0.`, 
                0.0827967064176047884`, 0.0236783135908093944`}, {0.`, 
                0.0399017468825833496`, 0.0191535555464783247`, 
                0.00270807982368636057`}, {0.0827967064176047884`, 
                0.0191535555464783247`, 0.00938698513191881644`, 
                0.00113029012349366642`}, {0.0236783135908093944`, 
                0.00270807982368636057`, 0.00113029012349366642`, 
                \(-0.00335993614130037343`\)}}}, {{{0, 0, 0}}, {{0, 0, 0}}, {{
                0, 0, 0.075786435786435744`, 0.03466666666666665`}, {0, 
                0.000021128012615336793`, 0.0181781450872359968`, 
                0.00831515151515151451`}, {0.0000281207369106695423`, 
                6.08740210924796087`*^-6, 5.1881008755438005`*^-6, 
                0.00403878787878788347`}, {0.0000323833969858550929`, 
                5.70981606483280224`*^-6, 4.18036451801984298`*^-6, 
                3.86371944858063276`*^-6}}}}, {
          \(-10000000000
            \), {{{0.265000000000000035`, 0.230000000000000026`, 
                0.270000000000000017`}}, {{1.`, 1.`, 1.`}}, {{0.`, 0.`, 
                0.0889416666666667055`, 0.0254774999999999973`}, {0.`, 
                0.0379916666666666502`, 0.0230581666666666595`, 
                0.00535031020833333315`}, {0.0889416666666667055`, 
                0.0230581666666666595`, 0.0100259314583333258`, 
                0.0000801008083333356424`}, {0.0254774999999999973`, 
                0.00535031020833333315`, 0.0000801008083333356424`, 
                \(-0.00569617918905902609`\)}}}, {{{0, 0, 0}}, {{0, 0, 0}}, {{
                0, 0, 0, 0}, {0, 0, 0, 0}, {0, 0, 0, 0}, {0, 0, 0, 0}}}}, {
          \(-8.83694445643476456`
            \), {{{0.265000000000000035`, 0.230000000000000026`, 
                0.270000000000000017`}}, {{1.`, 1.`, 1.`}}, {{0.`, 0.`, 
                0.0979999999999999893`, 0.0352028129925043753`}, {0.`, 
                0.0419999999999999928`, 0.0196125240082434295`, 
                0.00297434037955442143`}, {0.0979999999999999893`, 
                0.0196125240082434295`, 0.00666801273694813723`, 
                \(-0.00162284825661331293`\)}, {0.0352028129925043753`, 
                0.00297434037955442143`, \(-0.00162284825661331293`\), 
                \(-0.00444878579829228648`\)}}}, {{{0, 0, 0}}, {{0, 0, 0}}, {{
                0, 0, 0, 0.03466666666666665`}, {0, 0, 
                0.0181781450872359968`, 0.00831515151515151451`}, {0, 
                2.41800328000604913`*^-6, 1.51486851282116452`*^-6, 
                0.00403878787878788347`}, {0.0000292260157797342223`, 
                2.51304232322919318`*^-6, 1.10161005268982536`*^-6, 
                2.087799779938865`*^-6}}}}, {
          \(-13.8625843029471983`
            \), {{{0.265000000000000035`, 0.230000000000000026`, 
                0.270000000000000017`}}, {{1.`, 1.`, 1.`}}, {{0.`, 0.`, 
                0.0979999999999999893`, 0.0335999999999999898`}, {0.`, 
                0.0419999999999999928`, 0.0167999999999999953`, 
                0.00319199999999999706`}, {0.0979999999999999893`, 
                0.0167999999999999953`, 0.00632799999999999762`, 
                \(-0.00154560000000000119`\)}, {0.0335999999999999898`, 
                0.00319199999999999484`, \(-0.00154559999999999941`\), 
                \(-0.00449903999999999726`\)}}}, {{{0, 0, 0}}, {{0, 0, 0}}, {{
                0, 0, 0, 0}, {0, 0, 0, 0}, {0, 0, 0, 0}, {0, 0, 0, 0}}}}}, {{
          \(-56.653145174908559`
            \), {{{0.299988395990496812`, 0.315047785599714424`, 
                0.30999351881749777`}}, {{1.`, 1.`, 1.`}}, {{0.`, 0.`, 0.`, 
                0.`}, {0.`, 0.`, 0.`, 0.`}, {0.`, 0.`, 0.`, 0.`}, {0.`, 0.`, 
                0.`, 0.`}}}, {{{0.00073817365291053596`, 
                0.00048971948318013041`, 0.000601247053880962134`}}, {{0, 0, 
                0}}, {{0, 0, 0, 0}, {0, 0, 0, 0}, {0, 0, 0, 0}, {0, 0, 0, 
                0}}}}, {
          \(-6.9898501247816398`
            \), {{{0.298418808027180517`, 0.318116555339340534`, 
                0.323489950017569505`}}, {{1.`, 1.`, 1.`}}, {{0.`, 0.`, 
                0.106124400660961804`, 0.0326703592425285282`}, {0.`, 
                0.038662886401191244`, 0.0153350432850192541`, 
                0.00113617213214405499`}, {0.106124400660961804`, 
                0.0153350432850192541`, 0.00683953646615007482`, 
                0.00115756695292850286`}, {0.0326703592425285282`, 
                0.00113617213214405499`, 0.00115756695292850286`, 
                \(-0.00223690381272105565`\)}}}, {{{0.000293213144444671947`, 
                0.000359988820766779804`, 0.000158440680435960201`}}, {{0, 0, 
                0}}, {{0, 0, 0.075786435786435744`, 0.03466666666666665`}, {
                0, 0.0000984352137853056774`, 0.0181781450872359968`, 
                0.00831515151515151451`}, {0.000106711926343534568`, 
                0.0000124824983235522246`, 0.0000196876860038400725`, 
                0.00403878787878788347`}, {0.0000664036466348697285`, 
                0.00001297311994822675`, 7.73625701354496264`*^-6, 
                6.45311687883407447`*^-6}}}}, {
          \(-7.0893063318197278`
            \), {{{0.300807662168686329`, 0.31696831316675853`, 
                0.321563614118185192`}}, {{1.`, 1.`, 1.`}}, {{0.`, 0.`, 
                0.101675000000000048`, 0.0326187499999999719`}, {0.`, 
                0.0348916666666666586`, 0.0127970833333333344`, 
                0.00140673354166665998`}, {0.101675000000000048`, 
                0.0127970833333333344`, 0.00645364840277777673`, 
                0.00175913910416666974`}, {0.0326187499999999719`, 
                0.00140673354166665802`, 0.00175913910416666974`, 
                \(-0.00161774333741318621`\)}}}, {{{0.000194523590747106318`, 
                0.000441971833570067573`, 0.000359988820766779804`}}, {{0, 0, 
                0}}, {{0, 0, 0, 0}, {0, 0, 0, 0}, {0, 0, 0, 0}, {0, 0, 0, 
                0}}}}, {
          \(-7.13752347759634631`
            \), {{{0.299218544971399147`, 0.318366285325959053`, 
                0.323989666502743745`}}, {{1.`, 1.`, 1.`}}, {{0.`, 0.`, 
                0.0979999999999999893`, 0.0294866012568705038`}, {0.`, 
                0.0419999999999999928`, 0.016403463449075577`, 
                0.00164979194875942036`}, {0.0979999999999999893`, 
                0.016403463449075577`, 0.00758037215575522171`, 
                0.00121730394452393619`}, {0.0294866012568705038`, 
                0.00164979194875942036`, 0.00121730394452393619`, 
                \(-0.00287016490788824896`\)}}}, {{{0.000359988820766779804`, 
                0.000359988820766779804`, 0.000324889910742018805`}}, {{0, 0, 
                0}}, {{0, 0, 0, 0.03466666666666665`}, {0, 0, 
                0.0181781450872359968`, 0.00831515151515151451`}, {0, 
                0.0000255959375775051567`, 0.0000241713136072805756`, 
                0.00403878787878788347`}, {0.0000903338038165692402`, 
                0.0000143746481420795024`, 8.57202993190577622`*^-6, 
                9.72703970888462876`*^-6}}}}, {
          \(-9.652344090723318`
            \), {{{0.314126154047512473`, 0.322061299097755426`, 
                0.321596566101548342`}}, {{1.`, 1.`, 1.`}}, {{0.`, 0.`, 
                0.0979999999999999893`, 0.0335999999999999898`}, {0.`, 
                0.0419999999999999928`, 0.0167999999999999953`, 
                0.00319199999999999706`}, {0.0979999999999999893`, 
                0.0167999999999999953`, 0.00632799999999999762`, 
                \(-0.00154560000000000119`\)}, {0.0335999999999999898`, 
                0.00319199999999999484`, \(-0.00154559999999999941`\), 
                \(-0.00449903999999999726`\)}}}, {{{0.000441971833570067573`, 
                0.00048971948318013041`, 0.00073817365291053596`}}, {{0, 0, 
                0}}, {{0, 0, 0, 0}, {0, 0, 0, 0}, {0, 0, 0, 0}, {0, 0, 0, 
                0}}}}, {
          \(-56.6531440329453062`
            \), {{{0.3`, 0.314999999999999991`, 0.310000000000000008`}}, {{
                1.`, 1.`, 1.`}}, {{0.`, 0.`, 0.`, 0.`}, {0.`, 0.`, 0.`, 
                0.`}, {0.`, 0.`, 0.`, 0.`}, {0.`, 0.`, 0.`, 0.`}}}, {{{0, 0, 
                0}}, {{0, 0, 0}}, {{0, 0, 0, 0}, {0, 0, 0, 0}, {0, 0, 0, 0}, {
                0, 0, 0, 0}}}}, {
          \(-7.09685405779896427`
            \), {{{0.3`, 0.314999999999999991`, 0.310000000000000008`}}, {{
                1.`, 1.`, 1.`}}, {{0.`, 0.`, 0.102230905409839101`, 
                0.0333110688062625071`}, {0.`, 0.0341713112044546019`, 
                0.0133506545856897607`, 0.00202414589446225878`}, {
                0.102230905409839101`, 0.0133506545856897607`, 
                0.00686597117673204593`, 0.00198047372320167589`}, {
                0.0333110688062625071`, 0.00202414589446225878`, 
                0.00198047372320167589`, \(-0.00177950840286400202`\)}}}, {{{
                0, 0, 0}}, {{0, 0, 0}}, {{0, 0, 0.075786435786435744`, 
                0.03466666666666665`}, {0, 0.000164404778349770541`, 
                0.0181781450872359968`, 0.00831515151515151451`}, {
                0.000242457305917007648`, 0.0000581558433073662328`, 
                0.0000674261166097735564`, 0.00403878787878788347`}, {
                0.000227418296921416729`, 0.0000742064838450969688`, 
                0.0000293573703714298304`, 0.0000369119468046834509`}}}}, {
          \(-7.17603983223926888`
            \), {{{0.3`, 0.314999999999999991`, 0.310000000000000008`}}, {{
                1.`, 1.`, 1.`}}, {{0.`, 0.`, 0.101675000000000048`, 
                0.0326187499999999719`}, {0.`, 0.0348916666666666586`, 
                0.0127970833333333344`, 0.00140673354166665998`}, {
                0.101675000000000048`, 0.0127970833333333344`, 
                0.00645364840277777673`, 0.00175913910416666974`}, {
                0.0326187499999999719`, 0.00140673354166665802`, 
                0.00175913910416666974`, \(-0.00161774333741318621`\)}}}, {{{
                0, 0, 0}}, {{0, 0, 0}}, {{0, 0, 0, 0}, {0, 0, 0, 0}, {0, 0, 
                0, 0}, {0, 0, 0, 0}}}}, {
          \(-7.24092268426261398`
            \), {{{0.3`, 0.314999999999999991`, 0.310000000000000008`}}, {{
                1.`, 1.`, 1.`}}, {{0.`, 0.`, 0.0979999999999999893`, 
                0.0305327607186045657`}, {0.`, 0.0419999999999999928`, 
                0.0152133079529813253`, 0.00156975094850182994`}, {
                0.0979999999999999893`, 0.0152133079529813253`, 
                0.00713801014274350009`, 0.0015039056877108865`}, {
                0.0305327607186045657`, 0.00156975094850182994`, 
                0.0015039056877108865`, \(-0.00240896598318938259`\)}}}, {{{
                0, 0, 0}}, {{0, 0, 0}}, {{0, 0, 0, 0.03466666666666665`}, {0, 
                0, 0.0181781450872359968`, 0.00831515151515151451`}, {0, 
                0.00013213433188566892`, 0.0000495643915361801568`, 
                0.00403878787878788347`}, {0.000251987032599907845`, 
                0.0000492300975169590593`, 0.0000215803648901127065`, 
                0.0000453181873124772849`}}}}, {
          \(-9.83770099600332059`
            \), {{{0.3`, 0.314999999999999991`, 0.310000000000000008`}}, {{
                1.`, 1.`, 1.`}}, {{0.`, 0.`, 0.0979999999999999893`, 
                0.0335999999999999898`}, {0.`, 0.0419999999999999928`, 
                0.0167999999999999953`, 0.00319199999999999706`}, {
                0.0979999999999999893`, 0.0167999999999999953`, 
                0.00632799999999999762`, \(-0.00154560000000000119`\)}, {
                0.0335999999999999898`, 0.00319199999999999484`, 
                \(-0.00154559999999999941`\), 
                \(-0.00449903999999999726`\)}}}, {{{0, 0, 0}}, {{0, 0, 0}}, {{
                0, 0, 0, 0}, {0, 0, 0, 0}, {0, 0, 0, 0}, {0, 0, 0, 0}}}}}, {{
          \(-86.7810442537973969`
            \), {{{0.289897118936887245`, 0.299997422199866914`, 
                0.255000317996531444`}}, {{1.`, 1.`, 1.`}}, {{0.`, 0.`, 0.`, 
                0.`}, {0.`, 0.`, 0.`, 0.`}, {0.`, 0.`, 0.`, 0.`}, {0.`, 0.`, 
                0.`, 0.`}}}, {{{0.000601247053880962134`, 
                0.000324889910742018805`, 0.000601247053880962134`}}, {{0, 0, 
                0}}, {{0, 0, 0, 0}, {0, 0, 0, 0}, {0, 0, 0, 0}, {0, 0, 0, 
                0}}}}, {
          \(-8.07416670967933214`
            \), {{{0.277690387921320125`, 0.27831845381099054`, 
                0.270944168050125`}}, {{1.`, 1.`, 1.`}}, {{0.`, 0.`, 
                0.100382311784863698`, 0.0525258345730716591`}, {0.`, 
                0.0701593936144160412`, 0.0228169382562650246`, 
                0.00314077390352482099`}, {0.100382311784863698`, 
                0.0228169382562650246`, 0.00677700302773158469`, 
                \(-0.00588032382147379273`\)}, {0.0525258345730716591`, 
                0.00314077390352482099`, \(-0.00588032382147379273`\), 
                \(-0.0106703196684074796`\)}}}, {{{0.000666201721751758668`, 
                0.000666201721751758668`, 0.000817920945053225523`}}, {{0, 0, 
                0}}, {{0, 0, 0.075786435786435744`, 0.03466666666666665`}, {
                0, 0.0000390998763560192053`, 0.0181781450872359968`, 
                0.00831515151515151451`}, {0.000218817718590099419`, 
                0.0000385817746489520239`, 0.000013061213139751211`, 
                0.00403878787878788347`}, {0.000100092857414481173`, 
                0.0000400982221156726303`, 0.0000129209616219534462`, 
                0.0000119422530016002092`}}}}, {
          \(-7.82808059153649082`
            \), {{{0.283442323524842887`, 0.283453149753464437`, 
                0.276474171628027631`}}, {{1.`, 1.`, 1.`}}, {{0.`, 0.`, 
                0.104741666666666666`, 0.0563147499999999912`}, {0.`, 
                0.0769583333333333108`, 0.023055083333333326`, 
                0.000863470208333331257`}, {0.104741666666666666`, 
                0.023055083333333326`, 0.0040254106250000099`, 
                \(-0.00796676306249999122`\)}, {0.0563147499999999912`, 
                0.000863470208333327882`, \(-0.00796676306249999122`\), 
                \(-0.0101733340343576372`\)}}}, {{{0.000194523590747106318`, 
                0.000293213144444671947`, 0.0000856150199697032476`}}, {{0, 
                0, 0}}, {{0, 0, 0, 0}, {0, 0, 0, 0}, {0, 0, 0, 0}, {0, 0, 0, 
                0}}}}, {
          \(-10000000000
            \), {{{0.29`, 0.3`, 0.254999999999999982`}}, {{1.`, 1.`, 1.`}}, {{
                0.`, 0.`, 0.0979999999999999893`, 0.0563147499999999912`}, {
                0.`, 0.0419999999999999928`, 0.023055083333333326`, 
                0.0126977024999999921`}, {0.0979999999999999893`, 
                0.023055083333333326`, 0.0137093975000000023`, 
                \(-0.00228501499999999424`\)}, {0.0563147499999999912`, 
                0.0126977024999999876`, \(-0.00228501499999999779`\), 
                \(-0.0132324118751249875`\)}}}, {{{1.12611244643874397`*^-10, 
                1.12611244643874397`*^-10, 1.12611244643874397`*^-10}}, {{0, 
                0, 0}}, {{0, 0, 0, 0.03466666666666665`}, {0, 0, 
                0.0181781450872359968`, 0.00831515151515151451`}, {0, 
                2.23352943830675076`*^-11, 8.37810476717042007`*^-12, 
                0.00403878787878788347`}, {4.25945662532615632`*^-11, 
                1.02167386187892939`*^-11, 4.96241590055480141`*^-12, 
                3.37152374420047262`*^-12}}}}, {
          \(-12.4753100591340171`
            \), {{{0.263695172674783062`, 0.268568621033923804`, 
                0.249480301050056407`}}, {{1.`, 1.`, 1.`}}, {{0.`, 0.`, 
                0.0979999999999999893`, 0.0335999999999999898`}, {0.`, 
                0.0419999999999999928`, 0.0167999999999999953`, 
                0.00319199999999999706`}, {0.0979999999999999893`, 
                0.0167999999999999953`, 0.00632799999999999762`, 
                \(-0.00154560000000000119`\)}, {0.0335999999999999898`, 
                0.00319199999999999484`, \(-0.00154559999999999941`\), 
                \(-0.00449903999999999726`\)}}}, {{{0.000293213144444671947`, 
                0.000359988820766779804`, 0.000264624862861316367`}}, {{0, 0, 
                0}}, {{0, 0, 0, 0}, {0, 0, 0, 0}, {0, 0, 0, 0}, {0, 0, 0, 
                0}}}}, {
          \(-86.781039109251985`
            \), {{{0.29`, 0.3`, 0.254999999999999982`}}, {{1.`, 1.`, 1.`}}, {{
                0.`, 0.`, 0.`, 0.`}, {0.`, 0.`, 0.`, 0.`}, {0.`, 0.`, 0.`, 
                0.`}, {0.`, 0.`, 0.`, 0.`}}}, {{{0, 0, 0}}, {{0, 0, 0}}, {{0, 
                0, 0, 0}, {0, 0, 0, 0}, {0, 0, 0, 0}, {0, 0, 0, 0}}}}, {
          \(-9.31090384218134659`
            \), {{{0.29`, 0.3`, 0.254999999999999982`}}, {{1.`, 1.`, 1.`}}, {{
                0.`, 0.`, 0.100293266436351746`, 0.052344156070130543`}, {
                0.`, 0.0633710150049574139`, 0.0169663479628693325`, 
                0.000240086500448639439`}, {0.100293266436351746`, 
                0.0169663479628693325`, 0.00278460309004520079`, 
                \(-0.00466199555071689442`\)}, {0.052344156070130543`, 
                0.000240086500448639439`, \(-0.00466199555071689442`\), 
                \(-0.00566973341121847962`\)}}}, {{{0, 0, 0}}, {{0, 0, 0}}, {{
                0, 0, 0.075786435786435744`, 0.03466666666666665`}, {0, 
                0.0000433239627213509237`, 0.0181781450872359968`, 
                0.00831515151515151451`}, {0.000160851130460645368`, 
                0.0000101670729001478021`, 6.36962684515165022`*^-6, 
                0.00403878787878788347`}, {0.0000815262579444537394`, 
                0.0000326602525271035837`, 9.49809410737482195`*^-6, 
                5.25610402979084589`*^-6}}}}, {
          \(-10000000000
            \), {{{0.29`, 0.3`, 0.254999999999999982`}}, {{1.`, 1.`, 1.`}}, {{
                0.`, 0.`, 0.104741666666666666`, 0.0563147499999999912`}, {
                0.`, 0.0769583333333333108`, 0.023055083333333326`, 
                0.000863470208333331257`}, {0.104741666666666666`, 
                0.023055083333333326`, 0.0040254106250000099`, 
                \(-0.00796676306249999122`\)}, {0.0563147499999999912`, 
                0.000863470208333327882`, \(-0.00796676306249999122`\), 
                \(-0.0101733340343576372`\)}}}, {{{0, 0, 0}}, {{0, 0, 0}}, {{
                0, 0, 0, 0}, {0, 0, 0, 0}, {0, 0, 0, 0}, {0, 0, 0, 0}}}}, {
          \(-10000000000
            \), {{{0.29`, 0.3`, 0.254999999999999982`}}, {{1.`, 1.`, 1.`}}, {{
                0.`, 0.`, 0.0979999999999999893`, 0.0563147499999999912`}, {
                0.`, 0.0419999999999999928`, 0.023055083333333326`, 
                0.0126977024999999921`}, {0.0979999999999999893`, 
                0.023055083333333326`, 0.0137093975000000023`, 
                \(-0.00228501499999999424`\)}, {0.0563147499999999912`, 
                0.0126977024999999876`, \(-0.00228501499999999779`\), 
                \(-0.0132324118751249875`\)}}}, {{{0, 0, 0}}, {{0, 0, 0}}, {{
                0, 0, 0, 0.03466666666666665`}, {0, 0, 
                0.0181781450872359968`, 0.00831515151515151451`}, {0, 
                2.23352943830675076`*^-11, 8.37810476717042007`*^-12, 
                0.00403878787878788347`}, {4.25945662532615632`*^-11, 
                1.02167386187892939`*^-11, 4.96241590055480141`*^-12, 
                3.37152374420047262`*^-12}}}}, {
          \(-13.2743618729947465`
            \), {{{0.29`, 0.3`, 0.254999999999999982`}}, {{1.`, 1.`, 1.`}}, {{
                0.`, 0.`, 0.0979999999999999893`, 0.0335999999999999898`}, {
                0.`, 0.0419999999999999928`, 0.0167999999999999953`, 
                0.00319199999999999706`}, {0.0979999999999999893`, 
                0.0167999999999999953`, 0.00632799999999999762`, 
                \(-0.00154560000000000119`\)}, {0.0335999999999999898`, 
                0.00319199999999999484`, \(-0.00154559999999999941`\), 
                \(-0.00449903999999999726`\)}}}, {{{0, 0, 0}}, {{0, 0, 0}}, {{
                0, 0, 0, 0}, {0, 0, 0, 0}, {0, 0, 0, 0}, {0, 0, 0, 0}}}}}, {{
          \(-66.2110720376169847`
            \), {{{0.355007931842485868`, 0.294996595271343053`, 
                0.289991956683407359`}}, {{1.`, 1.`, 1.`}}, {{0.`, 0.`, 0.`, 
                0.`}, {0.`, 0.`, 0.`, 0.`}, {0.`, 0.`, 0.`, 0.`}, {0.`, 0.`, 
                0.`, 0.`}}}, {{{0.00048971948318013041`, 
                0.000666201721751758668`, 0.00073817365291053596`}}, {{0, 0, 
                0}}, {{0, 0, 0, 0}, {0, 0, 0, 0}, {0, 0, 0, 0}, {0, 0, 0, 
                0}}}}, {
          \(-8.45695651968577521`
            \), {{{0.350910946888943353`, 0.302624587892264651`, 
                0.291661537828860684`}}, {{1.`, 1.`, 1.`}}, {{0.`, 0.`, 
                0.0885453694975976368`, 0.0365164436661699109`}, {0.`, 
                0.0724036048795905085`, 0.012795988284733395`, 
                \(-0.00166063704747099238`\)}, {0.0885453694975976368`, 
                0.012795988284733395`, \(-0.00337232127288496386`\), 
                \(-0.00476868053721823148`\)}, {0.0365164436661699109`, 
                \(-0.00166063704747099238`\), \(-0.00476868053721823148`\), 
                \(-0.000448523052504344921`\)}}}, {{{
                0.000817920945053225523`, 0.000601247053880962134`, 
                0.00048971948318013041`}}, {{0, 0, 0}}, {{0, 0, 
                0.075786435786435744`, 0.03466666666666665`}, {0, 
                0.000413894390786075838`, 0.0181781450872359968`, 
                0.00831515151515151451`}, {0.000365465539621533652`, 
                0.0000714001191609840102`, 0.0000608520702403206303`, 
                0.00403878787878788347`}, {0.0001852336242068497`, 
                0.0000822232507978913851`, 0.0000543292723532137245`, 
                0.0000453181873124772849`}}}}, {
          \(-8.53897051195508538`
            \), {{{0.342068077407440762`, 0.297739206264047773`, 
                0.288314054226198734`}}, {{1.`, 1.`, 1.`}}, {{0.`, 0.`, 
                0.0868999999999999772`, 0.0364787500000000042`}, {0.`, 
                0.0709500000000000152`, 0.0134110833333333379`, 
                \(-0.000692696041666662765`\)}, {0.0868999999999999772`, 
                0.0134110833333333379`, \(-0.001916828958333328`\), 
                \(-0.00406351660833333472`\)}, {0.0364787500000000042`, 
                \(-0.000692696041666662765`\), \(-0.00406351660833333472`\), 
                \(-0.000822823275968751666`\)}}}, {{{
                0.000324889910742018805`, 0.000324889910742018805`, 
                0.000441971833570067573`}}, {{0, 0, 0}}, {{0, 0, 0, 0}, {0, 
                0, 0, 0}, {0, 0, 0, 0}, {0, 0, 0, 0}}}}, {
          \(-10.578292114366945`
            \), {{{0.349008896333840823`, 0.298227130694584374`, 
                0.285220399344434127`}}, {{1.`, 1.`, 1.`}}, {{0.`, 0.`, 
                0.0979999999999999893`, 0.0359752077931409441`}, {0.`, 
                0.0419999999999999928`, 0.00630718300822931698`, 
                0.0000998096753763410937`}, {0.0979999999999999893`, 
                0.00630718300822931698`, \(-0.00157391220224128813`\), 
                \(-0.00160412367299840363`\)}, {0.0359752077931409441`, 
                0.0000998096753763410937`, \(-0.00160412367299840363`\), 
                \(-0.000121142862258915262`\)}}}, {{{
                0.000601247053880962134`, 0.000441971833570067573`, 
                0.000666201721751758668`}}, {{0, 0, 0}}, {{0, 0, 0, 
                0.03466666666666665`}, {0, 0, 0.0181781450872359968`, 
                0.00831515151515151451`}, {0, 0.0000644386075427880555`, 
                0.0000608520702403206303`, 0.00403878787878788347`}, {
                0.000279210008420950472`, 0.0000742064838450969688`, 
                0.000036043149296189969`, 0.0000333130319912268157`}}}}, {
          \(-14.563927653864197`
            \), {{{0.315520767055639739`, 0.270569502075596624`, 
                0.272446681033825388`}}, {{1.`, 1.`, 1.`}}, {{0.`, 0.`, 
                0.0979999999999999893`, 0.0335999999999999898`}, {0.`, 
                0.0419999999999999928`, 0.0167999999999999953`, 
                0.00319199999999999706`}, {0.0979999999999999893`, 
                0.0167999999999999953`, 0.00632799999999999762`, 
                \(-0.00154560000000000119`\)}, {0.0335999999999999898`, 
                0.00319199999999999484`, \(-0.00154559999999999941`\), 
                \(-0.00449903999999999726`\)}}}, {{{0.000324889910742018805`, 
                0.000398879579796985961`, 0.000441971833570067573`}}, {{0, 0, 
                0}}, {{0, 0, 0, 0}, {0, 0, 0, 0}, {0, 0, 0, 0}, {0, 0, 0, 
                0}}}}, {
          \(-66.2110719731459784`
            \), {{{0.354999999999999982`, 0.294999999999999964`, 0.29`}}, {{
                1.`, 1.`, 1.`}}, {{0.`, 0.`, 0.`, 0.`}, {0.`, 0.`, 0.`, 
                0.`}, {0.`, 0.`, 0.`, 0.`}, {0.`, 0.`, 0.`, 0.`}}}, {{{0, 0, 
                0}}, {{0, 0, 0}}, {{0, 0, 0, 0}, {0, 0, 0, 0}, {0, 0, 0, 0}, {
                0, 0, 0, 0}}}}, {
          \(-8.53409258681625715`
            \), {{{0.354999999999999982`, 0.294999999999999964`, 0.29`}}, {{
                1.`, 1.`, 1.`}}, {{0.`, 0.`, 0.0877452441146567707`, 
                0.0360119210788831134`}, {0.`, 0.0719993437528937629`, 
                0.0130936811810307474`, \(-0.00144239187508206923`\)}, {
                0.0877452441146567707`, 0.0130936811810307474`, 
                \(-0.00322205749099072846`\), \(-0.00484897845772969837`\)}, {
                0.0360119210788831134`, \(-0.00144239187508206923`\), 
                \(-0.00484897845772969837`\), 
                \(-0.000642597857718788567`\)}}}, {{{0, 0, 0}}, {{0, 0, 
                0}}, {{0, 0, 0.075786435786435744`, 0.03466666666666665`}, {
                0, 0.000247813860707188426`, 0.0181781450872359968`, 
                0.00831515151515151451`}, {0.00055088074226386734`, 
                0.0000971308758423075779`, 0.0000447318633614025884`, 
                0.00403878787878788347`}, {0.000379830075643409426`, 
                0.0000822232507978913851`, 0.0000667020938798366991`, 
                0.0000502140579639637518`}}}}, {
          \(-8.72643250347113053`
            \), {{{0.354999999999999982`, 0.294999999999999964`, 0.29`}}, {{
                1.`, 1.`, 1.`}}, {{0.`, 0.`, 0.0868999999999999772`, 
                0.0364787500000000042`}, {0.`, 0.0709500000000000152`, 
                0.0134110833333333379`, \(-0.000692696041666662765`\)}, {
                0.0868999999999999772`, 0.0134110833333333379`, 
                \(-0.001916828958333328`\), \(-0.00406351660833333472`\)}, {
                0.0364787500000000042`, \(-0.000692696041666662765`\), 
                \(-0.00406351660833333472`\), 
                \(-0.000822823275968751666`\)}}}, {{{0, 0, 0}}, {{0, 0, 
                0}}, {{0, 0, 0, 0}, {0, 0, 0, 0}, {0, 0, 0, 0}, {0, 0, 0, 
                0}}}}, {
          \(-10.6326067285811509`
            \), {{{0.354999999999999982`, 0.294999999999999964`, 0.29`}}, {{
                1.`, 1.`, 1.`}}, {{0.`, 0.`, 0.0979999999999999893`, 
                0.0354395016190920175`}, {0.`, 0.0419999999999999928`, 
                0.00602071609104476834`, \(-0.0000712637269257902339`\)}, {
                0.0979999999999999893`, 0.00602071609104476834`, 
                \(-0.00160312550740448251`\), \(-0.00151517680712412472`\)}, {
                0.0354395016190920175`, \(-0.0000712637269257902339`\), 
                \(-0.00151517680712412472`\), 
                \(-0.0000456341681420150546`\)}}}, {{{0, 0, 0}}, {{0, 0, 
                0}}, {{0, 0, 0, 0.03466666666666665`}, {0, 0, 
                0.0181781450872359968`, 0.00831515151515151451`}, {0, 
                0.0000644386075427880555`, 0.0000364343822820084017`, 
                0.00403878787878788347`}, {0.000251987032599907845`, 
                0.0000266019798099041526`, 0.0000175773420802773605`, 
                0.0000408996640495107399`}}}}, {
          \(-18.7536535179473276`
            \), {{{0.354999999999999982`, 0.294999999999999964`, 0.29`}}, {{
                1.`, 1.`, 1.`}}, {{0.`, 0.`, 0.0979999999999999893`, 
                0.0335999999999999898`}, {0.`, 0.0419999999999999928`, 
                0.0167999999999999953`, 0.00319199999999999706`}, {
                0.0979999999999999893`, 0.0167999999999999953`, 
                0.00632799999999999762`, \(-0.00154560000000000119`\)}, {
                0.0335999999999999898`, 0.00319199999999999484`, 
                \(-0.00154559999999999941`\), 
                \(-0.00449903999999999726`\)}}}, {{{0, 0, 0}}, {{0, 0, 0}}, {{
                0, 0, 0, 0}, {0, 0, 0, 0}, {0, 0, 0, 0}, {0, 0, 0, 0}}}}}, {{
          \(-53.8828977192654257`
            \), {{{0.234988890634709823`, 0.284967145426400172`, 
                0.265030904700483205`}}, {{1.`, 1.`, 1.`}}, {{0.`, 0.`, 0.`, 
                0.`}, {0.`, 0.`, 0.`, 0.`}, {0.`, 0.`, 0.`, 0.`}, {0.`, 0.`, 
                0.`, 0.`}}}, {{{0.000264624862861316367`, 
                0.00048971948318013041`, 0.000359988820766779804`}}, {{0, 0, 
                0}}, {{0, 0, 0, 0}, {0, 0, 0, 0}, {0, 0, 0, 0}, {0, 0, 0, 
                0}}}}, {
          \(-7.48011256427088255`
            \), {{{0.218958098339375561`, 0.27764643583227393`, 
                0.254010502721675246`}}, {{1.`, 1.`, 1.`}}, {{0.`, 0.`, 
                0.0973767570836988127`, 0.0359966368787866031`}, {0.`, 
                0.0215711910488957414`, 0.0097284378738521795`, 
                0.00555883741468730541`}, {0.0973767570836988127`, 
                0.0097284378738521795`, 0.0024972273359328736`, 
                0.000846766839059191767`}, {0.0359966368787866031`, 
                0.00555883741468730541`, 0.000846766839059191767`, 
                \(-0.00140879086043405399`\)}}}, {{{0.000215538604705935021`, 
                0.000264624862861316367`, 0.000264624862861316367`}}, {{0, 0, 
                0}}, {{0, 0, 0.075786435786435744`, 0.03466666666666665`}, {
                0, 0.0000480043908269816466`, 0.0181781450872359968`, 
                0.00831515151515151451`}, {0.0000469667646469924449`, 
                0.0000112654547370058799`, 6.36962684515165022`*^-6, 
                0.00403878787878788347`}, {0.0000735774477948695082`, 
                0.0000105666872798303645`, 3.77277897751290769`*^-6, 
                4.74363388688623732`*^-6}}}}, {
          \(-7.62203052000859315`
            \), {{{0.234295736201835946`, 0.284186163022793802`, 
                0.280574400259152199`}}, {{1.`, 1.`, 1.`}}, {{0.`, 0.`, 
                0.100708333333333355`, 0.0390587499999999998`}, {0.`, 
                0.0244416666666666682`, 0.00892608333333333625`, 
                0.00466775625000000182`}, {0.100708333333333355`, 
                0.00892608333333333625`, 0.00100960624999999781`, 
                0.000129386658333332738`}, {0.0390587499999999998`, 
                0.00466775625000000182`, 0.000129386658333332738`, 
                \(-0.00133089422431944326`\)}}}, {{{
                0.0000948642880550728939`, 0.000129050924469342298`, 
                0.000129050924469342298`}}, {{0, 0, 0}}, {{0, 0, 0, 0}, {0, 
                0, 0, 0}, {0, 0, 0, 0}, {0, 0, 0, 0}}}}, {
          \(-8.30546317556633084`
            \), {{{0.235771164637339047`, 0.295391636341773633`, 
                0.266574401917997771`}}, {{1.`, 1.`, 1.`}}, {{0.`, 0.`, 
                0.0979999999999999893`, 0.0367975670971773727`}, {0.`, 
                0.0419999999999999928`, 0.0127167653227283716`, 
                0.00374520147438002215`}, {0.0979999999999999893`, 
                0.0127167653227283716`, 0.000223840765765265237`, 
                \(-0.0014483593752860413`\)}, {0.0367975670971773727`, 
                0.00374520147438002215`, \(-0.0014483593752860413`\), 
                \(-0.00217638931542780289`\)}}}, {{{0.00073817365291053596`, 
                0.000906283595626842775`, 0.00100419234972503357`}}, {{0, 0, 
                0}}, {{0, 0, 0, 0.03466666666666665`}, {0, 0, 
                0.0181781450872359968`, 0.00831515151515151451`}, {0, 
                0.0000714001191609840102`, 0.0000447318633614025884`, 
                0.00403878787878788347`}, {0.000167173345846681797`, 
                0.0000822232507978913851`, 0.0000293573703714298304`, 
                0.0000408996640495107399`}}}}, {
          \(-9.55031850973745122`
            \), {{{0.241417025983072086`, 0.300026778489573597`, 
                0.270525614233179112`}}, {{1.`, 1.`, 1.`}}, {{0.`, 0.`, 
                0.0979999999999999893`, 0.0335999999999999898`}, {0.`, 
                0.0419999999999999928`, 0.0167999999999999953`, 
                0.00319199999999999706`}, {0.0979999999999999893`, 
                0.0167999999999999953`, 0.00632799999999999762`, 
                \(-0.00154560000000000119`\)}, {0.0335999999999999898`, 
                0.00319199999999999484`, \(-0.00154559999999999941`\), 
                \(-0.00449903999999999726`\)}}}, {{{0.000215538604705935021`, 
                0.000238823938732338003`, 0.000441971833570067573`}}, {{0, 0, 
                0}}, {{0, 0, 0, 0}, {0, 0, 0, 0}, {0, 0, 0, 0}, {0, 0, 0, 
                0}}}}, {
          \(-53.8828966305383083`
            \), {{{0.234999999999999964`, 0.284999999999999964`, 
                0.265000000000000035`}}, {{1.`, 1.`, 1.`}}, {{0.`, 0.`, 0.`, 
                0.`}, {0.`, 0.`, 0.`, 0.`}, {0.`, 0.`, 0.`, 0.`}, {0.`, 0.`, 
                0.`, 0.`}}}, {{{0, 0, 0}}, {{0, 0, 0}}, {{0, 0, 0, 0}, {0, 0, 
                0, 0}, {0, 0, 0, 0}, {0, 0, 0, 0}}}}, {
          \(-7.68291894693459198`
            \), {{{0.234999999999999964`, 0.284999999999999964`, 
                0.265000000000000035`}}, {{1.`, 1.`, 1.`}}, {{0.`, 0.`, 
                0.106910754489525783`, 0.040592702574391728`}, {0.`, 
                0.0315968771453040409`, 0.0142876263074121183`, 
                0.00522656959966834033`}, {0.106910754489525783`, 
                0.0142876263074121183`, 0.00321551856020686743`, 
                \(-0.00109102626897184663`\)}, {0.040592702574391728`, 
                0.00522656959966834033`, \(-0.00109102626897184663`\), 
                \(-0.0033413845448382351`\)}}}, {{{0, 0, 0}}, {{0, 0, 0}}, {{
                0, 0, 0.075786435786435744`, 0.03466666666666665`}, {0, 
                0.0000352876384113073271`, 0.0181781450872359968`, 
                0.00831515151515151451`}, {0.0000576628658736411736`, 
                0.0000101670729001478021`, 4.22574058876089697`*^-6, 
                0.00403878787878788347`}, {0.0000599292910879699292`, 
                7.01015623248170793`*^-6, 1.83988990906611604`*^-6, 
                2.56327042295730134`*^-6}}}}, {
          \(-10000000000
            \), {{{0.234999999999999964`, 0.284999999999999964`, 
                0.265000000000000035`}}, {{1.`, 1.`, 1.`}}, {{0.`, 0.`, 
                0.100708333333333355`, 0.0390587499999999998`}, {0.`, 
                0.0244416666666666682`, 0.00892608333333333625`, 
                0.00466775625000000182`}, {0.100708333333333355`, 
                0.00892608333333333625`, 0.00100960624999999781`, 
                0.000129386658333332738`}, {0.0390587499999999998`, 
                0.00466775625000000182`, 0.000129386658333332738`, 
                \(-0.00133089422431944326`\)}}}, {{{0, 0, 0}}, {{0, 0, 0}}, {{
                0, 0, 0, 0}, {0, 0, 0, 0}, {0, 0, 0, 0}, {0, 0, 0, 0}}}}, {
          \(-8.27410868661456788`
            \), {{{0.234999999999999964`, 0.284999999999999964`, 
                0.265000000000000035`}}, {{1.`, 1.`, 1.`}}, {{0.`, 0.`, 
                0.0979999999999999893`, 0.0388704142203115665`}, {0.`, 
                0.0419999999999999928`, 0.0142241894669428736`, 
                0.00431683340716785401`}, {0.0979999999999999893`, 
                0.0142241894669428736`, 0.00157457818102510316`, 
                \(-0.00168205884418503437`\)}, {0.0388704142203115665`, 
                0.00431683340716785401`, \(-0.00168205884418503437`\), 
                \(-0.00298836938486459402`\)}}}, {{{0, 0, 0}}, {{0, 0, 0}}, {{
                0, 0, 0, 0.03466666666666665`}, {0, 0, 
                0.0181781450872359968`, 0.00831515151515151451`}, {0, 
                0.0000255959375775051567`, 0.0000106384397349094794`, 
                0.00403878787878788347`}, {0.000122887770860544276`, 
                0.0000400982221156726303`, 0.000014316854982773906`, 
                9.72703970888462876`*^-6}}}}, {
          \(-9.78469947857757915`
            \), {{{0.234999999999999964`, 0.284999999999999964`, 
                0.265000000000000035`}}, {{1.`, 1.`, 1.`}}, {{0.`, 0.`, 
                0.0979999999999999893`, 0.0335999999999999898`}, {0.`, 
                0.0419999999999999928`, 0.0167999999999999953`, 
                0.00319199999999999706`}, {0.0979999999999999893`, 
                0.0167999999999999953`, 0.00632799999999999762`, 
                \(-0.00154560000000000119`\)}, {0.0335999999999999898`, 
                0.00319199999999999484`, \(-0.00154559999999999941`\), 
                \(-0.00449903999999999726`\)}}}, {{{0, 0, 0}}, {{0, 0, 0}}, {{
                0, 0, 0, 0}, {0, 0, 0, 0}, {0, 0, 0, 0}, {0, 0, 0, 0}}}}}, {{
          \(-42.826940131857949`
            \), {{{0.299995370725750163`, 0.26501481042913042`, 
                0.250002680211212702`}}, {{1.`, 1.`, 1.`}}, {{0.`, 0.`, 0.`, 
                0.`}, {0.`, 0.`, 0.`, 0.`}, {0.`, 0.`, 0.`, 0.`}, {0.`, 0.`, 
                0.`, 0.`}}}, {{{0.000398879579796985961`, 
                0.0005426254661275685`, 0.000264624862861316367`}}, {{0, 0, 
                0}}, {{0, 0, 0, 0}, {0, 0, 0, 0}, {0, 0, 0, 0}, {0, 0, 0, 
                0}}}}, {
          \(-7.92184503341132995`
            \), {{{0.3120093758639225`, 0.27553879519664699`, 
                0.262337651990300502`}}, {{1.`, 1.`, 1.`}}, {{0.`, 0.`, 
                0.0747061317097439925`, 0.031249478108139943`}, {0.`, 
                0.0363182481163251091`, 0.0208800260142358951`, 
                0.0088262358316499867`}, {0.0747061317097439925`, 
                0.0208800260142358951`, 0.0109830253924848864`, 
                0.00177393275715189702`}, {0.031249478108139943`, 
                0.0088262358316499867`, 0.00177393275715189702`, 
                \(-0.0064498697829450613`\)}}}, {{{0.000264624862861316367`, 
                0.000238823938732338003`, 0.000175557540649263437`}}, {{0, 0, 
                0}}, {{0, 0, 0.075786435786435744`, 0.03466666666666665`}, {
                0, 0.000031847093666204862`, 0.0181781450872359968`, 
                0.00831515151515151451`}, {0.0000520407364509611536`, 
                0.0000101670729001478021`, 7.05775827717634474`*^-6, 
                0.00403878787878788347`}, {0.0000540861852068928605`, 
                0.0000159275879690631612`, 3.77277897751290769`*^-6, 
                2.84018883430171875`*^-6}}}}, {
          \(-8.02212685077398646`
            \), {{{0.29982428355517765`, 0.292540031381667908`, 
                0.264085244456117607`}}, {{1.`, 1.`, 1.`}}, {{0.`, 0.`, 
                0.0654083333333333438`, 0.0278762500000000024`}, {0.`, 
                0.0324249999999999882`, 0.0196412499999999994`, 
                0.0100894668749999971`}, {0.0654083333333333438`, 
                0.0196412499999999994`, 0.0110320095138888918`, 
                0.00347865147916666561`}, {0.0278762500000000024`, 
                0.0100894668749999971`, 0.00347865147916666561`, 
                \(-0.00508646938171875095`\)}}}, {{{0.000129050924469342298`, 
                0.0000856150199697032476`, 0.0000856150199697032476`}}, {{0, 
                0, 0}}, {{0, 0, 0, 0}, {0, 0, 0, 0}, {0, 0, 0, 0}, {0, 0, 0, 
                0}}}}, {
          \(-9.86016471402842853`
            \), {{{0.318146986543940846`, 0.292607339237299868`, 
                0.284664972093952961`}}, {{1.`, 1.`, 1.`}}, {{0.`, 0.`, 
                0.0979999999999999893`, 0.0372142698096089841`}, {0.`, 
                0.0419999999999999928`, 0.0222787315515053752`, 
                0.00667239754653332539`}, {0.0979999999999999893`, 
                0.0222787315515053752`, 0.0106520054861295609`, 
                \(-0.000471822413742568169`\)}, {0.0372142698096089841`, 
                0.00667239754653332539`, \(-0.000471822413742568169`\), 
                \(-0.00877679652172129109`\)}}}, {{{0.000116468459333581408`, 
                0.000293213144444671947`, 0.000293213144444671947`}}, {{0, 0, 
                0}}, {{0, 0, 0, 0.03466666666666665`}, {0, 0, 
                0.0181781450872359968`, 0.00831515151515151451`}, {0, 
                0.0000124824983235522246`, 7.82023077803473132`*^-6, 
                0.00403878787878788347`}, {0.0000735774477948695082`, 
                0.0000195548996328305193`, 9.49809410737482195`*^-6, 
                4.28112958291482925`*^-6}}}}, {
          \(-14.0508261358367008`
            \), {{{0.349833908477122346`, 0.316048777927409041`, 
                0.298390117213786254`}}, {{1.`, 1.`, 1.`}}, {{0.`, 0.`, 
                0.0979999999999999893`, 0.0335999999999999898`}, {0.`, 
                0.0419999999999999928`, 0.0167999999999999953`, 
                0.00319199999999999706`}, {0.0979999999999999893`, 
                0.0167999999999999953`, 0.00632799999999999762`, 
                \(-0.00154560000000000119`\)}, {0.0335999999999999898`, 
                0.00319199999999999484`, \(-0.00154559999999999941`\), 
                \(-0.00449903999999999726`\)}}}, {{{0.0005426254661275685`, 
                0.0005426254661275685`, 0.00048971948318013041`}}, {{0, 0, 
                0}}, {{0, 0, 0, 0}, {0, 0, 0, 0}, {0, 0, 0, 0}, {0, 0, 0, 
                0}}}}, {
          \(-42.8269400052079696`
            \), {{{0.3`, 0.265000000000000035`, 0.25`}}, {{1.`, 1.`, 1.`}}, {{
                0.`, 0.`, 0.`, 0.`}, {0.`, 0.`, 0.`, 0.`}, {0.`, 0.`, 0.`, 
                0.`}, {0.`, 0.`, 0.`, 0.`}}}, {{{0, 0, 0}}, {{0, 0, 0}}, {{0, 
                0, 0, 0}, {0, 0, 0, 0}, {0, 0, 0, 0}, {0, 0, 0, 0}}}}, {
          \(-8.10581383202986671`
            \), {{{0.3`, 0.265000000000000035`, 0.25`}}, {{1.`, 1.`, 1.`}}, {{
                0.`, 0.`, 0.0745089549642973203`, 0.0310287193127240534`}, {
                0.`, 0.0443520760493098897`, 0.0260810404914336269`, 
                0.0106240350488881674`}, {0.0745089549642973203`, 
                0.0260810404914336269`, 0.0130520828033374769`, 
                0.000719315873912271808`}, {0.0310287193127240534`, 
                0.0106240350488881674`, 0.000719315873912271808`, 
                \(-0.00985281739287625235`\)}}}, {{{0, 0, 0}}, {{0, 0, 0}}, {{
                0, 0, 0.075786435786435744`, 0.03466666666666665`}, {0, 
                0.000028742002033749884`, 0.0181781450872359968`, 
                0.00831515151515151451`}, {0.0000707948721985143514`, 
                0.0000112654547370058799`, 6.36962684515165022`*^-6, 
                0.00403878787878788347`}, {0.0000440535358896717532`, 
                8.60663283121732725`*^-6, 3.40493302720539903`*^-6, 
                2.31335155671896375`*^-6}}}}, {
          \(-10000000000
            \), {{{0.3`, 0.265000000000000035`, 0.25`}}, {{1.`, 1.`, 1.`}}, {{
                0.`, 0.`, 0.0654083333333333438`, 0.0278762500000000024`}, {
                0.`, 0.0324249999999999882`, 0.0196412499999999994`, 
                0.0100894668749999971`}, {0.0654083333333333438`, 
                0.0196412499999999994`, 0.0110320095138888918`, 
                0.00347865147916666561`}, {0.0278762500000000024`, 
                0.0100894668749999971`, 0.00347865147916666561`, 
                \(-0.00508646938171875095`\)}}}, {{{0, 0, 0}}, {{0, 0, 0}}, {{
                0, 0, 0, 0}, {0, 0, 0, 0}, {0, 0, 0, 0}, {0, 0, 0, 0}}}}, {
          \(-10.7788280069684683`
            \), {{{0.3`, 0.265000000000000035`, 0.25`}}, {{1.`, 1.`, 1.`}}, {{
                0.`, 0.`, 0.0979999999999999893`, 0.0422300082879318328`}, {
                0.`, 0.0419999999999999928`, 0.0246604607095691452`, 
                0.00701077476630509544`}, {0.0979999999999999893`, 
                0.0246604607095691452`, 0.0127093450997528822`, 
                \(-0.000802187359126903487`\)}, {0.0422300082879318328`, 
                0.00701077476630509544`, \(-0.000802187359126903487`\), 
                \(-0.00977004420837709908`\)}}}, {{{0, 0, 0}}, {{0, 0, 0}}, {{
                0, 0, 0, 0.03466666666666665`}, {0, 0, 
                0.0181781450872359968`, 0.00831515151515151451`}, {0, 
                9.17578329238339307`*^-6, 6.36962684515165022`*^-6, 
                0.00403878787878788347`}, {0.0000664036466348697285`, 
                0.0000195548996328305193`, 4.63198284545135052`*^-6, 
                3.14702363911547822`*^-6}}}}, {
          \(-18.299523730282317`
            \), {{{0.3`, 0.265000000000000035`, 0.25`}}, {{1.`, 1.`, 1.`}}, {{
                0.`, 0.`, 0.0979999999999999893`, 0.0335999999999999898`}, {
                0.`, 0.0419999999999999928`, 0.0167999999999999953`, 
                0.00319199999999999706`}, {0.0979999999999999893`, 
                0.0167999999999999953`, 0.00632799999999999762`, 
                \(-0.00154560000000000119`\)}, {0.0335999999999999898`, 
                0.00319199999999999484`, \(-0.00154559999999999941`\), 
                \(-0.00449903999999999726`\)}}}, {{{0, 0, 0}}, {{0, 0, 0}}, {{
                0, 0, 0, 0}, {0, 0, 0, 0}, {0, 0, 0, 0}, {0, 0, 0, 0}}}}}, {{
          \(-67.2303686689818924`
            \), {{{0.275068312225119981`, 0.325055043152877054`, 
                0.319987281170015958`}}, {{1.`, 1.`, 1.`}}, {{0.`, 0.`, 0.`, 
                0.`}, {0.`, 0.`, 0.`, 0.`}, {0.`, 0.`, 0.`, 0.`}, {0.`, 0.`, 
                0.`, 0.`}}}, {{{0.00073817365291053596`, 
                0.000441971833570067573`, 0.000601247053880962134`}}, {{0, 0, 
                0}}, {{0, 0, 0, 0}, {0, 0, 0, 0}, {0, 0, 0, 0}, {0, 0, 0, 
                0}}}}, {
          \(-6.27826569942533296`
            \), {{{0.27548434436667204`, 0.327201103953216421`, 
                0.327197773892912158`}}, {{1.`, 1.`, 1.`}}, {{0.`, 0.`, 
                0.11384410874369415`, 0.0487735708682295054`}, {0.`, 
                0.0378836644514499187`, 0.0128460808803493176`, 
                0.000745654334337235624`}, {0.11384410874369415`, 
                0.0128460808803493176`, 0.00397898234399391714`, 
                \(-0.000540140946829651191`\)}, {0.0487735708682295054`, 
                0.000745654334337235624`, \(-0.000540140946829651191`\), 
                \(-0.00197072552626186983`\)}}}, {{{0.000238823938732338003`, 
                0.000194523590747106318`, 0.000293213144444671947`}}, {{0, 0, 
                0}}, {{0, 0, 0.075786435786435744`, 0.03466666666666665`}, {
                0, 0.0000653039319834785469`, 0.0181781450872359968`, 
                0.00831515151515151451`}, {0.0000869175309563485498`, 
                0.0000208480511314878036`, 0.0000144722583265941384`, 
                0.00403878787878788347`}, {0.0000488127821492207925`, 
                0.0000176482969186295424`, 8.57202993190577622`*^-6, 
                7.15026800978844878`*^-6}}}}, {
          \(-6.61993444697372979`
            \), {{{0.304746944867893887`, 0.337242871921566367`, 
                0.337182317986228596`}}, {{1.`, 1.`, 1.`}}, {{0.`, 0.`, 
                0.116966666666666641`, 0.0563475000000000036`}, {0.`, 
                0.038783333333333342`, 0.010934166666666667`, 
                \(-0.000164472708333330057`\)}, {0.116966666666666641`, 
                0.010934166666666667`, 0.00165428104166667067`, 
                \(-0.00174981204166666497`\)}, {0.0563475000000000036`, 
                \(-0.000164472708333331807`\), \(-0.00174981204166666497`\), 
                \(-0.00218246176144097203`\)}}}, {{{0.000175557540649263437`, 
                0.000158440680435960201`, 0.000293213144444671947`}}, {{0, 0, 
                0}}, {{0, 0, 0, 0}, {0, 0, 0, 0}, {0, 0, 0, 0}, {0, 0, 0, 
                0}}}}, {
          \(-6.86029811339511752`
            \), {{{0.260124522589183326`, 0.307044433633488145`, 
                0.307160588873797646`}}, {{1.`, 1.`, 1.`}}, {{0.`, 0.`, 
                0.0979999999999999893`, 0.052011257993028126`}, {0.`, 
                0.0419999999999999928`, 0.0125279993872201123`, 
                0.00198906727576834754`}, {0.0979999999999999893`, 
                0.0125279993872201123`, 0.00447239008240782354`, 
                0.00014621082948011324`}, {0.052011257993028126`, 
                0.00198906727576834754`, 0.00014621082948011324`, 
                \(-0.0021471941160582757`\)}}}, {{{0.0005426254661275685`, 
                0.000441971833570067573`, 0.000601247053880962134`}}, {{0, 0, 
                0}}, {{0, 0, 0, 0.03466666666666665`}, {0, 0, 
                0.0181781450872359968`, 0.00831515151515151451`}, {0, 
                0.0000255959375775051567`, 0.0000328820300095125706`, 
                0.00403878787878788347`}, {0.000122887770860544276`, 
                0.0000266019798099041526`, 0.0000215803648901127065`, 
                0.0000244881396688820185`}}}}, {
          \(-10.261211950912128`
            \), {{{0.275148864378948809`, 0.334284075436463901`, 
                0.325730536564714912`}}, {{1.`, 1.`, 1.`}}, {{0.`, 0.`, 
                0.0979999999999999893`, 0.0335999999999999898`}, {0.`, 
                0.0419999999999999928`, 0.0167999999999999953`, 
                0.00319199999999999706`}, {0.0979999999999999893`, 
                0.0167999999999999953`, 0.00632799999999999762`, 
                \(-0.00154560000000000119`\)}, {0.0335999999999999898`, 
                0.00319199999999999484`, \(-0.00154559999999999941`\), 
                \(-0.00449903999999999726`\)}}}, {{{0.000398879579796985961`, 
                0.000398879579796985961`, 0.000601247053880962134`}}, {{0, 0, 
                0}}, {{0, 0, 0, 0}, {0, 0, 0, 0}, {0, 0, 0, 0}, {0, 0, 0, 
                0}}}}, {
          \(-67.23036487328363`
            \), {{{0.275`, 0.325`, 0.320000000000000017`}}, {{1.`, 1.`, 
                1.`}}, {{0.`, 0.`, 0.`, 0.`}, {0.`, 0.`, 0.`, 0.`}, {0.`, 
                0.`, 0.`, 0.`}, {0.`, 0.`, 0.`, 0.`}}}, {{{0, 0, 0}}, {{0, 0, 
                0}}, {{0, 0, 0, 0}, {0, 0, 0, 0}, {0, 0, 0, 0}, {0, 0, 0, 
                0}}}}, {
          \(-5.89299619144810549`
            \), {{{0.275`, 0.325`, 0.320000000000000017`}}, {{1.`, 1.`, 
                1.`}}, {{0.`, 0.`, 0.117617100010842734`, 
                0.0537735596248942115`}, {0.`, 0.0365140527300122252`, 
                0.012457219558360002`, 0.00155666735267050126`}, {
                0.117617100010842734`, 0.012457219558360002`, 
                0.00314344892680089582`, \(-0.000977727897179864768`\)}, {
                0.0537735596248942115`, 0.00155666735267050126`, 
                \(-0.000977727897179864768`\), 
                \(-0.00267423043281663508`\)}}}, {{{0, 0, 0}}, {{0, 0, 0}}, {{
                0, 0, 0.075786435786435744`, 0.03466666666666665`}, {0, 
                0.0000480043908269816466`, 0.0181781450872359968`, 
                0.00831515151515151451`}, {0.000118240361599484277`, 
                0.0000153252333220920355`, 0.0000241713136072805756`, 
                0.00403878787878788347`}, {0.0000599292910879699292`, 
                0.0000159275879690631612`, 8.57202993190577622`*^-6, 
                8.77865333726837704`*^-6}}}}, {
          \(-10000000000
            \), {{{0.275`, 0.325`, 0.320000000000000017`}}, {{1.`, 1.`, 
                1.`}}, {{0.`, 0.`, 0.116966666666666641`, 
                0.0563475000000000036`}, {0.`, 0.038783333333333342`, 
                0.010934166666666667`, \(-0.000164472708333330057`\)}, {
                0.116966666666666641`, 0.010934166666666667`, 
                0.00165428104166667067`, \(-0.00174981204166666497`\)}, {
                0.0563475000000000036`, \(-0.000164472708333331807`\), 
                \(-0.00174981204166666497`\), 
                \(-0.00218246176144097203`\)}}}, {{{0, 0, 0}}, {{0, 0, 0}}, {{
                0, 0, 0, 0}, {0, 0, 0, 0}, {0, 0, 0, 0}, {0, 0, 0, 0}}}}, {
          \(-7.24690569954157126`
            \), {{{0.275`, 0.325`, 0.320000000000000017`}}, {{1.`, 1.`, 
                1.`}}, {{0.`, 0.`, 0.0979999999999999893`, 
                0.0498945859120418511`}, {0.`, 0.0419999999999999928`, 
                0.0107766146480376412`, \(-0.000150246433129437795`\)}, {
                0.0979999999999999893`, 0.0107766146480376412`, 
                0.00469579492945913745`, 0.000449414272608574272`}, {
                0.0498945859120418511`, \(-0.000150246433129437795`\), 
                0.000449414272608574272`, \(-0.0011503148521859714`\)}}}, {{{
                0, 0, 0}}, {{0, 0, 0}}, {{0, 0, 0, 0.03466666666666665`}, {0, 
                0, 0.0181781450872359968`, 0.00831515151515151451`}, {0, 
                0.000047368297847870453`, 0.0000241713136072805756`, 
                0.00403878787878788347`}, {0.000150873944626630329`, 
                0.0000444301630090555565`, 0.0000175773420802773605`, 
                0.0000221005460511660212`}}}}, {
          \(-10.3164676429810819`
            \), {{{0.275`, 0.325`, 0.320000000000000017`}}, {{1.`, 1.`, 
                1.`}}, {{0.`, 0.`, 0.0979999999999999893`, 
                0.0335999999999999898`}, {0.`, 0.0419999999999999928`, 
                0.0167999999999999953`, 0.00319199999999999706`}, {
                0.0979999999999999893`, 0.0167999999999999953`, 
                0.00632799999999999762`, \(-0.00154560000000000119`\)}, {
                0.0335999999999999898`, 0.00319199999999999484`, 
                \(-0.00154559999999999941`\), 
                \(-0.00449903999999999726`\)}}}, {{{0, 0, 0}}, {{0, 0, 0}}, {{
                0, 0, 0, 0}, {0, 0, 0, 0}, {0, 0, 0, 0}, {0, 0, 0, 0}}}}}}
      \)], "Output",
  CellLabel->"Out[99]="]
}, Closed]],

Cell[TextData[{
  "The first matrix is the set of true moments used to generate the replicate \
samples.  For each replicate, the log likelihoods are printed for each \
combination of MethodP, MethodC.  Where no sensible starting point could be \
found, a warning message is printed (edited out in the above), and the \
log(likelihood) is set to ",
  Cell[BoxData[
      \(TraditionalForm\`\(-10\^10\)\)]],
  ".  In all but one case, this warning arose because all parameters were \
fixed at inadmissible values.  In the other case (sample 6, \
MethodP\[Rule]Fit, MethodC\[Rule]TrueC2) the moments could not be adjusted to \
give a valid starting point.  (It might have been possible to jointly adjust \
allele frequencies and moments, but DoReplicates[] does not attempt this)."
}], "Text"],

Cell[TextData[{
  "These are the frequencies of the ",
  Cell[BoxData[
      \(TraditionalForm\`3\^4\)]],
  "genotypes sampled in each of the 10 replicates.  There is strong linkage \
disequilibrium, reflected in the fact that most genotypes are missing:"
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(ReducedData[\(r[0.2, 0.3]\)[#], 3]&\)/@Range[10] // TableForm\)], 
  "Input",
  CellLabel->"In[100]:="],

Cell[BoxData[
    TagBox[GridBox[{
          {"33", "7", "0", "6", "5", "0", "0", "1", "0", "3", "9", "1", "6", 
            "7", "1", "0", "1", "1", "0", "0", "0", "4", "0", "4", "0", "1", 
            "10"},
          {"23", "8", "0", "7", "7", "1", "0", "1", "1", "12", "9", "1", "4", 
            "6", "0", "2", "2", "1", "1", "1", "0", "1", "2", "2", "0", "0", 
            "8"},
          {"37", "2", "1", "4", "7", "1", "1", "0", "1", "5", "4", "2", "5", 
            "11", "2", "0", "6", "0", "0", "1", "0", "1", "2", "1", "1", "3", 
            "2"},
          {"35", "11", "0", "5", "4", "1", "0", "2", "0", "12", "4", "0", 
            "4", "9", "2", "0", "0", "0", "0", "0", "1", "1", "1", "1", "0", 
            "1", "6"},
          {"30", "6", "1", "5", "5", "1", "0", "1", "1", "11", "2", "1", "4", 
            "14", "3", "1", "3", "1", "0", "0", "0", "2", "1", "0", "0", "0", 
            "7"},
          {"44", "5", "1", "3", "2", "1", "1", "0", "0", "4", "1", "0", "7", 
            "8", "1", "2", "4", "1", "2", "1", "0", "0", "1", "1", "0", "1", 
            "9"},
          {"35", "3", "2", "4", "3", "0", "1", "1", "0", "9", "4", "1", "5", 
            "5", "3", "0", "2", "2", "1", "0", "0", "3", "6", "2", "1", "0", 
            "7"},
          {"38", "5", "0", "11", "5", "0", "1", "1", "0", "3", "6", "2", "3", 
            "11", "1", "0", "4", "1", "0", "0", "0", "0", "3", "1", "0", "0", 
            "4"},
          {"27", "9", "1", "10", "6", "1", "0", "0", "0", "12", "5", "0", 
            "3", "9", "0", "3", "0", "0", "1", "2", "0", "2", "2", "0", "0", 
            "1", "6"},
          {"33", "7", "1", "8", "2", "1", "1", "0", "0", "6", "4", "1", "2", 
            "14", "3", "1", "6", "2", "0", "0", "0", "0", "1", "0", "0", "0", 
            "7"}
          },
        RowSpacings->1,
        ColumnSpacings->3,
        RowAlignments->Baseline,
        ColumnAlignments->{Left}],
      (TableForm[ #]&)]], "Output",
  CellLabel->"Out[100]//TableForm="]
}, Closed]],

Cell["\<\
DoReplicates[] returns a list of estimates for each replicate, made \
using various methods.  The method that was used can be checked by inspection \
of these results.  \
\>", "Text"],

Cell["These are the results for the eighth replicate sample:", "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[
    \(results\[LeftDoubleBracket]6\[RightDoubleBracket]\)], "Input",
  CellLabel->"In[101]:="],

Cell[BoxData[
    \({{\(-86.7810442537973969`
          \), {{{0.289897118936887245`, 0.299997422199866914`, 
              0.255000317996531444`}}, {{1.`, 1.`, 1.`}}, {{0.`, 0.`, 0.`, 
              0.`}, {0.`, 0.`, 0.`, 0.`}, {0.`, 0.`, 0.`, 0.`}, {0.`, 0.`, 
              0.`, 0.`}}}, {{{0.000601247053880962134`, 
              0.000324889910742018805`, 0.000601247053880962134`}}, {{0, 0, 
              0}}, {{0, 0, 0, 0}, {0, 0, 0, 0}, {0, 0, 0, 0}, {0, 0, 0, 
              0}}}}, {\(-8.07416670967933214`
          \), {{{0.277690387921320125`, 0.27831845381099054`, 
              0.270944168050125`}}, {{1.`, 1.`, 1.`}}, {{0.`, 0.`, 
              0.100382311784863698`, 0.0525258345730716591`}, {0.`, 
              0.0701593936144160412`, 0.0228169382562650246`, 
              0.00314077390352482099`}, {0.100382311784863698`, 
              0.0228169382562650246`, 0.00677700302773158469`, 
              \(-0.00588032382147379273`\)}, {0.0525258345730716591`, 
              0.00314077390352482099`, \(-0.00588032382147379273`\), 
              \(-0.0106703196684074796`\)}}}, {{{0.000666201721751758668`, 
              0.000666201721751758668`, 0.000817920945053225523`}}, {{0, 0, 
              0}}, {{0, 0, 0.075786435786435744`, 0.03466666666666665`}, {0, 
              0.0000390998763560192053`, 0.0181781450872359968`, 
              0.00831515151515151451`}, {0.000218817718590099419`, 
              0.0000385817746489520239`, 0.000013061213139751211`, 
              0.00403878787878788347`}, {0.000100092857414481173`, 
              0.0000400982221156726303`, 0.0000129209616219534462`, 
              0.0000119422530016002092`}}}}, {
        \(-7.82808059153649082`
          \), {{{0.283442323524842887`, 0.283453149753464437`, 
              0.276474171628027631`}}, {{1.`, 1.`, 1.`}}, {{0.`, 0.`, 
              0.104741666666666666`, 0.0563147499999999912`}, {0.`, 
              0.0769583333333333108`, 0.023055083333333326`, 
              0.000863470208333331257`}, {0.104741666666666666`, 
              0.023055083333333326`, 0.0040254106250000099`, 
              \(-0.00796676306249999122`\)}, {0.0563147499999999912`, 
              0.000863470208333327882`, \(-0.00796676306249999122`\), 
              \(-0.0101733340343576372`\)}}}, {{{0.000194523590747106318`, 
              0.000293213144444671947`, 0.0000856150199697032476`}}, {{0, 0, 
              0}}, {{0, 0, 0, 0}, {0, 0, 0, 0}, {0, 0, 0, 0}, {0, 0, 0, 
              0}}}}, {\(-10000000000
          \), {{{0.29`, 0.3`, 0.254999999999999982`}}, {{1.`, 1.`, 1.`}}, {{
              0.`, 0.`, 0.0979999999999999893`, 0.0563147499999999912`}, {
              0.`, 0.0419999999999999928`, 0.023055083333333326`, 
              0.0126977024999999921`}, {0.0979999999999999893`, 
              0.023055083333333326`, 0.0137093975000000023`, 
              \(-0.00228501499999999424`\)}, {0.0563147499999999912`, 
              0.0126977024999999876`, \(-0.00228501499999999779`\), 
              \(-0.0132324118751249875`\)}}}, {{{1.12611244643874397`*^-10, 
              1.12611244643874397`*^-10, 1.12611244643874397`*^-10}}, {{0, 0, 
              0}}, {{0, 0, 0, 0.03466666666666665`}, {0, 0, 
              0.0181781450872359968`, 0.00831515151515151451`}, {0, 
              2.23352943830675076`*^-11, 8.37810476717042007`*^-12, 
              0.00403878787878788347`}, {4.25945662532615632`*^-11, 
              1.02167386187892939`*^-11, 4.96241590055480141`*^-12, 
              3.37152374420047262`*^-12}}}}, {
        \(-12.4753100591340171`
          \), {{{0.263695172674783062`, 0.268568621033923804`, 
              0.249480301050056407`}}, {{1.`, 1.`, 1.`}}, {{0.`, 0.`, 
              0.0979999999999999893`, 0.0335999999999999898`}, {0.`, 
              0.0419999999999999928`, 0.0167999999999999953`, 
              0.00319199999999999706`}, {0.0979999999999999893`, 
              0.0167999999999999953`, 0.00632799999999999762`, 
              \(-0.00154560000000000119`\)}, {0.0335999999999999898`, 
              0.00319199999999999484`, \(-0.00154559999999999941`\), 
              \(-0.00449903999999999726`\)}}}, {{{0.000293213144444671947`, 
              0.000359988820766779804`, 0.000264624862861316367`}}, {{0, 0, 
              0}}, {{0, 0, 0, 0}, {0, 0, 0, 0}, {0, 0, 0, 0}, {0, 0, 0, 
              0}}}}, {\(-86.781039109251985`
          \), {{{0.29`, 0.3`, 0.254999999999999982`}}, {{1.`, 1.`, 1.`}}, {{
              0.`, 0.`, 0.`, 0.`}, {0.`, 0.`, 0.`, 0.`}, {0.`, 0.`, 0.`, 
              0.`}, {0.`, 0.`, 0.`, 0.`}}}, {{{0, 0, 0}}, {{0, 0, 0}}, {{0, 
              0, 0, 0}, {0, 0, 0, 0}, {0, 0, 0, 0}, {0, 0, 0, 0}}}}, {
        \(-9.31090384218134659`
          \), {{{0.29`, 0.3`, 0.254999999999999982`}}, {{1.`, 1.`, 1.`}}, {{
              0.`, 0.`, 0.100293266436351746`, 0.052344156070130543`}, {0.`, 
              0.0633710150049574139`, 0.0169663479628693325`, 
              0.000240086500448639439`}, {0.100293266436351746`, 
              0.0169663479628693325`, 0.00278460309004520079`, 
              \(-0.00466199555071689442`\)}, {0.052344156070130543`, 
              0.000240086500448639439`, \(-0.00466199555071689442`\), 
              \(-0.00566973341121847962`\)}}}, {{{0, 0, 0}}, {{0, 0, 0}}, {{
              0, 0, 0.075786435786435744`, 0.03466666666666665`}, {0, 
              0.0000433239627213509237`, 0.0181781450872359968`, 
              0.00831515151515151451`}, {0.000160851130460645368`, 
              0.0000101670729001478021`, 6.36962684515165022`*^-6, 
              0.00403878787878788347`}, {0.0000815262579444537394`, 
              0.0000326602525271035837`, 9.49809410737482195`*^-6, 
              5.25610402979084589`*^-6}}}}, {
        \(-10000000000
          \), {{{0.29`, 0.3`, 0.254999999999999982`}}, {{1.`, 1.`, 1.`}}, {{
              0.`, 0.`, 0.104741666666666666`, 0.0563147499999999912`}, {0.`, 
              0.0769583333333333108`, 0.023055083333333326`, 
              0.000863470208333331257`}, {0.104741666666666666`, 
              0.023055083333333326`, 0.0040254106250000099`, 
              \(-0.00796676306249999122`\)}, {0.0563147499999999912`, 
              0.000863470208333327882`, \(-0.00796676306249999122`\), 
              \(-0.0101733340343576372`\)}}}, {{{0, 0, 0}}, {{0, 0, 0}}, {{0, 
              0, 0, 0}, {0, 0, 0, 0}, {0, 0, 0, 0}, {0, 0, 0, 0}}}}, {
        \(-10000000000
          \), {{{0.29`, 0.3`, 0.254999999999999982`}}, {{1.`, 1.`, 1.`}}, {{
              0.`, 0.`, 0.0979999999999999893`, 0.0563147499999999912`}, {
              0.`, 0.0419999999999999928`, 0.023055083333333326`, 
              0.0126977024999999921`}, {0.0979999999999999893`, 
              0.023055083333333326`, 0.0137093975000000023`, 
              \(-0.00228501499999999424`\)}, {0.0563147499999999912`, 
              0.0126977024999999876`, \(-0.00228501499999999779`\), 
              \(-0.0132324118751249875`\)}}}, {{{0, 0, 0}}, {{0, 0, 0}}, {{0, 
              0, 0, 0.03466666666666665`}, {0, 0, 0.0181781450872359968`, 
              0.00831515151515151451`}, {0, 2.23352943830675076`*^-11, 
              8.37810476717042007`*^-12, 0.00403878787878788347`}, {
              4.25945662532615632`*^-11, 1.02167386187892939`*^-11, 
              4.96241590055480141`*^-12, 3.37152374420047262`*^-12}}}}, {
        \(-13.2743618729947465`
          \), {{{0.29`, 0.3`, 0.254999999999999982`}}, {{1.`, 1.`, 1.`}}, {{
              0.`, 0.`, 0.0979999999999999893`, 0.0335999999999999898`}, {
              0.`, 0.0419999999999999928`, 0.0167999999999999953`, 
              0.00319199999999999706`}, {0.0979999999999999893`, 
              0.0167999999999999953`, 0.00632799999999999762`, 
              \(-0.00154560000000000119`\)}, {0.0335999999999999898`, 
              0.00319199999999999484`, \(-0.00154559999999999941`\), 
              \(-0.00449903999999999726`\)}}}, {{{0, 0, 0}}, {{0, 0, 0}}, {{
              0, 0, 0, 0}, {0, 0, 0, 0}, {0, 0, 0, 0}, {0, 0, 0, 0}}}}}\)], 
  "Output",
  CellLabel->"Out[101]="]
}, Closed]],

Cell["\<\
The following elements give the log(likelihood); the estimated \
allele frequencies; and the estimated cumulants, together with their step \
sizes.  These are in the form that is supplied to FindMLE[].  The results \
differ according to which elements were allowed to vary.\
\>", "Text"],

Cell["\<\
The first element fits the allele frequencies by MLE, and assumes \
HWLE (i.e., all cumulants zero):\
\>", "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[
    \(j = 1; 
    \n{results\[LeftDoubleBracket]6, j, 1\[RightDoubleBracket], 
      results\[LeftDoubleBracket]6, j, 2, 1\[RightDoubleBracket] // 
        MatrixForm, 
      results\[LeftDoubleBracket]6, j, 2, 3\[RightDoubleBracket] // 
        MatrixForm}\)], "Input",
  CellLabel->"In[102]:="],

Cell[BoxData[
    RowBox[{"{", 
      RowBox[{\(-86.7810442537973969`\), ",", 
        TagBox[
          RowBox[{"(", GridBox[{
                {"0.289897118936887245`", "0.299997422199866914`", 
                  "0.255000317996531444`"}
                }], ")"}],
          (MatrixForm[ #]&)], ",", 
        TagBox[
          RowBox[{"(", GridBox[{
                {"0.`", "0.`", "0.`", "0.`"},
                {"0.`", "0.`", "0.`", "0.`"},
                {"0.`", "0.`", "0.`", "0.`"},
                {"0.`", "0.`", "0.`", "0.`"}
                }], ")"}],
          (MatrixForm[ #]&)]}], "}"}]], "Output",
  CellLabel->"Out[102]="]
}, Open  ]],

Cell["\<\
This fitting procedure is reflected in the step sizes.  Allele \
frequencies can vary, while moments cannot: \
\>", "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[
    \(j = 1; 
    \n{results\[LeftDoubleBracket]6, j, 3, 1\[RightDoubleBracket] // 
        MatrixForm, 
      results\[LeftDoubleBracket]6, j, 3, 3\[RightDoubleBracket] // 
        MatrixForm}\)], "Input",
  CellLabel->"In[103]:="],

Cell[BoxData[
    RowBox[{"{", 
      RowBox[{
        TagBox[
          RowBox[{"(", GridBox[{
                {"0.000601247053880962134`", "0.000324889910742018805`", 
                  "0.000601247053880962134`"}
                }], ")"}],
          (MatrixForm[ #]&)], ",", 
        TagBox[
          RowBox[{"(", GridBox[{
                {"0", "0", "0", "0"},
                {"0", "0", "0", "0"},
                {"0", "0", "0", "0"},
                {"0", "0", "0", "0"}
                }], ")"}],
          (MatrixForm[ #]&)]}], "}"}]], "Output",
  CellLabel->"Out[103]="]
}, Open  ]],

Cell["\<\
The next element fits allele frequencies by MLE, and fits all \
cumulants:\
\>", "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[
    \(j = 2; 
    \n{results\[LeftDoubleBracket]6, j, 1\[RightDoubleBracket], 
      results\[LeftDoubleBracket]6, j, 2, 1\[RightDoubleBracket] // 
        MatrixForm, 
      results\[LeftDoubleBracket]6, j, 2, 3\[RightDoubleBracket] // 
        MatrixForm}\)], "Input",
  CellLabel->"In[104]:="],

Cell[BoxData[
    RowBox[{"{", 
      RowBox[{\(-8.07416670967933214`\), ",", 
        TagBox[
          RowBox[{"(", GridBox[{
                {"0.277690387921320125`", "0.27831845381099054`", 
                  "0.270944168050125`"}
                }], ")"}],
          (MatrixForm[ #]&)], ",", 
        TagBox[
          RowBox[{"(", GridBox[{
                {"0.`", "0.`", "0.100382311784863698`", 
                  "0.0525258345730716591`"},
                {"0.`", "0.0701593936144160412`", "0.0228169382562650246`", 
                  "0.00314077390352482099`"},
                {"0.100382311784863698`", "0.0228169382562650246`", 
                  "0.00677700302773158469`", \(-0.00588032382147379273`\)},
                {"0.0525258345730716591`", "0.00314077390352482099`", 
                  \(-0.00588032382147379273`\), \(-0.0106703196684074796`\)}
                }], ")"}],
          (MatrixForm[ #]&)]}], "}"}]], "Output",
  CellLabel->"Out[104]="]
}, Open  ]],

Cell["\<\
The next element fits allele frequencies by MLE, and fixes the \
cumulants at their values estimated from the sample:\
\>", "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[
    \(j = 3; 
    \n{results\[LeftDoubleBracket]6, j, 1\[RightDoubleBracket], 
      results\[LeftDoubleBracket]6, j, 2, 1\[RightDoubleBracket] // 
        MatrixForm, 
      results\[LeftDoubleBracket]6, j, 2, 3\[RightDoubleBracket] // 
        MatrixForm}\)], "Input",
  CellLabel->"In[105]:="],

Cell[BoxData[
    RowBox[{"{", 
      RowBox[{\(-7.82808059153649082`\), ",", 
        TagBox[
          RowBox[{"(", GridBox[{
                {"0.283442323524842887`", "0.283453149753464437`", 
                  "0.276474171628027631`"}
                }], ")"}],
          (MatrixForm[ #]&)], ",", 
        TagBox[
          RowBox[{"(", GridBox[{
                {"0.`", "0.`", "0.104741666666666666`", 
                  "0.0563147499999999912`"},
                {"0.`", "0.0769583333333333108`", "0.023055083333333326`", 
                  "0.000863470208333331257`"},
                {"0.104741666666666666`", "0.023055083333333326`", 
                  "0.0040254106250000099`", \(-0.00796676306249999122`\)},
                {"0.0563147499999999912`", "0.000863470208333327882`", 
                  \(-0.00796676306249999122`\), \(-0.0101733340343576372`\)}
                }], ")"}],
          (MatrixForm[ #]&)]}], "}"}]], "Output",
  CellLabel->"Out[105]="]
}, Open  ]],

Cell["\<\
The next element fits allele frequencies by MLE, and fixes the \
first two cumulants at their true values; higher order moments are free to \
vary:\
\>", "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[
    \(j = 4; 
    \n{results\[LeftDoubleBracket]6, j, 1\[RightDoubleBracket], 
      results\[LeftDoubleBracket]6, j, 2, 1\[RightDoubleBracket] // 
        MatrixForm, 
      results\[LeftDoubleBracket]6, j, 2, 3\[RightDoubleBracket] // 
        MatrixForm}\)], "Input",
  CellLabel->"In[106]:="],

Cell[BoxData[
    RowBox[{"{", 
      RowBox[{\(-10000000000\), ",", 
        TagBox[
          RowBox[{"(", GridBox[{
                {"0.29`", "0.3`", "0.254999999999999982`"}
                }], ")"}],
          (MatrixForm[ #]&)], ",", 
        TagBox[
          RowBox[{"(", GridBox[{
                {"0.`", "0.`", "0.0979999999999999893`", 
                  "0.0563147499999999912`"},
                {"0.`", "0.0419999999999999928`", "0.023055083333333326`", 
                  "0.0126977024999999921`"},
                {"0.0979999999999999893`", "0.023055083333333326`", 
                  "0.0137093975000000023`", \(-0.00228501499999999424`\)},
                {"0.0563147499999999912`", "0.0126977024999999876`", 
                  \(-0.00228501499999999779`\), \(-0.0132324118751249875`\)}
                }], ")"}],
          (MatrixForm[ #]&)]}], "}"}]], "Output",
  CellLabel->"Out[106]="]
}, Open  ]],

Cell["This gives an inadmissible set of genotype frequencies:", "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(pl = \(\(AlleleFrequencyTable[\(r[0.2, 0.3]\)[6], 3] // N\) // 
            Transpose\) // Last;\)\), "\n", 
    \(\(rd = ReducedData[\(r[0.2, 0.3]\)[6], 3];\)\), "\n", 
    \(DiploidGenotypeFrequencyList[
        pl, \(Moment[3]\)[
          results\[LeftDoubleBracket]6, 4, 2, 3\[RightDoubleBracket]]] // 
      MatrixForm\)}], "Input",
  CellLabel->"In[110]:="],

Cell[BoxData[
    TagBox[
      RowBox[{"(", GridBox[{
            {"0.344012768054729134`", "0.0165130291661041539`", 
              "0.0351072305598541589`", "0.0175714476359791627`", 
              "0.0307913867181874811`", "0.0166358889776458269`", 
              "0.0216729988338958268`", "0.0428355000536042052`"},
            {"0.0165130291661041583`", "0.0127084361130625045`", 
              "0.0147519059693125065`", "0.00143707000152083068`", 
              "0.0142733506443125079`", "0.00121702782652083074`", 
              "0.00231724672027082956`", "0.00664168355889582251`"},
            {"0.0351072305598541634`", "0.0147519059693125065`", 
              "0.0179012283255625126`", "0.00222457639527082884`", 
              "0.0171657455005625081`", "0.00194196172027082809`", 
              "0.00337407811402082868`", "0.00934302341514584533`"},
            {"0.0175714476359791511`", "0.00143707000152083086`", 
              "0.0022245763952708315`", \(-0.00373295194943748942`\), 
              "0.00204495838693749698`", \(-0.00368523644110415649`\), 
              \(-0.00387918158485415673`\), "0.00120956755568748874`"},
            {"0.0307913867181874811`", "0.0142733506443125035`", 
              "0.0171657455005625081`", "0.00204495838693749565`", 
              "0.0164899651755625047`", "0.00177714121193749452`", 
              "0.00313093510568749433`", "0.00868626725681249745`"},
            {"0.0166358889776458163`", "0.00121702782652083074`", 
              "0.00194196172027083058`", \(-0.00368523644110415604`\), 
              "0.0017771412119374963`", \(-0.00362681843277082283`\), 
              \(-0.00387294107652082253`\), "0.000253226214020829143`"},
            {"0.0216729988338958134`", "0.00231724672027082911`", 
              "0.00337407811402082913`", \(-0.00387918158485415496`\), 
              "0.00313093510568749389`", \(-0.00387294107652082217`\), 
              \(-0.00386371122027082201`\), "0.00481082510777082195`"},
            {"0.0428355000536041963`", "0.00664168355889582784`", 
              "0.00934302341514585066`", "0.00120956755568748386`", 
              "0.00868626725681249922`", "0.000253226214020824125`", 
              "0.00481082510777081751`", "0.0875296568380624862`"}
            }], ")"}],
      (MatrixForm[ #]&)]], "Output",
  CellLabel->"Out[110]//MatrixForm="]
}, Open  ]],

Cell["Reducing the remaining cumulants to zero does not help:", "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"DiploidGenotypeFrequencyList", "[", 
        RowBox[{"pl", ",", 
          RowBox[{"(", GridBox[{
                {"1", "0", "0.098", "0"},
                {"0", "0.042", "0", "0"},
                {"0.098", "0", "0", "0"},
                {"0", "0", "0", "0"}
                }], ")"}]}], "]"}], "//", "MatrixForm"}]], "Input",
  CellLabel->"In[115]:="],

Cell[BoxData[
    TagBox[
      RowBox[{"(", GridBox[{
            {"0.394061964029999955`", "0.0228471299699999974`", 
              "0.0443492977200000026`", "0.0165675582799999947`", 
              "0.0393675289699999773`", "0.0157347770299999956`", 
              "0.0203980842799999928`", "0.028128659719999991`"},
            {"0.0228471299699999974`", \(-0.0118350239700000026`\), 
              \(-0.0116620417200000003`\), "0.00449398571999999685`", 
              \(-0.0117052229700000021`\), "0.00440171696999999806`", 
              "0.00483825971999999815`", "0.0121661962799999989`"},
            {"0.0443492977200000115`", \(-0.0116620417200000003`\), 
              \(-0.0103832069699999962`\), "0.00611450096999999992`", 
              \(-0.0106833157199999995`\), "0.00595965972000000121`", 
              "0.0067280999699999997`", "0.015072006029999998`"},
            {"0.0165675582800000036`", "0.00449398571999999685`", 
              "0.00611450096999999992`", "0.00883540503000000043`", 
              "0.00573005971999999719`", "0.00852479628000000033`", 
              "0.0100320060300000002`", "0.00920668797000000083`"},
            {"0.0393675289699999897`", \(-0.0117052229700000021`\), 
              \(-0.0106833157199999995`\), "0.00573005971999999896`", 
              \(-0.0109237219700000022`\), "0.00559001596999999961`", 
              "0.00628013371999999847`", "0.0143895222799999995`"},
            {"0.0157347770299999956`", "0.00440171696999999806`", 
              "0.00595965972000000032`", "0.00852479628000000033`", 
              "0.00559001596999999961`", "0.00822489003000000096`", 
              "0.00967992228000000132`", "0.00883922171999999939`"},
            {"0.0203980842799999972`", "0.00483825971999999815`", 
              "0.0067280999699999997`", "0.0100320060300000002`", 
              "0.00628013371999999847`", "0.00967992228000000132`", 
              "0.0113903070300000019`", "0.0106581869700000009`"},
            {"0.0281286597199999999`", "0.0121661962799999989`", 
              "0.0150720060300000024`", "0.00920668797000000083`", 
              "0.0143895222799999977`", "0.00883922172000000117`", 
              "0.0106581869700000009`", "0.00653451902999999845`"}
            }], ")"}],
      (MatrixForm[ #]&)]], "Output",
  CellLabel->"Out[115]//MatrixForm="]
}, Open  ]],

Cell["\<\
The next element fits allele frequencies by MLE, and fixes all \
cumulants at their true values (i.e., those for the population from which the \
samples were taken):\
\>", "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[
    \(j = 5; 
    \n{results\[LeftDoubleBracket]6, j, 1\[RightDoubleBracket], 
      results\[LeftDoubleBracket]6, j, 2, 1\[RightDoubleBracket] // 
        MatrixForm, 
      results\[LeftDoubleBracket]6, j, 2, 3\[RightDoubleBracket] // 
        MatrixForm}\)], "Input",
  CellLabel->"In[116]:="],

Cell[BoxData[
    RowBox[{"{", 
      RowBox[{\(-12.4753100591340171`\), ",", 
        TagBox[
          RowBox[{"(", GridBox[{
                {"0.263695172674783062`", "0.268568621033923804`", 
                  "0.249480301050056407`"}
                }], ")"}],
          (MatrixForm[ #]&)], ",", 
        TagBox[
          RowBox[{"(", GridBox[{
                {"0.`", "0.`", "0.0979999999999999893`", 
                  "0.0335999999999999898`"},
                {"0.`", "0.0419999999999999928`", "0.0167999999999999953`", 
                  "0.00319199999999999706`"},
                {"0.0979999999999999893`", "0.0167999999999999953`", 
                  "0.00632799999999999762`", \(-0.00154560000000000119`\)},
                {"0.0335999999999999898`", "0.00319199999999999484`", 
                  \(-0.00154559999999999941`\), \(-0.00449903999999999726`\)}
                }], ")"}],
          (MatrixForm[ #]&)]}], "}"}]], "Output",
  CellLabel->"Out[116]="]
}, Open  ]],

Cell[TextData[{
  "The previous five methods are now repeated, but fixing the allele \
frequencies at their sampled values.  Note that the sampled allele \
frequencies and cumulants estimated from the sample using EstimateMoments[], \
make an impossible combination ",
  Cell[BoxData[
      \(TraditionalForm\`\((j = 8)\)\)]],
  "; so does sampled allele frequency with ",
  Cell[BoxData[
      \(TraditionalForm\`\[Kappa]\_\(0, 2\)\)]],
  ", ",
  Cell[BoxData[
      \(TraditionalForm\`\[Kappa]\_\(1, 1\)\)]],
  "set to their true values ",
  Cell[BoxData[
      \(TraditionalForm\`\((j = 9)\)\)]],
  ":"
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(j = 6; 
    \n{results\[LeftDoubleBracket]6, j, 1\[RightDoubleBracket], 
      results\[LeftDoubleBracket]6, j, 2, 1\[RightDoubleBracket] // 
        MatrixForm, 
      results\[LeftDoubleBracket]6, j, 2, 3\[RightDoubleBracket] // 
        MatrixForm}\)], "Input",
  CellLabel->"In[117]:="],

Cell[BoxData[
    RowBox[{"{", 
      RowBox[{\(-86.781039109251985`\), ",", 
        TagBox[
          RowBox[{"(", GridBox[{
                {"0.29`", "0.3`", "0.254999999999999982`"}
                }], ")"}],
          (MatrixForm[ #]&)], ",", 
        TagBox[
          RowBox[{"(", GridBox[{
                {"0.`", "0.`", "0.`", "0.`"},
                {"0.`", "0.`", "0.`", "0.`"},
                {"0.`", "0.`", "0.`", "0.`"},
                {"0.`", "0.`", "0.`", "0.`"}
                }], ")"}],
          (MatrixForm[ #]&)]}], "}"}]], "Output",
  CellLabel->"Out[117]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(j = 7; 
    \n{results\[LeftDoubleBracket]6, j, 1\[RightDoubleBracket], 
      results\[LeftDoubleBracket]6, j, 2, 1\[RightDoubleBracket] // 
        MatrixForm, 
      results\[LeftDoubleBracket]6, j, 2, 3\[RightDoubleBracket] // 
        MatrixForm}\)], "Input",
  CellLabel->"In[118]:="],

Cell[BoxData[
    RowBox[{"{", 
      RowBox[{\(-9.31090384218134659`\), ",", 
        TagBox[
          RowBox[{"(", GridBox[{
                {"0.29`", "0.3`", "0.254999999999999982`"}
                }], ")"}],
          (MatrixForm[ #]&)], ",", 
        TagBox[
          RowBox[{"(", GridBox[{
                {"0.`", "0.`", "0.100293266436351746`", 
                  "0.052344156070130543`"},
                {"0.`", "0.0633710150049574139`", "0.0169663479628693325`", 
                  "0.000240086500448639439`"},
                {"0.100293266436351746`", "0.0169663479628693325`", 
                  "0.00278460309004520079`", \(-0.00466199555071689442`\)},
                {"0.052344156070130543`", "0.000240086500448639439`", 
                  \(-0.00466199555071689442`\), \(-0.00566973341121847962`\)}
                }], ")"}],
          (MatrixForm[ #]&)]}], "}"}]], "Output",
  CellLabel->"Out[118]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(j = 8; 
    \n{results\[LeftDoubleBracket]6, j, 1\[RightDoubleBracket], 
      results\[LeftDoubleBracket]6, j, 2, 1\[RightDoubleBracket] // 
        MatrixForm, 
      results\[LeftDoubleBracket]6, j, 2, 3\[RightDoubleBracket] // 
        MatrixForm}\)], "Input",
  CellLabel->"In[119]:="],

Cell[BoxData[
    RowBox[{"{", 
      RowBox[{\(-10000000000\), ",", 
        TagBox[
          RowBox[{"(", GridBox[{
                {"0.29`", "0.3`", "0.254999999999999982`"}
                }], ")"}],
          (MatrixForm[ #]&)], ",", 
        TagBox[
          RowBox[{"(", GridBox[{
                {"0.`", "0.`", "0.104741666666666666`", 
                  "0.0563147499999999912`"},
                {"0.`", "0.0769583333333333108`", "0.023055083333333326`", 
                  "0.000863470208333331257`"},
                {"0.104741666666666666`", "0.023055083333333326`", 
                  "0.0040254106250000099`", \(-0.00796676306249999122`\)},
                {"0.0563147499999999912`", "0.000863470208333327882`", 
                  \(-0.00796676306249999122`\), \(-0.0101733340343576372`\)}
                }], ")"}],
          (MatrixForm[ #]&)]}], "}"}]], "Output",
  CellLabel->"Out[119]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(j = 9; 
    \n{results\[LeftDoubleBracket]6, j, 1\[RightDoubleBracket], 
      results\[LeftDoubleBracket]6, j, 2, 1\[RightDoubleBracket] // 
        MatrixForm, 
      results\[LeftDoubleBracket]6, j, 2, 3\[RightDoubleBracket] // 
        MatrixForm}\)], "Input",
  CellLabel->"In[120]:="],

Cell[BoxData[
    RowBox[{"{", 
      RowBox[{\(-10000000000\), ",", 
        TagBox[
          RowBox[{"(", GridBox[{
                {"0.29`", "0.3`", "0.254999999999999982`"}
                }], ")"}],
          (MatrixForm[ #]&)], ",", 
        TagBox[
          RowBox[{"(", GridBox[{
                {"0.`", "0.`", "0.0979999999999999893`", 
                  "0.0563147499999999912`"},
                {"0.`", "0.0419999999999999928`", "0.023055083333333326`", 
                  "0.0126977024999999921`"},
                {"0.0979999999999999893`", "0.023055083333333326`", 
                  "0.0137093975000000023`", \(-0.00228501499999999424`\)},
                {"0.0563147499999999912`", "0.0126977024999999876`", 
                  \(-0.00228501499999999779`\), \(-0.0132324118751249875`\)}
                }], ")"}],
          (MatrixForm[ #]&)]}], "}"}]], "Output",
  CellLabel->"Out[120]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(j = 10; 
    \n{results\[LeftDoubleBracket]6, j, 1\[RightDoubleBracket], 
      results\[LeftDoubleBracket]6, j, 2, 1\[RightDoubleBracket] // 
        MatrixForm, 
      results\[LeftDoubleBracket]6, j, 2, 3\[RightDoubleBracket] // 
        MatrixForm}\)], "Input",
  CellLabel->"In[121]:="],

Cell[BoxData[
    RowBox[{"{", 
      RowBox[{\(-13.2743618729947465`\), ",", 
        TagBox[
          RowBox[{"(", GridBox[{
                {"0.29`", "0.3`", "0.254999999999999982`"}
                }], ")"}],
          (MatrixForm[ #]&)], ",", 
        TagBox[
          RowBox[{"(", GridBox[{
                {"0.`", "0.`", "0.0979999999999999893`", 
                  "0.0335999999999999898`"},
                {"0.`", "0.0419999999999999928`", "0.0167999999999999953`", 
                  "0.00319199999999999706`"},
                {"0.0979999999999999893`", "0.0167999999999999953`", 
                  "0.00632799999999999762`", \(-0.00154560000000000119`\)},
                {"0.0335999999999999898`", "0.00319199999999999484`", 
                  \(-0.00154559999999999941`\), \(-0.00449903999999999726`\)}
                }], ")"}],
          (MatrixForm[ #]&)]}], "}"}]], "Output",
  CellLabel->"Out[121]="]
}, Open  ]]
}, Open  ]]
},
FrontEndVersion->"4.0 for Macintosh",
ScreenRectangle->{{0, 1024}, {0, 748}},
WindowSize->{548, 658},
WindowMargins->{{Automatic, -2}, {Automatic, 5}},
StyleDefinitions -> "HelpBrowser.nb",
MacintoshSystemPageSetup->"\<\
00<0001804P000000`d26_oRon@3:`8f0dL5N`?N0080001804P000000`d26P01
0000I00000400@410?l00BL?00400@00000000000000000201T1T0000000@000
00000000004000000000000000010000\>"
]


(***********************************************************************
Cached data follows.  If you edit this Notebook file directly, not using
Mathematica, you must remove the line containing CacheID at the top of 
the file.  The cache data will then be recreated when you save this file 
from within Mathematica.
***********************************************************************)

(*CellTagsOutline
CellTagsIndex->{}
*)

(*CellTagsIndex
CellTagsIndex->{}
*)

(*NotebookFileOutline
Notebook[{

Cell[CellGroupData[{
Cell[1739, 51, 65, 0, 36, "SubsectionIcon"],
Cell[1807, 53, 432, 11, 52, "Text"],
Cell[2242, 66, 157, 3, 27, "Input"],
Cell[2402, 71, 562, 10, 78, "Text"],
Cell[2967, 83, 46, 0, 28, "MathCaption"],
Cell[3016, 85, 90, 2, 27, "Input"],

Cell[CellGroupData[{
Cell[3131, 91, 218, 5, 42, "Input"],
Cell[3352, 98, 1161, 22, 66, "Print"],
Cell[4516, 122, 1140, 19, 20, "Print"],
Cell[5659, 143, 1146, 18, 20, "Print"],
Cell[6808, 163, 1159, 19, 20, "Print"],
Cell[7970, 184, 1142, 19, 20, "Print"],
Cell[9115, 205, 1153, 19, 20, "Print"],
Cell[10271, 226, 1111, 19, 20, "Print"],
Cell[11385, 247, 1158, 19, 20, "Print"],
Cell[12546, 268, 1143, 19, 20, "Print"],
Cell[13692, 289, 1129, 18, 20, "Print"],
Cell[14824, 309, 1142, 19, 20, "Print"],
Cell[15969, 330, 85026, 1289, 5045, "Output"]
}, Closed]],
Cell[101010, 1622, 791, 13, 104, "Text"],
Cell[101804, 1637, 267, 6, 38, "Text"],

Cell[CellGroupData[{
Cell[102096, 1647, 125, 3, 27, "Input"],
Cell[102224, 1652, 1990, 38, 174, "Output"]
}, Closed]],
Cell[104229, 1693, 193, 4, 32, "Text"],
Cell[104425, 1699, 77, 0, 28, "MathCaption"],

Cell[CellGroupData[{
Cell[104527, 1703, 108, 2, 27, "Input"],
Cell[104638, 1707, 8041, 122, 523, "Output"]
}, Closed]],
Cell[112694, 1832, 297, 5, 46, "Text"],
Cell[112994, 1839, 131, 3, 42, "MathCaption"],

Cell[CellGroupData[{
Cell[113150, 1846, 310, 7, 42, "Input"],
Cell[113463, 1855, 636, 17, 67, "Output"]
}, Open  ]],
Cell[114114, 1875, 140, 3, 42, "MathCaption"],

Cell[CellGroupData[{
Cell[114279, 1882, 246, 6, 42, "Input"],
Cell[114528, 1890, 581, 17, 67, "Output"]
}, Open  ]],
Cell[115124, 1910, 105, 3, 28, "MathCaption"],

Cell[CellGroupData[{
Cell[115254, 1917, 310, 7, 42, "Input"],
Cell[115567, 1926, 967, 21, 88, "Output"]
}, Open  ]],
Cell[116549, 1950, 148, 3, 42, "MathCaption"],

Cell[CellGroupData[{
Cell[116722, 1957, 310, 7, 42, "Input"],
Cell[117035, 1966, 970, 21, 88, "Output"]
}, Open  ]],
Cell[118020, 1990, 178, 4, 42, "MathCaption"],

Cell[CellGroupData[{
Cell[118223, 1998, 310, 7, 42, "Input"],
Cell[118536, 2007, 907, 20, 88, "Output"]
}, Open  ]],
Cell[119458, 2030, 78, 0, 28, "MathCaption"],

Cell[CellGroupData[{
Cell[119561, 2034, 387, 8, 57, "Input"],
Cell[119951, 2044, 2352, 37, 251, "Output"]
}, Open  ]],
Cell[122318, 2084, 78, 0, 28, "MathCaption"],

Cell[CellGroupData[{
Cell[122421, 2088, 396, 10, 76, "Input"],
Cell[122820, 2100, 2338, 37, 251, "Output"]
}, Open  ]],
Cell[125173, 2140, 196, 4, 42, "MathCaption"],

Cell[CellGroupData[{
Cell[125394, 2148, 310, 7, 42, "Input"],
Cell[125707, 2157, 974, 21, 88, "Output"]
}, Open  ]],
Cell[126696, 2181, 617, 17, 64, "Text"],

Cell[CellGroupData[{
Cell[127338, 2202, 310, 7, 42, "Input"],
Cell[127651, 2211, 583, 16, 67, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[128271, 2232, 310, 7, 42, "Input"],
Cell[128584, 2241, 920, 20, 67, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[129541, 2266, 310, 7, 42, "Input"],
Cell[129854, 2275, 909, 20, 88, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[130800, 2300, 310, 7, 42, "Input"],
Cell[131113, 2309, 907, 20, 88, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[132057, 2334, 311, 7, 42, "Input"],
Cell[132371, 2343, 922, 20, 67, "Output"]
}, Open  ]]
}, Open  ]]
}
]
*)




(***********************************************************************
End of Mathematica Notebook file.
***********************************************************************)

