(***********************************************************************

                    Mathematica-Compatible Notebook

This notebook can be used on any computer system with Mathematica 4.0,
MathReader 4.0, or any compatible application. The data for the notebook 
starts with the line containing stars above.

To get the notebook into a Mathematica-compatible application, do one of 
the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing the 
word CacheID, otherwise Mathematica-compatible applications may try to 
use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
***********************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[      5225,        140]*)
(*NotebookOutlinePosition[      6595,        182]*)
(*  CellTagsIndexPosition[      6460,        174]*)
(*WindowFrame->Normal*)



Notebook[{

Cell[CellGroupData[{
Cell[TextData[StyleBox["Multilocus`Multilocus`", "Chapter"]], "SubsectionIcon",
  CellTags->{"S5.67.1", "1.1", "Multilocus`Multilocus`"}],

Cell[TextData[{
  "This package gives a general mathematical framework for the evolution  of \
systems of many genes.  It is based on the notation defined by Barton and \
Turelli (",
  StyleBox["Genetics",
    FontSlant->"Italic"],
  ", ",
  ButtonBox["1991",
    ButtonData:>{"Multilocus references", "Barton and Turelli 1991"},
    ButtonStyle->"AddOnsLink",
    ButtonNote->"1991"],
  "), but is considerably more general.  For a more detailed account, see ",
  ButtonBox["Kirkpatrick et al.",
    ButtonData:>{"Multilocus MS", "Introduction"},
    ButtonStyle->"AddOnsLink"],
  " The ",
  ButtonBox["relation",
    ButtonData:>{"Multilocus MS relation", None},
    ButtonStyle->"AddOnsLink"],
  " between that manuscript and these packages is also summarised; there are \
some minor differences in notation."
}], "Text"],

Cell[TextData[{
  "The underlying concepts are quite abstract, and apply to a very wide range \
of cases: deterministic or stochastic, haploid or diploid, and so on.  Each \
gene is in some ",
  StyleBox["context",
    FontSlant->"Italic"],
  ", which might represent whether it is on the maternal or paternal \
chromosome; which sex it is in; in what generation it is; and so on.  The \
state of the population is defined by associations between genes in different \
contexts: these correspond to classical linkage disequilibria.  Populations \
may change through two kinds of process: ",
  StyleBox["transmission",
    FontSlant->"Italic"],
  " of genes between contexts, and ",
  StyleBox["selection",
    FontSlant->"Italic"],
  ", by which sets of genes make different contributions to the next stage in \
the life cycle.  Transmission includes random union of gametes, \
recombination, migration, and mutation.  Rates of transmission may depend on \
genotype  - for example, with modifiers of recombination rate and habitat \
preference.  Selection can be on any set of genes-in-context: thus, it \
includes viability selection, sexual selection, and group selection. "
}], "Text"],

Cell[TextData[{
  "Examples of natural and sexual selection on diploids, and of migration, \
are given; examples of group selection, habitat preference, modifiers of \
recombination etc. are still to be added.  For these and other genetical \
models, functions are defined that allow the general notation to be used in a \
more compact way.  Thus, the section on \"Multilocus notation\" sets out the \
general principles, and \"Selection on diploids\" give methods for dealing \
with that particular case.  An extension to ",
  ButtonBox["random drift",
    ButtonData:>{"Introduction to random drift", None},
    ButtonStyle->"AddOnsLink"],
  " is also outlined."
}], "Text"],

Cell["This reads in the package:", "MathCaption"],

Cell[BoxData[
    RowBox[{
      RowBox[{"<<", 
        StyleBox["Multilocus`Multilocus`",
          "Chapter\[AGrave]"]}], 
      StyleBox[";",
        "Chapter\[AGrave]"]}]], "Input",
  CellLabel->"In[1]:="],

Cell[TextData[{
  "The package also reads in ",
  ButtonBox["Utilities`SetManipulation` ",
    ButtonData:>{"Overview of set manipulation", None},
    ButtonStyle->"AddOnsLink",
    ButtonNote->"Utilities`SetManipulation` "],
  "and ",
  ButtonBox["Utilities`Notation`",
    ButtonData:>{"Notation Documentation", None},
    ButtonStyle->"AddOnsLink"],
  ":"
}], "Text"]
}, Open  ]]
},
FrontEndVersion->"4.0 for Macintosh",
ScreenRectangle->{{0, 1152}, {0, 748}},
WindowSize->{956, 721},
WindowMargins->{{69, Automatic}, {Automatic, 1}},
StyleDefinitions -> "HelpBrowser.nb",
MacintoshSystemPageSetup->"\<\
00h0001804P000000b02<?oaonl3>@91H`85N0?N0@00005X0FP000003j0:l001
0@00I00100000@0200000BL?00400000000000000000010000000000000@0?ne
oj/@7@]500P1000000000000000001T1\>"
]


(***********************************************************************
Cached data follows.  If you edit this Notebook file directly, not using
Mathematica, you must remove the line containing CacheID at the top of 
the file.  The cache data will then be recreated when you save this file 
from within Mathematica.
***********************************************************************)

(*CellTagsOutline
CellTagsIndex->{
  "S5.67.1"->{
    Cell[1739, 51, 137, 1, 49, "SubsectionIcon",
      CellTags->{"S5.67.1", "1.1", "Multilocus`Multilocus`"}]},
  "1.1"->{
    Cell[1739, 51, 137, 1, 49, "SubsectionIcon",
      CellTags->{"S5.67.1", "1.1", "Multilocus`Multilocus`"}]},
  "Multilocus`Multilocus`"->{
    Cell[1739, 51, 137, 1, 49, "SubsectionIcon",
      CellTags->{"S5.67.1", "1.1", "Multilocus`Multilocus`"}]}
  }
*)

(*CellTagsIndex
CellTagsIndex->{
  {"S5.67.1", 6055, 161},
  {"1.1", 6179, 164},
  {"Multilocus`Multilocus`", 6322, 167}
  }
*)

(*NotebookFileOutline
Notebook[{

Cell[CellGroupData[{
Cell[1739, 51, 137, 1, 49, "SubsectionIcon",
  CellTags->{"S5.67.1", "1.1", "Multilocus`Multilocus`"}],
Cell[1879, 54, 824, 21, 53, "Text"],
Cell[2706, 77, 1187, 22, 96, "Text"],
Cell[3896, 101, 676, 12, 51, "Text"],
Cell[4575, 115, 49, 0, 28, "MathCaption"],
Cell[4627, 117, 209, 7, 27, "Input"],
Cell[4839, 126, 370, 11, 23, "Text"]
}, Open  ]]
}
]
*)




(***********************************************************************
End of Mathematica Notebook file.
***********************************************************************)

