(***********************************************************************

                    Mathematica-Compatible Notebook

This notebook can be used on any computer system with Mathematica 4.0,
MathReader 4.0, or any compatible application. The data for the notebook 
starts with the line containing stars above.

To get the notebook into a Mathematica-compatible application, do one of 
the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing the 
word CacheID, otherwise Mathematica-compatible applications may try to 
use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
***********************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[     33091,        777]*)
(*NotebookOutlinePosition[     37203,        885]*)
(*  CellTagsIndexPosition[     36855,        872]*)
(*WindowFrame->Normal*)



Notebook[{

Cell[CellGroupData[{
Cell["Migration", "SubsectionIcon"],

Cell[TextData[{
  "Migration is implemented in a similar way to ",
  ButtonBox["recombination",
    ButtonData:>{"Recombination", None},
    ButtonStyle->"AddOnsLink"],
  ".  Migrate[{\[GothicCapitalZ],\[GothicCapitalJ]},\[Alpha],\[Beta]] is a \
simple transmission rule which corresponds to movement of genes between \
zygote and adult stages.  Migration[\[CapitalOmega]] applies this rule to all \
possible movements, and thus expresses associations among juveniles in terms \
of those in zygotes.  The main difference is that the set of possible source \
demes must be specified by the function \[CapitalOmega]."
}], "Text"],

Cell[CellGroupData[{

Cell["Setting up\[Ellipsis]", "SubsubsectionIcon",
  CellTags->"Setting up"],

Cell["This loads the package:", "MathCaption"],

Cell[BoxData[
    \(\(<< Multilocus`Multilocus`;\)\)], "Input",
  CellLabel->"In[238]:=  (20:04:56 on 3/12/01)"],

Cell["A simple life cycle is defined using:", "MathCaption"],

Cell[BoxData[{
    \(\(DefineContext[\[GothicCapitalG], {Deme, \ Sex}];\)\), "\n", 
    \(\(DefineContext[\[GothicCapitalZ], {Deme, Sex, 
          SexOfOrigin}];\)\), "\n", 
    \(\(DefineContext[\[GothicCapitalJ], {Deme, Sex, 
          SexOfOrigin}];\)\), "\n", 
    \(\(DefineContext[\[GothicCapitalA], {Deme, Sex, 
          SexOfOrigin}];\)\), "\n", 
    \(\(DefineContext[\(\[GothicCapitalG]\^*\), {\ Deme, Sex}];\)\)}], "Input",\

  CellLabel->"In[239]:=  (20:05:02 on 3/12/01)"],

Cell[TextData[{
  " ",
  Cell[BoxData[
      FormBox[GridBox[{
            {\(Migrate[\[Alpha], \[Beta]]\), \(gene\ in\ deme\ \[Alpha]\ in\ \
juveniles, \ \[GothicCapitalJ], \ 
              came\ from\ genes\ in\ deme\ \[Beta]\ in\ zygotes, \ \
\[GothicCapitalZ]\)},
            {\(Migrate[{\[GothicCapitalZ], \[GothicCapitalJ]}, \[Alpha], \
\[Beta]]\), \(specifies\ explicitly\ that\ movement\ is\ between\ zygote\ and\
\ juvenile\ stages\)}
            }], TraditionalForm]]]
}], "DefinitionBox",
  CellTags->"Migrate"],

Cell[TextData[{
  "Migrate[\[Alpha], \[Beta]] derives genes in juveniles, ",
  Cell[BoxData[
      \(TraditionalForm\`\[GothicCapitalJ]\)]],
  ", from those in zygotes, \[GothicCapitalZ]:"
}], "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[
    \({i\_{\[GothicCapitalJ], 1, \[GothicCapitalM], \[GothicCapitalM]}, 
        j\_{\[GothicCapitalJ], 1, \[GothicCapitalM], \[GothicCapitalF]}, 
        k\_{\[GothicCapitalJ], 1, \[GothicCapitalM], \[GothicCapitalF]}}\
\[CirclePlus]Migrate[1, 3]\)], "Input",
  CellLabel->"In[140]:=  (20:00:43 on 3/11/01)"],

Cell[BoxData[
    \({i\_{\[GothicCapitalZ], 3, \[GothicCapitalM], \[GothicCapitalM]}, 
      j\_{\[GothicCapitalZ], 3, \[GothicCapitalM], \[GothicCapitalF]}, 
      k\_{\[GothicCapitalZ], 3, \[GothicCapitalM], \[GothicCapitalF]}}\)], \
"Output",
  CellLabel->"Out[140]=  (20:00:43 on 3/11/01)"]
}, Open  ]],

Cell["\<\
A set of genes in juveniles in deme 1 is derived from the same set \
in deme 3.\
\>", "Text"],

Cell[TextData[{
  "Note: ",
  StyleBox["All the genes are assumed to be in the same deme; however, no \
check is made that this is so.",
    FontWeight->"Plain"]
}], "Text",
  FontWeight->"Bold"],

Cell["\<\
The default is that migration is from diploid zygotes to diploid \
juveniles.  However, other stages can be specified.\
\>", "Text"],

Cell["This is an example of migration of haploids:", "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(DefineContext[\[GothicCapitalG]2, {Deme, \ Sex}];\)\), "\n", 
    \({i\_{\[GothicCapitalG]2, 1, \[GothicCapitalM]}, 
        j\_{\[GothicCapitalG]2, 1, \[GothicCapitalM]}, 
        k\_{\[GothicCapitalG]2, 1, \[GothicCapitalM]}}\[CirclePlus]Migrate[{\
\[GothicCapitalG], \[GothicCapitalG]2}, 1, 3]\)}], "Input",
  CellLabel->"In[141]:=  (20:05:00 on 3/11/01)"],

Cell[BoxData[
    \({i\_{\[GothicCapitalG], 3, \[GothicCapitalM]}, 
      j\_{\[GothicCapitalG], 3, \[GothicCapitalM]}, 
      k\_{\[GothicCapitalG], 3, \[GothicCapitalM]}}\)], "Output",
  CellLabel->"Out[142]=  (20:05:00 on 3/11/01)"]
}, Open  ]],

Cell["\<\
The associations after a particular migration event are complicated \
by the change in reference point between demes:\
\>", "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\[GothicCapitalD]\_{i\_{\[GothicCapitalJ], 1, \[GothicCapitalM], \
\[GothicCapitalM]}, j\_{\[GothicCapitalJ], 1, \[GothicCapitalM], \
\[GothicCapitalF]}}\[CirclePlus]Migrate[1, 3]\)], "Input"],

Cell[BoxData[
    \(\[GothicCapitalD]\_{i\_{\[GothicCapitalZ], 3, \[GothicCapitalM], \
\[GothicCapitalM]}, j\_{\[GothicCapitalZ], 3, \[GothicCapitalM], \
\[GothicCapitalF]}} + \[GothicCapitalD]\_{j\_{\[GothicCapitalZ], 3, \
\[GothicCapitalM], \[GothicCapitalF]}}\ \((\(-\[WeierstrassP]\_\(i\_{\
\[GothicCapitalJ], 1, \[GothicCapitalM], \[GothicCapitalM]}\)\) + \
\[WeierstrassP]\_\(i\_{\[GothicCapitalZ], 3, \[GothicCapitalM], \
\[GothicCapitalM]}\))\) + \[GothicCapitalD]\_{i\_{\[GothicCapitalZ], 3, \
\[GothicCapitalM], \[GothicCapitalM]}}\ \((\(-\[WeierstrassP]\_\(j\_{\
\[GothicCapitalJ], 1, \[GothicCapitalM], \[GothicCapitalF]}\)\) + \
\[WeierstrassP]\_\(j\_{\[GothicCapitalZ], 3, \[GothicCapitalM], \
\[GothicCapitalF]}\))\) + \((\(-\[WeierstrassP]\_\(i\_{\[GothicCapitalJ], 1, \
\[GothicCapitalM], \[GothicCapitalM]}\)\) + \[WeierstrassP]\_\(i\_{\
\[GothicCapitalZ], 3, \[GothicCapitalM], \[GothicCapitalM]}\))\)\ \((\(-\
\[WeierstrassP]\_\(j\_{\[GothicCapitalJ], 1, \[GothicCapitalM], \
\[GothicCapitalF]}\)\) + \[WeierstrassP]\_\(j\_{\[GothicCapitalZ], 3, \
\[GothicCapitalM], \[GothicCapitalF]}\))\)\)], "Output",
  CellLabel->"Out[143]=  (20:08:37 on 3/11/01)"]
}, Open  ]],

Cell[TextData[{
  "If all associations were measured relative to a ",
  StyleBox["global",
    FontSlant->"Italic"],
  " reference point, migration would not change them.  However, associations \
are generated by the movement of genes between contexts with ",
  StyleBox["different",
    FontSlant->"Italic"],
  " reference points."
}], "Text"],

Cell[TextData[{
  Cell[BoxData[
      \(TraditionalForm\`For\ a\ haploid\ stage, \ 
      Migrate[{\[GothicCapitalZ], \[GothicCapitalJ]}, \[Alpha], \[Beta]]\ \
is\)]],
  " just a set of rules  ",
  Cell[BoxData[
      \({{\[GothicCapitalJ], 
            x___, \[Alpha], \[GothicCapitalF]} \[LeftArrow] \
{\[GothicCapitalZ], x, \[Beta], \[GothicCapitalF]}, {\[GothicCapitalJ], 
            x___, \[Alpha], \[GothicCapitalM]} \[LeftArrow] \
{\[GothicCapitalZ], x, \[Beta], \[GothicCapitalM]}}\)],
    FontFamily->"Times"],
  "; diploids require four such rules. A stage is recognised as diploid if it \
includes SexOfOrigin."
}], "Text"],

Cell[TextData[{
  "Note: ",
  StyleBox["because Migrate[] is a ",
    FontWeight->"Plain"],
  ButtonBox["transmission rule",
    ButtonData:>{"Changing contexts", "Transmission vs Mathematica rules"},
    ButtonStyle->"AddOnsLink"],
  StyleBox[", it must be applied using \[CirclePlus] not /.",
    FontWeight->"Plain"]
}], "Text",
  FontWeight->"Bold"],

Cell[TextData[{
  " ",
  Cell[BoxData[
      FormBox[GridBox[{
            {\(Migration[\[CapitalOmega]]\), \(a\ rule\ which\ gives\ the\ \
mean\ contributions\ and\ linkage\ disequilibria\ in\ juveniles, \ \
\[GothicCapitalJ], \ 
              in\ terms\ of\ disequilibria\ in\ the\ pool\ of\ zygotes, \ \
\[GothicCapitalZ]; \ 
              a\ sum\ over\ all\ possible\ migration\ events, \ \
\[CapitalOmega][\[Alpha]], \ 
              each\ with\ probability\ \[CapitalMu]\_\(\[Alpha], \
\[Beta]\)\)},
            {\(Migration[{\[GothicCapitalZ], \[GothicCapitalJ]}, 
                MigrationRate, \[CapitalOmega]]\), \(specifies\ the\ stages\ \
and\ migration\ rate\ \(\(explicitly\)\(.\)\)\)},
            {\(\[CapitalMu]\_\(\[Alpha], \[Beta]\)\ or\ \
MigrationRate[\[Alpha], \[Beta]]\), \(the\ probability\ that\ an\ individual\ \
in\ deme\ \[Alpha]\ came\ from\ deme\ \(\(\[Beta]\)\(.\)\)\)}
            }], TraditionalForm]]]
}], "DefinitionBox",
  CellTags->{"Recombination", "RecombinationRate"}],

Cell["\<\
Individuals in deme \[Alpha] can come from a set of demes \
\[CapitalOmega][\[Alpha]]; Migration[] yields a sum over this set of possible \
source demes.\
\>", "Text"],

Cell["\<\
This is the mean contribution of a single locus after \
migration:\
\>", "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\[GothicM]\_\(j\_{\[GothicCapitalJ], 1, \[GothicCapitalM], \
\[GothicCapitalM]}\) /. Migration[{1, 2} &]\)], "Input"],

Cell[BoxData[
    \(\[GothicM]\_\(j\_{\[GothicCapitalZ], 1, \[GothicCapitalM], \
\[GothicCapitalM]}\)\ \[CapitalMu]\_\(1, 1\) + \[GothicM]\_\(j\_{\
\[GothicCapitalZ], 2, \[GothicCapitalM], \[GothicCapitalM]}\)\ \[CapitalMu]\_\
\(1, 2\)\)], "Output"]
}, Open  ]],

Cell[TextData[{
  "This is the cross-genome association between loci j and k among juveniles, \
",
  Cell[BoxData[
      \(TraditionalForm\`\(\(\[GothicCapitalJ]\)\(,\)\(\ \)\)\)]],
  "after migration:"
}], "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\[GothicCapitalD]\_{j\_{\[GothicCapitalJ], 1, \[GothicCapitalM], \
\[GothicCapitalM]}, k\_{\[GothicCapitalJ], 1, \[GothicCapitalM], \
\[GothicCapitalF]}} /. Migration[{1, 2} &]\)], "Input",
  CellLabel->"In[83]:=  (19:20:05 on 3/12/01)"],

Cell[BoxData[
    \(\[CapitalMu]\_\(1, 1\)\ \((\[GothicCapitalD]\_{j\_{\[GothicCapitalZ], \
1, \[GothicCapitalM], \[GothicCapitalM]}, k\_{\[GothicCapitalZ], 1, \
\[GothicCapitalM], \[GothicCapitalF]}} + \[GothicCapitalD]\_{k\_{\
\[GothicCapitalZ], 1, \[GothicCapitalM], \[GothicCapitalF]}}\ \((\(-\
\[WeierstrassP]\_\(j\_{\[GothicCapitalJ], 1, \[GothicCapitalM], \
\[GothicCapitalM]}\)\) + \[WeierstrassP]\_\(j\_{\[GothicCapitalZ], 1, \
\[GothicCapitalM], \[GothicCapitalM]}\))\) + \[GothicCapitalD]\_{j\_{\
\[GothicCapitalZ], 1, \[GothicCapitalM], \[GothicCapitalM]}}\ \((\(-\
\[WeierstrassP]\_\(k\_{\[GothicCapitalJ], 1, \[GothicCapitalM], \
\[GothicCapitalF]}\)\) + \[WeierstrassP]\_\(k\_{\[GothicCapitalZ], 1, \
\[GothicCapitalM], \[GothicCapitalF]}\))\) + \((\(-\[WeierstrassP]\_\(j\_{\
\[GothicCapitalJ], 1, \[GothicCapitalM], \[GothicCapitalM]}\)\) + \
\[WeierstrassP]\_\(j\_{\[GothicCapitalZ], 1, \[GothicCapitalM], \
\[GothicCapitalM]}\))\)\ \((\(-\[WeierstrassP]\_\(k\_{\[GothicCapitalJ], 1, \
\[GothicCapitalM], \[GothicCapitalF]}\)\) + \[WeierstrassP]\_\(k\_{\
\[GothicCapitalZ], 1, \[GothicCapitalM], \[GothicCapitalF]}\))\))\) + \
\[CapitalMu]\_\(1, 2\)\ \((\[GothicCapitalD]\_{j\_{\[GothicCapitalZ], 2, \
\[GothicCapitalM], \[GothicCapitalM]}, k\_{\[GothicCapitalZ], 2, \
\[GothicCapitalM], \[GothicCapitalF]}} + \[GothicCapitalD]\_{k\_{\
\[GothicCapitalZ], 2, \[GothicCapitalM], \[GothicCapitalF]}}\ \((\(-\
\[WeierstrassP]\_\(j\_{\[GothicCapitalJ], 1, \[GothicCapitalM], \
\[GothicCapitalM]}\)\) + \[WeierstrassP]\_\(j\_{\[GothicCapitalZ], 2, \
\[GothicCapitalM], \[GothicCapitalM]}\))\) + \[GothicCapitalD]\_{j\_{\
\[GothicCapitalZ], 2, \[GothicCapitalM], \[GothicCapitalM]}}\ \((\(-\
\[WeierstrassP]\_\(k\_{\[GothicCapitalJ], 1, \[GothicCapitalM], \
\[GothicCapitalF]}\)\) + \[WeierstrassP]\_\(k\_{\[GothicCapitalZ], 2, \
\[GothicCapitalM], \[GothicCapitalF]}\))\) + \((\(-\[WeierstrassP]\_\(j\_{\
\[GothicCapitalJ], 1, \[GothicCapitalM], \[GothicCapitalM]}\)\) + \
\[WeierstrassP]\_\(j\_{\[GothicCapitalZ], 2, \[GothicCapitalM], \
\[GothicCapitalM]}\))\)\ \((\(-\[WeierstrassP]\_\(k\_{\[GothicCapitalJ], 1, \
\[GothicCapitalM], \[GothicCapitalF]}\)\) + \[WeierstrassP]\_\(k\_{\
\[GothicCapitalZ], 2, \[GothicCapitalM], \[GothicCapitalF]}\))\))\)\)], \
"Output"]
}, Open  ]],

Cell["\<\
These expressions are linear sums, weighted by migration rates.  \
The set of possible source demes is defined by {1,2}& - that is, all demes \
can receive immigrants from demes {1,2}.\
\>", "Text"],

Cell["\<\
All genes in a set must be in the same deme if the rule is to \
apply:\
\>", "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\[GothicCapitalD]\_{j\_{\[GothicCapitalJ], 1, \[GothicCapitalM], \
\[GothicCapitalM]}, k\_{\[GothicCapitalJ], 2, \[GothicCapitalM], \
\[GothicCapitalF]}} /. Migration[{1, 2} &]\)], "Input",
  CellLabel->"In[92]:=  (19:33:15 on 3/12/01)"],

Cell[BoxData[
    \(\[GothicCapitalD]\_{j\_{\[GothicCapitalJ], 1, \[GothicCapitalM], \
\[GothicCapitalM]}, k\_{\[GothicCapitalJ], 2, \[GothicCapitalM], \
\[GothicCapitalF]}}\)], "Output",
  CellLabel->"Out[92]=  (19:33:15 on 3/12/01)"]
}, Open  ]],

Cell["\<\
The function (#+{-1,0,1})& defines nearest-neighbour migration in \
one dimension:\
\>", "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\[GothicM]\_\(j\_{\[GothicCapitalJ], 3, \[GothicCapitalM], \
\[GothicCapitalM]}\) /. Migration[\((# + {\(-1\), 0, 1})\) &]\)], "Input"],

Cell[BoxData[
    \(\[GothicM]\_\(j\_{\[GothicCapitalZ], 2, \[GothicCapitalM], \
\[GothicCapitalM]}\)\ \[CapitalMu]\_\(3, 2\) + \[GothicM]\_\(j\_{\
\[GothicCapitalZ], 3, \[GothicCapitalM], \[GothicCapitalM]}\)\ \[CapitalMu]\_\
\(3, 3\) + \[GothicM]\_\(j\_{\[GothicCapitalZ], 4, \[GothicCapitalM], \
\[GothicCapitalM]}\)\ \[CapitalMu]\_\(3, 4\)\)], "Output"]
}, Open  ]],

Cell["\<\
The function f defines nearest-neighbour migration in two \
dimensions:\
\>", "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(f[{x_, y_}] := {{x - 1, y}, {x + 1, y}, {x, y - 1}, {x, y + 1}, {x, 
            y}};\)\), "\n", 
    \(\[GothicM]\_\(j\_{\[GothicCapitalJ], {3, 2}, \[GothicCapitalM], \
\[GothicCapitalM]}\) /. Migration[f]\)}], "Input"],

Cell[BoxData[
    \(\[GothicM]\_\(j\_{\[GothicCapitalZ], {2, 2}, \[GothicCapitalM], \
\[GothicCapitalM]}\)\ \[CapitalMu]\_\({3, 2}, {2, 2}\) + \[GothicM]\_\(j\_{\
\[GothicCapitalZ], {3, 1}, \[GothicCapitalM], \[GothicCapitalM]}\)\ \
\[CapitalMu]\_\({3, 2}, {3, 1}\) + \[GothicM]\_\(j\_{\[GothicCapitalZ], {3, \
2}, \[GothicCapitalM], \[GothicCapitalM]}\)\ \[CapitalMu]\_\({3, 2}, {3, 2}\) \
+ \[GothicM]\_\(j\_{\[GothicCapitalZ], {3, 3}, \[GothicCapitalM], \
\[GothicCapitalM]}\)\ \[CapitalMu]\_\({3, 2}, {3, 3}\) + \[GothicM]\_\(j\_{\
\[GothicCapitalZ], {4, 2}, \[GothicCapitalM], \[GothicCapitalM]}\)\ \
\[CapitalMu]\_\({3, 2}, {4, 2}\)\)], "Output"]
}, Open  ]],

Cell["\<\
Demes can be denoted by any structure: here, it is natural to use \
{x,y} for a two-dimensional grid.\
\>", "Text"],

Cell[TextData[{
  "The notation ",
  Cell[BoxData[
      \(TraditionalForm\`\[CapitalMu]\_\(\[Alpha], \[Beta]\)\)]],
  " is automatically converted to MigrationRate[A,B] (\[CapitalMu] is entered \
as \[AliasIndicator]M\[AliasIndicator]). This allows the subscripted notation \
to be used:"
}], "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\[CapitalMu]\_\(\[Alpha], \[Beta]\) // FullForm\)], "Input",
  CellLabel->"In[91]:=  (19:31:15 on 3/12/01)"],

Cell[BoxData[
    TagBox[
      StyleBox[\(MigrationRate[\[Alpha], \[Beta]]\),
        ShowStringCharacters->True,
        NumberMarks->True],
      FullForm]], "Output",
  CellLabel->"Out[91]//FullForm=  (19:31:15 on 3/12/01)"]
}, Open  ]],

Cell[TextData[{
  "By default, Migration[\[CapitalOmega]] relates stages ",
  Cell[BoxData[
      \(TraditionalForm\`{\[GothicCapitalZ], \[GothicCapitalJ]}\)]],
  ", and gives the recombination rates in the form ",
  Cell[BoxData[
      \(TraditionalForm\`\[CapitalMu]\_\(\[Alpha], \[Beta]\)\)]],
  ".  "
}], "Text"],

Cell["Other stages and rates can be used:", "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\[GothicCapitalD]\_{j\_{\[GothicCapitalA], \[GothicCapitalM], \
\[GothicCapitalM]}, k\_{\[GothicCapitalA], \[GothicCapitalM], \
\[GothicCapitalM]}} /. 
      Recombination[{\[GothicCapitalA], \(\[GothicCapitalG]\^*\)}, 
        rec]\)], "Input"],

Cell[BoxData[
    \(rec[{j, 
            k}, {}]\ \((\[GothicCapitalD]\_{j\_{\[GothicCapitalA], \
\[GothicCapitalM], \[GothicCapitalF]}, k\_{\[GothicCapitalA], \
\[GothicCapitalM], \[GothicCapitalF]}} + \[GothicCapitalD]\_{k\_{\
\[GothicCapitalA], \[GothicCapitalM], \[GothicCapitalF]}}\ \((\(-\
\[WeierstrassP]\_\(j\_{\(\[GothicCapitalG]\^*\), \[GothicCapitalM]}\)\) + \
\[WeierstrassP]\_\(j\_{\[GothicCapitalA], \[GothicCapitalM], \
\[GothicCapitalF]}\))\) + \[GothicCapitalD]\_{j\_{\[GothicCapitalA], \
\[GothicCapitalM], \[GothicCapitalF]}}\ \((\(-\[WeierstrassP]\_\(k\_{\(\
\[GothicCapitalG]\^*\), \[GothicCapitalM]}\)\) + \[WeierstrassP]\_\(k\_{\
\[GothicCapitalA], \[GothicCapitalM], \[GothicCapitalF]}\))\) + \((\(-\
\[WeierstrassP]\_\(j\_{\(\[GothicCapitalG]\^*\), \[GothicCapitalM]}\)\) + \
\[WeierstrassP]\_\(j\_{\[GothicCapitalA], \[GothicCapitalM], \
\[GothicCapitalF]}\))\)\ \
\((\(-\[WeierstrassP]\_\(k\_{\(\[GothicCapitalG]\^*\), \[GothicCapitalM]}\)\) \
+ \[WeierstrassP]\_\(k\_{\[GothicCapitalA], \[GothicCapitalM], \
\[GothicCapitalF]}\))\))\) + 
      rec[{k}, {j}]\ \((\[GothicCapitalD]\_{j\_{\[GothicCapitalA], \
\[GothicCapitalM], \[GothicCapitalM]}, k\_{\[GothicCapitalA], \
\[GothicCapitalM], \[GothicCapitalF]}} + \[GothicCapitalD]\_{k\_{\
\[GothicCapitalA], \[GothicCapitalM], \[GothicCapitalF]}}\ \((\(-\
\[WeierstrassP]\_\(j\_{\(\[GothicCapitalG]\^*\), \[GothicCapitalM]}\)\) + \
\[WeierstrassP]\_\(j\_{\[GothicCapitalA], \[GothicCapitalM], \
\[GothicCapitalM]}\))\) + \[GothicCapitalD]\_{j\_{\[GothicCapitalA], \
\[GothicCapitalM], \[GothicCapitalM]}}\ \((\(-\[WeierstrassP]\_\(k\_{\(\
\[GothicCapitalG]\^*\), \[GothicCapitalM]}\)\) + \[WeierstrassP]\_\(k\_{\
\[GothicCapitalA], \[GothicCapitalM], \[GothicCapitalF]}\))\) + \((\(-\
\[WeierstrassP]\_\(j\_{\(\[GothicCapitalG]\^*\), \[GothicCapitalM]}\)\) + \
\[WeierstrassP]\_\(j\_{\[GothicCapitalA], \[GothicCapitalM], \
\[GothicCapitalM]}\))\)\ \
\((\(-\[WeierstrassP]\_\(k\_{\(\[GothicCapitalG]\^*\), \[GothicCapitalM]}\)\) \
+ \[WeierstrassP]\_\(k\_{\[GothicCapitalA], \[GothicCapitalM], \
\[GothicCapitalF]}\))\))\) + 
      rec[{j}, {k}]\ \((\[GothicCapitalD]\_{j\_{\[GothicCapitalA], \
\[GothicCapitalM], \[GothicCapitalF]}, k\_{\[GothicCapitalA], \
\[GothicCapitalM], \[GothicCapitalM]}} + \[GothicCapitalD]\_{k\_{\
\[GothicCapitalA], \[GothicCapitalM], \[GothicCapitalM]}}\ \((\(-\
\[WeierstrassP]\_\(j\_{\(\[GothicCapitalG]\^*\), \[GothicCapitalM]}\)\) + \
\[WeierstrassP]\_\(j\_{\[GothicCapitalA], \[GothicCapitalM], \
\[GothicCapitalF]}\))\) + \[GothicCapitalD]\_{j\_{\[GothicCapitalA], \
\[GothicCapitalM], \[GothicCapitalF]}}\ \((\(-\[WeierstrassP]\_\(k\_{\(\
\[GothicCapitalG]\^*\), \[GothicCapitalM]}\)\) + \[WeierstrassP]\_\(k\_{\
\[GothicCapitalA], \[GothicCapitalM], \[GothicCapitalM]}\))\) + \((\(-\
\[WeierstrassP]\_\(j\_{\(\[GothicCapitalG]\^*\), \[GothicCapitalM]}\)\) + \
\[WeierstrassP]\_\(j\_{\[GothicCapitalA], \[GothicCapitalM], \
\[GothicCapitalF]}\))\)\ \
\((\(-\[WeierstrassP]\_\(k\_{\(\[GothicCapitalG]\^*\), \[GothicCapitalM]}\)\) \
+ \[WeierstrassP]\_\(k\_{\[GothicCapitalA], \[GothicCapitalM], \
\[GothicCapitalM]}\))\))\) + 
      rec[{}, {j, 
            k}]\ \((\[GothicCapitalD]\_{j\_{\[GothicCapitalA], \
\[GothicCapitalM], \[GothicCapitalM]}, k\_{\[GothicCapitalA], \
\[GothicCapitalM], \[GothicCapitalM]}} + \[GothicCapitalD]\_{k\_{\
\[GothicCapitalA], \[GothicCapitalM], \[GothicCapitalM]}}\ \((\(-\
\[WeierstrassP]\_\(j\_{\(\[GothicCapitalG]\^*\), \[GothicCapitalM]}\)\) + \
\[WeierstrassP]\_\(j\_{\[GothicCapitalA], \[GothicCapitalM], \
\[GothicCapitalM]}\))\) + \[GothicCapitalD]\_{j\_{\[GothicCapitalA], \
\[GothicCapitalM], \[GothicCapitalM]}}\ \((\(-\[WeierstrassP]\_\(k\_{\(\
\[GothicCapitalG]\^*\), \[GothicCapitalM]}\)\) + \[WeierstrassP]\_\(k\_{\
\[GothicCapitalA], \[GothicCapitalM], \[GothicCapitalM]}\))\) + \((\(-\
\[WeierstrassP]\_\(j\_{\(\[GothicCapitalG]\^*\), \[GothicCapitalM]}\)\) + \
\[WeierstrassP]\_\(j\_{\[GothicCapitalA], \[GothicCapitalM], \
\[GothicCapitalM]}\))\)\ \
\((\(-\[WeierstrassP]\_\(k\_{\(\[GothicCapitalG]\^*\), \[GothicCapitalM]}\)\) \
+ \[WeierstrassP]\_\(k\_{\[GothicCapitalA], \[GothicCapitalM], \
\[GothicCapitalM]}\))\))\)\)], "Output",
  CellLabel->"Out[42]="]
}, Closed]],

Cell[TextData[{
  "To use subscripted notation, use the",
  Cell[BoxData[
      FormBox[
        ButtonBox[\(\(\ \)\(Notation\ \(\(Palette\)\(:\)\)\)\),
          ButtonData:>{
            FrontEnd`FileName[ {
              ParentDirectory[ 
                ParentDirectory[ ]], "AddOns", "ExtraPackages", "Utilities"}, 
              "NotationPalette.nb", CharacterEncoding -> "MacintoshRoman"], 
            None},
          ButtonStyle->"Hyperlink"], TraditionalForm]]]
}], "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[{
    RowBox[{
      RowBox[{"Notation", "[", 
        RowBox[{
          TagBox[\(mm\_x___\),
            NotationBoxTag,
            TagStyle->"NotationTemplateStyle"], " ", 
          "\[DoubleLongLeftRightArrow]", " ", 
          TagBox[\(mig[x___]\),
            NotationBoxTag,
            TagStyle->"NotationTemplateStyle"]}], "]"}], 
      ";"}], "\n", \(\[GothicCapitalD]\_{j\_{\[GothicCapitalJ], 1, \
\[GothicCapitalM], \[GothicCapitalM]}, k\_{\[GothicCapitalJ], 1, \
\[GothicCapitalM], \[GothicCapitalM]}} /. 
      Migration[{\[GothicCapitalZ], \[GothicCapitalJ]}, 
        mig, {1, 2} &]\)}], "Input",
  CellLabel->"In[97]:=  (19:34:56 on 3/12/01)"],

Cell[BoxData[
    \(mm\_\(1, 1\)\ \((\[GothicCapitalD]\_{j\_{\[GothicCapitalZ], 1, \
\[GothicCapitalM], \[GothicCapitalM]}, k\_{\[GothicCapitalZ], 1, \
\[GothicCapitalM], \[GothicCapitalM]}} + \[GothicCapitalD]\_{k\_{\
\[GothicCapitalZ], 1, \[GothicCapitalM], \[GothicCapitalM]}}\ \((\(-\
\[WeierstrassP]\_\(j\_{\[GothicCapitalJ], 1, \[GothicCapitalM], \
\[GothicCapitalM]}\)\) + \[WeierstrassP]\_\(j\_{\[GothicCapitalZ], 1, \
\[GothicCapitalM], \[GothicCapitalM]}\))\) + \[GothicCapitalD]\_{j\_{\
\[GothicCapitalZ], 1, \[GothicCapitalM], \[GothicCapitalM]}}\ \((\(-\
\[WeierstrassP]\_\(k\_{\[GothicCapitalJ], 1, \[GothicCapitalM], \
\[GothicCapitalM]}\)\) + \[WeierstrassP]\_\(k\_{\[GothicCapitalZ], 1, \
\[GothicCapitalM], \[GothicCapitalM]}\))\) + \((\(-\[WeierstrassP]\_\(j\_{\
\[GothicCapitalJ], 1, \[GothicCapitalM], \[GothicCapitalM]}\)\) + \
\[WeierstrassP]\_\(j\_{\[GothicCapitalZ], 1, \[GothicCapitalM], \
\[GothicCapitalM]}\))\)\ \((\(-\[WeierstrassP]\_\(k\_{\[GothicCapitalJ], 1, \
\[GothicCapitalM], \[GothicCapitalM]}\)\) + \[WeierstrassP]\_\(k\_{\
\[GothicCapitalZ], 1, \[GothicCapitalM], \[GothicCapitalM]}\))\))\) + 
      mm\_\(1, 2\)\ \((\[GothicCapitalD]\_{j\_{\[GothicCapitalZ], 2, \
\[GothicCapitalM], \[GothicCapitalM]}, k\_{\[GothicCapitalZ], 2, \
\[GothicCapitalM], \[GothicCapitalM]}} + \[GothicCapitalD]\_{k\_{\
\[GothicCapitalZ], 2, \[GothicCapitalM], \[GothicCapitalM]}}\ \((\(-\
\[WeierstrassP]\_\(j\_{\[GothicCapitalJ], 1, \[GothicCapitalM], \
\[GothicCapitalM]}\)\) + \[WeierstrassP]\_\(j\_{\[GothicCapitalZ], 2, \
\[GothicCapitalM], \[GothicCapitalM]}\))\) + \[GothicCapitalD]\_{j\_{\
\[GothicCapitalZ], 2, \[GothicCapitalM], \[GothicCapitalM]}}\ \((\(-\
\[WeierstrassP]\_\(k\_{\[GothicCapitalJ], 1, \[GothicCapitalM], \
\[GothicCapitalM]}\)\) + \[WeierstrassP]\_\(k\_{\[GothicCapitalZ], 2, \
\[GothicCapitalM], \[GothicCapitalM]}\))\) + \((\(-\[WeierstrassP]\_\(j\_{\
\[GothicCapitalJ], 1, \[GothicCapitalM], \[GothicCapitalM]}\)\) + \
\[WeierstrassP]\_\(j\_{\[GothicCapitalZ], 2, \[GothicCapitalM], \
\[GothicCapitalM]}\))\)\ \((\(-\[WeierstrassP]\_\(k\_{\[GothicCapitalJ], 1, \
\[GothicCapitalM], \[GothicCapitalM]}\)\) + \[WeierstrassP]\_\(k\_{\
\[GothicCapitalZ], 2, \[GothicCapitalM], \[GothicCapitalM]}\))\))\)\)], \
"Output",
  CellLabel->"Out[98]=  (19:34:57 on 3/12/01)"]
}, Open  ]],

Cell[TextData[{
  " ",
  Cell[BoxData[
      FormBox[GridBox[{
            {\(Migration[{c\_1, \[Ellipsis]}, \[CapitalOmega]]\), \(a\ rule\ \
which\ gives\ the\ linkage\ disequilibria\ in\ the\ juveniles, \ \
\[GothicCapitalJ], \ 
              in\ terms\ of\ disequilibria\ in\ the\ zygotes, \ \
\[GothicCapitalZ]; \ 
              migration\ rates\ \ \[CapitalMu]\_\(c\_1, \[Ellipsis], \
\[Alpha], \[Beta]\)\ depend\ on\ the\ c\_1, \[Ellipsis]\  . \ 
                  All\ linkage\ disequilibria\ must\ involve\ genes\ with\ \
the\ same\ c' s\)},
            {\(Migration[{\[GothicCapitalZ], \[GothicCapitalJ]}, 
                MigrationRate, {c\_1, \[Ellipsis]}, \[CapitalOmega]]\), \
\(specifies\ the\ stages\ and\ migration\ rate\ \(\(explicitly\)\(.\)\)\)},
            {\(\[CapitalMu]\_\(c\_1, \[Ellipsis], \[Alpha], \[Beta]\)\ or\ \
MigrationRate[
                  c\_1, \[Ellipsis], \[Alpha], \[Beta]]\), \(the\ probability\
\ of\ a\ movement\ from\ \[Beta]\ to\ \[Alpha]; \ 
              the\ rate\ depends\ on\ the\ c\_1, \[Ellipsis]\)}
            }], TraditionalForm]]]
}], "DefinitionBox",
  CellTags->"Context-dependent recombination"],

Cell["Here, the migration rates depend on sex:", "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\[GothicCapitalD]\_{j\_{\[GothicCapitalJ], a, \[GothicCapitalM], \
\[GothicCapitalM]}, k\_{\[GothicCapitalJ], a, \[GothicCapitalM], \
\[GothicCapitalM]}} /. Migration[{Sex}, {a, b} &]\)], "Input",
  CellLabel->"In[247]:=  (20:05:42 on 3/12/01)"],

Cell[BoxData[
    \(\[CapitalMu]\_\(\[GothicCapitalM], a, a\)\ \((\[GothicCapitalD]\_{j\_{\
\[GothicCapitalZ], a, \[GothicCapitalM], \[GothicCapitalM]}, k\_{\
\[GothicCapitalZ], a, \[GothicCapitalM], \[GothicCapitalM]}} + \
\[GothicCapitalD]\_{k\_{\[GothicCapitalZ], a, \[GothicCapitalM], \
\[GothicCapitalM]}}\ \((\(-\[WeierstrassP]\_\(j\_{\[GothicCapitalJ], a, \
\[GothicCapitalM], \[GothicCapitalM]}\)\) + \[WeierstrassP]\_\(j\_{\
\[GothicCapitalZ], a, \[GothicCapitalM], \[GothicCapitalM]}\))\) + \
\[GothicCapitalD]\_{j\_{\[GothicCapitalZ], a, \[GothicCapitalM], \
\[GothicCapitalM]}}\ \((\(-\[WeierstrassP]\_\(k\_{\[GothicCapitalJ], a, \
\[GothicCapitalM], \[GothicCapitalM]}\)\) + \[WeierstrassP]\_\(k\_{\
\[GothicCapitalZ], a, \[GothicCapitalM], \[GothicCapitalM]}\))\) + \((\(-\
\[WeierstrassP]\_\(j\_{\[GothicCapitalJ], a, \[GothicCapitalM], \
\[GothicCapitalM]}\)\) + \[WeierstrassP]\_\(j\_{\[GothicCapitalZ], a, \
\[GothicCapitalM], \[GothicCapitalM]}\))\)\ \((\(-\[WeierstrassP]\_\(k\_{\
\[GothicCapitalJ], a, \[GothicCapitalM], \[GothicCapitalM]}\)\) + \
\[WeierstrassP]\_\(k\_{\[GothicCapitalZ], a, \[GothicCapitalM], \
\[GothicCapitalM]}\))\))\) + \[CapitalMu]\_\(\[GothicCapitalM], a, b\)\ \((\
\[GothicCapitalD]\_{j\_{\[GothicCapitalZ], b, \[GothicCapitalM], \
\[GothicCapitalM]}, k\_{\[GothicCapitalZ], b, \[GothicCapitalM], \
\[GothicCapitalM]}} + \[GothicCapitalD]\_{k\_{\[GothicCapitalZ], b, \
\[GothicCapitalM], \[GothicCapitalM]}}\ \((\(-\[WeierstrassP]\_\(j\_{\
\[GothicCapitalJ], a, \[GothicCapitalM], \[GothicCapitalM]}\)\) + \
\[WeierstrassP]\_\(j\_{\[GothicCapitalZ], b, \[GothicCapitalM], \
\[GothicCapitalM]}\))\) + \[GothicCapitalD]\_{j\_{\[GothicCapitalZ], b, \
\[GothicCapitalM], \[GothicCapitalM]}}\ \((\(-\[WeierstrassP]\_\(k\_{\
\[GothicCapitalJ], a, \[GothicCapitalM], \[GothicCapitalM]}\)\) + \
\[WeierstrassP]\_\(k\_{\[GothicCapitalZ], b, \[GothicCapitalM], \
\[GothicCapitalM]}\))\) + \((\(-\[WeierstrassP]\_\(j\_{\[GothicCapitalJ], a, \
\[GothicCapitalM], \[GothicCapitalM]}\)\) + \[WeierstrassP]\_\(j\_{\
\[GothicCapitalZ], b, \[GothicCapitalM], \[GothicCapitalM]}\))\)\ \((\(-\
\[WeierstrassP]\_\(k\_{\[GothicCapitalJ], a, \[GothicCapitalM], \
\[GothicCapitalM]}\)\) + \[WeierstrassP]\_\(k\_{\[GothicCapitalZ], b, \
\[GothicCapitalM], \[GothicCapitalM]}\))\))\)\)], "Output",
  CellLabel->"Out[247]=  (20:05:42 on 3/12/01)"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(\[GothicM]\_\(j\_{\[GothicCapitalJ], a, \[GothicCapitalF], \
\[GothicCapitalM]}\) /. Migration[{Sex}, {a, b} &]\)], "Input",
  CellLabel->"In[248]:=  (20:06:11 on 3/12/01)"],

Cell[BoxData[
    \(\[GothicM]\_\(j\_{\[GothicCapitalZ], a, \[GothicCapitalF], \
\[GothicCapitalM]}\)\ \[CapitalMu]\_\(\[GothicCapitalF], a, a\) + \
\[GothicM]\_\(j\_{\[GothicCapitalZ], b, \[GothicCapitalF], \[GothicCapitalM]}\
\)\ \[CapitalMu]\_\(\[GothicCapitalF], a, b\)\)], "Output",
  CellLabel->"Out[248]=  (20:06:11 on 3/12/01)"]
}, Open  ]],

Cell["\<\
The associations must involve genes that share the same value for \
the specified components:\
\>", "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\[GothicCapitalD]\_{j\_{\[GothicCapitalJ], a, \[GothicCapitalM], \
\[GothicCapitalM]}, k\_{\[GothicCapitalJ], a, \[GothicCapitalF], \
\[GothicCapitalM]}} /. Migration[{Sex}, {a, b} &]\)], "Input",
  CellLabel->"In[250]:=  (6:57:32 on 3/13/01)"],

Cell[BoxData[
    \(Migration::"mix" \(\(:\)\(\ \)\) 
      "Mixed contexts in \!\(\[GothicCapitalD]\_\!\({j\_\({\[GothicCapitalJ], \
a, \[GothicCapitalM], \[GothicCapitalM]}\), k\_\({\[GothicCapitalJ], a, \
\[GothicCapitalF], \
\[GothicCapitalM]}\)}\)\)/.Migration[\!\({\[GothicCapitalZ], \
\[GothicCapitalJ]}\),\!\(MigrationRate\),\!\({Sex}\)]: the relevant \
components \!\({Sex}\) must be the same for all genes."\)], "Message",
  CellLabel->"From In[250]:=  (6:57:32 on 3/13/01)"],

Cell[BoxData[
    \(\[GothicCapitalD]\_{j\_{\[GothicCapitalJ], a, \[GothicCapitalM], \
\[GothicCapitalM]}, k\_{\[GothicCapitalJ], a, \[GothicCapitalF], \
\[GothicCapitalM]}}\)], "Output",
  CellLabel->"Out[250]=  (6:57:33 on 3/13/01)"]
}, Open  ]],

Cell[TextData[{
  StyleBox["Note: ",
    FontWeight->"Bold"],
  " It is not obvious how to model sexual selection and migration.  \
Associations can be defined for mixtures of gametes from a mated pair, which \
allows ",
  ButtonBox["sexual selection",
    ButtonData:>{"Sexual selection", None},
    ButtonStyle->"AddOnsLink"],
  " to be modelled;  ",
  ButtonBox["Recombination[]",
    ButtonData:>{"Recombination", "Sexual selection"},
    ButtonStyle->"AddOnsLink"],
  " allows for such mixed associations.  As the example above shows, mixed \
associations are not allowed with Migration[].  However, they should not be \
needed, provided that haploid or diploid individuals move independently. ",
  ButtonBox["RandomUnion[]",
    ButtonData:>{"Random union", "Random union of zygotes"},
    ButtonStyle->"AddOnsLink"],
  " can be used to separate the two diploids of a mated pair such that \
Migration[] can be applied separately to each individual."
}], "Text",
  CellTags->"Sexual selection"],

Cell[TextData[{
  " ",
  Cell[BoxData[
      FormBox[GridBox[{
            {\(Migration[\[DoubleStruckCapitalM], \[CapitalOmega]]\), \
\(allows\ for\ a\ dependence\ of\ migration\ rate\ on\ the\ set\ of\ genes\ \
\[DoubleStruckCapitalM]\)},
            {\(Migration[{\[GothicCapitalA], \(\[GothicCapitalG]\^*\)}, 
                MigrationRate, {c\_1, \[Ellipsis]}, \
\[DoubleStruckCapitalM]]\), \(specifies\ the\ stages\ and\ migration\ rate\ \
\(\(explicitly\)\(.\)\)\)},
            {\(\[CapitalMu]\_\(\[DoubleStruckCapitalR], \[Alpha], \[Beta]\)\ \
or\ MigrationRate[\[DoubleStruckCapitalM], \[Alpha], \[Beta]]\), \(is\ the\ \
dependence\ of\ the\ migration\ rate\ on\ the\ set\ of\ loci\ \
\[DoubleStruckCapitalM]\)},
            {\(\[DoubleStruckCapitalM]\_\(\(c\_1\) \[Ellipsis]\)\ or\ \
MigrationSet[\(c\_1\) \[Ellipsis]]\), \(is\ the\ set\ of\ genes - in - 
                context\ that\ may\ affect\ migration\ rates\)}
            }], TraditionalForm]]]
}], "DefinitionBox",
  CellTags->{"Genotype-dependent recombination", "RecombinationSet"}],

Cell["\<\
Migration rates can depend on genotype, in the same way as does \
fitness.\
\>", "Text"],

Cell[TextData[{
  "Note:  ",
  StyleBox["Genotype-dependent migration is not yet implemented, but will \
follow the same conventions as for selection coefficients etc.",
    FontWeight->"Plain"]
}], "Text",
  FontWeight->"Bold"]
}, Open  ]]
}, Open  ]]
},
FrontEndVersion->"4.0 for Macintosh",
ScreenRectangle->{{0, 1024}, {0, 748}},
WindowSize->{793, 700},
WindowMargins->{{2, Automatic}, {Automatic, 0}},
Visible->True,
InputAliases->{"notation"->RowBox[ {"Notation", "[", 
        RowBox[ {
          TagBox[ 
          "\[Placeholder]", NotationBoxTag, TagStyle -> 
            "NotationTemplateStyle"], " ", "\[DoubleLongLeftRightArrow]", " ",
           
          TagBox[ 
          "\[Placeholder]", NotationBoxTag, TagStyle -> 
            "NotationTemplateStyle"]}], "]"}], 
    "notation>"->RowBox[ {"Notation", "[", 
        RowBox[ {
          TagBox[ 
          "\[Placeholder]", NotationBoxTag, TagStyle -> 
            "NotationTemplateStyle"], " ", "\[DoubleLongRightArrow]", " ", 
          TagBox[ 
          "\[Placeholder]", NotationBoxTag, TagStyle -> 
            "NotationTemplateStyle"]}], "]"}], 
    "notation<"->RowBox[ {"Notation", "[", 
        RowBox[ {
          TagBox[ 
          "\[Placeholder]", NotationBoxTag, TagStyle -> 
            "NotationTemplateStyle"], " ", "\[DoubleLongLeftArrow]", " ", 
          TagBox[ 
          "\[Placeholder]", NotationBoxTag, TagStyle -> 
            "NotationTemplateStyle"]}], "]"}], 
    "symb"->RowBox[ {"Symbolize", "[", 
        TagBox[ 
        "\[Placeholder]", NotationBoxTag, TagStyle -> 
          "NotationTemplateStyle"], "]"}], 
    "infixnotation"->RowBox[ {"InfixNotation", "[", 
        RowBox[ {
          TagBox[ 
          "\[Placeholder]", NotationBoxTag, TagStyle -> 
            "NotationTemplateStyle"], ",", "\[Placeholder]"}], "]"}], 
    "addia"->RowBox[ {"AddInputAlias", "[", 
        RowBox[ {
          TagBox[ 
          "\[Placeholder]", NotationBoxTag, TagStyle -> 
            "NotationTemplateStyle"], ",", "\[Placeholder]"}], "]"}], 
    "pattwraper"->TagBox[ 
      "\[Placeholder]", NotationPatternTag, TagStyle -> 
        "NotationPatternWrapperStyle"], 
    "madeboxeswraper"->TagBox[ 
      "\[Placeholder]", NotationMadeBoxesTag, TagStyle -> 
        "NotationMadeBoxesWrapperStyle"]},
StyleDefinitions -> "HelpBrowser.nb",
MacintoshSystemPageSetup->"\<\
00h0001804P000000b02<?oaonl3>@91H`85N0?N0@00005X0FP000003j0:l001
0@00I00100000@0200000BL?00400000000000000000010000000000000@0?ne
oj/@7@]500P1000000000000000001T1\>"
]


(***********************************************************************
Cached data follows.  If you edit this Notebook file directly, not using
Mathematica, you must remove the line containing CacheID at the top of 
the file.  The cache data will then be recreated when you save this file 
from within Mathematica.
***********************************************************************)

(*CellTagsOutline
CellTagsIndex->{
  "Setting up"->{
    Cell[2429, 68, 76, 1, 24, "SubsubsectionIcon",
      CellTags->"Setting up"]},
  "Migrate"->{
    Cell[3225, 91, 522, 13, 54, "DefinitionBox",
      CellTags->"Migrate"]},
  "Recombination"->{
    Cell[8710, 239, 1008, 21, 104, "DefinitionBox",
      CellTags->{"Recombination", "RecombinationRate"}]},
  "RecombinationRate"->{
    Cell[8710, 239, 1008, 21, 104, "DefinitionBox",
      CellTags->{"Recombination", "RecombinationRate"}]},
  "Context-dependent recombination"->{
    Cell[25054, 599, 1154, 23, 106, "DefinitionBox",
      CellTags->"Context-dependent recombination"]},
  "Sexual selection"->{
    Cell[30673, 716, 999, 22, 68, "Text",
      CellTags->"Sexual selection"]},
  "Genotype-dependent recombination"->{
    Cell[31675, 740, 1056, 20, 98, "DefinitionBox",
      CellTags->{"Genotype-dependent recombination", "RecombinationSet"}]},
  "RecombinationSet"->{
    Cell[31675, 740, 1056, 20, 98, "DefinitionBox",
      CellTags->{"Genotype-dependent recombination", "RecombinationSet"}]}
  }
*)

(*CellTagsIndex
CellTagsIndex->{
  {"Setting up", 35819, 844},
  {"Migrate", 35917, 847},
  {"Recombination", 36016, 850},
  {"RecombinationRate", 36151, 853},
  {"Context-dependent recombination", 36300, 856},
  {"Sexual selection", 36430, 859},
  {"Genotype-dependent recombination", 36550, 862},
  {"RecombinationSet", 36702, 865}
  }
*)

(*NotebookFileOutline
Notebook[{

Cell[CellGroupData[{
Cell[1739, 51, 35, 0, 36, "SubsectionIcon"],
Cell[1777, 53, 627, 11, 51, "Text"],

Cell[CellGroupData[{
Cell[2429, 68, 76, 1, 24, "SubsubsectionIcon",
  CellTags->"Setting up"],
Cell[2508, 71, 46, 0, 28, "MathCaption"],
Cell[2557, 73, 112, 2, 27, "Input"],
Cell[2672, 77, 60, 0, 28, "MathCaption"],
Cell[2735, 79, 487, 10, 87, "Input"],
Cell[3225, 91, 522, 13, 54, "DefinitionBox",
  CellTags->"Migrate"],
Cell[3750, 106, 207, 5, 28, "MathCaption"],

Cell[CellGroupData[{
Cell[3982, 115, 323, 5, 28, "Input"],
Cell[4308, 122, 294, 5, 21, "Output"]
}, Open  ]],
Cell[4617, 130, 103, 3, 22, "Text"],
Cell[4723, 135, 195, 6, 24, "Text"],
Cell[4921, 143, 142, 3, 22, "Text"],
Cell[5066, 148, 67, 0, 28, "MathCaption"],

Cell[CellGroupData[{
Cell[5158, 152, 382, 6, 43, "Input"],
Cell[5543, 160, 235, 4, 21, "Output"]
}, Open  ]],
Cell[5793, 167, 148, 3, 28, "MathCaption"],

Cell[CellGroupData[{
Cell[5966, 174, 212, 3, 33, "Input"],
Cell[6181, 179, 1173, 17, 48, "Output"]
}, Open  ]],
Cell[7369, 199, 344, 9, 40, "Text"],
Cell[7716, 210, 635, 15, 36, "Text"],
Cell[8354, 227, 353, 10, 24, "Text"],
Cell[8710, 239, 1008, 21, 104, "DefinitionBox",
  CellTags->{"Recombination", "RecombinationRate"}],
Cell[9721, 262, 177, 4, 22, "Text"],
Cell[9901, 268, 97, 3, 28, "MathCaption"],

Cell[CellGroupData[{
Cell[10023, 275, 137, 2, 31, "Input"],
Cell[10163, 279, 249, 4, 24, "Output"]
}, Open  ]],
Cell[10427, 286, 221, 6, 28, "MathCaption"],

Cell[CellGroupData[{
Cell[10673, 296, 257, 4, 33, "Input"],
Cell[10933, 302, 2281, 33, 94, "Output"]
}, Open  ]],
Cell[13229, 338, 208, 4, 36, "Text"],
Cell[13440, 344, 101, 3, 28, "MathCaption"],

Cell[CellGroupData[{
Cell[13566, 351, 257, 4, 33, "Input"],
Cell[13826, 357, 235, 4, 26, "Output"]
}, Open  ]],
Cell[14076, 364, 113, 3, 28, "MathCaption"],

Cell[CellGroupData[{
Cell[14214, 371, 155, 2, 31, "Input"],
Cell[14372, 375, 357, 5, 24, "Output"]
}, Open  ]],
Cell[14744, 383, 102, 3, 28, "MathCaption"],

Cell[CellGroupData[{
Cell[14871, 390, 243, 4, 46, "Input"],
Cell[15117, 396, 652, 9, 41, "Output"]
}, Open  ]],
Cell[15784, 408, 125, 3, 22, "Text"],
Cell[15912, 413, 308, 7, 28, "MathCaption"],

Cell[CellGroupData[{
Cell[16245, 424, 128, 2, 28, "Input"],
Cell[16376, 428, 228, 6, 20, "Output"]
}, Open  ]],
Cell[16619, 437, 316, 8, 22, "Text"],
Cell[16938, 447, 58, 0, 28, "MathCaption"],

Cell[CellGroupData[{
Cell[17021, 451, 265, 5, 33, "Input"],
Cell[17289, 458, 4227, 67, 70, "Output"]
}, Closed]],
Cell[21531, 528, 491, 12, 18, "MathCaption"],

Cell[CellGroupData[{
Cell[22047, 544, 675, 16, 49, "Input"],
Cell[22725, 562, 2314, 34, 96, "Output"]
}, Open  ]],
Cell[25054, 599, 1154, 23, 106, "DefinitionBox",
  CellTags->"Context-dependent recombination"],
Cell[26211, 624, 63, 0, 28, "MathCaption"],

Cell[CellGroupData[{
Cell[26299, 628, 265, 4, 33, "Input"],
Cell[26567, 634, 2368, 34, 96, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[28972, 673, 193, 3, 31, "Input"],
Cell[29168, 678, 336, 5, 24, "Output"]
}, Open  ]],
Cell[29519, 686, 124, 3, 28, "MathCaption"],

Cell[CellGroupData[{
Cell[29668, 693, 264, 4, 33, "Input"],
Cell[29935, 699, 485, 8, 38, "Message"],
Cell[30423, 709, 235, 4, 26, "Output"]
}, Open  ]],
Cell[30673, 716, 999, 22, 68, "Text",
  CellTags->"Sexual selection"],
Cell[31675, 740, 1056, 20, 98, "DefinitionBox",
  CellTags->{"Genotype-dependent recombination", "RecombinationSet"}],
Cell[32734, 762, 98, 3, 22, "Text"],
Cell[32835, 767, 228, 6, 24, "Text"]
}, Open  ]]
}, Open  ]]
}
]
*)




(***********************************************************************
End of Mathematica Notebook file.
***********************************************************************)

