(***********************************************************************

                    Mathematica-Compatible Notebook

This notebook can be used on any computer system with Mathematica 4.0,
MathReader 4.0, or any compatible application. The data for the notebook 
starts with the line containing stars above.

To get the notebook into a Mathematica-compatible application, do one of 
the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing the 
word CacheID, otherwise Mathematica-compatible applications may try to 
use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
***********************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[    510655,      13332]*)
(*NotebookOutlinePosition[    567508,      15069]*)
(*  CellTagsIndexPosition[    561045,      14911]*)
(*WindowFrame->Normal*)



Notebook[{

Cell[CellGroupData[{
Cell["General models of multilocus evolution  ", "Title",
  CellMargins->{{18.1875, 24.375}, {Inherited, Inherited}}],

Cell[TextData[{
  " Version of 3-IX-01.  ",
  StyleBox["Draft",
    FontSlant->"Italic"]
}], "Text"],

Cell[CellGroupData[{

Cell[TextData[StyleBox["{Title page stuff}",
  FontSize->9]], "Subtitle",
  CellOpen->False],

Cell[TextData[{
  "MARK KIRKPATRICK",
  Cell[BoxData[
      \(TraditionalForm\`\^1\)]],
  ", TOBY JOHNSON",
  Cell[BoxData[
      \(TraditionalForm\`\^\(2, 3\)\)]],
  " and NICK BARTON",
  Cell[BoxData[
      \(TraditionalForm\`\^2\)]]
}], "Text",
  CellMargins->{{18.1875, 24.375}, {Inherited, Inherited}}],

Cell["\<\

\
\>", "Text",
  CellMargins->{{18.1875, 24.375}, {Inherited, Inherited}}],

Cell[TextData[{
  Cell[BoxData[
      \(TraditionalForm\`\^1\)]],
  " Section of Integrative Biology C0930, University of Texas, Austin, Texas \
78712  USA\n",
  Cell[BoxData[
      \(TraditionalForm\`\^2\)]],
  " Institute of Cell, Animal and Population Biology, University of \
Edinburgh, Scotland EH9 3JT, UK\n",
  Cell[BoxData[
      \(TraditionalForm\`\^3\)]],
  "  Present address: Department of Zoology, University of British Columbia, \
6270 University Blvd., Vancouver, B.C. V6T 1Z4,  Canada\n\nContact \
information for first author:  \n\temail:  kirkp@mail.utexas.edu\n\t\
telephone:  (512) 471-5996, -5858\n\tfax:  (512) 471-3768\n\nRunning head:  \
General multilocus models"
}], "Text",
  CellMargins->{{18.1875, 24.375}, {Inherited, Inherited}}]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Abstract ",
  FontWeight->"Bold"]], "Subtitle",
  CellMargins->{{18.1875, 24.375}, {Inherited, Inherited}},
  PageBreakAbove->True,
  CellTags->"Abstract"],

Cell[TextData[{
  "\tBarton and Turelli (",
  ButtonBox["1991",
    ButtonData:>"Barton & Turelli 1991",
    ButtonStyle->"Hyperlink"],
  ") developed recursions to describe the evolution of multilocus systems \
under arbitrary forms of selection.  This paper generalizes their approach to \
allow for arbitrary modes of inheritance, including diploidy, polyploidy, sex \
linkage, ",
  StyleBox["cytoplasmic",
    FontColor->RGBColor[1, 0, 0]],
  " transmission, and genomic imprinting.  The model is also generalized to \
allow for other deterministic evolutionary forces, including migration and \
mutation.  Exact recursions that fully describe the state of the population \
are presented; these are implemented in a computer algebra package.  Despite \
the generality of the framework, the evolutionary dynamics can be described \
exactly by just two equations.  These recursions can be further simplified \
using a \"quasi-linkage equilibrium\" (QLE) approximation.  We illustrate the \
methods by finding the effects of natural selection, sexual selection, \
mutation, and migration on the genetic composition of a population.  "
}], "Text",
  CellMargins->{{18.1875, 24.375}, {Inherited, Inherited}}]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[StyleBox["1. Introduction",
  FontWeight->"Bold"]], "Subtitle",
  CellMargins->{{18.1875, 24.375}, {Inherited, Inherited}},
  PageBreakAbove->True,
  CellTags->"Introduction"],

Cell[TextData[{
  "\tEvolution involves simultaneous changes at many genetic loci.  Modeling \
these changes is difficult because associations between alleles at different \
loci (\"linkage disequilibria\") cause the effects of selection acting on one \
locus to spill over onto other loci, generating indirect selection (see Ewens \
",
  ButtonBox["1979",
    ButtonData:>"Ewens 1979",
    ButtonStyle->"Hyperlink"],
  " p. 195).  These indirect effects influence the evolution of genes that \
are themselves under direct selection, altering the course of adaptation \
(e.g. Hill and Robertson ",
  ButtonBox["1966",
    ButtonData:>"Hill & Robertson 1966",
    ButtonStyle->"Hyperlink"],
  ";  Barton, ",
  ButtonBox["1983",
    ButtonData:>"Barton 1983",
    ButtonStyle->"Hyperlink"],
  ").  Moreover, indirect selection determines the fate of modifier genes \
that have important effects even if they themselves are free of direct \
selection.  Examples of such modifiers include female mating preference genes \
(Fisher ",
  ButtonBox["1930",
    ButtonData:>"Fisher 1958",
    ButtonStyle->"Hyperlink"],
  "), modifiers of recombination (Otto and Michalakis ",
  ButtonBox["1998",
    ButtonData:>"Otto & Michalakis 1998",
    ButtonStyle->"Hyperlink"],
  "), and modifiers of the mutation rate (Dawson ",
  ButtonBox["1999, ",
    ButtonData:>"Dawson 1999",
    ButtonStyle->"Hyperlink"],
  "Sniegowski et al. ",
  ButtonBox["2000",
    ButtonData:>"Sniegowski et al 2000",
    ButtonStyle->"Hyperlink"],
  ")."
}], "Text",
  CellMargins->{{18.1875, 24.375}, {Inherited, Inherited}}],

Cell["\<\
\tThe most obvious approach to modeling multilocus systems is \
simply to follow the frequencies of all possible genotypes.  There are three \
basic drawbacks here.  First, the number of genotypes grows exponentially \
with the number of loci, rapidly overwhelming both analytical and simulation \
approaches when there are even a modest number of genes.  Second, the \
quantities that are often of most interest, such as allele frequencies and \
mean phenotypes, are obscured by working with genotypes.  Third, \
approximations for the dynamic equations appear more naturally when we work \
with quantities other than genotype frequencies.\
\>", "Text",
  CellMargins->{{18.1875, 24.375}, {Inherited, Inherited}}],

Cell[TextData[{
  "\tSeveral approximate approaches have been developed to deal with these \
problems. 1) The infinitesimal model assumes that very many genes influence \
the phenotype, such that each allele has an infinitesimal effect (Fisher ",
  ButtonBox["1918",
    ButtonData:>"Fisher 1918",
    ButtonStyle->"Hyperlink"],
  ", Bulmer ",
  ButtonBox["1980",
    ButtonData:>"Bulmer 1980",
    ButtonStyle->"Hyperlink"],
  ", Turelli and Barton ",
  ButtonBox["1994",
    ButtonData:>"Turelli & Barton 1994",
    ButtonStyle->"Hyperlink"],
  ").  In this limit, the genetic variance contributed by allelic variation \
at each locus is constant, and evolutionary change is due solely to changes \
in associations among loci.  This is an accurate and general approximation \
for short term change under strong ",
  StyleBox["selection,",
    FontColor->RGBColor[1, 0, 0]],
  " but cannot describe changes in allele frequencies over the longer term.  \
2) The hypergeometric model (Kondrashov, ",
  ButtonBox["1984",
    ButtonData:>"Kondrashov 1984",
    ButtonStyle->"Hyperlink"],
  ", Barton, ",
  ButtonBox["1992",
    ButtonData:>"Barton 1992",
    ButtonStyle->"Hyperlink"],
  ", Doebeli ",
  ButtonBox["1996",
    ButtonData:>"Doebeli 1996",
    ButtonStyle->"Hyperlink"],
  ") also assumes that loci are unlinked and have equal effects, but allows \
the number of loci to be finite.  However, the stability of solutions to this \
model is limited to certain selection regimes (Shpak and Kondrashov ",
  ButtonBox["1999",
    ButtonData:>"Shpak & Kondrashov 1999",
    ButtonStyle->"Hyperlink"],
  ", Barton and Shpak ",
  ButtonBox["2000",
    ButtonData:>"Barton & Shpak 2000",
    ButtonStyle->"Hyperlink"],
  "), which do not include many scenarios of evolutionary interest, such as \
stabilising selection.  3) Another method introduced by Fisher (",
  ButtonBox["1953",
    ButtonData:>"Fisher 1953",
    ButtonStyle->"Hyperlink"],
  ") models a population by following the inheritance of \"junctions\" \
between chromosome regions with different ancestries.  This approach is well \
suited to describing the ancestry of samples of neutral genomes (Hudson ",
  ButtonBox["1990",
    ButtonData:>"Hudson 1990",
    ButtonStyle->"Hyperlink"],
  "), and models of hybridisation, in which selection can be approximated as \
acting on the proportions of genetic material derived from different source \
populations (Baird ",
  ButtonBox["1995",
    ButtonData:>"Baird 1995",
    ButtonStyle->"Hyperlink"],
  ").  However, it is again intractable over long timescales, since the \
number of junctions increases geometrically.  4) Price (",
  ButtonBox["1970",
    ButtonData:>"Price 1970",
    ButtonStyle->"Hyperlink"],
  ") gave an exact and completely general equation, in which the average \
change in a trait is precisely equal to its covariance with relative fitness, \
plus the change due to transmission.  This takes the classical approach of \
quantitative genetics, by following only the phenotype and disregarding the \
(usually unknown) genetics which underlies it.  5) There have been several \
independent developments which ",
  StyleBox["extend Price's",
    FontColor->RGBColor[1, 0, 0]],
  " approach, by following the mean, variance and higher moments of the \
phenotypic distribution (e.g. Barton and Turelli ",
  ButtonBox["1987",
    ButtonData:>"Barton & Turelli 1987",
    ButtonStyle->"Hyperlink"],
  ", Burger ",
  ButtonBox["1991",
    ButtonData:>"Burger 1991",
    ButtonStyle->"Hyperlink"],
  ", Shapiro et al. ",
  ButtonBox["1994",
    ButtonData:>"Shapiro et al 1994",
    ButtonStyle->"Hyperlink"],
  ").  However, each moment depends on higher moments, and approximations are \
required to give a closed set of dynamical equations. Such approximations are \
only accurate under restricted circumstances.  ",
  StyleBox["In",
    FontColor->RGBColor[1, 0, 0]],
  " contrast with thermodynamics, where molecular motions can be averaged out \
over macroscopic scales, genetic details do influence  phenotypic evolution."
}], "Text",
  CellMargins->{{18.1875, 24.375}, {Inherited, Inherited}}],

Cell[TextData[{
  "\tBarton and Turelli (",
  ButtonBox["1991",
    ButtonData:>"Barton & Turelli 1991",
    ButtonStyle->"Hyperlink"],
  ", hereafter ",
  ButtonBox["BT91",
    ButtonData:>"Barton & Turelli 1991",
    ButtonStyle->"Hyperlink"],
  ") developed the quantitative genetic approach to provide a complete \
description of multilocus systems, with no restrictions on the relation \
between genotype and phenotype.   This developed from work by Barton (",
  ButtonBox["1983",
    ButtonData:>"Barton 1983",
    ButtonStyle->"Hyperlink"],
  ", ",
  ButtonBox["1986",
    ButtonData:>"Barton 1986",
    ButtonStyle->"Hyperlink"],
  "), Barton and Turelli (",
  ButtonBox["1987",
    ButtonData:>"Barton & Turelli 1987",
    ButtonStyle->"Hyperlink"],
  ") and Turelli and Barton (",
  ButtonBox["1990",
    ButtonData:>"Turelli & Barton 1990",
    ButtonStyle->"Hyperlink"],
  ");  it was paralleled by independent work of Christiansen (",
  ButtonBox["1987",
    ButtonData:>"Christiansen 1987",
    ButtonStyle->"Hyperlink"],
  ") and Burger (",
  ButtonBox["1991",
    ButtonData:>"Burger 1991",
    ButtonStyle->"Hyperlink"],
  ").  Barton and Turelli's (",
  ButtonBox["1991",
    ButtonData:>"Barton & Turelli 1991",
    ButtonStyle->"Hyperlink"],
  ") approach contains three key elements.  First, it gives a general \
representation of populations with multiple alleles and multiple loci.  \
Second, it derives exact recursions for the effects of selection and \
recombination on allele frequencies and the associations between alleles at \
different loci.  Third, it finds a 'quasi-linkage equilibrium' approximation \
(QLE) that allows the recursion equations to be greatly simplified under some \
conditions."
}], "Text",
  CellMargins->{{18.1875, 24.375}, {Inherited, Inherited}}],

Cell[TextData[{
  "\tAlthough the notation and framework of ",
  ButtonBox["BT91",
    ButtonData:>"Barton & Turelli 1991",
    ButtonStyle->"Hyperlink"],
  " are general in many respects, the methods it develops are restricted to \
certain forms of inheritance.  Their notation can describe autosomal genes in \
randomly mating diploids and in non-randomly mating haploids.  It cannot, \
however, accomodate such complications as non-random mating in diploids, \
polyploidy, sex linkage, genome imprinting, and cytoplasmic inheritance.  The \
main aim of this paper is to show how the ",
  ButtonBox["BT91",
    ButtonData:>"Barton & Turelli 1991",
    ButtonStyle->"Hyperlink"],
  " approach can be generalized to include these cases and in fact to ",
  StyleBox["include",
    FontColor->RGBColor[1, 0, 0]],
  " all forms of inheritance.  We also show how migration and mutation can be \
described in the same framework."
}], "Text",
  CellMargins->{{18.1875, 24.375}, {Inherited, Inherited}}],

Cell["\<\
\tThis paper begins by presenting a notation that is sufficiently \
flexible to accomodate a variety of evolutionary forces and modes of \
inheritance.  Next, we derive general recursion equations that describe how \
the genetic state of a population changes over the course of a generation.  \
The following section shows how the selection and transmission coefficients \
that appear in the recursions are calculated for any particular situation.  \
We then present the \"quasi-linkage equilibrium\" (QLE) approximation for the \
recursions, which greatly simplifies the equations.  The QLE approach is \
illustrated with examples in following section.  \
\>", "Text",
  CellMargins->{{18.1875, 24.375}, {Inherited, Inherited}}],

Cell[TextData[{
  "\tThe notation and recursions set out in this paper have been implemented \
in a set of ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " packages (Wolfram, ",
  ButtonBox["1996",
    ButtonData:>"Wolfram 1996",
    ButtonStyle->"Hyperlink"],
  "), which are available from  \
http://helios.bto.ed.ac.uk/evolgen/index.html.  These packages use the \
general notation, in essentially the same form as in this paper, and apply \
this notation to define functions appropriate for selection and recombination \
in diploids.  Appendix 4 gives examples that show how the recursions can be \
computed automatically to give algebraic expressions for genetic changes in \
an arbitrary set of loci."
}], "Text",
  CellMargins->{{18.1875, 24.375}, {Inherited, Inherited}}]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[StyleBox["2. A General Notation for Multilocus Evolution",
  FontWeight->"Bold"]], "Subtitle",
  CellMargins->{{18.1875, 24.375}, {Inherited, Inherited}},
  PageBreakAbove->True,
  CellTags->"A general notation"],

Cell["\<\
\tHere we lay out a notation that is sufficiently flexible to \
account for the different modes of inheritance and evolutionary forces that \
motivate the model.  The section starts by introducing the concepts on which \
the notation relies, shows how the notation can describe genotypes and \
populations, and then describes the relation between phenotypes and \
genotypes.\
\>", "Text",
  CellMargins->{{18.1875, 24.375}, {Inherited, Inherited}}],

Cell[CellGroupData[{

Cell["(i) Contexts and Positions, Selection and Transmission", "Subsubtitle",
  CellMargins->{{18.1875, 24.375}, {Inherited, Inherited}},
  CellTags->"Contexts and positions"],

Cell[TextData[{
  "\tIt is useful to begin by defining the word \"gene\" to mean a particular \
copy of a nonrecombining sequence at some locus in some individual.  Thus two \
different genes may or may not reside at the same locus, and if they do they \
may or may not be in the same allelic state.  A gene at a given locus can be \
found in any of a number of situations:  it might be carried by a male or a \
female, it might have been inherited from a mother or a father, it might \
reside in one deme or another.  We refer to this collection of qualities as \
the gene's ",
  StyleBox["context",
    FontSlant->"Italic"],
  ".  Context is a key concept in our notation, and it is important in two \
ways.  First, it determines how evolutionary forces act on the gene.  A \
selection coefficient, for example, may  depend on whether the gene is \
carried by a male or a female.  If there is genomic imprinting, then the \
selection coefficient will also depend on the sex of the individual from \
which the gene was inherited.  Second, a gene's context affects how it is \
transmitted.  Consider two autosomal loci in a diploid individual.  If there \
is no recombination between the loci during meiosis, the resulting gamete \
will carry copies of the genes that both descended from either the \
individual's mother or father; with recombination, the gamete will carry one \
gene from the individual's mother and one from the father."
}], "Text",
  CellMargins->{{18.1875, 24.375}, {Inherited, Inherited}}],

Cell["\<\
\tThe information we need to specify a gene's context varies \
between models.  In a model of a spatially-structured population, the context \
will include geographical information.  Likewise, in a life history model the \
context specifies the life stage of the individual carrying it.  The context \
will include the sex of the individual carrying a gene in a model with two \
sexes, but not in a model of a hermaphroditic population.\
\>", "Text",
  CellMargins->{{18.1875, 24.375}, {Inherited, Inherited}}],

Cell[TextData[{
  "\tLoci are referred to by lower case italic letters.  The context is \
written in a series of subscripts whose elements carry the relevant \
information.  In this paper we use the convention that for diploid \
populations with two sexes, the first subscript of the context gives the sex \
of the individual carrying the gene, ",
  StyleBox["which",
    FontColor->RGBColor[1, 0, 0]],
  " we call its \"sex-of-carrier\".  The second subscript gives the sex of \
the parent from which it was inherited, its \"sex-of-origin\".  Sexes are \
denoted by \"m\"  for male and  \"f\"  for female.  For example, genes at a \
diploid locus ",
  StyleBox["i",
    FontSlant->"Italic"],
  " that are carried by females and that descended from a male (the female's \
father) are referred to as ",
  Cell[BoxData[
      FormBox[
        SubscriptBox["i", 
          RowBox[{
            StyleBox["f",
              FontSlant->"Plain"], " ", 
            StyleBox["m",
              FontSlant->"Plain"]}]], TraditionalForm]]],
  ".  There are then four possible contexts for genes at this locus.  \
Contexts in hermaphrodites would not include the sex-of-carrier (since all \
individuals are the same sex), but would include the sex-of-origin to denote \
whether the gene was transmitted through an egg or a sperm.  One would \
account for more than two sexes (as when modeling a plant population with \
tristyly) by simply allowing the subscripts to take more than two possible \
values.  Subscripts can be added to denote other information, such as the \
deme or the family in which a gene resides."
}], "Text",
  CellMargins->{{18.1875, 24.375}, {Inherited, Inherited}}],

Cell[TextData[{
  "\tWe use the term ",
  StyleBox["position",
    FontSlant->"Italic"],
  " to refer to a particular locus in a particular context.  An example of a \
position is the place in the genomes of females where genes inherited from \
males (their fathers) at locus ",
  StyleBox["i",
    FontSlant->"Italic"],
  " reside.",
  "  Positions, like loci, are defined independent of the allelic states of \
the genes that reside there.  With ",
  StyleBox["n",
    FontSlant->"Italic"],
  " diploid loci in a dioecious population, there are 4",
  StyleBox["n",
    FontSlant->"Italic"],
  " positions that genes occupy (",
  StyleBox["n",
    FontSlant->"Italic"],
  " loci \[Times] two sexes-of-carrier  \[Times] two sexes-of-origin).  \
Doublestruck lowercase letters refer to single positions, for example \
\[DoubleStruckI]  =  ",
  Cell[BoxData[
      FormBox[
        SubscriptBox["i", 
          RowBox[{
            StyleBox["f",
              FontSlant->"Plain"], " ", 
            StyleBox["m",
              FontSlant->"Plain"]}]], TraditionalForm]]],
  ".  Doublestruck upper case letters refer to sets of positions, e.g. \
\[DoubleStruckCapitalA] = {\[DoubleStruckI], \[DoubleStruckJ]}.  A genome, \
denoted \[DoubleStruckCapitalG], is the set of all positions in an \
individual.  With a single diploid locus ",
  StyleBox["i",
    FontSlant->"Italic"],
  ", for example, the genome for a male is \[DoubleStruckCapitalG] = ",
  Cell[BoxData[
      FormBox[
        RowBox[{"{", 
          RowBox[{
            SubscriptBox["i", 
              StyleBox[\(m\ m\),
                FontSlant->"Plain"]], ",", " ", 
            SubscriptBox["i", 
              StyleBox[\(m\ f\),
                FontSlant->"Plain"]]}], "}"}], TraditionalForm]]],
  ", and for a female it is  \[DoubleStruckCapitalG] = ",
  Cell[BoxData[
      FormBox[
        RowBox[{"{", " ", 
          RowBox[{
            SubscriptBox["i", 
              StyleBox[\(f\ m\),
                FontSlant->"Plain"]], ",", " ", 
            SubscriptBox["i", 
              StyleBox[\(f\ f\),
                FontSlant->"Plain"]]}], "}"}], TraditionalForm]]],
  ".  The notation is summarized in Table 1."
}], "Text",
  CellMargins->{{18.1875, 24.375}, {Inherited, Inherited}}],

Cell[TextData[{
  "\tTwo fundamental kinds of events that occur during the course of a \
generation are ",
  StyleBox["selection",
    FontSlant->"Italic"],
  " and ",
  StyleBox["transmission",
    FontSlant->"Italic"],
  ".  \"Selection\" accounts for variation in the contribution of different \
genotypes to the next stage in the life cycle.  Fitnesses are assigned to \
either individuals or groups, depending on the form of selection.  The \
simplest case is viability selection, in which case fitnesses are assigned to \
individuals.  For sexual selection and assortative mating, we account for the \
relative contributions of mated pairs of male and female genotypes;  here \
fitnesses are assigned to all possible kinds of pairs (",
  ButtonBox["BT91",
    ButtonData:>"Barton & Turelli 1991",
    ButtonStyle->"Hyperlink"],
  ").  Thus according to our use of the term, with non-random mating there \
can be \"selection\" even when all individual genotypes have equal survival, \
mating success, and fecundity.  Group selection is described by assigning \
fitnesses to all possible combinations of genotypes that could comprise a \
group. "
}], "Text",
  CellMargins->{{18.1875, 24.375}, {Inherited, Inherited}}],

Cell["\<\
\tBy \"transmission\" we mean an event that changes the context of \
a gene.  A simple example is meiosis followed by syngamy:  a gene that was \
carried by a female becomes a gene that was inherited from a female.  The \
rules of transmission depend both on the gene's context and on the mode of \
inheritance obeyed by its locus (autosomal, Y-linked, cytoplasmic, \
etc.).\
\>", "Text",
  CellMargins->{{18.1875, 24.375}, {Inherited, Inherited}}]
}, Open  ]],

Cell[CellGroupData[{

Cell["(ii) Describing genotypes and populations", "Subsubtitle",
  CellMargins->{{18.1875, 24.375}, {Inherited, Inherited}},
  CellTags->"Describing genotypes and populations"],

Cell[TextData[{
  "\tThe genotype of an individual at position \[DoubleStruckI] is \
represented by the indicator variable ",
  Cell[BoxData[
      \(TraditionalForm\`X\_\[DoubleStruckI]\)]],
  ".  With just two alleles per locus, ",
  Cell[BoxData[
      \(TraditionalForm\`X\_\[DoubleStruckI]\)]],
  "  can take two values, which it is convenient to set at 0 or 1;  for this \
special case, the frequency of allele 1 at position \[DoubleStruckI] is \
written ",
  Cell[BoxData[
      \(TraditionalForm\`p\_\[DoubleStruckI]\)]],
  " and the frequency of allele 0 as ",
  Cell[BoxData[
      \(TraditionalForm\`q\_\[DoubleStruckI]\  = \ 
        1\ \[Dash]\ \(\(p\_\[DoubleStruckI]\)\(\ \)\(.\)\)\)]],
  "  A fact that will be useful later is that under these conventions, the \
expected value of ",
  Cell[BoxData[
      \(TraditionalForm\`X\_\[DoubleStruckI]\)]],
  " (averaging over all individuals in the population) is equal to ",
  Cell[BoxData[
      \(TraditionalForm\`p\_\[DoubleStruckI]\)]],
  ".  When there are more than two alleles, we can choose any ",
  StyleBox["distinct",
    FontColor->RGBColor[1, 0, 0]],
  " values to distinguish the alleles.  If we are considering alleles that \
have additive effects on a quantitative trait, it is natural to set the \
values equal to their effects.  In general, an individual is represented by a \
vector ",
  StyleBox["X",
    FontWeight->"Bold"],
  " containing the values of his/her indicator variables for every position \
in the genome.  It will be useful below to extend this vector to include \
positions from more than one individual."
}], "Text",
  CellMargins->{{18.1875, 24.375}, {Inherited, Inherited}}],

Cell[TextData[{
  "\tThe genetic state of a population can be completely described by a set \
of statistical moments that we call ",
  StyleBox["associations",
    FontSlant->"Italic"],
  ".  These include associations among genes within a haploid genome, which \
are conventionally referred to as ",
  StyleBox["linkage disequilibria",
    FontSlant->"Italic"],
  ".  We use the more general term, however, since we will be concerned with \
associations among arbitrary sets of positions, which may or may not be \
linked and may or may not be in a population that is at equilibrium.  Indeed, \
we will need to consider associations between positions that are in different \
individuals. The relation between different measures of linkage \
disequilibrium is summarised in the Discussion.  "
}], "Text",
  CellMargins->{{18.1875, 24.375}, {Inherited, Inherited}}],

Cell[TextData[{
  "\tOur notation allows multilocus moments to be defined in a variety of \
ways.  The key quantities that determine the moments are a set of ",
  StyleBox["reference values",
    FontSlant->"Italic"],
  ".  There is one reference value for each position, and the reference value \
for position \[DoubleStruckI] ",
  "is denoted ",
  Cell[BoxData[
      \(TraditionalForm\`\[WeierstrassP]\_\[DoubleStruckI]\)]],
  ".  To describe a ",
  "population, we first make a change of variables, such that the allelic \
state of an individual gene at position \[DoubleStruckI] is measured relative \
to the reference value for that position, ",
  Cell[BoxData[
      \(TraditionalForm\`\[WeierstrassP]\_\[DoubleStruckI]\)]],
  ":"
}], "Text",
  CellMargins->{{18.1875, 24.375}, {Inherited, Inherited}}],

Cell[TextData[{
  "\n",
  Cell[BoxData[
      \(TraditionalForm\`\(\(\[IndentingNewLine]\)\(\[Zeta]\_\[DoubleStruckI] \
= X\_\[DoubleStruckI] - \(\(\[WeierstrassP]\_\[DoubleStruckI]\)\(\ \)\(.\)\(\
\[IndentingNewLine]\)\)\)\)\)]],
  " \n\t"
}], "NumberedEquation",
  CellMargins->{{18.1875, 24.375}, {Inherited, Inherited}},
  CellTags->"zetaDefn"],

Cell[TextData[{
  "Choice of the reference values is up to the investigator.  Typically it is \
useful to define ",
  Cell[BoxData[
      \(TraditionalForm\`\[WeierstrassP]\_\[DoubleStruckI]\)]],
  " as the expected value of ",
  Cell[BoxData[
      \(TraditionalForm\`X\_\[DoubleStruckI]\)]],
  " among zygotes.  The reference value then has a particularly simple \
meaning for ",
  "biallelic",
  " models.  Defined that way, if there are no differences in allele \
frequencies between positions at a locus (e.g. between males and females), \
the reference value is equal to the frequency of allele 1 at that locus ",
  Cell[BoxData[
      \(TraditionalForm\`\((\[WeierstrassP]\_\[DoubleStruckI]\  = \ \(\
\[WeierstrassP]\_i\  = \ p\_i\))\)\)]],
  ".  The new indicator variable ",
  Cell[BoxData[
      \(TraditionalForm\`\[Zeta]\_\[DoubleStruckI]\)]],
  " then takes the values ",
  Cell[BoxData[
      \(TraditionalForm\`1 - p\_i\)]],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`\(-p\_i\)\)]],
  "."
}], "Text",
  CellMargins->{{18.1875, 24.375}, {Inherited, Inherited}}],

Cell["\<\
\tNext we define the product of all the \[Zeta]s in the set of \
positions \[DoubleStruckCapitalA]:\
\>", "Text",
  CellMargins->{{18.1875, 24.375}, {Inherited, Inherited}}],

Cell[TextData[{
  "\n",
  Cell[BoxData[
      FormBox[
        RowBox[{
          
          FormBox[\(\(\[IndentingNewLine]\)\(\(\[Zeta]\_\
\[DoubleStruckCapitalA]\)\(=\)\)\),
            
            "TraditionalForm"], \(\[Product]\_\(\[DoubleStruckI] \[Element] \
\[DoubleStruckCapitalA]\)\(\(\[Zeta]\_\[DoubleStruckI]\)\(\ \)\(.\)\(\
\[IndentingNewLine]\)\)\)}], TraditionalForm]]],
  "\n"
}], "NumberedEquation",
  CellMargins->{{18.1875, 24.375}, {Inherited, Inherited}},
  CellTags->"zetaProductDefn"],

Cell[TextData[{
  "The symbol \[Element] indicates that the product includes one term for \
each element in the set \[DoubleStruckCapitalA].  If we choose an individual \
at random from the population, then ",
  Cell[BoxData[
      \(TraditionalForm\`\[Zeta]\_\[DoubleStruckCapitalA]\)]],
  " is a random variable.  The association between the alleles at the \
positions in set \[DoubleStruckCapitalA] is defined as the expectation of ",
  Cell[BoxData[
      \(TraditionalForm\`\[Zeta]\_\[DoubleStruckCapitalA]\)]],
  " taken over the whole population: "
}], "Text",
  CellMargins->{{18.1875, 24.375}, {Inherited, Inherited}}],

Cell[TextData[{
  "\n",
  Cell[BoxData[
      FormBox[
        RowBox[{"\[IndentingNewLine]", 
          RowBox[{
            RowBox[{\(D\_\[DoubleStruckCapitalA]\), "=", 
              RowBox[{
                SubscriptBox["E", 
                  StyleBox["X",
                    FontWeight->"Bold"]], 
                "[", \(\[Zeta]\_\[DoubleStruckCapitalA]\), "]"}]}], ",", 
            "\[IndentingNewLine]"}]}], TraditionalForm]]],
  "\n"
}], "NumberedEquation",
  CellMargins->{{18.1875, 24.375}, {Inherited, Inherited}},
  CellTags->"DDefn"],

Cell[TextData[{
  "where ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          SubscriptBox["E", 
            StyleBox["X",
              FontWeight->"Bold"]], "[", ".", "]"}], TraditionalForm]]],
  " denotes an expectation over the distribution of genotype frequencies.  \
The ",
  Cell[BoxData[
      \(TraditionalForm\`D\_\[DoubleStruckCapitalA]\)]],
  " are therefore moments, that is, measures of statistical association.  As \
an example of the notation, the association between alleles at loci ",
  StyleBox["i",
    FontSlant->"Italic"],
  " and ",
  StyleBox["j",
    FontSlant->"Italic"],
  " in a diploid male, one inherited from his female parent (mother) and the \
other from his male parent (father), is written ",
  Cell[BoxData[
      FormBox[
        SubscriptBox["D", 
          RowBox[{
            SubscriptBox["i", 
              RowBox[{
                StyleBox["m",
                  FontSlant->"Plain"], " ", 
                StyleBox["f",
                  FontSlant->"Plain"]}]], 
            SubscriptBox["j", 
              RowBox[{
                StyleBox["m",
                  FontSlant->"Plain"], " ", 
                StyleBox["m",
                  FontSlant->"Plain"]}]]}]], TraditionalForm]]],
  ".  Products over empty sets are defined to be 1, so that ",
  Cell[BoxData[
      \(TraditionalForm\`D\_\[EmptySet]\)]],
  " = 1.  The ",
  StyleBox["D",
    FontSlant->"Italic"],
  "s are the same as ",
  ButtonBox["BT91",
    ButtonData:>"Barton & Turelli 1991",
    ButtonStyle->"Hyperlink"],
  "'s ",
  StyleBox["C",
    FontSlant->"Italic"],
  "s.  Figure 1 illustrates the notation."
}], "Text",
  CellMargins->{{18.1875, 24.375}, {Inherited, Inherited}}],

Cell[TextData[{
  "\tThe associations have particularly simple interpretations when the \
reference points are chosen to be the current allele frequencies (",
  Cell[BoxData[
      \(TraditionalForm\`\[WeierstrassP]\_\[DoubleStruckI]\  = \ 
        p\_\[DoubleStruckI]\)]],
  ").  Moments for single positions vanish:  ",
  Cell[BoxData[
      \(TraditionalForm\`D\_\[DoubleStruckI]\ \  = \ \ 0\)]],
  ".  Associations between pairs of positions are equal to the covariance in \
the allelic state of genes at those positions.  Departures from \
Hardy-Weinberg proportions are measured by ",
  StyleBox["D",
    FontSlant->"Italic"],
  "s involving pairs of positions at the same locus that have the same \
sex-of-carrier but different sexes-of-origin, for example ",
  Cell[BoxData[
      FormBox[
        SubscriptBox["D", 
          RowBox[{
            SubscriptBox["i", 
              RowBox[{
                StyleBox["m",
                  FontSlant->"Plain"], " ", 
                StyleBox["f",
                  FontSlant->"Plain"]}]], 
            SubscriptBox["i", 
              RowBox[{
                StyleBox["m",
                  FontSlant->"Plain"], " ", 
                StyleBox["m",
                  FontSlant->"Plain"]}]]}]], TraditionalForm]]],
  " for locus ",
  StyleBox["i",
    FontSlant->"Italic"],
  " in males.  When there are no sex differences in allele frequencies, ",
  Cell[BoxData[
      FormBox[
        SubscriptBox["D", 
          RowBox[{
            SubscriptBox["i", 
              RowBox[{
                StyleBox["m",
                  FontSlant->"Plain"], " ", 
                StyleBox["f",
                  FontSlant->"Plain"]}]], 
            SubscriptBox["i", 
              RowBox[{
                StyleBox["m",
                  FontSlant->"Plain"], " ", 
                StyleBox["m",
                  FontSlant->"Plain"]}]]}]], TraditionalForm]]],
  " is equal to the conventional measure of pairwise linkage disequilibrium \
(also called gametic phase disequilibrium) between loci ",
  StyleBox["i",
    FontSlant->"Italic"],
  " and ",
  StyleBox["j",
    FontSlant->"Italic"],
  ".  Moments involving more than two loci are measures of higher-order \
associations in the population.  Following the standard terminology for \
statistical moments, we say that the associations are \"centered\" when the \
reference values are set equal to the current allele frequencies."
}], "Text",
  CellMargins->{{18.1875, 24.375}, {Inherited, Inherited}}],

Cell[TextData[{
  "\t",
  ButtonBox["Equations ",
    ButtonData:>"zetaDefn",
    ButtonStyle->"Hyperlink"],
  
  CounterBox["NumberedEquation", "zetaDefn"],
  ButtonBox[" - ",
    ButtonData:>"zetaDefn",
    ButtonStyle->"Hyperlink"],
  
  CounterBox["NumberedEquation", "DDefn"],
  ButtonBox[" ",
    ButtonData:>"DDefn",
    ButtonStyle->"Hyperlink"],
  "provide a recipe for translating genotypic frequencies into a set of \
reference values ",
  Cell[BoxData[
      \(TraditionalForm\`\[WeierstrassP]\)]],
  " and associations ",
  StyleBox["D",
    FontSlant->"Italic"],
  " that completely describe the genetic state of a population.  The reverse \
translation is of course also possible.  For example, with biallelic loci and \
the reference values defined to be equal to the current allele frequencies ",
  Cell[BoxData[
      \(TraditionalForm\`\((\[WeierstrassP]\_\[DoubleStruckI]\  = \ 
          p\_\[DoubleStruckI])\)\)]],
  ", the frequency of genotype ",
  StyleBox["X",
    FontWeight->"Bold",
    FontSlant->"Italic"],
  " is"
}], "Text",
  CellMargins->{{18.1875, 24.375}, {Inherited, Inherited}}],

Cell[TextData[{
  "\n",
  Cell[BoxData[
      FormBox[
        RowBox[{"\[IndentingNewLine]", 
          RowBox[{
            RowBox[{
              RowBox[{
                StyleBox["f",
                  FontSlant->"Italic"], "(", 
                StyleBox["X",
                  FontWeight->"Bold",
                  FontSlant->"Italic"], ")"}], "  ", "=", 
              "  ", \(\[Product]\+\(\[DoubleStruckI] \[Element] \
\[DoubleStruckCapitalG]\)\([X\_\[DoubleStruckI]\ p\_\[DoubleStruckI]\ \  + \ \
\ \((1\  - \ 
                            X\_\[DoubleStruckI])\)\ q\_\[DoubleStruckI]]\)\ \ \
\  + \ \ \ \(\[Sum]\+\(\[DoubleStruckCapitalU] \[SubsetEqual] \
\[DoubleStruckCapitalG]\)\%*\)\ \
\(\(D\_\[DoubleStruckCapitalU]\)(\(-1\))\)\^\(\((\(|\)\(\
\[DoubleStruckCapitalU]\)\(|\)\(\ \)\(-\ \(\[Sum]\+\(\(\ \)\(\[DoubleStruckI] \
\[Element] \[DoubleStruckCapitalU]\)\)X\_\[DoubleStruckI]\)\))\)\(\
\[IndentingNewLine]\)\)\)}], " ", ",", "\[IndentingNewLine]"}]}], 
        TraditionalForm]]],
  "\n"
}], "NumberedEquation",
  CellMargins->{{18.1875, 24.375}, {Inherited, Inherited}},
  CellTags->"genoFreqFromMoments"],

Cell[TextData[{
  "where |\[DoubleStruckCapitalU]| means the number of positions in set \
\[DoubleStruckCapitalU].  The first term in ",
  ButtonBox["Equation ",
    ButtonData:>"genoFreqFromMoments",
    ButtonStyle->"Hyperlink"],
  
  CounterBox["NumberedEquation", "genoFreqFromMoments"],
  ButtonBox[",",
    ButtonData:>"genoFreqFromMoments",
    ButtonStyle->"Hyperlink"],
  " a product that includes one term for each position in the genome, gives \
the genotype frequency that would be found in the absence of any \
associations.  The second term accounts for the effects of the associations.  \
\[DoubleStruckCapitalG] is a set of all positions in a genome whose \
sex-of-carrier is the same as that of ",
  StyleBox["X",
    FontWeight->"Bold",
    FontSlant->"Italic"],
  ".  Expressions more general than ",
  ButtonBox["Equation ",
    ButtonData:>"genoFreqFromMoments",
    ButtonStyle->"Hyperlink"],
  
  CounterBox["NumberedEquation", "genoFreqFromMoments"],
  ButtonBox[" ",
    ButtonData:>"genoFreqFromMoments",
    ButtonStyle->"Hyperlink"],
  "that allow for multiple alleles and arbitrary definitions for the \
reference values can be derived using results that will be developed below."
}], "Text",
  CellMargins->{{18.1875, 24.375}, {Inherited, Inherited}}],

Cell[TextData[{
  "\t",
  StyleBox["Summations",
    FontColor->RGBColor[1, 0, 0]],
  " of the kind seen in the second term of ",
  ButtonBox["Equation ",
    ButtonData:>"genoFreqFromMoments",
    ButtonStyle->"Hyperlink"],
  
  CounterBox["NumberedEquation", "genoFreqFromMoments"],
  " make frequent appearances in this paper.  The sum includes one term for \
each possible subset \[DoubleStruckCapitalU] of positions in the set \
\[DoubleStruckCapitalG], including \[DoubleStruckCapitalG] itself.  When the \
summation symbol is not followed by an asterisk, the sum includes a term in \
which \[DoubleStruckCapitalU] equals the empty set, \[Diameter].   When an \
asterisk appears, as in ",
  ButtonBox["Equation ",
    ButtonData:>"genoFreqFromMoments",
    ButtonStyle->"Hyperlink"],
  
  CounterBox["NumberedEquation", "genoFreqFromMoments"],
  ", the empty set is not included.  Thus, if \[DoubleStruckCapitalG] \
consists of the two positions \[DoubleStruckI] and \[DoubleStruckJ], the sum \
in ",
  ButtonBox["Equation ",
    ButtonData:>"genoFreqFromMoments",
    ButtonStyle->"Hyperlink"],
  
  CounterBox["NumberedEquation", "genoFreqFromMoments"],
  " will have three terms as \[DoubleStruckCapitalU] takes on the values {\
\[DoubleStruckI]}, {\[DoubleStruckJ]}, and {\[DoubleStruckI], \
\[DoubleStruckJ]}."
}], "Text",
  CellMargins->{{18.1875, 24.375}, {Inherited, Inherited}}],

Cell[TextData[{
  "\tThe notation allows for more than two alleles per locus.  It does become \
more complicated in that event, however, because the extra degrees of freedom \
require us to account for associations with repeated positions.  With three \
alleles, for example, the allele frequencies at a position are described by \
the two variables ",
  Cell[BoxData[
      \(TraditionalForm\`D\_\[DoubleStruckI]\ and\ D\_\[DoubleStruckI]\
\[DoubleStruckI]\)]],
  ".    However, when there are only two alleles per locus, associations \
containing repeated positions can be expressed in terms of associations with \
no repeated positions.  (This paper will focus mainly on biallelic loci, \
which is perhaps not a severe restriction as loci can be defined as single \
nucleotide sites.  Readers who are interested in loci with multiple alleles \
should consult BT91,",
  StyleBox[" or the documentation associated with the ",
    FontColor->RGBColor[1, 0, 0]],
  StyleBox["Mathematica",
    FontSlant->"Italic",
    FontColor->RGBColor[1, 0, 0]],
  StyleBox[" packages,",
    FontColor->RGBColor[1, 0, 0]],
  " for more details about those models.)  "
}], "Text",
  CellMargins->{{18.1875, 24.375}, {Inherited, Inherited}}],

Cell[TextData[{
  "\tTwo basic reduction equations for biallelic loci that follow from ",
  ButtonBox["Equations ",
    ButtonData:>"zetaProductDefn",
    ButtonStyle->"Hyperlink"],
  "1",
  ButtonBox[" - ",
    ButtonData:>"zetaProductDefn",
    ButtonStyle->"Hyperlink"],
  
  CounterBox["NumberedEquation", "DDefn"],
  ButtonBox[" will be useful later:",
    ButtonData:>"DDefn",
    ButtonStyle->"Hyperlink"]
}], "Text",
  CellMargins->{{18.1875, 24.375}, {Inherited, Inherited}}],

Cell[TextData[{
  "\n",
  Cell[BoxData[{
      \(TraditionalForm\`D\_\[DoubleStruckCapitalU]\[DoubleStruckI]\
\[DoubleStruckI]\ \ \  = \ \ \ \(p\_\[DoubleStruckI]\) 
            q\_\[DoubleStruckI]\ D\_\[DoubleStruckCapitalU]\ \  + \ \((1\  - \
\ 2  p\_\[DoubleStruckI])\) D\_\[DoubleStruckCapitalU]\[DoubleStruckI]\ , \ 
      and\[IndentingNewLine]\[IndentingNewLine]\), "\[IndentingNewLine]", 
      \(TraditionalForm\`\[Zeta]\_\[DoubleStruckI]\%2\ \ \  = \ \ \ \(\(p\_\
\[DoubleStruckI]\ q\_\[DoubleStruckI]\)\(\ \ \ \)\(+\)\(\ \ \)\(\(\[Zeta]\_\
\[DoubleStruckI]\)(1\  - \ 2  p\_\[DoubleStruckI])\)\(\ \)\)\)}]],
  "\n"
}], "NumberedEquation",
  CellMargins->{{18.1875, 24.375}, {Inherited, Inherited}},
  CellTags->"reductionFormula"],

Cell[TextData[{
  "(",
  ButtonBox["BT91",
    ButtonData:>"Barton & Turelli 1991",
    ButtonStyle->"Hyperlink"],
  ", Equation [5]).  Here and throughout,  expressions of the form \
\[DoubleStruckCapitalA]\[DoubleStruckCapitalB] stand for \
\[DoubleStruckCapitalA]\[Union]\[DoubleStruckCapitalB], the union of sets \
\[DoubleStruckCapitalA] and \[DoubleStruckCapitalB];  thus ",
  Cell[BoxData[
      \(TraditionalForm\`D\_\[DoubleStruckCapitalU]\[DoubleStruckI]\  = \ 
        D\_\(\[DoubleStruckCapitalU] \[Union] \[DoubleStruckI]\)\)]],
  ", etc."
}], "Text",
  CellMargins->{{18.1875, 24.375}, {Inherited, Inherited}}]
}, Open  ]],

Cell[CellGroupData[{

Cell["(iii) The relation between phenotypes and genotypes", "Subsubtitle",
  CellMargins->{{18.1875, 24.375}, {Inherited, Inherited}},
  CellTags->"Phenotypes"],

Cell[TextData[{
  "\tThis notation is sufficiently flexible to allow for any relation between \
phenotypes and genotypes.  Let ",
  Cell[BoxData[
      \(TraditionalForm\`Z\)]],
  " be the value of a phenotypic character in an individual.  This value can \
be written in general as a function of the individual's genotype :"
}], "Text",
  CellMargins->{{18.1875, 24.375}, {Inherited, Inherited}}],

Cell[TextData[{
  "\n",
  Cell[BoxData[
      FormBox[
        RowBox[{
          RowBox[{"Z", "(", 
            StyleBox["X",
              FontWeight->"Bold",
              FontSlant->"Italic"], ")"}], 
          "=", \(Z\&_ + \[Sum]\_\(\[DoubleStruckCapitalA] \[SubsetEqual] \
\[DoubleStruckCapitalG]\)\(b\_\[DoubleStruckCapitalA]\)(\[Zeta]\_\
\[DoubleStruckCapitalA] - D\_\[DoubleStruckCapitalA]) + e\_Z\)}], 
        TraditionalForm]]],
  " ,\n"
}], "NumberedEquation",
  CellMargins->{{18.1875, 24.375}, {Inherited, Inherited}},
  CellTags->"phenotypicDeterminationInGeneral"],

Cell[TextData[{
  "where ",
  Cell[BoxData[
      \(TraditionalForm\`Z\&_\)]],
  " is the trait mean in the population and ",
  Cell[BoxData[
      \(TraditionalForm\`e\_\[CapitalZeta]\)]],
  " is a random environmental component that is independent of genotype and \
that has mean 0.  The ",
  Cell[BoxData[
      \(TraditionalForm\`\[Zeta]\_\[DoubleStruckCapitalA]\)]],
  " that appear on the right hand side are calculated from the genotype \
vector ",
  StyleBox["X",
    FontWeight->"Bold",
    FontSlant->"Italic"],
  " on the left using ",
  ButtonBox["Equations ",
    ButtonData:>"zetaDefn",
    ButtonStyle->"Hyperlink"],
  
  CounterBox["NumberedEquation", "zetaDefn"],
  " and",
  ButtonBox[" ",
    ButtonData:>"zetaProductDefn",
    ButtonStyle->"Hyperlink"],
  
  CounterBox["NumberedEquation", "zetaProductDefn"],
  ButtonBox[".",
    ButtonData:>"zetaProductDefn",
    ButtonStyle->"Hyperlink"],
  "  (Note that the term in the sum corresponding to the null set \
\[DoubleStruckCapitalA] = \[Diameter] makes no contribution because ",
  Cell[BoxData[
      \(TraditionalForm\`\[Zeta]\_\[EmptySet] = \(D\_\[EmptySet] = 1\)\)]],
  ".)"
}], "Text",
  CellMargins->{{18.1875, 24.375}, {Inherited, Inherited}}],

Cell[TextData[{
  "\t",
  ButtonBox["Equation ",
    ButtonData:>"phenotypicDeterminationInGeneral",
    ButtonStyle->"Hyperlink"],
  
  CounterBox["NumberedEquation", "phenotypicDeterminationInGeneral"],
  ButtonBox[" ",
    ButtonData:>"genotypeInTermsOfMoments",
    ButtonStyle->"Hyperlink"],
  "and describe any kind of genetic dominance, epistasis, sex differences in \
expression, genomic imprinting, etc..  The relation between genotype and \
phenotype is determined by the choice of the coefficients ",
  Cell[BoxData[
      \(TraditionalForm\`b\_\[DoubleStruckCapitalA]\)]],
  ".  If there is gene-by-environment interaction, the ",
  Cell[BoxData[
      \(TraditionalForm\`b\)]],
  " become a function of the state of the environment; it may be convenient \
to include that environmental state as a component of the context.  ",
  ButtonBox["Equation ",
    ButtonData:>"phenotypicDeterminationInGeneral",
    ButtonStyle->"Hyperlink"],
  
  CounterBox["NumberedEquation", "phenotypicDeterminationInGeneral"],
  ButtonBox[" ",
    ButtonData:>"genotypeInTermsOfMoments",
    ButtonStyle->"Hyperlink"],
  "also applies with multiple alleles, provided that the set \
\[DoubleStruckCapitalG] includes the appropriate number of repeated elements. \
 For example, suppose that there are three alleles at locus ",
  Cell[BoxData[
      \(TraditionalForm\`i\)]],
  ", and two alleles at locus ",
  Cell[BoxData[
      \(TraditionalForm\`j\)]],
  ".  For haploid genotypes, the set \[DoubleStruckCapitalG] is then defined \
as {\[DoubleStruckI],\[DoubleStruckI],\[DoubleStruckJ]}.  The coefficients ",
  Cell[BoxData[
      \(TraditionalForm\`b\_\[DoubleStruckI], b\_\[DoubleStruckJ], 
      b\_\(\[DoubleStruckI]\[VeryThinSpace]\[DoubleStruckI]\), 
      b\_\(\[DoubleStruckI]\[VeryThinSpace]\[DoubleStruckJ]\), \ 
      b\_\(\[DoubleStruckI]\[VeryThinSpace]\[DoubleStruckI]\[VeryThinSpace]\
\[DoubleStruckJ]\)\)]],
  " are then required to account for the 5 degrees of freedom, and the set \
\[DoubleStruckCapitalA] in the summation of Equation (",
  
  CounterBox["NumberedEquation", "phenotypicDeterminationInGeneral"],
  ") ranges over all five distinct subsets of \[DoubleStruckCapitalG]."
}], "Text",
  CellMargins->{{18.1875, 24.375}, {Inherited, Inherited}}],

Cell[TextData[{
  "\tThe ",
  Cell[BoxData[
      \(TraditionalForm\`b\)]],
  " coefficients can become quite numerous.  For example, with just two \
biallelic loci each with four possible contexts (say, two sexes-of-carrier \
and two sexes-of-origin), there are ",
  Cell[BoxData[
      \(TraditionalForm\`2\^8\  - \ 1\)]],
  "  =  255 possible ",
  Cell[BoxData[
      \(TraditionalForm\`b\)]],
  " coefficients:  eight corresponding to single positions, 28 corresponding \
to pairs of positions, etc.  The number of coefficients drops dramatically, \
however, in many cases.  With no epistasis, genotype-phenotype relations can \
be fully described with only nine coefficients, while with a completely \
additive model (no dominance and no epistasis), only four ",
  Cell[BoxData[
      \(TraditionalForm\`b\)]],
  "s are needed."
}], "Text",
  CellMargins->{{18.1875, 24.375}, {Inherited, Inherited}}]
}, Closed]]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[StyleBox["3. Evolution by Selection and Transmission",
  FontWeight->"Bold"]], "Subtitle",
  CellMargins->{{18.1875, 24.375}, {Inherited, Inherited}},
  PageBreakAbove->True,
  CellTags->"Evolution by selection and transmission"],

Cell[TextData[{
  "\tHere we use the notation proposed above and results from ",
  ButtonBox["BT91",
    ButtonData:>"Barton & Turelli 1991",
    ButtonStyle->"Hyperlink"],
  " to find how the genetic composition of a population changes over the \
course of a generation.  We first show how selection and transmission change \
a population, then end with some statistical bookkeeping."
}], "Text",
  CellMargins->{{18.1875, 24.375}, {Inherited, Inherited}}],

Cell[CellGroupData[{

Cell["(i) Selection", "Subsubtitle",
  CellMargins->{{18.1875, 24.375}, {Inherited, Inherited}},
  CellTags->"Selection"],

Cell[TextData[{
  "\tFitness is just another phenotypic character.  Consequently, ",
  ButtonBox["Equation ",
    ButtonData:>"phenotypicDeterminationInGeneral",
    ButtonStyle->"Hyperlink"],
  
  CounterBox["NumberedEquation", "phenotypicDeterminationInGeneral"],
  ButtonBox[" ",
    ButtonData:>"genotypeInTermsOfMoments",
    ButtonStyle->"Hyperlink"],
  "applies when the trait under consideration is fitness.  ",
  ButtonBox["BT91",
    ButtonData:>"Barton & Turelli 1991",
    ButtonStyle->"Hyperlink"],
  " showed that this insight is useful because the ",
  Cell[BoxData[
      \(TraditionalForm\`b\)]],
  " coefficients then take on special significance:  they can be used to \
calculate how the genetic state of the population changes."
}], "Text",
  CellMargins->{{18.1875, 24.375}, {Inherited, Inherited}}],

Cell[TextData[{
  "\tWe noted earlier that fitness (that is, relative reproductive output) \
can depend on just the genotype of the individual (as with viability \
selection), on the genotype of a mated pair (as with any form of non-random \
mating), or on the genotypes of a larger group of individuals (as with kin or \
group selection).  To describe the effects of selection, we need to consider \
together the genomes of the ",
  StyleBox["selection group",
    FontSlant->"Italic"],
  ", by which we mean the set of individuals that interact to determine their \
mutual fitness.  With simple viability selection and random mating, the \
selection group is a single individual.  Often it is useful to define the \
selection group to be a male and female mated pair, which allows for \
nonrandom mating as well as viability selection.  The selection group can be \
expanded to more than two individuals in order to accomodate group \
selection."
}], "Text",
  CellMargins->{{18.1875, 24.375}, {Inherited, Inherited}}],

Cell[TextData[{
  "\tWe denote the set of all positions in a selection group as \
\[DoubleStruckCapitalW].  For example, take a selection group consisting of a \
male and female in a mated pair.  With a single biallelic diploid locus ",
  StyleBox["i",
    FontSlant->"Italic"],
  ", the selection group is \[DoubleStruckCapitalW] = ",
  Cell[BoxData[
      FormBox[
        RowBox[{"{", 
          RowBox[{
            SubscriptBox["i", 
              StyleBox[\(m\ m\),
                FontSlant->"Plain"]], ",", " ", 
            SubscriptBox["i", 
              StyleBox[\(m\ f\),
                FontSlant->"Plain"]], ",", " ", 
            SubscriptBox["i", 
              StyleBox[\(f\ m\),
                FontSlant->"Plain"]], ",", " ", 
            SubscriptBox["i", 
              StyleBox[\(f\ f\),
                FontSlant->"Plain"]]}], "}"}], TraditionalForm]]],
  ".  With three alleles, the selection group is the same, but with each \
element appearing twice."
}], "Text",
  CellMargins->{{18.1875, 24.375}, {Inherited, Inherited}}],

Cell[TextData[{
  "\tThe absolute fitness of a selection group is defined to be the ratio of \
its frequency after selection to its frequency before.  When a selection \
group consists of more than one individual, its \"frequency\" before \
selection is equal to the product of the frequencies of the genotypes of \
those individuals.  Take, for example, a selection group consisting of a \
mated pair of male and female genotypes.  The frequency before selection ",
  StyleBox["can often be taken as",
    FontColor->RGBColor[1, 0, 0]],
  " the product of the frequencies of the respective male and female \
genotypes, since the pre-mating \"groups\" are equivalent to randomly chosen \
pairs of males and females.  The frequency of the selection group after \
selection is the frequency with which those genotypes are found together \
among all mated pairs (weighting the pairs by their relative fecundities, if \
they differ).  This representation of selection can account for viability \
selection within each sex as well as non-random mating and fecundity \
selection."
}], "Text",
  CellMargins->{{18.1875, 24.375}, {Inherited, Inherited}}],

Cell[TextData[{
  "\tThe genotype  of the selection group is described by the vector ",
  StyleBox["X",
    FontWeight->"Bold"],
  ", which includes the allelic state for every position in every individual \
in the group.  Denoting the frequencies of the group's genotype before and \
after selection as ",
  StyleBox["f",
    FontSlant->"Italic"],
  "(",
  StyleBox["X",
    FontWeight->"Bold"],
  ") and  ",
  StyleBox["f ",
    FontSlant->"Italic"],
  "'(",
  StyleBox["X",
    FontWeight->"Bold"],
  "), the group's absolute fitness as ",
  StyleBox["W",
    FontSlant->"Italic"],
  "(",
  StyleBox["X",
    FontWeight->"Bold"],
  "), and the population's mean fitness as ",
  Cell[BoxData[
      \(TraditionalForm\`W\&_\)]],
  ", we see from ",
  ButtonBox["Equation ",
    ButtonData:>"phenotypicDeterminationInGeneral",
    ButtonStyle->"Hyperlink"],
  
  CounterBox["NumberedEquation", "phenotypicDeterminationInGeneral"],
  ButtonBox[" ",
    ButtonData:>"genotypeInTermsOfMoments",
    ButtonStyle->"Hyperlink"],
  "that we can always write the expected relative fitness of the genotype of \
a selection group in the form"
}], "Text",
  CellMargins->{{18.1875, 24.375}, {Inherited, Inherited}}],

Cell[TextData[{
  "\n",
  Cell[BoxData[
      FormBox[
        RowBox[{"\[IndentingNewLine]", 
          RowBox[{
            RowBox[{"w", "(", 
              StyleBox["X",
                FontWeight->"Bold",
                FontSlant->"Italic"], 
              StyleBox[")",
                FontSlant->"Plain"]}], "   ", "=", "   ", 
            RowBox[{
              FractionBox[
                RowBox[{"W", "(", 
                  StyleBox["X",
                    FontWeight->"Bold",
                    FontSlant->"Italic"], ")"}], \(W\&_\)], "=", 
              RowBox[{
                FractionBox[
                  RowBox[{\(f'\), 
                    RowBox[{"(", 
                      StyleBox["X",
                        FontWeight->"Bold",
                        FontSlant->"Italic"], ")"}]}], 
                  RowBox[{"f", "(", 
                    StyleBox["X",
                      FontWeight->"Bold",
                      FontSlant->"Italic"], ")"}]], 
                "=", \(1 + \(\(\[Sum]\_\(\[DoubleStruckCapitalU] \
\[SubsetEqual] \[DoubleStruckCapitalW]\)\)\(\(a\_\[DoubleStruckCapitalU]\)(\
\[Zeta]\_\[DoubleStruckCapitalU] - 
                        D\_\[DoubleStruckCapitalU])\)\(\[IndentingNewLine]\)\)\
\)}]}]}]}], TraditionalForm]]],
  "\n"
}], "NumberedEquation",
  CellMargins->{{18.1875, 24.375}, {Inherited, Inherited}},
  CellTags->"fitnessDefinition"],

Cell[TextData[{
  "(see ",
  ButtonBox["BT91",
    ButtonData:>"Barton & Turelli 1991",
    ButtonStyle->"Hyperlink"],
  " eq. [6]).  "
}], "Text",
  CellMargins->{{18.1875, 24.375}, {Inherited, Inherited}}],

Cell[TextData[{
  "\tThe coefficients ",
  Cell[BoxData[
      \(TraditionalForm\`a\_\[DoubleStruckCapitalA]\)]],
  " defined by ",
  ButtonBox["Equation ",
    ButtonData:>"fitnessDefinition",
    ButtonStyle->"Hyperlink"],
  
  CounterBox["NumberedEquation", "fitnessDefinition"],
  ButtonBox[" ",
    ButtonData:>"fitnessDefinition",
    ButtonStyle->"Hyperlink"],
  "are called ",
  StyleBox["selection coefficients",
    FontSlant->"Italic"],
  ".  The coefficient ",
  Cell[BoxData[
      \(TraditionalForm\`a\_\[DoubleStruckCapitalA]\)]],
  " represents the force of selection acting on the position in set \
\[DoubleStruckCapitalA].  These coefficients ",
  StyleBox["can",
    FontColor->RGBColor[1, 0, 0]],
  " account for any form of selection within individuals (including \
dominance, epistasis, and genomic imprinting) and any form of non-random \
mating.  Note that selection coefficients defined this way typically depend \
on allele frequencies and reference values, even if the fitnesses of \
genotypes are constant (",
  ButtonBox["BT91",
    ButtonData:>"Barton & Turelli 1991",
    ButtonStyle->"Hyperlink"],
  ").  If phenotypes include environmental (nongenetic) components, then the \
frequencies ",
  StyleBox["f",
    FontSlant->"Italic"],
  "() and ",
  StyleBox["f",
    FontSlant->"Italic"],
  "\[NonBreakingSpace]'() represent expectations averaging over those \
components (see Sections 5(",
  StyleBox["iii",
    FontSlant->"Italic"],
  ") and 5(",
  StyleBox["iv",
    FontSlant->"Italic"],
  ") below)."
}], "Text",
  CellMargins->{{18.1875, 24.375}, {Inherited, Inherited}}],

Cell[TextData[{
  "\tSelection coefficients have simple interpretations.  With biallelic \
loci, the coefficient ",
  Cell[BoxData[
      \(TraditionalForm\`a\_\[DoubleStruckI]\)]],
  " measures the force of direct selection acting on position \
\[DoubleStruckI] to increase the frequency of allele 1.  Dominance at a locus \
",
  StyleBox["i",
    FontSlant->"Italic"],
  " in diploid males is measured by ",
  Cell[BoxData[
      \(TraditionalForm\`a\_\(\(i\_mf\) i\_mm\)\)]],
  ".  This coefficient measures the force of selection favoring allele 1 at \
locus ",
  StyleBox["i",
    FontSlant->"Italic"],
  " when it appears in two copies, one inherited from a female (the \
individual's mother) and the other from a male (the father).  Epistatic \
selection in our scheme occurs when the fitness effects across loci are not \
additive;  these are represented by selection coefficients that include \
multiple loci with the same sex-of-carrier.  The effects of non-random mating \
appear in selection coefficients that include both male and female \
sexes-of-carrier.  When there are more than two alleles per locus, there are \
selection coefficients that have the same position repeated; the notation can \
accomodate a continuum-of-alleles model where there are an infinite number of \
alleles per locus, provided that fitness can be approximated by a polynomial \
function (see ",
  ButtonBox["BT91",
    ButtonData:>"Barton & Turelli 1991",
    ButtonStyle->"Hyperlink"],
  ").  (It may not be possible, however, to obtain a good approximation to a \
continuum-of-alleles model using a finite set of moments)."
}], "Text",
  CellMargins->{{18.1875, 24.375}, {Inherited, Inherited}}],

Cell[TextData[{
  "\tTwo points about ",
  ButtonBox["Equation ",
    ButtonData:>"fitnessDefinition",
    ButtonStyle->"Hyperlink"],
  
  CounterBox["NumberedEquation", "fitnessDefinition"],
  ButtonBox[" ",
    ButtonData:>"fitnessDefinition",
    ButtonStyle->"Hyperlink"],
  "are worth keeping in mind.  If the phenotype contains an environmental \
component, the relative fitness ",
  StyleBox["w",
    FontSlant->"Italic"],
  "(X) is understood to mean the relative fitness averaged over that \
environmental variation.  Second, the selection ",
  StyleBox["coefficients",
    FontColor->RGBColor[1, 0, 0]],
  " depend on how the selection group is defined.  For example, with random \
mating the selection group can be defined as a single individual, and no \
selection coefficients that include both sexes-of-carrier appear.  But if the \
selection group is defined as a mated pair, ",
  StyleBox["the",
    FontColor->RGBColor[1, 0, 0]],
  " fitness function ",
  ButtonBox["of Equation ",
    ButtonData:>"fitnessDefinition",
    ButtonStyle->"Hyperlink"],
  
  CounterBox["NumberedEquation", "fitnessDefinition"],
  ButtonBox[" ",
    ButtonData:>"fitnessDefinition",
    ButtonStyle->"Hyperlink"],
  "generates selection coefficients with both sexes-of-carrier even under \
random mating.  This discrepancy is not a problem, though, since the \
alternative definitions the selection group will produce the same results so \
long as the definition that is chosen is used consistently throughout the \
calculations."
}], "Text",
  CellMargins->{{18.1875, 24.375}, {Inherited, Inherited}}],

Cell[TextData[{
  "\tGiven any set of assumptions about how genotypes (or phenotypes) affect \
lifetime fitness, ",
  ButtonBox["Equation ",
    ButtonData:>"fitnessDefinition",
    ButtonStyle->"Hyperlink"],
  
  CounterBox["NumberedEquation", "fitnessDefinition"],
  ButtonBox[" ",
    ButtonData:>"fitnessDefinition",
    ButtonStyle->"Hyperlink"],
  "can be used to calculate the corresponding selection coefficients.  \
Appendix 1 presents a simple example of two loci under epistatic viability \
selection.  When several selection events occur over the course of a \
generation, the job is made easier by calculating coefficients for each event \
in isolation and then combining them.  For example, suppose that fitness is \
the product of viability through two stages of the life cycle, each \
represented by ",
  ButtonBox["Equation ",
    ButtonData:>"fitnessDefinition",
    ButtonStyle->"Hyperlink"],
  
  CounterBox["NumberedEquation", "fitnessDefinition"],
  ButtonBox[" ",
    ButtonData:>"fitnessDefinition",
    ButtonStyle->"Hyperlink"],
  "but with coefficients ",
  Cell[BoxData[
      \(TraditionalForm\`b\_\[DoubleStruckCapitalU]\ and\ \(\(c\_\
\[DoubleStruckCapitalU]\)\(.\)\(\ \ \)\)\)]],
  "For biallelic loci, the overall selection coefficient  is "
}], "Text",
  CellMargins->{{18.1875, 24.375}, {Inherited, Inherited}}],

Cell[TextData[{
  "\n",
  Cell[BoxData[
      \(TraditionalForm\`\(\(\[IndentingNewLine]\)\(a\_\[DoubleStruckCapitalU]\
 = \[Sum]\_\(\[DoubleStruckCapitalV] \[SubsetEqual] \[DoubleStruckCapitalU]\)\
\(b\_\[DoubleStruckCapitalV]\) \(\(c\_\(\[DoubleStruckCapitalU]\[Backslash]\
\[DoubleStruckCapitalV]\)\)\(\ \)\(.\)\(\[IndentingNewLine]\)\)\)\)\)]],
  "\n"
}], "NumberedEquation",
  CellMargins->{{18.1875, 24.375}, {Inherited, Inherited}},
  CellTags->"CombiningSelectionCoefs"],

Cell[TextData[{
  "The notation \[DoubleStruckCapitalU]\\\[DoubleStruckCapitalV] stands for \
the positions in set \[DoubleStruckCapitalU] that are left after those in set \
\[DoubleStruckCapitalV] are taken away.  (To prove ",
  ButtonBox["Equation ",
    ButtonData:>"CombiningSelectionCoefs",
    ButtonStyle->"Hyperlink"],
  
  CounterBox["NumberedEquation", "CombiningSelectionCoefs"],
  ButtonBox[",",
    ButtonData:>"CombiningSelectionCoefs",
    ButtonStyle->"Hyperlink"],
  " write ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          RowBox[{\(w\_a\), "(", 
            StyleBox["X",
              FontWeight->"Bold"], 
            StyleBox[")",
              FontWeight->"Plain"]}], "  ", "=", "  ", 
          RowBox[{
            RowBox[{\(w\_b\), "(", 
              StyleBox["X",
                FontWeight->"Bold"], 
              StyleBox[")",
                FontWeight->"Plain"]}], " ", 
            RowBox[{\(w\_c\), "(", 
              StyleBox["X",
                FontWeight->"Bold"], 
              StyleBox[")",
                FontWeight->"Plain"]}]}]}], TraditionalForm]]],
  ", expand each of the ",
  StyleBox["w",
    FontSlant->"Italic"],
  "s using ",
  ButtonBox["Equation ",
    ButtonData:>"fitnessDefinition",
    ButtonStyle->"Hyperlink"],
  
  CounterBox["NumberedEquation", "fitnessDefinition"],
  ButtonBox[" ",
    ButtonData:>"fitnessDefinition",
    ButtonStyle->"Hyperlink"],
  ", use ",
  ButtonBox["Equations ",
    ButtonData:>"zetaReductionFormula",
    ButtonStyle->"Hyperlink"],
  
  CounterBox["NumberedEquation", "reductionFormula"],
  " to eliminate products of \[Zeta]s, and finally match the corresponding \
coefficients of the \[Zeta]s on the right and left sides.)  In the event of \
weak selection, the situation can be simplified further by approximation:  if \
the selection coefficients ",
  StyleBox["b",
    FontSlant->"Italic"],
  " and ",
  StyleBox["c",
    FontSlant->"Italic"],
  " are of order ",
  Cell[BoxData[
      \(TraditionalForm\`s\)]],
  ", then ",
  Cell[BoxData[
      \(TraditionalForm\`a\_\[DoubleStruckCapitalU] = 
        b\_\[DoubleStruckCapitalU] + c\_\[DoubleStruckCapitalU]\)]],
  " to leading order in ",
  Cell[BoxData[
      \(TraditionalForm\`s\)]],
  ".  "
}], "Text",
  CellMargins->{{18.1875, 24.375}, {Inherited, Inherited}}],

Cell[TextData[{
  "\tGiven the selection coefficients, we can determine the state of a \
population following the selection event.  ",
  ButtonBox["BT91",
    ButtonData:>"Barton & Turelli 1991",
    ButtonStyle->"Hyperlink"],
  " showed ",
  StyleBox["how",
    FontColor->RGBColor[1, 0, 0]],
  " the new allele frequencies and associations are given by"
}], "Text",
  CellMargins->{{18.1875, 24.375}, {Inherited, Inherited}}],

Cell[TextData[{
  "\n",
  Cell[BoxData[
      \(TraditionalForm\`\(\(\[IndentingNewLine]\)\(\(D\_\
\[DoubleStruckCapitalA]\%'\) = 
        D\_\[DoubleStruckCapitalA] + \[Sum]\_\(\[DoubleStruckCapitalU] \
\[SubsetEqual] \[DoubleStruckCapitalW]\)\(\(\(a\_\[DoubleStruckCapitalU]\)(
                D\_\[DoubleStruckCapitalA]\[DoubleStruckCapitalU] - \(D\_\
\[DoubleStruckCapitalU]\) 
                    D\_\[DoubleStruckCapitalA])\)\(\ \)\(.\)\(\
\[IndentingNewLine]\)\)\)\)\)]],
  "\n"
}], "NumberedEquation",
  CellMargins->{{18.1875, 24.375}, {Inherited, Inherited}},
  CellTags->"exactChangeInDWithSelection"],

Cell[TextData[{
  "This is our main result for the effects of selection.  We see that the \
change in the associations for positions in set \[DoubleStruckCapitalA], \
represented here by the second term on the right, is equal to a sum of all \
the selection coefficients acting on sets of positions in ",
  StyleBox["the",
    FontColor->RGBColor[1, 0, 0]],
  " population, weighted by the association between those positions and the \
ones in set \[DoubleStruckCapitalA]."
}], "Text",
  CellMargins->{{18.1875, 24.375}, {Inherited, Inherited}}],

Cell[TextData[{
  "\t",
  ButtonBox["Equation ",
    ButtonData:>"exactChangeInDWithSelection",
    ButtonStyle->"Hyperlink"],
  
  CounterBox["NumberedEquation", "exactChangeInDWithSelection"],
  ButtonBox[",",
    ButtonData:>"exactChangeInDWithSelection",
    ButtonStyle->"Hyperlink"],
  " which gives the new moments in terms of the old reference values, can be \
used to calculate changes in allele frequencies caused by selection.  If we \
choose the reference values to be the allele frequencies before selection ",
  Cell[BoxData[
      \(TraditionalForm\`\((\[WeierstrassP]\_\[DoubleStruckI]\  = \ 
          p\_\[DoubleStruckI])\)\)]],
  ", then the change in allele frequency at position \[DoubleStruckI] is \
equal to ",
  Cell[BoxData[
      \(TraditionalForm\`\(D\_\[DoubleStruckI]\%'\)\)]],
  ButtonBox[". ",
    ButtonData:>"exactChangeInDWithSelection",
    ButtonStyle->"Hyperlink"],
  "With two alleles per locus,",
  ButtonBox[" Equation ",
    ButtonData:>"exactChangeInDWithSelection",
    ButtonStyle->"Hyperlink"],
  
  CounterBox["NumberedEquation", "exactChangeInDWithSelection"],
  " gives"
}], "Text",
  CellMargins->{{18.1875, 24.375}, {Inherited, Inherited}}],

Cell[TextData[{
  "\n",
  Cell[BoxData[
      FormBox[
        RowBox[{"\[IndentingNewLine]", 
          RowBox[{
            RowBox[{
              SubscriptBox[
                StyleBox[
                  RowBox[{"\[CapitalDelta]", 
                    StyleBox["p",
                      FontSlant->"Italic"]}]], "\[DoubleStruckI]"], "   ", 
              "=", "   ", \(\(D\_\[DoubleStruckI]\%'\)\ \  = \ \ \(\[Sum]\_\(\
\[DoubleStruckCapitalU] \[SubsetEqual] \[DoubleStruckCapitalW]\)\(a\_\
\[DoubleStruckCapitalU]\) 
                      D\_\[DoubleStruckCapitalU]\[DoubleStruckI]\ \ \  = \ \ \
\ a\_\[DoubleStruckI]\ pq\_\[DoubleStruckI]\ \  + \ \ \[Sum]\_\(\
\[DoubleStruckCapitalU] \[SubsetEqual] \[DoubleStruckCapitalW], \
\[IndentingNewLine]\[DoubleStruckCapitalU] \[NotEqual] \
\[DoubleStruckI]\)\(a\_\[DoubleStruckCapitalU]\) 
                        D\_\[DoubleStruckCapitalU]\[DoubleStruckI]\)\)}], " ",
             ",", "  ", "where", "\[IndentingNewLine]"}]}], 
        TraditionalForm]]],
  " \n"
}], "NumberedEquation",
  CellMargins->{{18.1875, 24.375}, {Inherited, Inherited}},
  CellTags->"ExactDeltaP"],

Cell[TextData[{
  "\n",
  Cell[BoxData[
      \(TraditionalForm\`\(\(\ \)\(\[IndentingNewLine]\)\(\ \)\(pq\_\
\[DoubleStruckCapitalU]\ \  \[Congruent] \ \ \[Product]\+\(\[DoubleStruckI] \
\[Element] \[DoubleStruckCapitalU]\)p\_\[DoubleStruckI]\ \(\(q\_\
\[DoubleStruckI]\)\(\ \)\(.\)\(\[IndentingNewLine]\)\)\)\)\)]],
  "\n"
}], "NumberedEquation",
  CellMargins->{{18.1875, 24.375}, {Inherited, Inherited}},
  CellTags->"pqDefinition"],

Cell[TextData[{
  "On the righthand side of ",
  ButtonBox["Equation ",
    ButtonData:>"ExactDeltaP",
    ButtonStyle->"Hyperlink"],
  
  CounterBox["NumberedEquation", "ExactDeltaP"],
  ButtonBox[",",
    ButtonData:>"ExactDeltaP",
    ButtonStyle->"Hyperlink"],
  " the first term represents selection acting directly on alleles at \
position \[DoubleStruckI].  The second term represents the effects of \
indirect selection:  the force of selection acting on other positions that is \
transmitted to position \[DoubleStruckI] through the associations.  "
}], "Text",
  CellMargins->{{18.1875, 24.375}, {Inherited, Inherited}}],

Cell[TextData[{
  "\t",
  ButtonBox["Equation ",
    ButtonData:>"ExactDeltaP",
    ButtonStyle->"Hyperlink"],
  
  CounterBox["NumberedEquation", "ExactDeltaP"],
  " gives an exact expression for the change in allele frequency at position \
\[DoubleStruckI] caused by selection over one generation.  If all positions \
at locus ",
  StyleBox["i",
    FontSlant->"Italic"],
  " are equivalent, then this is equal to the change in allele frequency at \
that locus.  If not, the overall change at locus ",
  StyleBox["i",
    FontSlant->"Italic"],
  " is found by averaging ",
  Cell[BoxData[
      FormBox[
        SubscriptBox[
          StyleBox[
            RowBox[{"\[CapitalDelta]", 
              StyleBox["p",
                FontSlant->"Italic"]}]], "\[DoubleStruckI]"], 
        TraditionalForm]]],
  " over all the positions at that locus.  (Note, however, that the average \
allele frequency is not sufficient to fully describe the population.)"
}], "Text",
  CellMargins->{{18.1875, 24.375}, {Inherited, Inherited}}]
}, Open  ]],

Cell[CellGroupData[{

Cell["(ii) Transmission", "Subsubtitle",
  CellMargins->{{18.1875, 24.375}, {Inherited, Inherited}},
  CellTags->"Transmission"],

Cell[TextData[{
  "\t\"Transmission\" refers to an event that changes the contexts of genes.  \
Obvious examples are meiosis, where a gene carried by a diploid individual \
becomes a gene in a haploid individual (the gamete), and fertilization, where \
the reverse transition happens.  Migration can also be considered as a form \
of transmission, since genes change their context as they move from one \
location to another.  The effects of transmission on the state of the \
population are determined by the ",
  StyleBox["transmission coefficients",
    FontSlant->"Italic"],
  ".  The transmission coefficient ",
  Cell[BoxData[
      \(TraditionalForm\`t\_\(\[DoubleStruckCapitalA] \[LeftArrow] \
\[DoubleStruckCapitalB]\)\)]],
  " is defined simply as the probability that the positions in set \
\[DoubleStruckCapitalA] were inherited from positions in set \
\[DoubleStruckCapitalB].  (Note that this is generally not the same as the \
probability that the positions in set \[DoubleStruckCapitalB] are transmitted \
to set \[DoubleStruckCapitalA].)"
}], "Text",
  CellMargins->{{18.1875, 24.375}, {Inherited, Inherited}}],

Cell[TextData[{
  "\tTo clarify the meaning of these coefficients, consider autosomal loci in \
a haploid population with two sexes.  The transmission coefficient ",
  Cell[BoxData[
      FormBox[
        SubscriptBox["t", 
          RowBox[{
            SubscriptBox["i", 
              StyleBox["m",
                FontSlant->"Plain"]], "\[LeftArrow]", 
            SubscriptBox["i", 
              StyleBox["f",
                FontSlant->"Plain"]]}]], TraditionalForm]]],
  " is the probability that a gene at locus ",
  StyleBox["i",
    FontSlant->"Italic"],
  " in a male was inherited from a gene at locus ",
  StyleBox["i",
    FontSlant->"Italic"],
  " in a female, and is therefore 1/2.  The transmission coefficient  ",
  Cell[BoxData[
      FormBox[
        SubscriptBox["t", 
          RowBox[{
            RowBox[{"{", 
              RowBox[{
                SubscriptBox["i", 
                  StyleBox["m",
                    FontSlant->"Plain"]], ",", " ", 
                SubscriptBox["j", 
                  StyleBox["m",
                    FontSlant->"Plain"]]}], "}"}], "\[LeftArrow]", 
            RowBox[{"{", 
              RowBox[{
                SubscriptBox["i", 
                  StyleBox["f",
                    FontSlant->"Plain"]], ",", " ", 
                SubscriptBox["j", 
                  StyleBox["f",
                    FontSlant->"Plain"]]}], "}"}]}]], TraditionalForm]]],
  " is the probability that the genes at loci ",
  StyleBox["i",
    FontSlant->"Italic"],
  " and ",
  StyleBox["j",
    FontSlant->"Italic"],
  " in a male were both inherited from a female (the mother), which is (1 \
\[Dash] ",
  Cell[BoxData[
      FormBox[
        SubscriptBox["r", 
          StyleBox["ij",
            FontSlant->"Italic"]], TraditionalForm]]],
  ")/2, where ",
  Cell[BoxData[
      FormBox[
        SubscriptBox["r", 
          StyleBox["ij",
            FontSlant->"Italic"]], TraditionalForm]]],
  " is the recombination rate between loci ",
  StyleBox["i",
    FontSlant->"Italic"],
  " and ",
  StyleBox["j",
    FontSlant->"Italic"],
  ".  "
}], "Text",
  CellMargins->{{18.1875, 24.375}, {Inherited, Inherited}}],

Cell[TextData[{
  "\tThere are two constraints on transmission coefficients.  First, \
transmission coefficients are zero unless each position in set \
\[DoubleStruckCapitalA] has a corresponding position in set \
\[DoubleStruckCapitalB] from which it descended.  This implies that sets \
\[DoubleStruckCapitalA] and \[DoubleStruckCapitalB] must be equal when the \
context information is stripped from all of their positions.  To state this \
point concisely,",
  " ",
  Cell[BoxData[
      \(TraditionalForm\`t\_\(\[DoubleStruckCapitalA] \[LeftArrow] \
\[DoubleStruckCapitalB]\)\)]],
  " = 0 if ",
  StyleBox["A",
    FontSlant->"Italic"],
  " \[NotEqual] ",
  StyleBox["B",
    FontSlant->"Italic"],
  ".",
  "  A second constraint on the coefficients applies when transmission \
represents recombination, segregation, and/or syngamy.  Then sex-of-origin \
for each position in set \[DoubleStruckCapitalA] must then equal the \
sex-of-carrier for the corresponding position in set \[DoubleStruckCapitalB], \
since that is the sex of the parent from which a gene in set \
\[DoubleStruckCapitalA] descended."
}], "Text",
  CellMargins->{{18.1875, 24.375}, {Inherited, Inherited}}],

Cell[TextData[{
  "\tTransmission coefficients often involve recombination between groups of \
more than two loci.  We use ",
  Cell[BoxData[
      \(TraditionalForm\`r\_A\)]],
  " to denote the probability that recombination occurs somewhere in ",
  StyleBox["the",
    FontColor->RGBColor[1, 0, 0]],
  " set of loci ",
  StyleBox["A",
    FontSlant->"Italic"],
  ", that is, the alleles at those loci passed to a gamete are a mixture of \
those inherited from the individual's mother and father. Table 2 gives the \
transmission coefficients for several cases of interest, including autosomes, \
X-linked loci, and cytoplasmic factors."
}], "Text",
  CellMargins->{{18.1875, 24.375}, {Inherited, Inherited}}],

Cell[TextData[{
  "\tMany models assume that there is no genetic variation for the rules of \
transmission.  In that case, the effect of ",
  "transmission",
  " on the moments (the allele frequencies and associations) that describe a \
population is simple.  ",
  ButtonBox["Equation ",
    ButtonData:>"DDefn",
    ButtonStyle->"Hyperlink"],
  
  CounterBox["NumberedEquation", "DDefn"],
  ButtonBox[" ",
    ButtonData:>"DDefn",
    ButtonStyle->"Hyperlink"],
  "implies that the moments after transmission, ",
  Cell[BoxData[
      \(TraditionalForm\`D\_\[DoubleStruckCapitalA]\%\(\('\)\(\ \
\)\('\)\)\)]],
  ", are then just a linear combination of the moments before, ",
  Cell[BoxData[
      \(TraditionalForm\`D\_\[DoubleStruckCapitalA]\%\(\(\ \)\('\)\)\)]],
  ".  When the reference values are chose to be equal for all positions at a \
given locus,"
}], "Text",
  CellMargins->{{18.1875, 24.375}, {Inherited, Inherited}}],

Cell[TextData[{
  "\n",
  Cell[BoxData[
      \(TraditionalForm\`\(\(\[IndentingNewLine]\)\(D\_\[DoubleStruckCapitalA]\
\%\(\('\)\(\ \)\('\)\) = \[Sum]\_\(\[DoubleStruckCapitalU] : U = A\)t\_\(\
\[DoubleStruckCapitalA] \[LeftArrow] \[DoubleStruckCapitalU]\)\ \(\(D\_\
\[DoubleStruckCapitalU]\%\(\(\ \)\('\)\)\)\(\ \
\)\(.\)\(\[IndentingNewLine]\)\)\)\)\)]],
  "\n"
}], "NumberedEquation",
  CellMargins->{{18.1875, 24.375}, {Inherited, Inherited}},
  CellTags->"ExactChangeInDWithTransmissionNoVariationInT"],

Cell[TextData[{
  "This is our main result for the effects of transmission.  The summation is \
over all sets of positions \[DoubleStruckCapitalU] that could become set \
\[DoubleStruckCapitalA] following transmission.  The notation \"\
\[DoubleStruckCapitalU] : ",
  StyleBox["U",
    FontSlant->"Italic"],
  " = ",
  StyleBox["A",
    FontSlant->"Italic"],
  "\" means that \[DoubleStruckCapitalU] and \[DoubleStruckCapitalA] must be \
equal when the context information is stripped from them (that is, when ",
  StyleBox["U",
    FontSlant->"Italic"],
  " = ",
  StyleBox["A",
    FontSlant->"Italic"],
  ").  This requirement follows from the first constraint on transmission \
described above.  The two-locus example presented in Appendix 1 shows how \
transmission coefficients are used in calculating changes in allele \
frequencies."
}], "Text",
  CellMargins->{{18.1875, 24.375}, {Inherited, Inherited}}],

Cell[TextData[{
  "\t",
  ButtonBox["Equation ",
    ButtonData:>"ExactChangeInDWithTransmissionNoVariationInT",
    ButtonStyle->"Hyperlink"],
  
  CounterBox["NumberedEquation", 
    "ExactChangeInDWithTransmissionNoVariationInT"],
  " can be easily generalized to allow different genotypes to follow \
different transmission rules.  Examples include cases where there is meiotic \
drive or genetic variation in recombination rates.  As in ",
  ButtonBox["Equation ",
    ButtonData:>"phenotypicDeterminationInGeneral",
    ButtonStyle->"Hyperlink"],
  
  CounterBox["NumberedEquation", "phenotypicDeterminationInGeneral"],
  ButtonBox[" ",
    ButtonData:>"genotypeInTermsOfMoments",
    ButtonStyle->"Hyperlink"],
  ", we write the transmission coefficients as a polynomial function of \
genotype:"
}], "Text",
  CellMargins->{{18.1875, 24.375}, {Inherited, Inherited}}],

Cell[TextData[{
  "\n",
  Cell[BoxData[
      FormBox[
        RowBox[{"\[IndentingNewLine]", 
          RowBox[{
            RowBox[{
              
              RowBox[{\(t\_\(\(\[DoubleStruckCapitalA]\)\(\[LeftArrow]\)\(\
\[DoubleStruckCapitalU]\)\(\ \)\)\), "(", 
                StyleBox["X",
                  FontWeight->"Bold",
                  FontSlant->"Italic"], ")"}], 
              "=", \(t\&_\_\(\(\[DoubleStruckCapitalA]\)\(\[LeftArrow]\)\(\
\[DoubleStruckCapitalU]\)\(\ \)\) + \[Sum]\_\(\[DoubleStruckCapitalV] \
\[SubsetEqual] \[DoubleStruckCapitalT]\)\(t\_\(\[DoubleStruckCapitalA] \
\[LeftArrow] \[DoubleStruckCapitalU]\  | \
\[DoubleStruckCapitalV]\)\)(\[Zeta]\_\[DoubleStruckCapitalV] - \(D\_\
\[DoubleStruckCapitalV]\%'\))\)}], "  ", ",", "\[IndentingNewLine]"}]}], 
        TraditionalForm]]],
  " \n"
}], "NumberedEquation",
  CellMargins->{{18.1875, 24.375}, {Inherited, Inherited}},
  CellTags->"transmissionCoefficients"],

Cell["\<\
where \[DoubleStruckCapitalT] is the set of all positions that \
influence the transmission coefficient.  We then average the transmission \
probabilities over all genotypes:\
\>", "Text",
  CellMargins->{{18.1875, 24.375}, {Inherited, Inherited}}],

Cell[TextData[{
  "\n",
  Cell[BoxData[
      FormBox[
        RowBox[{"\[IndentingNewLine]", 
          RowBox[{\(D\_\[DoubleStruckCapitalA]\%\(\('\)\(\ \)\('\)\)\), "=", 
            RowBox[{
              RowBox[{\(\[Sum]\_\(\[DoubleStruckCapitalU] : U = A\)\), 
                RowBox[{
                  SubscriptBox["E", 
                    StyleBox["X",
                      FontWeight->"Bold"]], "[", 
                  RowBox[{
                    
                    RowBox[{\(t\_\(\(\[DoubleStruckCapitalA]\)\(\[LeftArrow]\)\
\(\[DoubleStruckCapitalU]\)\(\ \)\)\), "(", 
                      StyleBox["X",
                        FontWeight->"Bold",
                        FontSlant->"Italic"], 
                      ")"}], \(\[Zeta]\_\[DoubleStruckCapitalA]\)}], "]"}]}], 
              "=", 
              RowBox[{\(\[Sum]\_\(\[DoubleStruckCapitalU] : U = A\)\), 
                
                RowBox[{\(\[Sum]\_\(\[DoubleStruckCapitalV] \[SubsetEqual] \
\[DoubleStruckCapitalT]\)\), 
                  RowBox[{
                    SubscriptBox["t", 
                      
                      RowBox[{\(\[DoubleStruckCapitalA] \[LeftArrow] \
\[DoubleStruckCapitalU]\), " ", "|", " ", 
                        StyleBox["\[DoubleStruckCapitalV]",
                          FontWeight->"Bold",
                          FontSlant->"Italic"]}]], 
                    " ", \(\((D\_\[DoubleStruckCapitalU]\
\[DoubleStruckCapitalV]\%\(\(\ \)\('\)\) - \(D\_\[DoubleStruckCapitalU]\%\(\(\
\ \)\('\)\)\) 
                            D\_\[DoubleStruckCapitalV]\%\(\(\ \)\('\)\))\)\(\ \
\)\(.\)\(\[IndentingNewLine]\)\)}]}]}]}]}]}], TraditionalForm]]],
  "\n"
}], "NumberedEquation",
  CellMargins->{{18.1875, 24.375}, {Inherited, Inherited}},
  CellTags->"ExactChangeInDWithTransmissionWithVariationInT"],

Cell[TextData[{
  "(c.f. Barton ",
  ButtonBox["1995, ",
    ButtonData:>"Barton 1995",
    ButtonStyle->"Hyperlink"],
  "Eq. 5).   The transmission coefficient ",
  Cell[BoxData[
      FormBox[
        SubscriptBox["t", 
          
          RowBox[{\(\[DoubleStruckCapitalA] \[LeftArrow] \
\[DoubleStruckCapitalU]\), " ", "|", " ", 
            StyleBox["\[DoubleStruckCapitalV]",
              FontWeight->"Bold",
              FontSlant->"Italic"]}]], TraditionalForm]]],
  " represents the effect of the set of positions \[DoubleStruckCapitalV] on \
the transmission coefficient ",
  Cell[BoxData[
      \(TraditionalForm\`t\_\(\(\[DoubleStruckCapitalA]\)\(\[LeftArrow]\)\(\
\[DoubleStruckCapitalU]\)\(\ \)\)\)]],
  ", in the same way that the selection coefficient  ",
  Cell[BoxData[
      \(TraditionalForm\`a\_\[DoubleStruckCapitalV]\)]],
  " represents the effects of the set \[DoubleStruckCapitalV] on fitness.  \
This equation can be used to study the evolution of an allele that modifies \
the transmission system, for example by altering recombination rates or the \
breeding system. ",
  StyleBox[" In fact, Eq.14 is similar to Eq. 9, which describes the effect \
of selection.  One can think of selection as a special form of \
genotype-dependant transmission,where the transmission is between \
correspobnding positions at consecutive stages in the life cycle, and where \
the transmission coefficients are just the relative fitnesses.",
    FontColor->RGBColor[1, 0, 0]]
}], "Text",
  CellMargins->{{18.1875, 24.375}, {Inherited, Inherited}}]
}, Open  ]],

Cell[CellGroupData[{

Cell["(iii) Changing reference values", "Subsubtitle",
  CellMargins->{{18.1875, 24.375}, {Inherited, Inherited}},
  CellTags->"Changing reference values"],

Cell["\<\
\tAs described earlier, our system of describing a population is \
defined relative to a set of reference values.  The investigator is free to \
leave these fixed or to change them as often as desired.  It is often \
convenient, however, to change the reference values once per generation.  By \
updating the reference values to the current allele frequencies, the \
associations have simple interpretations, and we can calculate the \
per-generation changes in allele frequencies.  Moreover, updating only once \
per generation avoids a proliferation of algebra, involving reference values \
at intermediate stages that eventually cancel.  Sometimes it is convenient to \
update the reference values at the zygote stage.  Alternatively, it may be \
easiest to update them before transmission, since under normal meiosis (no \
meiotic drive, etc.) allele frequencies are unchanged and the change in \
associations caused by transmission often take a simple form when the \
associations have already been centered.  If we are only interested in \
finding the evolutionary equilibrium, changing reference values from one \
generation to the next is not an issue.\
\>", "Text",
  CellMargins->{{18.1875, 24.375}, {Inherited, Inherited}}],

Cell[TextData[{
  "\tChanging the reference values changes the associations ",
  StyleBox["D",
    FontSlant->"Italic"],
  ", because the latter are defined in terms of the former.  Denote the \
associations before and after the change as ",
  Cell[BoxData[
      \(TraditionalForm\`D\_\[DoubleStruckCapitalA]\%\(\(\ \)\(\('\)\(\ \)\('\
\)\)\)\)]],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`D\_\[DoubleStruckCapitalA]\%\(\(\ \)\(\(\('\)\(\ \
\)\('\)\)\ '\)\)\)]],
  ", respectively, and the reference values before and after as ",
  Cell[BoxData[
      \(TraditionalForm\`\[WeierstrassP]\_\[DoubleStruckI]\%\(\(\ \)\(\('\)\(\
\ \)\('\)\)\)\)]],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`\[WeierstrassP]\_\[DoubleStruckI]\%\(\(\ \)\(\(\('\)\
\(\ \)\('\)\)\ '\)\)\)]],
  ".  (If the reference values have not been changed since the start of the \
generation, then ",
  Cell[BoxData[
      \(TraditionalForm\`\[WeierstrassP]\_\[DoubleStruckI]\%\(\(\ \)\(\('\)\(\
\ \)\('\)\)\)\)]],
  " = ",
  Cell[BoxData[
      \(TraditionalForm\`\[WeierstrassP]\_\[DoubleStruckI]\)]],
  ".)  The associations after the reference values change are found using ",
  ButtonBox["Equations ",
    ButtonData:>"zetaDefn",
    ButtonStyle->"Hyperlink"],
  
  CounterBox["NumberedEquation", "zetaDefn"],
  ButtonBox["-",
    ButtonData:>"zetaDefn",
    ButtonStyle->"Hyperlink"],
  
  CounterBox["NumberedEquation", "DDefn"],
  ButtonBox[":",
    ButtonData:>"DDefn",
    ButtonStyle->"Hyperlink"]
}], "Text",
  CellMargins->{{18.1875, 24.375}, {Inherited, Inherited}}],

Cell[TextData[{
  "\n",
  Cell[BoxData[
      FormBox[
        RowBox[{"\[IndentingNewLine]", 
          
          RowBox[{\(D\_\[DoubleStruckCapitalA]\%\(\(\ \)\(\(\('\)\(\ \
\)\('\)\)\ '\)\)\), "  ", "=", "  ", 
            RowBox[{
              RowBox[{
                SubscriptBox["E", 
                  StyleBox["X",
                    FontWeight->"Bold"]], "[", 
                " ", \(\[Product]\+\(\[DoubleStruckI] \[Element] \
\[DoubleStruckCapitalA]\)\((X\_\[DoubleStruckI] - \[WeierstrassP]\_\
\[DoubleStruckI]\%\(\(\ \)\(\(\('\)\(\ \)\('\)\)\ '\)\))\)\), " ", "]"}], 
              "  ", "=", "  ", 
              RowBox[{
                RowBox[{
                  SubscriptBox["E", 
                    StyleBox["X",
                      FontWeight->"Bold"]], 
                  "[", \(\[Product]\+\(\[DoubleStruckI] \[Element] \
\[DoubleStruckCapitalA]\)\((X\_\[DoubleStruckI] - \[WeierstrassP]\_\
\[DoubleStruckI]\%\(\(\ \)\(\('\)\(\ \)\('\)\)\))\)\  + \ \
\((\[WeierstrassP]\_\[DoubleStruckI]\%\(\(\ \)\(\('\)\(\ \)\('\)\)\) - \
\[WeierstrassP]\_\[DoubleStruckI]\%\(\(\ \)\(\(\('\)\(\ \)\('\)\)\ '\)\))\)\),
                   "]"}], "\[IndentingNewLine]", "\[IndentingNewLine]", 
                "\[IndentingNewLine]", "=", 
                RowBox[{
                  
                  RowBox[{\(\[Sum]\_\(\[DoubleStruckCapitalU] \[SubsetEqual] \
\[DoubleStruckCapitalA]\)\), "  ", 
                    
                    RowBox[{\(\[Product]\+\(\[DoubleStruckI] \[Element] \
\[DoubleStruckCapitalU]\)\), " ", 
                      
                      RowBox[{\((\[WeierstrassP]\_\[DoubleStruckI]\%\(\(\ \
\)\(\('\)\(\ \)\('\)\)\)\  - \ \[WeierstrassP]\_\[DoubleStruckI]\%\(\(\ \
\)\(\(\('\)\(\ \)\('\)\)\ '\)\))\), 
                        RowBox[{
                          SubscriptBox["E", 
                            StyleBox["X",
                              FontWeight->"Bold"]], "[", 
                          " ", \(\[Product]\+\(\[DoubleStruckJ] \[Element] \
\[DoubleStruckCapitalA]\[Backslash]\[DoubleStruckCapitalU]\)\((X\_\
\[DoubleStruckJ] - \[WeierstrassP]\_\[DoubleStruckJ]\%\(\(\ \)\(\('\)\(\ \
\)\('\)\)\))\)\), "]"}]}]}]}], "     ", "\[IndentingNewLine]", 
                  "\[IndentingNewLine]", "\[IndentingNewLine]", "=", 
                  "   ", \(\[Sum]\_\(\[DoubleStruckCapitalU] \[SubsetEqual] \
\[DoubleStruckCapitalA]\)\(\([\(D\_\(\[DoubleStruckCapitalA]\\\
\[DoubleStruckCapitalU]\)\%\(\(\ \)\(\('\)\(\ \)\('\)\)\)\) \(\[Product]\+\(\
\[DoubleStruckI] \[Element] \[DoubleStruckCapitalU]\)\((\[WeierstrassP]\_\
\[DoubleStruckI]\%\(\(\ \)\(\('\)\(\ \)\('\)\)\)\  - \ \[WeierstrassP]\_\
\[DoubleStruckI]\%\(\(\('\)\(\ \)\('\)\)\ '\))\)\)]\)\(\ \ \ \)\(.\)\(\
\[IndentingNewLine]\)\)\)}]}]}]}]}], TraditionalForm]]]
}], "NumberedEquation",
  CellMargins->{{18.1875, 24.375}, {Inherited, Inherited}},
  CellTags->"ChangeInReferenceValueEquation"],

Cell[TextData[{
  "Because the sum in (",
  
  CounterBox["NumberedEquation", "ChangeInReferenceValueEquation"],
  ") is not asterisked, it includes the term corresponding to \
\[DoubleStruckCapitalU] = \[EmptySet], which is ",
  Cell[BoxData[
      \(TraditionalForm\`\(\(\ \)\(D\_\[DoubleStruckCapitalA]\%\(\(\ \
\)\(\('\)\(\ \)\('\)\)\)\)\)\)]],
  ".  This last expression is the main result for changing reference values."
}], "Text",
  CellMargins->{{18.1875, 24.375}, {Inherited, Inherited}}],

Cell[TextData[{
  "\tWith the exception of random drift, all of genetic evolution can be \
concisely represented by two equations:  ",
  ButtonBox["Equation ",
    ButtonData:>"exactChangeInDWithSelection",
    ButtonStyle->"Hyperlink"],
  
  CounterBox["NumberedEquation", "exactChangeInDWithSelection"],
  ButtonBox[" ",
    ButtonData:>"exactChangeInDWithSelection",
    ButtonStyle->"Hyperlink"],
  "for the effects of selection and other deterministic forces, and ",
  ButtonBox["Equation ",
    ButtonData:>"ExactChangeInDWithTransmissionNoVariationInT",
    ButtonStyle->"Hyperlink"],
  
  CounterBox["NumberedEquation", 
    "ExactChangeInDWithTransmissionNoVariationInT"],
  ButtonBox[" ",
    ButtonData:>"ExactChangeInDWithTransmissionNoVariationInT",
    ButtonStyle->"Hyperlink"],
  "for the effects of transmission.  These can be supplemented by ",
  ButtonBox["Equation ",
    ButtonData:>"ChangeInReferenceValueEquation",
    ButtonStyle->"Hyperlink"],
  
  CounterBox["NumberedEquation", "ChangeInReferenceValueEquation"],
  ButtonBox[", ",
    ButtonData:>"ChangeInReferenceValueEquation",
    ButtonStyle->"Hyperlink"],
  "which does the bookkeeping needed to ensure that the associations have a \
simple interpretation.  Other deterministic forces, like mutation and \
migration, can also be described by these equations.  Mutation can be \
represented as a form of frequency-dependent selection, and migration as a \
form of transmission (since genes change their contexts when they move).  It \
is easier to find the effects of ",
  StyleBox["mutation",
    FontColor->RGBColor[1, 0, 0]],
  " directly, however, which we will do shortly.  Before doing that, however, \
we will develop an approximation that greatly simplifies the equations for \
selection and transmission."
}], "Text",
  CellMargins->{{18.1875, 24.375}, {Inherited, Inherited}}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[StyleBox["4. The Quasi-Linkage Equilibrium (QLE) Approximation",
  
  FontWeight->"Bold"]], "Subtitle",
  CellMargins->{{18.1875, 24.375}, {Inherited, Inherited}},
  PageBreakAbove->True,
  CellTags->"The QLE approximation"],

Cell[TextData[{
  "\tThe recursions derived above can be used to calculate the exact dynamics \
for a wide range of multilocus population genetic models.  Although this \
approach may give more insight than directly following genotype frequencies, \
it will not necessarily be any more tractable.  That is because exact results \
require following the dynamics of the same number of variables, regardless of \
whether they are genotype frequencies or moments (that is, allele frequencies \
and associations).  One of the great appeals of the moment-based approach \
introduced by ",
  ButtonBox["BT91",
    ButtonData:>"Barton & Turelli 1991",
    ButtonStyle->"Hyperlink"],
  " is that in some situations expressions for the associations can be \
greatly simplified by approximation."
}], "Text",
  CellMargins->{{18.1875, 24.375}, {Inherited, Inherited}}],

Cell[TextData[{
  "\tIn this section, we derive approximate expressions for the associations \
and changes in allele frequencies when the population is in a state of \
\"quasi-linkage equilibrium\", abbreviated as QLE (Kimura ",
  ButtonBox["1965",
    ButtonData:>"Kimura 1965",
    ButtonStyle->"Hyperlink"],
  ").  The first fundamental assumption we must make is that all the \
associations ",
  StyleBox["D",
    FontSlant->"Italic"],
  " are of order ",
  StyleBox["a",
    FontSlant->"Italic"],
  ", by which we mean that they are not larger than a constant factor times \
the largest of the ",
  StyleBox["a",
    FontSlant->"Italic"],
  "s.  ",
  ButtonBox["BT91",
    ButtonData:>"Barton & Turelli 1991",
    ButtonStyle->"Hyperlink"],
  " show this condition is met when the forces that generate associations \
within a sex (epistasis, migration, etc.) are weak relative to recombination, \
and when nonrandom mating is not strong.  An intuitive justification is that \
the associations are produced by evolutionary forces that are of order ",
  StyleBox["a",
    FontSlant->"Italic"],
  " (see Equation ",
  ButtonBox["[",
    ButtonData:>"exactChangeInDWithSelection",
    ButtonStyle->"Hyperlink"],
  
  CounterBox["NumberedEquation", "exactChangeInDWithSelection"],
  ButtonBox["]",
    ButtonData:>"exactChangeInDWithSelection",
    ButtonStyle->"Hyperlink"],
  "), and will not accumulate to values that are much larger than that if the \
forces breaking them down (recombination, segregation, and mutation) are \
sufficiently strong.  The second assumption needed for the QLE approximation \
is that all the selection coefficients ",
  StyleBox["a",
    FontSlant->"Italic"],
  " are much smaller than 1.  ",
  ButtonBox["BT91",
    ButtonData:>"Barton & Turelli 1991",
    ButtonStyle->"Hyperlink"],
  " show that when these two conditions hold, a population rapidly settles \
into a state where the allele frequencies are changing slowly, and the \
associations are close to the equilibrium values they would reach if the \
allele frequencies were in fact stationary (see also Nagylaki ",
  ButtonBox["1993",
    ButtonData:>"Nagylaki 1993",
    ButtonStyle->"Hyperlink"],
  ").  We can then neglect terms involving higher powers of the ",
  StyleBox["a",
    FontSlant->"Italic"],
  "s, and also higher powers of the ",
  StyleBox["D",
    FontSlant->"Italic"],
  "s (because they are of order ",
  StyleBox["a",
    FontSlant->"Italic"],
  ").  Futhermore, the effects of a series of events of selection, migration, \
and mutation can be added together, provided they are each of order ",
  StyleBox["a",
    FontSlant->"Italic"],
  " (Kirkpatrick and Servedio, ",
  ButtonBox["1999",
    ButtonData:>"Kirkpatrick & Servedio 1999",
    ButtonStyle->"Hyperlink"],
  ")."
}], "Text",
  CellMargins->{{18.1875, 24.375}, {Inherited, Inherited}}],

Cell[TextData[{
  "\tWe assume there are two alleles at each locus, which simplifies the \
analysis.  The approach can be extended to multiple alleles following the \
leads of ",
  ButtonBox["BT91",
    ButtonData:>"Barton & Turelli 1991",
    ButtonStyle->"Hyperlink"],
  ".  The main results developed below are illustrated with a simple \
two-locus example in Appendix 1."
}], "Text",
  CellMargins->{{18.1875, 24.375}, {Inherited, Inherited}}],

Cell[CellGroupData[{

Cell["(i) Approximations for the associations", "Subsubtitle",
  CellMargins->{{18.1875, 24.375}, {Inherited, Inherited}},
  CellTags->"Approximations for the disequilibria"],

Cell[TextData[{
  "\tThis section derives the QLE approximation for the associations ",
  StyleBox["D",
    FontSlant->"Italic"],
  " with biallelic loci.  Readers who are not interested in the derivations \
can skip to the section, ",
  StyleBox["Changes in allele frequencies at QLE",
    FontSlant->"Italic"],
  ", where the results are put to use. "
}], "Text",
  CellMargins->{{18.1875, 24.375}, {Inherited, Inherited}}],

Cell[CellGroupData[{

Cell["\tGeneral results", "Subsection",
  CellMargins->{{18.1875, 24.375}, {Inherited, Inherited}},
  CellTags->"General results"],

Cell[TextData[{
  "\tConsider a life cycle in which we define the reference values to be the \
allele frequencies at the zygote stage.  A series of selection events occur \
during the course of the generation.  The generation ends with transmission, \
creating the zygotes for the next generation.  We seek to derive an \
approximation for the dynamics of allele frequencies that is accurate up to \
(and including) terms of order ",
  Cell[BoxData[
      \(TraditionalForm\`a\^2\)]],
  ", which we denote ",
  Cell[BoxData[
      \(TraditionalForm\`O(a\^2)\)]],
  ".  From ",
  ButtonBox["Equation ",
    ButtonData:>"ExactDeltaP",
    ButtonStyle->"Hyperlink"],
  
  CounterBox["NumberedEquation", "ExactDeltaP"],
  ButtonBox[",",
    ButtonData:>"ExactDeltaP",
    ButtonStyle->"Hyperlink"],
  " we see that approximation requires in turn that we find an approximation \
for the associations ",
  StyleBox["D",
    FontSlant->"Italic"],
  " that is accurate to order ",
  StyleBox["a",
    FontSlant->"Italic"],
  ".  To do that we will find the values that give an equilibrium for the \
recursion equations for the ",
  StyleBox["D",
    FontSlant->"Italic"],
  " that are accurate to order ",
  StyleBox["a",
    FontSlant->"Italic"],
  ";  those solutions will be our quasi-linkage equilibrium (QLE) \
approximations for the associations.  The results apply not just to selection \
but to other deterministic forces that generate associations (such as \
migration) so long as they are weak relative to recombination and \
segregation.  To simplify the derivations, we will assume that there is no \
genetic variation in the transmission coefficients,",
  StyleBox[" an assumption which",
    FontColor->RGBColor[1, 0, 0]],
  " could be relaxed (see Barton ",
  ButtonBox["1995",
    ButtonData:>"Barton 1995",
    ButtonStyle->"Hyperlink"],
  ").  However, we must assume that the transmission coefficients are \
sufficiently large that forces of order ",
  Cell[BoxData[
      \(TraditionalForm\`a\)]],
  " do not eventually generate strong associations.  This requires that all \
eigenvalues of the matrix of transmission coefficients ",
  Cell[BoxData[
      \(TraditionalForm\`t\_\(\[DoubleStruckCapitalA] \[LeftArrow] \
\[DoubleStruckCapitalU]\)\)]],
  " are ",
  StyleBox["O",
    FontSlant->"Italic"],
  "(1).  We will also assume there are only two alleles at each locus."
}], "Text",
  CellMargins->{{18.1875, 24.375}, {Inherited, Inherited}}],

Cell[TextData[{
  "\tTo begin deriving an approximate recursion for the ",
  StyleBox["D",
    FontSlant->"Italic"],
  ", ",
  ButtonBox["Equation ",
    ButtonData:>"exactChangeInDWithSelection",
    ButtonStyle->"Hyperlink"],
  
  CounterBox["NumberedEquation", "exactChangeInDWithSelection"],
  ButtonBox[" ",
    ButtonData:>"exactChangeInDWithSelection",
    ButtonStyle->"Hyperlink"],
  "gives the cumulative effect of selection and other deterministic forces on \
the associations between positions in set \[DoubleStruckCapitalA]:"
}], "Text",
  CellMargins->{{18.1875, 24.375}, {Inherited, Inherited}}],

Cell[TextData[{
  Cell[BoxData[
      \(TraditionalForm\`\(\(\[IndentingNewLine]\)\(\(D\_\
\[DoubleStruckCapitalA]\%'\)\ \  = \ \ \(D\_\[DoubleStruckCapitalA] + \
\(\[Sum]\_\(\[DoubleStruckCapitalU] \[SubsetEqual] \
\[DoubleStruckCapitalW]\)\%*\)\(a\_\[DoubleStruckCapitalU]\) 
                D\_\[DoubleStruckCapitalU]\[DoubleStruckCapitalA]\ \  + \ \ O(
              a\^2)\[IndentingNewLine]\[IndentingNewLine]\[IndentingNewLine] \
= \ \ \(\(D\_\[DoubleStruckCapitalA]\)\(\ \ \)\(+\)\(\ \ \)\(\(a\_\
\[DoubleStruckCapitalA]\) 
              pq\_\[DoubleStruckCapitalA]\)\(\ \ \)\(+\)\(\ \ \)\(O(
              a\^2)\)\(\ \)\(\[IndentingNewLine]\)\)\)\)\)\)]],
  "\n"
}], "NumberedEquation",
  CellMargins->{{18.1875, 24.375}, {Inherited, Inherited}},
  CellTags->"DPrimeAfterSelectionAtQLE"],

Cell[TextData[{
  "where \[DoubleStruckCapitalA] is a set of distinct positions, and ",
  Cell[BoxData[
      \(TraditionalForm\`pq\_\[DoubleStruckCapitalA]\)]],
  " is defined by  ",
  ButtonBox["Equation ",
    ButtonData:>"pqDefinition",
    ButtonStyle->"Hyperlink"],
  
  CounterBox["NumberedEquation", "pqDefinition"],
  ButtonBox[".",
    ButtonData:>"pqDefinition",
    ButtonStyle->"Hyperlink"],
  "  The asterisked ",
  Cell[BoxData[
      \(TraditionalForm\`\(\[Sum]\^*\)\)]],
  " indicates that the sum does not include the term with \
\[DoubleStruckCapitalU] = \[EmptySet];  it has been separated out to give the \
first term, ",
  Cell[BoxData[
      \(TraditionalForm\`D\_\[DoubleStruckCapitalA]\)]],
  "."
}], "Text",
  CellMargins->{{18.1875, 24.375}, {Inherited, Inherited}}],

Cell[TextData[{
  "\tThe first step of ",
  ButtonBox["Equation ",
    ButtonData:>"DPrimeAfterSelectionAtQLE",
    ButtonStyle->"Hyperlink"],
  
  CounterBox["NumberedEquation", "DPrimeAfterSelectionAtQLE"],
  ButtonBox[" ",
    ButtonData:>"DPrimeAfterSelectionAtQLE",
    ButtonStyle->"Hyperlink"],
  "follows from ",
  ButtonBox["Equation ",
    ButtonData:>"exactChangeInDWithSelection",
    ButtonStyle->"Hyperlink"],
  
  CounterBox["NumberedEquation", "exactChangeInDWithSelection"],
  ButtonBox[" ",
    ButtonData:>"exactChangeInDWithSelection",
    ButtonStyle->"Hyperlink"],
  "because the ",
  StyleBox["D",
    FontSlant->"Italic"],
  " are of order ",
  StyleBox["a",
    FontSlant->"Italic"],
  " and therefore the term ",
  Cell[BoxData[
      \(TraditionalForm\`a\_\[DoubleStruckCapitalU]\ D\_\
\[DoubleStruckCapitalU]\ D\_\[DoubleStruckCapitalA]\)]],
  " in ",
  ButtonBox["Equation ",
    ButtonData:>"exactChangeInDWithSelection",
    ButtonStyle->"Hyperlink"],
  
  CounterBox["NumberedEquation", "exactChangeInDWithSelection"],
  ButtonBox[" ",
    ButtonData:>"exactChangeInDWithSelection",
    ButtonStyle->"Hyperlink"],
  "is of order ",
  Cell[BoxData[
      \(TraditionalForm\`a\^3\)]],
  " and so can be neglected.  The second step follows because the term ",
  Cell[BoxData[
      \(TraditionalForm\`\(a\_\[DoubleStruckCapitalU]\) 
        D\_\[DoubleStruckCapitalU]\[DoubleStruckCapitalA]\)]],
  " in the first line is of order ",
  Cell[BoxData[
      \(TraditionalForm\`a\^2\)]],
  " except when \[DoubleStruckCapitalU] = \[DoubleStruckCapitalA], in which \
event the reduction formula ",
  ButtonBox["Equation ",
    ButtonData:>"reductionFormula",
    ButtonStyle->"Hyperlink"],
  
  CounterBox["NumberedEquation", "reductionFormula"],
  ButtonBox[" gives us ",
    ButtonData:>"reductionFormula",
    ButtonStyle->"Hyperlink"],
  Cell[BoxData[
      \(TraditionalForm\`D\_\[DoubleStruckCapitalU]\[DoubleStruckCapitalA]\)]]\
,
  "  =  ",
  Cell[BoxData[
      \(TraditionalForm\`D\_\[DoubleStruckCapitalA]\[DoubleStruckCapitalA]\)]]\
,
  "  =  ",
  Cell[BoxData[
      \(TraditionalForm\`pq\_\[DoubleStruckCapitalA]\)]],
  " + ",
  Cell[BoxData[
      \(TraditionalForm\`O(a)\)]],
  "."
}], "Text",
  CellMargins->{{18.1875, 24.375}, {Inherited, Inherited}}],

Cell[TextData[{
  "\tThe effect of changing reference values can also be simplified.  ",
  ButtonBox["Equation ",
    ButtonData:>"ExactDeltaP",
    ButtonStyle->"Hyperlink"],
  
  CounterBox["NumberedEquation", "ExactDeltaP"],
  ButtonBox[" ",
    ButtonData:>"ExactDeltaP",
    ButtonStyle->"Hyperlink"],
  "shows that the change in the allele frequencies is of order ",
  StyleBox["a",
    FontSlant->"Italic"],
  ".  If we define the reference values to be the allele frequencies, then \
the quantities (",
  Cell[BoxData[
      \(TraditionalForm\`\[WeierstrassP]\_\[DoubleStruckI]\%\(\(\ \)\(\('\)\(\
\ \)\('\)\)\)\  - \ \[WeierstrassP]\_\[DoubleStruckI]\%\(\(\ \)\(\(\('\)\(\ \
\)\('\)\)\ '\)\)\)]],
  ") that appear in the product in ",
  ButtonBox["Equation ",
    ButtonData:>"ChangeInReferenceValueEquation",
    ButtonStyle->"Hyperlink"],
  
  CounterBox["NumberedEquation", "ChangeInReferenceValueEquation"],
  ButtonBox[" ",
    ButtonData:>"ChangeInReferenceValueEquation",
    ButtonStyle->"Hyperlink"],
  "are of order ",
  StyleBox["a",
    FontSlant->"Italic"],
  ".  That equation therefore reduces simply to ",
  Cell[BoxData[
      \(TraditionalForm\`D\_\[DoubleStruckCapitalA]\%\(\(\('\)\(\ \)\('\)\)\ \
'\)\ \  = \ \ D\_\[DoubleStruckCapitalA]\%\(\('\)\(\ \)\('\)\) + \ \ O(
            a\^2)\)]],
  ", meaning that the effect of updating the reference values can be \
neglected.  Assume that differences between positions at the same locus are \
",
  StyleBox["O",
    FontSlant->"Italic"],
  "(",
  StyleBox["a",
    FontSlant->"Italic"],
  "), which holds under normal sexual inheritance.  ",
  "With help from ",
  ButtonBox["Equations ",
    ButtonData:>"ExactChangeInDWithTransmissionNoVariationInT",
    ButtonStyle->"Hyperlink"],
  
  CounterBox["NumberedEquation", 
    "ExactChangeInDWithTransmissionNoVariationInT"],
  ButtonBox[" ",
    ButtonData:>"ExactChangeInDWithTransmissionNoVariationInT",
    ButtonStyle->"Hyperlink"],
  "and",
  ButtonBox[" ",
    ButtonData:>"DPrimeAfterSelectionAtQLE",
    ButtonStyle->"Hyperlink"],
  
  CounterBox["NumberedEquation", "DPrimeAfterSelectionAtQLE"],
  ButtonBox[" ",
    ButtonData:>"DPrimeAfterSelectionAtQLE",
    ButtonStyle->"Hyperlink"],
  "we then get the full recursion for the associations over an entire \
generation:"
}], "Text",
  CellMargins->{{18.1875, 24.375}, {Inherited, Inherited}}],

Cell[TextData[{
  "\n",
  Cell[BoxData[
      \(TraditionalForm\`\(\(\[IndentingNewLine]\)\(D\_\[DoubleStruckCapitalA]\
\%\(\(\('\)\(\ \)\('\)\)\ '\)\ \ \  = \ \ \ \[Sum]\_\(\[DoubleStruckCapitalU] \
\[SubsetEqual] \[DoubleStruckCapitalW]\)t\_\(\[DoubleStruckCapitalA] \
\[LeftArrow] \[DoubleStruckCapitalU]\)\ \(\((D\_\[DoubleStruckCapitalU]\ \  + \
\ \ \(a\_\[DoubleStruckCapitalU]\) 
                    pq\_\[DoubleStruckCapitalU])\)\(\ \ \)\(.\)\(\
\[IndentingNewLine]\)\)\)\)\)]],
  "\n"
}], "NumberedEquation",
  CellMargins->{{18.1875, 24.375}, {Inherited, Inherited}},
  CellTags->"DTriplePrimeAtQLE"],

Cell[TextData[{
  "On setting ",
  Cell[BoxData[
      \(TraditionalForm\`D\_\[DoubleStruckCapitalA]\%\(\(\('\)\(\ \)\('\)\)\ \
'\)\)]],
  "  =  ",
  Cell[BoxData[
      \(TraditionalForm\`D\_\[DoubleStruckCapitalA]\)]],
  "  \[Congruent]  ",
  Cell[BoxData[
      \(TraditionalForm\`D\&~\)]],
  ", we get a QLE approximation for the ",
  "associations",
  " that is accurate to order ",
  StyleBox["O",
    FontSlant->"Italic"],
  "(",
  StyleBox["a",
    FontSlant->"Italic"],
  "):"
}], "Text",
  CellMargins->{{18.1875, 24.375}, {Inherited, Inherited}}],

Cell[TextData[{
  "\n",
  Cell[BoxData[
      \(TraditionalForm\`\(\(\[IndentingNewLine]\)\(D\&~\_\
\[DoubleStruckCapitalA]\ \ \  = \ \ \[Sum]\_\[DoubleStruckCapitalU] t\_\(\
\[DoubleStruckCapitalA] \[LeftArrow] \[DoubleStruckCapitalU]\)\ D\&~\_\
\[DoubleStruckCapitalU]\ \ \  + \ \ \ \[Sum]\_\[DoubleStruckCapitalU] t\_\(\
\[DoubleStruckCapitalA] \[LeftArrow] \[DoubleStruckCapitalU]\)\ \(a\_\
\[DoubleStruckCapitalU]\) \(\(pq\_\[DoubleStruckCapitalU]\)\(\ \)\(.\)\(\
\[IndentingNewLine]\)\)\)\)\)]],
  "\n"
}], "NumberedEquation",
  CellMargins->{{18.1875, 24.375}, {Inherited, Inherited}},
  CellTags->"implicitApproximationForDAtQLE"],

Cell[TextData[{
  "The first sum on the right is zero if the positions in \
\[DoubleStruckCapitalA] include more than one sex-of-origin.  That is because \
if \[DoubleStruckCapitalA] includes more than one sex-of-origin, then \
\[DoubleStruckCapitalU] in the first sum would have to include more than one \
sex-of-carrier.  But ",
  Cell[BoxData[
      \(TraditionalForm\`D\_\[DoubleStruckCapitalU]\)]],
  " is of order ",
  Cell[BoxData[
      \(TraditionalForm\`a\^2\)]],
  " if the positions in \[DoubleStruckCapitalU] include both \
sexes-of-carrier, since then ",
  Cell[BoxData[
      \(TraditionalForm\`D\_\[DoubleStruckCapitalU]\)]],
  " represents associations between alleles in two randomly chosen zygotes."
}], "Text",
  CellMargins->{{18.1875, 24.375}, {Inherited, Inherited}}],

Cell[TextData[{
  "\t ",
  ButtonBox["Equation ",
    ButtonData:>"implicitApproximationForDAtQLE",
    ButtonStyle->"Hyperlink"],
  
  CounterBox["NumberedEquation", "implicitApproximationForDAtQLE"],
  ButtonBox[" ",
    ButtonData:>"implicitApproximationForDAtQLE",
    ButtonStyle->"Hyperlink"],
  "is the main result of this section.  It gives the solutions for the \
associations implicitly:  the QLE value ",
  Cell[BoxData[
      \(TraditionalForm\`D\&~\_\[DoubleStruckCapitalA]\)]],
  " on the left side depends on the QLE values for the other associations, \
which appear as ",
  Cell[BoxData[
      \(TraditionalForm\`D\&~\_\[DoubleStruckCapitalU]\)]],
  " on the right side.  The relationship is linear (because of the linear \
form of the transmission ",
  ButtonBox["equation ",
    ButtonData:>"ExactChangeInDWithTransmissionNoVariationInT",
    ButtonStyle->"Hyperlink"],
  
  CounterBox["NumberedEquation", 
    "ExactChangeInDWithTransmissionNoVariationInT"],
  ButtonBox[")",
    ButtonData:>"ExactChangeInDWithTransmissionNoVariationInT",
    ButtonStyle->"Hyperlink"],
  ", and so the solution can always be found using standard matrix algebra.  \
Thus the ",
  Cell[BoxData[
      \(TraditionalForm\`D\&~\)]],
  " can be calculated directly, using standard matrix methods, given a set of \
transmission rules that specify the ",
  StyleBox["t",
    FontSlant->"Italic"],
  "s, a set of allele frequencies from which we can calculate ",
  Cell[BoxData[
      \(TraditionalForm\`pq\_\[DoubleStruckCapitalU]\)]],
  ", and a set of selection coefficients ",
  Cell[BoxData[
      \(TraditionalForm\`a\)]],
  ".  The next two sections illustrate how to do this by carrying out the \
calculations for autosomal genes in dioecious haploids and for autosomal, \
sex-linked, and cytoplasmic genes in diploids."
}], "Text",
  CellMargins->{{18.1875, 24.375}, {Inherited, Inherited}}]
}, Open  ]],

Cell[CellGroupData[{

Cell["\tAutosomal genes in haploids", "Subsection",
  CellMargins->{{18.1875, 24.375}, {Inherited, Inherited}},
  CellTags->"Autosomal genes in haploids"],

Cell[TextData[{
  "\tThe QLE approximation for autosomal inheritance in a haploid population \
with two sexes was found by ",
  ButtonBox["BT91",
    ButtonData:>"Barton & Turelli 1991",
    ButtonStyle->"Hyperlink"],
  ".  This section rederives their result to illustrate the new notation and \
how to use ",
  ButtonBox["Equation ",
    ButtonData:>"implicitApproximationForDAtQLE",
    ButtonStyle->"Hyperlink"],
  
  CounterBox["NumberedEquation", "implicitApproximationForDAtQLE"],
  ButtonBox[" ",
    ButtonData:>"implicitApproximationForDAtQLE",
    ButtonStyle->"Hyperlink"],
  "to find a QLE approximation."
}], "Text",
  CellMargins->{{18.1875, 24.375}, {Inherited, Inherited}}],

Cell[TextData[{
  "\tThe context for each gene now contains only its sex-of-carrier.  That is \
because an individual carries only one gene at each locus, rather than the \
two that must be distinguished in the case of diploids.  The comments \
following ",
  ButtonBox["Equation ",
    ButtonData:>"implicitApproximationForDAtQLE",
    ButtonStyle->"Hyperlink"],
  
  CounterBox["NumberedEquation", "implicitApproximationForDAtQLE"],
  ButtonBox[" ",
    ButtonData:>"implicitApproximationForDAtQLE",
    ButtonStyle->"Hyperlink"],
  "imply that for this case the first sum on its right side reduces to (",
  Cell[BoxData[
      FormBox[
        RowBox[{
          SubscriptBox["t", 
            RowBox[{"\[DoubleStruckCapitalA]", "\[LeftArrow]", 
              SubscriptBox["\[DoubleStruckCapitalA]", 
                StyleBox["f",
                  FontSlant->"Plain"]]}]], " ", 
          SubscriptBox[\(D\&~\), 
            SubscriptBox["\[DoubleStruckCapitalA]", 
              StyleBox["f",
                FontSlant->"Plain"]]]}], TraditionalForm]]],
  " + ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          SubscriptBox["t", 
            RowBox[{"\[DoubleStruckCapitalA]", "\[LeftArrow]", 
              SubscriptBox["\[DoubleStruckCapitalA]", 
                StyleBox["m",
                  FontSlant->"Plain"]]}]], " ", 
          SubscriptBox[\(D\&~\), 
            SubscriptBox["\[DoubleStruckCapitalA]", 
              StyleBox["m",
                FontSlant->"Plain"]]]}], TraditionalForm]]],
  "), where ",
  Cell[BoxData[
      FormBox[
        SubscriptBox["\[DoubleStruckCapitalA]", 
          StyleBox["f",
            FontSlant->"Plain"]], TraditionalForm]]],
  " stands for set \[DoubleStruckCapitalA] with the sexes-of-carrier for all \
its positions converted to f, and similarly for ",
  Cell[BoxData[
      FormBox[
        SubscriptBox["\[DoubleStruckCapitalA]", 
          StyleBox["m",
            FontSlant->"Plain"]], TraditionalForm]]],
  ".  The associations among a set of autosomal loci are equal in male and \
female zygotes, so ",
  Cell[BoxData[
      FormBox[
        SubscriptBox[\(D\&~\), 
          SubscriptBox["\[DoubleStruckCapitalA]", 
            StyleBox["f",
              FontSlant->"Plain"]]], TraditionalForm]]],
  " = ",
  Cell[BoxData[
      FormBox[
        SubscriptBox[\(D\&~\), 
          SubscriptBox["\[DoubleStruckCapitalA]", 
            StyleBox["m",
              FontSlant->"Plain"]]], TraditionalForm]]],
  ", and further those quantities must be equal to ",
  Cell[BoxData[
      \(TraditionalForm\`D\_\[DoubleStruckCapitalA]\)]],
  " on the left side of ",
  ButtonBox["Equation ",
    ButtonData:>"implicitApproximationForDAtQLE",
    ButtonStyle->"Hyperlink"],
  
  CounterBox["NumberedEquation", "implicitApproximationForDAtQLE"],
  ButtonBox[" ",
    ButtonData:>"implicitApproximationForDAtQLE",
    ButtonStyle->"Hyperlink"],
  "because all the positions in \[DoubleStruckCapitalA] must have the same \
sex-of-carrier.  With no sex differences in recombination we have ",
  Cell[BoxData[
      FormBox[
        SubscriptBox["t", 
          RowBox[{"\[DoubleStruckCapitalA]", "\[LeftArrow]", 
            SubscriptBox["\[DoubleStruckCapitalA]", 
              StyleBox["f",
                FontSlant->"Plain"]]}]], TraditionalForm]]],
  " = ",
  Cell[BoxData[
      FormBox[
        SubscriptBox["t", 
          RowBox[{"\[DoubleStruckCapitalA]", "\[LeftArrow]", 
            SubscriptBox["\[DoubleStruckCapitalA]", 
              StyleBox["m",
                FontSlant->"Plain"]]}]], TraditionalForm]]],
  " = ",
  Cell[BoxData[
      \(TraditionalForm\`\((1\  - \ r\_\[DoubleStruckCapitalA])\)/2\)]],
  ", where ",
  Cell[BoxData[
      \(TraditionalForm\`\((1\  - \ r\_\[DoubleStruckCapitalA])\)\)]],
  " is the probability that the loci in set \[DoubleStruckCapitalA] are not \
broken apart by recombination, and the factor of 1/2 accounts for the \
probability that genes in set \[DoubleStruckCapitalA] were inherited from a \
given parent."
}], "Text",
  CellMargins->{{18.1875, 24.375}, {Inherited, Inherited}}],

Cell["\tPutting those facts together gives the QLE approximation", "Text",
  CellMargins->{{18.1875, 24.375}, {Inherited, Inherited}}],

Cell[TextData[{
  "\n",
  Cell[BoxData[
      \(TraditionalForm\`\(\(\[IndentingNewLine]\)\(D\&~\_\
\[DoubleStruckCapitalA]\ \ \  = \ \ \(1\/r\_\[DoubleStruckCapitalA]\) \
\(\[Sum]\_\(\[DoubleStruckCapitalU] : U = A\)t\_\(\[DoubleStruckCapitalA] \
\[LeftArrow] \[DoubleStruckCapitalU]\)\ \(a\_\[DoubleStruckCapitalU]\) 
                pq\_\[DoubleStruckCapitalU]\)\ \ \  + \ \ \(\(O(
              a\^2)\)\(\ \ \)\(.\)\(\[IndentingNewLine]\)\)\)\)\)]],
  "\n"
}], "NumberedEquation",
  CellMargins->{{18.1875, 24.375}, {Inherited, Inherited}},
  CellTags->"DAtQLEInHaploids"],

Cell[TextData[{
  "This is equivalent to ",
  ButtonBox["BT91's",
    ButtonData:>"Barton & Turelli 1991",
    ButtonStyle->"Hyperlink"],
  " Equation (25).  Some superficial differences are caused by three changes \
in notation.  Their result is expressed in terms of recombination rates \
rather than transmission rates.  Second,  ",
  ButtonBox["BT91",
    ButtonData:>"Barton & Turelli 1991",
    ButtonStyle->"Hyperlink"],
  " separately defined within-male, within-female, and between-sex \
(non-random mating) selection coefficients;  all of these are included in the \
sum on the right side of ",
  ButtonBox["Equation ",
    ButtonData:>"DAtQLEInHaploids",
    ButtonStyle->"Hyperlink"],
  
  CounterBox["NumberedEquation", "DAtQLEInHaploids"],
  ButtonBox[".",
    ButtonData:>"DAtQLEInHaploids",
    ButtonStyle->"Hyperlink"],
  "  Last, they counted separately selection coefficients with different \
permutations of the same set of positions, which generates the combinatorial \
terms in their expression."
}], "Text",
  CellMargins->{{18.1875, 24.375}, {Inherited, Inherited}}]
}, Open  ]],

Cell[CellGroupData[{

Cell["\tAutosomal, sex-linked, and cytoplasmic genes in diploids", \
"Subsection",
  CellMargins->{{18.1875, 24.375}, {Inherited, Inherited}},
  CellTags->"Autosomal sex-linked and cytoplasmic genes in diploids"],

Cell["\<\
\tNow consider autosomal genes in a diploid population with two \
sexes.  The context for a gene now includes both its sex-of-carrier and \
sex-of-origin.  We allow for non-random mating and sex differences in \
selection and recombination.  To simplify the calculation, however, we will \
assume there is no genetic variation in recombination rates and no genomic \
imprinting (that is, an allele's sex-of-origin does not affect its \
expression).  The approach outlined here can be directly extended to allow \
for more than two sexes, as might be appropriate to describe a population \
with partial selfing.\
\>", "Text",
  CellMargins->{{18.1875, 24.375}, {Inherited, Inherited}}],

Cell[TextData[{
  "\tCareful consideration of ",
  ButtonBox["Equation ",
    ButtonData:>"implicitApproximationForDAtQLE",
    ButtonStyle->"Hyperlink"],
  
  CounterBox["NumberedEquation", "implicitApproximationForDAtQLE"],
  ButtonBox[" ",
    ButtonData:>"implicitApproximationForDAtQLE",
    ButtonStyle->"Hyperlink"],
  "shows that the associations fall into three cases.  Case (1) are \
associations among a set of positions \[DoubleStruckCapitalA] that include \
both sexes-of-carrier.  The QLE approximation for these associations is \
simply  ",
  Cell[BoxData[
      \(TraditionalForm\`D\&~\_\[DoubleStruckCapitalA]\)]],
  " = 0.  That is because these represent associations between genes in two \
or more randomly chosen zygotes."
}], "Text",
  CellMargins->{{18.1875, 24.375}, {Inherited, Inherited}}],

Cell[TextData[{
  "\tCase (2) are the associations between a set of positions that all have \
the same sex-of-carrier, but some have a male and others a female \
sex-of-origin.  This kind of association exists for some sets of positions \
(for example autosomal), but not others (for example, sets with only \
cytoplasmic loci).  If they do exist, ",
  ButtonBox["Equation ",
    ButtonData:>"implicitApproximationForDAtQLE",
    ButtonStyle->"Hyperlink"],
  
  CounterBox["NumberedEquation", "implicitApproximationForDAtQLE"],
  " gives the QLE approximation:"
}], "Text",
  CellMargins->{{18.1875, 24.375}, {Inherited, Inherited}}],

Cell[TextData[{
  "\n",
  Cell[BoxData[
      \(TraditionalForm\`\(\(\[IndentingNewLine]\)\(D\&~\_\
\[DoubleStruckCapitalA]\ \ \  = \ \ \ \[Sum]\_\(\[DoubleStruckCapitalU] : U = \
A\)t\_\(\[DoubleStruckCapitalA] \[LeftArrow] \[DoubleStruckCapitalU]\)\ \(a\_\
\[DoubleStruckCapitalU]\) \(\(pq\_\[DoubleStruckCapitalU]\)\(\ \)\(.\)\(\
\[IndentingNewLine]\)\)\)\)\)]],
  "\n"
}], "NumberedEquation",
  CellMargins->{{18.1875, 24.375}, {Inherited, Inherited}},
  CellTags->"DatQLECase2"],

Cell[TextData[{
  "These associations come from non-random mating in the previous generation: \
 associations between genes with different sexes-of-origin within an \
individual appear when there are correlations between the genotypes of mating \
males and females in the previous generation.  These associations, which \
include Hardy-Weinberg disequilibria (an excess or deficit of heterozygotes), \
are zero under random mating because then the selection coefficients for \
positions with both sexes-of-carrier are of order ",
  Cell[BoxData[
      \(TraditionalForm\`a\^2\)]],
  ".  The transmission coefficient ",
  Cell[BoxData[
      \(TraditionalForm\`t\_\(\[DoubleStruckCapitalA] \[LeftArrow] \
\[DoubleStruckCapitalU]\)\)]],
  " can be translated into recombination rates according to the way that the \
genes in set ",
  StyleBox["A",
    FontSlant->"Italic"],
  " are inherited, as discussed above in the section on transmission."
}], "Text",
  CellMargins->{{18.1875, 24.375}, {Inherited, Inherited}}],

Cell[TextData[{
  "\tCase (3), the last category of association, is when all positions in \
\[DoubleStruckCapitalA] have the same sex-of-carrier and all have the same \
sex-of-origin.  Here ",
  Cell[BoxData[
      \(TraditionalForm\`D\_\[DoubleStruckCapitalA]\)]],
  " represents an association among genes within a single individual that \
were inherited from the same parent.  The QLE approximations for this case \
depend on how the genes in set \[DoubleStruckCapitalA] are inherited.  They \
can be calculated by first writing out ",
  ButtonBox["Equation ",
    ButtonData:>"implicitApproximationForDAtQLE",
    ButtonStyle->"Hyperlink"],
  
  CounterBox["NumberedEquation", "implicitApproximationForDAtQLE"],
  " for the four possible cases ",
  Cell[BoxData[
      FormBox[
        SubscriptBox[\(D\&~\), 
          SubscriptBox["A", 
            RowBox[{
              StyleBox["f",
                FontSlant->"Plain",
                FontVariations->{"CompatibilityType"->0}], 
              StyleBox[" ",
                FontVariations->{"CompatibilityType"->0}], 
              StyleBox["f",
                FontSlant->"Plain",
                FontVariations->{"CompatibilityType"->0}]}]]], 
        TraditionalForm]]],
  ",  ",
  Cell[BoxData[
      FormBox[
        SubscriptBox[\(D\&~\), 
          SubscriptBox["A", 
            RowBox[{
              StyleBox["f",
                FontSlant->"Plain",
                FontVariations->{"CompatibilityType"->0}], 
              StyleBox[" ",
                FontVariations->{"CompatibilityType"->0}], 
              StyleBox["m",
                FontSlant->"Plain",
                FontVariations->{"CompatibilityType"->0}]}]]], 
        TraditionalForm]]],
  ", ",
  Cell[BoxData[
      FormBox[
        SubscriptBox[\(D\&~\), 
          SubscriptBox["A", 
            RowBox[{
              StyleBox["m",
                FontSlant->"Plain",
                FontVariations->{"CompatibilityType"->0}], 
              StyleBox[" ",
                FontVariations->{"CompatibilityType"->0}], 
              StyleBox["f",
                FontSlant->"Plain",
                FontVariations->{"CompatibilityType"->0}]}]]], 
        TraditionalForm]]],
  ", and ",
  Cell[BoxData[
      FormBox[
        SubscriptBox[\(D\&~\), 
          SubscriptBox["A", 
            RowBox[{
              StyleBox["m",
                FontSlant->"Plain",
                FontVariations->{"CompatibilityType"->0}], 
              StyleBox[" ",
                FontVariations->{"CompatibilityType"->0}], 
              StyleBox["m",
                FontSlant->"Plain",
                FontVariations->{"CompatibilityType"->0}]}]]], 
        TraditionalForm]]],
  ", where for example ",
  Cell[BoxData[
      FormBox[
        SubscriptBox["A", 
          RowBox[{
            StyleBox["f",
              FontSlant->"Plain",
              FontVariations->{"CompatibilityType"->0}], 
            StyleBox[" ",
              FontVariations->{"CompatibilityType"->0}], 
            StyleBox["m",
              FontSlant->"Plain",
              FontVariations->{"CompatibilityType"->0}]}]], 
        TraditionalForm]]],
  " means that all positions in set ",
  StyleBox["A",
    FontSlant->"Italic"],
  " have a female sex-of-carrier and a male sex-of-origin.  Next, delete from \
those equations any of the ",
  Cell[BoxData[
      \(TraditionalForm\`D\_A\)]],
  " that do not exist, given the mode of inheritance.  (For example, ",
  Cell[BoxData[
      FormBox[
        SubscriptBox[\(D\&~\), 
          SubscriptBox["A", 
            RowBox[{
              StyleBox["m",
                FontSlant->"Plain"], " ", 
              StyleBox["m",
                FontSlant->"Plain"]}]]], TraditionalForm]]],
  " does not exist when all genes in set \[DoubleStruckCapitalA] are \
X-linked, since males do not pass X-chromosomes to their sons.)  Last, solve \
the equations for the remaining ",
  Cell[BoxData[
      \(TraditionalForm\`D\&~\)]],
  ".  That procedure leads to the following results for autosomal, X-linked, \
Y-linked, and cytoplasmic genes.  We will assume that selection and \
transmission do not depend on a gene's sex-of-origin (e.g., there is no \
genomic imprinting)."
}], "Text",
  CellMargins->{{18.1875, 24.375}, {Inherited, Inherited}}],

Cell[TextData[{
  "\tWhen all the genes in set ",
  StyleBox["A",
    FontSlant->"Italic"],
  " are autosomal, all four of the possible Case (3) associations exist.  \
Solving ",
  ButtonBox["Equation ",
    ButtonData:>"implicitApproximationForDAtQLE",
    ButtonStyle->"Hyperlink"],
  
  CounterBox["NumberedEquation", "implicitApproximationForDAtQLE"],
  " then gives"
}], "Text",
  CellMargins->{{18.1875, 24.375}, {Inherited, Inherited}}],

Cell[TextData[{
  "\n",
  Cell[BoxData[
      FormBox[
        RowBox[{"\[IndentingNewLine]", 
          RowBox[{
            RowBox[{
              SubscriptBox[\(D\&~\), 
                SubscriptBox["\[DoubleStruckCapitalA]", 
                  RowBox[{
                    StyleBox["f",
                      FontSlant->"Plain"], " ", 
                    StyleBox["x",
                      FontSlant->"Italic"]}]]], "   ", "=", "   ", 
              RowBox[{
                SubscriptBox[\(D\&~\), 
                  SubscriptBox["\[DoubleStruckCapitalA]", 
                    RowBox[{
                      StyleBox["m",
                        FontSlant->"Plain"], " ", 
                      StyleBox["x",
                        FontSlant->"Italic"]}]]], "   ", "=", 
                "\[IndentingNewLine]", "\[IndentingNewLine]", "\t", 
                RowBox[{
                  RowBox[{"(", 
                    FractionBox[\(\(pq\_A\)\(\ \ \)\), 
                      RowBox[{
                        SubsuperscriptBox["r", "A", 
                          StyleBox["f",
                            FontSlant->"Plain"]], " ", "+", " ", 
                        SubsuperscriptBox["r", "A", 
                          StyleBox["m",
                            FontSlant->"Plain"]]}]], ")"}], 
                  RowBox[{"{", " ", 
                    RowBox[{
                      RowBox[{
                        RowBox[{"[", 
                          RowBox[{
                            SubscriptBox["a", 
                              SubscriptBox["A", 
                                StyleBox["x",
                                  FontSlant->"Italic"]]], " ", "+", " ", 
                            RowBox[{"T", "(", 
                              SubscriptBox["A", 
                                StyleBox["xx",
                                  FontSlant->"Italic"]], ")"}]}], "]"}], " ", 
                        
                        RowBox[{"(", " ", 
                          RowBox[{"1", " ", "+", " ", 
                            SubsuperscriptBox["r", "A", 
                              StyleBox[\(\(~\)\(x\)\),
                                FontSlant->"Italic"]]}], ")"}]}], "  ", "+", 
                      "  ", 
                      RowBox[{
                        RowBox[{"[", 
                          RowBox[{
                            SubscriptBox["a", 
                              SubscriptBox["A", 
                                RowBox[{"~", 
                                  StyleBox["x",
                                    FontSlant->"Italic"]}]]], " ", "+", 
                            " ", \(T(A\_\(x~x\))\)}], "]"}], " ", 
                        RowBox[{"(", " ", 
                          RowBox[{"1", " ", "-", " ", 
                            SubsuperscriptBox["r", "A", 
                              StyleBox["x",
                                FontSlant->"Italic"]]}], ")"}]}]}], " ", 
                    "}"}]}]}]}], 
            StyleBox[" ",
              FontSlant->"Plain"], 
            StyleBox[",",
              FontSlant->"Plain"], "\[IndentingNewLine]"}]}], 
        TraditionalForm]]],
  "\n"
}], "NumberedEquation",
  CellMargins->{{18.1875, 24.375}, {Inherited, Inherited}},
  CellTags->"QLECase3Autosomes"],

Cell["where", "Text",
  CellMargins->{{18.1875, 24.375}, {Inherited, Inherited}}],

Cell[TextData[{
  "\n",
  Cell[BoxData[
      FormBox[
        RowBox[{"\[IndentingNewLine]", 
          RowBox[{\(T(A\_\(x\ y\))\), "   ", "=", "   ", 
            RowBox[{\(\[Sum]\+\(S + T = A\)\), " ", 
              RowBox[{
                SubscriptBox["t", 
                  RowBox[{\(A\_\(x\ y\)\), "\[LeftArrow]", " ", 
                    RowBox[{"{", 
                      RowBox[{
                        SubscriptBox["S", 
                          RowBox[{
                            StyleBox["y",
                              FontSlant->"Italic"], "  ", 
                            StyleBox["f",
                              FontSlant->"Plain"]}]], 
                        SubscriptBox["T", 
                          RowBox[{"y", " ", 
                            StyleBox["m",
                              FontSlant->"Plain"]}]]}], "}"}]}]], " ", 
                RowBox[{
                  SubscriptBox["a", 
                    RowBox[{
                      SubscriptBox["S", 
                        StyleBox["f",
                          FontSlant->"Plain"]], 
                      SubscriptBox["T", 
                        StyleBox["m",
                          FontSlant->"Plain"]]}]], " ", ".", 
                  "\[IndentingNewLine]"}]}]}]}]}], TraditionalForm]]],
  "\n"
}], "NumberedEquation",
  CellMargins->{{18.1875, 24.375}, {Inherited, Inherited}},
  CellTags->"TDefn"],

Cell[TextData[{
  "Here ",
  Cell[BoxData[
      \(TraditionalForm\`r\_A\%x\)]],
  " is the recombination rate for set ",
  StyleBox["A",
    FontSlant->"Italic"],
  " in sex ",
  StyleBox["x",
    FontSlant->"Italic"],
  ", where ",
  StyleBox["x",
    FontSlant->"Italic"],
  " can take the values m and f, and ~",
  StyleBox["x",
    FontSlant->"Italic"],
  " stands for the opposite sex of ",
  StyleBox["x",
    FontSlant->"Italic"],
  " (for example, if ",
  StyleBox["x",
    FontSlant->"Italic"],
  " = f then ~",
  StyleBox["x",
    FontSlant->"Italic"],
  " = m).  The term ",
  StyleBox["T",
    FontSlant->"Italic"],
  " results from non-random mating, which creates associations between \
alleles inherited from different parents in the next generation.  These \
alleles are brought together in single gametes by recombination, producing \
associations within the same gametic genome (i.e., linkage disequilibria) two \
generations later.  The summation in (",
  
  CounterBox["NumberedEquation", "TDefn"],
  ") is over all the different ways that the set of loci ",
  StyleBox["A",
    FontSlant->"Italic"],
  " can be partitioned.  With ",
  StyleBox["A",
    FontSlant->"Italic"],
  " = {",
  StyleBox["i",
    FontSlant->"Italic"],
  ", ",
  StyleBox["j",
    FontSlant->"Italic"],
  ", ",
  StyleBox["k",
    FontSlant->"Italic"],
  "}, for example, the sum includes six terms:  ",
  StyleBox["S",
    FontSlant->"Italic"],
  " ",
  Cell[BoxData[
      FormBox[
        RowBox[{"=", 
          StyleBox[\({i}\),
            FontColor->RGBColor[1, 0, 0]]}], TraditionalForm]]],
  " and ",
  StyleBox["T",
    FontSlant->"Italic"],
  " = {",
  StyleBox["j",
    FontSlant->"Italic"],
  ", ",
  StyleBox["k",
    FontSlant->"Italic"],
  "}, ",
  StyleBox["S",
    FontSlant->"Italic"],
  " = {",
  StyleBox["j",
    FontSlant->"Italic"],
  ", ",
  StyleBox["k",
    FontSlant->"Italic"],
  "} and ",
  StyleBox["T",
    FontSlant->"Italic"],
  " = {",
  StyleBox["i",
    FontSlant->"Italic"],
  "}, ",
  StyleBox["S",
    FontSlant->"Italic"],
  " = ",
  Cell[BoxData[
      FormBox[
        StyleBox[\({j}\),
          FontColor->RGBColor[1, 0, 0]], TraditionalForm]]],
  " and ",
  StyleBox["T",
    FontSlant->"Italic"],
  " = {",
  StyleBox["i",
    FontSlant->"Italic"],
  ", ",
  StyleBox["k",
    FontSlant->"Italic"],
  "}, etc..  ",
  StyleBox["T",
    FontSlant->"Italic"],
  ", which will appear in results below, vanishes under random mating.  The \
selection coefficients ",
  Cell[BoxData[
      FormBox[
        SubscriptBox["a", 
          SubscriptBox["A", 
            StyleBox["f",
              FontSlant->"Plain"]]], TraditionalForm]]],
  " and  ",
  Cell[BoxData[
      FormBox[
        SubscriptBox["a", 
          SubscriptBox["A", 
            StyleBox["m",
              FontSlant->"Italic"]]], TraditionalForm]]],
  " reflect epistatic selection within each sex, and vanish when there is no \
epistasis."
}], "Text",
  CellMargins->{{18.1875, 24.375}, {Inherited, Inherited}}],

Cell[TextData[{
  "\tWhen ",
  StyleBox["A",
    FontSlant->"Italic"],
  " is a set of either all X-linked genes or a mixture of X-linked and \
autosomal genes, ",
  Cell[BoxData[
      FormBox[
        SubscriptBox[\(D\&~\), 
          SubscriptBox["A", 
            RowBox[{
              StyleBox["m",
                FontSlant->"Plain"], " ", 
              StyleBox["m",
                FontSlant->"Plain"]}]]], TraditionalForm]]],
  " does not exist.  Solving ",
  ButtonBox["Equation ",
    ButtonData:>"implicitApproximationForDAtQLE",
    ButtonStyle->"Hyperlink"],
  
  CounterBox["NumberedEquation", "implicitApproximationForDAtQLE"],
  " for the remaining three kinds of associations in Case (3) gives"
}], "Text",
  CellMargins->{{18.1875, 24.375}, {Inherited, Inherited}}],

Cell[TextData[{
  "\n",
  Cell[BoxData[
      FormBox[
        RowBox[{"\[IndentingNewLine]", 
          RowBox[{
            RowBox[{
              SubscriptBox[\(D\&~\), 
                SubscriptBox["\[DoubleStruckCapitalA]", 
                  RowBox[{
                    StyleBox["f",
                      FontSlant->"Plain"], " ", 
                    StyleBox["f",
                      FontSlant->"Plain"]}]]], "   ", "=", "   ", 
              RowBox[{
                SubscriptBox[\(D\&~\), 
                  SubscriptBox["\[DoubleStruckCapitalA]", 
                    RowBox[{
                      StyleBox["m",
                        FontSlant->"Plain"], " ", 
                      StyleBox["f",
                        FontSlant->"Plain"]}]]], "   ", "=", "    ", 
                RowBox[{
                  FractionBox[\(pq\_A\), 
                    RowBox[{
                      RowBox[{
                        SubsuperscriptBox["r", "A", 
                          StyleBox["f",
                            FontSlant->"Plain"]], " ", 
                        RowBox[{"(", 
                          RowBox[{"2", " ", "-", " ", 
                            SubsuperscriptBox["r", "A", 
                              StyleBox["m",
                                FontSlant->"Plain"]]}], ")"}]}], "   ", "+", 
                      "   ", 
                      SubsuperscriptBox["r", "A", 
                        StyleBox["m",
                          FontSlant->"Plain"]]}]], "  ", 
                  RowBox[{"{", 
                    RowBox[{
                      RowBox[{"2", " ", "[", 
                        RowBox[{
                          SubscriptBox["a", 
                            SubscriptBox["A", 
                              StyleBox["f",
                                FontSlant->"Plain"]]], "+", 
                          " ", \(T(A\_ff)\)}], "]"}], "  ", "+", "  ", 
                      RowBox[{\([a\_\(A\_m\)\  + \ T(A\_fm)]\), 
                        RowBox[{"(", 
                          RowBox[{"1", " ", "-", " ", 
                            SubsuperscriptBox["r", "A", 
                              StyleBox["f",
                                FontSlant->"Plain"]]}], ")"}]}]}], " ", 
                    "}"}]}]}]}], "  ", ",", "\[IndentingNewLine]", 
            "\[IndentingNewLine]", "\[IndentingNewLine]", 
            RowBox[{
              SubscriptBox[\(D\&~\), 
                SubscriptBox["\[DoubleStruckCapitalA]", 
                  RowBox[{
                    StyleBox["f",
                      FontSlant->"Plain"], " ", 
                    StyleBox["m",
                      FontSlant->"Plain"]}]]], "  ", "=", "   ", 
              RowBox[{
                FractionBox[\(pq\_A\), 
                  RowBox[{
                    RowBox[{
                      SubsuperscriptBox["r", "A", 
                        StyleBox["f",
                          FontSlant->"Plain"]], " ", 
                      RowBox[{"(", 
                        RowBox[{"2", " ", "-", " ", 
                          SubsuperscriptBox["r", "A", 
                            StyleBox["m",
                              FontSlant->"Plain"]]}], ")"}]}], "  ", "+", 
                    "  ", 
                    SubsuperscriptBox["r", "A", 
                      StyleBox["m",
                        FontSlant->"Plain"]]}]], " ", 
                RowBox[{
                  RowBox[{"{", 
                    RowBox[{
                      RowBox[{
                        RowBox[{"2", " ", "[", 
                          RowBox[{
                            SubscriptBox["a", 
                              SubscriptBox["A", 
                                StyleBox["f",
                                  FontSlant->"Plain"]]], " ", "+", 
                            " ", \(T(A\_ff)\)}], "]"}], 
                        RowBox[{"(", 
                          RowBox[{"1", "  ", "-", "  ", 
                            SubsuperscriptBox["r", "A", 
                              StyleBox["m",
                                FontSlant->"Plain"]]}], ")"}]}], "  ", "+", 
                      "  ", 
                      RowBox[{\([a\_\(A\_m\)\ \  + \ \ T(A\_fm)]\), 
                        RowBox[{"(", 
                          RowBox[{"1", "+", " ", 
                            SubsuperscriptBox["r", "A", 
                              StyleBox["f",
                                FontSlant->"Plain"]]}], ")"}]}]}], " ", "}"}],
                   "  ", "."}]}]}]}]}], TraditionalForm]]],
  "\n\n"
}], "NumberedEquation",
  CellMargins->{{18.1875, 24.375}, {Inherited, Inherited}},
  CellTags->"QLECase3XLinkage"],

Cell[TextData[{
  "\tWhen ",
  StyleBox["A",
    FontSlant->"Italic"],
  " is a mixture of cytoplasmic and autosomal genes, or only a set of \
cytoplasmic genes, then ",
  Cell[BoxData[
      FormBox[
        SubscriptBox[\(D\&~\), 
          SubscriptBox["A", 
            RowBox[{
              StyleBox["f",
                FontSlant->"Plain"], " ", 
              StyleBox["m",
                FontSlant->"Plain"]}]]], TraditionalForm]]],
  " and ",
  Cell[BoxData[
      FormBox[
        SubscriptBox[\(D\&~\), 
          SubscriptBox["A", 
            RowBox[{
              StyleBox["m",
                FontSlant->"Plain"], " ", 
              StyleBox["m",
                FontSlant->"Plain"]}]]], TraditionalForm]]],
  " do not exist.  The remaining two kinds of Case 3 ",
  "associations",
  " are"
}], "Text",
  CellMargins->{{18.1875, 24.375}, {Inherited, Inherited}}],

Cell[TextData[{
  "\n",
  Cell[BoxData[
      FormBox[
        RowBox[{"\[IndentingNewLine]", "\[IndentingNewLine]", 
          RowBox[{
            SubscriptBox[\(D\&~\), 
              SubscriptBox["\[DoubleStruckCapitalA]", 
                RowBox[{
                  StyleBox["f",
                    FontSlant->"Plain"], " ", 
                  StyleBox["f",
                    FontSlant->"Plain"]}]]], "   ", "=", "   ", 
            RowBox[{
              SubscriptBox[\(D\&~\), 
                SubscriptBox["\[DoubleStruckCapitalA]", 
                  RowBox[{
                    StyleBox["m",
                      FontSlant->"Plain"], " ", 
                    StyleBox["f",
                      FontSlant->"Plain"]}]]], "   ", "=", "  ", 
              RowBox[{
                RowBox[{
                  FractionBox[\(\(pq\_A\)\(\ \)\), 
                    SubsuperscriptBox["r", "A", 
                      StyleBox["f",
                        FontSlant->"Plain"]]], "[", 
                  RowBox[{
                    SubscriptBox["a", 
                      SubscriptBox["A", 
                        StyleBox["f",
                          FontSlant->"Plain"]]], "+", \(T(A\_ff)\)}], "]"}], 
                "  ", ".", "\[IndentingNewLine]", 
                "\[IndentingNewLine]"}]}]}]}], TraditionalForm]]],
  "\n"
}], "NumberedEquation",
  CellMargins->{{18.1875, 24.375}, {Inherited, Inherited}},
  CellTags->"QLECase3CytoplasmicGenes"],

Cell[TextData[{
  "If ",
  StyleBox["A",
    FontSlant->"Italic"],
  " has only cytoplasmically-inherited genes, then ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          SubsuperscriptBox["r", "A", 
            StyleBox["f",
              FontSlant->"Plain"]], "  ", "=", "  ", "0"}], 
        TraditionalForm]]],
  " and that expression becomes undefined.  In this situation, there is no \
recombination to break down associations generated by selection, so they \
become large and the QLE approximation fails."
}], "Text",
  CellMargins->{{18.1875, 24.375}, {Inherited, Inherited}}],

Cell[TextData[{
  "\tA similar situation occurs with Y-linkage.  When ",
  StyleBox["A",
    FontSlant->"Italic"],
  " is a set of Y-linked genes or a mixture of Y-linked and autosomal genes, \
the only kind of Case 3 association that exists is:"
}], "Text",
  CellMargins->{{18.1875, 24.375}, {Inherited, Inherited}}],

Cell[TextData[{
  "\n",
  Cell[BoxData[
      FormBox[
        RowBox[{"\[IndentingNewLine]", "\[IndentingNewLine]", 
          
          RowBox[{\(D\&~\_\(\[DoubleStruckCapitalA]\_\(m\ m\)\)\), "   ", "=",
             "  ", 
            RowBox[{
              RowBox[{
                FractionBox[\(pq\_A\), 
                  SubsuperscriptBox["r", "A", 
                    StyleBox["m",
                      FontSlant->"Plain"]]], " ", "[", 
                RowBox[{
                  SubscriptBox["a", 
                    SubscriptBox[
                      StyleBox["A",
                        FontSlant->"Italic"], 
                      StyleBox["m",
                        FontSlant->"Plain"]]], "  ", "+", 
                  "  ", \(T(A\_mm)\)}], "]"}], "  ", ".", 
              "\[IndentingNewLine]", "\[IndentingNewLine]"}]}]}], 
        TraditionalForm]]],
  "\n"
}], "NumberedEquation",
  CellMargins->{{18.1875, 24.375}, {Inherited, Inherited}},
  CellTags->"QLECase3YLinkage"],

Cell[TextData[{
  "If ",
  StyleBox["A",
    FontSlant->"Italic"],
  " includes only Y-linked loci, then ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          SubsuperscriptBox["r", "A", 
            StyleBox["m",
              FontSlant->"Plain"]], " ", "=", " ", "0"}], TraditionalForm]]],
  " and there is no QLE approximation for ",
  Cell[BoxData[
      \(TraditionalForm\`D\&~\_\(\[DoubleStruckCapitalA]\_\(m\ m\)\)\)]],
  "."
}], "Text",
  CellMargins->{{18.1875, 24.375}, {Inherited, Inherited}}],

Cell[TextData[{
  "\tWe will stop our inventory of the Case 3 associations at this point.  \
There can be kinds of associations that are not discussed above, for example \
between cytoplasmic and X-linked genes, and associations between genes with \
more than 2 modes of inheritance (cf. Asmussen and Orive, ",
  ButtonBox["2000",
    ButtonData:>"Asmussen & Orive 2000",
    ButtonStyle->"Hyperlink"],
  ").  Those can be calculated, however, from ",
  ButtonBox["Equation ",
    ButtonData:>"implicitApproximationForDAtQLE",
    ButtonStyle->"Hyperlink"],
  
  CounterBox["NumberedEquation", "implicitApproximationForDAtQLE"],
  " using the same method.  Examples showing how this can be done with ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " are given in Appendix 4."
}], "Text",
  CellMargins->{{18.1875, 24.375}, {Inherited, Inherited}}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["(ii) Changes in allele frequencies at QLE", "Subsubtitle",
  CellMargins->{{18.1875, 24.375}, {Inherited, Inherited}}],

Cell[TextData[{
  "\tWhen a population is in quasi-linkage equilibrium, changes in allele \
frequencies can be approximated by simple expressions.  The exact expression \
for allele frequency change is given by ",
  ButtonBox["Equation ",
    ButtonData:>"ExactDeltaP",
    ButtonStyle->"Hyperlink"],
  
  CounterBox["NumberedEquation", "ExactDeltaP"],
  ".  The QLE approximation for ",
  Cell[BoxData[
      \(TraditionalForm\`\[CapitalDelta]p\_\[DoubleStruckI]\)]],
  " is found by substituting into that equation the QLE approximations for \
the associations.  We saw in the previous section that the approximations for \
the ",
  StyleBox["D",
    FontSlant->"Italic"],
  " depend on the specifics of the genetic system that is being modelled.  \
When the model consists of diploid autosomal loci, for example, the \
associations are given by ",
  ButtonBox["Equations ",
    ButtonData:>"DatQLECase2",
    ButtonStyle->"Hyperlink"],
  
  CounterBox["NumberedEquation", "DatQLECase2"],
  ButtonBox[" ",
    ButtonData:>"DatQLECase2",
    ButtonStyle->"Hyperlink"],
  "and",
  ButtonBox[" ",
    ButtonData:>"QLECase3Autosomes",
    ButtonStyle->"Hyperlink"],
  
  CounterBox["NumberedEquation", "QLECase3Autosomes"],
  "."
}], "Text",
  CellMargins->{{18.1875, 24.375}, {Inherited, Inherited}}]
}, Closed]]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[StyleBox["5. Mutation and migration",
  FontWeight->"Bold"]], "Subtitle",
  CellMargins->{{18, Inherited}, {Inherited, Inherited}}],

Cell["\<\
 \tMutation and migration are two other deterministic forces that \
change the genetic composition of a population.  This section shows how they \
change allele frequencies and the associations between loci. \
\>", "Text",
  CellMargins->{{18, Inherited}, {Inherited, Inherited}}],

Cell[CellGroupData[{

Cell["(i) Mutation", "Subsubtitle",
  CellMargins->{{18.1875, 24.375}, {Inherited, Inherited}},
  CellTags->"Mutation"],

Cell[TextData[{
  " \tWhile the effects of mutation on allele frequencies have been \
understood since Haldane (",
  ButtonBox["1927",
    ButtonData:>"Haldane 1927",
    ButtonStyle->"Hyperlink"],
  "), its effects on associations among loci have not been fully worked out.  \
Indeed, it seems to us that the general case, in which there is an arbitrary \
matrix of mutation rates between alternative alleles, does not lead to simple \
expressions.  Burger (",
  ButtonBox["2000",
    ButtonData:>"Burger 2000",
    ButtonStyle->"Hyperlink"],
  ", p. 190) gives expressions for the effects of 'random walk' mutation, in \
which the change in allelic effect ",
  Cell[BoxData[
      \(TraditionalForm\`X\_\[DoubleStruckI]\)]],
  " has a distribution independent of its current value, and for 'House of \
Cards' mutation, in which the absolute value of the new mutation has a \
constant distribution.  ",
  StyleBox["Baake (",
    FontColor->RGBColor[1, 0, 0]],
  StyleBox[ButtonBox["2001",
    ButtonData:>"Baake 2001",
    ButtonStyle->"Hyperlink"],
    FontColor->RGBColor[1, 0, 0]],
  StyleBox[") gives an explicit solution for the effects of mutation and \
recombination which applies with multiple alleles, but this requires the \
assumption that no more than one cross-over occurs at any time. ",
    FontColor->RGBColor[1, 0, 0]],
  "Here, we give the general result for two alleles at each locus;  see ",
  ButtonBox["Appendix 2 for details",
    ButtonData:>"Appendix: Mutation",
    ButtonStyle->"Hyperlink"],
  ".  Denote the mutation rate at position \[DoubleStruckI] from allele 0 to \
allele 1 as ",
  Cell[BoxData[
      \(TraditionalForm\`u\_\[DoubleStruckI]\)]],
  " and the reverse mutation rate from 1 to 0 as ",
  Cell[BoxData[
      \(TraditionalForm\`v\_\[DoubleStruckI]\)]],
  ".  The change in frequency of allele 1 at position \[DoubleStruckI] caused \
by mutation is:"
}], "Text",
  CellMargins->{{18.1875, 24.375}, {Inherited, Inherited}}],

Cell[TextData[{
  "\n",
  Cell[BoxData[
      \(TraditionalForm\`\(\(\[IndentingNewLine]\)\(\[CapitalDelta]p\_\
\[DoubleStruckI]\ \  = \ \ v\_\[DoubleStruckI]\ q\_\[DoubleStruckI]\ \  - \ \ \
\(\(u\_\[DoubleStruckI]\)\(\ \)\(p\_\[DoubleStruckI]\)\(\[IndentingNewLine]\)\
\)\)\)\)]],
  "\n"
}], "NumberedEquation",
  CellMargins->{{18.1875, 24.375}, {Inherited, Inherited}},
  CellTags->"deltaPMutation"],

Cell[TextData[{
  "(Haldane, ",
  ButtonBox["1927",
    ButtonData:>"Haldane 1927",
    ButtonStyle->"Hyperlink"],
  ").  The associations after mutation are"
}], "Text",
  CellMargins->{{18.1875, 24.375}, {Inherited, Inherited}}],

Cell[TextData[{
  "\n",
  Cell[BoxData[
      \(TraditionalForm\`\(\(\[IndentingNewLine]\)\(\(D\_\
\[DoubleStruckCapitalA]\%\(\(\ \)\(\('\)\(\ \)\('\)\)\)\ \  = \ \ D\_\
\[DoubleStruckCapitalA]\ \ \(\[Product]\+\(i \[Element] \
\[DoubleStruckCapitalA]\)\((1\  - \ u\_\[DoubleStruckI]\  - \ 
                v\_\[DoubleStruckI])\)\)\)\(\ \
\)\(,\)\(\[IndentingNewLine]\)\)\)\)]],
  "\n"
}], "NumberedEquation",
  CellMargins->{{18.1875, 24.375}, {Inherited, Inherited}},
  CellTags->"DAAfterMutation"],

Cell["\<\
where the reference values are equal to the current (post-mutation) \
allele frequencies.  This result shows that mutation erodes the associations. \
 A striking fact is that the rate at which they decline depends only on the \
mutation rates at the positions involved, and not on the allele frequencies \
or other properties of the genetic state of the population.\
\>", "Text",
  CellMargins->{{18.1875, 24.375}, {Inherited, Inherited}}]
}, Open  ]],

Cell[CellGroupData[{

Cell["(ii) Migration", "Subsubtitle",
  CellMargins->{{18.1875, 24.375}, {Inherited, Inherited}},
  CellTags->"Migration"],

Cell["\<\
 \tThe effects of migration on single loci were found by Wright \
(1931), and later workers have understood that migration can generate \
associations between loci.  General results for the effects of migration on \
associations, however, have apparently not been worked out previously.\
\>", \
"Text",
  CellMargins->{{18.1875, 24.375}, {Inherited, Inherited}}],

Cell["\<\
\tThe change in the frequency of allele 1 at position \
\[DoubleStruckI] caused by migration is\
\>", "Text",
  CellMargins->{{18.1875, 24.375}, {Inherited, Inherited}}],

Cell[TextData[{
  "\n",
  Cell[BoxData[
      FormBox[
        RowBox[{"\[IndentingNewLine]", 
          RowBox[{
            RowBox[{\(\[CapitalDelta]p\_\[DoubleStruckI]\), "  ", "=", "  ", 
              RowBox[{"m", "(", 
                RowBox[{
                  SubsuperscriptBox["p", "\[DoubleStruckI]", 
                    StyleBox["M",
                      FontSlant->"Plain"]], "  ", "-", "  ", 
                  SubsuperscriptBox["p", "\[DoubleStruckI]", 
                    StyleBox["R",
                      FontSlant->"Plain"]]}], ")"}]}], "  ", ",", 
            "\[IndentingNewLine]"}]}], TraditionalForm]]],
  "\n"
}], "NumberedEquation",
  CellMargins->{{18.1875, 24.375}, {Inherited, Inherited}},
  CellTags->"deltaPMigration"],

Cell[TextData[{
  "where ",
  Cell[BoxData[
      FormBox[
        SubsuperscriptBox["p", "\[DoubleStruckI]", 
          StyleBox["M",
            FontSlant->"Plain"]], TraditionalForm]]],
  " and ",
  Cell[BoxData[
      FormBox[
        SubsuperscriptBox["p", "\[DoubleStruckI]", 
          StyleBox["R",
            FontSlant->"Plain"]], TraditionalForm]]],
  " are the allele frequency among the migrants and residents, respectively \
(Wright ",
  ButtonBox["1931",
    ButtonData:>"Wright 1931",
    ButtonStyle->"Hyperlink"],
  ").  The exact values for the centered associations after migration are \
derived in ",
  ButtonBox["Appendix 3",
    ButtonData:>"Appendix: Migration",
    ButtonStyle->"Hyperlink"],
  ":"
}], "Text",
  CellMargins->{{18.1875, 24.375}, {Inherited, Inherited}}],

Cell[TextData[{
  "\n",
  Cell[BoxData[
      FormBox[
        RowBox[{"\[IndentingNewLine]", 
          RowBox[{
            
            RowBox[{\(D\_\[DoubleStruckCapitalA]\%\(\(\ \)\(\('\)\(\ \
\)\('\)\)\)\), "   ", "=", "   ", 
              
              RowBox[{\(\[Sum]\_\(\[DoubleStruckCapitalU] \[SubsetEqual] \
\[DoubleStruckCapitalA]\)\), 
                
                RowBox[{\(\((\(-m\))\)\^\(\(|\)\(\[DoubleStruckCapitalU]\)\(|\
\)\)\), " ", \(d\_\[DoubleStruckCapitalU]\), " ", 
                  RowBox[{"{", 
                    RowBox[{
                      RowBox[{\((1\  - \ m)\), 
                        
                        SubsuperscriptBox[
                          "D", \(\[DoubleStruckCapitalA]\\\
\[DoubleStruckCapitalU]\), 
                          RowBox[{" ", 
                            StyleBox["R",
                              FontSlant->"Plain"]}]]}], "  ", "+", "  ", 
                      RowBox[{"m", " ", 
                        
                        RowBox[{\(\[Sum]\_\(\[DoubleStruckCapitalV] \
\[SubsetEqual] \[DoubleStruckCapitalA]\\\[DoubleStruckCapitalU]\)\), 
                          RowBox[{\(d\_\[DoubleStruckCapitalV]\), " ", 
                            
                            SubsuperscriptBox[
                              "D", \(\((\[DoubleStruckCapitalA]\\\
\[DoubleStruckCapitalU])\)\\\[DoubleStruckCapitalV]\), 
                              StyleBox["M",
                                FontSlant->"Plain"]]}]}]}]}], "}"}]}]}]}], 
            ",", "\[IndentingNewLine]"}]}], TraditionalForm]]],
  "\n"
}], "NumberedEquation",
  CellMargins->{{18.1875, 24.375}, {Inherited, Inherited}},
  CellTags->"DAPrimeCentered"],

Cell["where", "Text",
  CellMargins->{{18.1875, 24.375}, {Inherited, Inherited}}],

Cell[TextData[{
  "\n",
  Cell[BoxData[
      FormBox[
        RowBox[{"\[IndentingNewLine]", 
          RowBox[{\(d\_\[DoubleStruckCapitalU]\), "   ", "=", "   ", 
            RowBox[{\(\[Product]\+i\[Epsilon]\[DoubleStruckCapitalU]\), 
              RowBox[{
                RowBox[{"(", 
                  RowBox[{
                    SubsuperscriptBox["p", "\[DoubleStruckI]", 
                      StyleBox["M",
                        FontSlant->"Plain"]], "  ", "-", "  ", 
                    SubsuperscriptBox["p", "\[DoubleStruckI]", 
                      StyleBox["R",
                        FontSlant->"Plain"]]}], ")"}], " ", 
                "\[IndentingNewLine]"}]}]}]}], TraditionalForm]]],
  "\n"
}], "NumberedEquation",
  CellMargins->{{18.1875, 24.375}, {Inherited, Inherited}},
  CellTags->"dAProductDefn"],

Cell[TextData[{
  "and ",
  Cell[BoxData[
      \(TraditionalForm\`d\_\[Diameter]\)]],
  "\[Congruent] 1.  The ",
  Cell[BoxData[
      FormBox[
        SubsuperscriptBox["D", "\[DoubleStruckCapitalA]", 
          RowBox[{" ", 
            StyleBox["M",
              FontSlant->"Plain"]}]], TraditionalForm]]],
  " are the centered associations in the migrant population and the ",
  Cell[BoxData[
      FormBox[
        SubsuperscriptBox["D", "\[DoubleStruckCapitalA]", 
          RowBox[{" ", 
            StyleBox["R",
              FontSlant->"Plain"]}]], TraditionalForm]]],
  " are the centered associations among the residents before migration.  \
(That is, the reference values for ",
  Cell[BoxData[
      FormBox[
        SubsuperscriptBox["D", "\[DoubleStruckCapitalA]", 
          RowBox[{" ", 
            StyleBox["M",
              FontSlant->"Plain"]}]], TraditionalForm]]],
  " are the allele frequencies among the migrants, and the reference values \
for ",
  Cell[BoxData[
      FormBox[
        SubsuperscriptBox["D", "\[DoubleStruckCapitalA]", 
          RowBox[{" ", 
            StyleBox["R",
              FontSlant->"Plain"]}]], TraditionalForm]]],
  " are the allele frequencies in the residents before migration.)  The first \
term in ",
  ButtonBox["Equation ",
    ButtonData:>"DAPrimeCentered",
    ButtonStyle->"Hyperlink"],
  
  CounterBox["NumberedEquation", "DAPrimeCentered"],
  ButtonBox[" ",
    ButtonData:>"DAPrimeCentered",
    ButtonStyle->"Hyperlink"],
  "is produced when \[DoubleStruckCapitalU] = \[EmptySet] and \
\[DoubleStruckCapitalV] = \[DoubleStruckCapitalA], giving ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          RowBox[{\((1\  - \ m)\), 
            SubsuperscriptBox["D", "\[DoubleStruckCapitalA]", 
              RowBox[{" ", 
                StyleBox["R",
                  FontSlant->"Plain"]}]]}], "  ", "+", 
          "  ", \(\(m\)\(\ \)\(d\_\[DoubleStruckCapitalA]\)\(\ \)\)}], 
        TraditionalForm]]],
  ".  "
}], "Text",
  CellMargins->{{18.1875, 24.375}, {Inherited, Inherited}}],

Cell["\<\
\tWe illustrate the use of this result with two special cases that \
may be of general interest.  The first is the association between pairs of \
positions generated by migration.  The association between positions \
\[DoubleStruckI] and \[DoubleStruckJ] after migration is in general\
\>", \
"Text",
  CellMargins->{{18.1875, 24.375}, {Inherited, Inherited}}],

Cell[TextData[{
  "\n",
  Cell[BoxData[
      FormBox[
        RowBox[{"\[IndentingNewLine]", 
          
          RowBox[{\(D\_\[DoubleStruckI]\[DoubleStruckJ]\%\(\(\ \)\(\('\)\(\ \
\)\('\)\)\)\), "   ", "=", "   ", 
            RowBox[{
              RowBox[{\((1\  - \ m)\), 
                SubsuperscriptBox["D", "\[DoubleStruckI]\[DoubleStruckJ]", 
                  RowBox[{" ", 
                    StyleBox["R",
                      FontSlant->"Plain"]}]]}], "  ", "+", " ", 
              RowBox[{"m", " ", 
                SubsuperscriptBox["D", "\[DoubleStruckI]\[DoubleStruckJ]", 
                  RowBox[{" ", 
                    StyleBox["M",
                      FontSlant->"Plain"]}]]}], "  ", "+", "  ", 
              RowBox[{\(m(1\  - \ m)\), 
                RowBox[{"(", 
                  RowBox[{
                    SubsuperscriptBox["p", "\[DoubleStruckI]", 
                      StyleBox["M",
                        FontSlant->"Plain"]], "  ", "-", "  ", 
                    SubsuperscriptBox["p", "\[DoubleStruckI]", 
                      StyleBox["R",
                        FontSlant->"Plain"]]}], ")"}], 
                RowBox[{
                  RowBox[{"(", 
                    RowBox[{
                      SubsuperscriptBox["p", "\[DoubleStruckJ]", 
                        StyleBox["M",
                          FontSlant->"Plain"]], "  ", "-", "  ", 
                      SubsuperscriptBox["p", "\[DoubleStruckJ]", 
                        StyleBox["R",
                          FontSlant->"Plain"]]}], ")"}], ".", 
                  "\[IndentingNewLine]"}]}]}]}]}], TraditionalForm]]]
}], "NumberedEquation",
  CellMargins->{{18.1875, 24.375}, {Inherited, Inherited}},
  CellTags->"DijPrimeExactAfterMigration"],

Cell["\<\
The associations following migration are a weighted average of the \
associations in the contributing populations (the first two terms) and a \
component caused by differences in allele frequencies in the two populations \
(the third term).\
\>", "Text",
  CellMargins->{{18.1875, 24.375}, {Inherited, Inherited}}],

Cell[TextData[{
  "\tA second situation that may also be of general interest is when the \
associations among the residents and migrants are initially zero.  Then ",
  ButtonBox["Equation ",
    ButtonData:>"DAPrimeCentered",
    ButtonStyle->"Hyperlink"],
  
  CounterBox["NumberedEquation", "DAPrimeCentered"],
  " gives"
}], "Text",
  CellMargins->{{18.1875, 24.375}, {Inherited, Inherited}}],

Cell[TextData[{
  "\n",
  Cell[BoxData[
      \(TraditionalForm\`\(\(\[IndentingNewLine]\)\(D\_\[DoubleStruckCapitalA]\
\%\(\(\ \)\(\('\)\(\ \)\('\)\)\)\ \ \  = \ \ \ d\_\[DoubleStruckCapitalA]\ \(\
\({\ \ \((\(-m\))\)\^\(\(|\)\(\[DoubleStruckCapitalA]\)\(|\)\)\ \((1\  - \ 
                      m)\)\ \  + \ \ m\ \((1\  - \ m)\)\^\(\(|\)\(\
\[DoubleStruckCapitalA]\)\(|\)\)\ }\)\(\ \ \)\(.\)\(\[IndentingNewLine]\)\)\)\
\)\)]]
}], "NumberedEquation",
  CellMargins->{{18.1875, 24.375}, {Inherited, Inherited}},
  CellTags->"DADoublePrimeNoDisequilibriumAmongMigrants"],

Cell[TextData[{
  "Thus the associations generated in this case are simply proportional to \
the differences in allele frequencies between the contributing populations.  \
More generally, ",
  ButtonBox["Equation ",
    ButtonData:>"DAPrimeCentered",
    ButtonStyle->"Hyperlink"],
  
  CounterBox["NumberedEquation", "DAPrimeCentered"],
  ButtonBox[" ",
    ButtonData:>"DAPrimeCentered",
    ButtonStyle->"Hyperlink"],
  "shows that if a pair of demes is initially at linkage equilibrium, \
associations will evolve such that ",
  Cell[BoxData[
      \(TraditionalForm\`D\_\[DoubleStruckCapitalA]\)]],
  " remains proportional to the product of allele frequency differences at \
the loci involved,  ",
  Cell[BoxData[
      \(TraditionalForm\`d\_\[DoubleStruckCapitalA]\)]],
  " (Barton, ",
  ButtonBox["2000",
    ButtonData:>"Barton 2000",
    ButtonStyle->"Hyperlink"],
  ")."
}], "Text",
  CellMargins->{{18.1875, 24.375}, {Inherited, Inherited}}],

Cell[TextData[{
  "\tThe exact results can be used to find simple approximations for the \
effects of migration on the associations. ",
  " ",
  ButtonBox["Equation ",
    ButtonData:>"DAPrimeCentered",
    ButtonStyle->"Hyperlink"],
  
  CounterBox["NumberedEquation", "DAPrimeCentered"],
  ButtonBox[" ",
    ButtonData:>"DAPrimeCentered",
    ButtonStyle->"Hyperlink"],
  "shows that the change caused by migration is"
}], "Text",
  CellMargins->{{18.1875, 24.375}, {Inherited, Inherited}}],

Cell[TextData[{
  "\n",
  Cell[BoxData[
      FormBox[
        RowBox[{"\[IndentingNewLine]", 
          RowBox[{
            RowBox[{
              SubscriptBox["\[CapitalDelta]", 
                StyleBox["m",
                  FontSlant->"Plain"]], 
              SubscriptBox[
                StyleBox["D",
                  FontSlant->"Italic"], "\[DoubleStruckCapitalA]"]}], "   ", 
            "=", "   ", \(m\ d\_\[DoubleStruckCapitalA]\ \  + \ \ \(\(O(
                  m\ D, \ m\^2)\)\(.\)\(\[IndentingNewLine]\)\)\)}]}], 
        TraditionalForm]]]
}], "NumberedEquation",
  CellMargins->{{18.1875, 24.375}, {Inherited, Inherited}},
  CellTags->"deltaDAMigrationToLeadingOrder"],

Cell[TextData[{
  "To find an approximation for ",
  Cell[BoxData[
      \(TraditionalForm\`D\_\[DoubleStruckCapitalA]\)]],
  " at a migration-recombination equilibrium, we need the change caused by \
transmission.  Taking the example of a set of autosomal positions with the \
same sex-of-origin in a random mating population, that change is  ",
  Cell[BoxData[
      FormBox[
        SubscriptBox["\[CapitalDelta]", 
          StyleBox["t",
            FontSlant->"Plain"]], TraditionalForm]]],
  " ",
  Cell[BoxData[
      \(TraditionalForm\`D\_\[DoubleStruckCapitalA]\)]],
  " = ",
  Cell[BoxData[
      \(TraditionalForm\`\(-r\_\[DoubleStruckCapitalA]\)\)]],
  " + ",
  Cell[BoxData[
      \(TraditionalForm\`O(D\^2)\)]],
  ".  Setting the net change to zero gives a leading order approximation for \
the ",
  "associations",
  " at a migration-recombination balance:"
}], "Text",
  CellMargins->{{18.1875, 24.375}, {Inherited, Inherited}}],

Cell[TextData[{
  "\n",
  Cell[BoxData[
      FormBox[
        RowBox[{"\[IndentingNewLine]", 
          RowBox[{
            SubscriptBox[
              StyleBox[
                OverscriptBox[
                  StyleBox["D",
                    FontSlant->"Italic"], "^"],
                FontSlant->"Italic"], "\[DoubleStruckCapitalA]"], "   ", "=", 
            "   ", \(\(m\ d\_\[DoubleStruckCapitalA]\)\/r\_\
\[DoubleStruckCapitalA]\ \  + \ \ \(\(O(m\ D, \ m\^2, \ 
                  D\^2)\)\(.\)\(\[IndentingNewLine]\)\)\)}]}], 
        TraditionalForm]]]
}], "NumberedEquation",
  CellMargins->{{18.1875, 24.375}, {Inherited, Inherited}},
  CellTags->"dAAtQLEFromExactCalculation"],

Cell[TextData[{
  "That result was derived by Kirkpatrick and Servedio (",
  ButtonBox["1999",
    ButtonData:>"Kirkpatrick & Servedio 1999",
    ButtonStyle->"Hyperlink"],
  ") by treating migration as a form of frequency-dependent selection.  Our \
new approach extends that earlier result in two ways.  It can be applied to \
genes other than autosomes by using the appropriate transmission \
probabilities.  Further, the approximation can be expanded to include \
higher-order terms, for example those involving ",
  Cell[BoxData[
      \(TraditionalForm\`m\^2\)]],
  " and ",
  StyleBox["m D",
    FontSlant->"Italic"],
  "."
}], "Text",
  CellMargins->{{18.1875, 24.375}, {Inherited, Inherited}}]
}, Closed]]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[StyleBox["6. Applications",
  FontWeight->"Bold"]], "Subtitle",
  CellMargins->{{18.1875, 24.375}, {Inherited, Inherited}},
  PageBreakAbove->True,
  CellTags->"Applications"],

Cell["\<\
 \tThis section uses the machinery described above to develop \
results for the effects of natural and sexual selection.  The aim is both to \
illustrate how these methods work and to develop some results that are \
biologically interesting in their own right.\
\>", "Text",
  CellMargins->{{18.1875, 24.375}, {Inherited, Inherited}}],

Cell["\<\
\tIn the first application, we find the selection coefficients \
generated by natural selection acting on an additive polygenic trait and use \
those results to study how it evolves under autosomal inheritance.  Next, we \
find approximations for the genetic correlation between a female mating \
preference and a male display trait produced by sexual selection.  We will \
see how the mode of inheritance affects this correlation by deriving results \
for haploid autosomal, diploid autosomal, and diploid X-linked genes.\
\>", \
"Text",
  CellMargins->{{18.1875, 24.375}, {Inherited, Inherited}}],

Cell[CellGroupData[{

Cell["\<\
(i) Quadratic stabilizing selection on an additive polygenic \
trait\
\>", "Subsubtitle",
  CellMargins->{{18.1875, 24.375}, {Inherited, Inherited}},
  CellTags->"Natural selection on an additive polygenic trait"],

Cell["\<\
 \tMany problems in evolutionary biology involve evolution of \
traits controlled by multiple genes of approximately additive effect.  In \
this section we derive exact expressions for the selection coefficients on \
single positions and sets of positions that result from quadratic stabilizing \
selection.  These can be used to calculate the evolutionary changes in the \
mean, variance, and higher moments of the trait.  The same methods can be \
used to calculate selection coefficients more generally, for an arbitrary \
form of selection acting on any number of additive genes.\
\>", "Text",
  CellMargins->{{18.1875, 24.375}, {Inherited, Inherited}}],

Cell[TextData[{
  "\tConsider a trait controlled by a set of genes with additive effects \
under stabilizing selection.  The calculations will illustrate a general \
strategy for calculating selection coefficients:  write an explicit model for \
the phenotype, write the fitness function as a polynomial, substitute the \
expression for the phenotype into that fitness function, equate the result \
with Equation (",
  
  CounterBox["NumberedEquation", "fitnessDefinition"],
  "), and finally pick out the coefficients of the fitness function that \
correspond to the ",
  StyleBox["a",
    FontSlant->"Italic"],
  "s.  This example is very similar to one in ",
  ButtonBox["BT91, p. 244",
    ButtonData:>"Barton & Turelli 1991",
    ButtonStyle->"Hyperlink"],
  ".  It will introduce readers who are not familiar with that paper to the \
approach, and show those who are how the new notation works."
}], "Text",
  CellMargins->{{18.1875, 24.375}, {Inherited, Inherited}}],

Cell[TextData[{
  "\tThe model for the phenotype of an individual comes from Equation (",
  
  CounterBox["NumberedEquation", "phenotypicDeterminationInGeneral"],
  "), which simplifies under our assumption that genes have additive effects \
"
}], "Text",
  CellMargins->{{18.1875, 24.375}, {Inherited, Inherited}}],

Cell[TextData[{
  "\n",
  Cell[BoxData[
      \(TraditionalForm\`\(\(\[IndentingNewLine]\)\(\(Z\ \ \  = \ \ \ Z\&_\ \ \
 + \ \ \[Sum]\+\(\[DoubleStruckI] \[Element] \[DoubleStruckCapitalW]\)b\_\
\[DoubleStruckI]\ \[Zeta]\_\[DoubleStruckI]\ \  + \ \ e\_Z\)\(\ \)\(,\)\(\
\[IndentingNewLine]\)\)\)\)]]
}], "NumberedEquation",
  CellMargins->{{18.1875, 24.375}, {Inherited, Inherited}},
  CellTags->"ZTwoLoci"],

Cell[TextData[{
  "where ",
  Cell[BoxData[
      \(TraditionalForm\`e\_Z\)]],
  ", the random environmental component, has variance ",
  Cell[BoxData[
      \(TraditionalForm\`V\_e\)]],
  ".  The sum is over all positions \[DoubleStruckI] that affect expression \
of the trait and hence fitness; for example, with autosomal genes in a \
diploid male, the set \[DoubleStruckCapitalW] includes positions inherited \
from both males and females:  ",
  Cell[BoxData[
      \(TraditionalForm\`{i\_\(m\[VeryThinSpace]m\), \
\(i\_\(m\[VeryThinSpace]f\)\) \[Ellipsis]}\)]],
  "."
}], "Text",
  CellMargins->{{18.1875, 24.375}, {Inherited, Inherited}}],

Cell["\<\
\tOur model for fitness is the quadratic function:\
\>", "Text",
  CellMargins->{{18.1875, 24.375}, {Inherited, Inherited}}],

Cell[TextData[{
  "\n",
  Cell[BoxData[
      \(TraditionalForm\`\(\(\[IndentingNewLine]\)\(\(W(Z)\ \ \  = \ \ 1 - 
          Z\^2\/\(2  \[Omega]\^2\)\)\(,\)\(\[IndentingNewLine]\)\)\)\)]]
}], "NumberedEquation",
  CellMargins->{{18.1875, 24.375}, {Inherited, Inherited}},
  CellTags->"GaussianFitnessFunction"],

Cell[TextData[{
  "where ",
  Cell[BoxData[
      \(TraditionalForm\`\[Omega]\^2\)]],
  " is the width of the fitness function and is inversely related to the \
strength of stabilizing selection.  The trait has been scaled so that the \
fitness optimum is at ",
  StyleBox["Z",
    FontSlant->"Italic"],
  " = 0.  Clearly, selection must be weak enough that fitness remains \
positive (Var(",
  StyleBox["Z",
    FontSlant->"Italic"],
  ") << ",
  Cell[BoxData[
      \(TraditionalForm\`\[Omega]\^2\)]],
  ").  This quadratic model is a weak-selection approximation to other forms \
of stabilizing selection, such as the Gaussian ",
  Cell[BoxData[
      \(TraditionalForm\`W(z)\  \[Proportional] \ 
        exp(\(-Z\^2\)/2  \[Omega]\^2)\)]],
  " (see ",
  ButtonBox["BT91",
    ButtonData:>"Barton & Turelli 1991",
    ButtonStyle->"Hyperlink"],
  ")."
}], "Text",
  CellMargins->{{18.1875, 24.375}, {Inherited, Inherited}}],

Cell[TextData[{
  "\tSubstituting ",
  ButtonBox["Equation ",
    ButtonData:>"ZTwoLoci",
    ButtonStyle->"Hyperlink"],
  
  CounterBox["NumberedEquation", "ZTwoLoci"],
  ButtonBox[" ",
    ButtonData:>"ZTwoLoci",
    ButtonStyle->"Hyperlink"],
  "into ",
  ButtonBox["Equation ",
    ButtonData:>"GaussianFitnessFunction",
    ButtonStyle->"Hyperlink"],
  
  CounterBox["NumberedEquation", "GaussianFitnessFunction"],
  ButtonBox[" ",
    ButtonData:>"GaussianFitnessFunction",
    ButtonStyle->"Hyperlink"],
  "and averaging over the environmental variation gives"
}], "Text",
  CellMargins->{{18.1875, 24.375}, {Inherited, Inherited}}],

Cell[TextData[{
  "\n",
  Cell[BoxData[
      FormBox[
        RowBox[{"\[IndentingNewLine]", 
          RowBox[{
            RowBox[{\(E\_e\), "[", 
              RowBox[{"W", "(", 
                StyleBox["X",
                  FontWeight->"Bold",
                  FontSlant->"Italic"], ")"}], "]"}], "   ", "=", 
            "   ", \(1\ \  - \ 
                V\_e\/\(2  \[Omega]\^2\) - \(1\/\(2  \[Omega]\^2\)\) \
\((\[Sum]\+\[DoubleStruckI]\( b\_\[DoubleStruckI]\) \[Zeta]\_\[DoubleStruckI] \
+ Z\&_)\)\^2\[IndentingNewLine]\[IndentingNewLine]\ \ \[IndentingNewLine]\t = \
\ \ \ 1\ \  - \ V\_e\/\(2  \[Omega]\^2\) - 
                Z\&_\^2\/\(2  \[Omega]\^2\) - \(Z\&_\/\[Omega]\^2\) \
\(\[Sum]\+\(\[DoubleStruckI] \[Element] \[DoubleStruckCapitalW]\)\(b\_\
\[DoubleStruckI]\) \[Zeta]\_\[DoubleStruckI]\) - \(1\/\(2  \[Omega]\^2\)\) \(\
\[Sum]\+\(\[DoubleStruckI], \[DoubleStruckJ] \[Element] \
\[DoubleStruckCapitalW]\)\(\(b\_\[DoubleStruckI]\) \(b\_\[DoubleStruckJ]\) \(\
\[Zeta]\_\[DoubleStruckI]\) \
\(\[Zeta]\_\[DoubleStruckJ]\)\(\[IndentingNewLine]\)\)\)\)}]}], 
        TraditionalForm]]],
  "\n"
}], "NumberedEquation",
  CellMargins->{{18.1875, 24.375}, {Inherited, Inherited}},
  CellTags->"wTwoLociAfterZetasReduced"],

Cell[TextData[{
  "where ",
  Cell[BoxData[
      \(TraditionalForm\`E\_e\)]],
  " is the expectation over the distribution of ",
  Cell[BoxData[
      \(TraditionalForm\`e\_Z\)]],
  ".  "
}], "Text",
  CellMargins->{{18.1875, 24.375}, {Inherited, Inherited}}],

Cell[TextData[{
  "\tThe selection coefficients ",
  Cell[BoxData[
      \(TraditionalForm\`a\_U\)]],
  " are defined by the polynomial of ",
  ButtonBox["Equation ",
    ButtonData:>"fitnessDefinition",
    ButtonStyle->"Hyperlink"],
  
  CounterBox["NumberedEquation", "fitnessDefinition"],
  ".  Rewriting the last term in Eq. 37 in this way, and using Equation (",
  
  CounterBox["NumberedEquation", "reductionFormula"],
  ") for biallelic loci,  gives"
}], "Text",
  CellMargins->{{18.1875, 24.375}, {Inherited, Inherited}}],

Cell[TextData[{
  "\n",
  Cell[BoxData[
      FormBox[
        RowBox[{"\[IndentingNewLine]", 
          RowBox[{
            RowBox[{\(E\_e\), "[", 
              RowBox[{"W", "(", 
                StyleBox["X",
                  FontWeight->"Bold",
                  FontSlant->"Italic"], ")"}], "]"}], "   ", "=", 
            "    ", \(1\ \  - \ V\_e\/\(2  \[Omega]\^2\) - 
              Z\&_\^2\/\(2  \[Omega]\^2\) - \(Z\&_\/\[Omega]\^2\) \
\(\[Sum]\+\(\[DoubleStruckI] \[Element] \[DoubleStruckCapitalW]\)\(b\_\
\[DoubleStruckI]\) \[Zeta]\_\[DoubleStruckI]\)\[IndentingNewLine]\
\[IndentingNewLine]\[IndentingNewLine] - \(1\/\(2  \[Omega]\^2\)\) \(\[Sum]\+\
\(\[DoubleStruckI] \[Element] \[DoubleStruckCapitalW]\)b\_\[DoubleStruckI]\%2[
                    p\[VeryThinSpace]q\_\[DoubleStruckI] - \(\[Zeta]\_\
\[DoubleStruckI]\)(p\_\[DoubleStruckI]\  - \ 
                          q\_\[DoubleStruckI])]\) - \(1\/\[Omega]\^2\) \(\
\[Sum]\+\(\[DoubleStruckI] < \[DoubleStruckJ]\)\(b\_\[DoubleStruckI]\) \(b\_\
\[DoubleStruckJ]\) \(\[Zeta]\_\[DoubleStruckI]\) \
\(\(\[Zeta]\_\[DoubleStruckJ]\)\(\ \)\(.\)\(\[IndentingNewLine]\)\)\)\)}]}], 
        TraditionalForm]]],
  "\n"
}], "NumberedEquation",
  CellMargins->{{18.1875, 24.375}, {Inherited, Inherited}},
  CellTags->"wTwoLociAfterZetasReducedTwo"],

Cell[TextData[{
  "\tWe find the selection coefficients from ",
  ButtonBox["Equation ",
    ButtonData:>"wTwoLociAfterZetasReducedTwo",
    ButtonStyle->"Hyperlink"],
  
  CounterBox["NumberedEquation", "wTwoLociAfterZetasReducedTwo"],
  " by the mean fitness ",
  Cell[BoxData[
      \(TraditionalForm\`W\&_\)]],
  " and identifying the coefficients of ",
  Cell[BoxData[
      \(TraditionalForm\`\[Zeta]\_\[DoubleStruckI]\)]],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`\[Zeta]\_\[DoubleStruckI]\ \[Zeta]\_\[DoubleStruckJ]\
\)]],
  ".  All coefficients ",
  Cell[BoxData[
      \(TraditionalForm\`a\_\[DoubleStruckCapitalU]\)]],
  " involving more than two positions (|\[DoubleStruckCapitalU]| > 2) are \
zero.  The selection acting on the single position \[DoubleStruckI] is"
}], "Text",
  CellMargins->{{18.1875, 24.375}, {Inherited, Inherited}}],

Cell[TextData[{
  "\n",
  Cell[BoxData[
      \(TraditionalForm\`\(\(\[IndentingNewLine]\)\(a\_\[DoubleStruckI]\ \ \  \
= \ \ \ \(-\ 
              b\_\[DoubleStruckI]\)\ Z\&_\/\(\(W\&_\) \[Omega]\^2\)\ \  + \ \ \
b\_\[DoubleStruckI]\%2\ 1\/\(2 \( W\&_\) \[Omega]\^2\)\ \(\((p\_\
\[DoubleStruckI]\  - \ 
                  q\_\[DoubleStruckI])\)\(.\)\(\[IndentingNewLine]\)\)\)\)\)]]\
,
  "\n"
}], "NumberedEquation",
  CellMargins->{{18.1875, 24.375}, {Inherited, Inherited}},
  CellTags->"aiForTwoLoci"],

Cell[TextData[{
  "The first term represents the effect of directional selection, which \
pushes the mean of the trait towards the optimum at ",
  StyleBox["Z",
    FontSlant->"Italic"],
  " = 0.  It is proportional to ",
  Cell[BoxData[
      \(TraditionalForm\`b\_i\)]],
  ", which is the effect that allele 1 at position \[DoubleStruckI] has on \
the phenotype.  The second term represents the effect of stabilizing \
selection, which favors fixation by driving the allele frequency towards 0 if \
",
  Cell[BoxData[
      \(TraditionalForm\`p\_\[DoubleStruckI]\)]],
  " is less than 1/2 and towards 1 if ",
  Cell[BoxData[
      \(TraditionalForm\`p\_\[DoubleStruckI]\)]],
  " is greater than 1/2 (Wright, ",
  ButtonBox["1935",
    ButtonData:>"Wright 1935",
    ButtonStyle->"Hyperlink"],
  ").  This effect will be weak when the effect of the locus on the phenotype \
is small relative to the width of the fitness function ",
  Cell[BoxData[
      \(TraditionalForm\`\((b\_\[DoubleStruckI]\ << \ \[Omega])\)\)]],
  ".  (Note that if allele frequencies differ in males and females ",
  Cell[BoxData[
      FormBox[
        RowBox[{"(", 
          RowBox[{
            SubscriptBox["p", 
              SubscriptBox["i", 
                RowBox[{
                  StyleBox["m",
                    FontSlant->"Italic"], " ", 
                  StyleBox["x",
                    FontSlant->"Plain"]}]]], "\[NotEqual]", 
            SubscriptBox["p", 
              SubscriptBox["i", 
                RowBox[{
                  StyleBox["f",
                    FontSlant->"Plain"], " ", 
                  StyleBox["x",
                    FontSlant->"Plain"]}]]]}], ")"}], TraditionalForm]]],
  " or in genes inherited from males and females ",
  Cell[BoxData[
      FormBox[
        RowBox[{"(", 
          RowBox[{
            SubscriptBox["p", 
              SubscriptBox["i", 
                StyleBox[
                  RowBox[{
                    StyleBox["x",
                      FontSlant->"Plain"], "m"}]]]], "\[NotEqual]", 
            SubscriptBox["p", 
              SubscriptBox["i", 
                StyleBox[
                  RowBox[{
                    StyleBox["x",
                      FontSlant->"Plain"], "f"}]]]]}], ")"}], 
        TraditionalForm]]],
  ", then the different positions at a single locus can have different \
selection coefficients (e.g.  ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          SubscriptBox["a", 
            SubscriptBox["i", 
              StyleBox[
                RowBox[{
                  StyleBox["x",
                    FontSlant->"Plain"], "m"}]]]], "\[NotEqual]", 
          SubscriptBox["a", 
            SubscriptBox["i", 
              StyleBox[
                RowBox[{
                  StyleBox["x",
                    FontSlant->"Plain"], "f"}]]]]}], TraditionalForm]]],
  ") even if selection acts identically on males and females.)"
}], "Text",
  CellMargins->{{18.1875, 24.375}, {Inherited, Inherited}}],

Cell[TextData[{
  "\tThe selection coefficient acting jointly on positions \[DoubleStruckI] \
and \[DoubleStruckJ] is given by the coefficient of ",
  Cell[BoxData[
      \(TraditionalForm\`\[Zeta]\_\[DoubleStruckI]\ \[Zeta]\_\[DoubleStruckJ]\
\)]],
  " in the fitness function ",
  ButtonBox["Equation ",
    ButtonData:>"wTwoLociAfterZetasReducedTwo",
    ButtonStyle->"Hyperlink"],
  
  CounterBox["NumberedEquation", "wTwoLociAfterZetasReducedTwo"],
  ButtonBox[":",
    ButtonData:>"wTwoLociAfterZetasReducedTwo",
    ButtonStyle->"Hyperlink"]
}], "Text",
  CellMargins->{{18.1875, 24.375}, {Inherited, Inherited}}],

Cell[TextData[{
  "\n",
  Cell[BoxData[
      \(TraditionalForm\`\(\(\[IndentingNewLine]\)\(a\_\[DoubleStruckI]\
\[DoubleStruckJ]\ \ \  = \ \ \ \(-\(1\/\(\(W\&_\) \[Omega]\^2\)\)\)\ b\_i\ \
b\_j\ \ \ \ \ \ for\ \[DoubleStruckI] \[NotEqual] \(\(\[DoubleStruckJ]\)\(.\)\
\(\[IndentingNewLine]\)\)\)\)\)]],
  "\n"
}], "NumberedEquation",
  CellMargins->{{18.1875, 24.375}, {Inherited, Inherited}},
  CellTags->"aijForTwoLoci"],

Cell[TextData[{
  "To see the meaning of this coefficient, adopt the convention of naming the \
alleles such that allele 1 produces a larger phenotype than allele 0 at each \
locus;  then ",
  Cell[BoxData[
      \(TraditionalForm\`b\_\[DoubleStruckI]\)]],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`b\_\[DoubleStruckJ]\)]],
  " are positive.  With stabilizing selection, ",
  Cell[BoxData[
      \(TraditionalForm\`a\_\[DoubleStruckI]\[DoubleStruckJ]\)]],
  " is negative, indicating that selection favors the combination of allele 0 \
at one locus with allele 1 at the other.  This is simply the well-known fact \
that stabilizing selection produces negative associations.  Disruptive \
selection can be modeled by taking ",
  Cell[BoxData[
      \(TraditionalForm\`\[Omega]\^2\)]],
  " as negative.  In that event, ",
  Cell[BoxData[
      \(TraditionalForm\`a\_\[DoubleStruckI]\[DoubleStruckJ]\)]],
  " is positive:  selection favors positive associations between alleles that \
increase the trait and also associations between alleles that decrease the \
trait."
}], "Text",
  CellMargins->{{18.1875, 24.375}, {Inherited, Inherited}}],

Cell["\<\
\tTo complete the analysis of this model we will find how the \
population evolves.  To determine the state of the population in the \
following generation, we need to make some assumption about inheritance, that \
is, the rules of transmission.  To keep things simple, we will assume that \
\[DoubleStruckI] and \[DoubleStruckJ] are autosomally inherited diploid \
genes, that mating is random, and that there is no meiotic drive.  We will \
define the reference values for each position to be the frequency of allele 1 \
there.\
\>", "Text",
  CellMargins->{{18.1875, 24.375}, {Inherited, Inherited}}],

Cell[TextData[{
  "\tThe change in allele frequencies caused by selection is found using ",
  ButtonBox["Equation ",
    ButtonData:>"ExactDeltaP",
    ButtonStyle->"Hyperlink"],
  
  CounterBox["NumberedEquation", "ExactDeltaP"],
  " with some help from ",
  ButtonBox["Equation ",
    ButtonData:>"reductionFormula",
    ButtonStyle->"Hyperlink"],
  
  CounterBox["NumberedEquation", "reductionFormula"],
  ":"
}], "Text",
  CellMargins->{{18.1875, 24.375}, {Inherited, Inherited}}],

Cell[TextData[{
  "\n",
  Cell[BoxData[
      FormBox[
        RowBox[{"\[IndentingNewLine]", 
          RowBox[{
            SubscriptBox[
              StyleBox[
                RowBox[{"\[CapitalDelta]", 
                  StyleBox["p",
                    FontSlant->"Italic"]}]], "\[DoubleStruckI]"], 
            "                 ", "=", "   ", 
            
            RowBox[{\(\[Sum]\+\(\[DoubleStruckCapitalU] \[SubsetEqual] \
\[DoubleStruckCapitalW]\)\(a\_\[DoubleStruckCapitalU]\) 
                  D\_\[DoubleStruckI]\[DoubleStruckCapitalU]\), " ", 
              "\[IndentingNewLine]", "\[IndentingNewLine]", 
              "\[IndentingNewLine]", "\t", "=", " ", 
              RowBox[{
                RowBox[{
                  RowBox[{\(a\_\[DoubleStruckI]\), " ", 
                    SubscriptBox[
                      StyleBox["p",
                        FontSlant->"Italic"], "\[DoubleStruckI]"], 
                    SubscriptBox[
                      StyleBox["q",
                        FontSlant->"Italic"], "\[DoubleStruckI]"]}], "  ", 
                  "+", " ", \(\[Sum]\+\(\[DoubleStruckJ] \[NotEqual] \
\[DoubleStruckI]\)\ 
                    a\_\[DoubleStruckJ]\ \
D\_\[DoubleStruckI]\[DoubleStruckJ]\), "  ", 
                  "+", \(\[Sum]\+\(\[DoubleStruckJ] \[NotEqual] \
\[DoubleStruckI]\)\ \(a\_\[DoubleStruckI]\[DoubleStruckJ]\) 
                      D\_\[DoubleStruckI]\[DoubleStruckI]\[DoubleStruckJ]\), 
                  "+", \(\[Sum]\+\(\(\[DoubleStruckJ], \[DoubleStruckK] \
\[NotEqual] \[DoubleStruckI]\)\+\(\[DoubleStruckJ] < \[DoubleStruckK]\)\)\ \ \
a\_\[DoubleStruckJ]\[DoubleStruckK]\ D\_\[DoubleStruckI]\[DoubleStruckJ]\
\[DoubleStruckK]\)}], " ", "\[IndentingNewLine]", "  ", "\[IndentingNewLine]",
                 "\[IndentingNewLine]", "\t", "=", "   ", 
                RowBox[{
                  RowBox[{\(a\_\[DoubleStruckI]\), " ", 
                    SubscriptBox[
                      StyleBox["pq",
                        FontSlant->"Italic"], "\[DoubleStruckI]"]}], "  ", 
                  "+", " ", \(\[Sum]\+\(\[DoubleStruckJ] \[NotEqual] \
\[DoubleStruckI]\)\ \([a\_\[DoubleStruckJ]\  - \(a\_\[DoubleStruckI]\
\[DoubleStruckJ]\)(p\_\[DoubleStruckI] - q\_\[DoubleStruckI])]\) 
                      D\_\[DoubleStruckI]\[DoubleStruckJ]\), "  ", 
                  "+", \(\[Sum]\+\(\(\[DoubleStruckJ], \[DoubleStruckK] \
\[NotEqual] \[DoubleStruckI]\)\+\(\[DoubleStruckJ] < \[DoubleStruckK]\)\)\ \ \
\(\(a\_\[DoubleStruckJ]\[DoubleStruckK]\)\(\ \)\(D\_\[DoubleStruckI]\
\[DoubleStruckJ]\[DoubleStruckK]\)\(\[IndentingNewLine]\)\)\)}]}]}]}]}], 
        TraditionalForm]]],
  "\n"
}], "NumberedEquation",
  CellMargins->{{18.1875, 24.375}, {Inherited, Inherited}},
  CellTags->"deltaPTwoLoci"],

Cell[TextData[{
  "where the special cases such as \[DoubleStruckI] = \[DoubleStruckJ] have \
been separated out.  Note that the sums are over all ",
  StyleBox["positions",
    FontSlant->"Italic"],
  ", and so include contributions from genes on both maternal and paternal \
genomes."
}], "Text",
  CellMargins->{{18.1875, 24.375}, {Inherited, Inherited}}],

Cell[TextData[{
  "\tSince transmission does not change allele frequencies, the overall \
change in the mean of the trait from the start of one generation to the next \
can be found by summing ",
  Cell[BoxData[
      \(TraditionalForm\`\[CapitalDelta]p\_\[DoubleStruckI]\)]],
  " and substituting for the ",
  Cell[BoxData[
      \(TraditionalForm\`a\_\[DoubleStruckI], \ 
      a\_\[DoubleStruckI]\[DoubleStruckJ]\)]],
  " from ",
  ButtonBox["Equations ",
    ButtonData:>"aiForTwoLoci",
    ButtonStyle->"Hyperlink"],
  
  CounterBox["NumberedEquation", "aiForTwoLoci"],
  ButtonBox[" ",
    ButtonData:>"aiForTwoLoci",
    ButtonStyle->"Hyperlink"],
  ButtonBox["and ",
    ButtonData:>"aijForTwoLoci",
    ButtonStyle->"Hyperlink"],
  
  CounterBox["NumberedEquation", "aijForTwoLoci"],
  ButtonBox[". ",
    ButtonData:>"aijForTwoLoci",
    ButtonStyle->"Hyperlink"],
  "This leads to the simple expression: "
}], "Text",
  CellMargins->{{18.1875, 24.375}, {Inherited, Inherited}}],

Cell[TextData[{
  "\n\n",
  Cell[BoxData[
      \(TraditionalForm\`\[CapitalDelta] 
           Z\&_\ \  = \ \(\[Sum]\+i\ 
            b\_\[DoubleStruckI]\ \[CapitalDelta]p\_\[DoubleStruckI]\  = \ \(-\
\ \(Z\&_\/\(\(W\&_\) \[Omega]\^2\)\)\)\ \(\[Sum]\+\(\[DoubleStruckI] < \
\[DoubleStruckJ]\)\(b\_\[DoubleStruckI]\) \(b\_\[DoubleStruckJ]\) 
                  D\_\[DoubleStruckI]\[DoubleStruckJ]\)\ \  - \ 
            1\/\(2 \( W\&_\) \[Omega]\^2\)\ \(\[Sum]\+\(\(\[DoubleStruckJ], \
\[DoubleStruckK] \[NotEqual] \[DoubleStruckI], \)\+\(\[DoubleStruckJ] < \
\[DoubleStruckK]\)\)\(\(b\_\[DoubleStruckI]\) \(b\_\[DoubleStruckJ]\) \(b\_\
\[DoubleStruckK]\) \(D\_\[DoubleStruckI]\[DoubleStruckJ]\[DoubleStruckK]\)\(\ \
\)\)\)\)\)]],
  "\n\n"
}], "NumberedEquation",
  CellMargins->{{18.1875, 24.375}, {Inherited, Inherited}},
  CellTags->"deltaZBarTwoLoci"],

Cell[TextData[{
  "The result is a sum of two terms.  The first is standard equation for the \
selection response of a quantitative trait under directional selection:  it \
is the product of the directional selection gradient, which in this case is \
\[Dash] ",
  Cell[BoxData[
      \(TraditionalForm\`Z\&_\ /\ \[Omega]\^2\)]],
  ", and the additive genetic variance for the trait, which appears as the \
first summation on the right side.  The second term is the result of \
stabilizing selection acting on the genetic variance.  That form of selection \
also changes allele frequencies, and hence the trait mean, if the trait \
distribution is skewed: the second sum is just the skew of the distribution \
of breeding values of Z (Burger ",
  ButtonBox["1991",
    ButtonData:>"Burger 1991",
    ButtonStyle->"Hyperlink"],
  ", Turelli and Barton ",
  ButtonBox["1994",
    ButtonData:>"Turelli & Barton 1994",
    ButtonStyle->"Hyperlink"],
  ").  "
}], "Text",
  CellMargins->{{18.1875, 24.375}, {Inherited, Inherited}}],

Cell[TextData[{
  "\tNow consider the change in the association ",
  Cell[BoxData[
      \(TraditionalForm\`D\_\[DoubleStruckI]\[DoubleStruckJ]\)]],
  ".  Using ",
  ButtonBox["Equations ",
    ButtonData:>"reductionFormula",
    ButtonStyle->"Hyperlink"],
  
  CounterBox["NumberedEquation", "reductionFormula"],
  ButtonBox[" ",
    ButtonData:>"reductionFormula",
    ButtonStyle->"Hyperlink"],
  "and",
  ButtonBox[" ",
    ButtonData:>"exactChangeInDWithSelection",
    ButtonStyle->"Hyperlink"],
  
  CounterBox["NumberedEquation", "exactChangeInDWithSelection"],
  ButtonBox[", ",
    ButtonData:>"exactChangeInDWithSelection",
    ButtonStyle->"Hyperlink"],
  "we find that the (uncentered) value after selection is"
}], "Text",
  CellMargins->{{18.1875, 24.375}, {Inherited, Inherited}}],

Cell[TextData[{
  "\n",
  Cell[BoxData[
      \(TraditionalForm\`\(\(\[IndentingNewLine]\)\(\(D\_\[DoubleStruckI]\
\[DoubleStruckJ]\%\(\(\ \)\('\)\)\ \ \  = \ \ \ \ \ \(\[Sum]\+\(\
\[DoubleStruckCapitalU] \[SubsetEqual] \[DoubleStruckCapitalW]\)\(a\_\
\[DoubleStruckCapitalU]\)(
              D\_\[DoubleStruckI]\[DoubleStruckJ]\[DoubleStruckCapitalU]\  - \
\ \(D\_\[DoubleStruckI]\[DoubleStruckJ]\) 
                  D\_\[DoubleStruckCapitalU])\[IndentingNewLine]\
\[IndentingNewLine]\[IndentingNewLine]\ \ \  = \ 
          D\_\[DoubleStruckI]\[DoubleStruckJ]\ \  + \ \ \
\((a\_\[DoubleStruckI]\ \ D\_\[DoubleStruckI]\[DoubleStruckI]\[DoubleStruckJ] \
+ a\_\[DoubleStruckJ]\ \ D\_\[DoubleStruckI]\[DoubleStruckJ]\[DoubleStruckJ])\
\)\  + \ \ \[Sum]\+\(\[DoubleStruckK] \[NotEqual] \[DoubleStruckI], \
\[DoubleStruckJ]\)a\_\[DoubleStruckK]\ \ D\_\[DoubleStruckI]\[DoubleStruckJ]\
\[DoubleStruckK]\ \ \[IndentingNewLine]\[IndentingNewLine]\[IndentingNewLine] \
+ \ \ a\_\[DoubleStruckI]\[DoubleStruckJ]\ \ \((D\_\[DoubleStruckI]\
\[DoubleStruckJ]\[DoubleStruckI]\[DoubleStruckJ]\ \  - \ 
                  D\_\[DoubleStruckI]\[DoubleStruckJ]\%2)\) + \[Sum]\+\(\
\[DoubleStruckK] \[NotEqual] \[DoubleStruckI], \[DoubleStruckJ]\)a\_\
\[DoubleStruckI]\[DoubleStruckK]\ \ \((D\_\[DoubleStruckI]\[DoubleStruckI]\
\[DoubleStruckJ]\[DoubleStruckK]\ \  - \ \
\(D\_\[DoubleStruckI]\[DoubleStruckJ]\) 
                      D\_\[DoubleStruckI]\[DoubleStruckK])\) + \
\[IndentingNewLine]\[IndentingNewLine]\[IndentingNewLine]\[Sum]\+\(\
\[DoubleStruckK] \[NotEqual] \[DoubleStruckI], \[DoubleStruckJ]\)a\_\
\[DoubleStruckJ]\[DoubleStruckK]\ \ \((D\_\[DoubleStruckI]\[DoubleStruckJ]\
\[DoubleStruckJ]\[DoubleStruckK]\ \  - \ \
\(D\_\[DoubleStruckI]\[DoubleStruckJ]\) 
                      D\_\[DoubleStruckJ]\[DoubleStruckK])\) + \ \ \[Sum]\+\(\
\[DoubleStruckK] < \[DoubleStruckL], \[IndentingNewLine]\[DoubleStruckK], \
\[DoubleStruckL] \[NotEqual] \[DoubleStruckI], \[DoubleStruckJ]\)a\_\
\[DoubleStruckK]\[DoubleStruckL]\ \ \((D\_\[DoubleStruckI]\[DoubleStruckJ]\
\[DoubleStruckK]\[DoubleStruckL]\ \  - \ \
\(D\_\[DoubleStruckI]\[DoubleStruckJ]\) 
                      D\_\[DoubleStruckK]\[DoubleStruckL])\)\)\)\(\ \)\(,\)\(\
\[IndentingNewLine]\)\)\)\)]],
  "\n"
}], "NumberedEquation",
  CellMargins->{{18.1875, 24.375}, {Inherited, Inherited}},
  CellTags->"DijAfterSelection"],

Cell[TextData[{
  "where again, the various special cases have been separated out.  The \
expression can be further simplified using ",
  ButtonBox["Equation ",
    ButtonData:>"reductionFormula",
    ButtonStyle->"Hyperlink"],
  
  CounterBox["NumberedEquation", "reductionFormula"],
  " to reduce associations with repeated indices, as above.  It is convenient \
 to change the reference values at this point from the old allele frequencies \
to the new.  Using ",
  ButtonBox["Equation ",
    ButtonData:>"ChangeInReferenceValueEquation",
    ButtonStyle->"Hyperlink"],
  
  CounterBox["NumberedEquation", "ChangeInReferenceValueEquation"],
  ButtonBox[",",
    ButtonData:>"ChangeInReferenceValueEquation",
    ButtonStyle->"Hyperlink"]
}], "Text",
  CellMargins->{{18.1875, 24.375}, {Inherited, Inherited}}],

Cell[TextData[{
  "\n",
  Cell[BoxData[
      \(TraditionalForm\`\(\(\[IndentingNewLine]\)\(D\_\[DoubleStruckI]\
\[DoubleStruckJ]\%\(\(\ \)\(\('\)\(\ \)\('\)\)\)\ \ \  = \ \ \ \ \(D\_\
\[DoubleStruckI]\[DoubleStruckJ]\%\(\(\ \)\('\)\)\ \  - \ \ \
\(\[CapitalDelta]p\_\[DoubleStruckI]\) \[CapitalDelta]p\_\[DoubleStruckJ]\ \  \
- \ \ \(\[CapitalDelta]p\_\[DoubleStruckI]\) \[CapitalDelta]p\_\
\[DoubleStruckJ] + \ \ \(\[CapitalDelta]p\_\[DoubleStruckI]\) \
\[CapitalDelta]p\_\[DoubleStruckJ]\ \ \  = \ \ \ D\_\[DoubleStruckI]\
\[DoubleStruckJ]\%\(\(\ \)\('\)\)\ \  - \ \ \(\[CapitalDelta]p\_\
\[DoubleStruckI]\) \(\(\[CapitalDelta]p\_\[DoubleStruckJ]\)\(\ \)\(.\)\(\ \
\)\(\[IndentingNewLine]\)\)\)\)\)\)]],
  "\n"
}], "NumberedEquation",
  CellMargins->{{18.1875, 24.375}, {Inherited, Inherited}},
  CellTags->"DijAfterChangingReferenceValues"],

Cell[TextData[{
  "Finally, the association at the start of the next generation is given by \
",
  Cell[BoxData[
      FormBox[
        RowBox[{\(D\_\[DoubleStruckI]\[DoubleStruckJ]\%\(\(\ \)\(\(\('\)\(\ \
\)\('\)\)\ '\)\)\), "   ", "=", "    ", 
          RowBox[{
            RowBox[{"(", 
              RowBox[{"1", " ", "-", " ", 
                SubscriptBox["r", 
                  StyleBox["ij",
                    FontSlant->"Italic"]]}], ")"}], 
            " ", \(D\_\[DoubleStruckI]\[DoubleStruckJ]\%\(\(\ \)\(\('\)\(\ \)\
\('\)\)\)\)}]}], TraditionalForm]]],
  " for positions \[DoubleStruckI], \[DoubleStruckJ] inherited from the same \
parent, and 0 for positions inherited from different parents.  Just as for \
the trait mean, this procedure again leads to a relatively simple expression \
for the genetic variance at the start of the next generation (cf. Eqs. 53-54 \
of ",
  ButtonBox["BT91",
    ButtonData:>"Barton & Turelli 1991",
    ButtonStyle->"Hyperlink"],
  ").    However, this expression involves third and fourth-order \
associations, and so approximations are required to obtain a closed set of \
equations."
}], "Text",
  CellMargins->{{18.1875, 24.375}, {Inherited, Inherited}}]
}, Closed]],

Cell[CellGroupData[{

Cell["(ii) Sexual selection by female choice", "Subsubtitle",
  CellMargins->{{18.1875, 24.375}, {Inherited, Inherited}},
  CellTags->"Sexual selection by female choice"],

Cell[TextData[{
  "\tWe mentioned earlier that the multilocus machinery developed here can be \
used to study the genetic consequences of non-random mating.  This section \
shows how to calculate a QLE approximation for the genetic correlation (or \
covariance) between a female mating preference and male display trait that is \
generated by sexual selection.  This quantity is important to many theories \
about sexual selection (Kirkpatrick and Ryan ",
  ButtonBox["1991",
    ButtonData:>"Kirkpatrick & Ryan 1991",
    ButtonStyle->"Hyperlink"],
  ").  Previous work has calculated the covariance expected under autosomal \
inheritance in diploids (Lande ",
  ButtonBox["1981",
    ButtonData:>"Lande 1981",
    ButtonStyle->"Hyperlink"],
  ", Barton and Turelli ",
  ButtonBox["1991",
    ButtonData:>"Barton & Turelli 1991",
    ButtonStyle->"Hyperlink"],
  ") and haploids (Kirkpatrick ",
  ButtonBox["1982",
    ButtonData:>"Kirkpatrick 1982",
    ButtonStyle->"Hyperlink"],
  ", Kirkpatrick and Barton ",
  ButtonBox["1997",
    ButtonData:>"Kirkpatrick & Barton 1997",
    ButtonStyle->"Hyperlink"],
  ").  Here we extend the earlier results by finding the covariance when some \
genes are sex linked.  In addition to the biological interest in the result, \
the derivations will illustrate how non-random mating and nonautosomal \
inheritance are modeled in our framework."
}], "Text",
  CellMargins->{{18.1875, 24.375}, {Inherited, Inherited}}],

Cell[TextData[{
  "\tConsider a pair of characters, one expressed in females and the other in \
males, that together affect the probability that a male and female will mate. \
 We will refer to the first as a \"preference\" and the second as the \"male \
trait\".  In fact, the preference need not be a behavioral phenotype:  it can \
be any character that affects mating probabilities.  The value of a female's \
preference phenotype is denoted ",
  StyleBox["P",
    FontSlant->"Italic"],
  " and that of the male trait ",
  StyleBox["T",
    FontSlant->"Italic"],
  ".  A set of genes \[DoubleStruckCapitalP] affects the preference and a set \
\[DoubleStruckCapitalT] affects the male trait.  We assume that ",
  StyleBox["both",
    FontColor->RGBColor[1, 0, 0]],
  " sets act additively, ",
  StyleBox["so",
    FontColor->RGBColor[1, 0, 0]],
  " that the preference and male trait phenotype of an individual can be \
written in the form of ",
  ButtonBox["Equation ",
    ButtonData:>"ZTwoLoci",
    ButtonStyle->"Hyperlink"],
  
  CounterBox["NumberedEquation", "ZTwoLoci"],
  ButtonBox[".",
    ButtonData:>"ZTwoLoci",
    ButtonStyle->"Hyperlink"],
  "  We will further assume that the parent from which a gene was inherited \
(its sex-of-origin) does not affect the gene's expression.  Carrying allele 1 \
at position \[DoubleStruckI] rather than allele 0 increases the preference \
phenotype by ",
  Cell[BoxData[
      FormBox[
        SubsuperscriptBox["b", "i", 
          StyleBox["P",
            FontSlant->"Plain"]], TraditionalForm]]],
  ";  the corresponding effect of allele 1 at position \[DoubleStruckJ] on \
the male trait is ",
  Cell[BoxData[
      FormBox[
        SubsuperscriptBox["b", "j", 
          StyleBox["T",
            FontSlant->"Plain"]], TraditionalForm]]],
  "."
}], "Text",
  CellMargins->{{18.1875, 24.375}, {Inherited, Inherited}}],

Cell["\<\
\tWe begin by calculating the selection coefficients, which are \
independent of the inheritance rules.  We then use them to find QLE \
approximations for the preference-trait covariance under three types of \
inheritance:  haploid autosomal, diploid autosomal, and diploid \
X-linked.\
\>", "Text",
  CellMargins->{{18.1875, 24.375}, {Inherited, Inherited}}],

Cell[CellGroupData[{

Cell["\tSelection coefficients", "Subsection",
  CellMargins->{{18.1875, 24.375}, {Inherited, Inherited}},
  CellTags->"Selection coefficients"],

Cell[TextData[{
  "\tDerivation of the selection coefficients follows Kirkpatrick and Barton \
(",
  ButtonBox["1997",
    ButtonData:>"Kirkpatrick & Barton 1997",
    ButtonStyle->"Hyperlink"],
  ").  The phenotypic distribution of the preference among females at birth,  \
",
  Cell[BoxData[
      \(TraditionalForm\`\(f\_P\)( . )\)]],
  ", has mean ",
  Cell[BoxData[
      \(TraditionalForm\`P\&_\)]],
  " and variance ",
  Cell[BoxData[
      \(TraditionalForm\`\[Sigma]\_P\%2\)]],
  ";  the corresponding distribution ",
  Cell[BoxData[
      \(TraditionalForm\`\(f\_T\)( . )\)]],
  " for the trait among males at birth has mean ",
  Cell[BoxData[
      \(TraditionalForm\`T\&_\)]],
  " and variance ",
  Cell[BoxData[
      \(TraditionalForm\`\[Sigma]\_T\%2\)]],
  ".  The frequency of matings between a female with preference phenotype ",
  StyleBox["P",
    FontSlant->"Italic"],
  " and a male with trait phenotype ",
  StyleBox["T,",
    FontSlant->"Italic"],
  " denoted ",
  StyleBox["M",
    FontSlant->"Italic"],
  "(",
  StyleBox["P",
    FontSlant->"Italic"],
  ", ",
  StyleBox["T",
    FontSlant->"Italic"],
  "), has means ",
  Cell[BoxData[
      \(TraditionalForm\`\(P\&_\^*\)\)]],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`\(T\&_\^*\)\)]],
  ", variances ",
  Cell[BoxData[
      \(TraditionalForm\`\[Sigma]\_P\%\(\(*\)\(2\)\)\)]],
  " and  ",
  Cell[BoxData[
      \(TraditionalForm\`\[Sigma]\_T\%\(\(*\)\(2\)\)\)]],
  ", and correlation ",
  Cell[BoxData[
      \(TraditionalForm\`\[Rho]\_PT\)]],
  ".  We define the selection group as a mated pair of individuals.  The \
relative fitness of a selection group is defined as its frequency after \
selection divided by its frequency before.  The frequency after selection is \
given by ",
  StyleBox["M",
    FontSlant->"Italic"],
  ", while the \"frequency\" of a mated pair before pairing occurs is simply \
the frequency it would occur under random mating.  "
}], "Text",
  CellMargins->{{18.1875, 24.375}, {Inherited, Inherited}}],

Cell[TextData[{
  "\tWe now make two kinds of approximations.  Assume that the preference and \
trait are not evolving rapidly, so that ",
  Cell[BoxData[
      \(TraditionalForm\`\(P\&_\^*\)\)]],
  " \[TildeTilde] ",
  Cell[BoxData[
      \(TraditionalForm\`P\&_\)]],
  ",  ",
  Cell[BoxData[
      \(TraditionalForm\`\(T\&_\^*\)\)]],
  " \[TildeTilde] ",
  Cell[BoxData[
      \(TraditionalForm\`T\&_\)]],
  ", ",
  Cell[BoxData[
      \(TraditionalForm\`\[Sigma]\_P\%\(\(*\)\(2\)\)\)]],
  " \[TildeTilde] ",
  Cell[BoxData[
      \(TraditionalForm\`\[Sigma]\_P\%2\)]],
  ", and ",
  Cell[BoxData[
      \(TraditionalForm\`\[Sigma]\_T\%\(\(*\)\(2\)\)\)]],
  " \[TildeTilde] ",
  Cell[BoxData[
      \(TraditionalForm\`\[Sigma]\_T\%2\)]],
  ".  Next, approximate ",
  Cell[BoxData[
      \(TraditionalForm\`f\_P\)]],
  ", ",
  Cell[BoxData[
      \(TraditionalForm\`f\_T\)]],
  ", and ",
  StyleBox["M",
    FontSlant->"Italic"],
  " with gaussian densities.  The relative fitness of a mated pair in which \
the female has preference ",
  StyleBox["P",
    FontSlant->"Italic"],
  " and the male has trait ",
  StyleBox["T",
    FontSlant->"Italic"],
  " is"
}], "Text",
  CellMargins->{{18.1875, 24.375}, {Inherited, Inherited}}],

Cell[TextData[{
  "\n",
  Cell[BoxData[
      \(TraditionalForm\`\(\(\[IndentingNewLine]\)\(\ \)\(w(P, 
          T)\ \ \  = \ \ \ \(M(P, \ T)\)\/\(\(\(f\_P\)(P)\)\ \
\(\(f\_T\)(T)\)\)\ \ \ \[IndentingNewLine]\[IndentingNewLine]\
\[IndentingNewLine] \[TildeTilde] \ \ \ 1\/\@\(\(1\)\(\ \ \)\(-\)\(\ \ \)\(\
\[Rho]\^2\)\(\ \)\)\ exp \(\({\ \([\(-\[Rho]\) \((\(\((P\  - \ 
                                    P\&_)\)\^2\) \[Sigma]\_T\%2\ \[Rho]\_PT\ \
\  - \ \ 2\ \((P\  - \ P\&_)\) \((T\  - \ 
                                T\&_)\)\ \[Sigma]\_P\ \[Sigma]\_T\ \ \
\[IndentingNewLine]\[IndentingNewLine]\[IndentingNewLine] + \ \((T\  - \ \
T\&_)\)\^2\ \[Sigma]\_P\%2\ \ \[Rho]\_PT)\)\ ]\)\ /\ \((2 \((1\  - \ \ \[Rho]\
\_PT\^2)\) \(\[Sigma]\_P\%2\) \[Sigma]\_T\%2)\)}\)\(\ \)\(.\)\(\
\[IndentingNewLine]\)\)\)\)\)]]
}], "NumberedEquation",
  CellMargins->{{18.1875, 24.375}, {Inherited, Inherited}},
  CellTags->"SexSelFitnessFunctionVersion1"],

Cell[TextData[{
  "To calculate the selection coefficients, the fitness function must be \
expressed as a polynomial.  Taking the first-order Taylor series of ",
  StyleBox["w",
    FontSlant->"Italic"],
  "(",
  StyleBox["P",
    FontSlant->"Italic"],
  ",",
  StyleBox["T",
    FontSlant->"Italic"],
  ")",
  " around ",
  Cell[BoxData[
      \(TraditionalForm\`P\&_\)]],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`T\&_\)]],
  " gives:"
}], "Text",
  CellMargins->{{18.1875, 24.375}, {Inherited, Inherited}}],

Cell[TextData[{
  "\n",
  Cell[BoxData[
      FormBox[
        RowBox[{"\[IndentingNewLine]", " ", 
          RowBox[{
            RowBox[{
              RowBox[{
                
                FormBox[\(\(w(P, 
                      T)\)\(\ \ \ \ \)\(\[TildeTilde]\)\(\ \ \ \)\),
                  "TraditionalForm"], \(1\/\@\(1 - \[Rho]\_PT\^2\)\)}], "+", 
              FractionBox[
                RowBox[{" ", 
                  RowBox[{\(\[Rho]\_PT\), 
                    RowBox[{"(", 
                      RowBox[{
                        StyleBox["P",
                          FontSlant->"Italic"], " ", "-", "  ", 
                        OverscriptBox[
                          StyleBox["P",
                            FontSlant->"Italic"], "_"]}], ")"}], " ", 
                    RowBox[{"(", 
                      RowBox[{
                        StyleBox["T",
                          FontSlant->"Italic"], " ", "-", "  ", 
                        OverscriptBox[
                          StyleBox["T",
                            FontSlant->"Italic"], "_"]}], 
                      ")"}]}]}], \(\(\ \)\(\(\((1 - \[Rho]\_PT\^2)\)\^\(3/
                        2\)\) \[Sigma]\_P\ \[Sigma]\_T\)\)]}], "    ", 
            "\[TildeTilde]", "   ", 
            RowBox[{"1", "  ", "+", "  ", 
              RowBox[{\(\[Rho]\_PT\), 
                RowBox[{
                  FractionBox[
                    RowBox[{
                      RowBox[{"(", 
                        RowBox[{
                          StyleBox["P",
                            FontSlant->"Italic"], " ", "-", "  ", 
                          OverscriptBox[
                            StyleBox["P",
                              FontSlant->"Italic"], "_"]}], ")"}], " ", 
                      RowBox[{"(", 
                        RowBox[{
                          StyleBox["T",
                            FontSlant->"Italic"], " ", "-", "  ", 
                          StyleBox[
                            OverscriptBox[
                              StyleBox["T",
                                FontSlant->"Italic"], "_"],
                            FontSlant->"Italic"]}], 
                        ")"}]}], \(\[Sigma]\_P\ \[Sigma]\_T\)], ".", 
                  "\[IndentingNewLine]"}]}]}]}]}], TraditionalForm]]],
  "\n"
}], "NumberedEquation",
  CellMargins->{{18.1875, 24.375}, {Inherited, Inherited}},
  CellTags->"SexSelFitnessFunctionVersion2"],

Cell[TextData[{
  "The last step, which is not required for the QLE approximation, linearizes \
the fitness function in ",
  Cell[BoxData[
      \(TraditionalForm\`\[Rho]\_PT\)]],
  ".  The result is quite accurate for ",
  Cell[BoxData[
      \(TraditionalForm\`\[Rho]\_PT\)]],
  " less than 0.4."
}], "Text",
  CellMargins->{{18.1875, 24.375}, {Inherited, Inherited}}],

Cell[TextData[{
  "\tNow substitute the expressions for ",
  StyleBox["P",
    FontSlant->"Italic"],
  " and ",
  StyleBox["T",
    FontSlant->"Italic"],
  " written in the form of ",
  ButtonBox["Equation ",
    ButtonData:>"ZTwoLoci",
    ButtonStyle->"Hyperlink"],
  
  CounterBox["NumberedEquation", "ZTwoLoci"],
  " into ",
  ButtonBox["Equation ",
    ButtonData:>"SexSelFitnessFunctionVersion2",
    ButtonStyle->"Hyperlink"],
  
  CounterBox["NumberedEquation", "SexSelFitnessFunctionVersion2"],
  ButtonBox[".  ",
    ButtonData:>"SexSelFitnessFunctionVersion2",
    ButtonStyle->"Hyperlink"],
  "The selection coefficient for a set of loci \[DoubleStruckCapitalA] are \
then again given by the coefficient of ",
  Cell[BoxData[
      \(TraditionalForm\`\[Zeta]\_\[DoubleStruckCapitalA]\)]],
  " in the fitness function.  We find that the selection coefficient for a \
preference position \[DoubleStruckI] in a female and a trait position \
\[DoubleStruckJ] in a male is"
}], "Text",
  CellMargins->{{18.1875, 24.375}, {Inherited, Inherited}}],

Cell[TextData[{
  "\n",
  Cell[BoxData[
      FormBox[
        RowBox[{"\[IndentingNewLine]", " ", 
          RowBox[{
            SubscriptBox["a", 
              RowBox[{
                SubscriptBox[
                  StyleBox["i",
                    FontSlant->"Italic"], 
                  StyleBox["f",
                    FontSlant->"Plain"]], 
                SubscriptBox["j", 
                  StyleBox["m",
                    FontSlant->"Plain"]]}]], "  ", "\[TildeTilde]", "   ", 
            RowBox[{\(\[Rho]\_PT\), 
              RowBox[{
                FractionBox[
                  RowBox[{
                    SubsuperscriptBox["b", 
                      SubscriptBox[
                        StyleBox["i",
                          FontSlant->"Italic"], 
                        StyleBox["f",
                          FontSlant->"Plain"]], 
                      StyleBox["P",
                        FontSlant->"Plain"]], " ", 
                    SubsuperscriptBox["b", 
                      SubscriptBox[
                        StyleBox["j",
                          FontSlant->"Italic"], 
                        StyleBox["m",
                          FontSlant->"Plain"]], 
                      StyleBox["T",
                        FontSlant->"Plain"]]}], \(\[Sigma]\_P\ \[Sigma]\_T\)],
                 " ", ".", "\[IndentingNewLine]"}]}]}]}], TraditionalForm]]],
  "\n"
}], "NumberedEquation",
  CellMargins->{{18.1875, 24.375}, {Inherited, Inherited}},
  CellTags->"SexSelSelectionCoefficient"],

Cell[TextData[{
  "The context for each locus has only the sex-of-carrier (female for the \
preference locus ",
  StyleBox["i",
    FontSlant->"Italic"],
  ", male for the trait locus ",
  StyleBox["j",
    FontSlant->"Italic"],
  ").  That is because of our assumption that the parent from which a gene \
was inherited (its sex-of-origin) does not affect its expression."
}], "Text",
  CellMargins->{{18.1875, 24.375}, {Inherited, Inherited}}],

Cell[TextData[{
  "\tThis result shows that the force of sexual selection that unites a \
female preference gene with a male trait gene is simply proportional to ",
  Cell[BoxData[
      \(TraditionalForm\`\[Rho]\_PT\)]],
  ", the phenotypic correlation between the preference and trait among mated \
pairs.  It is also proportional to the size of each gene's effect on the \
phenotype relative to the character's phenotypic standard deviation.  \
Selection coefficients for all other sets of positions are 0.  "
}], "Text",
  CellMargins->{{18.1875, 24.375}, {Inherited, Inherited}}],

Cell["\<\
\tThese selection coefficients are valid regardless of how the \
genes affecting the preference and the male trait are inherited.  In the \
following two sections we find the genetic correlation generated by this type \
of selection when the loci are haploid autosomal, diploid autosomal, and \
diploid X-linked.  The examples show how the QLE approximation accomodates \
different modes of inheritance.\
\>", "Text",
  CellMargins->{{18.1875, 24.375}, {Inherited, Inherited}}]
}, Closed]],

Cell[CellGroupData[{

Cell["\tHaploid autosomal inheritance", "Subsection",
  CellMargins->{{18.1875, 24.375}, {Inherited, Inherited}},
  CellTags->"Haploid autosomal inheritance"],

Cell["\<\
\tWe begin by calculating the genetic correlation in males between \
the female preference and male trait.  In haploids, a context needs to only \
keep track of a gene's sex-of-carrier, so we can write this correlation \
as\
\>", "Text",
  CellMargins->{{18.1875, 24.375}, {Inherited, Inherited}}],

Cell[TextData[{
  "\n",
  Cell[BoxData[
      FormBox[
        RowBox[{"\[IndentingNewLine]", " ", 
          RowBox[{\(r\_PT\), "   ", "=", "  ", 
            RowBox[{\(\[Sum]\_\(i \[Element] \[DoubleStruckCapitalP]\)\), 
              RowBox[{\(\[Sum]\_\(j \[Element] \[DoubleStruckCapitalT]\)\), 
                RowBox[{
                  SubsuperscriptBox["b", 
                    SubscriptBox[
                      StyleBox["i",
                        FontSlant->"Italic"], 
                      StyleBox["f",
                        FontSlant->"Plain"]], 
                    StyleBox["P",
                      FontSlant->"Plain"]], " ", 
                  SubsuperscriptBox["b", 
                    SubscriptBox[
                      StyleBox["j",
                        FontSlant->"Italic"], 
                      StyleBox["m",
                        FontSlant->"Plain"]], 
                    StyleBox["T",
                      FontSlant->"Plain"]], 
                  RowBox[{
                    SubscriptBox["D", 
                      RowBox[{
                        SubscriptBox["i", 
                          StyleBox["m",
                            FontSlant->"Plain"]], 
                        SubscriptBox["j", 
                          StyleBox["m",
                            FontSlant->"Plain"]]}]], ".", " ", 
                    "\[IndentingNewLine]"}]}]}]}]}]}], TraditionalForm]]],
  "\n"
}], "NumberedEquation",
  CellMargins->{{18.1875, 24.375}, {Inherited, Inherited}},
  CellTags->"SexSelGeneticCorrelationInGeneral"],

Cell["\<\
When the preference and trait loci are autosomal, this correlation \
is the same in male and female zygotes.  The genetic variance of the \
preference in females and of the trait in males are:\
\>", "Text",
  CellMargins->{{18.1875, 24.375}, {Inherited, Inherited}}],

Cell[TextData[{
  "\n",
  Cell[BoxData[{
      FormBox[
        RowBox[{"\[IndentingNewLine]", " ", 
          RowBox[{
            SubscriptBox["G", 
              StyleBox["P",
                FontSlant->"Plain"]], "   ", "=", "  ", 
            RowBox[{
              
              RowBox[{\(\[Sum]\_\(i, j \[Element] \[DoubleStruckCapitalP]\)\),
                 
                RowBox[{
                  SubsuperscriptBox["b", "i", 
                    StyleBox["P",
                      FontSlant->"Plain"]], 
                  SubsuperscriptBox["b", "j", 
                    StyleBox["P",
                      FontSlant->"Plain"]], \(D\_ij\)}]}], "     ", "=", "  ",
               
              RowBox[{
                
                RowBox[{\(\[Sum]\_\(i \[Element] \[DoubleStruckCapitalP]\)\), 
                  
                  RowBox[{
                    SuperscriptBox[
                      RowBox[{"(", 
                        SubsuperscriptBox["b", "i", 
                          StyleBox["P",
                            FontSlant->"Plain"]], ")"}], "2"], \(pq\_i\)}]}], 
                "  ", "+", "  ", \(\(O(a)\)\ \ \ \ and\)}]}]}], 
          "\[IndentingNewLine]", "\[IndentingNewLine]"}], TraditionalForm], 
    "\[IndentingNewLine]", 
      FormBox[
        RowBox[{
          SubscriptBox["G", 
            StyleBox["T",
              FontSlant->"Plain"]], "   ", "=", "  ", 
          RowBox[{
            RowBox[{\(\[Sum]\_\(i, j \[Element] \[DoubleStruckCapitalT]\)\), 
              RowBox[{
                SubsuperscriptBox["b", "i", 
                  StyleBox["T",
                    FontSlant->"Plain"]], 
                SubsuperscriptBox["b", "j", 
                  StyleBox["T",
                    FontSlant->"Plain"]], \(D\_ij\)}]}], "     ", "=", "  ", 
            RowBox[{
              RowBox[{\(\[Sum]\_\(i \[Element] \[DoubleStruckCapitalT]\)\), 
                RowBox[{
                  SuperscriptBox[
                    RowBox[{"(", 
                      SubsuperscriptBox["b", "i", 
                        StyleBox["T",
                          FontSlant->"Plain"]], ")"}], "2"], \(pq\_i\)}]}], 
              "  ", "+", 
              "  ", \(\(O(a)\)\(\ \)\(.\)\(\[IndentingNewLine]\)\)}]}]}], 
        TraditionalForm]}]],
  "\n"
}], "NumberedEquation",
  CellMargins->{{18.1875, 24.375}, {Inherited, Inherited}},
  CellTags->"HaploidGeneticVariancesForPandT"],

Cell[TextData[{
  "To calculate the covariance, we substitute the selection coefficients we \
just calculated (Equation ",
  
  CounterBox["NumberedEquation", "SexSelSelectionCoefficient"],
  ButtonBox[")",
    ButtonData:>"SexSelSelectionCoefficient",
    ButtonStyle->"Hyperlink"],
  " into the expression for the associations at QLE (",
  ButtonBox["Equation ",
    ButtonData:>"DAtQLEInHaploids",
    ButtonStyle->"Hyperlink"],
  
  CounterBox["NumberedEquation", "DAtQLEInHaploids"],
  "), giving"
}], "Text",
  CellMargins->{{18.1875, 24.375}, {Inherited, Inherited}}],

Cell[TextData[{
  "\n",
  Cell[BoxData[
      FormBox[
        RowBox[{"\[IndentingNewLine]", " ", 
          RowBox[{
            SubscriptBox[\(D\&~\), 
              RowBox[{
                SubscriptBox[
                  StyleBox["i",
                    FontSlant->"Italic"], 
                  StyleBox["m",
                    FontSlant->"Plain"]], ",", 
                SubscriptBox[
                  StyleBox["j",
                    FontSlant->"Italic"], 
                  StyleBox["m",
                    FontSlant->"Plain"]]}]], "   ", "=", "  ", 
            RowBox[{
              RowBox[{
                RowBox[{"(", 
                  FractionBox[
                    SubscriptBox["t", 
                      RowBox[{
                        RowBox[{
                          SubscriptBox["i", 
                            StyleBox["m",
                              FontSlant->"Plain"]], " ", 
                          SubscriptBox["j", 
                            StyleBox["m",
                              FontSlant->"Plain"]]}], "\[LeftArrow]", " ", 
                        RowBox[{
                          SubscriptBox["i", 
                            StyleBox["f",
                              FontSlant->"Plain"]], " ", 
                          SubscriptBox["j", 
                            StyleBox["m",
                              FontSlant->"Plain"]]}]}]], 
                    SubscriptBox["r", 
                      StyleBox["ij",
                        FontSlant->"Italic"]]], ")"}], " ", 
                SubscriptBox["a", 
                  RowBox[{
                    SubscriptBox[
                      StyleBox["i",
                        FontSlant->"Italic"], 
                      StyleBox["f",
                        FontSlant->"Plain"]], 
                    SubscriptBox["j", 
                      StyleBox["m",
                        FontSlant->"Plain"]]}]], 
                SubscriptBox["pq", 
                  StyleBox["ij",
                    FontSlant->"Italic"]]}], "   ", "=", "   ", 
              RowBox[{\(1\/2\), " ", \(\[Rho]\_PT\), 
                FractionBox[
                  RowBox[{
                    SubscriptBox["b", 
                      SubscriptBox[
                        StyleBox["i",
                          FontSlant->"Italic"], 
                        StyleBox["f",
                          FontSlant->"Plain"]]], " ", 
                    SubscriptBox["b", 
                      SubscriptBox[
                        StyleBox["j",
                          FontSlant->"Italic"], 
                        StyleBox["m",
                          
                          FontSlant->
                            "Plain"]]]}], \(\[Sigma]\_P\ \[Sigma]\_T\)], " ", 
                
                RowBox[{
                  SubscriptBox["pq", 
                    StyleBox["ij",
                      FontSlant->"Italic"]], ".", 
                  "\[IndentingNewLine]"}]}]}]}]}], TraditionalForm]]],
  "\n"
}], "NumberedEquation",
  CellMargins->{{18.1875, 24.375}, {Inherited, Inherited}},
  CellTags->"SexSelD"],

Cell[TextData[{
  "Substituting that result into",
  ButtonBox[" (",
    ButtonData:>"SexSelGeneticCorrelationInGeneral",
    ButtonStyle->"Hyperlink"],
  
  CounterBox["NumberedEquation", "SexSelGeneticCorrelationInGeneral"],
  ")",
  " gives the genetic covariance and genetic correlation between a female \
mating preference and a male display trait in haploids:"
}], "Text",
  CellMargins->{{18.1875, 24.375}, {Inherited, Inherited}}],

Cell[TextData[{
  "\n",
  Cell[BoxData[
      FormBox[
        RowBox[{"\[IndentingNewLine]", 
          RowBox[{
            RowBox[{\(G\_PT\), "  ", "\[TildeTilde]", "  ", 
              RowBox[{\(1\/2\), " ", \(\[Rho]\_PT\), " ", 
                SubscriptBox["h", 
                  StyleBox["P",
                    FontSlant->"Plain"]], " ", 
                SubscriptBox["h", 
                  StyleBox["T",
                    FontSlant->"Plain"]], 
                SqrtBox[
                  RowBox[{
                    SubscriptBox["G", 
                      StyleBox["P",
                        FontSlant->"Plain"]], " ", 
                    SubscriptBox["G", 
                      StyleBox["T",
                        FontSlant->"Plain"]]}]]}]}], " ", ",", "     ", 
            RowBox[{\(r\_PT\), "   ", "\[TildeTilde]", "  ", 
              RowBox[{\(1\/2\), " ", \(\[Rho]\_PT\), " ", 
                SubscriptBox["h", 
                  StyleBox["P",
                    FontSlant->"Plain"]], " ", 
                SubscriptBox["h", 
                  StyleBox["T",
                    FontSlant->"Plain"]]}]}], "  ", ",", 
            "\[IndentingNewLine]"}]}], TraditionalForm]]],
  "\n"
}], "NumberedEquation",
  CellMargins->{{18.1875, 24.375}, {Inherited, Inherited}},
  CellTags->"GPTandrPTInHaploids"],

Cell[TextData[{
  "where ",
  Cell[BoxData[
      FormBox[
        SubscriptBox["h", 
          StyleBox["P",
            FontSlant->"Plain"]], TraditionalForm]]],
  " and ",
  Cell[BoxData[
      FormBox[
        StyleBox[
          SubscriptBox["h", 
            StyleBox["T",
              FontSlant->"Plain"]],
          FontColor->RGBColor[1, 0, 0]], TraditionalForm]]],
  " are the square roots of the heritabilities of the preference in females \
and the trait in males.  This result agrees with Kirkpatrick and Barton (",
  ButtonBox["1997",
    ButtonData:>"Kirkpatrick & Barton 1997",
    ButtonStyle->"Hyperlink"],
  "), who used the ",
  ButtonBox["BT91",
    ButtonData:>"Barton & Turelli 1991",
    ButtonStyle->"Hyperlink"],
  " framework for their calculation."
}], "Text",
  CellMargins->{{18.1875, 24.375}, {Inherited, Inherited}}]
}, Open  ]],

Cell[CellGroupData[{

Cell["\tDiploid autosomal inheritance", "Subsection",
  CellMargins->{{18.1875, 24.375}, {Inherited, Inherited}},
  CellTags->"Haploid autosomal inheritance"],

Cell["\<\
\tIn diploids, there are two positions at the preference locus and \
two at the trait locus, corresponding to copies of those genes inherited from \
mothers and fathers.  The genetic covariance between preference and trait in \
males is therefore\
\>", "Text",
  CellMargins->{{18.1875, 24.375}, {Inherited, Inherited}}],

Cell[TextData[{
  "\n",
  Cell[BoxData[
      FormBox[
        RowBox[{"\[IndentingNewLine]", " ", 
          RowBox[{
            SubsuperscriptBox["G", 
              StyleBox["PT",
                FontSlant->"Plain"], 
              StyleBox["m",
                FontSlant->"Plain"]], "   ", "=", "  ", 
            RowBox[{\(\[Sum]\_\(i \[Element] \[DoubleStruckCapitalP]\)\), 
              RowBox[{\(\[Sum]\_\(j \[Element] \[DoubleStruckCapitalT]\)\), 
                RowBox[{
                  SubsuperscriptBox["b", 
                    SubscriptBox[
                      StyleBox["i",
                        FontSlant->"Italic"], 
                      StyleBox["f",
                        FontSlant->"Plain"]], 
                    StyleBox["P",
                      FontSlant->"Plain"]], " ", 
                  RowBox[{
                    RowBox[{
                      SubsuperscriptBox["b", 
                        SubscriptBox[
                          StyleBox["j",
                            FontSlant->"Italic"], 
                          StyleBox["m",
                            FontSlant->"Plain"]], 
                        StyleBox["T",
                          FontSlant->"Plain"]], "(", 
                      RowBox[{
                        SubscriptBox["D", 
                          RowBox[{
                            SubscriptBox["i", 
                              StyleBox["mf",
                                FontSlant->"Plain"]], 
                            SubscriptBox["j", 
                              StyleBox["mf",
                                FontSlant->"Plain"]]}]], " ", "+", " ", 
                        SubscriptBox["D", 
                          RowBox[{
                            SubscriptBox["i", 
                              StyleBox["mf",
                                FontSlant->"Plain"]], 
                            SubscriptBox["j", 
                              StyleBox["mm",
                                FontSlant->"Plain"]]}]], " ", "+", " ", 
                        SubscriptBox["D", 
                          RowBox[{
                            SubscriptBox["i", 
                              StyleBox["mm",
                                FontSlant->"Plain"]], 
                            SubscriptBox["j", 
                              StyleBox["mf",
                                FontSlant->"Plain"]]}]], " ", "+", " ", 
                        SubscriptBox["D", 
                          RowBox[{
                            SubscriptBox["i", 
                              StyleBox["mm",
                                FontSlant->"Plain"]], 
                            SubscriptBox["j", 
                              StyleBox["mm",
                                FontSlant->"Plain"]]}]]}], ")"}], " ", ".", 
                    " ", "\[IndentingNewLine]"}]}]}]}]}]}], 
        TraditionalForm]]],
  "\n"
}], "NumberedEquation",
  CellMargins->{{18.1875, 24.375}, {Inherited, Inherited}},
  CellTags->"GPTForDiploidAutosomesInTermsOfDs"],

Cell[TextData[{
  "The genetic variances are twice the values given by Equation (",
  
  CounterBox["NumberedEquation", "HaploidGeneticVariancesForPandT"],
  ") because diploid zygotes carry two haploid genomes.  The covariance in \
female zygotes has the same value because the loci are autosomal."
}], "Text",
  CellMargins->{{18.1875, 24.375}, {Inherited, Inherited}}],

Cell[TextData[{
  "\tTo find those associations, we use ",
  ButtonBox["Equations ",
    ButtonData:>"DAtQLEInHaploids",
    ButtonStyle->"Hyperlink"],
  ButtonBox["(",
    ButtonData:>"DatQLECase2",
    ButtonStyle->"Hyperlink"],
  
  CounterBox["NumberedEquation", "DatQLECase2"],
  ButtonBox[") and (",
    ButtonData:>"DatQLECase2",
    ButtonStyle->"Hyperlink"],
  
  CounterBox["NumberedEquation", "QLECase3Autosomes"],
  ButtonBox[")",
    ButtonData:>"QLECase3Autosomes",
    ButtonStyle->"Hyperlink"],
  ".  The function ",
  StyleBox["T",
    FontSlant->"Italic"],
  " that appears there",
  " is calculated using ",
  ButtonBox["(",
    ButtonData:>"TDefn",
    ButtonStyle->"Hyperlink"],
  
  CounterBox["NumberedEquation", "TDefn"],
  ButtonBox[")",
    ButtonData:>"TDefn",
    ButtonStyle->"Hyperlink"],
  ":"
}], "Text",
  CellMargins->{{18.1875, 24.375}, {Inherited, Inherited}}],

Cell[TextData[{
  "\n",
  Cell[BoxData[
      FormBox[
        RowBox[{"\[IndentingNewLine]", " ", 
          RowBox[{
            RowBox[{
              RowBox[{"T", "(", 
                SubscriptBox[
                  StyleBox["ij",
                    FontSlant->"Italic"], "ff"], " ", ")"}], "   ", "=", 
              "   ", 
              RowBox[{
                RowBox[{"T", "(", 
                  SubscriptBox[
                    StyleBox["ij",
                      FontSlant->"Italic"], "mf"], ")"}], "   ", "=", "   ", 
                RowBox[{
                  
                  RowBox[{\(t\_\(\(i\_ff\) j\_ff \[LeftArrow] \ \(i\_ff\) 
                            j\_fm\)\), " ", 
                    SubscriptBox["a", 
                      RowBox[{
                        SubscriptBox["i", 
                          StyleBox["f",
                            FontSlant->"Plain"]], 
                        SubscriptBox["j", 
                          StyleBox["m",
                            FontSlant->"Plain"]]}]]}], "   ", "=", "   ", 
                  RowBox[{\(1\/2\), 
                    SubsuperscriptBox["r", 
                      StyleBox["ij",
                        FontSlant->"Italic"], 
                      StyleBox["f",
                        FontSlant->"Plain"]], 
                    SubscriptBox["a", 
                      RowBox[{
                        SubscriptBox["i", 
                          StyleBox["f",
                            FontSlant->"Plain"]], 
                        SubscriptBox["j", 
                          StyleBox["m",
                            FontSlant->"Plain"]]}]]}]}]}]}], ",", " ", 
            "\[IndentingNewLine]", "\[IndentingNewLine]", 
            "\[IndentingNewLine]", 
            RowBox[{
              RowBox[{"T", "(", 
                SubscriptBox[
                  StyleBox["ij",
                    FontSlant->"Italic"], "fm"], " ", ")"}], "   ", "=", 
              "   ", 
              RowBox[{
                RowBox[{"T", "(", 
                  SubscriptBox[
                    StyleBox["ij",
                      FontSlant->"Italic"], "mm"], ")"}], "   ", "=", "   ", 
                RowBox[{
                  
                  RowBox[{\(t\_\(\(i\_fm\) j\_fm \[LeftArrow] \ \(i\_mf\) 
                            j\_mm\)\), " ", 
                    SubscriptBox["a", 
                      RowBox[{
                        SubscriptBox["i", 
                          StyleBox["f",
                            FontSlant->"Plain"]], 
                        SubscriptBox["j", 
                          StyleBox["m",
                            FontSlant->"Plain"]]}]]}], "   ", "=", "   ", 
                  RowBox[{\(1\/2\), 
                    SubsuperscriptBox["r", 
                      StyleBox["ij",
                        FontSlant->"Italic"], 
                      StyleBox["m",
                        FontSlant->"Plain"]], 
                    RowBox[{
                      SubscriptBox["a", 
                        RowBox[{
                          SubscriptBox["i", 
                            StyleBox["f",
                              FontSlant->"Plain"]], 
                          SubscriptBox["j", 
                            StyleBox["m",
                              FontSlant->"Plain"]]}]], ".", 
                      "\[IndentingNewLine]"}]}]}]}]}]}]}], 
        TraditionalForm]]],
  "\n"
}], "NumberedEquation",
  CellMargins->{{18.1875, 24.375}, {Inherited, Inherited}},
  CellTags->"TForDiploidAutosomes"],

Cell[TextData[{
  "The QLE approximations for the associations are found by substituting the \
selection coefficient from Equation (",
  
  CounterBox["NumberedEquation", "SexSelSelectionCoefficient"],
  ButtonBox[")",
    ButtonData:>"SexSelSelectionCoefficient",
    ButtonStyle->"Hyperlink"],
  " into those expressions, and then those results into",
  ButtonBox[" ",
    ButtonData:>"DAtQLEInHaploids",
    ButtonStyle->"Hyperlink"],
  ButtonBox["(",
    ButtonData:>"DatQLECase2",
    ButtonStyle->"Hyperlink"],
  
  CounterBox["NumberedEquation", "DatQLECase2"],
  ButtonBox[") and (",
    ButtonData:>"DatQLECase2",
    ButtonStyle->"Hyperlink"],
  
  CounterBox["NumberedEquation", "QLECase3Autosomes"],
  ButtonBox[")",
    ButtonData:>"QLECase3Autosomes",
    ButtonStyle->"Hyperlink"],
  ", giving"
}], "Text",
  CellMargins->{{18.1875, 24.375}, {Inherited, Inherited}}],

Cell[TextData[{
  "\n",
  Cell[BoxData[
      FormBox[
        RowBox[{"\[IndentingNewLine]", " ", 
          RowBox[{
            RowBox[{
              SubscriptBox[\(D\&~\), 
                RowBox[{
                  SubscriptBox[
                    StyleBox["i",
                      FontSlant->"Italic"], "mf"], 
                  SubscriptBox[
                    StyleBox["j",
                      FontSlant->"Italic"], 
                    StyleBox["mf",
                      FontSlant->"Plain"]]}]], "   ", "=", "  ", 
              RowBox[{
                SubscriptBox[\(D\&~\), 
                  RowBox[{
                    SubscriptBox[
                      StyleBox["i",
                        FontSlant->"Italic"], 
                      StyleBox["mm",
                        FontSlant->"Plain"]], 
                    SubscriptBox[
                      StyleBox["j",
                        FontSlant->"Italic"], 
                      StyleBox["mm",
                        FontSlant->"Plain"]]}]], "   ", "=", "    ", 
                RowBox[{\(1\/2\), \(\[Rho]\_PT\), 
                  FractionBox[
                    RowBox[{
                      SubsuperscriptBox["b", 
                        SubscriptBox[
                          StyleBox["i",
                            FontSlant->"Italic"], 
                          StyleBox["f",
                            FontSlant->"Plain"]], 
                        StyleBox["P",
                          FontSlant->"Plain"]], " ", 
                      SubsuperscriptBox["b", 
                        SubscriptBox[
                          StyleBox["j",
                            FontSlant->"Italic"], 
                          StyleBox["m",
                            FontSlant->"Plain"]], 
                        StyleBox["T",
                          
                          FontSlant->
                            "Plain"]]}], \(\[Sigma]\_P\ \[Sigma]\_T\)], " ", 
                  SubscriptBox["pq", 
                    StyleBox["ij",
                      FontSlant->"Italic"]]}]}]}], "  ", ",", 
            "\[IndentingNewLine]", "\[IndentingNewLine]", 
            "\[IndentingNewLine]", 
            RowBox[{
              SubscriptBox[\(D\&~\), 
                RowBox[{
                  SubscriptBox[
                    StyleBox["i",
                      FontSlant->"Italic"], 
                    StyleBox["mf",
                      FontSlant->"Plain"]], 
                  SubscriptBox[
                    StyleBox["j",
                      FontSlant->"Italic"], 
                    StyleBox["mm",
                      FontSlant->"Plain"]]}]], "   ", "=", "  ", 
              RowBox[{\(\[Rho]\_PT\), 
                FractionBox[
                  RowBox[{
                    SubsuperscriptBox["b", 
                      SubscriptBox[
                        StyleBox["i",
                          FontSlant->"Italic"], 
                        StyleBox["f",
                          FontSlant->"Plain"]], 
                      StyleBox["P",
                        FontSlant->"Plain"]], " ", 
                    SubsuperscriptBox["b", 
                      SubscriptBox[
                        StyleBox["j",
                          FontSlant->"Italic"], 
                        StyleBox["m",
                          FontSlant->"Plain"]], 
                      StyleBox["T",
                        FontSlant->"Plain"]]}], \(\[Sigma]\_P\ \[Sigma]\_T\)],
                 " ", 
                SubscriptBox["pq", 
                  StyleBox["ij",
                    FontSlant->"Italic"]]}]}], " ", ",", "   ", 
            RowBox[{
              SubscriptBox[\(D\&~\), 
                RowBox[{
                  SubscriptBox[
                    StyleBox["i",
                      FontSlant->"Italic"], 
                    StyleBox["mm",
                      FontSlant->"Plain"]], 
                  SubscriptBox[
                    StyleBox["j",
                      FontSlant->"Italic"], 
                    StyleBox["mf",
                      FontSlant->"Plain"]]}]], "  ", "=", "   ", "0.", 
              "\[IndentingNewLine]"}]}]}], TraditionalForm]]],
  "\n"
}], "NumberedEquation",
  CellMargins->{{18.1875, 24.375}, {Inherited, Inherited}},
  CellTags->"SexSelDForDiploidAutosomes"],

Cell[TextData[{
  "Substituting these into (",
  
  CounterBox["NumberedEquation", "GPTForDiploidAutosomesInTermsOfDs"],
  ") shows that the genetic covariance and genetic correlation are the same \
as we found for the haploid case, Equations (",
  
  CounterBox["NumberedEquation", "GPTandrPTInHaploids"],
  ").  This is a useful result, as it shows that several basic conclusions \
based on haploid models regarding the evolution of mating preferences \
(Kirkpatrick and Barton ",
  ButtonBox["1997",
    ButtonData:>"Kirkpatrick & Barton 1997",
    ButtonStyle->"Hyperlink"],
  ") and reinforcement (Kirkpatrick and Servedio, ",
  ButtonBox["1999",
    ButtonData:>"Kirkpatrick & Servedio 1999",
    ButtonStyle->"Hyperlink"],
  ") carry over to diploids.  An interesting conclusion is that the genetic \
correlation is independent of the recombination rates, even when they differ \
between the sexes."
}], "Text",
  CellMargins->{{18.1875, 24.375}, {Inherited, Inherited}}]
}, Closed]],

Cell[CellGroupData[{

Cell["\tX-linked inheritance", "Subsection",
  CellMargins->{{18.1875, 24.375}, {Inherited, Inherited}},
  CellTags->"Haploid autosomal inheritance"],

Cell["\<\
\tTo illustrate how our methods extend to other forms of \
inheritance, consider next a case in which genetic variation in a female \
mating preference is X-linked while variation in the male trait is autosomal. \
 We will see that the genetic covariance and correlation in males are \
different than when both characters are autosomally-inherited.\
\>", "Text",
  CellMargins->{{18.1875, 24.375}, {Inherited, Inherited}}],

Cell["\tThe preference-trait covariance in males is", "Text",
  CellMargins->{{18.1875, 24.375}, {Inherited, Inherited}}],

Cell[TextData[{
  "\n",
  Cell[BoxData[
      FormBox[
        RowBox[{"\[IndentingNewLine]", " ", 
          RowBox[{
            SubsuperscriptBox["G", 
              StyleBox["PT",
                FontSlant->"Plain"], 
              StyleBox["m",
                FontSlant->"Plain"]], "   ", "=", "  ", 
            RowBox[{\(\[Sum]\_\(i \[Element] \[DoubleStruckCapitalP]\)\), 
              RowBox[{\(\[Sum]\_\(j \[Element] \[DoubleStruckCapitalT]\)\), 
                RowBox[{
                  SubsuperscriptBox["b", 
                    SubscriptBox[
                      StyleBox["i",
                        FontSlant->"Italic"], 
                      StyleBox["f",
                        FontSlant->"Plain"]], 
                    StyleBox["P",
                      FontSlant->"Plain"]], " ", 
                  RowBox[{
                    RowBox[{
                      SubsuperscriptBox["b", 
                        SubscriptBox[
                          StyleBox["j",
                            FontSlant->"Italic"], 
                          StyleBox["m",
                            FontSlant->"Plain"]], 
                        StyleBox["T",
                          FontSlant->"Plain"]], "(", 
                      RowBox[{
                        SubscriptBox["D", 
                          RowBox[{
                            SubscriptBox["i", 
                              StyleBox["mf",
                                FontSlant->"Plain"]], 
                            SubscriptBox["j", 
                              StyleBox["mf",
                                FontSlant->"Plain"]]}]], " ", "+", " ", 
                        SubscriptBox["D", 
                          RowBox[{
                            SubscriptBox["i", 
                              StyleBox["mf",
                                FontSlant->"Plain"]], 
                            SubscriptBox["j", 
                              StyleBox["mm",
                                FontSlant->"Plain"]]}]]}], ")"}], " ", ".", 
                    " ", "\[IndentingNewLine]"}]}]}]}]}]}], 
        TraditionalForm]]],
  "\n"
}], "NumberedEquation",
  CellMargins->{{18.1875, 24.375}, {Inherited, Inherited}},
  CellTags->"GmPTForXLinkageInTermsOfDs"],

Cell[TextData[{
  "Because males do not inherit an ",
  StyleBox["X",
    FontSlant->"Italic"],
  " chromosome from their mothers, the terms ",
  Cell[BoxData[
      FormBox[
        SubscriptBox["D", 
          RowBox[{
            SubscriptBox["i", 
              StyleBox["mm",
                FontSlant->"Plain"]], 
            SubscriptBox["j", 
              StyleBox["mf",
                FontSlant->"Plain"]]}]], TraditionalForm]]],
  " and ",
  Cell[BoxData[
      FormBox[
        SubscriptBox["D", 
          RowBox[{
            SubscriptBox["i", 
              StyleBox["mm",
                FontSlant->"Plain"]], 
            SubscriptBox["j", 
              StyleBox["mm",
                FontSlant->"Plain"]]}]], TraditionalForm]]],
  " that appear in the diploid case (see Equation ",
  
  CounterBox["NumberedEquation", "GPTForDiploidAutosomesInTermsOfDs"],
  ") not exist.  The genetic variance for the trait is given by twice the \
expressions in Equation ",
  
  CounterBox["NumberedEquation", "HaploidGeneticVariancesForPandT"],
  " for haploids, because those loci are diploid and autosomal, while the \
variance for the male trait is given by (",
  
  CounterBox["NumberedEquation", "HaploidGeneticVariancesForPandT"],
  "), because males have only one haploid genome for X-linked loci.  "
}], "Text",
  CellMargins->{{18.1875, 24.375}, {Inherited, Inherited}}],

Cell[TextData[{
  "\tThe associations that appear in Equation (",
  
  CounterBox["NumberedEquation", "GmPTForXLinkageInTermsOfDs"],
  ") are given by Equations ",
  ButtonBox["(",
    ButtonData:>"DAtQLEInHaploids",
    ButtonStyle->"Hyperlink"],
  
  CounterBox["NumberedEquation", "DatQLECase2"],
  ") and (",
  
  CounterBox["NumberedEquation", "QLECase3XLinkage"],
  ").  The values for ",
  StyleBox["T",
    FontSlant->"Italic"],
  " are now"
}], "Text",
  CellMargins->{{18.1875, 24.375}, {Inherited, Inherited}}],

Cell[TextData[{
  "\n",
  Cell[BoxData[
      FormBox[
        RowBox[{
          RowBox[{
            RowBox[{"T", "(", 
              SubscriptBox[
                StyleBox["ij",
                  FontSlant->"Italic"], "ff"], " ", ")"}], "   ", "=", "   ", 
            
            RowBox[{
              RowBox[{"T", "(", 
                SubscriptBox[
                  StyleBox["ij",
                    FontSlant->"Italic"], "mf"], ")"}], "   ", "=", "   ", 
              RowBox[{
                
                RowBox[{\(t\_\(\(i\_ff\) j\_ff \[LeftArrow] \ \(i\_ff\) 
                          j\_fm\)\), " ", 
                  SubscriptBox["a", 
                    RowBox[{
                      SubscriptBox["i", 
                        StyleBox["f",
                          FontSlant->"Plain"]], 
                      SubscriptBox["j", 
                        StyleBox["m",
                          FontSlant->"Plain"]]}]]}], "   ", "=", "   ", 
                RowBox[{\(1\/4\), 
                  SubscriptBox["a", 
                    RowBox[{
                      SubscriptBox["i", 
                        StyleBox["f",
                          FontSlant->"Plain"]], 
                      SubscriptBox["j", 
                        StyleBox["m",
                          FontSlant->"Plain"]]}]]}]}]}]}], ",", " ", 
          "\[IndentingNewLine]", "\[IndentingNewLine]", "\[IndentingNewLine]",
           
          RowBox[{
            RowBox[{"T", "(", 
              SubscriptBox[
                StyleBox["ij",
                  FontSlant->"Italic"], "fm"], " ", ")"}], "   ", "=", "    ",
             
            RowBox[{
              
              RowBox[{\(t\_\(\(i\_fm\) j\_fm \[LeftArrow] \ \(i\_mf\) 
                        j\_mm\)\), " ", 
                SubscriptBox["a", 
                  RowBox[{
                    SubscriptBox["i", 
                      StyleBox["f",
                        FontSlant->"Plain"]], 
                    SubscriptBox["j", 
                      StyleBox["m",
                        FontSlant->"Plain"]]}]]}], "   ", "=", "   ", 
              RowBox[{\(1\/2\), 
                SubscriptBox["a", 
                  RowBox[{
                    SubscriptBox["i", 
                      StyleBox["f",
                        FontSlant->"Plain"]], 
                    SubscriptBox["j", 
                      StyleBox["m",
                        FontSlant->"Plain"]]}]]}]}]}], ",", "  ", 
          "\[IndentingNewLine]", "\[IndentingNewLine]", "\[IndentingNewLine]",
           
          RowBox[{
            RowBox[{"T", "(", 
              SubscriptBox[
                StyleBox["ij",
                  FontSlant->"Italic"], "mm"], ")"}], "   ", "=", "  ", 
            RowBox[{
              
              RowBox[{\(t\_\(\(i\_mm\) j\_mm \[LeftArrow] \ \(i\_mf\) 
                        j\_mm\)\), " ", 
                SubscriptBox["a", 
                  RowBox[{
                    SubscriptBox["i", 
                      StyleBox["f",
                        FontSlant->"Plain"]], 
                    SubscriptBox["j", 
                      StyleBox["m",
                        FontSlant->"Plain"]]}]]}], "   ", "=", "   ", "0"}]}],
           " ", ","}], TraditionalForm]]],
  "\n"
}], "NumberedEquation",
  CellMargins->{{18.1875, 24.375}, {Inherited, Inherited}},
  CellTags->"TsXLinkage"],

Cell["\<\
The QLE approximations for the associations in males are \
therefore\
\>", "Text",
  CellMargins->{{18.1875, 24.375}, {Inherited, Inherited}}],

Cell[TextData[{
  "\n",
  Cell[BoxData[
      FormBox[
        RowBox[{"\[IndentingNewLine]", " ", 
          RowBox[{
            RowBox[{
              SubscriptBox[\(D\&~\), 
                RowBox[{
                  SubscriptBox[
                    StyleBox["i",
                      FontSlant->"Italic"], "mf"], ",", 
                  SubscriptBox[
                    StyleBox["j",
                      FontSlant->"Italic"], 
                    StyleBox["mf",
                      FontSlant->"Plain"]]}]], "   ", "=", "   ", 
              RowBox[{
                RowBox[{\(3\/5\), " ", \(a\_\(\(i\_f\) j\_m\)\), " ", 
                  SubscriptBox["pq", 
                    StyleBox["ij",
                      FontSlant->"Italic"]]}], "  ", "=", "   ", 
                RowBox[{\(3\/5\), " ", \(\[Rho]\_PT\), 
                  FractionBox[
                    RowBox[{
                      SubsuperscriptBox["b", 
                        SubscriptBox[
                          StyleBox["i",
                            FontSlant->"Italic"], 
                          StyleBox["f",
                            FontSlant->"Plain"]], 
                        StyleBox["P",
                          FontSlant->"Plain"]], " ", 
                      SubsuperscriptBox["b", 
                        SubscriptBox[
                          StyleBox["j",
                            FontSlant->"Italic"], 
                          StyleBox["f",
                            FontSlant->"Plain"]], 
                        StyleBox["T",
                          
                          FontSlant->
                            "Plain"]]}], \(\[Sigma]\_P\ \[Sigma]\_T\)], " ", 
                  SubscriptBox["pq", 
                    StyleBox["ij",
                      FontSlant->"Italic"]]}]}]}], "  ", ",", "  ", 
            "\[IndentingNewLine]", "\[IndentingNewLine]", 
            "\[IndentingNewLine]", 
            RowBox[{
              SubscriptBox[\(D\&~\), 
                RowBox[{
                  SubscriptBox[
                    StyleBox["i",
                      FontSlant->"Italic"], 
                    StyleBox["mf",
                      FontSlant->"Plain"]], ",", 
                  SubscriptBox[
                    StyleBox["j",
                      FontSlant->"Italic"], 
                    StyleBox["mm",
                      FontSlant->"Plain"]]}]], "   ", "=", "   ", 
              RowBox[{
                RowBox[{\(a\_\(\(i\_f\) j\_m\)\), " ", 
                  SubscriptBox["pq", 
                    StyleBox["ij",
                      FontSlant->"Italic"]]}], "  ", "=", "  ", 
                RowBox[{\(\[Rho]\_PT\), 
                  FractionBox[
                    RowBox[{
                      SubsuperscriptBox["b", 
                        SubscriptBox[
                          StyleBox["i",
                            FontSlant->"Italic"], 
                          StyleBox["f",
                            FontSlant->"Plain"]], 
                        StyleBox["P",
                          FontSlant->"Plain"]], " ", 
                      SubsuperscriptBox["b", 
                        SubscriptBox[
                          StyleBox["j",
                            FontSlant->"Italic"], 
                          StyleBox["m",
                            FontSlant->"Plain"]], 
                        StyleBox["T",
                          
                          FontSlant->
                            "Plain"]]}], \(\[Sigma]\_P\ \[Sigma]\_T\)], " ", 
                  RowBox[{
                    SubscriptBox["pq", 
                      StyleBox["ij",
                        FontSlant->"Italic"]], "  ", ".", 
                    "\[IndentingNewLine]"}]}]}]}]}]}], TraditionalForm]]],
  "\n"
}], "NumberedEquation",
  CellMargins->{{18.1875, 24.375}, {Inherited, Inherited}},
  CellTags->"SexSelDsForXLinkage"],

Cell["\<\
\t  Putting these facts together shows that in male zygotes the \
genetic covariance and correlation between the mating preference and male \
trait are:\
\>", "Text",
  CellMargins->{{18.1875, 24.375}, {Inherited, Inherited}}],

Cell[TextData[{
  "\n",
  Cell[BoxData[
      FormBox[
        RowBox[{"\[IndentingNewLine]", 
          RowBox[{
            RowBox[{
              SubsuperscriptBox["G", "PT", 
                StyleBox["m",
                  FontSlant->"Plain"]], "  ", "\[TildeTilde]", "  ", 
              RowBox[{\(4\/5\), " ", \(\[Rho]\_PT\), " ", 
                SubscriptBox["h", 
                  StyleBox["P",
                    FontSlant->"Plain"]], " ", 
                SubscriptBox["h", 
                  StyleBox["T",
                    FontSlant->"Plain"]], 
                SqrtBox[
                  RowBox[{
                    SubscriptBox["G", 
                      StyleBox["P",
                        FontSlant->"Plain"]], " ", 
                    SubscriptBox["G", 
                      StyleBox["T",
                        FontSlant->"Plain"]]}]]}]}], "  ", ",", "     ", 
            RowBox[{
              SubsuperscriptBox["r", "PT", 
                StyleBox["m",
                  FontSlant->"Plain"]], "   ", "\[TildeTilde]", "  ", 
              RowBox[{\(4\/5\), " ", \(\[Rho]\_PT\), " ", 
                SubscriptBox["h", 
                  StyleBox["P",
                    FontSlant->"Plain"]], " ", 
                RowBox[{
                  SubscriptBox["h", 
                    StyleBox["T",
                      FontSlant->"Plain"]], "     ", ".", 
                  "\[IndentingNewLine]"}]}]}]}]}], TraditionalForm]]],
  "\n"
}], "NumberedEquation",
  CellMargins->{{18.1875, 24.375}, {Inherited, Inherited}},
  CellTags->"GmPTAndrMPTForXLinkage"],

Cell[TextData[{
  "An interesting conclusion is that the genetic covariance and correlation \
are 60% larger here than they are when the preference and male trait are both \
autosomally-inherited (given by Equation ",
  
  CounterBox["NumberedEquation", "GPTandrPTInHaploids"],
  ").  Thus the impact of indirect selection on a female mating preference \
depends on how the preference and trait are inherited."
}], "Text",
  CellMargins->{{18.1875, 24.375}, {Inherited, Inherited}}]
}, Closed]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[StyleBox["7. Discussion",
  FontWeight->"Bold"]], "Subtitle",
  CellMargins->{{18.1875, 24.375}, {Inherited, Inherited}},
  PageBreakAbove->True,
  CellTags->"Discussion"],

Cell[TextData[{
  "(iv)  The most widely applicable approach, which requires that selection \
is weak relative to recombination, is to study the population in a state of \
'quasi-linkage equilibrium' (QLE; Kimura ",
  ButtonBox["1965",
    ButtonData:>"Kimura 1965",
    ButtonStyle->"Hyperlink"],
  ", Nagylaki ",
  ButtonBox["1976",
    ButtonData:>"Nagylaki 1976",
    ButtonStyle->"Hyperlink"],
  ", Gillespie ",
  ButtonBox["1981",
    ButtonData:>"Gillespie 1981",
    ButtonStyle->"Hyperlink"],
  ", Barton and Turelli ",
  ButtonBox["1991",
    ButtonData:>"Barton & Turelli 1991",
    ButtonStyle->"Hyperlink"],
  ", Nagylaki ",
  ButtonBox["1993",
    ButtonData:>"Nagylaki 1993",
    ButtonStyle->"Hyperlink"],
  ", Kirkpatrick and Barton ",
  ButtonBox["1997",
    ButtonData:>"Kirkpatrick & Barton 1997",
    ButtonStyle->"Hyperlink"],
  ", Kirkpatrick and Servedio ",
  ButtonBox["1999",
    ButtonData:>"Kirkpatrick & Servedio 1999",
    ButtonStyle->"Hyperlink"],
  ").  When this approximation is valid, associations change rapidly compared \
to the allele frequencies.  It is then reasonable to assume that, for given \
allele frequencies, the associations are close to the value they would take \
if the allele frequencies were stationary.  These are the QLE values for the \
associations, which can be used to determine the longer timescale changes in \
the allele frequencies.  The approach is identical to that used in some areas \
of physics (references), where the dynamics of a system separate into fast \
and slow variables."
}], "Text",
  CellMargins->{{18.1875, 24.375}, {Inherited, Inherited}},
  CellOpen->False],

Cell["\<\
\tWe have set out a general notation that describes arbitrary modes \
of selection and genetic transmission.  The key components are the \
representation of genotype frequencies in terms of means and higher moments \
of the distribution of allelic states;  of selection as a polynomial function \
of genotype;  and of genetic transmission as the movement of genes between \
different contexts.  The first two components are already well developed, \
particularly in models of additive quantitative traits.  The main \
contribution of this paper is to combine them with a generalized \
representation of transmission.  The calculations can be automated, as \
described in Appendix 4.\
\>", "Text",
  CellMargins->{{18.1875, 24.375}, {Inherited, Inherited}}],

Cell[TextData[{
  "\tHow does a general multilocus notation help us to better understand \
evolution?  A set of equations can be derived automatically for arbitrary \
models, but will in all but the simplest cases be impenetrably complicated.  \
If only a few loci are involved, the equations could be iterated numerically. \
 However, if that were the only aim it would probably be simpler to simulate \
genotype frequencies directly.  The value of an algebraic expression, written \
in terms of multilocus moments or cumulants, is that it allows one to \
identify and interpret the key processes responsible for evolutionary change. \
 For example,  ",
  ButtonBox["Equations (",
    ButtonData:>"DAPrimeCentered",
    ButtonStyle->"Hyperlink"],
  
  CounterBox["NumberedEquation", "DAPrimeCentered"],
  " - ",
  
  CounterBox["NumberedEquation", "dAAtQLEFromExactCalculation"],
  ") show that migration builds up associations among loci in proportion to \
the product of the allele frequency differences.  A second example come from \
the analysis of sexual selection.  The analysis shows that the genetic \
correlation between a female preference and a male trait is directly \
proportional to the phenotypic correlation between the preference and trait \
in mating pairs.  Further, the genetic correlation depends on the way in \
which the preference and trait genes are inherited (",
  ButtonBox["Equations ",
    ButtonData:>"SexSelD",
    ButtonStyle->"Hyperlink"],
  
  CounterBox["NumberedEquation", "GPTandrPTInHaploids"],
  ButtonBox[" and ",
    ButtonData:>"SexSelD",
    ButtonStyle->"Hyperlink"],
  
  CounterBox["NumberedEquation", "GmPTAndrMPTForXLinkage"],
  ").",
  ButtonBox[" ",
    ButtonData:>"SexSelD",
    ButtonStyle->"Hyperlink"]
}], "Text",
  CellMargins->{{18.1875, 24.375}, {Inherited, Inherited}}],

Cell[TextData[{
  "\tDefining a model in a standard notation can reveal similarities among \
apparently different mechanisms.  For example, if the indirect selection on a \
modifier of recombination is expressed in terms of selection coefficients ",
  Cell[BoxData[
      \(TraditionalForm\`\((a\_U)\)\)]],
  ", it can be shown to depend on the effects of recombination on the mean \
and variance of log(fitness), regardless of the causes of fitness variation \
(Barton ",
  ButtonBox["1995",
    ButtonData:>"Barton 1995",
    ButtonStyle->"Hyperlink"],
  ").  An unambiguous notation may also clarify conceptual issues.  We \
believe that models of group selection using our notation may clarify \
definitions of fitness and of 'levels of selection'."
}], "Text",
  CellMargins->{{18.1875, 24.375}, {Inherited, Inherited}}],

Cell[TextData[{
  "\tModels of multiple loci are most fruitful when combined with appropriate \
approximations.  The best-developed is the \"quasi-linkage equilibrium\" \
(QLE) approximation, which assumes that processes such as epistasis and \
migration that generate associations among loci are weak, relative to those \
that break them down, such as recombination, segregation, and mutation (see \
Burger ",
  ButtonBox["2000",
    ButtonData:>"Burger 2000",
    ButtonStyle->"Hyperlink"],
  " pp 81 and 186 for a review).  This leads to simple expressions for \
associations of all orders, and is likely to be accurate for most sexually \
reproducing populations.  Several workers have explored this approach, using \
different measures of association (linkage disequilibrium).  Table 3 \
summarizes these measures and their corresponding versions of the QLE \
approximation.  (For a more detailed treatment, see Burger [",
  ButtonBox["2000",
    ButtonData:>"Burger 2000",
    ButtonStyle->"Hyperlink"],
  ", pp 183-190].) "
}], "Text",
  CellMargins->{{18.1875, 24.375}, {Inherited, Inherited}}],

Cell[TextData[{
  StyleBox[" The different measures can be divided into two classes.",
    FontColor->RGBColor[1, 0, 0]],
  "  Most measures are defined for each genotype, usually as a difference \
between its actual frequency and the frequency expected at linkage \
equilibrium.   In contrast, we define associations as moments of the \
distribution of allelic states; these moments are defined for each set of \
positions ",
  Cell[BoxData[
      \(TraditionalForm\`\((D\_\[DoubleStruckI], \ 
        D\_\[DoubleStruckI]\[DoubleStruckJ]\[DoubleStruckK]\ \
\(\(etc\)\(.\)\))\)\)]],
  ", and correspond in a natural way to a polynomial representation of \
selection.  Moreover, they lead to a simple representation of transmission \
(",
  ButtonBox["Equation ",
    ButtonData:>"ExactChangeInDWithTransmissionNoVariationInT",
    ButtonStyle->"Hyperlink"],
  
  CounterBox["NumberedEquation", 
    "ExactChangeInDWithTransmissionNoVariationInT"],
  ").  When selection acts on an additive quantitative trait, the effects of \
selection are more elegantly represented in terms of the cumulants of the \
distribution of allelic effects, rather than the moments (Burger ",
  ButtonBox["1991",
    ButtonData:>"Burger 1991",
    ButtonStyle->"Hyperlink"],
  ", ",
  ButtonBox["2000",
    ButtonData:>"Burger 2000",
    ButtonStyle->"Hyperlink"],
  ";  Turelli and Barton ",
  ButtonBox["1994",
    ButtonData:>"Turelli & Barton 1994",
    ButtonStyle->"Hyperlink"],
  ").  (This is because the cumulants of the trait distribution are then \
simply sums over multilocus cumulants of the same order.)  Since we do not \
deal primarily with additive traits in this paper, we use moments throughout. \
 However, it is simple to transform between the two representations as \
necessary. ",
  StyleBox[" Moreover, at QLE, when associations are weak, moments and \
cumulants converge; and in general,it is easy to translate between moments \
and cumulants using the ",
    FontColor->RGBColor[1, 0, 0]],
  StyleBox["Mathematica",
    FontSlant->"Italic",
    FontColor->RGBColor[1, 0, 0]],
  StyleBox[" packages.",
    FontColor->RGBColor[1, 0, 0]]
}], "Text",
  CellMargins->{{18.1875, 24.375}, {Inherited, Inherited}}],

Cell[TextData[{
  "\tThe multilocus notations used by Christiansen (",
  ButtonBox["1999",
    ButtonData:>"Christiansen 1999",
    ButtonStyle->"Hyperlink"],
  ") and Burger (",
  ButtonBox["2000",
    ButtonData:>"Burger 2000",
    ButtonStyle->"Hyperlink"],
  ") are closest to that used here.  The main difference is that we deal with \
sets of genes-in-context, or ",
  StyleBox["positions",
    FontSlant->"Italic"],
  ", which allows us to avoid restrictive assumptions such as autosomal \
diploid inheritance, random mating, and equal transmission rates in males and \
female.   The relation between the notations can be illustrated by comparing \
expressions for associations among loci at QLE.  Christiansen's (",
  ButtonBox["1999) ",
    ButtonData:>"Christiansen 1999",
    ButtonStyle->"Hyperlink"],
  "Equation 7.19 for the associations among a set of loci ",
  StyleBox["M",
    FontSlant->"Italic"],
  " in a gamete is"
}], "Text",
  CellMargins->{{18.1875, 24.375}, {Inherited, Inherited}}],

Cell[TextData[{
  "\n",
  Cell[BoxData[
      FormBox[
        RowBox[{
          RowBox[{\(\(D\&^\)\_M\), "   ", "\[TildeTilde]", "   ", 
            FractionBox[
              RowBox[{\([\[Epsilon]\ \ \ \(C\&^\)\_M]\), "  ", "[", " ", 
                RowBox[{
                  RowBox[{
                    SubsuperscriptBox[\(\[Pi]\&^\), "M", 
                      StyleBox["R",
                        FontSlant->"Plain"]], "(", "\[Diameter]", ")"}], "   ",
                   
                  RowBox[{
                    SubsuperscriptBox[\(\[Pi]\&^\), "M", 
                      StyleBox["R",
                        FontSlant->"Plain"]], "(", "M", ")"}]}], " ", "]"}], 
              RowBox[{"1", "  ", "-", "  ", 
                RowBox[{"2", " ", 
                  RowBox[{\(R\_M\), 
                    StyleBox["(",
                      FontSlant->"Italic"], 
                    StyleBox["0",
                      FontSlant->"Italic"], 
                    StyleBox[")",
                      FontSlant->"Italic"]}]}]}]]}], ","}], 
        TraditionalForm]]],
  "\n"
}], "NumberedEquation",
  CellMargins->{{18.1875, 24.375}, {Inherited, Inherited}},
  CellTags->"QLE_Christiansen"],

Cell[TextData[{
  "Here, ",
  Cell[BoxData[
      RowBox[{"[", 
        RowBox[{"\[Epsilon]", " ", 
          SubscriptBox[
            OverscriptBox[
              StyleBox["\[GothicCapitalC]",
                FontSlant->"Italic"], "^"], "M"]}], "]"}]]],
  " is a measure of epistasis amongst the the loci in set ",
  Cell[BoxData[
      \(TraditionalForm\`M\)]],
  ";  under his assumption of no sex differences in selection, it is \
equivalent to our selection coefficients ",
  Cell[BoxData[
      \(TraditionalForm\`a\_\(M\_ff\)\)]],
  ", ",
  Cell[BoxData[
      \(TraditionalForm\`a\_\(M\_fm\)\)]],
  ", ",
  Cell[BoxData[
      \(TraditionalForm\`a\_\(M\_mf\)\)]],
  ", and ",
  Cell[BoxData[
      \(TraditionalForm\`a\_\(M\_mm\)\)]],
  ".  The quantity ",
  Cell[BoxData[
      RowBox[{"[", 
        RowBox[{
          SubsuperscriptBox[\(\[Pi]\&^\), 
            StyleBox["M",
              FontSlant->"Italic"], "R"], \((\[EmptySet])\), " ", 
          SubsuperscriptBox[\(\[Pi]\&^\), 
            StyleBox["M",
              FontSlant->"Italic"], "R"], 
          RowBox[{"(", 
            StyleBox["M",
              FontSlant->"Italic"], ")"}]}], "]"}]]],
  " is the frequency of ",
  Cell[BoxData[
      \(TraditionalForm\`M\)]],
  " gametes at linkage equilibrium, which is equal to our product of allele \
frequencies ",
  Cell[BoxData[
      \(TraditionalForm\`pq\_M\)]],
  ".  Last, ",
  Cell[BoxData[
      \(TraditionalForm\`\(\(\(R\_M\)(\[EmptySet])\)\(\ \)\)\)]],
  "is the chance that at meiosis, a gamete derives all the genes in the set \
",
  StyleBox["M",
    FontSlant->"Italic"],
  " from the maternal genome, which is ",
  Cell[BoxData[
      \(TraditionalForm\`\((1 - r\_M)\)/2\)]],
  " in our notation.  Under Christiansen's assumptions of autosomal \
inheritance, random mating, equal selection in males and females, and equal \
recombination rates in males and females, our ",
  ButtonBox["Equation ",
    ButtonData:>"QLECase3Autosomes",
    ButtonStyle->"Hyperlink"],
  
  CounterBox["NumberedEquation", "QLECase3Autosomes"],
  ButtonBox[" ",
    ButtonData:>"QLECase3Autosomes",
    ButtonStyle->"Hyperlink"],
  ButtonBox["gives",
    ButtonData:>"TandSDefns",
    ButtonStyle->"Hyperlink"]
}], "Text",
  CellMargins->{{18.1875, 24.375}, {Inherited, Inherited}}],

Cell[TextData[{
  "\n",
  Cell[BoxData[
      FormBox[
        RowBox[{
          SubscriptBox[\(D\&~\), 
            SubscriptBox["\[DoubleStruckCapitalM]", 
              RowBox[{
                StyleBox["f",
                  FontSlant->"Plain"], " ", 
                StyleBox["x",
                  FontSlant->"Italic"]}]]], "   ", "=", "   ", 
          RowBox[{
            SubscriptBox[\(D\&~\), 
              SubscriptBox["\[DoubleStruckCapitalM]", 
                RowBox[{
                  StyleBox["m",
                    FontSlant->"Plain"], " ", 
                  StyleBox["x",
                    FontSlant->"Italic"]}]]], "   ", "=", 
            "  ", \(\(\(\(a\_\(M\_\(x\ y\)\)\) \(pq\_M\)\(\ \ \)\)\/r\_M\)\(.\
\)\)}]}], TraditionalForm]]],
  "\n"
}], "NumberedEquation",
  CellMargins->{{18.1875, 24.375}, {Inherited, Inherited}},
  CellTags->"QLEChristainsenInOurNotation"],

Cell["\<\
Thus the two approaches are consistent. \
\>", "Text",
  CellMargins->{{18.1875, 24.375}, {Inherited, Inherited}}],

Cell[TextData[{
  "\tBurger's (",
  ButtonBox["2000, p. 188",
    ButtonData:>"Burger 2000",
    ButtonStyle->"Hyperlink"],
  ") expression for cumulant associations at QLE in generation ",
  StyleBox["t",
    FontSlant->"Italic"],
  " is"
}], "Text",
  CellMargins->{{18.1875, 24.375}, {Inherited, Inherited}}],

Cell[TextData[{
  "\n",
  Cell[BoxData[
      FormBox[
        RowBox[{
          RowBox[{
            SubscriptBox["c", 
              StyleBox["m",
                FontWeight->"Bold",
                FontSlant->"Plain"]], "(", "t", ")"}], "   ", "=", "   ", 
          RowBox[{
            FractionBox[
              RowBox[{
                SubscriptBox[\(h\&~\), 
                  RowBox[{
                    StyleBox["m",
                      FontWeight->"Bold",
                      FontSlant->"Plain"], ",", " ", "LE"}]], "(", \(C, \ t\),
                 ")"}], 
              SubscriptBox["r", 
                StyleBox["m",
                  FontWeight->"Bold",
                  FontSlant->"Plain"]]], "  ", "+", 
            "  ", \(\(O(s\^2)\)\(\ \)\(.\)\)}]}], TraditionalForm]]],
  "\n"
}], "NumberedEquation",
  CellMargins->{{18.1875, 24.375}, {Inherited, Inherited}},
  CellTags->"QLEBurger"],

Cell[TextData[{
  "Here, ",
  StyleBox["m",
    FontWeight->"Bold"],
  " is a vector containing the number of times that each allele is included \
in the association;  for example, our ",
  Cell[BoxData[
      \(TraditionalForm\`D\_\[DoubleStruckI]\[DoubleStruckK]\[DoubleStruckK]\)\
]],
  " corresponds to Burger's ",
  Cell[BoxData[
      \(TraditionalForm\`c\_{1, \ 0, \ 2}\)]],
  ",",
  StyleBox[" if positions {\[DoubleStruckI], \[DoubleStruckJ], \
\[DoubleStruckK]} are relevant",
    FontColor->RGBColor[1, 0, 0]],
  ".  (Note that Christiansen's (",
  ButtonBox["1999",
    ButtonData:>"Christiansen 1999",
    ButtonStyle->"Hyperlink"],
  ") notation is restricted to two alleles per locus, whereas Burger's (",
  ButtonBox["2000",
    ButtonData:>"Burger 2000",
    ButtonStyle->"Hyperlink"],
  ") and ours allow multiple alleles.)  The term ",
  Cell[BoxData[
      RowBox[{
        SubscriptBox[\(h\&~\), 
          RowBox[{
            StyleBox["m",
              FontWeight->"Bold",
              FontSlant->"Plain"], ",", " ", "LE"}]], \((C, \ t)\)}]]],
  " is a composite measure of epistasis and allele frequencies.  It is equal \
to the change due to selection at linkage equilibrium, which is ",
  Cell[BoxData[
      \(TraditionalForm\`a\_M\ pq\_M\)]],
  " in our notation.  At QLE, cumulants and moments converge, and indeed \
Equations (",
  
  CounterBox["NumberedEquation", "QLEChristainsenInOurNotation"],
  ") and (",
  
  CounterBox["NumberedEquation", "QLEBurger"],
  ") are equal.  Thus Burger's and our approaches are consistent."
}], "Text",
  CellMargins->{{18.1875, 24.375}, {Inherited, Inherited}}],

Cell[TextData[{
  "\tAlthough the QLE results developed in this paper are consistent \
internally and with independent derivations, we have not rigorously shown \
that this quasi-equilibrium is unique or that the population will always \
converge to it when the assumptions are met.  Nagylaki (1993;  see also \
Nagylaki et al. [2000]) showed that autosomal loci in a random mating diploid \
population under weak selection converge to a QLE.  In this paper we have \
relaxed his assumptions to allow for nonrandom mating, other forms of \
inheritance, and other evolutionary forces (migration and mutation).  Since \
the effects migration and mutation are equivalent to forms of \
frequency-dependent selection, Nagylaki's results should also apply when they \
act so long as the effective selection coefficients that they generate are \
small.  The consequences of nonrandom mating and variations in inheritance \
are more difficult to account for.  We expect convergence to our QLE values \
whenever all the ",
  StyleBox["a",
    FontSlant->"Italic"],
  "s are sufficiently small and all eigenvalues of the matrix of transmission \
coefficients ",
  Cell[BoxData[
      \(TraditionalForm\`t\_\(\[DoubleStruckCapitalA] \[LeftArrow] \
\[DoubleStruckCapitalU]\)\)]],
  " are of order 1, but that conjecture remains to be proven."
}], "Text",
  CellMargins->{{18.1875, 24.375}, {Inherited, Inherited}}],

Cell[TextData[{
  " \tThe QLE approximation developed here can be used to study a variety of \
interesting models.  Selection on the genetic system (recombination, selfing, \
mutation rate, for example) can be studied by assuming a modifier allele of \
small effect.  Even if the system as a whole is under strong selection, \
associations involving the modifier will be weak, and can therefore be \
modelled by a set of linear equations (Barton ",
  ButtonBox["1995",
    ButtonData:>"Barton 1995",
    ButtonStyle->"Hyperlink"],
  ").   The ",
  StyleBox["infinitesimal",
    FontColor->RGBColor[1, 0, 0]],
  " model is based on a different kind of approximation, in which the limit \
of a large number of loci, each with infinitessimal effect, is taken.  \
Turelli and Barton (",
  ButtonBox["1994",
    ButtonData:>"Turelli & Barton 1994",
    ButtonStyle->"Hyperlink"],
  ") give a heuristic argument which extends this model to allow for linkage \
and epistasis.  However, as Burger (",
  ButtonBox["2000",
    ButtonData:>"Burger 2000",
    ButtonStyle->"Hyperlink"],
  ", p. 189) points out, this extension remains to be proven rigorously.  "
}], "Text",
  CellMargins->{{18.1875, 24.375}, {Inherited, Inherited}}],

Cell[TextData[{
  "\tThe biggest lacuna in the framework presented here is the lack of a \
model for random genetic drift.  Its effects can be included by accounting \
for the variation in allele frequencies and associations caused by random \
sampling.  The effects of drift on allele frequencies and pairwise \
associations have been well studied (Ewens 1979), but exact results and \
approximations for the joint probability distribution of the higher-order \
associations remain to be worked out.",
  StyleBox[" A basic implementation ofrandomdrift is included in the ",
    FontColor->RGBColor[1, 0, 0]],
  StyleBox["Mathematica",
    FontSlant->"Italic",
    FontColor->RGBColor[1, 0, 0]],
  StyleBox[" packages.",
    FontColor->RGBColor[1, 0, 0]]
}], "Text",
  CellMargins->{{18.1875, 24.375}, {Inherited, Inherited}}],

Cell["\<\
\tFor the future, there is considerable scope for applying the \
methods set out in this paper to bring together analyses of particular \
models, and to explore better ways to approximate general multilocus systems. \
 \
\>", "Text",
  CellMargins->{{18.1875, 24.375}, {Inherited, Inherited}}]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Acknowledgements",
  FontWeight->"Bold"]], "Subtitle",
  CellMargins->{{18.1875, 24.375}, {Inherited, Inherited}}],

Cell["\<\
\tWe thank Oph\[EAcute]lie Ronce and Stuart Thomas for their \
comments on the manuscript.  We are greatful for support from the NSF (grant \
DEB-9973221), BBSRC, Wellcome Trust, and Darwin Trust for funding.\
\>", \
"Text",
  CellMargins->{{18.1875, 24.375}, {Inherited, Inherited}}]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData[StyleBox["References",
  FontWeight->"Bold"]], "Subtitle",
  CellMargins->{{18.1875, 24.375}, {Inherited, Inherited}},
  PageBreakAbove->True,
  CellTags->"References"],

Cell[TextData[{
  "A",
  StyleBox["SMUSSEN",
    FontSize->9],
  ", M. A., and M. E. O",
  StyleBox["RIVE",
    FontSize->9],
  ", 2000 The effects of pollen and seed migration on nuclear-dicytoplasmic \
systems I Nonrandom associations and equilibrium structure with both maternal \
and paternal cytoplasmic inheritance. Genetics ",
  StyleBox["155:",
    FontWeight->"Bold"],
  " 813-831."
}], "Text",
  CellMargins->{{18.1875, 24.375}, {Inherited, Inherited}},
  CellTags->"Asmussen & Orive 2000"],

Cell[TextData[{
  "B",
  StyleBox["AIRD",
    FontSize->9],
  ", S. J. E., 1995 The mixing of genotypes in hybrid zones: a simulation \
study of multilocus clines. Evolution ",
  StyleBox["49:",
    FontWeight->"Bold"],
  " 1038-1045."
}], "Text",
  CellMargins->{{18.1875, 24.375}, {Inherited, Inherited}},
  CellTags->"Baird 1995"],

Cell[TextData[{
  "B",
  StyleBox["ARTON",
    FontSize->9],
  ", N. H., 1983 Multilocus clines. Evolution  ",
  StyleBox["37:",
    FontWeight->"Bold"],
  " 454-471."
}], "Text",
  CellMargins->{{18.1875, 24.375}, {Inherited, Inherited}},
  CellTags->"Barton 1983"],

Cell[TextData[{
  "B",
  StyleBox["ARTON",
    FontSize->9],
  ", N. H., 1986 The effects of linkage and density-dependent regulation on \
gene flow. Heredity  ",
  StyleBox["57:",
    FontWeight->"Bold"],
  " 415-426."
}], "Text",
  CellMargins->{{18.1875, 24.375}, {Inherited, Inherited}},
  CellTags->"Barton 1986"],

Cell[TextData[{
  "B",
  StyleBox["ARTON",
    FontSize->9],
  ", N.H., 1992  On the spread of new gene combinations in the third phase of \
Wright's shifting balance.  ",
  StyleBox["Evolution",
    FontSlant->"Italic"],
  " ",
  StyleBox["46",
    FontWeight->"Bold"],
  ", 551-557."
}], "Text",
  CellMargins->{{18.1875, 24.375}, {Inherited, Inherited}},
  CellTags->"Barton 1992"],

Cell[TextData[{
  StyleBox["B",
    AutoIndent->False],
  StyleBox["ARTON",
    FontSize->9],
  StyleBox[", N. H., 1995\tA general model for the evolution of \
recombination. Genet. Res. ",
    AutoIndent->False],
  StyleBox["65:",
    AutoIndent->False,
    FontWeight->"Bold"],
  StyleBox[" 123-144.",
    AutoIndent->False]
}], "Text",
  CellMargins->{{18.1875, 24.375}, {Inherited, Inherited}},
  CellTags->"Barton 1995"],

Cell[TextData[{
  "B",
  StyleBox["ARTON",
    FontSize->9],
  ", N. H., 2000 Estimating multilocus linkage disequilibria. Heredity ",
  StyleBox["84:",
    FontWeight->"Bold"],
  " 373-389."
}], "Text",
  CellMargins->{{18.1875, 24.375}, {Inherited, Inherited}},
  CellTags->"Barton 2000"],

Cell[TextData[{
  "B",
  StyleBox["ARTON",
    FontSize->9],
  ", N. H., and M. S",
  StyleBox["HPAK",
    FontSize->9],
  ", 2000 The stability of symmetrical solutions to polygenic models.  Theor. \
Pop. Biol. ",
  StyleBox["57:",
    FontWeight->"Bold"],
  " 249-264."
}], "Text",
  CellMargins->{{18.1875, 24.375}, {Inherited, Inherited}},
  CellTags->"Barton & Shpak 2000"],

Cell[TextData[{
  "B",
  StyleBox["ARTON",
    FontSize->9],
  ", N. H., and M. T",
  StyleBox["URELLI",
    FontSize->9],
  ", 1987 Adaptive landscapes, genetic distance, and the evolution of \
quantitative characters. ",
  StyleBox["Genet. Res.",
    AutoIndent->False],
  " ",
  StyleBox["49:",
    FontWeight->"Bold"],
  " 157-174."
}], "Text",
  CellMargins->{{18.1875, 24.375}, {Inherited, Inherited}},
  CellTags->"Barton & Turelli 1987"],

Cell[TextData[{
  "B",
  StyleBox["ARTON",
    FontSize->9],
  ", N. H. and M. T",
  StyleBox["URELLI",
    FontSize->9],
  ", 1991  Natural and sexual selection on many loci.  Genetics ",
  StyleBox["127",
    FontWeight->"Bold"],
  ": 229-255."
}], "Text",
  CellMargins->{{18.1875, 24.375}, {Inherited, Inherited}},
  CellTags->"Barton & Turelli 1991"],

Cell[TextData[{
  StyleBox["B",
    FontColor->RGBColor[1, 0, 0]],
  StyleBox["AAKE",
    FontSize->9,
    FontColor->RGBColor[1, 0, 0]],
  StyleBox[", E., 2001 Mutation and recombination with tight linkage. Journal \
of Mathematical Biology ",
    FontColor->RGBColor[1, 0, 0]],
  StyleBox["42:",
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 0]],
  StyleBox[" 455-488.",
    FontColor->RGBColor[1, 0, 0]]
}], "Text",
  CellMargins->{{18.1875, 24.375}, {Inherited, Inherited}},
  CellTags->"Baake 2001"],

Cell[TextData[{
  "B",
  StyleBox["ULMER",
    FontSize->9],
  ", M. G.,  1980  ",
  StyleBox["The Mathematical Theory of Quantitative Genetics. ",
    FontSlant->"Italic"],
  "Oxford University Press, Oxford."
}], "Text",
  CellMargins->{{18.1875, 24.375}, {Inherited, Inherited}},
  CellTags->"Bulmer 1980"],

Cell[TextData[{
  "B",
  StyleBox["URGER",
    FontSize->9],
  ", R., 1991 Moments, cumulants and polygenic dynamics. J. Math. Biol. ",
  StyleBox["30:",
    FontWeight->"Bold"],
  " 199-213."
}], "Text",
  CellMargins->{{18.1875, 24.375}, {Inherited, Inherited}},
  CellTags->"Burger 1991"],

Cell[TextData[{
  "B",
  StyleBox["URGER",
    FontSize->9],
  ", R., 2000 ",
  StyleBox["The Mathematical Theory of Selection, Recombination and Mutation",
    
    FontSlant->"Italic"],
  ". Wiley, Chichester."
}], "Text",
  CellMargins->{{18.1875, 24.375}, {Inherited, Inherited}},
  CellTags->"Burger 2000"],

Cell[TextData[{
  "C",
  StyleBox["HRISTIANSEN",
    FontSize->9],
  ", F.B., 1987 The deviation from linkage equilibrium with multiple loci \
varying in a stepping-stone cline. ",
  " J. Genet.",
  " ",
  StyleBox["40",
    FontWeight->"Bold"],
  ": 45-67."
}], "Text",
  CellMargins->{{18.1875, 24.375}, {Inherited, Inherited}},
  CellTags->"Christiansen 1987"],

Cell[TextData[{
  "C",
  StyleBox["HRISTIANSEN",
    FontSize->9],
  ", F.B., 1999",
  StyleBox[" Population Genetics of Multiple Loci",
    FontSlant->"Italic"],
  ". Wiley Series in Mathematical and Computational Biology, ed. S. Levin. \
John Wiley & Sons, New York."
}], "Text",
  CellMargins->{{18.1875, 24.375}, {Inherited, Inherited}},
  CellTags->"Christiansen 1999"],

Cell[TextData[{
  "D",
  StyleBox["AWSON",
    FontSize->9],
  ", K. J., 1999  The dynamics of infinitesimally rare alleles, applied to \
the evolution of mutation rates and the expression of deleterious mutations.  \
Theoretical Population Biology ",
  StyleBox["55",
    FontWeight->"Bold"],
  ": 1-22."
}], "Text",
  CellMargins->{{18.1875, 24.375}, {Inherited, Inherited}},
  CellTags->"Dawson 1999"],

Cell[TextData[{
  "D",
  StyleBox["OEBELI",
    FontSize->9],
  ", M., 1996  A quantitative genetic model for sympatric speciation. J. \
Evol. Biol. ",
  StyleBox["9:",
    FontWeight->"Bold"],
  " 893-909."
}], "Text",
  CellMargins->{{18.1875, 24.375}, {Inherited, Inherited}},
  CellTags->"Doebeli 1996"],

Cell[TextData[{
  "E",
  StyleBox["WENS",
    FontSize->9],
  ", W. J., 1979 ",
  StyleBox["Mathematical Population Genetics",
    FontSlant->"Italic"],
  ". Springer Verlag, Berlin."
}], "Text",
  CellMargins->{{18.1875, 24.375}, {Inherited, Inherited}},
  CellTags->"Ewens 1979"],

Cell[TextData[{
  "F",
  StyleBox["ISHER",
    FontSize->9],
  ", R. A.,  1918  The correlation between relatives on the supposition of \
Mendelian inheritance.  Proc. Roy. Soc. Edinburgh 52: 399-433."
}], "Text",
  CellMargins->{{18.1875, 24.375}, {Inherited, Inherited}},
  CellTags->"Fisher 1918"],

Cell[TextData[{
  "F",
  StyleBox["ISHER",
    FontSize->9],
  ", R. A., 1930 ",
  StyleBox["The Genetical Theory of Natural Selection",
    FontSlant->"Italic"],
  ". Oxford University Press, Oxford."
}], "Text",
  CellMargins->{{18.1875, 24.375}, {Inherited, Inherited}},
  CellTags->"Fisher 1958"],

Cell[TextData[{
  "F",
  StyleBox["ISHER",
    FontSize->9],
  ", R. A., 1953 A fuller theory of 'junctions' in inbreeding. Heredity  ",
  StyleBox["8:",
    FontWeight->"Bold"],
  " 187-198."
}], "Text",
  CellMargins->{{18.1875, 24.375}, {Inherited, Inherited}},
  CellTags->"Fisher 1953"],

Cell[TextData[{
  "G",
  StyleBox["ILLESPIE",
    FontSize->9],
  ", J. H., 1981\tMutation modification in a random environment. Evolution ",
  StyleBox["35:",
    FontWeight->"Bold"],
  " 468-476."
}], "Text",
  CellMargins->{{18.1875, 24.375}, {Inherited, Inherited}},
  CellTags->"Gillespie 1981"],

Cell[TextData[{
  "H",
  StyleBox["ALDANE",
    FontSize->9],
  ", J. B. S., 1927 A mathematical theory of natural and artificial selection \
V Selection and mutation. Proc. Camb. Phil. Soc.  ",
  StyleBox["26:",
    FontWeight->"Bold"],
  " 220-230."
}], "Text",
  CellMargins->{{18.1875, 24.375}, {Inherited, Inherited}},
  CellTags->"Haldane 1927"],

Cell[TextData[{
  "H",
  StyleBox["ILL",
    FontSize->9],
  ", W. G., and A. R",
  StyleBox["OBERTSON",
    FontSize->9],
  ", 1966 The effect of linkage on limits to artificial selection. Genet. \
Res. ",
  StyleBox["8:",
    FontWeight->"Bold"],
  " 269-294."
}], "Text",
  CellMargins->{{18.1875, 24.375}, {Inherited, Inherited}},
  CellTags->"Hill & Robertson 1966"],

Cell[TextData[{
  "H",
  StyleBox["UDSON",
    FontSize->9],
  ", R., 1990 Gene genealogies and the coalescent process. Oxford Surveys in \
Evolutionary Biology ",
  StyleBox["7:",
    FontWeight->"Bold"],
  " 1-44."
}], "Text",
  CellMargins->{{18.1875, 24.375}, {Inherited, Inherited}},
  CellTags->"Hudson 1990"],

Cell[TextData[{
  "K",
  StyleBox["IMURA",
    FontSize->9],
  ", M.,  1965  Attainment of quasilinkage equilibrium when gene frequencies \
are changing by natural selection.  Genetics ",
  StyleBox["52",
    FontWeight->"Bold"],
  ": 875-890."
}], "Text",
  CellMargins->{{18.1875, 24.375}, {Inherited, Inherited}},
  CellTags->"Kimura 1965"],

Cell[TextData[{
  "K",
  StyleBox["IRKPATRICK",
    FontSize->9],
  ", M., 1982 Sexual selection and the evolution of female choice. Evolution  \
",
  StyleBox["36:",
    FontWeight->"Bold"],
  " 1-12."
}], "Text",
  CellMargins->{{18.1875, 24.375}, {Inherited, Inherited}},
  CellTags->"Kirkpatrick 1982"],

Cell[TextData[{
  "K",
  StyleBox["IRKPATRICK",
    FontSize->9],
  ", M. and N.H. B",
  StyleBox["ARTON",
    FontSize->9],
  ",  1997 The strength of indirect selection on female mating preferences.  \
Proc. Natl. Acad. Sci. USA ",
  StyleBox["94",
    FontWeight->"Bold"],
  ": 1282-1286."
}], "Text",
  CellMargins->{{18.1875, 24.375}, {Inherited, Inherited}},
  CellTags->"Kirkpatrick & Barton 1997"],

Cell[TextData[{
  "K",
  StyleBox["IRKPATRICK",
    FontSize->9],
  ", M., and M.J. R",
  StyleBox["YAN",
    FontSize->9],
  ",  1991  The evolution of mating preferences and the paradox of the lek.  \
Nature ",
  StyleBox["350",
    FontWeight->"Bold"],
  ": 33-38."
}], "Text",
  CellMargins->{{18.1875, 24.375}, {Inherited, Inherited}},
  CellTags->"Kirkpatrick & Ryan 1991"],

Cell[TextData[{
  "K",
  StyleBox["IRKPATRICK",
    FontSize->9],
  ", M., and M. S",
  StyleBox["ERVEDIO",
    FontSize->9],
  ",  1999  The reinforcement of mating preferences on an island.  Genetics \
",
  StyleBox["151",
    FontWeight->"Bold"],
  ": 865-884."
}], "Text",
  CellMargins->{{18.1875, 24.375}, {Inherited, Inherited}},
  CellTags->"Kirkpatrick & Servedio 1999"],

Cell[TextData[{
  "K",
  StyleBox["ONDRASHOV",
    FontSize->9],
  ", A.S., 1984  On the intensity of selection for reproductive isolation at \
the beginnings of sympatric speciation.  ",
  StyleBox["Genetika",
    FontSlant->"Italic"],
  " ",
  StyleBox["20:",
    FontWeight->"Bold"],
  " 408-415."
}], "Text",
  CellMargins->{{18.1875, 24.375}, {Inherited, Inherited}},
  CellTags->"Kondrashov 1984"],

Cell[TextData[{
  "L",
  StyleBox["ANDE",
    FontSize->9],
  ", R.,  1981.  Models of speciation by sexual selection on polygenic \
traits.  Proc. Natl. Acad. Sci. USA  ",
  StyleBox["78",
    FontWeight->"Bold"],
  ": 3721-3725."
}], "Text",
  CellMargins->{{18.1875, 24.375}, {Inherited, Inherited}},
  CellTags->"Lande 1981"],

Cell[TextData[{
  "N",
  StyleBox["AGYLAKI",
    FontSize->9],
  ", T.,  1976  The evolution of one- and two-locus systems.  Genetics ",
  StyleBox["83",
    FontWeight->"Bold"],
  ": 583-600."
}], "Text",
  CellMargins->{{18.1875, 24.375}, {Inherited, Inherited}},
  CellTags->"Nagylaki 1976"],

Cell[TextData[{
  "N",
  StyleBox["AGYLAKI",
    FontSize->9],
  ", T.,  1993  The evolution of multilocus systems under weak selection.  \
Genetics ",
  StyleBox["134",
    FontWeight->"Bold"],
  ": 627-647."
}], "Text",
  CellMargins->{{18.1875, 24.375}, {Inherited, Inherited}},
  CellTags->"Nagylaki 1993"],

Cell[TextData[{
  "N",
  StyleBox["AGYLAKI",
    FontSize->9],
  ", T., J. H",
  StyleBox["OFFBAUER",
    FontSize->9],
  ", and P. B",
  StyleBox["RUNOVSKY",
    FontSize->9],
  ",   1999  Convergence of multilocus systems under weak epistasis or weak \
selection.  Journal of Mathematical Biology ",
  StyleBox["38",
    FontWeight->"Bold"],
  ": 103-133",
  "."
}], "Text",
  CellMargins->{{18.1875, 24.375}, {Inherited, Inherited}},
  CellTags->"Nagylaki 1993"],

Cell[TextData[{
  "O",
  StyleBox["TTO",
    FontSize->9],
  ", S. P., and Y. M",
  StyleBox["ICHALAKIS",
    FontSize->9],
  ", 1998 The evolution of recombination in changing environments. Trends in \
Ecology and Evolution ",
  StyleBox["13:",
    FontWeight->"Bold"],
  " 145-151."
}], "Text",
  CellMargins->{{18.1875, 24.375}, {Inherited, Inherited}},
  CellTags->"Otto & Michalakis 1998"],

Cell[TextData[{
  "P",
  StyleBox["RICE",
    FontSize->9],
  ", G. R., 1970 Selection and covariance. Nature  ",
  StyleBox["227:",
    FontWeight->"Bold"],
  " 520-521."
}], "Text",
  CellMargins->{{18.1875, 24.375}, {Inherited, Inherited}},
  CellTags->"Price 1970"],

Cell[TextData[{
  "S",
  StyleBox["HAPIRO",
    FontSize->9],
  ", J. L., A. P",
  StyleBox["R\[CapitalUDoubleDot]GEL",
    FontSize->9],
  "-B",
  StyleBox["ENNETT",
    FontSize->9],
  " and M. R",
  StyleBox["ATTRAY",
    FontSize->9],
  ", 1994 A statistical mechanics formulation of the dynamics of genetic \
algorithms. Lecture Notes in Computer Science ",
  StyleBox["865:",
    FontWeight->"Bold"],
  " 17-27."
}], "Text",
  CellMargins->{{18.1875, 24.375}, {Inherited, Inherited}},
  CellTags->"Shapiro et al 1994"],

Cell[TextData[{
  "S",
  StyleBox["HPAK",
    FontSize->9],
  ", M., and A. S. K",
  StyleBox["ONDRASHOV",
    FontSize->9],
  ", 1999 Applicability of the hypergeometric phenotypic model to haploid and \
diploid populations. Evolution ",
  StyleBox["53:",
    FontWeight->"Bold"],
  " 600-604."
}], "Text",
  CellMargins->{{18.1875, 24.375}, {Inherited, Inherited}},
  CellTags->"Shpak & Kondrashov 1999"],

Cell[TextData[{
  "S",
  StyleBox["NIEGOWSKI",
    FontSize->9],
  ", P., P. J. G",
  StyleBox["ERRISH",
    FontSize->9],
  " and T. J",
  StyleBox["OHNSON",
    FontSize->9],
  ", 2000 Evolution of mutation rates: separating causes from consequences. \
BioEssays ",
  StyleBox["22:",
    FontWeight->"Bold"],
  " 1057-1066."
}], "Text",
  CellMargins->{{18.1875, 24.375}, {Inherited, Inherited}},
  CellTags->"Sniegowski et al 2000"],

Cell[TextData[{
  "T",
  StyleBox["URELLI",
    FontSize->9],
  ", M., and N. H. B",
  StyleBox["ARTON",
    FontSize->9],
  ", 1990 Dynamics of polygenic characters under selection. Theor. Pop. Biol. \
",
  StyleBox["38:",
    FontWeight->"Bold"],
  " 1-57."
}], "Text",
  CellMargins->{{18.1875, 24.375}, {Inherited, Inherited}},
  CellTags->"Turelli & Barton 1990"],

Cell[TextData[{
  "T",
  StyleBox["URELLI",
    FontSize->9],
  ", M., and N.H. B",
  StyleBox["ARTON",
    FontSize->9],
  ", 1994 Genetic and statistical analyses of strong selection on polygenic \
traits: what, me normal?  Genetics ",
  StyleBox["138",
    FontWeight->"Bold"],
  ": 913-941."
}], "Text",
  CellMargins->{{18.1875, 24.375}, {Inherited, Inherited}},
  CellTags->"Turelli & Barton 1994"],

Cell[TextData[{
  "W",
  StyleBox["RIGHT",
    FontSize->9],
  ", S., 1931 Evolution in Mendelian populations. Genetics  ",
  StyleBox["16:",
    FontWeight->"Bold"],
  " 97-159."
}], "Text",
  CellMargins->{{18.1875, 24.375}, {Inherited, Inherited}},
  CellTags->"Wright 1931"],

Cell[TextData[{
  "W",
  StyleBox["RIGHT",
    FontSize->9],
  ", S., 1935 Evolution in populations in approximate equilibrium. J. Genet. \
",
  StyleBox["30:",
    FontWeight->"Bold"],
  " 257-266."
}], "Text",
  CellMargins->{{18.1875, 24.375}, {Inherited, Inherited}},
  CellTags->"Wright 1935"],

Cell[TextData[{
  "W",
  StyleBox["OLFRAM",
    FontSize->9],
  ", S., 1996 ",
  StyleBox["The Mathematica Book",
    FontSlant->"Italic"],
  ". Wolfram Media/Cambridge University Press, Cambridge."
}], "Text",
  CellMargins->{{18.1875, 24.375}, {Inherited, Inherited}},
  CellTags->"Wolfram 1996"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Appendices",
  FontWeight->"Bold"]], "Subtitle",
  CellMargins->{{18.1875, 24.375}, {Inherited, Inherited}},
  PageBreakAbove->True,
  CellTags->"Appendices"],

Cell[CellGroupData[{

Cell["Appendix 1:  A 2-locus example", "Section",
  CellMargins->{{17.75, 24}, {Inherited, Inherited}}],

Cell["\<\
\tThe goal of this appendix is to develop a simple example that \
illustrates the notation and calculations involved in selection, \
transmission, and the quasi-linkage equilibrium (QLE) approximation.  We will \
look at the effects of viability selection acting on two diploid autosomal \
loci in a random mating hermaphroditic population.\
\>", "Text",
  CellMargins->{{17.75, 24}, {Inherited, Inherited}}],

Cell[TextData[{
  "\tConsider a simple selection scheme in which allele 1 at locus ",
  StyleBox["i",
    FontSlant->"Italic"],
  " changes relative fitness by ",
  Cell[BoxData[
      \(TraditionalForm\`s\_i\)]],
  ", and allele 1 at locus ",
  StyleBox["j",
    FontSlant->"Italic"],
  " by ",
  Cell[BoxData[
      \(TraditionalForm\`s\_j\)]],
  ".  Interactions between the loci also affect fitness.  More specifically, \
assume that each interaction between an allele 1 at locus ",
  StyleBox["i",
    FontSlant->"Italic"],
  " and an allele 1 at locus ",
  StyleBox["j",
    FontSlant->"Italic"],
  " changes relative fitness by ",
  Cell[BoxData[
      FormBox[
        SubscriptBox["e", 
          StyleBox["ij",
            FontSlant->"Italic"]], TraditionalForm]]],
  ".  These assumptions lead to the fitnesses for diploid genotypes shown in \
Table 4."
}], "Text",
  CellMargins->{{17.75, 24}, {Inherited, Inherited}}],

Cell[TextData[{
  "\tBecause mating is random, we can define the selection group as a single \
individual.  Since the population is hermaphrodite, the contexts for the two \
loci only need to give the sex-of-origin for each gene.  For example, ",
  Cell[BoxData[
      FormBox[
        SubscriptBox["i", 
          StyleBox["m",
            FontSlant->"Plain"]], TraditionalForm]]],
  " stands for a gene that was inherited via a sperm.  "
}], "Text",
  CellMargins->{{17.75, 24}, {Inherited, Inherited}}],

Cell[TextData[{
  "\tTo calculate the selection coefficients (the ",
  StyleBox["a",
    FontSlant->"Italic"],
  "s), first write the fitnesses that appear in Table 4 in the form of a \
polynomial in the ",
  StyleBox["X",
    FontSlant->"Italic"],
  "s:"
}], "Text",
  CellMargins->{{17.75, 24}, {Inherited, Inherited}}],

Cell[TextData[{
  "\n",
  Cell[BoxData[
      FormBox[
        RowBox[{
          RowBox[{"W", "(", 
            RowBox[{
              SubscriptBox["X", 
                SubscriptBox["i", 
                  StyleBox["f",
                    FontSlant->"Plain"]]], ",", 
              SubscriptBox["X", 
                SubscriptBox["j", 
                  StyleBox["f",
                    FontSlant->"Plain"]]], ",", " ", 
              SubscriptBox["X", 
                SubscriptBox["i", 
                  StyleBox["m",
                    FontSlant->"Plain"]]], ",", " ", 
              SubscriptBox["X", 
                SubscriptBox["j", 
                  StyleBox["m",
                    FontSlant->"Plain"]]]}], ")"}], "  ", "=", "  ", 
          RowBox[{"1", "  ", "+", "  ", 
            RowBox[{\(s\_i\), "(", 
              RowBox[{
                SubscriptBox["X", 
                  SubscriptBox["i", 
                    StyleBox["f",
                      FontSlant->"Plain"]]], " ", "+", " ", 
                SubscriptBox["X", 
                  SubscriptBox["i", 
                    StyleBox["m",
                      FontSlant->"Plain"]]]}], ")"}], "  ", "+", "  ", 
            RowBox[{\(s\_j\), "(", 
              RowBox[{
                SubscriptBox["X", 
                  SubscriptBox["j", 
                    StyleBox["f",
                      FontSlant->"Plain"]]], " ", "+", " ", 
                SubscriptBox["X", 
                  SubscriptBox["j", 
                    StyleBox["m",
                      FontSlant->"Plain"]]]}], ")"}], "  ", "+", " ", 
            "\[IndentingNewLine]", "\[IndentingNewLine]", 
            "\[IndentingNewLine]", " ", 
            RowBox[{
              RowBox[{
                SubscriptBox["e", 
                  StyleBox["ij",
                    FontSlant->"Italic"]], "(", 
                RowBox[{
                  RowBox[{
                    SubscriptBox["X", 
                      SubscriptBox["i", 
                        StyleBox["f",
                          FontSlant->"Plain"]]], 
                    SubscriptBox["X", 
                      SubscriptBox["j", 
                        StyleBox["f",
                          FontSlant->"Plain"]]]}], " ", "+", " ", 
                  RowBox[{
                    SubscriptBox["X", 
                      SubscriptBox["i", 
                        StyleBox["f",
                          FontSlant->"Plain"]]], 
                    SubscriptBox["X", 
                      SubscriptBox["i", 
                        StyleBox["m",
                          FontSlant->"Plain"]]]}], " ", "+", " ", 
                  RowBox[{
                    SubscriptBox["X", 
                      SubscriptBox["i", 
                        StyleBox["m",
                          FontSlant->"Plain"]]], 
                    SubscriptBox["X", 
                      SubscriptBox["j", 
                        StyleBox["f",
                          FontSlant->"Plain"]]]}], " ", "+", " ", 
                  RowBox[{
                    SubscriptBox["X", 
                      SubscriptBox["i", 
                        StyleBox["m",
                          FontSlant->"Plain"]]], 
                    SubscriptBox["X", 
                      SubscriptBox["j", 
                        StyleBox["m",
                          FontSlant->"Plain"]]]}]}], ")"}], "  ", "."}]}]}], 
        TraditionalForm]]],
  "\n"
}], "NumberedEquation",
  CellMargins->{{18.1875, 24.375}, {Inherited, Inherited}},
  CellTags->"FitnessPolynomialFor2Loci"],

Cell[TextData[{
  "Next, write out the fitness function that defines the selection \
coefficients, Equation ",
  
  CounterBox["NumberedEquation", "fitnessDefinition"],
  ":"
}], "Text",
  CellMargins->{{17.75, 24}, {Inherited, Inherited}}],

Cell[TextData[{
  "\n",
  Cell[BoxData[
      FormBox[
        RowBox[{
          RowBox[{"W", "(", 
            RowBox[{
              SubscriptBox["X", 
                SubscriptBox["i", 
                  StyleBox["f",
                    FontSlant->"Plain"]]], ",", 
              SubscriptBox["X", 
                SubscriptBox["j", 
                  StyleBox["f",
                    FontSlant->"Plain"]]], ",", " ", 
              SubscriptBox["X", 
                SubscriptBox["i", 
                  StyleBox["m",
                    FontSlant->"Plain"]]], ",", " ", 
              SubscriptBox["X", 
                SubscriptBox["j", 
                  StyleBox["m",
                    FontSlant->"Plain"]]]}], ")"}], "   ", "=", "   ", 
          RowBox[{\(W\&_\), 
            RowBox[{
              RowBox[{"{", 
                RowBox[{"1", "  ", "+", "  ", 
                  RowBox[{
                    SubscriptBox["a", 
                      SubscriptBox["i", 
                        StyleBox["f",
                          FontSlant->"Plain"]]], " ", "[", 
                    RowBox[{
                      RowBox[{"(", 
                        RowBox[{
                          SubscriptBox["X", 
                            SubscriptBox["i", 
                              StyleBox["f",
                                FontSlant->"Plain"]]], " ", "-", 
                          " ", \(p\_i\)}], ")"}], " ", "-", " ", 
                      SubscriptBox["D", 
                        SubscriptBox["i", 
                          StyleBox["f",
                            FontSlant->"Plain"]]]}], "]"}], "  ", "+", "   ", 
                  
                  RowBox[{
                    SubscriptBox["a", 
                      SubscriptBox["i", 
                        StyleBox["m",
                          FontSlant->"Plain"]]], " ", "[", 
                    RowBox[{
                      RowBox[{"(", 
                        RowBox[{
                          SubscriptBox["X", 
                            SubscriptBox["i", 
                              StyleBox["m",
                                FontSlant->"Plain"]]], " ", "-", 
                          " ", \(p\_i\)}], ")"}], " ", "-", " ", 
                      SubscriptBox["D", 
                        SubscriptBox["i", 
                          StyleBox["m",
                            FontSlant->"Plain"]]]}], "]"}], "   ", "+", 
                  "\[IndentingNewLine]", "\[IndentingNewLine]", 
                  "\[IndentingNewLine]", 
                  RowBox[{
                    SubscriptBox["a", 
                      SubscriptBox["j", 
                        StyleBox["f",
                          FontSlant->"Plain"]]], "[", 
                    RowBox[{
                      RowBox[{"(", 
                        RowBox[{
                          SubscriptBox["X", 
                            SubscriptBox["j", 
                              StyleBox["f",
                                FontSlant->"Plain"]]], " ", "-", 
                          " ", \(p\_j\)}], ")"}], " ", "-", " ", 
                      SubscriptBox["D", 
                        SubscriptBox["j", 
                          StyleBox["f",
                            FontSlant->"Plain"]]]}], "]"}], "  ", "+", "  ", 
                  RowBox[{
                    SubscriptBox["a", 
                      SubscriptBox["j", 
                        StyleBox["m",
                          FontSlant->"Plain"]]], " ", "[", 
                    RowBox[{
                      RowBox[{"(", 
                        RowBox[{
                          SubscriptBox["X", 
                            SubscriptBox["j", 
                              StyleBox["f",
                                FontSlant->"Plain"]]], " ", "-", 
                          " ", \(p\_j\)}], ")"}], " ", "-", " ", 
                      SubscriptBox["D", 
                        SubscriptBox["j", 
                          StyleBox["m",
                            FontSlant->"Plain"]]]}], "]"}], "  ", "+", "  ", 
                  "\[IndentingNewLine]", "\[IndentingNewLine]", 
                  "\[IndentingNewLine]", 
                  RowBox[{
                    SubscriptBox["a", 
                      RowBox[{
                        SubscriptBox["i", 
                          StyleBox["f",
                            FontSlant->"Plain"]], 
                        SubscriptBox["j", 
                          StyleBox["f",
                            FontSlant->"Plain"]]}]], "[", 
                    RowBox[{
                      RowBox[{
                        RowBox[{"(", 
                          RowBox[{
                            SubscriptBox["X", 
                              SubscriptBox["i", 
                                StyleBox["f",
                                  FontSlant->"Plain"]]], "-", " ", \(p\_i\)}],
                           ")"}], 
                        RowBox[{"(", 
                          RowBox[{
                            SubscriptBox["X", 
                              SubscriptBox["j", 
                                StyleBox["f",
                                  FontSlant->"Plain"]]], " ", "-", 
                            " ", \(p\_j\)}], ")"}]}], " ", "-", " ", 
                      SubscriptBox["D", 
                        RowBox[{
                          SubscriptBox["i", 
                            StyleBox["f",
                              FontSlant->"Plain"]], 
                          SubscriptBox["j", 
                            StyleBox["f",
                              FontSlant->"Plain"]]}]]}], "]"}], " ", "+", " ",
                   
                  RowBox[{
                    SubscriptBox["a", 
                      RowBox[{
                        SubscriptBox["i", 
                          StyleBox["f",
                            FontSlant->"Plain"]], 
                        SubscriptBox["j", 
                          StyleBox["m",
                            FontSlant->"Plain"]]}]], "[", 
                    RowBox[{
                      RowBox[{
                        RowBox[{"(", 
                          RowBox[{
                            SubscriptBox["X", 
                              SubscriptBox["i", 
                                StyleBox["f",
                                  FontSlant->"Plain"]]], " ", "-", 
                            " ", \(p\_i\)}], ")"}], 
                        RowBox[{"(", 
                          RowBox[{
                            SubscriptBox["X", 
                              SubscriptBox["j", 
                                StyleBox["m",
                                  FontSlant->"Plain"]]], " ", "-", 
                            " ", \(p\_j\)}], ")"}]}], "  ", "-", " ", 
                      SubscriptBox["D", 
                        RowBox[{
                          SubscriptBox["i", 
                            StyleBox["f",
                              FontSlant->"Plain"]], 
                          SubscriptBox["j", 
                            StyleBox["m",
                              FontSlant->"Plain"]]}]]}], "]"}], " ", "+", 
                  "  ", "\[IndentingNewLine]", "\[IndentingNewLine]", 
                  "\[IndentingNewLine]", 
                  RowBox[{
                    SubscriptBox["a", 
                      RowBox[{
                        SubscriptBox["i", 
                          StyleBox["m",
                            FontSlant->"Plain"]], 
                        SubscriptBox["j", 
                          StyleBox["f",
                            FontSlant->"Plain"]]}]], "[", 
                    RowBox[{
                      RowBox[{
                        RowBox[{"(", 
                          RowBox[{
                            SubscriptBox["X", 
                              SubscriptBox["i", 
                                StyleBox["m",
                                  FontSlant->"Plain"]]], "-", \(p\_i\)}], 
                          ")"}], 
                        RowBox[{"(", 
                          RowBox[{
                            SubscriptBox["X", 
                              SubscriptBox["j", 
                                StyleBox["f",
                                  FontSlant->"Plain"]]], " ", "-", 
                            " ", \(p\_j\)}], ")"}]}], " ", "-", " ", 
                      SubscriptBox["D", 
                        RowBox[{
                          SubscriptBox["i", 
                            StyleBox["m",
                              FontSlant->"Plain"]], 
                          SubscriptBox["j", 
                            StyleBox["f",
                              FontSlant->"Plain"]]}]]}], "]"}], " ", "+", 
                  RowBox[{
                    SubscriptBox["a", 
                      RowBox[{
                        SubscriptBox["i", 
                          StyleBox["m",
                            FontSlant->"Plain"]], 
                        SubscriptBox["j", 
                          StyleBox["m",
                            FontSlant->"Plain"]]}]], "[", 
                    RowBox[{
                      RowBox[{
                        RowBox[{"(", 
                          RowBox[{
                            SubscriptBox["X", 
                              SubscriptBox["i", 
                                StyleBox["m",
                                  FontSlant->"Plain"]]], "-", " ", \(p\_i\)}],
                           ")"}], 
                        RowBox[{"(", 
                          RowBox[{
                            SubscriptBox["X", 
                              SubscriptBox["j", 
                                StyleBox["m",
                                  FontSlant->"Plain"]]], " ", "-", 
                            " ", \(p\_j\)}], ")"}]}], " ", "-", " ", 
                      SubscriptBox["D", 
                        RowBox[{
                          SubscriptBox["i", 
                            StyleBox["m",
                              FontSlant->"Plain"]], 
                          SubscriptBox["j", 
                            StyleBox["m",
                              FontSlant->"Plain"]]}]]}], "]"}], " ", "+", 
                  "\[IndentingNewLine]", "\[IndentingNewLine]", 
                  "\[IndentingNewLine]", 
                  RowBox[{
                    SubscriptBox["a", 
                      RowBox[{
                        SubscriptBox["i", 
                          StyleBox["f",
                            FontSlant->"Plain"]], 
                        SubscriptBox["i", 
                          StyleBox["m",
                            FontSlant->"Plain"]], 
                        SubscriptBox["j", 
                          StyleBox["f",
                            FontSlant->"Plain"]]}]], "[", 
                    RowBox[{
                      RowBox[{
                        RowBox[{"(", 
                          RowBox[{
                            SubscriptBox["X", 
                              SubscriptBox["i", 
                                StyleBox["f",
                                  FontSlant->"Plain"]]], " ", "-", 
                            " ", \(p\_i\)}], ")"}], 
                        RowBox[{"(", 
                          RowBox[{
                            SubscriptBox["X", 
                              SubscriptBox["i", 
                                StyleBox["m",
                                  FontSlant->"Plain"]]], " ", "-", 
                            " ", \(p\_i\)}], ")"}], 
                        RowBox[{"(", 
                          RowBox[{
                            SubscriptBox["X", 
                              SubscriptBox["j", 
                                StyleBox["f",
                                  FontSlant->"Plain"]]], " ", "-", 
                            " ", \(p\_j\)}], ")"}]}], " ", "-", " ", 
                      SubscriptBox["D", 
                        RowBox[{
                          SubscriptBox["i", 
                            StyleBox["f",
                              FontSlant->"Plain"]], 
                          SubscriptBox["i", 
                            StyleBox["m",
                              FontSlant->"Plain"]], 
                          SubscriptBox["j", 
                            StyleBox["f",
                              FontSlant->"Plain"]]}]]}], "]"}], "  ", "+", 
                  "\[IndentingNewLine]", "\[IndentingNewLine]", 
                  "\[IndentingNewLine]", 
                  RowBox[{
                    SubscriptBox["a", 
                      RowBox[{
                        SubscriptBox["i", 
                          StyleBox["f",
                            FontSlant->"Plain"]], 
                        SubscriptBox["i", 
                          StyleBox["m",
                            FontSlant->"Plain"]], 
                        SubscriptBox["j", 
                          StyleBox["m",
                            FontSlant->"Plain"]]}]], "[", 
                    RowBox[{
                      RowBox[{
                        RowBox[{"(", 
                          RowBox[{
                            SubscriptBox["X", 
                              SubscriptBox["i", 
                                StyleBox["f",
                                  FontSlant->"Plain"]]], " ", "-", 
                            " ", \(p\_i\)}], ")"}], 
                        RowBox[{"(", 
                          RowBox[{
                            SubscriptBox["X", 
                              SubscriptBox["i", 
                                StyleBox["m",
                                  FontSlant->"Plain"]]], " ", "-", 
                            " ", \(p\_j\)}], ")"}], 
                        RowBox[{"(", 
                          RowBox[{
                            SubscriptBox["X", 
                              SubscriptBox["j", 
                                StyleBox["m",
                                  FontSlant->"Plain"]]], " ", "-", 
                            " ", \(p\_j\)}], ")"}]}], " ", "-", " ", 
                      SubscriptBox["D", 
                        RowBox[{
                          SubscriptBox["i", 
                            StyleBox["f",
                              FontSlant->"Plain"]], 
                          SubscriptBox["i", 
                            StyleBox["m",
                              FontSlant->"Plain"]], 
                          SubscriptBox["j", 
                            StyleBox["m",
                              FontSlant->"Plain"]]}]]}], "]"}], "  ", "+", 
                  "\[IndentingNewLine]", "\[IndentingNewLine]", 
                  "\[IndentingNewLine]", 
                  RowBox[{
                    SubscriptBox["a", 
                      RowBox[{
                        SubscriptBox["i", 
                          StyleBox["f",
                            FontSlant->"Plain"]], 
                        SubscriptBox["j", 
                          StyleBox["f",
                            FontSlant->"Plain"]], 
                        SubscriptBox["j", 
                          StyleBox["m",
                            FontSlant->"Plain"]]}]], "[", 
                    RowBox[{
                      RowBox[{
                        RowBox[{"(", 
                          RowBox[{
                            SubscriptBox["X", 
                              SubscriptBox["i", 
                                StyleBox["f",
                                  FontSlant->"Plain"]]], " ", "-", 
                            " ", \(p\_i\)}], ")"}], 
                        RowBox[{"(", 
                          RowBox[{
                            SubscriptBox["X", 
                              SubscriptBox["j", 
                                StyleBox["f",
                                  FontSlant->"Plain"]]], " ", "-", 
                            " ", \(p\_j\)}], ")"}], 
                        RowBox[{"(", 
                          RowBox[{
                            SubscriptBox["X", 
                              SubscriptBox["j", 
                                StyleBox["m",
                                  FontSlant->"Plain"]]], " ", "-", 
                            " ", \(p\_j\)}], ")"}]}], " ", "-", " ", 
                      SubscriptBox["D", 
                        RowBox[{
                          SubscriptBox["i", 
                            StyleBox["f",
                              FontSlant->"Plain"]], 
                          SubscriptBox["j", 
                            StyleBox["f",
                              FontSlant->"Plain"]], 
                          SubscriptBox["j", 
                            StyleBox["m",
                              FontSlant->"Plain"]]}]]}], "]"}], "  ", "+", 
                  "\[IndentingNewLine]", "\[IndentingNewLine]", 
                  "\[IndentingNewLine]", 
                  RowBox[{
                    SubscriptBox["a", 
                      RowBox[{
                        SubscriptBox["i", 
                          StyleBox["m",
                            FontSlant->"Plain"]], 
                        SubscriptBox["j", 
                          StyleBox["f",
                            FontSlant->"Plain"]], 
                        SubscriptBox["j", 
                          StyleBox["m",
                            FontSlant->"Plain"]]}]], "[", 
                    RowBox[{
                      RowBox[{
                        RowBox[{"(", 
                          RowBox[{
                            SubscriptBox["X", 
                              SubscriptBox["i", 
                                StyleBox["m",
                                  FontSlant->"Plain"]]], " ", "-", 
                            " ", \(p\_i\)}], ")"}], 
                        RowBox[{"(", 
                          RowBox[{
                            SubscriptBox["X", 
                              SubscriptBox["j", 
                                StyleBox["f",
                                  FontSlant->"Plain"]]], " ", "-", 
                            " ", \(p\_j\)}], ")"}], 
                        RowBox[{"(", 
                          RowBox[{
                            SubscriptBox["X", 
                              SubscriptBox["j", 
                                StyleBox["m",
                                  FontSlant->"Plain"]]], " ", "-", 
                            " ", \(p\_j\)}], ")"}]}], " ", "-", " ", 
                      SubscriptBox["D", 
                        RowBox[{
                          SubscriptBox["i", 
                            StyleBox["m",
                              FontSlant->"Plain"]], 
                          SubscriptBox["j", 
                            StyleBox["f",
                              FontSlant->"Plain"]], 
                          SubscriptBox["j", 
                            StyleBox["m",
                              FontSlant->"Plain"]]}]]}], "]"}], "  ", "+", 
                  "\[IndentingNewLine]", "\[IndentingNewLine]", 
                  "\[IndentingNewLine]", 
                  RowBox[{
                    SubscriptBox["a", 
                      RowBox[{
                        SubscriptBox["i", 
                          StyleBox["f",
                            FontSlant->"Plain"]], 
                        SubscriptBox["j", 
                          StyleBox["m",
                            FontSlant->"Plain"]], 
                        SubscriptBox["j", 
                          StyleBox["f",
                            FontSlant->"Plain"]], 
                        SubscriptBox["j", 
                          StyleBox["m",
                            FontSlant->"Plain"]]}]], "[", 
                    RowBox[{
                      RowBox[{
                        RowBox[{"(", 
                          RowBox[{
                            SubscriptBox["X", 
                              SubscriptBox["i", 
                                StyleBox["f",
                                  FontSlant->"Plain"]]], " ", "-", 
                            " ", \(p\_i\)}], ")"}], 
                        RowBox[{"(", 
                          RowBox[{
                            SubscriptBox["X", 
                              SubscriptBox["i", 
                                StyleBox["m",
                                  FontSlant->"Plain"]]], " ", "-", 
                            " ", \(p\_i\)}], ")"}], 
                        RowBox[{"(", 
                          RowBox[{
                            SubscriptBox["X", 
                              SubscriptBox["j", 
                                StyleBox["f",
                                  FontSlant->"Plain"]]], " ", "-", " ", 
                            SubscriptBox["p", 
                              StyleBox["j",
                                FontSlant->"Italic"]]}], ")"}], 
                        RowBox[{"(", 
                          RowBox[{
                            SubscriptBox["X", 
                              SubscriptBox["j", 
                                StyleBox["m",
                                  FontSlant->"Plain"]]], " ", "-", 
                            " ", \(p\_j\)}], ")"}]}], " ", "-", " ", 
                      SubscriptBox["D", 
                        RowBox[{
                          SubscriptBox["i", 
                            StyleBox["f",
                              FontSlant->"Plain"]], 
                          SubscriptBox["i", 
                            StyleBox["m",
                              FontSlant->"Plain"]], 
                          SubscriptBox["j", 
                            StyleBox["f",
                              FontSlant->"Plain"]], 
                          SubscriptBox["j", 
                            StyleBox["m",
                              FontSlant->"Plain"]]}]]}], "]"}]}], "  ", "}"}],
               "  ", "."}]}]}], TraditionalForm]]],
  "\n"
}], "NumberedEquation",
  CellMargins->{{18.1875, 24.375}, {Inherited, Inherited}},
  CellTags->"FitnessDefnFor2Loci"],

Cell[TextData[{
  "There are fifteen selection coefficients, as required with four positions \
with two alleles each ",
  Cell[BoxData[
      \(TraditionalForm\`\((15\ \  = \ \ 2\^4\  - \ 1)\)\)]],
  ".  Equating Equations (",
  
  CounterBox["NumberedEquation", "FitnessPolynomialFor2Loci"],
  ") and (",
  
  CounterBox["NumberedEquation", "FitnessDefnFor2Loci"],
  "), and identifying coefficients with the same combinations of ",
  StyleBox["X",
    FontSlant->"Italic"],
  "s, gives the selection coefficients:"
}], "Text",
  CellMargins->{{17.75, 24}, {Inherited, Inherited}}],

Cell[TextData[{
  "\n",
  Cell[BoxData[{
      FormBox[
        RowBox[{
          RowBox[{
            SubscriptBox["a", 
              SubscriptBox["i", 
                StyleBox["f",
                  FontSlant->"Plain"]]], "  ", "=", "  ", 
            RowBox[{
              SubscriptBox["a", 
                SubscriptBox["i", 
                  StyleBox["m",
                    FontSlant->"Plain"]]], "  ", "=", 
              "  ", \(s\_i\/W\&_\)}]}], "    ", "\[IndentingNewLine]"}], 
        TraditionalForm], "\[IndentingNewLine]", 
      FormBox[
        RowBox[{" ", 
          RowBox[{
            RowBox[{
              SubscriptBox["a", 
                SubscriptBox["j", 
                  StyleBox["f",
                    FontSlant->"Plain"]]], "  ", "=", "  ", 
              RowBox[{
                SubscriptBox["a", 
                  SubscriptBox["j", 
                    StyleBox["m",
                      FontSlant->"Plain"]]], "  ", "=", 
                "  ", \(s\_j\/W\&_\)}]}], " ", ",", " ", 
            "\[IndentingNewLine]", "\[IndentingNewLine]", 
            RowBox[{
              SubscriptBox["a", 
                RowBox[{
                  SubscriptBox["i", 
                    StyleBox["f",
                      FontSlant->"Plain"]], 
                  SubscriptBox["j", 
                    StyleBox["f",
                      FontSlant->"Plain"]]}]], "  ", "=", "  ", 
              RowBox[{
                SubscriptBox["a", 
                  RowBox[{
                    SubscriptBox["i", 
                      StyleBox["m",
                        FontSlant->"Plain"]], 
                    SubscriptBox["j", 
                      StyleBox["m",
                        FontSlant->"Plain"]]}]], "  ", "=", "  ", 
                RowBox[{
                  SubscriptBox["a", 
                    RowBox[{
                      SubscriptBox["i", 
                        StyleBox["f",
                          FontSlant->"Plain"]], 
                      SubscriptBox["j", 
                        StyleBox["m",
                          FontSlant->"Plain"]]}]], "  ", "=", "  ", 
                  RowBox[{
                    SubscriptBox["a", 
                      RowBox[{
                        SubscriptBox["i", 
                          StyleBox["m",
                            FontSlant->"Plain"]], 
                        SubscriptBox["j", 
                          StyleBox["f",
                            FontSlant->"Plain"]]}]], "  ", "=", "   ", 
                    RowBox[{
                      FractionBox[
                        SubscriptBox["e", 
                          StyleBox["ij",
                            FontSlant->"Italic"]], \(W\&_\)], "  ", 
                      "."}]}]}]}]}]}]}], TraditionalForm]}]],
  "\n"
}], "NumberedEquation",
  CellMargins->{{18.1875, 24.375}, {Inherited, Inherited}},
  CellTags->"SelectionCoefs2Loci"],

Cell[TextData[{
  "The other eight selection coefficients that appear in (",
  
  CounterBox["NumberedEquation", "FitnessDefnFor2Loci"],
  ") are 0.  "
}], "Text",
  CellMargins->{{17.75, 24}, {Inherited, Inherited}}],

Cell[TextData[{
  "\tThe change in the frequency of allele 1 at locus ",
  StyleBox["i",
    FontSlant->"Italic"],
  " is calculated using Equation ",
  
  CounterBox["NumberedEquation", "ExactDeltaP"],
  ".  Because the population is haploid, allele frequencies and associations \
in genes inherited via sperm will be equal to those inherited via eggs: ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          SubscriptBox["p", 
            SubscriptBox["i", 
              StyleBox["f",
                FontSlant->"Plain"]]], "  ", "=", "  ", 
          SubscriptBox["p", 
            SubscriptBox["i", 
              StyleBox["m",
                FontSlant->"Plain"]]]}], TraditionalForm]]],
  " \[Congruent]  ",
  Cell[BoxData[
      \(TraditionalForm\`p\_i\)]],
  ", and ",
  Cell[BoxData[
      FormBox[
        SubscriptBox["D", 
          RowBox[{
            SubscriptBox["i", 
              StyleBox["f",
                FontSlant->"Plain"]], 
            SubscriptBox["j", 
              StyleBox["f",
                FontSlant->"Plain"]]}]], TraditionalForm]]],
  "  =  ",
  Cell[BoxData[
      FormBox[
        SubscriptBox["D", 
          RowBox[{
            SubscriptBox["i", 
              StyleBox["m",
                FontSlant->"Plain"]], 
            SubscriptBox["j", 
              StyleBox["m",
                FontSlant->"Plain"]]}]], TraditionalForm]]],
  "  \[Congruent]  ",
  Cell[BoxData[
      FormBox[
        SubscriptBox["D", 
          StyleBox["ij",
            FontSlant->"Italic"]], TraditionalForm]]],
  ".  After one generation of random mating, associations involving more than \
one sex-of-origin (e.g. ",
  Cell[BoxData[
      FormBox[
        SubscriptBox["D", 
          RowBox[{
            SubscriptBox["i", 
              StyleBox["f",
                FontSlant->"Plain"]], 
            SubscriptBox["j", 
              StyleBox["m",
                FontSlant->"Plain"]]}]], TraditionalForm]]],
  ") are zero.  The exact change in allele frequency will then be"
}], "Text",
  CellMargins->{{17.75, 24}, {Inherited, Inherited}}],

Cell[TextData[{
  "\n",
  Cell[BoxData[
      FormBox[
        RowBox[{
          SubscriptBox[
            StyleBox[
              RowBox[{"\[CapitalDelta]", 
                StyleBox["p",
                  FontSlant->"Italic"]}]], "i"], "  ", "=", "  ", 
          RowBox[{
            SubscriptBox[
              StyleBox[
                RowBox[{"\[CapitalDelta]", 
                  StyleBox["p",
                    FontSlant->"Italic"]}]], 
              SubscriptBox["i", 
                StyleBox["f",
                  FontSlant->"Plain"]]], "  ", "\[IndentingNewLine]", 
            "\[IndentingNewLine]", "\[IndentingNewLine]", 
            "\[IndentingNewLine]", "=", "   ", 
            RowBox[{
              RowBox[{
                RowBox[{
                  SubscriptBox["t", 
                    RowBox[{
                      SubscriptBox["i", 
                        StyleBox["f",
                          FontSlant->"Plain"]], "\[LeftArrow]", " ", 
                      SubscriptBox["i", 
                        StyleBox["f",
                          FontSlant->"Plain"]]}]], " ", 
                  RowBox[{"{", 
                    RowBox[{
                      RowBox[{
                        SubscriptBox["a", 
                          SubscriptBox["i", 
                            StyleBox["f",
                              FontSlant->"Plain"]]], 
                        SubscriptBox[
                          StyleBox["pq",
                            FontSlant->"Italic"], 
                          SubscriptBox["i", 
                            StyleBox["f",
                              FontSlant->"Plain"]]]}], "   ", "+", "  ", 
                      RowBox[{
                        SubscriptBox["a", 
                          SubscriptBox["j", 
                            StyleBox["f",
                              FontSlant->"Plain"]]], 
                        SubscriptBox["D", 
                          RowBox[{
                            SubscriptBox["i", 
                              StyleBox["f",
                                FontSlant->"Plain"]], 
                            SubscriptBox["j", 
                              StyleBox["f",
                                FontSlant->"Plain"]]}]]}], "  ", "+", "  ", 
                      RowBox[{
                        SubscriptBox["a", 
                          RowBox[{
                            SubscriptBox["i", 
                              StyleBox["f",
                                FontSlant->"Plain"]], 
                            SubscriptBox["j", 
                              StyleBox["f",
                                FontSlant->"Plain"]]}]], 
                        SubscriptBox["D", 
                          RowBox[{
                            SubscriptBox["i", 
                              StyleBox["f",
                                FontSlant->"Plain"]], 
                            SubscriptBox["i", 
                              StyleBox["f",
                                FontSlant->"Plain"]], 
                            SubscriptBox["j", 
                              StyleBox["f",
                                FontSlant->"Plain"]]}]]}]}], "}"}]}], 
                "\[IndentingNewLine]", "\[IndentingNewLine]", 
                "\[IndentingNewLine]", "+", "  ", 
                RowBox[{
                  SubscriptBox["t", 
                    RowBox[{
                      SubscriptBox["i", 
                        StyleBox["f",
                          FontSlant->"Plain"]], "\[LeftArrow]", " ", 
                      SubscriptBox["i", 
                        StyleBox["m",
                          FontSlant->"Plain"]]}]], " ", 
                  RowBox[{"{", " ", 
                    RowBox[{
                      RowBox[{
                        SubscriptBox["a", 
                          SubscriptBox["i", 
                            StyleBox["m",
                              FontSlant->"Plain"]]], 
                        SubscriptBox[
                          StyleBox["pq",
                            FontSlant->"Italic"], 
                          SubscriptBox["i", 
                            StyleBox["m",
                              FontSlant->"Plain"]]]}], "   ", "+", "  ", 
                      RowBox[{
                        SubscriptBox["a", 
                          SubscriptBox["j", 
                            StyleBox["m",
                              FontSlant->"Plain"]]], 
                        SubscriptBox["D", 
                          RowBox[{
                            SubscriptBox["i", 
                              StyleBox["m",
                                FontSlant->"Plain"]], 
                            SubscriptBox["j", 
                              StyleBox["m",
                                FontSlant->"Plain"]]}]]}], "  ", "+", "  ", 
                      RowBox[{
                        SubscriptBox["a", 
                          RowBox[{
                            SubscriptBox["i", 
                              StyleBox["m",
                                FontSlant->"Plain"]], 
                            SubscriptBox["j", 
                              StyleBox["m",
                                FontSlant->"Plain"]]}]], 
                        SubscriptBox["D", 
                          RowBox[{
                            SubscriptBox["i", 
                              StyleBox["m",
                                FontSlant->"Plain"]], 
                            SubscriptBox["i", 
                              StyleBox["m",
                                FontSlant->"Plain"]], 
                            SubscriptBox["j", 
                              StyleBox["m",
                                FontSlant->"Plain"]]}]]}]}], " ", "}"}]}]}], 
              "\[IndentingNewLine]", "\[IndentingNewLine]", 
              "\[IndentingNewLine]", "\[IndentingNewLine]", "=", "  ", 
              RowBox[{
                RowBox[{
                  RowBox[{\(1\/2\), " ", 
                    RowBox[{"{", 
                      RowBox[{
                        RowBox[{\(s\_i\/W\&_\), 
                          SubscriptBox[
                            StyleBox["pq",
                              FontSlant->"Italic"], "i"]}], "   ", "+", "  ", 
                        
                        RowBox[{\(s\_j\/W\&_\), 
                          SubscriptBox["D", 
                            StyleBox["ij",
                              FontSlant->"Italic"]]}], "  ", "+", "  ", 
                        RowBox[{
                          FractionBox[
                            SubscriptBox["e", 
                              StyleBox["ij",
                                FontSlant->"Italic"]], \(W\&_\)], 
                          SubscriptBox["D", 
                            StyleBox["iij",
                              FontSlant->"Italic"]]}]}], "}"}]}], "  ", "+", 
                  "  ", 
                  RowBox[{\(1\/2\), " ", 
                    RowBox[{"{", " ", 
                      RowBox[{
                        RowBox[{\(s\_i\/W\&_\), 
                          SubscriptBox[
                            StyleBox["pq",
                              FontSlant->"Italic"], 
                            SubscriptBox["i", 
                              StyleBox["m",
                                FontSlant->"Plain"]]]}], "   ", "+", "  ", 
                        RowBox[{\(s\_j\/W\&_\), 
                          SubscriptBox["D", 
                            RowBox[{
                              SubscriptBox["i", 
                                StyleBox["m",
                                  FontSlant->"Plain"]], 
                              SubscriptBox["j", 
                                StyleBox["m",
                                  FontSlant->"Plain"]]}]]}], "  ", "+", "  ", 
                        
                        RowBox[{
                          FractionBox[
                            SubscriptBox["e", 
                              StyleBox["ij",
                                FontSlant->"Italic"]], \(W\&_\)], 
                          SubscriptBox["D", 
                            StyleBox["iij",
                              FontSlant->"Italic"]]}]}], " ", "}"}]}]}], 
                "\[IndentingNewLine]", "\[IndentingNewLine]", 
                "\[IndentingNewLine]", "\[IndentingNewLine]", "=", "  ", 
                RowBox[{
                  RowBox[{\(1\/W\&_\), " ", "[", " ", 
                    RowBox[{
                      RowBox[{\(s\_i\), " ", 
                        SubscriptBox[
                          StyleBox["pq",
                            FontSlant->"Italic"], "i"]}], "   ", "+", "  ", 
                      RowBox[{\(s\_j\), " ", 
                        SubscriptBox["D", 
                          StyleBox["ij",
                            FontSlant->"Italic"]]}], "  ", "+", "  ", 
                      RowBox[{
                        SubscriptBox["e", 
                          StyleBox["ij",
                            FontSlant->"Italic"]], " ", \((1\  - \ 2  p\_i)\),
                         
                        SubscriptBox["D", 
                          StyleBox["ij",
                            FontSlant->"Italic"]]}]}], " ", "]"}], "  ", 
                  "."}]}]}]}]}], TraditionalForm]]],
  "\n"
}], "NumberedEquation",
  CellMargins->{{18.1875, 24.375}, {Inherited, Inherited}},
  CellTags->"deltaPI2LociVersion1"],

Cell[TextData[{
  "\tThat result can be written entirely in terms of the selection \
coefficients and allele frequencies once the population reaches quasi-linkage \
equilibrium (QLE).  At that point, Equation ",
  
  CounterBox["NumberedEquation", "QLECase3Autosomes"],
  " shows that the the association between the loci is"
}], "Text",
  CellMargins->{{17.75, 24}, {Inherited, Inherited}}],

Cell[TextData[{
  "\n",
  Cell[BoxData[
      FormBox[
        RowBox[{
          RowBox[{
            SubscriptBox["D", 
              StyleBox["ij",
                FontSlant->"Italic"]], "  ", "=", "   ", 
            RowBox[{
              RowBox[{
                RowBox[{
                  RowBox[{"(", 
                    FractionBox[
                      StyleBox[\(pq\_ij\),
                        FontSlant->"Italic"], 
                      RowBox[{"2", " ", 
                        SubscriptBox["r", 
                          StyleBox["ij",
                            FontSlant->"Italic"]]}]], ")"}], "[", 
                  RowBox[{
                    RowBox[{
                      SubscriptBox["a", 
                        RowBox[{
                          SubscriptBox["i", 
                            StyleBox["f",
                              FontSlant->"Plain"]], 
                          SubscriptBox["j", 
                            StyleBox["f",
                              FontSlant->"Plain"]]}]], "(", 
                      RowBox[{"1", " ", "+", " ", 
                        SubscriptBox["r", 
                          StyleBox["ij",
                            FontSlant->"Italic"]]}], ")"}], " ", "+", " ", 
                    RowBox[{
                      SubscriptBox["a", 
                        RowBox[{
                          SubscriptBox["i", 
                            StyleBox["m",
                              FontSlant->"Plain"]], 
                          SubscriptBox["j", 
                            StyleBox["m",
                              FontSlant->"Plain"]]}]], "(", 
                      RowBox[{"1", " ", "+", " ", 
                        SubscriptBox["r", 
                          StyleBox["ij",
                            FontSlant->"Italic"]]}], ")"}]}], "]"}], "  ", 
                "+", "  ", \(O(a\^2)\)}], "   ", "=", "  ", 
              RowBox[{
                FractionBox[
                  RowBox[{
                    SubscriptBox["e", 
                      StyleBox["ij",
                        FontSlant->"Italic"]], " ", 
                    StyleBox[\(pq\_ij\),
                      FontSlant->"Italic"]}], 
                  SubscriptBox["r", 
                    StyleBox["ij",
                      FontSlant->"Italic"]]], "   ", "+", 
                "  ", \(O(a\^2)\)}]}]}], " ", ","}], TraditionalForm]]],
  "\n"
}], "NumberedEquation",
  CellMargins->{{18.1875, 24.375}, {Inherited, Inherited}},
  CellTags->"Dij2LociQLE"],

Cell[TextData[{
  "where by ",
  Cell[BoxData[
      \(TraditionalForm\`O(a\^2)\)]],
  " we mean terms that are no larger than a constant of order 1 times the \
largest of the ",
  StyleBox["a",
    FontSlant->"Italic"],
  "s given above in Equation ",
  
  CounterBox["NumberedEquation", "SelectionCoefs2Loci"],
  ".  At QLE, the mean fitness is to ",
  StyleBox["O",
    FontSlant->"Italic"],
  "(",
  StyleBox["a",
    FontSlant->"Italic"],
  ") equal to the mean fitness of a population with no associations (at \
linkage equilibrium):"
}], "Text",
  CellMargins->{{17.75, 24}, {Inherited, Inherited}}],

Cell[TextData[{
  "\n",
  Cell[BoxData[
      FormBox[
        RowBox[{\(W\&_\), "   ", "=", "   ", 
          RowBox[{
          "1", "  ", "+", "  ", \(2  s\_i\ p\_i\), "  ", "+", 
            "  ", \(2  s\_j\ p\_j\), "  ", "+", "  ", 
            RowBox[{"4", 
              SubscriptBox["e", 
                StyleBox["ij",
                  FontSlant->"Italic"]], " ", \(p\_i\), " ", \(p\_j\)}], "  ",
             "+", "  ", \(\(O(a\^2)\)\(\ \)\(.\)\)}]}], TraditionalForm]]],
  "\n"
}], "NumberedEquation",
  CellMargins->{{18.1875, 24.375}, {Inherited, Inherited}},
  CellTags->"WBar2LociQLE"],

Cell[TextData[{
  "Putting together these last three results shows that the change in \
frequency of allele 1 at locus ",
  StyleBox["i",
    FontSlant->"Italic"],
  " in a population at QLE is:"
}], "Text",
  CellMargins->{{17.75, 24}, {Inherited, Inherited}}],

Cell[TextData[{
  "\n",
  Cell[BoxData[
      FormBox[
        RowBox[{
          SubscriptBox[
            StyleBox[
              RowBox[{"\[CapitalDelta]", 
                StyleBox["p",
                  FontSlant->"Italic"]}]], "i"], "  ", "=", "   ", 
          RowBox[{
            RowBox[{
              RowBox[{\(1\/W\&_\), " ", "[", " ", 
                RowBox[{
                  RowBox[{\(s\_i\), " ", 
                    SubscriptBox[
                      StyleBox["pq",
                        FontSlant->"Italic"], "i"]}], "   ", "+", "  ", 
                  RowBox[{\(s\_j\), " ", 
                    FractionBox[
                      RowBox[{
                        SubscriptBox["e", 
                          StyleBox["ij",
                            FontSlant->"Italic"]], " ", 
                        StyleBox[\(pq\_ij\),
                          FontSlant->"Italic"]}], 
                      SubscriptBox["r", 
                        StyleBox["ij",
                          FontSlant->"Italic"]]]}], "  ", "+", "  ", 
                  RowBox[{\((1\  - \ 2  p\_i)\), " ", 
                    FractionBox[
                      RowBox[{
                        SubsuperscriptBox["e", 
                          StyleBox["ij",
                            FontSlant->"Italic"], "2"], 
                        StyleBox[\(pq\_ij\),
                          FontSlant->"Italic"]}], 
                      SubscriptBox["r", 
                        StyleBox["ij",
                          FontSlant->"Italic"]]]}]}], " ", "]"}], "  ", "+", 
              "  ", \(O(a\^3)\)}], "\[IndentingNewLine]", 
            "\[IndentingNewLine]", "\[IndentingNewLine]", 
            "\[IndentingNewLine]", "=", "   ", 
            RowBox[{
              RowBox[{\(s\_i\), " ", 
                SubscriptBox[
                  StyleBox["pq",
                    FontSlant->"Italic"], "i"], " ", 
                RowBox[{"(", 
                  RowBox[{
                  "1", "  ", "-", "  ", \(2  s\_i\ p\_i\), "  ", "-", 
                    "  ", \(2  s\_j\ p\_j\), "  ", "-", "  ", 
                    RowBox[{"4", 
                      SubscriptBox["e", 
                        StyleBox["ij",
                          FontSlant->"Italic"]], " ", \(p\_i\), 
                      " ", \(p\_j\)}]}], " ", ")"}]}], "  ", "+", "  ", 
              "\[IndentingNewLine]", "\[IndentingNewLine]", 
              "\[IndentingNewLine]", 
              RowBox[{
                FractionBox[
                  RowBox[{
                    SubscriptBox["e", 
                      StyleBox["ij",
                        FontSlant->"Italic"]], " ", 
                    StyleBox[\(pq\_ij\),
                      FontSlant->"Italic"]}], 
                  SubscriptBox["r", 
                    StyleBox["ij",
                      FontSlant->"Italic"]]], "[", 
                RowBox[{\(s\_j\), "  ", "+", "  ", 
                  RowBox[{\((1\  - \ 2  p\_i)\), " ", 
                    SubscriptBox["e", 
                      StyleBox["ij",
                        FontSlant->"Italic"]]}]}], "]"}], "  ", "+", 
              "  ", \(\(O(a\^3)\)\(\ \ \)\(.\)\)}]}]}], TraditionalForm]]],
  "\n"
}], "NumberedEquation",
  CellMargins->{{18.1875, 24.375}, {Inherited, Inherited}},
  CellTags->"deltaPI2LociVersion2"]
}, Closed]],

Cell[CellGroupData[{

Cell["Appendix 2:  Mutation", "Section",
  CellMargins->{{18.1875, 24.375}, {Inherited, Inherited}},
  CellTags->"Appendix: Mutation"],

Cell["\<\
 \tThe centered associations following mutation can be written \
as:\
\>", "Text",
  CellMargins->{{18.1875, 24.375}, {Inherited, Inherited}}],

Cell[TextData[{
  "\n",
  Cell[BoxData[
      \(TraditionalForm\`\(\(\[IndentingNewLine]\)\(\(D\_\
\[DoubleStruckCapitalA]\%\(\(\ \)\(\('\)\(\ \)\('\)\)\) = 
        E\_\(X, M\)[\ \[Product]\_\(\[DoubleStruckI] \[Element] \
\[DoubleStruckCapitalA]\)\((\((X\_\[DoubleStruckI] + \ \[Delta]X\_\
\[DoubleStruckI])\)\  - \ \((p\_\[DoubleStruckI]\  + \ \(\[CapitalDelta]\_\
\[Mu]\) p\_\[DoubleStruckI])\))\)\ ]\)\(\ \ \
\)\(,\)\(\[IndentingNewLine]\)\)\)\)]],
  "\n"
}], "NumberedEquation",
  CellMargins->{{18.1875, 24.375}, {Inherited, Inherited}},
  CellTags->"DANextByMutationExactlyDefnVersion1"],

Cell[TextData[{
  "where ",
  Cell[BoxData[
      \(TraditionalForm\`\[Delta]X\_\[DoubleStruckI]\)]],
  " is the random change to allelic state at position \[DoubleStruckI] caused \
by mutation.  The expectation ",
  Cell[BoxData[
      \(TraditionalForm\`E\_\(X, M\)[]\)]],
  " is over random mutational events, ",
  StyleBox["M",
    FontSlant->"Italic"],
  ", as well as over allelic states, ",
  StyleBox["X",
    FontWeight->"Bold",
    FontSlant->"Italic"],
  ".    ",
  Cell[BoxData[
      \(TraditionalForm\`\(\[CapitalDelta]\_\[Mu]\) p\_\[DoubleStruckI]\)]],
  " is the change in the frequency of allele 1 at position \[DoubleStruckI].  \
Denoting the mutation rate at position \[DoubleStruckI] from allele 0 to \
allele 1 as ",
  Cell[BoxData[
      \(TraditionalForm\`u\_\[DoubleStruckI]\)]],
  " and the reverse mutation rate from 1 to 0 as ",
  Cell[BoxData[
      \(TraditionalForm\`v\_\[DoubleStruckI]\)]],
  ", that change is"
}], "Text",
  CellMargins->{{18.1875, 24.375}, {Inherited, Inherited}}],

Cell[TextData[{
  "\n",
  Cell[BoxData[
      \(TraditionalForm\`\(\(\[IndentingNewLine]\)\(\(\[CapitalDelta]\_\[Mu]\)\
 p\_\[DoubleStruckI]\ \ \  = \ \ \ u\_\[DoubleStruckI]\ q\_\[DoubleStruckI]\ \
\  - \ \ v\_\[DoubleStruckI]\ \(\(p\_\[DoubleStruckI]\)\(\ \)\(.\)\(\
\[IndentingNewLine]\)\)\)\)\)]],
  "\n"
}], "NumberedEquation",
  CellMargins->{{18.1875, 24.375}, {Inherited, Inherited}},
  CellTags->"deltaPiByMutation"],

Cell[TextData[{
  ButtonBox["Equation ",
    ButtonData:>"DANextByMutationExactlyDefnVersion1",
    ButtonStyle->"Hyperlink"],
  
  CounterBox["NumberedEquation", "DANextByMutationExactlyDefnVersion1"],
  ButtonBox[" ",
    ButtonData:>"DANextByMutationExactlyDefnVersion1",
    ButtonStyle->"Hyperlink"],
  "can be simplified by defining the random variable ",
  Cell[BoxData[
      \(TraditionalForm\`R[x]\)]],
  " as having value 1 with probability ",
  StyleBox["x",
    FontSlant->"Italic"],
  ", and zero otherwise.  Let ",
  Cell[BoxData[
      \(TraditionalForm\`R\&^[x]\)]],
  " \[Congruent] R[",
  StyleBox["x",
    FontSlant->"Italic"],
  "] \[Dash] ",
  StyleBox["x",
    FontSlant->"Italic"],
  ".  If ",
  Cell[BoxData[
      \(TraditionalForm\`X\_i = 0\)]],
  " then ",
  Cell[BoxData[
      \(TraditionalForm\`\[Delta]X\_i = \(+R[u\_i]\)\)]],
  ", and if ",
  Cell[BoxData[
      \(TraditionalForm\`X\_i = \(1\ then\ \[Delta]X\_i = \(-R[v\_i]\)\)\)]],
  ".  Hence, ",
  Cell[BoxData[
      \(TraditionalForm\`\[Delta]X\_i = \((1 - X\_i)\) R[u\_i] - \(X\_i\) 
            R[v\_i]\)]],
  ".  Rewriting this in terms of ",
  Cell[BoxData[
      \(TraditionalForm\`R\&^\)]],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`\[Zeta]\_i = X\_i - p\_i\)]],
  ":"
}], "Text",
  CellMargins->{{18.1875, 24.375}, {Inherited, Inherited}}],

Cell[BoxData[
    \(TraditionalForm\`\(\(\[IndentingNewLine]\)\(\[Delta]X\_i = \((q\_i - \
\[Zeta]\_i)\)\ \((u\_i + \(R\&^\)(
                u\_i))\) - \((p\_i + \[Zeta]\_i)\)\ \(\((v\_i + \(R\&^\)(
                  v\_i))\)\(\ \)\(.\)\(\[IndentingNewLine]\)\)\)\)\)], \
"NumberedEquation",
  CellMargins->{{18.1875, 24.375}, {Inherited, Inherited}},
  CellTags->"delXForMutation"],

Cell[TextData[{
  "Substituting into ",
  ButtonBox["Equation ",
    ButtonData:>"DANextByMutationExactlyDefnVersion1",
    ButtonStyle->"Hyperlink"],
  
  CounterBox["NumberedEquation", "DANextByMutationExactlyDefnVersion1"],
  ":"
}], "Text",
  CellMargins->{{18.1875, 24.375}, {Inherited, Inherited}}],

Cell[TextData[{
  "\n",
  Cell[BoxData[
      \(TraditionalForm\`\(\(\[IndentingNewLine]\)\(D\_\[DoubleStruckCapitalA]\
\%\(\(\ \)\(\('\)\(\ \)\('\)\)\) = \(E\_\(X, M\)[\[Product]\_\(\
\[DoubleStruckI] \[Element] \[DoubleStruckCapitalA]\)\((p\_\[DoubleStruckI] + \
\[Zeta]\_i + \ \((q\_i - \[Zeta]\_i)\)\ \((u\_i + \(R\&^\)(
                          u\_i))\) - \((p\_i + \[Zeta]\_i)\)\ \((v\_i + \
\(R\&^\)(v\_i))\)\  - \ 
                  p\_\[DoubleStruckI]\  - \ \(\[CapitalDelta]\_\[Mu]\) 
                    p\_\[DoubleStruckI])\)\ ]\[IndentingNewLine]\
\[IndentingNewLine]\[IndentingNewLine] = \(\(E\_\(X, M\)[\[Product]\_\(\
\[DoubleStruckI] \[Element] \[DoubleStruckCapitalA]\)\((\ 
                  q\_i\ \(\(R\&^\)(u\_i)\) - 
                    p\_i\ \(\(R\&^\)(v\_i)\)\ \  + \(\[Zeta]\_i\)(
                      1 - u\_i - \(R\&^\)(u\_i) - 
                        v\_i - \(R\&^\)(
                          v\_i))\ )\)\ ]\)\(\ \
\)\(.\)\(\[IndentingNewLine]\)\)\)\)\)\)]],
  "\n"
}], "NumberedEquation",
  CellMargins->{{18.1875, 24.375}, {Inherited, Inherited}},
  CellTags->"DANextByMutationExactlyDefnVersion2"],

Cell[TextData[{
  "Now, the ",
  Cell[BoxData[
      \(TraditionalForm\`R\&^\)]],
  " are independent across loci and are independent of allelic state, and so \
vanish when the expectation over mutational events is taken.  This leads \
immediately to ",
  ButtonBox["Equation ",
    ButtonData:>"DAAfterMutation",
    ButtonStyle->"Hyperlink"],
  
  CounterBox["NumberedEquation", "DAAfterMutation"],
  ButtonBox[".",
    ButtonData:>"DAAfterMutation",
    ButtonStyle->"Hyperlink"]
}], "Text",
  CellMargins->{{18.1875, 24.375}, {Inherited, Inherited}}]
}, Open  ]],

Cell[CellGroupData[{

Cell["Appendix 3:  Migration", "Section",
  CellMargins->{{18.1875, 24.375}, {Inherited, Inherited}},
  CellTags->"Appendix: Migration"],

Cell[TextData[{
  "\tIn this appendix we calculate the centered associations following a \
migration event.  The result is most easy to interpret when it is expressed \
in terms of the centered association among the residents and migrants before \
the event.  We therefore define the reference values in the resident \
population, ",
  Cell[BoxData[
      FormBox[
        SubsuperscriptBox["\[WeierstrassP]", "\[DoubleStruckI]", 
          RowBox[{" ", 
            StyleBox["R",
              FontSlant->"Plain"]}]], TraditionalForm]]],
  ", to equal the allele frequencies in that population before migration, ",
  Cell[BoxData[
      FormBox[
        SubsuperscriptBox["p", "\[DoubleStruckI]", 
          RowBox[{" ", 
            StyleBox["R",
              FontSlant->"Plain"]}]], TraditionalForm]]],
  "."
}], "Text",
  CellMargins->{{18.1875, 24.375}, {Inherited, Inherited}}],

Cell[TextData[{
  "\tJust after migration, the (uncentered) associations are given by ",
  ButtonBox["Equation ",
    ButtonData:>"DDefn",
    ButtonStyle->"Hyperlink"],
  
  CounterBox["NumberedEquation", "DDefn"],
  ButtonBox[":",
    ButtonData:>"DDefn",
    ButtonStyle->"Hyperlink"]
}], "Text",
  CellMargins->{{18.1875, 24.375}, {Inherited, Inherited}}],

Cell[TextData[{
  "\n",
  Cell[BoxData[
      FormBox[
        RowBox[{"\[IndentingNewLine]", 
          RowBox[{
            RowBox[{\(D\_\[DoubleStruckCapitalA]\%\(\(\ \)\('\)\)\), "=", 
              RowBox[{\(E\_X\), "[", " ", 
                
                RowBox[{\(\[Product]\_\(\[DoubleStruckI] \[Element] \
\[DoubleStruckCapitalA]\)\), 
                  RowBox[{"(", 
                    RowBox[{\(X\_\[DoubleStruckI]\%\(\(\ \)\('\)\)\), "-", 
                      SubsuperscriptBox["p", "\[DoubleStruckI]", 
                        RowBox[{" ", 
                          StyleBox["R",
                            FontSlant->"Plain"]}]]}], ")"}]}], " ", "]"}]}], 
            " ", ",", "\[IndentingNewLine]"}]}], TraditionalForm]]],
  "\n"
}], "NumberedEquation",
  CellMargins->{{18.1875, 24.375}, {Inherited, Inherited}},
  CellTags->"DAPrimeDefn"],

Cell[TextData[{
  "where ",
  Cell[BoxData[
      \(TraditionalForm\`X\_\[DoubleStruckI]\%\(\(\ \)\('\)\)\)]],
  " is the allelic state of an individual in the population after migration.  \
That expression can be rewritten in terms of ",
  Cell[BoxData[
      FormBox[
        SubsuperscriptBox["X", "\[DoubleStruckI]", 
          RowBox[{" ", 
            StyleBox["M",
              FontSlant->"Plain"]}]], TraditionalForm]]],
  ", the allelic states of the migrants, and ",
  Cell[BoxData[
      FormBox[
        SubsuperscriptBox["X", "\[DoubleStruckI]", 
          RowBox[{" ", 
            StyleBox["R",
              FontSlant->"Plain"]}]], TraditionalForm]]],
  ", the allelic states of the residents:"
}], "Text",
  CellMargins->{{18.1875, 24.375}, {Inherited, Inherited}}],

Cell[TextData[{
  "\n",
  Cell[BoxData[
      FormBox[
        RowBox[{"\[IndentingNewLine]", 
          RowBox[{
            
            RowBox[{\(D\_\[DoubleStruckCapitalA]\%\(\(\ \)\('\)\)\), "   ", 
              "=", "   ", 
              RowBox[{
                RowBox[{
                  RowBox[{\((1\  - \ m)\), 
                    RowBox[{\(E\_X\), "[", " ", 
                      
                      RowBox[{\(\[Product]\_\(\[DoubleStruckI] \[Element] \
\[DoubleStruckCapitalA]\)\), 
                        RowBox[{"(", 
                          RowBox[{
                            SubsuperscriptBox["X", "\[DoubleStruckI]", 
                              RowBox[{" ", 
                                StyleBox["R",
                                  FontSlant->"Plain"]}]], "-", 
                            SubsuperscriptBox["p", "\[DoubleStruckI]", 
                              RowBox[{" ", 
                                StyleBox["R",
                                  FontSlant->"Plain"]}]]}], ")"}]}], " ", 
                      "]"}]}], " ", "+", " ", 
                  RowBox[{"m", " ", 
                    RowBox[{\(E\_X\), "[", 
                      
                      RowBox[{\(\[Product]\_\(\[DoubleStruckI] \[Element] \
\[DoubleStruckCapitalA]\)\), 
                        RowBox[{"(", 
                          RowBox[{
                            SubsuperscriptBox["X", "\[DoubleStruckI]", 
                              RowBox[{" ", 
                                StyleBox["M",
                                  FontSlant->"Plain"]}]], "-", 
                            SubsuperscriptBox["p", "\[DoubleStruckI]", 
                              RowBox[{" ", 
                                StyleBox["R",
                                  FontSlant->"Plain"]}]]}], ")"}]}], " ", 
                      "]"}]}]}], "   ", "\[IndentingNewLine]", 
                "\[IndentingNewLine]", "\[IndentingNewLine]", "=", "   ", 
                RowBox[{
                  RowBox[{\((1\  - \ m)\), 
                    SubsuperscriptBox["D", "\[DoubleStruckCapitalA]", 
                      RowBox[{" ", 
                        StyleBox["R",
                          FontSlant->"Plain"]}]]}], "  ", "+", 
                  " ", \(m\ D\_\[DoubleStruckCapitalA]\%\(\(\ \
\)\(MR\)\)\)}]}]}], " ", ",", "\[IndentingNewLine]"}]}], TraditionalForm]]],
  "\n"
}], "NumberedEquation",
  CellMargins->{{18.1875, 24.375}, {Inherited, Inherited}},
  CellTags->"DPrimeInTermsOfDMR"],

Cell[TextData[{
  "where ",
  StyleBox["m",
    FontSlant->"Italic"],
  " is the migration rate.  The ",
  Cell[BoxData[
      FormBox[
        SubsuperscriptBox["D", "\[DoubleStruckCapitalA]", 
          RowBox[{" ", 
            StyleBox["R",
              FontSlant->"Plain"]}]], TraditionalForm]]],
  " are the (centered) associations among the residents before migration, \
while ",
  Cell[BoxData[
      \(TraditionalForm\`D\_\[DoubleStruckCapitalA]\%\(\(\ \)\(MR\)\)\)]],
  " are the uncentered ",
  "associations",
  " of the migrants measured relative to the resident reference values, ",
  Cell[BoxData[
      FormBox[
        SubsuperscriptBox["\[WeierstrassP]", "\[DoubleStruckI]", 
          RowBox[{" ", 
            StyleBox["R",
              FontSlant->"Plain"]}]], TraditionalForm]]],
  " = ",
  Cell[BoxData[
      FormBox[
        SubsuperscriptBox["p", "\[DoubleStruckI]", 
          RowBox[{" ", 
            StyleBox["R",
              FontSlant->"Plain"]}]], TraditionalForm]]],
  " ."
}], "Text",
  CellMargins->{{18.1875, 24.375}, {Inherited, Inherited}}],

Cell[TextData[{
  "\tThe next step is to express the ",
  Cell[BoxData[
      \(TraditionalForm\`D\_\[DoubleStruckCapitalA]\%\(\(\ \)\(MR\)\)\)]],
  " in terms of the centered associations in migrant population, ",
  Cell[BoxData[
      FormBox[
        SubsuperscriptBox["D", "\[DoubleStruckCapitalA]", 
          RowBox[{" ", 
            StyleBox["M",
              FontSlant->"Plain"]}]], TraditionalForm]]],
  ".  To do that we need to rescale those associations in terms of the \
reference values for the migrant population, ",
  Cell[BoxData[
      FormBox[
        SubsuperscriptBox["\[WeierstrassP]", "\[DoubleStruckI]", 
          RowBox[{" ", 
            StyleBox["M",
              FontSlant->"Plain"]}]], TraditionalForm]]],
  ".  Using ",
  ButtonBox["Equation ",
    ButtonData:>"ChangeInReferenceValueEquation",
    ButtonStyle->"Hyperlink"],
  
  CounterBox["NumberedEquation", "ChangeInReferenceValueEquation"],
  ButtonBox[" ",
    ButtonData:>"ChangeInReferenceValueEquation",
    ButtonStyle->"Hyperlink"],
  "for changing reference values and some algebra gives"
}], "Text",
  CellMargins->{{18.1875, 24.375}, {Inherited, Inherited}}],

Cell[TextData[{
  "\n",
  Cell[BoxData[
      FormBox[
        RowBox[{"\[IndentingNewLine]", 
          
          RowBox[{\(D\_\[DoubleStruckCapitalA]\%\(\(\ \)\(MR\)\)\), "   ", 
            "=", "   ", 
            
            RowBox[{\(\[Sum]\_\(\[DoubleStruckCapitalU] \[SubsetEqual] \
\[DoubleStruckCapitalA]\)\), 
              RowBox[{\(d\_\[DoubleStruckCapitalU]\), " ", 
                RowBox[{
                  
                  SubsuperscriptBox[
                    "D", \(\[DoubleStruckCapitalA]\\\[DoubleStruckCapitalU]\),
                     
                    RowBox[{" ", 
                      StyleBox["M",
                        FontSlant->"Plain"]}]], " ", ".", 
                  "\[IndentingNewLine]"}]}]}]}]}], TraditionalForm]]],
  "\n"
}], "NumberedEquation",
  CellMargins->{{18.1875, 24.375}, {Inherited, Inherited}},
  CellTags->"DMRFormula"],

Cell[TextData[{
  "where ",
  Cell[BoxData[
      \(TraditionalForm\`d\_\[DoubleStruckCapitalU]\)]],
  " was defined earlier in ",
  ButtonBox["Equation ",
    ButtonData:>"dAProductDefn",
    ButtonStyle->"Hyperlink"],
  
  CounterBox["NumberedEquation", "dAProductDefn"],
  ".  The sum includes the term in which \[DoubleStruckCapitalU] equals the \
empty set \[EmptySet], which generates the term ",
  Cell[BoxData[
      FormBox[
        SubsuperscriptBox["D", "\[DoubleStruckCapitalA]", 
          RowBox[{" ", 
            StyleBox["M",
              FontSlant->"Plain"]}]], TraditionalForm]]],
  ".  Substituting this expression for ",
  Cell[BoxData[
      \(TraditionalForm\`D\_\[DoubleStruckCapitalA]\%\(\(\ \)\(MR\)\)\)]],
  " in ",
  ButtonBox["Equation ",
    ButtonData:>"DPrimeInTermsOfDMR",
    ButtonStyle->"Hyperlink"],
  
  CounterBox["NumberedEquation", "DPrimeInTermsOfDMR"],
  ButtonBox[" ",
    ButtonData:>"DPrimeInTermsOfDMR",
    ButtonStyle->"Hyperlink"],
  "produces"
}], "Text",
  CellMargins->{{18.1875, 24.375}, {Inherited, Inherited}}],

Cell[TextData[{
  "\n",
  Cell[BoxData[
      FormBox[
        RowBox[{"\[IndentingNewLine]", 
          
          RowBox[{\(D\_\[DoubleStruckCapitalA]\%\(\(\ \)\('\)\)\), "   ", "=",
             "   ", 
            RowBox[{
              RowBox[{\((1\  - \ m)\), 
                SubsuperscriptBox["D", "\[DoubleStruckCapitalA]", 
                  RowBox[{" ", 
                    StyleBox["R",
                      FontSlant->"Plain"]}]]}], "  ", "+", " ", 
              RowBox[{"m", " ", 
                
                RowBox[{\(\[Sum]\_\(\[DoubleStruckCapitalU] \[SubsetEqual] \
\[DoubleStruckCapitalA]\)\), 
                  RowBox[{\(d\_\[DoubleStruckCapitalU]\), " ", 
                    RowBox[{
                      
                      SubsuperscriptBox[
                        "D", \(\[DoubleStruckCapitalA]\\\
\[DoubleStruckCapitalU]\), 
                        RowBox[{" ", 
                          StyleBox["M",
                            FontSlant->"Plain"]}]], " ", ".", 
                      "\[IndentingNewLine]"}]}]}]}]}]}]}], 
        TraditionalForm]]],
  "\n"
}], "NumberedEquation",
  CellMargins->{{18.1875, 24.375}, {Inherited, Inherited}},
  CellTags->"DAPrimeUncenteredResult"],

Cell[TextData[{
  "These ",
  "associations",
  " ",
  Cell[BoxData[
      \(TraditionalForm\`D\_\[DoubleStruckCapitalA]\%\(\(\ \)\('\)\)\)]],
  " are based on the reference values for the residents before migration, ",
  Cell[BoxData[
      FormBox[
        SubsuperscriptBox["\[WeierstrassP]", "\[DoubleStruckI]", 
          RowBox[{" ", 
            StyleBox["R",
              FontSlant->"Plain"]}]], TraditionalForm]]],
  " = ",
  Cell[BoxData[
      FormBox[
        SubsuperscriptBox["p", "\[DoubleStruckI]", 
          RowBox[{" ", 
            StyleBox["R",
              FontSlant->"Plain"]}]], TraditionalForm]]],
  ".  "
}], "Text",
  CellMargins->{{18.1875, 24.375}, {Inherited, Inherited}}],

Cell[TextData[{
  "\tTo find the central moments after migration, we set the new reference \
points to the allele frequencies after migration:  ",
  Cell[BoxData[
      \(TraditionalForm\`\[WeierstrassP]\_\[DoubleStruckI]\%\(\(\ \)\(\('\)\(\
\ \)\('\)\)\)\)]],
  "  =  ",
  Cell[BoxData[
      FormBox[
        RowBox[{\((1\  - \ m)\), " ", 
          SubsuperscriptBox["p", "\[DoubleStruckI]", 
            RowBox[{" ", 
              StyleBox["R",
                FontSlant->"Plain"]}]]}], TraditionalForm]]],
  " + ",
  StyleBox["m",
    FontSlant->"Italic"],
  " ",
  Cell[BoxData[
      FormBox[
        SubsuperscriptBox["p", "\[DoubleStruckI]", 
          RowBox[{" ", 
            StyleBox["M",
              FontSlant->"Plain"]}]], TraditionalForm]]],
  ".  Using ",
  ButtonBox["Equation ",
    ButtonData:>"ChangeInReferenceValueEquation",
    ButtonStyle->"Hyperlink"],
  
  CounterBox["NumberedEquation", "ChangeInReferenceValueEquation"],
  ButtonBox[" ",
    ButtonData:>"ChangeInReferenceValueEquation",
    ButtonStyle->"Hyperlink"],
  "as before gives  ",
  ButtonBox["Equation ",
    ButtonData:>"DAPrimeCentered",
    ButtonStyle->"Hyperlink"],
  
  CounterBox["NumberedEquation", "DAPrimeCentered"],
  ",",
  ButtonBox[" ",
    ButtonData:>"DAPrimeCentered",
    ButtonStyle->"Hyperlink"],
  "above."
}], "Text",
  CellMargins->{{18.1875, 24.375}, {Inherited, Inherited}}]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  "Appendix 4:  ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " examples"
}], "Section",
  CellMargins->{{18.1875, 24.375}, {Inherited, Inherited}},
  CellTags->"Appendix: Mathematica"],

Cell[TextData[{
  "\tHere, we give some examples which outline how ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " (Wolfram, 1996) can be used to find algebraic expressions for the changes \
in associations due to various evolutionary processes.  Software that extends \
",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " to do the calculations described in this paper is available at \
http://helios.bto.ed.ac.uk/evolgen/index.html.  The notation used by that \
software is essentially the ",
  StyleBox["same",
    FontColor->RGBColor[1, 0, 0]],
  " as in the text, but there are a few differences which need to be \
explained.  "
}], "Text",
  CellMargins->{{18.1875, 24.375}, {Inherited, Inherited}}],

Cell["i)  Stages in the life cycle", "Text",
  CellMargins->{{18.1875, 24.375}, {Inherited, Inherited}},
  FontSlant->"Italic"],

Cell[TextData[{
  "\tDifferent stages in the life cycle are denoted by the first element in \
the context, rather than by primes.  Thus, the association between two \
positions in male gametes would be written ",
  Cell[BoxData[
      \(TraditionalForm\`\[GothicCapitalD]\_{i\_{\[GothicCapitalG], \
\[GothicCapitalM]}, j\_{\[GothicCapitalG], \[GothicCapitalM]}}\)]],
  ", where \[GothicCapitalG] denotes the gamete stage.",
  StyleBox[" (Special Gothic fonts are used to avoid clashes with other \
symbols).  ",
    FontColor->RGBColor[1, 0, 0]],
  "Similarly, the association between two positions in a male diploid zygote, \
one inherited from the mother, and one from the father, would be written ",
  Cell[BoxData[
      \(TraditionalForm\`\[GothicCapitalD]\_{i\_{\[GothicCapitalZ], \
\[GothicCapitalM], \[GothicCapitalM]}, j\_{\[GothicCapitalZ], \
\[GothicCapitalM], \[GothicCapitalF]}}\)]],
  ".  "
}], "Text",
  CellMargins->{{18.1875, 24.375}, {Inherited, Inherited}}],

Cell[TextData[{
  "\tThe first step is to define the contexts for each stage.   For example, \
this defines gamete (\[GothicCapitalG]), zygote (\[GothicCapitalZ]), adult (\
\[GothicCapitalA]), and new gamete (",
  Cell[BoxData[
      \(\(\[GothicCapitalG]\^*\)\)]],
  ") stages:"
}], "Text",
  CellMargins->{{18.1875, 24.375}, {Inherited, Inherited}}],

Cell[TextData[{
  "\n",
  Cell[BoxData[{
      \(\(DefineContext[\[GothicCapitalG], {\ Sex}];\)\), "\n", 
      \(\(DefineContext[\[GothicCapitalZ], {Sex, SexOfOrigin}];\)\), "\n", 
      \(\(DefineContext[\[GothicCapitalA], {Sex, SexOfOrigin}];\)\), "\n", 
      \(\(DefineContext[\(\[GothicCapitalG]\^*\), {\ Sex}];\)\)}]],
  "\n"
}], "InlineFormula",
  CellMargins->{{18.1875, 24.375}, {Inherited, Inherited}},
  FontWeight->"Bold"],

Cell["\<\
Throughout, lines that are input by the user will be shown in bold.\
\
\>", "Text",
  CellMargins->{{18.1875, 24.375}, {Inherited, Inherited}}],

Cell["ii) Recombination", "Text",
  CellMargins->{{18.1875, 24.375}, {Inherited, Inherited}},
  FontSlant->"Italic"],

Cell["\<\
\tExpressions for the mean and for the associations at one stage \
are expressed in terms of variables at the previous stage by applying various \
rules.  For example, the mean contribution of a gene in the new gamete pool \
is:\
\>", "Text",
  CellMargins->{{18.1875, 24.375}, {Inherited, Inherited}}],

Cell[BoxData[
    \(\(\(\[IndentingNewLine]\)\(\[GothicM]\_\(j\_{\(\[GothicCapitalG]\^*\), \
\[GothicCapitalM]}\) //. Recombination[]\)\)\)], "InlineFormula",
  CellMargins->{{18.1875, 24.375}, {Inherited, Inherited}},
  FontWeight->"Bold"],

Cell[BoxData[
    \(\[GothicM]\_\(j\_{\[GothicCapitalA], \[GothicCapitalM], \
\[GothicCapitalM]}\)\ \[GothicR]\_\({}, {j}\) + \(\(\[GothicM]\_\(j\_{\
\[GothicCapitalA], \[GothicCapitalM], \[GothicCapitalF]}\)\)\(\ \
\)\(\[GothicR]\_\({j}, {}\)\)\(\[IndentingNewLine]\)\)\)], "InlineFormula",
  CellMargins->{{18.1875, 24.375}, {Inherited, Inherited}}],

Cell[TextData[{
  "Here, ",
  StyleBox["//. denotes application of a transformation rule, an",
    FontColor->RGBColor[1, 0, 0]],
  "d t  ",
  Cell[BoxData[
      \(TraditionalForm\`\[GothicR]\_\({}, {j}\)\)]],
  " is a generalised recombination rate, which gives the chance that the gene \
",
  Cell[BoxData[
      \(TraditionalForm\`j\)]],
  " was inherited from the father at meiosis.  Further rules apply the usual \
assumptions of Mendelian inheritance:"
}], "Text",
  CellMargins->{{18.1875, 24.375}, {Inherited, Inherited}}],

Cell[BoxData[
    \(\(\(\[IndentingNewLine]\)\(\[GothicM]\_\(j\_{\(\[GothicCapitalG]\^*\), \
\[GothicCapitalM]}\) //. 
      Recombination[]\[Vee]SymmetricRecombination[]\)\)\)], "InlineFormula",
  CellMargins->{{18.1875, 24.375}, {Inherited, Inherited}},
  FontWeight->"Bold"],

Cell[BoxData[
    \(1\/2\ \[GothicM]\_\(j\_{\[GothicCapitalA], \[GothicCapitalM], \
\[GothicCapitalF]}\) + \(\(1\/2\)\(\ \)\(\[GothicM]\_\(j\_{\[GothicCapitalA], \
\[GothicCapitalM], \[GothicCapitalM]}\)\)\(\[IndentingNewLine]\)\)\)], \
"InlineFormula",
  CellMargins->{{18.1875, 24.375}, {Inherited, Inherited}}],

Cell[TextData[{
  "where ",
  Cell[BoxData[
      \(TraditionalForm\`rule\_1\[Vee]rule\_2\)]],
  " denotes a collection of rules.  When applied to an association, the \
result depends on the change in the reference values, \[WeierstrassP], \
defined for each stage:"
}], "Text",
  CellMargins->{{18.1875, 24.375}, {Inherited, Inherited}}],

Cell[BoxData[
    \(\(\(\[IndentingNewLine]\)\(\[GothicCapitalD]\_{i\_{\(\[GothicCapitalG]\^\
*\), \[GothicCapitalM]}, j\_{\(\[GothicCapitalG]\^*\), \[GothicCapitalM]}} //. 
        Recombination[]\[Vee]SymmetricRecombination[] // 
      Simplify\)\)\)], "InlineFormula",
  CellMargins->{{18.1875, 24.375}, {Inherited, Inherited}},
  FontWeight->"Bold"],

Cell[BoxData[
    \(\[GothicR]\_\({}, {i, j}\)\ \
\((\[GothicCapitalD]\_{i\_{\[GothicCapitalA], \[GothicCapitalM], \
\[GothicCapitalF]}, j\_{\[GothicCapitalA], \[GothicCapitalM], \
\[GothicCapitalF]}} + \[GothicCapitalD]\_{j\_{\[GothicCapitalA], \
\[GothicCapitalM], \[GothicCapitalF]}}\ \((\(-\[WeierstrassP]\_\(i\_{\(\
\[GothicCapitalG]\^*\), \[GothicCapitalM]}\)\) + \[WeierstrassP]\_\(i\_{\
\[GothicCapitalA], \[GothicCapitalM], \[GothicCapitalF]}\))\) - \((\
\[GothicCapitalD]\_{i\_{\[GothicCapitalA], \[GothicCapitalM], \
\[GothicCapitalF]}} - \[WeierstrassP]\_\(i\_{\(\[GothicCapitalG]\^*\), \
\[GothicCapitalM]}\) + \[WeierstrassP]\_\(i\_{\[GothicCapitalA], \
\[GothicCapitalM], \[GothicCapitalF]}\))\)\ \((\[WeierstrassP]\_\(j\_{\(\
\[GothicCapitalG]\^*\), \[GothicCapitalM]}\) - \[WeierstrassP]\_\(j\_{\
\[GothicCapitalA], \[GothicCapitalM], \[GothicCapitalF]}\))\))\) + \[GothicR]\
\_\({i}, {j}\)\ \((\[GothicCapitalD]\_{i\_{\[GothicCapitalA], \
\[GothicCapitalM], \[GothicCapitalM]}, j\_{\[GothicCapitalA], \
\[GothicCapitalM], \[GothicCapitalF]}} + \[GothicCapitalD]\_{j\_{\
\[GothicCapitalA], \[GothicCapitalM], \[GothicCapitalF]}}\ \((\(-\
\[WeierstrassP]\_\(i\_{\(\[GothicCapitalG]\^*\), \[GothicCapitalM]}\)\) + \
\[WeierstrassP]\_\(i\_{\[GothicCapitalA], \[GothicCapitalM], \
\[GothicCapitalM]}\))\) - \((\[GothicCapitalD]\_{i\_{\[GothicCapitalA], \
\[GothicCapitalM], \[GothicCapitalM]}} - \[WeierstrassP]\_\(i\_{\(\
\[GothicCapitalG]\^*\), \[GothicCapitalM]}\) + \[WeierstrassP]\_\(i\_{\
\[GothicCapitalA], \[GothicCapitalM], \[GothicCapitalM]}\))\)\ \((\
\[WeierstrassP]\_\(j\_{\(\[GothicCapitalG]\^*\), \[GothicCapitalM]}\) - \
\[WeierstrassP]\_\(j\_{\[GothicCapitalA], \[GothicCapitalM], \
\[GothicCapitalF]}\))\))\) + \[GothicR]\_\({i}, {j}\)\ \
\((\[GothicCapitalD]\_{i\_{\[GothicCapitalA], \[GothicCapitalM], \
\[GothicCapitalF]}, j\_{\[GothicCapitalA], \[GothicCapitalM], \
\[GothicCapitalM]}} + \[GothicCapitalD]\_{j\_{\[GothicCapitalA], \
\[GothicCapitalM], \[GothicCapitalM]}}\ \((\(-\[WeierstrassP]\_\(i\_{\(\
\[GothicCapitalG]\^*\), \[GothicCapitalM]}\)\) + \[WeierstrassP]\_\(i\_{\
\[GothicCapitalA], \[GothicCapitalM], \[GothicCapitalF]}\))\) - \((\
\[GothicCapitalD]\_{i\_{\[GothicCapitalA], \[GothicCapitalM], \
\[GothicCapitalF]}} - \[WeierstrassP]\_\(i\_{\(\[GothicCapitalG]\^*\), \
\[GothicCapitalM]}\) + \[WeierstrassP]\_\(i\_{\[GothicCapitalA], \
\[GothicCapitalM], \[GothicCapitalF]}\))\)\ \((\[WeierstrassP]\_\(j\_{\(\
\[GothicCapitalG]\^*\), \[GothicCapitalM]}\) - \[WeierstrassP]\_\(j\_{\
\[GothicCapitalA], \[GothicCapitalM], \[GothicCapitalM]}\))\))\) + \(\(\
\[GothicR]\_\({}, {i, 
              j}\)\)\(\ \)\((\[GothicCapitalD]\_{i\_{\[GothicCapitalA], \
\[GothicCapitalM], \[GothicCapitalM]}, j\_{\[GothicCapitalA], \
\[GothicCapitalM], \[GothicCapitalM]}} + \[GothicCapitalD]\_{j\_{\
\[GothicCapitalA], \[GothicCapitalM], \[GothicCapitalM]}}\ \((\(-\
\[WeierstrassP]\_\(i\_{\(\[GothicCapitalG]\^*\), \[GothicCapitalM]}\)\) + \
\[WeierstrassP]\_\(i\_{\[GothicCapitalA], \[GothicCapitalM], \
\[GothicCapitalM]}\))\) - \((\[GothicCapitalD]\_{i\_{\[GothicCapitalA], \
\[GothicCapitalM], \[GothicCapitalM]}} - \[WeierstrassP]\_\(i\_{\(\
\[GothicCapitalG]\^*\), \[GothicCapitalM]}\) + \[WeierstrassP]\_\(i\_{\
\[GothicCapitalA], \[GothicCapitalM], \[GothicCapitalM]}\))\)\ \((\
\[WeierstrassP]\_\(j\_{\(\[GothicCapitalG]\^*\), \[GothicCapitalM]}\) - \
\[WeierstrassP]\_\(j\_{\[GothicCapitalA], \[GothicCapitalM], \
\[GothicCapitalM]}\))\))\)\(\[IndentingNewLine]\)\)\)], "InlineFormula",
  CellMargins->{{18.1875, 24.375}, {Inherited, Inherited}}],

Cell["\<\
Such expressions are simplified by defining the reference values \
(see below).\
\>", "Text",
  CellMargins->{{18.1875, 24.375}, {Inherited, Inherited}}],

Cell["iii)  Stabilizing selection", "Text",
  CellMargins->{{18.1875, 24.375}, {Inherited, Inherited}},
  FontSlant->"Italic"],

Cell["\<\
\tStabilizing selection is represented by defining fitness as a \
function of genotype.  It is convenient to define the trait and fitness \
separately for each sex, even though they are in fact the same.  The \
expressions can be simplified later.\
\>", "Text",
  CellMargins->{{18.1875, 24.375}, {Inherited, Inherited}}],

Cell[BoxData[{
    RowBox[{
      "\[IndentingNewLine]", \(Z\_\[GothicCapitalM] = \[Sum]\+\(i \[Element] \
{j, k}\)\(b\_i\) \((X\_\(i\_{\[GothicCapitalZ], \[GothicCapitalM], \
\[GothicCapitalM]}\) + 
                X\_\(i\_{\[GothicCapitalZ], \[GothicCapitalM], \
\[GothicCapitalF]}\) - 1)\); 
      Z\_\[GothicCapitalF] = \[Sum]\+\(i \[Element] {j, k}\)\(b\_i\) \
\((X\_\(i\_{\[GothicCapitalZ], \[GothicCapitalF], \[GothicCapitalM]}\) + 
                X\_\(i\_{\[GothicCapitalZ], \[GothicCapitalF], \
\[GothicCapitalF]}\) - 1)\);\)}], "\[IndentingNewLine]", 
    RowBox[{\(\(W\_\[GothicCapitalM] = 
          1 - \(s\/2\) Z\_\[GothicCapitalM]\%2\) \), ";", 
      RowBox[{\(W\_\[GothicCapitalF]\), "=", 
        RowBox[{"1", "-", 
          RowBox[{\(s\/2\), 
            StyleBox[\(Z\_\[GothicCapitalF]\%2\),
              FontColor->RGBColor[1, 0, 0]]}]}]}], ";", 
      "\[IndentingNewLine]"}]}], "InlineFormula",
  CellMargins->{{18.1875, 24.375}, {Inherited, Inherited}},
  FontWeight->"Bold"],

Cell[TextData[{
  "Fitness depends on two loci, ",
  Cell[BoxData[
      \(TraditionalForm\`j\ and\ k\)]],
  ".  This defines the set of positions which influence fitness of males and \
females:"
}], "Text",
  CellMargins->{{18.1875, 24.375}, {Inherited, Inherited}}],

Cell[BoxData[{
    \(\[IndentingNewLine]\(\[DoubleStruckCapitalW]\_\[GothicCapitalM] = {j\_{\
\[GothicCapitalZ], \[GothicCapitalM], \[GothicCapitalM]}, 
          j\_{\[GothicCapitalZ], \[GothicCapitalM], \[GothicCapitalF]}, 
          k\_{\[GothicCapitalZ], \[GothicCapitalM], \[GothicCapitalM]}, 
          k\_{\[GothicCapitalZ], \[GothicCapitalM], \[GothicCapitalF]}};\)\), \
"\[IndentingNewLine]", 
    \(\(\[DoubleStruckCapitalW]\_\[GothicCapitalF] = {j\_{\[GothicCapitalZ], \
\[GothicCapitalF], \[GothicCapitalM]}, 
          j\_{\[GothicCapitalZ], \[GothicCapitalF], \[GothicCapitalF]}, 
          k\_{\[GothicCapitalZ], \[GothicCapitalF], \[GothicCapitalM]}, 
          k\_{\[GothicCapitalZ], \[GothicCapitalF], \[GothicCapitalF]}};\)\
\[IndentingNewLine]\)}], "InlineFormula",
  CellMargins->{{18.1875, 24.375}, {Inherited, Inherited}},
  FontWeight->"Bold"],

Cell["\<\
The fitness is now an explicit polynomial function of the states of \
genes in zygotes:\
\>", "MathCaption",
  CellMargins->{{18.1875, 24.375}, {Inherited, Inherited}}],

Cell[BoxData[
    \(W\_\[GothicCapitalM]\)], "InlineFormula",
  CellMargins->{{18.1875, 24.375}, {Inherited, Inherited}},
  FontWeight->"Bold"],

Cell[BoxData[
    \(1 - \(\(1\/2\)\(\ \)\(s\)\(\ \)\(\((\((\(-1\) + 
                      X\_\(j\_{\[GothicCapitalZ], \[GothicCapitalM], \
\[GothicCapitalF]}\) + 
                      X\_\(j\_{\[GothicCapitalZ], \[GothicCapitalM], \
\[GothicCapitalM]}\))\)\ b\_j + \((\(-1\) + 
                      X\_\(k\_{\[GothicCapitalZ], \[GothicCapitalM], \
\[GothicCapitalF]}\) + 
                      X\_\(k\_{\[GothicCapitalZ], \[GothicCapitalM], \
\[GothicCapitalM]}\))\)\ b\_k)\)\^2\)\(\[IndentingNewLine]\)\)\)], \
"InlineFormula",
  CellMargins->{{18.1875, 24.375}, {Inherited, Inherited}}],

Cell[TextData[{
  "Since we assume two alleles per locus, the fitness must be simplified to \
remove superfluous higher powers of the ",
  StyleBox["X",
    FontSlant->"Italic"],
  "s",
  ":"
}], "MathCaption",
  CellMargins->{{18.1875, 24.375}, {Inherited, Inherited}}],

Cell[BoxData[{
    \(\[IndentingNewLine]W2\_\[GothicCapitalM] = 
      Expand[W\_\[GothicCapitalM]] //. Biallelic[]; 
    W2\_\[GothicCapitalF] = 
      Expand[W\_\[GothicCapitalF]] //. Biallelic[];\), "\n", 
    \(W2\_\[GothicCapitalM] // Simplify\)}], "InlineFormula",
  CellMargins->{{18.1875, 24.375}, {Inherited, Inherited}},
  FontWeight->"Bold"],

Cell[BoxData[
    \(\(\(1\/2\)\(\ \)\((2 + 
          s\ \((\(-1\) + 
                X\_\(j\_{\[GothicCapitalZ], \[GothicCapitalM], \
\[GothicCapitalF]}\)\ \((1 - 
                      2\ X\_\(j\_{\[GothicCapitalZ], \[GothicCapitalM], \
\[GothicCapitalM]}\))\) + 
                X\_\(j\_{\[GothicCapitalZ], \[GothicCapitalM], \
\[GothicCapitalM]}\))\)\ b\_j\%2 - 
          2\ s\ \((\(-1\) + 
                X\_\(j\_{\[GothicCapitalZ], \[GothicCapitalM], \
\[GothicCapitalF]}\) + 
                X\_\(j\_{\[GothicCapitalZ], \[GothicCapitalM], \
\[GothicCapitalM]}\))\)\ \((\(-1\) + 
                X\_\(k\_{\[GothicCapitalZ], \[GothicCapitalM], \
\[GothicCapitalF]}\) + 
                X\_\(k\_{\[GothicCapitalZ], \[GothicCapitalM], \
\[GothicCapitalM]}\))\)\ b\_j\ b\_k + 
          s\ \((\(-1\) + 
                X\_\(k\_{\[GothicCapitalZ], \[GothicCapitalM], \
\[GothicCapitalF]}\)\ \((1 - 
                      2\ X\_\(k\_{\[GothicCapitalZ], \[GothicCapitalM], \
\[GothicCapitalM]}\))\) + 
                X\_\(k\_{\[GothicCapitalZ], \[GothicCapitalM], \
\[GothicCapitalM]}\))\)\ b\_k\%2)\)\(\[IndentingNewLine]\)\)\)], \
"InlineFormula",
  CellMargins->{{18.1875, 24.375}, {Inherited, Inherited}}],

Cell[TextData[{
  "The rule Biallelic[] implements the reduction formula ",
  StyleBox["which led to",
    FontColor->RGBColor[1, 0, 0]],
  " ",
  ButtonBox["Equation ",
    ButtonData:>"reductionFormula",
    ButtonStyle->"Hyperlink"],
  
  CounterBox["NumberedEquation", "reductionFormula"],
  ButtonBox[".",
    ButtonData:>"reductionFormula",
    ButtonStyle->"Hyperlink"]
}], "Text",
  CellMargins->{{18.1875, 24.375}, {Inherited, Inherited}}],

Cell["\<\
\tThe effect of selection on the mean contribution of a position \
is:\
\>", "Text",
  CellMargins->{{18.1875, 24.375}, {Inherited, Inherited}}],

Cell[BoxData[
    \(\(\(\[IndentingNewLine]\)\(\(\(\(\(\[GothicM]\_\(i\_{\[GothicCapitalA], \
\[GothicCapitalM], \[GothicCapitalF]}\) /. 
              Selection[{Sex}]\) /. {\[GothicA]\_\(sex_, \
\[DoubleStruckCapitalU]_\) \[RuleDelayed] \((MakeSelectionCoefficient[\
\[DoubleStruckCapitalU], W2\_sex]/
                    wb)\)}\) /. \[WeierstrassP]\_\(i_\_{\[GothicCapitalZ], _, \
_}\) :> \[GothicP]\_i\) /. 
        ReferencePointZero[\[GothicCapitalZ]]\)\(//\)\(Simplify\)\(\
\[IndentingNewLine]\)\)\)\)], "InlineFormula",
  CellMargins->{{18.1875, 24.375}, {Inherited, Inherited}},
  FontWeight->"Bold"],

Cell[BoxData[
    \(\[GothicP]\_i - \(\(s\/\(2\ wb\)\)\(\ \)\((\((\((\(-1\) + 
                        2\ \[GothicP]\_j)\)\ \[GothicCapitalD]\_{i\_{\
\[GothicCapitalZ], \[GothicCapitalM], \[GothicCapitalF]}, j\_{\
\[GothicCapitalZ], \[GothicCapitalM], \[GothicCapitalF]}} + \((\(-1\) + 
                        2\ \[GothicP]\_j)\)\ \[GothicCapitalD]\_{i\_{\
\[GothicCapitalZ], \[GothicCapitalM], \[GothicCapitalF]}, j\_{\
\[GothicCapitalZ], \[GothicCapitalM], \[GothicCapitalM]}} + 
                  2\ \[GothicCapitalD]\_{i\_{\[GothicCapitalZ], \
\[GothicCapitalM], \[GothicCapitalF]}, j\_{\[GothicCapitalZ], \
\[GothicCapitalM], \[GothicCapitalF]}, j\_{\[GothicCapitalZ], \
\[GothicCapitalM], \[GothicCapitalM]}})\)\ b\_j\%2 + 
            2\ \((\((\(-1\) + 
                        2\ \[GothicP]\_k)\)\ \[GothicCapitalD]\_{i\_{\
\[GothicCapitalZ], \[GothicCapitalM], \[GothicCapitalF]}, j\_{\
\[GothicCapitalZ], \[GothicCapitalM], \[GothicCapitalF]}} + \((\(-1\) + 
                        2\ \[GothicP]\_k)\)\ \[GothicCapitalD]\_{i\_{\
\[GothicCapitalZ], \[GothicCapitalM], \[GothicCapitalF]}, j\_{\
\[GothicCapitalZ], \[GothicCapitalM], \[GothicCapitalM]}} - \[GothicCapitalD]\
\_{i\_{\[GothicCapitalZ], \[GothicCapitalM], \[GothicCapitalF]}, k\_{\
\[GothicCapitalZ], \[GothicCapitalM], \[GothicCapitalF]}} + 
                  2\ \[GothicP]\_j\ \
\[GothicCapitalD]\_{i\_{\[GothicCapitalZ], \[GothicCapitalM], \
\[GothicCapitalF]}, k\_{\[GothicCapitalZ], \[GothicCapitalM], \
\[GothicCapitalF]}} - \[GothicCapitalD]\_{i\_{\[GothicCapitalZ], \
\[GothicCapitalM], \[GothicCapitalF]}, k\_{\[GothicCapitalZ], \
\[GothicCapitalM], \[GothicCapitalM]}} + 
                  2\ \[GothicP]\_j\ \
\[GothicCapitalD]\_{i\_{\[GothicCapitalZ], \[GothicCapitalM], \
\[GothicCapitalF]}, k\_{\[GothicCapitalZ], \[GothicCapitalM], \
\[GothicCapitalM]}} + \[GothicCapitalD]\_{i\_{\[GothicCapitalZ], \
\[GothicCapitalM], \[GothicCapitalF]}, j\_{\[GothicCapitalZ], \
\[GothicCapitalM], \[GothicCapitalF]}, k\_{\[GothicCapitalZ], \
\[GothicCapitalM], \[GothicCapitalF]}} + \[GothicCapitalD]\_{i\_{\
\[GothicCapitalZ], \[GothicCapitalM], \[GothicCapitalF]}, j\_{\
\[GothicCapitalZ], \[GothicCapitalM], \[GothicCapitalF]}, k\_{\
\[GothicCapitalZ], \[GothicCapitalM], \[GothicCapitalM]}} + \[GothicCapitalD]\
\_{i\_{\[GothicCapitalZ], \[GothicCapitalM], \[GothicCapitalF]}, j\_{\
\[GothicCapitalZ], \[GothicCapitalM], \[GothicCapitalM]}, k\_{\
\[GothicCapitalZ], \[GothicCapitalM], \[GothicCapitalF]}} + \[GothicCapitalD]\
\_{i\_{\[GothicCapitalZ], \[GothicCapitalM], \[GothicCapitalF]}, j\_{\
\[GothicCapitalZ], \[GothicCapitalM], \[GothicCapitalM]}, k\_{\
\[GothicCapitalZ], \[GothicCapitalM], \[GothicCapitalM]}})\)\ b\_j\ b\_k + \
\((\((\(-1\) + 
                        2\ \[GothicP]\_k)\)\ \[GothicCapitalD]\_{i\_{\
\[GothicCapitalZ], \[GothicCapitalM], \[GothicCapitalF]}, k\_{\
\[GothicCapitalZ], \[GothicCapitalM], \[GothicCapitalF]}} + \((\(-1\) + 
                        2\ \[GothicP]\_k)\)\ \[GothicCapitalD]\_{i\_{\
\[GothicCapitalZ], \[GothicCapitalM], \[GothicCapitalF]}, k\_{\
\[GothicCapitalZ], \[GothicCapitalM], \[GothicCapitalM]}} + 
                  2\ \[GothicCapitalD]\_{i\_{\[GothicCapitalZ], \
\[GothicCapitalM], \[GothicCapitalF]}, k\_{\[GothicCapitalZ], \
\[GothicCapitalM], \[GothicCapitalF]}, k\_{\[GothicCapitalZ], \
\[GothicCapitalM], \[GothicCapitalM]}})\)\ \
b\_k\%2)\)\(\[IndentingNewLine]\)\)\)], "InlineFormula",
  CellMargins->{{18.1875, 24.375}, {Inherited, Inherited}}],

Cell[TextData[{
  Cell[BoxData[
      \(TraditionalForm\`MakeSelectionCoefficient[\[DoubleStruckCapitalU], 
        W2\_sex]\)]],
  " generates the coefficient ",
  Cell[BoxData[
      \(TraditionalForm\`a\_\[DoubleStruckCapitalU]\)]],
  "from the fitness function.  ReferencePointZero[\[GothicCapitalZ]] sets the \
reference values in zygotes equal to the current allele frequencies, which \
are assumed equal across the sexes.  The mean fitness in the denominator is \
represented by wb, and is best substituted later."
}], "Text",
  CellMargins->{{18.1875, 24.375}, {Inherited, Inherited}}],

Cell["iv)  The complete life cycle", "Text",
  CellMargins->{{18.1875, 24.375}, {Inherited, Inherited}},
  FontSlant->"Italic"],

Cell["\<\
\tThis set of rules defines the change over the whole life cycle:\
\
\>", "Text",
  CellMargins->{{18.1875, 24.375}, {Inherited, Inherited}}],

Cell[BoxData[
    \(\(\(\[IndentingNewLine]\)\(rules = \
\((Recombination[]\[Vee]SymmetricRecombination[]\[Vee]ReferencePointSame[\
\[GothicCapitalG], {\[GothicCapitalA], \
\[GothicCapitalZ]}]\[Vee]ReferencePointZero[{\(\[GothicCapitalG]\^*\), \
\[GothicCapitalG]}]\[Vee]Selection[{Sex}]\[Vee]UnionOfGametes[]\[Vee]\
RandomUnion[\[GothicCapitalG]]\[Vee]\(Symmetrise[
                Disequilibrium]\[Vee]SymmetricSexes[]\))\);\)\(\
\[IndentingNewLine]\)\)\)], "InlineFormula",
  CellMargins->{{18.1875, 24.375}, {Inherited, Inherited}},
  FontWeight->"Bold"],

Cell[TextData[{
  "The mean contributions in the two sexes are assumed equal, as have all the \
linkage disequilibria; thus, SymmetricSexes[] is applied.  \
Symmetrise[Disequilibrium] simplifies ",
  Cell[BoxData[
      \(TraditionalForm\`\[GothicCapitalD]\_\(\({\[DoubleStruckK], \
\[DoubleStruckJ]}\)\(\ \)\)\ to\ \(\(\[GothicCapitalD]\_{\[DoubleStruckJ], \
\[DoubleStruckK]}\)\(.\)\)\)]],
  " ReferencePointSame[\[GothicCapitalG],{\[GothicCapitalA],\[GothicCapitalZ]}\
] sets the reference points in diploid stages to be inherited from the gamete \
stage, where they are equal to the current allele frequencies.  \
UnionOfGametes[] derives genes at the zygote stage from those in the gamete \
stage, and RandomUnion[\[GothicCapitalG]] makes the further assumption that \
gametes unite at random."
}], "Text",
  CellMargins->{{18.1875, 24.375}, {Inherited, Inherited}}],

Cell["\<\
\tThe new mean depends on selection coefficients up to fourth \
order:\
\>", "MathCaption",
  CellMargins->{{18.1875, 24.375}, {Inherited, Inherited}}],

Cell[BoxData[
    \(\(\(\[IndentingNewLine]\)\(nm = \
\[GothicM]\_\(j\_{\(\[GothicCapitalG]\^*\), \[GothicCapitalM]}\) //. rules // 
        Simplify\)\)\)], "InlineFormula",
  CellMargins->{{18.1875, 24.375}, {Inherited, Inherited}},
  FontWeight->"Bold"],

Cell[BoxData[
    \(\(\(1\/2\)\(\ \)\((2\ \[GothicM]\_\(j\_{\[GothicCapitalG], \
\[GothicCapitalF]}\) + \[GothicCapitalD]\_{j\_{\[GothicCapitalG], \
\[GothicCapitalF]}, k\_{\[GothicCapitalG], \[GothicCapitalF]}}\ \
\[GothicA]\_\(\[GothicCapitalM], {k\_{\[GothicCapitalZ], \[GothicCapitalM], \
\[GothicCapitalF]}}\) + \[GothicCapitalD]\_{j\_{\[GothicCapitalG], \
\[GothicCapitalF]}, k\_{\[GothicCapitalG], \[GothicCapitalF]}}\ \
\[GothicA]\_\(\[GothicCapitalM], {k\_{\[GothicCapitalZ], \[GothicCapitalM], \
\[GothicCapitalM]}}\) + \[GothicCapitalD]\_{j\_{\[GothicCapitalG], \
\[GothicCapitalF]}, j\_{\[GothicCapitalG], \[GothicCapitalF]}, k\_{\
\[GothicCapitalG], \[GothicCapitalF]}}\ \[GothicA]\_\(\[GothicCapitalM], \
{j\_{\[GothicCapitalZ], \[GothicCapitalM], \[GothicCapitalF]}, k\_{\
\[GothicCapitalZ], \[GothicCapitalM], \[GothicCapitalF]}}\) + \
\[GothicCapitalD]\_{j\_{\[GothicCapitalG], \[GothicCapitalF]}, j\_{\
\[GothicCapitalG], \[GothicCapitalF]}, k\_{\[GothicCapitalG], \
\[GothicCapitalF]}}\ \[GothicA]\_\(\[GothicCapitalM], {j\_{\[GothicCapitalZ], \
\[GothicCapitalM], \[GothicCapitalM]}, k\_{\[GothicCapitalZ], \
\[GothicCapitalM], \[GothicCapitalM]}}\) + \[GothicCapitalD]\_{j\_{\
\[GothicCapitalG], \[GothicCapitalF]}, j\_{\[GothicCapitalG], \
\[GothicCapitalF]}}\ \((\[GothicA]\_\(\[GothicCapitalM], {j\_{\
\[GothicCapitalZ], \[GothicCapitalM], \[GothicCapitalF]}}\) + \[GothicA]\_\(\
\[GothicCapitalM], {j\_{\[GothicCapitalZ], \[GothicCapitalM], \
\[GothicCapitalM]}}\) + \[GothicCapitalD]\_{j\_{\[GothicCapitalG], \
\[GothicCapitalF]}, k\_{\[GothicCapitalG], \[GothicCapitalF]}}\ \((\[GothicA]\
\_\(\[GothicCapitalM], {j\_{\[GothicCapitalZ], \[GothicCapitalM], \
\[GothicCapitalF]}, j\_{\[GothicCapitalZ], \[GothicCapitalM], \
\[GothicCapitalM]}, k\_{\[GothicCapitalZ], \[GothicCapitalM], \
\[GothicCapitalF]}}\) + \[GothicA]\_\(\[GothicCapitalM], {j\_{\
\[GothicCapitalZ], \[GothicCapitalM], \[GothicCapitalF]}, j\_{\
\[GothicCapitalZ], \[GothicCapitalM], \[GothicCapitalM]}, k\_{\
\[GothicCapitalZ], \[GothicCapitalM], \[GothicCapitalM]}}\))\))\) + \
\[GothicCapitalD]\_\({j\_{\[GothicCapitalG], \[GothicCapitalF]}, k\_{\
\[GothicCapitalG], \[GothicCapitalF]}}\)\%2\ \[GothicA]\_\(\[GothicCapitalM], \
{j\_{\[GothicCapitalZ], \[GothicCapitalM], \[GothicCapitalF]}, k\_{\
\[GothicCapitalZ], \[GothicCapitalM], \[GothicCapitalF]}, k\_{\
\[GothicCapitalZ], \[GothicCapitalM], \[GothicCapitalM]}}\) + \
\[GothicCapitalD]\_\({j\_{\[GothicCapitalG], \[GothicCapitalF]}, k\_{\
\[GothicCapitalG], \[GothicCapitalF]}}\)\%2\ \[GothicA]\_\(\[GothicCapitalM], \
{j\_{\[GothicCapitalZ], \[GothicCapitalM], \[GothicCapitalM]}, k\_{\
\[GothicCapitalZ], \[GothicCapitalM], \[GothicCapitalF]}, k\_{\
\[GothicCapitalZ], \[GothicCapitalM], \[GothicCapitalM]}}\) + 
          2\ \[GothicCapitalD]\_{j\_{\[GothicCapitalG], \[GothicCapitalF]}, k\
\_{\[GothicCapitalG], \[GothicCapitalF]}}\ \[GothicCapitalD]\_{j\_{\
\[GothicCapitalG], \[GothicCapitalF]}, j\_{\[GothicCapitalG], \
\[GothicCapitalF]}, k\_{\[GothicCapitalG], \[GothicCapitalF]}}\ \
\[GothicA]\_\(\[GothicCapitalM], {j\_{\[GothicCapitalZ], \[GothicCapitalM], \
\[GothicCapitalF]}, j\_{\[GothicCapitalZ], \[GothicCapitalM], \
\[GothicCapitalM]}, k\_{\[GothicCapitalZ], \[GothicCapitalM], \
\[GothicCapitalF]}, k\_{\[GothicCapitalZ], \[GothicCapitalM], \
\[GothicCapitalM]}}\))\)\(\[IndentingNewLine]\)\)\)], "InlineFormula",
  CellMargins->{{18.1875, 24.375}, {Inherited, Inherited}}],

Cell["\<\
We now substitute in the selection coefficients for this specific \
scheme:\
\>", "MathCaption",
  CellMargins->{{18.1875, 24.375}, {Inherited, Inherited}}],

Cell[BoxData[
    \(\(\(\[IndentingNewLine]\)\(nms = \(nm //. {\[GothicA]\_\(sex_, \
\[DoubleStruckCapitalU]_\) \[RuleDelayed] \((MakeSelectionCoefficient[\
\[DoubleStruckCapitalU], W2\_sex]/
                      wb)\)}\[Vee]Biallelic[]\[Vee]rules\) /. {\[GothicM]\_\
\[DoubleStruckI]_ \[Rule] \[GothicP]\_\[DoubleStruckI]} // 
        Simplify\)\)\)], "InlineFormula",
  CellMargins->{{18.1875, 24.375}, {Inherited, Inherited}},
  FontWeight->"Bold"],

Cell[BoxData[
    \(\[GothicP]\_\(j\_{\[GothicCapitalG], \[GothicCapitalF]}\) + \(\(s\/\(\(\
\ \)\(wb\)\)\)\(\ \)\((\ \(b\_j\) \((1 - \[GothicP]\_\(j\_{\[GothicCapitalG], \
\[GothicCapitalF]}\))\)\ \[GothicP]\_\(j\_{\[GothicCapitalG], \
\[GothicCapitalF]}\)\ \((\ \(1\/2\) \((1 - 
                        2\ \[GothicP]\_\(j\_{\[GothicCapitalG], \
\[GothicCapitalF]}\))\)\ b\_j + \ \((1 - 
                        2\ \[GothicP]\_\(k\_{\[GothicCapitalG], \
\[GothicCapitalF]}\))\)\ b\_k)\) + \[GothicCapitalD]\_{j\_{\[GothicCapitalG], \
\[GothicCapitalF]}, k\_{\[GothicCapitalG], \[GothicCapitalF]}}\ b\_k\ \
\((\(1\/2\) \((1 - 
                      2\ \[GothicP]\_\(k\_{\[GothicCapitalG], \
\[GothicCapitalF]}\))\)\ b\_k)\))\)\(\[IndentingNewLine]\)\)\)], \
"InlineFormula",
  CellMargins->{{18.1875, 24.375}, {Inherited, Inherited}}],

Cell[TextData[{
  "This expression is the same as ",
  ButtonBox["Equation ",
    ButtonData:>"deltaPTwoLoci",
    ButtonStyle->"Hyperlink"],
  
  CounterBox["NumberedEquation", "deltaPTwoLoci"],
  ButtonBox[" ",
    ButtonData:>"deltaPTwoLoci",
    ButtonStyle->"Hyperlink"],
  "with two loci."
}], "Text",
  CellMargins->{{18.1875, 24.375}, {Inherited, Inherited}}],

Cell["v)  Other processes", "Text",
  CellMargins->{{18.1875, 24.375}, {Inherited, Inherited}},
  FontSlant->"Italic"],

Cell["\<\
\tNon-Mendelian inheritance is handled by interpreting \
recombination rates appropriately. For example, a cytoplasmically inherited \
gene is certain to be inherited from the mother::\
\>", "Text",
  CellMargins->{{18.1875, 24.375}, {Inherited, Inherited}}],

Cell[BoxData[
    \(\(\(\[IndentingNewLine]\)\({\[GothicR]\_\({i, j}, {k}\), \
\[GothicR]\_\({j}, {i, k}\)} /. 
      NonMendelian[CytoplasmicLoci -> {i}]\)\)\)], "InlineFormula",
  CellMargins->{{18.1875, 24.375}, {Inherited, Inherited}},
  FontWeight->"Bold"],

Cell[BoxData[
    \(\(\({\[GothicR]\_\({j}, {k}\), 
      0}\)\(\[IndentingNewLine]\)\)\)], "InlineFormula",
  CellMargins->{{18.1875, 24.375}, {Inherited, Inherited}}],

Cell[TextData[{
  Cell[BoxData[
      \(\[GothicR]\_\({i, j}, {k}\)\)]],
  " is the chance that genes ",
  Cell[BoxData[
      \(TraditionalForm\`i, \ j\)]],
  " are inherited from the mother, and ",
  Cell[BoxData[
      \(TraditionalForm\`k\)]],
  " from the father; if ",
  Cell[BoxData[
      \(TraditionalForm\`i\)]],
  " is cytoplasmically inherited, then this is equal to the recombination \
rate for the autosomal loci,  ",
  Cell[BoxData[
      \(\[GothicR]\_\({j}, {k}\)\)]],
  ".  The converse, ",
  Cell[BoxData[
      \(\[GothicR]\_\({j}, {i, k}\)\)]],
  ", is impossible if ",
  Cell[BoxData[
      \(TraditionalForm\`i\)]],
  " is cytoplasmically inherited."
}], "Text",
  CellMargins->{{18.1875, 24.375}, {Inherited, Inherited}}],

Cell[TextData[{
  "\tMigration is implemented in a similar way to recombination, as a set of \
transmission rules.  For example, this is the cross-genome association \
between loci j and k among juveniles, ",
  Cell[BoxData[
      \(TraditionalForm\`\(\(\[GothicCapitalJ]\)\(,\)\(\ \)\)\)]],
  "after migration: "
}], "Text",
  CellMargins->{{18.1875, 24.375}, {Inherited, Inherited}}],

Cell[BoxData[
    \(\(\(\[IndentingNewLine]\)\(\[GothicCapitalD]\_{j\_{\[GothicCapitalJ], \
1, \[GothicCapitalM], \[GothicCapitalM]}, k\_{\[GothicCapitalJ], 1, \
\[GothicCapitalM], \[GothicCapitalF]}} /. 
      Migration[{1, 2} &]\)\)\)], "InlineFormula",
  CellMargins->{{18.1875, 24.375}, {Inherited, Inherited}},
  FontWeight->"Bold"],

Cell[BoxData[
    \(\[CapitalMu]\_\(1, 1\)\ \((\[GothicCapitalD]\_{j\_{\[GothicCapitalZ], \
1, \[GothicCapitalM], \[GothicCapitalM]}, k\_{\[GothicCapitalZ], 1, \
\[GothicCapitalM], \[GothicCapitalF]}} + \[GothicCapitalD]\_{k\_{\
\[GothicCapitalZ], 1, \[GothicCapitalM], \[GothicCapitalF]}}\ \((\(-\
\[WeierstrassP]\_\(j\_{\[GothicCapitalJ], 1, \[GothicCapitalM], \
\[GothicCapitalM]}\)\) + \[WeierstrassP]\_\(j\_{\[GothicCapitalZ], 1, \
\[GothicCapitalM], \[GothicCapitalM]}\))\) + \[GothicCapitalD]\_{j\_{\
\[GothicCapitalZ], 1, \[GothicCapitalM], \[GothicCapitalM]}}\ \((\(-\
\[WeierstrassP]\_\(k\_{\[GothicCapitalJ], 1, \[GothicCapitalM], \
\[GothicCapitalF]}\)\) + \[WeierstrassP]\_\(k\_{\[GothicCapitalZ], 1, \
\[GothicCapitalM], \[GothicCapitalF]}\))\) + \((\(-\[WeierstrassP]\_\(j\_{\
\[GothicCapitalJ], 1, \[GothicCapitalM], \[GothicCapitalM]}\)\) + \
\[WeierstrassP]\_\(j\_{\[GothicCapitalZ], 1, \[GothicCapitalM], \
\[GothicCapitalM]}\))\)\ \((\(-\[WeierstrassP]\_\(k\_{\[GothicCapitalJ], 1, \
\[GothicCapitalM], \[GothicCapitalF]}\)\) + \[WeierstrassP]\_\(k\_{\
\[GothicCapitalZ], 1, \[GothicCapitalM], \[GothicCapitalF]}\))\))\) + \(\(\
\[CapitalMu]\_\(1, 
            2\)\)\(\ \)\((\[GothicCapitalD]\_{j\_{\[GothicCapitalZ], 2, \
\[GothicCapitalM], \[GothicCapitalM]}, k\_{\[GothicCapitalZ], 2, \
\[GothicCapitalM], \[GothicCapitalF]}} + \[GothicCapitalD]\_{k\_{\
\[GothicCapitalZ], 2, \[GothicCapitalM], \[GothicCapitalF]}}\ \((\(-\
\[WeierstrassP]\_\(j\_{\[GothicCapitalJ], 1, \[GothicCapitalM], \
\[GothicCapitalM]}\)\) + \[WeierstrassP]\_\(j\_{\[GothicCapitalZ], 2, \
\[GothicCapitalM], \[GothicCapitalM]}\))\) + \[GothicCapitalD]\_{j\_{\
\[GothicCapitalZ], 2, \[GothicCapitalM], \[GothicCapitalM]}}\ \((\(-\
\[WeierstrassP]\_\(k\_{\[GothicCapitalJ], 1, \[GothicCapitalM], \
\[GothicCapitalF]}\)\) + \[WeierstrassP]\_\(k\_{\[GothicCapitalZ], 2, \
\[GothicCapitalM], \[GothicCapitalF]}\))\) + \((\(-\[WeierstrassP]\_\(j\_{\
\[GothicCapitalJ], 1, \[GothicCapitalM], \[GothicCapitalM]}\)\) + \
\[WeierstrassP]\_\(j\_{\[GothicCapitalZ], 2, \[GothicCapitalM], \
\[GothicCapitalM]}\))\)\ \((\(-\[WeierstrassP]\_\(k\_{\[GothicCapitalJ], 1, \
\[GothicCapitalM], \[GothicCapitalF]}\)\) + \[WeierstrassP]\_\(k\_{\
\[GothicCapitalZ], 2, \[GothicCapitalM], \[GothicCapitalF]}\))\))\)\(\
\[IndentingNewLine]\)\)\)], "InlineFormula",
  CellMargins->{{18.1875, 24.375}, {Inherited, Inherited}}],

Cell[TextData[{
  "These expressions are linear sums, weighted by migration rates, ",
  Cell[BoxData[
      \(\[CapitalMu]\_\(i, j\)\)]],
  ".  The set of possible source demes is defined by {1,2}& - that is, all \
demes can receive immigrants from demes 1 or 2.  The deme in which a gene is \
found is indicated by an extra element in the context, that takes values 1 or \
2 in this example."
}], "Text",
  CellMargins->{{18.1875, 24.375}, {Inherited, Inherited}}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Tables",
  FontWeight->"Bold"]], "Subtitle",
  CellMargins->{{18.1875, 24.375}, {Inherited, Inherited}},
  PageBreakAbove->True],

Cell[CellGroupData[{

Cell["Table 1.  Summary of notation", "Subsection",
  CellMargins->{{18.1875, 24.375}, {Inherited, Inherited}},
  PageBreakAbove->True,
  CellTags->"Summary of notation"],

Cell[BoxData[
    StyleBox[GridBox[{
          {
            StyleBox["Symbol",
              FontWeight->"Bold"], 
            RowBox[{
              StyleBox["Meaning",
                FontWeight->"Bold"], "\[IndentingNewLine]"}]},
          {
            StyleBox[\(Loci, \ contexts, \ and\ positions\),
              FontVariations->{"Underline"->True}], " "},
          {
            RowBox[{
              StyleBox["i",
                FontSlant->"Italic"], ",", 
              StyleBox["j",
                FontSlant->"Italic"], " "}], \(a\ locus\)},
          {
            RowBox[{\(m, f\), "\[IndentingNewLine]", 
              RowBox[{"\[DoubleStruckI]", "  ", "=", "  ", 
                SubscriptBox[
                  StyleBox["i",
                    FontSlant->"Italic"], \(m\ f\)], 
                "\[IndentingNewLine]"}]}], 
            
            RowBox[{\(male, \ female; \ \ used\ to\ specify\ contexts\), 
              "\[IndentingNewLine]", 
              RowBox[{
                RowBox[{
                "the", " ", "position", " ", "corresponding", " ", "to", " ", 
                  "locus", " ", 
                  StyleBox["i",
                    FontSlant->"Italic"], 
                  StyleBox[" ",
                    FontSlant->"Plain"], 
                  StyleBox["in",
                    FontSlant->"Plain"], 
                  StyleBox[" ",
                    FontSlant->"Plain"], 
                  StyleBox["the",
                    FontSlant->"Plain"], 
                  StyleBox[" ",
                    FontSlant->"Plain"], 
                  StyleBox["context",
                    FontSlant->"Plain"], 
                  StyleBox[" ",
                    FontSlant->"Plain"], 
                  StyleBox[\({m\ f}\),
                    FontSlant->"Plain"]}], ";", " ", 
                StyleBox[\(that\ is\),
                  FontSlant->"Plain"]}], 
              StyleBox[",",
                FontSlant->"Plain"], 
              StyleBox[" ",
                FontSlant->"Plain"], "\[IndentingNewLine]", "     ", 
              RowBox[{
                StyleBox["a",
                  FontSlant->"Plain"], 
                StyleBox[" ",
                  FontSlant->"Plain"], 
                StyleBox["gene",
                  FontSlant->"Plain"], 
                StyleBox[" ",
                  FontSlant->"Plain"], 
                StyleBox["at",
                  FontSlant->"Plain"], 
                StyleBox[" ",
                  FontSlant->"Plain"], 
                StyleBox["locus",
                  FontSlant->"Plain"], 
                StyleBox[" ",
                  FontSlant->"Plain"], 
                StyleBox["i",
                  FontSlant->"Italic"], 
                StyleBox[" ",
                  FontSlant->"Plain"], 
                StyleBox["in",
                  FontSlant->"Plain"], 
                StyleBox[" ",
                  FontSlant->"Plain"], 
                StyleBox["a",
                  FontSlant->"Plain"], 
                StyleBox[" ",
                  FontSlant->"Plain"], 
                StyleBox["male",
                  FontSlant->"Plain"], 
                StyleBox[" ",
                  FontSlant->"Plain"], "that", " ", "was", " ", "inherited", 
                " ", "from", " ", "a", " ", "female", 
                StyleBox[" ",
                  FontSlant->"Plain"]}]}]},
          {\(\[DoubleStruckCapitalU] = {\[DoubleStruckI], \[DoubleStruckJ], \
\[Ellipsis]}\), \(a\ set\ of\ positions\)},
          {\(\[DoubleStruckCapitalU]\[Backslash]\[DoubleStruckCapitalV]\), \
\(the\ set\ \ \[DoubleStruckCapitalU]\ with\ the\ elements\ of\ the\ set\
\ \ \[DoubleStruckCapitalV]\ removed; \ only\ defined\ \[IndentingNewLine]
            \ \ \ \ \ when\ \[DoubleStruckCapitalV]\ is\ a\ subset\ of\ \
\[DoubleStruckCapitalU]\)},
          {\(\(\[DoubleStruckCapitalG]\)\(\[IndentingNewLine]\)\(\
\[IndentingNewLine]\)
            \(\[DoubleStruckCapitalW]\)\(\[IndentingNewLine]\)\), \(the\ set\ \
of\ all\ positions\ within\ an\ individual\ genome; \ 
            repeated\ \ \[IndentingNewLine]
            \ \ \ \ \ \ elements\ are\ included\ if\ there\ are\ multiple\ \
alleles\[IndentingNewLine]
            the\ set\ of\ all\ positions\ in\ the\ selection\ group\)},
          {
            RowBox[{
              StyleBox["Summations",
                FontVariations->{"Underline"->True}], 
              "\[IndentingNewLine]", \(\[Sum]\+\(\[DoubleStruckI] \[Element] \
\[DoubleStruckCapitalU]\)\)}], \(\(\[IndentingNewLine]\)\(a\ sum\ over\ all\ \
positions\ \[DoubleStruckI]\ in\ the\ set\ \[DoubleStruckCapitalU]\)\)},
          {
            
            RowBox[{\(\[Sum]\+\(\[DoubleStruckCapitalU] \[SubsetEqual] \
\[DoubleStruckCapitalA]\)\[IndentingNewLine]'\), 
              "\[IndentingNewLine]", \(\(\[Sum]\+\(\[DoubleStruckCapitalU] \
\[SubsetEqual] \[DoubleStruckCapitalA]\)\%*\)\[IndentingNewLine]'\), 
              "\[IndentingNewLine]", 
              RowBox[{
                UnderscriptBox["\[Sum]", 
                  RowBox[{
                    RowBox[{"\[DoubleStruckCapitalU]", ":", 
                      StyleBox["U",
                        FontSlant->"Italic"]}], "=", 
                    StyleBox["A",
                      FontSlant->"Italic"]}]], "\[IndentingNewLine]", "'"}], 
              "\[IndentingNewLine]", 
              RowBox[{
                UnderscriptBox["\[Sum]", 
                  RowBox[{
                    RowBox[{
                      StyleBox["S",
                        FontSlant->"Italic"], "+", 
                      StyleBox["T",
                        FontSlant->"Italic"]}], "=", 
                    StyleBox["A",
                      FontSlant->"Italic"]}]], "\[IndentingNewLine]", 
                "\[IndentingNewLine]", "\[IndentingNewLine]"}]}], 
            
            RowBox[{\(a\ sum\ over\ all\ subsets\ \
\[DoubleStruckCapitalU]\ \ of\ the\ set\ \[DoubleStruckCapitalA], \ 
              including\ terms\ for\ the\ set\ \[DoubleStruckCapitalA]\), " ",
               "\[IndentingNewLine]", 
              "     ", \(itself\ and\ the\ empty\ set\ \[EmptySet]\), " ", 
              "\[IndentingNewLine]", \(a\ sum\ over\ all\ subsets\ \
\[DoubleStruckCapitalU]\ \ of\ the\ set\ \[DoubleStruckCapitalA], \ 
              including\ a\ term\ for\ the\ set\), " ", "\[IndentingNewLine]",
               "      ", \(\[DoubleStruckCapitalA]\ itself\ but\ not\ for\ \
the\ empty\ set\ \[EmptySet]\), "\[IndentingNewLine]", 
              RowBox[{
                RowBox[{
                  RowBox[{
                  "a", " ", "sum", " ", "over", " ", "all", " ", "sets", " ", 
                    "\[DoubleStruckCapitalU]", " ", "such", " ", "that", " ", 
                    
                    StyleBox["U",
                      FontSlant->"Italic"]}], 
                  StyleBox[" ",
                    FontSlant->"Plain"], 
                  StyleBox["=",
                    FontSlant->"Plain"], 
                  StyleBox[" ",
                    FontSlant->"Plain"], 
                  StyleBox["A",
                    FontSlant->"Italic"]}], 
                StyleBox[",",
                  FontSlant->"Plain"], 
                StyleBox[" ",
                  FontSlant->"Plain"], 
                StyleBox[\(that\ is\),
                  FontSlant->"Plain"], 
                StyleBox[",",
                  FontSlant->"Plain"], 
                StyleBox[" ",
                  FontSlant->"Plain"], 
                RowBox[{
                  StyleBox["such",
                    FontSlant->"Plain"], 
                  StyleBox[" ",
                    FontSlant->"Plain"], 
                  StyleBox["that",
                    FontSlant->"Plain"], 
                  StyleBox[" ",
                    FontSlant->"Plain"], 
                  StyleBox["U",
                    FontSlant->"Italic"], 
                  StyleBox[" ",
                    FontSlant->"Plain"], 
                  StyleBox["and",
                    FontSlant->"Plain"], 
                  StyleBox[" ",
                    FontSlant->"Plain"], 
                  StyleBox["A",
                    FontSlant->"Italic"]}]}], "\[IndentingNewLine]", 
              "     ", \(are\ equal\ when\ the\ context\ information\ is\ \
removed\), "\[IndentingNewLine]", 
              RowBox[{
                RowBox[{
                  RowBox[{
                  "a", " ", "sum", " ", "over", " ", "all", " ", "nonnull", 
                    " ", "partitions", " ", "of", " ", "the", " ", "set", " ",
                     
                    StyleBox["A",
                      FontSlant->"Italic"]}], ";", "  ", \(for\ example\)}], 
                ",", " ", "with"}], "\[IndentingNewLine]", "     ", 
              RowBox[{
                RowBox[{
                  StyleBox["A",
                    FontSlant->"Italic"], " ", "=", " ", 
                  RowBox[{
                    RowBox[{
                      RowBox[{"{", 
                        RowBox[{
                          StyleBox["i",
                            FontSlant->"Italic"], ",", " ", 
                          StyleBox["j",
                            FontSlant->"Italic"]}], "}"}], " ", "there", " ", 
                      "is", " ", "one", " ", "term", " ", "with", " ", 
                      StyleBox["S",
                        FontSlant->"Italic"]}], 
                    StyleBox[" ",
                      FontSlant->"Plain"], 
                    StyleBox["=",
                      FontSlant->"Plain"], 
                    StyleBox[" ",
                      FontSlant->"Plain"], 
                    RowBox[{
                      RowBox[{
                        StyleBox["i",
                          FontSlant->"Italic"], 
                        StyleBox[" ",
                          FontSlant->"Plain"], 
                        StyleBox["and",
                          FontSlant->"Plain"], 
                        StyleBox[" ",
                          FontSlant->"Plain"], 
                        StyleBox["T",
                          FontSlant->"Italic"]}], 
                      StyleBox[" ",
                        FontSlant->"Plain"], 
                      StyleBox["=",
                        FontSlant->"Plain"], 
                      StyleBox[" ",
                        FontSlant->"Plain"], 
                      StyleBox["j",
                        FontSlant->"Italic"]}]}]}], 
                StyleBox[",",
                  FontSlant->"Plain"], 
                StyleBox[" ",
                  FontSlant->"Plain"], 
                StyleBox[\(and\ one\ term\),
                  FontSlant->"Plain"]}], "\[IndentingNewLine]", "     ", 
              RowBox[{
                RowBox[{"with", " ", 
                  StyleBox["S",
                    FontSlant->"Italic"]}], 
                StyleBox[" ",
                  FontSlant->"Plain"], 
                StyleBox["=",
                  FontSlant->"Plain"], 
                StyleBox[" ",
                  FontSlant->"Plain"], 
                RowBox[{
                  RowBox[{
                    StyleBox["j",
                      FontSlant->"Italic"], 
                    StyleBox[" ",
                      FontSlant->"Plain"], 
                    StyleBox["and",
                      FontSlant->"Plain"], 
                    StyleBox[" ",
                      FontSlant->"Plain"], 
                    StyleBox["T",
                      FontSlant->"Italic"]}], 
                  StyleBox[" ",
                    FontSlant->"Plain"], 
                  StyleBox["=",
                    FontSlant->"Plain"], 
                  StyleBox[" ",
                    FontSlant->"Plain"], 
                  StyleBox["i",
                    FontSlant->"Italic"], "\[IndentingNewLine]"}]}]}]},
          {
            StyleBox[\(Allele\ frequencies\ and\ associations\),
              FontVariations->{"Underline"->True}], 
            StyleBox[" ",
              FontSlant->"Italic"]},
          {
            RowBox[{
              SubscriptBox[
                StyleBox["X",
                  FontSlant->"Italic"], "\[DoubleStruckI]"], 
              "\[IndentingNewLine]", 
              StyleBox["X",
                FontWeight->"Bold",
                FontSlant->"Italic"]}], 
            
            RowBox[{\(the\ indicator\ variable\ that\ labels\ the\ allelic\ \
state\ of\ position\ \[DoubleStruckI]\), "\[IndentingNewLine]", 
              RowBox[{"a", " ", "vector", " ", "of", " ", 
                StyleBox[
                  RowBox[{
                    StyleBox["X",
                      FontSlant->"Italic"], 
                    StyleBox["s",
                      FontSlant->"Plain"]}]], " ", "that", " ", "gives", 
                StyleBox[" ",
                  FontSlant->"Plain"], 
                StyleBox["the",
                  FontSlant->"Plain"], 
                StyleBox[" ",
                  FontSlant->"Plain"], 
                StyleBox["genotype",
                  FontSlant->"Plain"], 
                StyleBox[" ",
                  FontSlant->"Plain"], 
                StyleBox["of",
                  FontSlant->"Plain"], 
                StyleBox[" ",
                  FontSlant->"Plain"], 
                StyleBox["an",
                  FontSlant->"Plain"], 
                StyleBox[" ",
                  FontSlant->"Plain"], 
                StyleBox["individual",
                  FontSlant->"Plain"]}]}]},
          {
            RowBox[{
              StyleBox["f",
                FontSlant->"Italic"], 
              RowBox[{"(", 
                StyleBox["X",
                  FontWeight->"Bold",
                  FontSlant->"Italic"], ")"}]}], 
            RowBox[{
            "the", " ", "frequency", " ", "of", " ", "genotype", " ", 
              StyleBox["X",
                FontWeight->"Bold",
                FontSlant->"Italic"]}]},
          {\(\[WeierstrassP]\_\[DoubleStruckI]\), \(the\ reference\ value\ \
for\ position\ \[DoubleStruckI]\)},
          {
            RowBox[{\(\[Zeta]\_\[DoubleStruckI]\), "=", 
              RowBox[{
                SubscriptBox[
                  StyleBox["X",
                    FontSlant->"Italic"], "\[DoubleStruckI]"], 
                "-", \(\[WeierstrassP]\_\[DoubleStruckI]\)}]}], \(\(the\)\(\ \
\)\(deviation\)\(\ \)\(of\)\(\ \)\(an\)\(\ \)\(individual\)\(\ \)\(at\)\(\ \)\
\(position\)\(\ \)\(\[DoubleStruckI]\)\(\ \)\(from\)\(\ \)\(the\)\(\ \
\)\(reference\)\(\ \)\(value\)\(\ \)\)},
          {
            RowBox[{
              RowBox[{
                SubscriptBox["E", 
                  StyleBox["X",
                    FontWeight->"Bold"]], "[", 
                RowBox[{
                  StyleBox["g",
                    FontSlant->"Italic"], 
                  RowBox[{"(", 
                    StyleBox["X",
                      FontWeight->"Bold"], ")"}]}], "]"}], " ", "=", " ", 
              RowBox[{
                UnderscriptBox["\[Sum]", 
                  StyleBox["X",
                    FontWeight->"Bold"]], 
                RowBox[{
                  StyleBox["f",
                    FontSlant->"Italic"], 
                  RowBox[{"(", 
                    StyleBox["X",
                      FontWeight->"Bold"], ")"}], 
                  StyleBox["g",
                    FontSlant->"Italic"], 
                  RowBox[{"(", 
                    StyleBox["X",
                      FontWeight->"Bold"], ")"}]}]}]}], 
            RowBox[{
              RowBox[{"the", "  ", "expectation", " ", "of", " ", "g", 
                RowBox[{"(", 
                  StyleBox["X",
                    FontWeight->"Bold",
                    FontSlant->"Italic"], ")"}], " ", "over", " ", "allelic", 
                " ", "states"}], ",", " ", 
              StyleBox["X",
                FontWeight->"Bold",
                FontSlant->"Italic"]}]},
          {
            RowBox[{
              SubscriptBox[
                StyleBox["m",
                  FontSlant->"Italic"], "\[DoubleStruckI]"], "=", 
              RowBox[{"E", "[", 
                SubscriptBox[
                  StyleBox["X",
                    FontSlant->"Italic"], "\[DoubleStruckI]"], 
                "]"}]}], \(\(the\)\(\ \)\(mean\)\(\ \)\(value\)\(\ \)\(of\)\(\
\ \)\(position\)\(\ \)\(\[DoubleStruckI]\)\(\ \)\)},
          {
            SubscriptBox[
              StyleBox["p",
                FontSlant->"Italic"], "\[DoubleStruckI]"], 
            RowBox[{
              RowBox[{
              "the", "  ", "frequency", " ", "of", " ", "allele", " ", 
                SubscriptBox[
                  StyleBox["X",
                    FontSlant->"Italic"], "\[DoubleStruckI]"]}], 
              "=", \(\(1\)\(\ \)\(at\)\(\ \)\(position\)\(\ \)\(\
\[DoubleStruckI]\)\(\ \)\)}]},
          {
            StyleBox[\(p\[VeryThinSpace]q\_\[DoubleStruckI]\),
              FontSlant->"Italic",
              FontColor->RGBColor[1, 0, 0]], 
            RowBox[{
              SubscriptBox[
                StyleBox["p",
                  FontSlant->"Italic"], "\[DoubleStruckI]"], 
              RowBox[{"(", 
                RowBox[{"1", " ", "-", " ", 
                  SubscriptBox[
                    StyleBox["p",
                      FontSlant->"Italic"], "\[DoubleStruckI]"]}], ")"}]}]},
          {
            RowBox[{
              SubscriptBox[
                StyleBox["pq",
                  FontSlant->"Italic"], "\[DoubleStruckCapitalU]"], "=", 
              
              RowBox[{\(\[Product]\+\(\[DoubleStruckI] \[Element] \
\[DoubleStruckCapitalU]\)\), 
                SubscriptBox[
                  StyleBox["pq",
                    FontSlant->"Italic"], 
                  "\[DoubleStruckI]"]}]}], \(the\ product\ of\ allele\ \
frequencies\ over\ the\ set\ of\ positions\ \[DoubleStruckCapitalU]\)},
          {\(\[Zeta]\_\[DoubleStruckCapitalU] = \
\[Product]\+\(\[DoubleStruckI] \[Element] \[DoubleStruckCapitalU]\)\[Zeta]\_\
\[DoubleStruckI]\), \(the\ product\ of\ deviations\ over\ the\ set\ of\ \
positions\ \[DoubleStruckCapitalU]\)},
          {
            RowBox[{
              SubscriptBox[
                StyleBox["D",
                  FontSlant->"Italic"], "\[DoubleStruckCapitalU]"], "=", 
              RowBox[{
                SubscriptBox["E", 
                  StyleBox["X",
                    FontWeight->"Bold",
                    FontSlant->"Italic"]], 
                "[", \(\[Zeta]\_\[DoubleStruckCapitalU]\), 
                "]"}]}], \(\(the\)\(\ \)\(association\)\(\ \)\(between\)\(\ \
\)\(the\)\(\ \)\(set\)\(\ \)\(of\)\(\ \)\(positions\)\(\ \ \)\(\
\[DoubleStruckCapitalU]\)\(\[IndentingNewLine]\)\)},
          {
            StyleBox[\(Phenotypes, \ fitness, \ and\ selection\),
              FontVariations->{"Underline"->True}], " "},
          {
            StyleBox["Z",
              
              FontSlant->
                "Italic"], \(the\ value\ of\ a\ phenotypic\ trait\)},
          {
            "\[DoubleStruckCapitalZ]", \(the\ set\ of\ all\ positions\ \
influencing\ trait\ \ Z\)},
          {
            StyleBox["W",
              FontSlant->"Italic"], "fitness"},
          {
            RowBox[{
              OverscriptBox[
                StyleBox["W",
                  FontSlant->"Italic"], "_"], "=", 
              RowBox[{
                SubscriptBox["E", 
                  StyleBox["X",
                    FontWeight->"Bold",
                    FontSlant->"Italic"]], "[", 
                StyleBox["W",
                  FontSlant->"Italic"], "]"}]}], \(mean\ fitness\)},
          {
            SubscriptBox[
              StyleBox["a",
                FontSlant->"Italic"], "\[DoubleStruckCapitalU]"], 
            
            RowBox[{\(the\ selection\ coefficient\ for\ the\ set\ of\ \
positions\ \[DoubleStruckCapitalU], \ defined\ by\), " ", 
              "\[IndentingNewLine]", "     ", 
              RowBox[{"Equation", " ", 
                RowBox[{"(", 
                  CounterBox["NumberedEquation", "fitnessDefinition"], ")"}], 
                "\[IndentingNewLine]"}]}]},
          {
            StyleBox["Transmission",
              FontVariations->{"Underline"->True}], " "},
          {
            SubscriptBox[
              StyleBox["t",
                
                FontSlant->
                  "Italic"], \(\[DoubleStruckCapitalA] \[LeftArrow] \
\[DoubleStruckCapitalB]\)], \(the\ proportion\ of\ genes\ at\ positions\ \
\[DoubleStruckCapitalA]\ that\ were\ transmitted\ from\ \[IndentingNewLine]
            \ \ \ \ \ positions\ \[DoubleStruckCapitalB]\)}
          },
        ColumnAlignments->{Left},
        GridFrame->True],
      FontFamily->"Times"]], "Text",
  CellMargins->{{18.1875, 23.375}, {Inherited, Inherited}},
  TextAlignment->Left]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
Table 2.  Examples of transmission coefficients under meiosis and \
syngamy\
\>", "Subsection",
  CellMargins->{{18.1875, 24.375}, {Inherited, Inherited}},
  PageBreakAbove->True,
  CellTags->"Transmission coefficients for various forms of recombination"],

Cell[TextData[{
  "\t",
  StyleBox["Haploid autosomes",
    FontVariations->{"Underline"->True}],
  "\n\t\t",
  Cell[BoxData[
      FormBox[
        RowBox[{
          SubscriptBox["t", 
            RowBox[{
              SubscriptBox["i", 
                StyleBox["f",
                  FontSlant->"Plain"]], "\[LeftArrow]", " ", 
              SubscriptBox["i", 
                StyleBox["m",
                  FontSlant->"Plain"]]}]], "  ", "=", "  ", \(1/2\)}], 
        TraditionalForm]]],
  "\n\t\t",
  Cell[BoxData[
      FormBox[
        RowBox[{
          SubscriptBox["t", 
            RowBox[{
              RowBox[{
                SubscriptBox["i", 
                  StyleBox["f",
                    FontSlant->"Plain"]], 
                SubscriptBox["j", 
                  StyleBox["f",
                    FontSlant->"Plain"]]}], "\[LeftArrow]", " ", 
              RowBox[{
                SubscriptBox["i", 
                  StyleBox["m",
                    FontSlant->"Plain"]], 
                SubscriptBox["j", 
                  StyleBox["f",
                    FontSlant->"Plain"]]}]}]], "  ", "=", "  ", 
          RowBox[{
            SubscriptBox["r", 
              StyleBox["ij",
                FontSlant->"Italic"]], "/", "2"}]}], TraditionalForm]]],
  "\n\t",
  StyleBox["Diploid autosomes",
    FontVariations->{"Underline"->True}],
  "\n\t\t",
  Cell[BoxData[
      \(TraditionalForm\`t\_\(i\_fm \[LeftArrow] \ i\_mm\)\ \  = \ \ 1/2\)]],
  "\n\t\t",
  Cell[BoxData[
      FormBox[
        RowBox[{\(t\_\(\(i\_fm\) j\_fm \[LeftArrow] \ \(i\_mf\) j\_mm\)\), 
          "  ", "=", "  ", 
          RowBox[{
            SubsuperscriptBox["r", 
              StyleBox["ij",
                FontSlant->"Italic"], 
              StyleBox["m",
                FontSlant->"Plain"]], "/", "2"}]}], TraditionalForm]]],
  "\n\t\t",
  Cell[BoxData[
      FormBox[
        RowBox[{\(t\_\(\[DoubleStruckCapitalA]\_mf \[LeftArrow] \ \
\[DoubleStruckCapitalA]\_fm\)\), "  ", "=", "  ", 
          RowBox[{
            RowBox[{"(", 
              RowBox[{"1", " ", "-", " ", 
                SubsuperscriptBox["r", "\[DoubleStruckCapitalA]", 
                  StyleBox["f",
                    FontSlant->"Plain"]]}], ")"}], "/", "2"}]}], 
        TraditionalForm]]],
  "\n\t",
  StyleBox["Sex linkage in diploids",
    FontVariations->{"Underline"->True}],
  ":  loci ",
  StyleBox["i",
    FontSlant->"Italic"],
  " and ",
  StyleBox["j",
    FontSlant->"Italic"],
  " X-linked, ",
  StyleBox["k",
    FontSlant->"Italic"],
  " autosomal\n\t\t",
  Cell[BoxData[
      \(TraditionalForm\`t\_\(i\_m \[LeftArrow] i\_m\)\ \  = \ \ 0\)]],
  "\n\t\t",
  Cell[BoxData[
      \(TraditionalForm\`t\_\(\(i\_fm\) j\_fm \[LeftArrow] \ \(i\_mf\) \
j\_mf\)\ \  = \ \ 1\)]],
  "\n\t\t",
  Cell[BoxData[
      FormBox[
        RowBox[{\(t\_\(\(i\_ff\) j\_ff \[LeftArrow] \ \(i\_fm\) j\_fm\)\), 
          "  ", "=", "  ", 
          RowBox[{
            RowBox[{"(", 
              RowBox[{"1", " ", "-", " ", 
                SubsuperscriptBox["r", 
                  StyleBox["ij",
                    FontSlant->"Italic"], 
                  StyleBox["f",
                    FontSlant->"Plain"]]}], ")"}], "/", "2"}]}], 
        TraditionalForm]]],
  "\n\t\t",
  Cell[BoxData[
      \(TraditionalForm\`t\_\(\(i\_fm\) k\_fm \[LeftArrow] \ \(i\_mf\) \
k\_mf\)\ \  = \ \ 1/2\)]]
}], "Text",
  CellFrame->True,
  CellMargins->{{18, 24.375}, {Inherited, Inherited}},
  Background->GrayLevel[1]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Table 3.  Measures of association (linkage disequilibrium)", \
"Subsection",
  CellMargins->{{18.1875, 24.375}, {Inherited, Inherited}},
  PageBreakAbove->True,
  CellTags->"Measures of D"],

Cell[TextData[Cell[BoxData[
    StyleBox[GridBox[{
          {
            StyleBox["Symbol",
              TextAlignment->Left,
              FontWeight->"Bold",
              FontSlant->"Plain",
              FontTracking->"Plain",
              FontVariations->{"Underline"->False,
              "Outline"->False,
              "Shadow"->False,
              "StrikeThrough"->False,
              "Masked"->False,
              "CompatibilityType"->0,
              "RotationAngle"->0}], 
            StyleBox["Definition",
              TextAlignment->Left,
              FontWeight->"Bold",
              FontSlant->"Plain",
              FontTracking->"Plain",
              FontVariations->{"Underline"->False,
              "Outline"->False,
              "Shadow"->False,
              "StrikeThrough"->False,
              "Masked"->False,
              "CompatibilityType"->0,
              "RotationAngle"->0}], 
            StyleBox[
              RowBox[{
                StyleBox["Comments",
                  TextAlignment->Left,
                  FontWeight->"Bold"], "\[IndentingNewLine]"}],
              FontWeight->"Plain",
              FontSlant->"Plain",
              FontTracking->"Plain",
              FontVariations->{"Underline"->False,
              "Outline"->False,
              "Shadow"->False,
              "StrikeThrough"->False,
              "Masked"->False,
              "CompatibilityType"->0,
              "RotationAngle"->0}], 
            StyleBox["Notes",
              FontWeight->"Plain",
              FontSlant->"Plain",
              FontTracking->"Plain",
              FontVariations->{"Underline"->False,
              "Outline"->False,
              "Shadow"->False,
              "StrikeThrough"->False,
              "Masked"->False,
              "CompatibilityType"->0,
              "RotationAngle"->0}], 
            StyleBox["Reference",
              TextAlignment->Left,
              FontWeight->"Plain",
              FontSlant->"Plain",
              FontTracking->"Plain",
              FontVariations->{"Underline"->False,
              "Outline"->False,
              "Shadow"->False,
              "StrikeThrough"->False,
              "Masked"->False,
              "CompatibilityType"->0,
              "RotationAngle"->0}]},
          {
            StyleBox[
              SubscriptBox[
                StyleBox["D",
                  FontSlant->"Italic"], "\[DoubleStruckCapitalU]"],
              TextAlignment->Left], 
            RowBox[{
              SubscriptBox[
                StyleBox["E",
                  TextAlignment->Left,
                  FontSlant->"Italic"], 
                StyleBox["X",
                  FontWeight->"Bold",
                  FontSlant->"Italic"]], "[", 
              
              RowBox[{\(\[Product]\+\(\[DoubleStruckI] \[Element] \
\[DoubleStruckCapitalU]\)\), 
                RowBox[{"(", 
                  RowBox[{
                    SubscriptBox[
                      StyleBox["X",
                        FontSlant->"Italic"], "\[DoubleStruckI]"], 
                    "-", \(\[WeierstrassP]\_\[DoubleStruckI]\)}], ")"}]}], 
              "]"}], 
            StyleBox[\(defined\ in\ this\ paper\),
              TextAlignment->Left], " ", 
            StyleBox[\(this\ paper\),
              TextAlignment->Left]},
          {
            StyleBox[
              SubsuperscriptBox["\[CapitalDelta]", 
                SubscriptBox[
                  StyleBox["X",
                    FontWeight->"Bold"], "U"], \((S)\)],
              TextAlignment->Left], 
            RowBox[{
              StyleBox["equivalent",
                TextAlignment->Left], 
              StyleBox[" ",
                TextAlignment->Left], 
              StyleBox["to",
                TextAlignment->Left], 
              StyleBox[" ",
                TextAlignment->Left], 
              SubscriptBox[
                StyleBox["D",
                  TextAlignment->Left,
                  FontSlant->"Italic"], "\[DoubleStruckCapitalU]"]}], 
            StyleBox[\(defined\ by\ Slatkin\ \((1972)\)\),
              TextAlignment->Left], " ", 
            StyleBox[\(Slatkin\ 1972, \ Nagylaki\ 1993\),
              TextAlignment->Left]},
          {
            RowBox[{
              SubscriptBox[
                StyleBox["D",
                  FontSlant->"Italic"], "U"], "or", " ", 
              StyleBox[
                SubsuperscriptBox["\[CapitalDelta]", 
                  SubscriptBox[
                    StyleBox["X",
                      FontWeight->"Bold"], "U"], \((U)\)],
                
                TextAlignment->
                  Left]}], \(\[Sum]\+\(V \[SubsetEqual] U\)\(\(\((\(-1\))\)\^\
\(\(|\)\(U\\V\)\(|\)\)\) \(p\_\(U\\V\)\) \(E[
                  X\_V]\)\(\ \)\)\), \(two\ alleles\ at\ each\ locus; \ 
            X\_i = 0\ or\ 1\[IndentingNewLine]
            
            E[X\_V]\ is\ the\ marginal\ frequency\ of\ gametes\ with\ ' 
              1'\ alleles\ at\ loci\ in\ V\), \(\(\ \)\(2\)\), \(Slatkin\ \
1972, \ Nagylaki\ \ 1993\[IndentingNewLine]
            Christiansen\ 1999\ Eq . \ 2.4  .1\)},
          {
            SubscriptBox["\[Theta]", 
              StyleBox["X",
                FontWeight->"Bold"]], 
            RowBox[{
              RowBox[{"f", 
                RowBox[{"(", 
                  StyleBox["X",
                    FontWeight->"Bold"], ")"}]}], "-", 
              RowBox[{\(f\&~\), 
                RowBox[{"(", 
                  StyleBox["X",
                    FontWeight->"Bold"], ")"}]}]}], 
            RowBox[{
              RowBox[{
              "deviation", " ", "of", " ", "gamete", " ", "frequency", " ", 
                "f", 
                RowBox[{"(", 
                  StyleBox["X",
                    FontWeight->"Bold"], ")"}], " ", "from", " ", "that", " ",
                 "at", " ", "LE"}], ",", " ", 
              RowBox[{\(f\&~\), 
                RowBox[{"(", 
                  StyleBox["X",
                    FontWeight->"Bold"], ")"}]}]}], "1", 
            StyleBox[\(Burger\ 2000\ p . \ 83\),
              TextAlignment->Left]},
          {
            StyleBox[
              SubsuperscriptBox["\[Theta]", 
                SubscriptBox[
                  StyleBox["X",
                    FontWeight->"Bold"], "U"], \((U)\)],
              TextAlignment->Left], 
            RowBox[{
              RowBox[{
                SubscriptBox[
                  StyleBox["f",
                    TextAlignment->Left], "U"], 
                RowBox[{
                  StyleBox["(",
                    TextAlignment->Left], 
                  SubscriptBox[
                    StyleBox["X",
                      TextAlignment->Left,
                      FontWeight->"Bold"], "U"], 
                  StyleBox[")",
                    TextAlignment->Left]}]}], 
              StyleBox["-",
                TextAlignment->Left], 
              RowBox[{
                SubscriptBox[
                  StyleBox[\(f\&~\),
                    TextAlignment->Left], "U"], 
                RowBox[{
                  StyleBox["(",
                    TextAlignment->Left], 
                  SubscriptBox[
                    StyleBox["X",
                      TextAlignment->Left,
                      FontWeight->"Bold"], "U"], 
                  StyleBox[")",
                    TextAlignment->Left]}]}]}], 
            
            StyleBox[\(deviation\ of\ marginal\ frequencies, \ 
              restricted\ to\ the\ set\ of\ loci\ S\),
              TextAlignment->Left], "2", 
            StyleBox[\(Burger\ 2000\ p . \ 82\),
              TextAlignment->Left]},
          {
            StyleBox[
              SubscriptBox["\[CapitalTheta]", 
                StyleBox["X",
                  TextAlignment->Left,
                  FontWeight->"Bold"]],
              TextAlignment->Left], 
            RowBox[{
              StyleBox[\(1\/W\&_\),
                TextAlignment->Left], 
              RowBox[{
                StyleBox[
                  UnderscriptBox["\[Sum]", 
                    StyleBox["Y",
                      FontWeight->"Bold"]],
                  TextAlignment->Left], 
                RowBox[{
                  StyleBox["W",
                    TextAlignment->Left], 
                  RowBox[{
                    StyleBox["(",
                      TextAlignment->Left], 
                    RowBox[{
                      StyleBox["X",
                        TextAlignment->Left,
                        FontWeight->"Bold"], 
                      StyleBox[",",
                        TextAlignment->Left], 
                      StyleBox["Y",
                        TextAlignment->Left,
                        FontWeight->"Bold"]}], 
                    StyleBox[")",
                      TextAlignment->Left]}], 
                  RowBox[{
                    StyleBox[\(\[Sum]\+\(I \[SubsetEqual] G\)\),
                      TextAlignment->Left], 
                    RowBox[{
                      StyleBox[\(r\_I\),
                        TextAlignment->Left], 
                      RowBox[{
                        StyleBox["(",
                          TextAlignment->Left], 
                        RowBox[{
                          RowBox[{
                            StyleBox["f",
                              TextAlignment->Left], 
                            RowBox[{
                              StyleBox["(",
                                TextAlignment->Left], 
                              StyleBox["X",
                                TextAlignment->Left,
                                FontWeight->"Bold"], 
                              StyleBox[")",
                                TextAlignment->Left]}], 
                            StyleBox["f",
                              TextAlignment->Left], 
                            RowBox[{
                              StyleBox["(",
                                TextAlignment->Left], 
                              StyleBox["Y",
                                TextAlignment->Left,
                                FontWeight->"Bold"], 
                              StyleBox[")",
                                TextAlignment->Left]}]}], 
                          StyleBox["-",
                            TextAlignment->Left], 
                          RowBox[{
                            StyleBox["f",
                              TextAlignment->Left], 
                            RowBox[{
                              StyleBox["(",
                                TextAlignment->Left], 
                              RowBox[{
                                SubscriptBox[
                                  StyleBox["X",
                                    TextAlignment->Left,
                                    FontWeight->"Bold"], "I"], 
                                SubscriptBox[
                                  StyleBox["Y",
                                    TextAlignment->Left,
                                    FontWeight->"Bold"], \(G\\I\)]}], ")"}], 
                            "f", 
                            RowBox[{"(", 
                              RowBox[{
                                SubscriptBox[
                                  StyleBox["X",
                                    TextAlignment->Left,
                                    FontWeight->"Bold"], \(G\\I\)], 
                                SubscriptBox[
                                  StyleBox["Y",
                                    TextAlignment->Left,
                                    FontWeight->"Bold"], "I"]}], ")"}]}]}], 
                        StyleBox[")",
                          TextAlignment->Left]}]}]}]}]}]}], 
            RowBox[{
              RowBox[{"where", " ", 
                StyleBox["W",
                  TextAlignment->Left], 
                RowBox[{
                  StyleBox["(",
                    TextAlignment->Left], 
                  RowBox[{
                    StyleBox["X",
                      TextAlignment->Left,
                      FontWeight->"Bold"], 
                    StyleBox[",",
                      TextAlignment->Left], 
                    StyleBox["Y",
                      TextAlignment->Left,
                      FontWeight->"Bold"]}], 
                  StyleBox[")",
                    TextAlignment->Left]}], " ", "is", " ", "the", " ", 
                "fitness", " ", "of", " ", "a", " ", "diploid", " ", "with", 
                " ", "genomes", " ", 
                RowBox[{"{", 
                  RowBox[{
                    StyleBox["X",
                      TextAlignment->Left,
                      FontWeight->"Bold"], 
                    StyleBox[",",
                      TextAlignment->Left], 
                    StyleBox["Y",
                      TextAlignment->Left,
                      FontWeight->"Bold"]}], "}"}]}], "\[IndentingNewLine]", 
              RowBox[{\(G\ is\ the\ set\ of\ all\ loci\), 
                StyleBox[";",
                  TextAlignment->Left], 
                StyleBox[" ",
                  TextAlignment->Left], 
                
                StyleBox[\(assumes\ random\ mating\ and\ no\ position\ \
effects\),
                  TextAlignment->Left]}], "\[IndentingNewLine]", 
              RowBox[{
                RowBox[{
                "Under", " ", "selection", " ", "and", " ", "recombination", 
                  " ", \(f'\), 
                  RowBox[{"(", 
                    StyleBox["X",
                      TextAlignment->Left,
                      FontWeight->"Bold"], ")"}]}], "=", 
                RowBox[{
                  RowBox[{"f", 
                    RowBox[{"(", 
                      StyleBox["X",
                        TextAlignment->Left,
                        FontWeight->"Bold"], ")"}], 
                    FractionBox[
                      RowBox[{"W", 
                        RowBox[{"(", 
                          StyleBox["X",
                            TextAlignment->Left,
                            FontWeight->"Bold"], ")"}]}], \(W\&_\)]}], "-", 
                  SubscriptBox["\[CapitalTheta]", 
                    StyleBox["X",
                      TextAlignment->Left,
                      FontWeight->"Bold"]]}]}]}], " ", 
            RowBox[{
              StyleBox[\(Nagylaki, \ 1993\),
                TextAlignment->Left], 
              "\[IndentingNewLine]", \(Burger\ 2000, \ p . \ 56\)}]},
          {
            StyleBox[
              SubsuperscriptBox["\[CapitalTheta]", 
                SubscriptBox[
                  StyleBox["X",
                    TextAlignment->Left,
                    FontWeight->"Bold"], "U"], \((U)\)],
              TextAlignment->Left], 
            RowBox[{
              UnderscriptBox[
                StyleBox["\[Sum]",
                  TextAlignment->Left], 
                SubscriptBox[
                  StyleBox["X",
                    FontWeight->"Bold"], \(G\\U\)]], 
              StyleBox[
                SubscriptBox["\[CapitalTheta]", 
                  StyleBox["X",
                    TextAlignment->Left,
                    FontWeight->"Bold"]],
                TextAlignment->Left]}], 
            RowBox[{
              StyleBox["marginal",
                TextAlignment->Left], 
              StyleBox[" ",
                TextAlignment->Left], 
              StyleBox["version",
                TextAlignment->Left], 
              StyleBox[" ",
                TextAlignment->Left], 
              StyleBox["of",
                TextAlignment->Left], 
              StyleBox[" ",
                TextAlignment->Left], 
              SubscriptBox["\[CapitalTheta]", 
                StyleBox["X",
                  TextAlignment->Left,
                  FontWeight->"Bold"]]}], " ", 
            StyleBox[\(Burger\ 2000\ p  .71\),
              TextAlignment->Left]},
          {
            StyleBox[
              RowBox[{"L", 
                RowBox[{"(", 
                  SubscriptBox[
                    StyleBox["X",
                      TextAlignment->Left,
                      FontWeight->"Bold"], "U"], ")"}]}],
              TextAlignment->Left], 
            RowBox[{
              RowBox[{
                StyleBox[\(L'\),
                  TextAlignment->Left], 
                RowBox[{
                  StyleBox["(",
                    TextAlignment->Left], 
                  SubscriptBox[
                    StyleBox["X",
                      TextAlignment->Left,
                      FontWeight->"Bold"], "U"], ")"}]}], "=", 
              RowBox[{"L", 
                RowBox[{"(", 
                  SubscriptBox[
                    StyleBox["X",
                      FontWeight->"Bold"], "U"], ")"}], \((1 - r\_U)\)}]}], 
            
            StyleBox[\(principal\ component; \ 
              decays\ geometrically\ \ for\ every\ set\ of\ loci\),
              TextAlignment->Left], " ", 
            StyleBox[\(Bennett\ 1954\),
              TextAlignment->Left]},
          {
            StyleBox["??",
              TextAlignment->Left], 
            StyleBox["??",
              TextAlignment->Left], 
            
            StyleBox[\(decay\ geometrically\ under\ weak\ mutation\ and\ \
recombination\),
              TextAlignment->Left], " ", 
            StyleBox[\(Baake\ 2000\),
              TextAlignment->Left]},
          {
            RowBox[{
              StyleBox[\(c\_U\),
                TextAlignment->Left], " ", "or", " ", \(\[Kappa]\_U\)}], " ", 
            
            RowBox[{
              StyleBox[\(cumulant\ measure\),
                TextAlignment->Left], 
              StyleBox[",",
                TextAlignment->Left], 
              StyleBox[" ",
                TextAlignment->Left], 
              RowBox[{
                StyleBox["corresponding",
                  TextAlignment->Left], 
                StyleBox[" ",
                  TextAlignment->Left], 
                StyleBox["to",
                  TextAlignment->Left], 
                StyleBox[" ",
                  TextAlignment->Left], 
                StyleBox["moments",
                  TextAlignment->Left], 
                StyleBox[" ",
                  TextAlignment->Left], 
                SubscriptBox[
                  StyleBox["D",
                    TextAlignment->Left], "U"]}]}], " ", 
            StyleBox[\(Burger\ 2000, Turelli\ and\ Barton\ 1994\),
              TextAlignment->Left]}
          },
        GridFrame->True],
      FontFamily->"Times"]]]], "Text",
  CellMargins->{{18.1875, 24.375}, {Inherited, Inherited}},
  GridBoxOptions->{ColumnAlignments->{Left}}],

Cell[TextData[{
  "Notes\n1.  Gametes are denoted by the vector ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          StyleBox["X",
            FontWeight->"Bold"], "=", \({X\_1, \[Ellipsis]}\)}], 
        TraditionalForm]]],
  ", rather than by Burger's (2000) 'multi-index' of integers, i={0,1,3,\
\[Ellipsis]} indicating which allele is present at each locus.\n2.  ",
  Cell[BoxData[
      \(TraditionalForm\`X\_S\)]],
  " indicates the subset of allelic states for the set of loci S; corresponds \
to Burger's (2000) 'multi-index' ",
  Cell[BoxData[
      \(TraditionalForm\`i\_S\)]],
  "."
}], "Text",
  CellMargins->{{18.1875, 24.375}, {Inherited, Inherited}}]
}, Open  ]],

Cell[CellGroupData[{

Cell["Table 4.  Fitnesses for the two-locus example", "Subsection",
  CellMargins->{{17.75, 24}, {Inherited, Inherited}}],

Cell[TextData[{
  "\n\t\t\t\t     ",
  StyleBox["Maternal genome",
    FontVariations->{"Underline"->True}],
  "\n\t\t",
  StyleBox["0 0\t\t0 1\t\t\t1 0\t\t\t11",
    FontVariations->{"Underline"->True}],
  "\n\n\t0 0:\t1\t\t1 + ",
  Cell[BoxData[
      \(TraditionalForm\`s\_j\)]],
  "\t\t\t1 + ",
  Cell[BoxData[
      \(TraditionalForm\`s\_i\)]],
  "\t\t\t1 + ",
  Cell[BoxData[
      \(TraditionalForm\`s\_i\)]],
  "+ ",
  Cell[BoxData[
      \(TraditionalForm\`s\_j\)]],
  " + ",
  Cell[BoxData[
      FormBox[
        SubscriptBox["e", 
          StyleBox["ij",
            FontSlant->"Italic"]], TraditionalForm]]],
  "\nPaternal\n\t0 1:\t1 + ",
  Cell[BoxData[
      \(TraditionalForm\`s\_j\)]],
  "\t\t1 + 2 ",
  Cell[BoxData[
      \(TraditionalForm\`s\_j\)]],
  "\t\t\t1 + ",
  Cell[BoxData[
      FormBox[
        RowBox[{\(s\_i\), " ", "+", " ", \(s\_j\), " ", "+", " ", 
          SubscriptBox["e", 
            StyleBox["ij",
              FontSlant->"Italic"]]}], TraditionalForm]]],
  "\t1 + ",
  Cell[BoxData[
      FormBox[
        RowBox[{\(s\_i\), " ", "+", " ", \(2  s\_j\), " ", "+", " ", 
          RowBox[{"2", 
            SubscriptBox["e", 
              StyleBox["ij",
                FontSlant->"Italic"]]}]}], TraditionalForm]]],
  "\ngenome:\n\t1 0:\t1 + ",
  Cell[BoxData[
      \(TraditionalForm\`s\_i\)]],
  "\t\t1 + ",
  Cell[BoxData[
      FormBox[
        RowBox[{\(s\_i\), " ", "+", " ", \(s\_j\), " ", "+", " ", 
          SubscriptBox["e", 
            StyleBox["ij",
              FontSlant->"Italic"]]}], TraditionalForm]]],
  "\t1 + ",
  Cell[BoxData[
      \(TraditionalForm\`2  s\_i\)]],
  "\t\t\t1 + ",
  Cell[BoxData[
      FormBox[
        RowBox[{\(2  s\_i\), " ", "+", " ", \(s\_j\), " ", "+", " ", 
          RowBox[{"2", 
            SubscriptBox["e", 
              StyleBox["ij",
                FontSlant->"Italic"]]}]}], TraditionalForm]]],
  "\n\t\t\n\t1 1:\t1 + ",
  Cell[BoxData[
      FormBox[
        RowBox[{\(s\_i\), " ", "+", " ", \(s\_j\), " ", "+", " ", 
          SubscriptBox["e", 
            StyleBox["ij",
              FontSlant->"Italic"]]}], TraditionalForm]]],
  "  1 + ",
  Cell[BoxData[
      FormBox[
        RowBox[{\(s\_i\), " ", "+", " ", \(2  s\_j\), " ", "+", " ", 
          RowBox[{"2", 
            SubscriptBox["e", 
              StyleBox["ij",
                FontSlant->"Italic"]]}]}], TraditionalForm]]],
  "\t   1 + ",
  Cell[BoxData[
      FormBox[
        RowBox[{\(2  s\_i\), " ", "+", " ", \(s\_j\), " ", "+", " ", 
          RowBox[{"2", 
            SubscriptBox["e", 
              StyleBox["ij",
                FontSlant->"Italic"]]}]}], TraditionalForm]]],
  "\t    1 + ",
  Cell[BoxData[
      FormBox[
        RowBox[{\(2  s\_i\), " ", "+", " ", \(2  s\_j\), " ", "+", " ", 
          RowBox[{"4", 
            SubscriptBox["e", 
              StyleBox["ij",
                FontSlant->"Italic"]]}]}], TraditionalForm]]],
  "\n\t\t"
}], "Text",
  CellMargins->{{1, -11.9375}, {Inherited, Inherited}}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Figure",
  FontWeight->"Bold"]], "Subtitle",
  CellMargins->{{18.1875, 24.375}, {Inherited, Inherited}},
  PageBreakAbove->True,
  CellTags->"References"],

Cell[CellGroupData[{

Cell["Figure caption", "Subsection",
  CellMargins->{{18.1875, 24.375}, {Inherited, Inherited}}],

Cell["\<\
\tSchematic for a model of a dioecious population with four \
autosomal loci.  Open circles represent genes inherited from a female (the \
mother), and dark circles are those inherited from a male (the father).  At \
each locus there are four possible contexts for a gene (two sexes-of-origin X \
two sexes-of-carrier), giving a total of 16 positions.  Three different kinds \
of associations between pairs of positions are shown.\
\>", "Text",
  CellMargins->{{18.1875, 24.375}, {Inherited, Inherited}}]
}, Open  ]],

Cell[CellGroupData[{

Cell["Figure 1", "Subsection",
  CellMargins->{{18.1875, 24.375}, {Inherited, Inherited}}],

Cell[TextData[{
  " ",
  Cell[GraphicsData["PICT", "\<\
P6`000000EP1h`0A0_l<0?on0000B00004P000000001F07S0000002Q06@01TA1
A3Em002Q06AKP4A1A3Em0P000@00002d001JaP2BPeX0;JFg0NX3FP8@9KL00001
0000002BPeX0;JFg0NX3FP8@9KL00@0000000000000000000040000000000000
0000000100000@000000000000000000004000000000000000000001000000V@
0002K0002B@000]4000;;0002:Sooooo0000<`00030000c<0000]000CLH004ij
000=000000000000003oo`00000003<cHfeiJ`01000000000000000000000@00
000000000000000000000001000000000000000000000@000000000000000000
0040000I00006@0001T0000I0000000000000000ool00000003oof=]NF/00@00
0040000000000000000S_`0000000000000000000040002hoooooooooooooooo
0000600001P0nl3R088Nd03k`>80PQk@0?M3FP227]00md=J088Nd03g@eX0PQk@
0?1X20227]00j/=J08O3OP3Z`eX0SYk@0>[3FP2>W]00j/=J08jNd03Z`eX0][EV
0>[3FP2f]FH0j/=J0;JeIP3Z`eX0][EV0>[3FP3Nbo`0j/=J0=k;o03Z`eX0g/_l
0>[3FP3UYdl0l6P80>];o03g@eX0jd_l0?M3FP3[Bo`0md=J0>];o04:?;h0jd_l
0@Xl_P3[Bo`19F1R088Nd04K4EX0PQk@0F_Eb0227]01H922088Nd00000P00008
0JQ0X02P1W@1Z42P0:06M06X@:00SYk@0JQ0X02>W]01Z42P08jNd06X@:00SL=V
0JPZ3@2<k=L1YolO08`MF00000`0000<0CL4``3[Bo`1=`C30>];o06K`:00jd_l
0I_0X03[Bo`1Vl2P0>];o06RVo<0jd_l0JQ0X03UYdl1Z42P0=k;o06X@:00g/_l
0JQ0X03Nbo`1Z42P0<X=a@6X@:00bPg50000000000000?oo00000000001SKGU[
004000010000000000000000;:h00000000000000000000100021?oooooooooo
ooooo`0000000000003oo`0000000<c<HfeiJ`0002P0000X0@HJ<`4c@WP11QXc
0C=2N03g@eX1<d9h0?M3FP4c@WP0md=J0C=2N03`J0P1<d9h0>[3FP4hibH0j/=J
0Co2N03Z`eX1?l9h0>[3FP4o`WP0j/=J0FOI3P3Z`eX1ImT>0>[3FP5Wf@h0j/=J
0FOI3P3Z`eX1SnnT0>[3FP6?kj@0j/=J0Ho_Y03Z`eX1U/[g0?1X206LKj@0md=J
0Ia_Y03g@eX1W6nT0?M3FP6LKj@1VZDc0Ia_Y06JYC<1W6nT0IZU<`6LKj@1XH26
0Ia_Y06W9C<1U/[g0JLU<`6?kj@1YbDc0Ho_Y06W9C<1SnnT0JLU<`4o`WP1YbDc
0Co2N06W9C<1?l9h0JLU<`4hibH1XH260C=2N06JYC<1<d9h0IZU<`4c@WP1VZDc
0C=2N05V23@1<d9h0FH8=04c@WP00`0000<0000000000000000S_`0000000000
00000000004000G0oooooooooooooooo0<lL`P2fHb`0h=aR0;IS;@0100000000
0000000000000@000000000000h0001600000001000000000000000000000@00
00000?oooo;ooonj0040000000000B0000000?onh00000000000004k9=[o`9;V
00000000003ooaab00000000hhh000000000000hH?/162320040001^7QL0n5h0
07gTgP3hGP00__5L0G3J6P2b;B@1OIiB0;9lfP5no^P0/WcL0Fa@9P0100000000
0000000000000@000000000002d0000f00000001000000000000000000000@00
00000?ooom?oooo:0040000000000B0000000?onh00000000000003aN7oo<Zig
00000000003ooaab00000000hhh000000000002fPEd0eZ?o00400?n3/eD1I3l7
oh>cE@5CXk000P000080000000000000000S_`0000000000000000000Pcoo000
ooD00009@0010@00000000000@00002d0001F0000000000000P0000;00000001
0000002S:3<10nVe0:/X<`4>jKD00@000000000000000000ool00000003no1I;
0:/X<`0100000@000000000000000000ool0000000010nVe0:/X<`01003ooooo
0000O000033ooooooooooooooooooooo00000`000000002D0000]00008P0004l
0000d001000000000000000000000@0000000000000000000000000100000000
0000000000000@0000000000000000000040000000000000003oo`0000000?oo
HfeiJ`0000@000040:Lh<`4>jKD0ZbPc0@?Y]@2S:3<10nVe0:Lh<`4>jKD0000;
00`e8061Zm00000P00000000P00000040000B0000000000100000?ooool00004
ooooo`0004P00000000000000000000;0GBcZ061Zm01aFc`00000000P000000<
0000U000000000010000B?ooool0000`00000Oooool0000H0000000000400018
00000@2S:3<10nVe0:/X<`4>jKD008000000;Oooool0000X000000000600001l
ooooo`000300000`00023?ol003om@0000U0004100000000000100000;@0005H
000000000000200000/00000004000000:<X<`43jKD0ZbPc0@kY]@0100000000
0000000000000@0000000?kl5T_oG=O=00400001000000000000000000000@00
00000043jKD0XbPc00400?ooool0001l0000<?ooooooooooooooooooool00003
0000000009@0002d0000R0000C`0003@00400000000000000000000100000000
0000000000000000004000000000000000000001000000000000000000000@00
0000000000000?oo00000000oomSKGU[0000100000@0YcPc0@kY]@2[:3<10nVe
0:<X<`43jKD0YcPc0@kY]@0000/033DP0H6[d000020000000020000000@00018
0000000000400000ooooo`0000Cooooo0000B000000000000000000000/1M;>X
0H6[d075K?0000000020000000`0002D0000000000400018ooooo`0003000001
ooooo`0001P0000000000@0004P000010:<X<`43jKD0ZbPc0@kY]@00P000000]
ooooo`0002P000000000H00007cooooo0000<000030000010008N?ooool000R@
0008Z00000P000080@/25@29R2h12`8E077hXP4DJHT0GTPW0B22801NB2L1888P
05i89`4/V[L0GTPW0CH2:P1aGn/1=P8Z08S_M@01000000000000000000000@00
00000?ooonkoool:00000001000000000000000000000@00000000000180003f
00400000XT[oocX500000000aO/00:9:00000?imegT11=QV00000000XT/00<Gm
00000?oo>P<00:9;0000006nR`H0QDR00040000000P000080N37Y`3of>D1h<NW
0=lJ?@7^4SL0`kce0OlZa033_?D1ob[40<>lm@8@@e40`kce0Qf=h03NAOd27HgP
0?l4YP0000000001000030000000000000000400@01004000000000000000000
00000000000000000000000000000000CVmbKF5/000000000000000000000000
0000000000000000000000000000000000400000000000000000000000000000
00000000000000020000000000000@0200000000000000000020000000000000
0020000300801P03000000000000000006@00000000000000000000000000000
CVmbKF5/000000000000000000000000000000000000000@0004N00018P000QX
0040000<00000000005`L@00000000070000000005@000100001h4@XJFXYIVH@
00D0200000000000000000000000000000L000000040100000000P0500000004
00@0000000D01P0000002?oo00000000P02ZZPn>fU0?S^1`00005P0B0040000B
000000000000000000500001@0001P0000000000000000Uiokkon`0000000000
0000;@0T0042000T000000000000000000500001@000000000000000000000Ui
oKoon`000000000000007P0H0042000H000000000000000000500001@0001000
00000000000000UioKkon`000000000000007P0H0040000H0000000000000000
00500001@000100000000000000000Uiokkon`00000000000080600B00<0000H
ooono0000000000000500001@000100000000000000000UiokkonP0000000000
0040600B00<2000Hooono0000000000000500001@000100000000000000000Ui
oKkonP000000000000404P0>00<0000Booono0000000000000500001@0001P00
00000000000000UiokkonP00000000000040900K00<2000Tooono00000000000
00500001@000000000000000000000UioKoonP000000000002F0000K00000000
000000000000000000000000000?Nb]@000000000V0?Nf1@0@410@400@410@41
3g/>h002/214IE8c00000001ZO`000080000100000P00000000030000000004h
0000000100006`000000000000X00Ooo00000000000000000000000000000000
0000000000000000000000000000000000006P000000000000001`008000@dj0
0000000T0000000000000000004000010000700000`000000000000000000001
00000@0000000000004000000000000000000000000000000000000000000002
00H0000000000@00000000000000000000200000000000000020000300801P03
0009TMooool0000006@0000000000000000000000080000<0000000000009000
0000000000000000000000000000000000000000000000000000000000000000
0000000000000000000000000000000000000000000000000000000000000000
0000000000000000000000000000000000000000000000000000000300@00000
1TMUKVEfHCPOoHadooooo`n_[700=EYlomKl/0mL>0P?[jb0009[n0mL@6P00000
3e`LO00000400`084138o0n_[;00001h3eP?80nVj30?[jb`@P00Q?oFGK`?[jdh
3jn/`002JoPOoHS@00000@n_[=00=EYl00000@0000000`04000000I7IFiUMV4h
7of<M?ooool?[ja`03EJO?oFo;0?G3P83jn/P002JoP?G41X000000mL77`00001
00<0210@b?`?[jb`0000N0mH3b0?Y^P`3jn//48008CoeUfl3jn]>0n_[<000V_h
7of8d000004?[jc@03EJO0000040000000<010000006AfE^IGIQ>1omS7Cooooo
3jn/L00eFWcoe_b`3e`h20n_[8000V_h3ea0J000000?G1al00000@0300P@4<Sl
3jn//00007P?F0lP3jKX<0n_[;120024omIM_0n_[CP?[jc0009[n1omR=000001
3jn/d00eFW`000010000000300@000001TMUKVEfHCPOoHadooooo`n_[700=EYl
omKl/0mL>0P?[jb0009[n0mL@6P000003e`LO00000400`084138o0n_[;00001h
3eP?80nVj30?[jb`@P00Q?oFGK`?[jdh3jn/`002JoPOoHS@00000@n_[=00=EYl
00000@0000005004000000EDJFeUL`n_7of<M0mL@I0?[kQ@03EJO1mj91000001
3jnhH0mF6G`ONQ5<00000?h20000>JI701BhT0003/009Al>02E^/Pn_^@X?[kT8
3jnhP2X018GoeUfl0000000000000V_h000000000000000000000000000?dgB4
01@010000005E6U]IG<?[aomS7@?G46@3jnhD00eFW`ONR@@00000@n_^60?EQUl
7gXAC000003n0P0003VVA`0D^90000k002DO3P0UK[8?[kT:3jni20n_^80Z00B5
omIM_00000000000009[n0000000000000000000000000003m=dQ00D00@00000
1EAYKFEc3jlOoHad3ea1T0n_^500=EYl7gXT4000004?[kQP3eHIO1mj4D`00000
oP80000iYTL05;R@000>`00U7`h09Fjb3jni2Pn_^@P?[kR0:P04QOoFGK`00000
00000002JoP000000000000000000000000000oCM8@05004000000EDJFeUL`n_
7of<M0mL@I0?[kQ@03EJO1mj910000013jnhH0mF6G`ONQ5<00000?h20000>JI7
01BhT0003/009Al>02E^/Pn_^@X?[kT83jnhP2X018GoeUfl0000000000000V_h
000000000000000000000000000?dgB400000@0000P00@041TMUKVEfHOKfm_Kf
m_Kfm_Kfm_l00000000000000000000000000000000000000000000000000000
0000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000@041TMUKVEfH@00000000000@3o00000000
0000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000003om_Kfm_Kfm_Kfm_Kfm_Kfm_Kf
m_Kfm_Kfm_H00@041TMUKVEfHOKfm_Kfm_Kfm_Kfm_Kfm_Kfm_Kfm_Kfm_Kfm_Kf
m_Kfm_Kfm_Kfm_Kfm_Kfm_Kfm_Kfm_Kfm_Kfm_Kfm_Kfm_Kfm_Ko000000000000
0000000000000000000000000000000000000000000000000000000000000@04
1TMUKVEfH@000000003om_Kfm_Kfm_Kfm_Kfm_Kfm_Kfm_Kfm_Kfm_oooooom_Kf
m_Kfm_Kfm_Kfm_Kfm_Kfm_Kfm_Kfm_Kfm_Kfm_Kfm_Kfm_Kfm_Kfm_Kfm_oooooo
m_Kfm_Kfm_Kfm_Kfm_Kfm_Kfm_Kfm_Ko0000000000000@041TMUKVEfH@000000
0000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000100<
000000020000o`000000000000000@041TMUKVEfH@0000000000000000000000
000000000000000000000000000000000000000000000000000000000000ooKf
m_Kfm_Kfm_Kfm_Kfm_Kfm_Kfm_Kfm_KoooooooKfm_Kfm_Kfm_Kfm_Kfm_Kfm_Kf
m_Kfm_Kfm_H00@041TMUKVEfHOKfm_Kfm_KoooooooKfm_Kfm_Kfm_Kfm_Kfm_Kf
m_Kfm_Kfo`000000000000000000000000000000000000000000000000000000
0000000000000000000000000000000000000000ooKfm_Kfm_Kfm_Kfm_H00@04
1TMUKVEfHOl000000?ooooofm_Kfm_Kfm_Kfm_Kfm_Kfm_Kfm_Kfm_Kfm_Kfm_Kf
m_Kfm_Kfm_ooooolo?clo?ooooKfm_Kfm_Kfm_Kfm_Kfm_Kfm_Kfo`0000000000
00000000000000000000000000000000000000000000000@0004N00018P000QX
0040000<00000000005`L@00000000080000000005@000100001h4A[IVHPK6I]
00D0200000000000000000000000000000L0000000401@0000000P0600000005
00D0000000H01P0000002Ooo00000000P02ZZPn>fU0?S^1`00005P0B0040000B
000000000000000000500001@0001P0000000000000000Uiokkon`0000000000
0000;@0T0042000T000000000000000000500001@000000000000000000000Ui
oKoon`000000000000007P0H0042000H000000000000000000500001@0001000
00000000000000UioKkon`000000000000007P0H0040000H0000000000000000
00500001@000100000000000000000Uiokkon`00000000000000600B00<0000H
000000000000000000500001@000100000000000000000UiokkonP0000000000
0080600B00<2000Hooono0000000000000500001@000100000000000000000Ui
oKkonP000000000000804P0>00<0000Booono0000000000000500001@0001P00
00000000000000UiokkonP00000000000040900K00<2000Tooono00000000000
00500001@000000000000000000000UioKoonP000000000002F0000K00000000
000000000000000000000000000?Nb]@000000000V0?Nf1@0@410@400@410@41
3g/>h002/214IE8c00000001ZO`000080000100000P00000000030000000004h
0000000100006`000000000000X00Ooo00000000000000000000000000000000
0000000000000000000000000000000000008`0000000000000020018000Cle0
0000000T0000000000000000004000010000700000`000000000000000000001
00000@0000000000004000000000000000000000000000000000000000000002
00H0000000000@00000000000000000000200000000000000020000300801P03
0009TMooool0000006@0000000000000000000000080000<0000000000009000
0000000000000000000000000000000000000000000000000000000000000000
0000000000000000000000000000000000000000000000000000000000000000
0000000000000000000000000000000000000000000000000000000300@00000
1TMUKVEfHCPOoHadooooo`n_[700=EYlomKl/0mL>0P?[jb0009[n0mL@6P00000
3e`LO00000400`084138o0n_[;00001h3eP?80nVj30?[jb`@P00Q?oFGK`?[jdh
3jn/`002JoPOoHS@00000@n_[=00=EYl00000@0000000`04000000I7IFiUMV4h
7of<M?ooool?[ja`03EJO?oFo;0?G3P83jn/P002JoP?G41X000000mL77`00001
00<0210@b?`?[jb`0000N0mH3b0?Y^P`3jn//48008CoeUfl3jn]>0n_[<000V_h
7of8d000004?[jc@03EJO0000040000000<010000006AfE^IGIQ>1omS7Cooooo
3jn/L00eFWcoe_b`3e`h20n_[8000V_h3ea0J000000?G1al00000@0300P@4<Sl
3jn//00007P?F0lP3jKX<0n_[;120024omIM_0n_[CP?[jc0009[n1omR=000001
3jn/d00eFW`000010000000300@000001TMUKVEfHCPOoHadooooo`n_[700=EYl
omKl/0mL>0P?[jb0009[n0mL@6P000003e`LO00000400`084138o0n_[;00001h
3eP?80nVj30?[jb`@P00Q?oFGK`?[jdh3jn/`002JoPOoHS@00000@n_[=00=EYl
00000@0000005004000000EDJFeUL`n_7of<M0mL@I0?[kQ@03EJO1mj91000001
3jnhH0mF6G`ONQ5<00000?h20000>JI701BhT0003/009Al>02E^/Pn_^@X?[kT8
3jnhP2X018GoeUfl0000000000000V_h000000000000000000000000000?dgB4
01@010000005E6U]IG<?[aomS7@?G46@3jnhD00eFW`ONR@@00000@n_^60?EQUl
7gXAC000003n0P0003VVA`0D^90000k002DO3P0UK[8?[kT:3jni20n_^80Z00B5
omIM_00000000000009[n0000000000000000000000000003m=dQ00D00@00000
1EAYKFEc3jlOoHad3ea1T0n_^500=EYl7gXT4000004?[kQP3eHIO1mj4D`00000
oP80000iYTL05;R@000>`00U7`h09Fjb3jni2Pn_^@P?[kR0:P04QOoFGK`00000
00000002JoP000000000000000000000000000oCM8@05004000000EDJFeUL`n_
7of<M0mL@I0?[kQ@03EJO1mj910000013jnhH0mF6G`ONQ5<00000?h20000>JI7
01BhT0003/009Al>02E^/Pn_^@X?[kT83jnhP2X018GoeUfl0000000000000V_h
000000000000000000000000000?dgB400000@0000P00@041TMUKVEfH@000000
000000000000000000000000000000000?l00000000000000000000000000000
0000000000000000000000000000000000000000000000000000000000000000
000000000?ooooooooooooofm_H00@041TMUKVEfH@0000000000000000000000
000000000?ofm_Kfm_Kfm_Kfm_Kfm_Kfm_Kfm_Koo?clo?clo?clo?clo?clo?cl
o?clo?clo?clo?ofm_Kfm_Kfm_Kfm_l000000000000000000000000000000000
0000000000000@041TMUKVEfH@00000000000000000000000000000000000?Kf
m_Kfm_Kfm_Kfm_Kfo`00000000000000000000000000000000000?ofm_Kfm_Kf
m_Kfm_Kfm_Kfm_Kfm_Koo?clo?clo?clo?clo?clo?clo?clo?clo?clo?l00@04
1TMUKVEfHOl00000000000000000000000000000000000000000000000000000
000000000000003oool000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000@041TMUKVEfH@000000
0000000000000000000000000000000000000000000000000000000000000000
0000000000000000000000000000003ooooooooooooooooom_Kfm_Kfo`000000
00000000000000000000000000000@041TMUKVEfHOKfm_Kfm_Kfm_Kfm_Kfoocl
o?clo?clo?clo?clo?clo?clo?clo?clo?com_Kfm_Kfm_Kfm_Ko000000000000
0000000000000000000000000000000000000000000000000000000000000000
0000000000000@041TMUKVEfHOKfm_Kfm_Kfm_l0000000000000000000000000
00000000003om_Kfm_Kfm_Kfm_Kfm_Kfm_Kfm_Kfooclo?clo?clo?clo?clo?cl
o?clo?clo?clo?com_Kfm_Kfm_Kfm_Ko00000000000000000000000000000@04
1TMUKVEfH@00000000000000000000000000oooo000000000000000000000000
0000000000000000000000000000000000000000000000000000000000000000
000000000000o`000000000000000000000000000000000:00002P4G`QD0h<PW
0B3m4@3/ZJ`1:NT80?PcS04bQOH10fG50C[CgP4>@5P1>]?N0@i0F052Th816Cgh
0DV5[`4TfF01CjYP0C4BS@5E0IP1?NV2000040000^X000;j0002800100003000
00000001L740000000000@000000000d0000@00007QY00010080000000000000
000000000000000100000002ool0000000801P0000001@mg:O00000H01800`80
01P000000000000000000D000050000000000000000000002GWm_ooj00000000
00000@0T01/00`8002Coookl0000000000000D00005000000000000000000000
2GWm_ooj000000000000900001/00000000000000000000000000000000000mg
;60000000002H0mg=O010@410@010@410@4?MbX`00:`X4AUDS<0000000417000
00P00004000020000000000<000000000CP000000040000K0000000000002P01
ool0000000000000000000000000000000000000000000000000000000000000
000000060000000000000001000P000:0800000002@000000000000000000@00
0040000L000030000000000000000000004000010000000000000@0000000000
0000000000000000000000000000000000801P00000000010000000000000000
00000800000000000000080000<00P0600<000VAgoooo`000000I00000000000
0000000000000P0000`000000000000T00000000000000000000000000000000
0000000000000000000000000000000000000000000000000000000000000000
0000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000001@010000005E6U]IG<?[aomS7@?G46@3jnhD00e
FW`ONR@@00000@n_^60?EQUl7gXAC000003n0P0003VVA`0D^90000k002DO3P0U
K[8?[kT:3jni20n_^80Z00B5omIM_00000000000009[n0000000000000000000
000000003m=dQ00D00@000001EAYKFEc3jlOoHad3ea1T0n_^500=EYl7gXT4000
004?[kQP3eHIO1mj4D`00000oP80000iYTL05;R@000>`00U7`h09Fjb3jni2Pn_
^@P?[kR0:P04QOoFGK`0000000000002JoP000000000000000000000000000oC
M8@0000100000P0100@6AfE^IGIQ000000000000000000000000000000000000
0000000000000000000000000?ooo`0000000000000000000000000000000000
0000000000000000000000000000000000000000000000000000000000000001
00@6AfE^IGIQ0000000000000000000000000?ooo`00000000000000oooo0000
0000000000000000000000000000000000000000ooooooooooofm_Kfm_Kfm_Kf
m_Kfo`0000000000000000000000000000000000ooKfmP00010000;Z0002nP00
0R000@0000`0000000000G1a00000000004000000000=0000400001hJPP00@02
00000000000000000000000000000@0000000_oo0000000200H0000000D?MbW`
0000600B00<2000H000000000000000000500001@000000000000000000000Ui
oKoonP00000000000040900K00<2000Tooono0000000000000500001@0000000
00000000000000UioKoonP000000000002@0000K000000000000000000000000
00000000000?MbaP000000000V0?McG`0@410@400@410@413gLZ<002/:14IE8c
000000010A`000080000100000P00000000030000000004h0000000100006`00
0000000000X00Ooo000000000000000000000000000000000000000000000000
000000000000000000001P000000000000000@0080002P200000000T00000000
00000000004000010000700000`00000000000000000000100000@0000000000
00400000000000000000000000000000000000000000000200H0000000000@00
000000000000000000200000000000000020000300801P030009TMooool00000
06@0000000000000000000000080000<00000000000090000000000000000000
0000000000000000000000000000000000000000000000000000000000000000
0000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000D00@000001EAYKFEc3jlOoHad
3ea1T0n_^500=EYl7gXT4000004?[kQP3eHIO1mj4D`00000oP80000iYTL05;R@
000>`00U7`h09Fjb3jni2Pn_^@P?[kR0:P04QOoFGK`0000000000002JoP00000
0000000000000000000000oCM8@05004000000EDJFeUL`n_7of<M0mL@I0?[kQ@
03EJO1mj910000013jnhH0mF6G`ONQ5<00000?h20000>JI701BhT0003/009Al>
02E^/Pn_^@X?[kT83jnhP2X018GoeUfl0000000000000V_h0000000000000000
00000000000?dgB400000@0000800@041TMUKVEfH@0000000000000000000000
00000000000000000000m_Kfm_Kfm_Kfm_Kfm_Kfm_l000000000000000000000
0000003om_Kfm_Kfm_Kfm_Kfm_Kfm_Kfm_Kfm_Kfm_Kfm_olo?clo?clo?clo?cl
o?clo?clo?`00@041TMUKVEfHOKfm_Kfo`000000000000000000000000000000
00000000000000000?ooool00000000000000000000000000000000000000000
m_Kfm_Kfm_Kfm_Kfm_Kfm_Ko000000000000000000000000003om_Kfm_H0000@
0002jP000_X0008P0040000<00000000005`L@00000000010000000003@00010
0000N6]d00400P000000000000000000000000000040000000;oo`0000000P06
000000053gLYl00001P04P030P0060000000000000000001@0000D0000000000
000000000009NOfoooX000000000000102@06`030P009?ooo_`0000000000001
@0000D0000000000000000000009NOfoooX000000000000T00006`0000000000
0000000000000000000000003gL/H0000000009P3gLel0410@4100410@410@mg
:S000[2PA6EB<`0000000@4L0000200000@000080000000000`000000001>000
00000@0001/000000000000:007oo`0000000000000000000000000000000000
0000000000000000000000000000000000H00000000000000040020000ojP000
00009000000000000000000100000@0001`0000<000000000000000000000@00
0040000000000001000000000000000000000000000000000000000000000P06
00000000004000000000000000000000P000000000000000P0000`0200H00`00
2I7Ooooo0000001T000000000000000000000002000030000000000002@00000
0000000000000000000000000000000000000000000000000000000000000000
0000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000005004000000ED
JFeUL`n_7of<M0mL@I0?[kQ@03EJO1mj910000013jnhH0mF6G`ONQ5<00000?h2
0000>JI701BhT0003/009Al>02E^/Pn_^@X?[kT83jnhP2X018GoeUfl00000000
00000V_h000000000000000000000000000?dgB401@010000005E6U]IG<?[aom
S7@?G46@3jnhD00eFW`ONR@@00000@n_^60?EQUl7gXAC000003n0P0003VVA`0D
^90000k002DO3P0UK[8?[kT:3jni20n_^80Z00B5omIM_00000000000009[n000
0000000000000000000000003m=dQ00000400002004010I7IFiUMV400000003o
ool00000000000000000000000000000003fm_Kfm_Kfm_Kfm_Kfm_Kfm_Kfm_Kf
m_oooooooooom_Kfm_Kfm_Kfm_Kfm_Kfm_Kfm_Kfm_Kfm_Kfm_Kfm_Kfm_Kfm_Kf
m_Kfm_Kfoooooooom_Kfm_Kf004010I7IFiUMV7fm_Kfm_Ko0000000000000000
0000000000000000000000000000000000000000oooo003oool0000000000000
0000000000000000000000000000000000000000000000000000000000000000
00000000000040000^X000;j000280010000300000000001L740000000000@00
0000000d0000@00007Q/50010080000000000000000000000000000100000002
ool0000000801P0000001@mg:O00000H01800`8001P000000000000000000D00
0050000000000000000000002GWm_ooj0000000000000@0T01/00`8002Coookl
0000000000000D000050000000000000000000002GWm_ooj0000000000009000
01/00000000000000000000000000000000000mg;60000000002H0mg=O010@41
0@010@410@4?MbX`00:`X4AUDS<000000041700000P00004000020000000000<
000000000CP000000040000K0000000000002P01ool000000000000000000000
0000000000000000000000000000000000000000000000060000000000000001
000P000:0800000002@000000000000000000@000040000L0000300000000000
00000000004000010000000000000@0000000000000000000000000000000000
0000000000801P00000000010000000000000000000008000000000000000800
00<00P0600<000VAgoooo`000000I000000000000000000000000P0000`00000
0000000T00000000000000000000000000000000000000000000000000000000
0000000000000000000000000000000000000000000000000000000000000000
0000000000000000000000000000000000000000000000000000000000000000
01@010000005E6U]IG<?[aomS7@?G46@3jnhD00eFW`ONR@@00000@n_^60?EQUl
7gXAC000003n0P0003VVA`0D^90000k002DO3P0UK[8?[kT:3jni20n_^80Z00B5
omIM_00000000000009[n0000000000000000000000000003m=dQ00D00@00000
1EAYKFEc3jlOoHad3ea1T0n_^500=EYl7gXT4000004?[kQP3eHIO1mj4D`00000
oP80000iYTL05;R@000>`00U7`h09Fjb3jni2Pn_^@P?[kR0:P04QOoFGK`00000
00000002JoP000000000000000000000000000oCM8@0000100000P0100@6AfE^
IGIQ000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000003o
00000000000000000000000000000?ooo`00000100@6AfE^IGIQ000000000?oo
000000000?oo00000000ool00000003oo`00ool00000ooofm_Kfm_Kfm_Kfm_Kf
m_Kfm_Kfm_Kfm_Kfm_Kfm_Kfm_Kfm_Kfm_Kfm_Kfm_Kfm_Kfm_Kfm_Kfm_Kfm_Kf
m_Kfm_Kfm_Kfm_Kfm_KfmP00010000:b0002`P000A@00@0000`0000000000G1a
0000000000D000000000=0000400000lC6mSMG<000400@000000000000000000
000000000000000000Koo`00oolP06BH00000>0Z3glmL00101h0600110006?oo
o_`0000000000001@0000D0000000000000000000009NO^ooo/000000000000O
jg006000000000000000000000000000000000003gln00000000009P3gm60000
000?G2jddZ`000mo?6000[0@A6EB<`0000000@4L0000200000@0000800000000
00`000000001>00000000@0001P000000000000:007oo`000000000000000000
00000000000000000000000000000000000000000000000000T0000000000000
00D00?0F04?M000000009000000000000000000100000@0001`0000<00000000
0000000000000@00004000000000000100000000000000000000000000000000
0000000000000P0600000000004000000000000000000000P000000000000000
P0000`0200H00`002I7Ooooo0000001T00000000000000000000000200003000
0000000002@00000000000000000000000000000000000000000000000000000
0000000000000000000000000000000000000000000000000000000000000000
0000000000000000000000000000000000000000000000000000000000000000
00000`04000000I7IFiUMV4h7of<M?ooool?[ja`03EJO?oFo;0?G3P83jn/P002
JoP?G41X000000mL77`0000100<0210@b?`?[jb`0000N0mH3b0?Y^P`3jn//480
08CoeUfl3jn]>0n_[<000V_h7of8d000004?[jc@03EJO0000040000000000@00
00400@041TMUKVEfH@0000000000000000000000000000000000000000000000
0000000000000000000000000000000000000000000000000000000000000000
000000000000000@00000@03000000000?l00000000000000000080000200000
00000000000S_`000000000000000000004000//oooooooooooooooo00002000
00P14=U/0E/g2`4Do;T1F:c<0AO5O@5D6`h15lEm0Dk`304GaGd1C_0<0AO5O@58
1iP14/_a0D8`o@4<@iD1@=Ki00004000010134>E0D3Fn@4;E:`1@:F90@YMX050
Rh`12F3m0D2;S049H?d1@8^<0@5ki`50Rh`0n_an0DL:m@3jo7h1C_0<0?[lOP5>
l0`0n_an0EKE8P41NnL1GEB;0@UPo@5ME8/12F3m0EeDR`4<6a81GEB;0@jZN`5L
SQ`146aE0E]j000000`0000<0Cd2l053FEd1>XCk0D59k`4gECL1@0^<0C?Po@50
2h`1<n3m0D0;S04[nnL1@0^<0BElOP56R_D19Gan0Di`304UO7h1CW0<0BElOP5F
EB81:o_W0EcDR`4ch?d1G=B;0000200000P1<n3m0EcDR`4kaQ@1G=B;0D95O@5F
EB81@TEm0Di`3052AGd1CW0<0D95O@59obl1@3L]0DGoOP4mIIL1@j[/00004000
17P000B80008J0010000300000000001L7400000000020000000001D0000@000
0N14JFI]86]]IP0500P000000000000000000000000000070000000100D00000
00801P0000001@050000000600H0000000Woo`0000000800ZZX?S]Y@3hkPL000
01H04P0100004P000000000000000001@0000D0000H00000000000000009NOnn
oo/000000000000002d090010P0090000000000000000001@0000D0000000000
000000000009NOfooo/000000000000001h060010P0060000000000000000001
@0000D0000@00000000000000009NOfnoo/000000000000001h0600100006000
0000000000000001@0000D0000@00000000000000009NOnnoo/0000000000000
01P04P03000060000000000000000001@0000D0000@00000000000000009NOnn
ooX000000000000201P04P030P006?ooo_`0000000000001@0000D0000@00000
000000000009NOfnooX000000000000201803P0300004_ooo_`0000000000001
@0000D0000H00000000000000009NOnnooX000000000000102@06`030P009?oo
o_`0000000000001@0000D0000000000000000000009NOfoooX000000000000U
P0006`00000000000000000000000000000000003g/[D0000000009P3g]PD041
0@4100410@410@mk3^000P0dA6EB<`0000000@000000200000@0000800000000
00`000000001>00000000@0001/000000000000:007oo`000000000000000000
00000000000000000000000000000000000000000000000002P0000000000000
00P00B0005O?000000009000000000000000000100000@0001`0000<00000000
0000000000000@00004000000000000100000000000000000000000000000000
0000000000000P0600000000004000000000000000000000P000000000000000
P0000`0200H00`002I7Ooooo0000001T00000000000000000000000200003000
0000000002@00000000000000000000000000000000000000000000000000000
0000000000000000000000000000000000000000000000000000000000000000
0000000000000000000000000000000000000000000000000000000000000000
00000`04000000I7IFiUMV4h7of<M?ooool?[ja`03EJO?oFo;0?G3P83jn/P002
JoP?G41X000000mL77`0000100<0210@b?`?[jb`0000N0mH3b0?Y^P`3jn//480
08CoeUfl3jn]>0n_[<000V_h7of8d000004?[jc@03EJO0000040000000<01000
0006AfE^IGIQ>1omS7Cooooo3jn/L00eFWcoe_b`3e`h20n_[8000V_h3ea0J000
000?G1al00000@0300P@4<Sl3jn//00007P?F0lP3jKX<0n_[;120024omIM_0n_
[CP?[jc0009[n1omR=0000013jn/d00eFW`000010000000300@000001TMUKVEf
HCPOoHadooooo`n_[700=EYlomKl/0mL>0P?[jb0009[n0mL@6P000003e`LO000
00400`084138o0n_[;00001h3eP?80nVj30?[jb`@P00Q?oFGK`?[jdh3jn/`002
JoPOoHS@00000@n_[=00=EYl00000@0000000`04000000I7IFiUMV4h7of<M?oo
ool?[ja`03EJO?oFo;0?G3P83jn/P002JoP?G41X000000mL77`0000100<0210@
b?`?[jb`0000N0mH3b0?Y^P`3jn//48008CoeUfl3jn]>0n_[<000V_h7of8d000
004?[jc@03EJO0000040000001@010000005E6U]IG<?[aomS7@?G46@3jnhD00e
FW`ONR@@00000@n_^60?EQUl7gXAC000003n0P0003VVA`0D^90000k002DO3P0U
K[8?[kT:3jni20n_^80Z00B5omIM_00000000000009[n0000000000000000000
000000003m=dQ00D00@000001EAYKFEc3jlOoHad3ea1T0n_^500=EYl7gXT4000
004?[kQP3eHIO1mj4D`00000oP80000iYTL05;R@000>`00U7`h09Fjb3jni2Pn_
^@P?[kR0:P04QOoFGK`0000000000002JoP000000000000000000000000000oC
M8@05004000000EDJFeUL`n_7of<M0mL@I0?[kQ@03EJO1mj910000013jnhH0mF
6G`ONQ5<00000?h20000>JI701BhT0003/009Al>02E^/Pn_^@X?[kT83jnhP2X0
18GoeUfl0000000000000V_h000000000000000000000000000?dgB401@01000
0005E6U]IG<?[aomS7@?G46@3jnhD00eFW`ONR@@00000@n_^60?EQUl7gXAC000
003n0P0003VVA`0D^90000k002DO3P0UK[8?[kT:3jni20n_^80Z00B5omIM_000
00000000009[n0000000000000000000000000003m=dQ00000400008004010I7
IFiUMV4000000000000000000000003fm_Kfm_Kfm_Kfm_Kfm_Kfm_l000000000
0000000000000000003om_Kfm_Kfm_Kfm_Kfm_Kfm_Kfm_Kfm_Kfm_Kfm_olo?cl
o?clo?clo?clo?clo?clo?com_Kfm_Kfm_Kfm_Kf004010I7IFiUMV4000000000
0000000000000000000000000000000000000000000000000000000000000000
00000000003fm_Kfm_Kfm_Kfm_Kfm_Kfo`000000000000000000000000000000
ooKfm_Kfm_Kfm_Kfm_Kfm_Kf004010I7IFiUMV7lo?clo?clo?clo?clo?clo?cl
o?clooKfm_Kfm_Kfm_Kfm_Ko0000000000000000000000000000000000000000
000000000000000000000000003oool000000000000000000000000000000000
00000000004010I7IFiUMV400000000000000000000000000040000000000000
0000o`0000000000000000000000000000000000000000000000000000000000
0000000000000000000000000000000000000000000000000000m_Kf004010I7
IFiUMV7fm_l000000000000000000000000000000?ofm_Kfm_Kfm_Kfm_Kfm_Kf
m_Kfm_Kfm_Kfm_olo?clo?clo?clo?clo?clo?clo?clo?ofm_Kfm_Kfm_Kfm_Kf
o`00000000000000000000000000000000000000004010I7IFiUMV4000000000
00000000000000000000000000000000m_Kfm_Kfm_Kfm_Kfm_Kfo`0000000000
00000000000000000000003om_Kfm_Kfm_Kfm_Kfm_Kfm_Kfm_Kfm_Kfooclo?cl
o?clo?clo?clo?clo?clo?cl004010I7IFiUMV7fm_Kfo`000000000000000000
00000000000000000000000000000000000000000000003oool0000000000000
0000000000000000000000000000000000000000000000000000000000000000
00000000004010I7IFiUMV400?l0000000000000000000000000000000000000
0000000000000000000000000000000000000000000000000000000000000000
000000000?Kfm_Kfm_Kfm_Kfm_Kfm_l000000000000000000000000000001@00
00D12h=J0D6e]`4=0eX1@GFg0A4CFP5K5KL13h=J0E[U]`4;PeX1@KFg00001@00
00D1<g=J0E`U]`4e@eX1G0Fg0CfCFP54mKL1?4=J0D;U]`4cLeX1G2Fg00000Ooo
ool0000H000000000040000000001?ooool00018000000000000000H0000203Z
@eX1<ak@0JO0X06LBo`008000000;@0006`000080000000006000000ooooo`00
01P0000H0000203Z`eX0PQk@0JQ0X03[Bo`0080000001@000>P0000800000000
06P00000ooooo`000040000000006000000000010000L00000?ooooo00008000
000000010000R00000;ooooo00005000000000010000Z0000080j/=J088Nd04:
?;h0jd_l0020000000H0004L0000b0000000002l0000X0000=0000090BEPHP22
7]016a5J088Nd000P00000060001D000010000000001Q0000:00003@00002@5[
eLP0PQk@0F2@PP227]00080000001P000H@0000@000000000I@0002P0000d000
0081YolO08`MF06X@:00X0Id0020000000H0006h0000B0000000006T0000X000
0=0000020CL4``3:3LD1Z42P0>];o000P00000060002=00006P000000001k000
0:00003@00000@000:00000H000000000040009D00000`000;P0000P00000000
0040009/00000P000=00000D00000000004000:<00001`3l65d0SfOT0ASQG02/
<><0080000001`000X@00000000000000Z00007/0000X0000Q`000010001k000
01P0000000000@000Z0000070?`HG@32EEL16>5L0=lNEP00P00000070002_000
000000000002^0000V`0002P0002700000L19[PT08kJ;P53PB<0Zj<]00200000
00L000;d00000000000000:h0001k0000:00008L00001`4V^2@0`LNQ0D>18`3N
T:00080000001`000b`00000000000000[P0009/0000X0000Q`000070E5Gj`2?
In@1KR3Z0:``h`00P00000070003I000000000000002^0000N`0002P00027000
00L1DEO[0<9EE`5^8>X0gaiF0020000000L000>L00000000000000:h0002K000
0:00008L00001`5kmk80SfOT0IS0/@2/<><0080000001`000m@0000000000000
0[P0007/0000X0000Q`000070G_g/P32EEL1V<2a0=lNEP00P000000700043000
000000000002^0000V`0002P000270000080j/=J0C=2N06W9C<1W6nT00200000
00H000A00001B000000000:h0000X0000=0000070?[ll05cN?l15lG_0I11oP00
P00000070004N00000000000000400000V`0002P0002700000L19Ibg0G;[B@52
IKH1SkA80020000000L000B`00000000000000@00002K0000:00008L00001`5@
?7h1@8^<0Fd5O@5ME8/0080000001`001>P00000000000001000007/0000X000
0Q`000070E0lOP5cN?l1K@Em0I11oP00P0000007000580000000000000040000
0V`0002P0002700000L1N]a50D2;S06GYD@1GEB;0020000000L000EH00000000
000000@00001k0000:00008L00001`5jg4D1LgSo0INUA06@@Oh0080000001`00
1I000000000000001000009/0000X0000Q`0000;7D=i0000000000002Y_Z^000
P00000040005l0000000000200040?ooool00003000210000200000000000@00
100000020002700001@0000000000@00120000070;834P2WL>d0cnMm0<EEF000
P000000o0006=000000000000004=0000N`0002P0005f00001P0000H00006000
00/M@gT000000000000:VnZh0020000000@000IT00000000008000@dooooo`00
00T0cac20;IS;03Pg680]V<]0020000001h000K@00004000000000@d0000X000
1MP0000H0000600000@0000H0000B000000000000004A00000@000JP0000B000
000000000004S00000T0KQhG0?QN001mi=h0n5h00020000001h000L<00004000
000000CD0000X0001MP000Jh0006X00000/M@gT000000000000:VnZh00200000
00@000Ll0000000000<000CTooooo`0000L0^cC>0EOa5@3I6CT1MMF000200000
00L000Md00000000000000CT0001k0000:0000GH00002@2nlE`1L=XJ0;8]905m
WU80080000001P001jP0000@000000001>@0002P0005f00000/M@gT000000000
000:VnZh0020000000@000OH00000000008000Cdooooo`0000T0/WcJ0Gknj02b
O=`1K50V0020000000H000Pl00004000000000Cd0000X0001MP000040006^000
04P00000000000001@@000040008300004P00000000000001D`00009oh>cE@5T
?`OoPk=E0E>S/000P000000N0008f000010000000005U0000:0000GH00089000
20`000030005`0000200000000000@001J@00005ooooo`000R@0000000000@00
1L@000050008T0000R@0000000000@001nP000020005f00001@0000000000@00
2P`000020@/25@1NB2L1=P8Z08V8;P00P00000060009?00004P00000000:8000
0:0000S00000100022@0001800000000000000YX000010002@`0001800000000
000000Z`00000P7PajL0`kce0Qf=h03of>D0080000007P002JP0001800000000
2_P0002P0008`0002B@000T<00002?ooool0001T00000EAHE20000]000002000
2GP0002X000015AHE20000^T00003P4`l>D0@Kkf0EK`i@25__H0080000001000
2MP000c`E5QD800034cooooo00003P6`L>D0G3kf0MI`i@2/?_H0080000001000
2PP000c`E5QD80006Ccooooo00000@4G`QD0h<PW0ED1V04mjH80080000001P00
2S`0001H000000009R`0002P0008`00000h0nD`U0L]V_P4MC2D1eVJn00200000
00@000Y/00056UAHE20002J4ooooo`0000h18/`T0L]V_P56c2@1eVJn00200000
00@000ZL00056UAHE20002^Nooooo`0000h1D8`S0LSV_P5dS2<1f>Jn00200000
00@000[<00056UAHE200032hooooo`0000h1O4`R0L]V_P6PC281eVJn00200000
00@000[l00056UAHE20003GBooooo`0000h0^l=J0Jl5]`3K`eX1l`Fg00200000
00@000]L0003eUAHE20003[/ooooo`0000<000Qh0000800000000001000n`P00
008000S00000500000000001000nhP0000H0T/=J02gU]`7Y`eX23nFg00200000
00H000^@00000000000003kf0000X0002d@000020@a3U@50e_T15lEm0E/g2`00
P0000005000;a00004P00000000nmP000Ncooooo00000P3jo7h1@8^<0A1/E@5M
E8/0080000001`002o`0002800000000?ch0007/0000X0000Q`000020BElOP50
2h`1?@;`0EcDR`00P0000005000<<00006P00000000oaP000Ncooooo00000P4c
h?d1@j[/0D95O@5Le8/0080000001`0036P0001800000000@2h0007/0000X000
0Q`0000>0@c`i@42O_H1<_3U0EYnmP00P0000004000<V0003?1DF5@P0010M_oo
ool000010@^3FP51MKL14A=J0E/E]`00P0000005000<c00003000000001=IP00
0Ncooooo00000@4cLeX1@^Fg0CfCFP5L9KL0080000001Oooool0000`00000000
CIH0007/ooooo`2Q06@01TA1A3Em0@0N01[Fe]OGe]H00@0:0000005H0N<0L@22
05P11@4E0Fh0F04j05P1HP1H0F80F05W05/1J`1O0Fd0I05^06@1KP480Fh1205^
0@d1K@4A0F/1505W0AD1HP4E0F815@4B0AD14P4D0@d14@490@d11P480@D12045
06@11@1T0@D0G`4605/12@1H0@d0F04B05P14P1H0CX0L@2205P0E04E0;d0F029
05P0/@1H0;40F@2f05`0^P1P0;`0I@2m06D0_@490;d12@2m0@h0_04B0;X15@2f
0AD0/@4E0;415@1Q0AD0H@4E05`14P1H0@h0E@4905@12@1D06D0E01U05@0H01E
05`0F01I05`0F01Q05P0H@1H08T06P000000000R06T0E03l02<0000S00008`00
02<1n`0S00008`?l02<0000S1?d08`0002<5o`0S00008`0002<0000S:0008`00
02<0000S00008bP002<0000S00008`0002<50@0S00008`@302<0000S0P@08`00
02<11@0S00008`0002<0000S01808P2C05@0m@0R0=T0E03e02815@1bk`008`00
02<0000S00008oh002<0000So`008P2T0;d0I@0S00008`0002<0000So`D08`00
02?n100S00008o`302<0000Sn`008`0002<0000S00008n/001[oooooool0L@1J
06T0HP2607h0N01n07d0O@2207X0Q@1e08H0L0260700Q@1Z0880IP1m06<0N01R
07P0HP1b06<0KP1V06X0JP1Y0700J@1`06X0M@1^07X0LP1m07P0OP0J00000000
0280N01no`D08`0002?m1@0S00008o/302<0000Sn`408`0002<0000S00008o[o
02<0000So?d08`0002?mn`0S00008ook02<0000S00008`0002<1nP0S00008`?l
02<0000S1?`08`0002<6o`0S00008`0002<0000S1@408`0002<5100S00008`<4
02<0000S0@H08`0001Y9BDU9BDT0L@1J06T0U0260;40N02a07d0/0220:d0Q@2X
08H0X`260:<0Q@2M0880V@1m09H0N02D07P0U01b09H0KP2I06X0W@1Y0:<0J@2S
06X0Z01^0:d0LP2`07P0/@0J000000000280N02ao`D08`0002?m1@0S00008o/3
02<0000Sn`408`0002<0000S00008o[o02<0000So?d08`0002?mn`0S00008okk
02<0000S00008`0002<2nP0S00008`?l02<0000S1?`08`0002<6o`0S00008`00
02<0000S1@408`0002<5100S00008`<402<0000S0@H08`0001[oooooool0L@1J
09@0H@2a07h0XP1n0:P0O@2]07X0/01e0;40K`2a06l0/01Z0:d0I@2X0680XP1Q
0:80H@2M0680V01U09D0JP2D06l0U01_09D0M@2H07X0W@1m0:80OP0J00000000
0280XP1no`H08`0002?m1@0S00008o/302<0000SnP408`0002<0000S00008o_o
02<0000Snod08`0002?mn`0S00008ooj02<0000S00008`0002<1n`0S00008`?k
02<0000S1Od08`0002<5o`0S00008`0002<0000S1P408`0002<50`0S00008`<5
02<0000S0@D08`0001Y9BDU9BDT0L@1J09@0U02a0;40XP2a0:P0/02]0:`0/02X
0;40XP2a0:80/02M0:d0V02X09D0XP2D0:80U02M09D0V02H09D0W@2D0:80U02R
09D0Z02H0:`0W@2`0:80/@0J000000000280XP2ao`H08`0002?l1@0S00008o`3
02<0000SnP408`0002<0000S00008o_o02<0000Snod08`0002?mn`0S00008ooj
02<0000S00008`0002<1n`0S00008`?k02<0000S1Od08`0002<5o`0S00008`00
02<0000S1P408`0002<40`0S00008`@502<0000S0@D08`0001[oooooool0L@1J
0;l0HP3K07h0c@1n0=<0O@3G07X0fP1e0=/0L03K0700fP1Z0=L0IP3C06<0c@1R
0<d0HP3706<0``1V0<00JP2o0700_`1`0<00M@3307X0a`1m0<d0OP0J00000000
0280c@1no`H08`0002?m100S00008o/302<0000Sn`408`0002<0000S00008o[o
02<0000So?d08`0002?mo00S00008ooj02<0000S00008`0002<1nP0S00008`?l
02<0000S1?d08`0002<6o`0S00008`0002<0000S1@408`0002<50`0S00008`<4
02<0000S0@H08`0001Y9BDU9BDT0L@1J0;l0U03K0;40c@2a0=<0/03G0:d0fP2X
0=/0X`3K0:<0fP2M0=L0V@3C09H0c@2D0<d0U03709H0``2I0<00W@2o0:<0_`2S
0<00Z0330:d0a`2`0<d0/@0J000000000280c@2ao`H08`0002?m100S00008o/3
02<0000Sn`408`0002<0000S00008o[o02<0000So?d08`0002?mo00S00008okj
02<0000S00008`0002<2nP0S00008`?l02<0000S1?d08`0002<6o`0S00008`00
02<0000S1@408`0002<50`0S00008`<402<0000S0@H08`0001[oooooool0L@1J
0>T0HP4607h0n01n0?d0O@4207X11@1e0@H0L04607011@1Z0@80IP3m06<0n01R
0?P0HP3b06<0k@1V0>X0JP3Y0700j@1`0>X0M@3]07X0lP1m0?P0OP0J00000000
0280n01no`D08`0002?m1@0S00008o/302<0000Sn`408`0002<0000S00008o[o
02<0000So?d08`0002?mn`0S00008ook02<0000S00008`0002<1nP0S00008`?k
02<0000S1?d08`0002<6o`0S00008`0002<0000S1@408`0002<50`0S00008`<5
02<0000S0@H08`0001Y9BDU9BDT0L@1J0>T0U0460;40n02a0?d0/0420:d11@2X
0@H0X`460:<11@2M0@80V@3m09H0n02D0?P0U03b09H0k@2I0>X0W@3Y0:<0j@2S
0>X0Z03]0:d0lP2`0?P0/@0J000000000280n02ao`D08`0002?m1@0S00008o/3
02<0000Sn`408`0002<0000S00008o[o02<0000So?d08`0002?mn`0S00008okk
02<0000S00008`0002<2nP0S00008`?k02<0000S1?d08`0002<6o`0S00008`00
02<0000S1@408`0002<50`0S00008`<502<0000S0@H08`000280L`450?808`00
02<0000S00008`7k02<0000S0o`08`0002<4o@0S00008`Go02<0000S00008`00
02<X000S00008`0002<0000S:0008`0002<0000S00008`D102<0000S10<08`00
02<3100S00008`4502<0000S00008`000241205_02<0000S00008`0002?o1@0S
00008od402<0000So0808`0002?k0@0S00008`0002<0000S/0008`0002<0000S
00008o_o02<0000So?h08`0002?mo00S00008ook02<0000S00008`0002<0b`0J
BDU9BDU90740FP1X0DH0Q@5R07L1HP1l0F40P@5N08@1FP250E@0Q@5D08@1CP21
0DX0O05707L1AP1g0DH0L@5706`1BP1Y0Dh0J05D06P1E01Y0EX0K05N0741H@1g
0F806P000000000R07L1H_l502<0000So@D08`0002?l0`0S00008oX102<0000S
00008`0002?jo`0S00008ocm02<0000SoO/08`0002?on`0S00008`0002<0000S
0OX08`0002<3n`0S00008`Cm02<0000S1_l08`0002<0000S00008`H102<0000S
10<08`0002<31@0S00008`4602<0000JBDU9BDU90740FP2C0DD0/05R0:41HP2W
0F40Z`5N0:h1F@2`0E<0/05C0:h1CP2[0DT0Y`560:41A@2Q0DD0W05609L1B@2D
0Dh0T`5C09<1D`2D0ET0U`5N09`1H@2Q0F806P000000000R0:41H_l602<0000S
o@@08`0002?k0`0S00008oX202<0000S00008`0002?koP0S00008o_m02<0000S
oO`08`0002?onP0S00008`0002<0000S0O/08`0002<3n`0S00008`Gm02<0000S
1Ol08`0002<0000S00008`H102<0000S1@<08`0002<31@0S00008`4502<0000J
oooooooo0740FP2m0A<0fP4_0<`1;`3A0Bh0eP4[0=T19`3J0B40fP4Q0=T16`3F
0AL0d@4D0<`14`3<0A<0aP4D0<815`2o0A/0_@4Q0;d18@2o0BL0`P4[0<H1;P3<
0Bl06P000000000R0<`1;ol502<0000So@D08`0002?l0`0S00008oX102<0000S
00008`0002?jo`0S00008ocm02<0000SoO/08`0002?on`0S00008`0002<0000S
0OX08`0002<3o00S00008`Cm02<0000S1_h08`0002<0000S00008`H202<0000S
10<08`0002<3100S00008`4602<0000JBDU9BDU90740FP2m0DH0fP5R0<`1HP3A
0F40eP5N0=T1FP3J0E@0fP5D0=T1CP3F0DX0d@570<`1AP3<0DH0aP570<81BP2o
0Dh0_@5D0;d1E02o0EX0`P5N0<H1H@3<0F806P000000000R0<`1H_l502<0000S
o@D08`0002?l0`0S00008oX102<0000S00008`0002?jo`0S00008ocm02<0000S
oO/08`0002?on`0S00008`0002<0000S0OX08`0002<3o00S00008`Cm02<0000S
1_h08`0002<0000S00008`H202<0000S10<08`0002<3100S00008`4602<0000J
oooooooo0740FP3X0A<11@4_0?H1;`3l0Bh10@4[0@@19`450B411@4Q0@@16`41
0AL0o04D0?H14`3f0A<0l@4D0>`15`3Y0A/0j04Q0>P18@3Y0BL0k04[0?41;P3f
0Bl06P000000000R0?H1;ol602<0000So@D08`0002?l0`0S00008oX102<0000S
00008`0002?jo`0S00008ocm02<0000SoO/08`0002?onP0S00008`0002<0000S
0O/08`0002<3n`0S00008`Cm02<0000S1_l08`0002<0000S00008`H102<0000S
10<08`0002<31@0S00008`4502<0000JBDU9BDU90740FP3X0DH11@5R0?H1HP3l
0F410@5N0@@1FP450E@11@5D0@@1CP410DX0o0570?H1AP3f0DH0l@570>`1BP3Y
0Dh0j05D0>P1E03Y0EX0k05N0?41H@3f0F806P000000000R0?H1H_l602<0000S
o@D08`0002?l0`0S00008oX102<0000S00008`0002?jo`0S00008ocm02<0000S
oO/08`0002?onP0S00008`0002<0000S0O/08`0002<3n`0S00008`Cm02<0000S
1_l08`0002<0000S00008`H102<0000S10<08`0002<31@0S00008`4502<0000J
oooooooo0740FP0O07X0?@2G02h0U`0d09H0>@2C03`0SP0m08P0?@2803`0P`0i
07h0=01k02h0NP0^07X0:01k02@0OP0P08<07`2801l0R00P08h0902C02P0UP0^
09L06P000000001a01h0;P2E03@0V@0^09H0;P2I03@0V00d09D0;P2F07409P0c
0980>P2H03D0V00e09L0>P2D03P0TP0c09D0=02H03D0V01a02H0>02=03d0U00j
09@0>P2D03d0S`0k08d0>02B03X0U00j09@0L@0V03X0R00o08l0?@2?03d0S`0o
08T0?02803X0SP0m08l0?@2?07409P0j0880?`2903l0R00o08P0?@2203X0P`0l
08T0?`2903l0R01a02H0>01m03d0Q00m0880?@2203X0O@0h07l0>`2403d0PP0m
0880L@0V03<0N@0j07l0>P1m03X0O@0e07T0<`1l03P0O`0j07d0>P1m07409P0^
07P0=@1l03D0N@0d07T0;P1h02h0N`0d07`0=@1i03D0N@1a02H0:01h02h0O00^
07P0;P1h02P0N@0Y07`0;P1k02h0N00^07P0L@0V02<0N@0Y07l0:01i02P0N@0S
07d0901o02T0O00X07T0:01i07409P0O07d09@2402<0O@0R07d07`220280Q00U
07l08`1m02<0O@1a02H07P220280R@0O08807`2201h0R00Q08T08P2301l0PP0O
0880L@0V01h0R00R08l07P2801h0R@0O08l08P2>0240R00N08P07P2807409P0O
08d09@2D01l0S`0O08l08P2D02D0TP0R08d07`2?01l0S`1a02H08P2B02T0U`0S
09@08`2D02P0U`0Y09D0902B0280U00S09@0L@0V02P0U@0^09T0:02H02P0V00^
09T0;P2F02T0U@0X09L0:02H07409P0^09D0=02I02h0V@0^09T0=02H03@0U@0^
09H0;P2I02h0V@1a01h0?02704h0RP0l08L0?02:04h0RP1>08L0?02707407P14
0800A`2A04@0T@170940A`2004@0P01409406_ooooooo`1a05X0:04Z04H1B00g
0DP0?@570481A0150Cl0AP4i04H1>@150C<0@P4^03d1:`0g0BX0=`4Z0381:`0]
0Bh0:P4c02P1>@0X0CT0:P4o02d1A00b0DL0=`5801X000000000L@0N03L1A@0m
0DT0=`5603P1B@0m0DP0?@5503L1AP1a02H0?05204<1B00n0DP0?P5804<1A@11
0D80?05603d1B00n0DP0L@0V0441?P160DD0@`5504<1A0160D00A04n0441@`13
0DD0@`5507409P140CT0B05004L1?`170Cl0B04i04D1>@140Ch0AP5004L1?`1a
02H0A04c04P1>@180CT0B04i04L1<`140C<0A@4i04P1>@180CT0L@0V0441;P17
0C@0A`4c04H1<P130Bh0@@4_04@1=0170C<0A`4c07409P0l0BX0@`4`04<1;@13
0Bd0?P4Z03`1;0110C00@`4^04<1;@1a02H0=`4Y03h1;@0n0BX0?@4Z03P1:@0g
0B`0?@4]03h1:P0n0BX0L@0V0341:@0h0Bd0=`4Y03L1:@0a0BX0<P4]03P1;00h
0BT0=`4Y07409P0/0BX0<P4`0341:P0a0BX0;04]02h1<00b0B`0<@4Z0341:P1a
02H0:04]02h1=00/0Bd0;04^02P1<P0[0C@0;P4_02`1;@0/0Bd0L@0V02L1<P0[
0CT0:04c02P1<`0W0CT0:P4i02/1<`0X0C80:04c07409P0W0CT0:`4o02L1>@0W
0CT0:04o02/1?P0Z0CT09`4i02L1>@1a02H0:04n02h1A00X0Cl0:05002`1A00^
0D<0:`4n02P1?`0X0Cl0L@0V02`1@P0b0DP0;05502`1A@0a0DP0<P5602h1@P0/
0D@0;05507409P0a0DD0>0590341B00a0DP0=`5903P1AP0b0DD0<@580341B01a
02H0=`5503d1B@0g0DT0>05903d1B00m0DD0=`5603L1B@0g0DT0L@0N01h1@P0]
0E40;@5402/1@P0N0Dl0805A02d1A01a01h07P4n0241D@0N0E408@5A0241?P0N
0Ch07P5A07407P0N0Dh0<@5A0341D@0a0Dh07P5>01h1D@0a0E40L@0N07P0B`1k
0500N01@07X0D01k04/0N@1;07P0D01a02H0N@1307d0B`1i04/0N`1;07d0A01k
04<0N@1;07T0B`1i04/0L@0V07/0?@1o04@0N`1307d0A01o03h0OP0m07/0@`1k
04<0N`1307409P1n03L0PP0n07h0?@1o03h0PP0h0840=`1n03d0OP0m07h0?@1a
02H0P@0c08H0>@2103L0PP0i08H0=@2503<0P@0g0840=`2103L0L@0V08D0<02:
03D0Q@0c08H0=@2:0380R@0`08D0<`2503<0Q@0c07409P2902l0SP0b08T0<02:
0380SP0a08h0;`290300R@0`08T0<01a02H0SP0_0980<P2>02l0SP0a0980<P2B
0300SP0_08h0;`2>02l0L@0V0980<02G03D0TP0`0980<P2F03D0U`0c09<0<02C
0300TP0`07409P2E03<0V`0h09L0<`2E03@0V@0h09/0=`2G03<0U`0c09L0<`1a
02H0V@0g09h0?@2K03L0V@0h09`0?@2N03`0V`0g09/0=`2K03L0L@0V09`0?02Q
04@0WP0l09`0?@2O04@0X@1309h0?02N03`0WP0l07409P2O04<0X`1;0:40@`2O
04<0X@1;0:<0BP2Q04<0X@130:40@`1a02H0X@1:0:<0D02S04X0X@1;0:40D02S
04l0X`1:0:<0BP2S04X0L@0J07<0CP1m05`0N01L07<0CP1m04h0N01L07406P2N
04d0Z01K0:<0F`2X04d0WP1=0:<0F`1a01h0iP1N0>L0H03V05h0i`1P0>L0H03V
05h0iP1N07409P3V05P0l@1P0>H0GP3W0600l@1J0?00F03V05h0iP1N0>H0GP1a
02H0l01D0?X0FP3`05P0l@1J0?X0EP3j05@0l01H0?00F03`05P0L@0V0?X0D@44
05H0nP1D0?X0EP4405<10`1A0?X0E03j05@0nP1D07409P430501301C0@<0D@43
05<1301B0@`0D04305410`1A0@<0D@1a02H1301@0A@0DP4<0501301B0A<0DP4D
0501301@0@`0D04<0500L@0V0A<0D04J05@1501@0A<0DP4J05@16P1B0A@0D04D
0501501@07409P4I05817`1H0AX0DP4I05@17P1H0Al0E`4J05<16P1B0AX0DP1a
02H17P1G0B<0G@4O05L17P1H0B40G@4S05`1801G0B00E`4O05L0L@0V0B40G04T
06@18`1L0B40G@4R06@1901S0B<0G@4S05d18`1L07409P4Q06<1901[0B@0H`4R
06<18@1[0B<0J`4T06@1901T0B@0H`1a02H17P1[0B<0L`4S06/18@1[0Ah0L`4P
07<18`1[0B<0J`4S06/0L@0V0AX0L`4P07`1801c0Ah0L`4J07/16`1l0B00M04P
07<1801c07409P4D07/16`250A/0O04J07/150230AD0Q@4K07`16`1l0A/0O01a
02H130230AD0S@4E08D150230@`0S04>08d15@250AD0Q@4E08D0L@0V0@`0S04>
08d13P2=0@`0S04<08`13@2=0@h0S@4>08d13P2=07406P3M05T0j`1V0=d0IP3T
05T0j`1Q0=d0IP1a01X110280A80U04409@14P2@0@`0R04409@0X@2F00X10000
000000000:00V00/00P050EDJFeUL`0301@0108000D02@0=02@0;P04o`3o000@
00500001@000:aBi0D@0X02I0:00U`2Q09H02P40000000000000X02H00@0000=
01P0:aX40BP0X02I0:00U`2Q09H02P40000000000000X02H00@2000Y209YJP2P
09T0X02G0:40UP0:0@0000000000002P09P0100002T=0BT00:00V@2P09L0X@2F
00X10000000000000:00V00=0180:`P20VIV002P09T0X02G0:40UP0:0@000000
0000002P09P0108000d0900X0CP0;`540:00V@2P09L0X@2F00X1000000000000
0:00V00=01P0:aX40F/0X02I0:00U`2Q09H02P40000000000000X02H00@0000=
0180:`/20fIV802P09T0X02G0:40UP0:0@0000000000002P09P0108000d0600X
0C`0I05/0:00V@2P09L0X@2F00X10000000000000:00V00400003@0B02/70P9V
K@00X02I0:00U`1a01h0R`2k08l0_`2=0;/0R`2m08d0_`2?0;h0S@2k07409P2=
0;h0V03;08l0_P2=0;l0UP3;09P0bP2?0;h0S`2n08l0_P1a02H0UP3:0:40eP2H
0<X0UP3;09l0eP2Q0=D0V03:09P0bP2H0<X0L@0V09l0e@2Y0>40X@3E09l0eP2W
0>40Z@3P0:40e@2Q0=D0X@3E07409P2W0>00/@3/0:T0h02W0>40[`3/0;40j`2Y
0>00Z@3P0:T0h01a02H0[`3[0;P0m`2a0>/0[`3/0;H0m`2h0?H0/@3[0;40j`2a
0>/0L@0V0;H0mP2n0@@0^03f0;H0m`2l0@@0_P430;P0m`2h0?H0^03f07409P2l
0@<0_`460;h10`2l0@@0_@460;l11@2n0@<0_P430;h10`1a01X0Q@2c0940`@25
0;<0T@2k08T0`@250;<0L@0J0;P10@320A00`P4@0<810@2h0@D0`P4@0:40UP0:
0@0000000000002P09P0108000d0900X0841WP5Y0:00V@2P09L0X@2F00X10000
000000000:00V00Z:P5Z002P09T0X02G0:40UP0:0@0000000000002P09P0:03H
0I`1J`2P09T0X02G0:40UP0:0@0000000000002P09P0:`8/0F`0X02I0:00U`2Q
09H02P40000000000000X02H02`02@031TMUKVEfH@000`0300@0000=01P0:011
0H85C6mSMG<0X02I0:00U`0800T0L@0N04<1PP140LH0@`6204<1aP140LH0A062
04<1PP0800P080000000007R02<0000Q0EL1hP0S00008@5G00008`0002400000
02<0000Joooooooo0740<P1j0A<0Q@4]07h1;@210B/0P`4X08D19@250B40Q@4Q
08@170220AP0OP4E07X14`1a04X0J04C07h1;`1j0A<0N04C07L14`1g0A<0L@4D
06`15`1Y0A/0J04Q06P18@1Y0BL0K04[0741;P1g0Bl0M`4_07/1;`1n0Bh06P00
0000000R07X14`3n02<0000S0?l08`0002<0000S00008`7j02<0000S0o/08`00
02<4o@0S00008`Ko02<0000S00008`0002<60@0S00008`@302<0000S0`D08`00
02<11P0S00008`0002<0000S00@08`0002?o0`0Joooooooo0740?P2C0A80ZP4_
0:X15@2V0A<0X@4B0:414P2L0A<0U`4F09@16`2C0B40T`4Q09@19P2G0B/0W04^
0:41;`1a0380X@4F0;01;`2Q0Bl0Y`4^0:/1:`2^0BH0/04Q0;018@2_0Ad0[P4J
0:d1602[0AH06P000000000R0:41;ol602<0000So@@08`0002?k0`0S00008o/2
02<0000S00008`0002?lo`0S00008ogo02<0000So_l08`0002?noP2Q09H02P40
000000000000X02H00<050040P003@0T02P0U@3E0D@0X02I0:00U`2Q09H02P40
000000000000X02H00d0600[6P@1J@2P09T0X02G0:40UP0:0@0000000000002P
09P0100000d04P0[1`83IVdP0:00V@2P09L0X@2F00X10000000000000:00V004
0P003@0H02P0V@4>0F/0X02I0:00U`2Q09H02P40000000000000X02H00@0000=
0180:`/20VeV002P09T0X02G01[oooooool0L@0N07T1501n0Bd0N@4D07X1501n
0Bd0O@4]07T1501a01h0X@4E0:/1;P2Q0Bh0X`4^0:/15`2Z0AD0X@4^0?l\>"], "Graphics",
    GeneratedCell->False,
    CellAutoOverwrite->False,
    ImageSize->{483, 344},
    ImageMargins->{{48.1875, 0}, {0, 360.5}},
    ImageRegion->{{0, 1}, {0, 1}}]
}], "Text",
  CellMargins->{{18.1875, 24.375}, {Inherited, Inherited}}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[StyleBox["{Equation numbering stuff}",
  FontSize->9]], "Subtitle",
  CellMargins->{{18.1875, 24.375}, {Inherited, Inherited}},
  PageBreakAbove->True],

Cell[BoxData[{
    StyleBox[\(<< Utilities`Numbering`;\),
      FontWeight->"Bold"], "\n", \(Scan[eqLink, 
        findTags["\<NumberedEquation\>"]];\)}], "Input",
  CellMargins->{{Inherited, 24.375}, {Inherited, Inherited}}],

Cell[TextData[{
  "zetaDefn",
  "   ",
  ButtonBox["(",
    ButtonData:>"zetaDefn",
    ButtonStyle->"Hyperlink"],
  
  CounterBox["NumberedEquation", "zetaDefn"],
  ButtonBox[")",
    ButtonData:>"zetaDefn",
    ButtonStyle->"Hyperlink"],
  "\n",
  "zetaProductDefn",
  "   ",
  ButtonBox["(",
    ButtonData:>"zetaProductDefn",
    ButtonStyle->"Hyperlink"],
  
  CounterBox["NumberedEquation", "zetaProductDefn"],
  ButtonBox[")",
    ButtonData:>"zetaProductDefn",
    ButtonStyle->"Hyperlink"],
  "\n",
  "DDefn",
  "   ",
  ButtonBox["(",
    ButtonData:>"DDefn",
    ButtonStyle->"Hyperlink"],
  
  CounterBox["NumberedEquation", "DDefn"],
  ButtonBox[")",
    ButtonData:>"DDefn",
    ButtonStyle->"Hyperlink"],
  "\n",
  "genoFreqFromMoments",
  "   ",
  ButtonBox["(",
    ButtonData:>"genoFreqFromMoments",
    ButtonStyle->"Hyperlink"],
  
  CounterBox["NumberedEquation", "genoFreqFromMoments"],
  ButtonBox[")",
    ButtonData:>"genoFreqFromMoments",
    ButtonStyle->"Hyperlink"],
  "\n",
  "reductionFormula",
  "   ",
  ButtonBox["(",
    ButtonData:>"reductionFormula",
    ButtonStyle->"Hyperlink"],
  
  CounterBox["NumberedEquation", "reductionFormula"],
  ButtonBox[")",
    ButtonData:>"reductionFormula",
    ButtonStyle->"Hyperlink"],
  "\n",
  "phenotypicDeterminationInGeneral",
  "   ",
  ButtonBox["(",
    ButtonData:>"phenotypicDeterminationInGeneral",
    ButtonStyle->"Hyperlink"],
  
  CounterBox["NumberedEquation", "phenotypicDeterminationInGeneral"],
  ButtonBox[")",
    ButtonData:>"phenotypicDeterminationInGeneral",
    ButtonStyle->"Hyperlink"],
  "\n",
  "fitnessDefinition",
  "   ",
  ButtonBox["(",
    ButtonData:>"fitnessDefinition",
    ButtonStyle->"Hyperlink"],
  
  CounterBox["NumberedEquation", "fitnessDefinition"],
  ButtonBox[")",
    ButtonData:>"fitnessDefinition",
    ButtonStyle->"Hyperlink"],
  "\n",
  "CombiningSelectionCoefs",
  "   ",
  ButtonBox["(",
    ButtonData:>"CombiningSelectionCoefs",
    ButtonStyle->"Hyperlink"],
  
  CounterBox["NumberedEquation", "CombiningSelectionCoefs"],
  ButtonBox[")",
    ButtonData:>"CombiningSelectionCoefs",
    ButtonStyle->"Hyperlink"],
  "\n",
  "exactChangeInDWithSelection",
  "   ",
  ButtonBox["(",
    ButtonData:>"exactChangeInDWithSelection",
    ButtonStyle->"Hyperlink"],
  
  CounterBox["NumberedEquation", "exactChangeInDWithSelection"],
  ButtonBox[")",
    ButtonData:>"exactChangeInDWithSelection",
    ButtonStyle->"Hyperlink"],
  "\n",
  "ExactDeltaP",
  "   ",
  ButtonBox["(",
    ButtonData:>"ExactDeltaP",
    ButtonStyle->"Hyperlink"],
  
  CounterBox["NumberedEquation", "ExactDeltaP"],
  ButtonBox[")",
    ButtonData:>"ExactDeltaP",
    ButtonStyle->"Hyperlink"],
  "\n",
  "pqDefinition",
  "   ",
  ButtonBox["(",
    ButtonData:>"pqDefinition",
    ButtonStyle->"Hyperlink"],
  
  CounterBox["NumberedEquation", "pqDefinition"],
  ButtonBox[")",
    ButtonData:>"pqDefinition",
    ButtonStyle->"Hyperlink"],
  "\n",
  "ExactChangeInDWithTransmissionNoVariationInT",
  "   ",
  ButtonBox["(",
    ButtonData:>"ExactChangeInDWithTransmissionNoVariationInT",
    ButtonStyle->"Hyperlink"],
  
  CounterBox["NumberedEquation", 
    "ExactChangeInDWithTransmissionNoVariationInT"],
  ButtonBox[")",
    ButtonData:>"ExactChangeInDWithTransmissionNoVariationInT",
    ButtonStyle->"Hyperlink"],
  "\n",
  "transmissionCoefficients",
  "   ",
  ButtonBox["(",
    ButtonData:>"transmissionCoefficients",
    ButtonStyle->"Hyperlink"],
  
  CounterBox["NumberedEquation", "transmissionCoefficients"],
  ButtonBox[")",
    ButtonData:>"transmissionCoefficients",
    ButtonStyle->"Hyperlink"],
  "\n",
  "ExactChangeInDWithTransmissionWithVariationInT",
  "   ",
  ButtonBox["(",
    ButtonData:>"ExactChangeInDWithTransmissionWithVariationInT",
    ButtonStyle->"Hyperlink"],
  
  CounterBox["NumberedEquation", 
    "ExactChangeInDWithTransmissionWithVariationInT"],
  ButtonBox[")",
    ButtonData:>"ExactChangeInDWithTransmissionWithVariationInT",
    ButtonStyle->"Hyperlink"],
  "\n",
  "ChangeInReferenceValueEquation",
  "   ",
  ButtonBox["(",
    ButtonData:>"ChangeInReferenceValueEquation",
    ButtonStyle->"Hyperlink"],
  
  CounterBox["NumberedEquation", "ChangeInReferenceValueEquation"],
  ButtonBox[")",
    ButtonData:>"ChangeInReferenceValueEquation",
    ButtonStyle->"Hyperlink"],
  "\n",
  "DPrimeAfterSelectionAtQLE",
  "   ",
  ButtonBox["(",
    ButtonData:>"DPrimeAfterSelectionAtQLE",
    ButtonStyle->"Hyperlink"],
  
  CounterBox["NumberedEquation", "DPrimeAfterSelectionAtQLE"],
  ButtonBox[")",
    ButtonData:>"DPrimeAfterSelectionAtQLE",
    ButtonStyle->"Hyperlink"],
  "\n",
  "DTriplePrimeAtQLE",
  "   ",
  ButtonBox["(",
    ButtonData:>"DTriplePrimeAtQLE",
    ButtonStyle->"Hyperlink"],
  
  CounterBox["NumberedEquation", "DTriplePrimeAtQLE"],
  ButtonBox[")",
    ButtonData:>"DTriplePrimeAtQLE",
    ButtonStyle->"Hyperlink"],
  "\n",
  "implicitApproximationForDAtQLE",
  "   ",
  ButtonBox["(",
    ButtonData:>"implicitApproximationForDAtQLE",
    ButtonStyle->"Hyperlink"],
  
  CounterBox["NumberedEquation", "implicitApproximationForDAtQLE"],
  ButtonBox[")",
    ButtonData:>"implicitApproximationForDAtQLE",
    ButtonStyle->"Hyperlink"],
  "\n",
  "DAtQLEInHaploids",
  "   ",
  ButtonBox["(",
    ButtonData:>"DAtQLEInHaploids",
    ButtonStyle->"Hyperlink"],
  
  CounterBox["NumberedEquation", "DAtQLEInHaploids"],
  ButtonBox[")",
    ButtonData:>"DAtQLEInHaploids",
    ButtonStyle->"Hyperlink"],
  "\n",
  "DatQLECase2",
  "   ",
  ButtonBox["(",
    ButtonData:>"DatQLECase2",
    ButtonStyle->"Hyperlink"],
  
  CounterBox["NumberedEquation", "DatQLECase2"],
  ButtonBox[")",
    ButtonData:>"DatQLECase2",
    ButtonStyle->"Hyperlink"],
  "\n",
  "QLECase3Autosomes",
  "   ",
  ButtonBox["(",
    ButtonData:>"QLECase3Autosomes",
    ButtonStyle->"Hyperlink"],
  
  CounterBox["NumberedEquation", "QLECase3Autosomes"],
  ButtonBox[")",
    ButtonData:>"QLECase3Autosomes",
    ButtonStyle->"Hyperlink"],
  "\n",
  "TDefn",
  "   ",
  ButtonBox["(",
    ButtonData:>"TDefn",
    ButtonStyle->"Hyperlink"],
  
  CounterBox["NumberedEquation", "TDefn"],
  ButtonBox[")",
    ButtonData:>"TDefn",
    ButtonStyle->"Hyperlink"],
  "\n",
  "QLECase3XLinkage",
  "   ",
  ButtonBox["(",
    ButtonData:>"QLECase3XLinkage",
    ButtonStyle->"Hyperlink"],
  
  CounterBox["NumberedEquation", "QLECase3XLinkage"],
  ButtonBox[")",
    ButtonData:>"QLECase3XLinkage",
    ButtonStyle->"Hyperlink"],
  "\n",
  "QLECase3CytoplasmicGenes",
  "   ",
  ButtonBox["(",
    ButtonData:>"QLECase3CytoplasmicGenes",
    ButtonStyle->"Hyperlink"],
  
  CounterBox["NumberedEquation", "QLECase3CytoplasmicGenes"],
  ButtonBox[")",
    ButtonData:>"QLECase3CytoplasmicGenes",
    ButtonStyle->"Hyperlink"],
  "\n",
  "QLECase3YLinkage",
  "   ",
  ButtonBox["(",
    ButtonData:>"QLECase3YLinkage",
    ButtonStyle->"Hyperlink"],
  
  CounterBox["NumberedEquation", "QLECase3YLinkage"],
  ButtonBox[")",
    ButtonData:>"QLECase3YLinkage",
    ButtonStyle->"Hyperlink"],
  "\n",
  "deltaPMutation",
  "   ",
  ButtonBox["(",
    ButtonData:>"deltaPMutation",
    ButtonStyle->"Hyperlink"],
  
  CounterBox["NumberedEquation", "deltaPMutation"],
  ButtonBox[")",
    ButtonData:>"deltaPMutation",
    ButtonStyle->"Hyperlink"],
  "\n",
  "DAAfterMutation",
  "   ",
  ButtonBox["(",
    ButtonData:>"DAAfterMutation",
    ButtonStyle->"Hyperlink"],
  
  CounterBox["NumberedEquation", "DAAfterMutation"],
  ButtonBox[")",
    ButtonData:>"DAAfterMutation",
    ButtonStyle->"Hyperlink"],
  "\n",
  "deltaPMigration",
  "   ",
  ButtonBox["(",
    ButtonData:>"deltaPMigration",
    ButtonStyle->"Hyperlink"],
  
  CounterBox["NumberedEquation", "deltaPMigration"],
  ButtonBox[")",
    ButtonData:>"deltaPMigration",
    ButtonStyle->"Hyperlink"],
  "\n",
  "DAPrimeCentered",
  "   ",
  ButtonBox["(",
    ButtonData:>"DAPrimeCentered",
    ButtonStyle->"Hyperlink"],
  
  CounterBox["NumberedEquation", "DAPrimeCentered"],
  ButtonBox[")",
    ButtonData:>"DAPrimeCentered",
    ButtonStyle->"Hyperlink"],
  "\n",
  "dAProductDefn",
  "   ",
  ButtonBox["(",
    ButtonData:>"dAProductDefn",
    ButtonStyle->"Hyperlink"],
  
  CounterBox["NumberedEquation", "dAProductDefn"],
  ButtonBox[")",
    ButtonData:>"dAProductDefn",
    ButtonStyle->"Hyperlink"],
  "\n",
  "DijPrimeExactAfterMigration",
  "   ",
  ButtonBox["(",
    ButtonData:>"DijPrimeExactAfterMigration",
    ButtonStyle->"Hyperlink"],
  
  CounterBox["NumberedEquation", "DijPrimeExactAfterMigration"],
  ButtonBox[")",
    ButtonData:>"DijPrimeExactAfterMigration",
    ButtonStyle->"Hyperlink"],
  "\n",
  "DADoublePrimeNoDisequilibriumAmongMigrants",
  "   ",
  ButtonBox["(",
    ButtonData:>"DADoublePrimeNoDisequilibriumAmongMigrants",
    ButtonStyle->"Hyperlink"],
  
  CounterBox["NumberedEquation", 
    "DADoublePrimeNoDisequilibriumAmongMigrants"],
  ButtonBox[")",
    ButtonData:>"DADoublePrimeNoDisequilibriumAmongMigrants",
    ButtonStyle->"Hyperlink"],
  "\n",
  "deltaDAMigrationToLeadingOrder",
  "   ",
  ButtonBox["(",
    ButtonData:>"deltaDAMigrationToLeadingOrder",
    ButtonStyle->"Hyperlink"],
  
  CounterBox["NumberedEquation", "deltaDAMigrationToLeadingOrder"],
  ButtonBox[")",
    ButtonData:>"deltaDAMigrationToLeadingOrder",
    ButtonStyle->"Hyperlink"],
  "\n",
  "dAAtQLEFromExactCalculation",
  "   ",
  ButtonBox["(",
    ButtonData:>"dAAtQLEFromExactCalculation",
    ButtonStyle->"Hyperlink"],
  
  CounterBox["NumberedEquation", "dAAtQLEFromExactCalculation"],
  ButtonBox[")",
    ButtonData:>"dAAtQLEFromExactCalculation",
    ButtonStyle->"Hyperlink"],
  "\n",
  "ZTwoLoci",
  "   ",
  ButtonBox["(",
    ButtonData:>"ZTwoLoci",
    ButtonStyle->"Hyperlink"],
  
  CounterBox["NumberedEquation", "ZTwoLoci"],
  ButtonBox[")",
    ButtonData:>"ZTwoLoci",
    ButtonStyle->"Hyperlink"],
  "\n",
  "GaussianFitnessFunction",
  "   ",
  ButtonBox["(",
    ButtonData:>"GaussianFitnessFunction",
    ButtonStyle->"Hyperlink"],
  
  CounterBox["NumberedEquation", "GaussianFitnessFunction"],
  ButtonBox[")",
    ButtonData:>"GaussianFitnessFunction",
    ButtonStyle->"Hyperlink"],
  "\n",
  "wTwoLociAfterZetasReduced",
  "   ",
  ButtonBox["(",
    ButtonData:>"wTwoLociAfterZetasReduced",
    ButtonStyle->"Hyperlink"],
  
  CounterBox["NumberedEquation", "wTwoLociAfterZetasReduced"],
  ButtonBox[")",
    ButtonData:>"wTwoLociAfterZetasReduced",
    ButtonStyle->"Hyperlink"],
  "\n",
  "wTwoLociAfterZetasReducedTwo",
  "   ",
  ButtonBox["(",
    ButtonData:>"wTwoLociAfterZetasReducedTwo",
    ButtonStyle->"Hyperlink"],
  
  CounterBox["NumberedEquation", "wTwoLociAfterZetasReducedTwo"],
  ButtonBox[")",
    ButtonData:>"wTwoLociAfterZetasReducedTwo",
    ButtonStyle->"Hyperlink"],
  "\n",
  "aiForTwoLoci",
  "   ",
  ButtonBox["(",
    ButtonData:>"aiForTwoLoci",
    ButtonStyle->"Hyperlink"],
  
  CounterBox["NumberedEquation", "aiForTwoLoci"],
  ButtonBox[")",
    ButtonData:>"aiForTwoLoci",
    ButtonStyle->"Hyperlink"],
  "\n",
  "aijForTwoLoci",
  "   ",
  ButtonBox["(",
    ButtonData:>"aijForTwoLoci",
    ButtonStyle->"Hyperlink"],
  
  CounterBox["NumberedEquation", "aijForTwoLoci"],
  ButtonBox[")",
    ButtonData:>"aijForTwoLoci",
    ButtonStyle->"Hyperlink"],
  "\n",
  "deltaPTwoLoci",
  "   ",
  ButtonBox["(",
    ButtonData:>"deltaPTwoLoci",
    ButtonStyle->"Hyperlink"],
  
  CounterBox["NumberedEquation", "deltaPTwoLoci"],
  ButtonBox[")",
    ButtonData:>"deltaPTwoLoci",
    ButtonStyle->"Hyperlink"],
  "\n",
  "deltaZBarTwoLoci",
  "   ",
  ButtonBox["(",
    ButtonData:>"deltaZBarTwoLoci",
    ButtonStyle->"Hyperlink"],
  
  CounterBox["NumberedEquation", "deltaZBarTwoLoci"],
  ButtonBox[")",
    ButtonData:>"deltaZBarTwoLoci",
    ButtonStyle->"Hyperlink"],
  "\n",
  "DijAfterSelection",
  "   ",
  ButtonBox["(",
    ButtonData:>"DijAfterSelection",
    ButtonStyle->"Hyperlink"],
  
  CounterBox["NumberedEquation", "DijAfterSelection"],
  ButtonBox[")",
    ButtonData:>"DijAfterSelection",
    ButtonStyle->"Hyperlink"],
  "\n",
  "DijAfterChangingReferenceValues",
  "   ",
  ButtonBox["(",
    ButtonData:>"DijAfterChangingReferenceValues",
    ButtonStyle->"Hyperlink"],
  
  CounterBox["NumberedEquation", "DijAfterChangingReferenceValues"],
  ButtonBox[")",
    ButtonData:>"DijAfterChangingReferenceValues",
    ButtonStyle->"Hyperlink"],
  "\n",
  "SexSelFitnessFunctionVersion1",
  "   ",
  ButtonBox["(",
    ButtonData:>"SexSelFitnessFunctionVersion1",
    ButtonStyle->"Hyperlink"],
  
  CounterBox["NumberedEquation", "SexSelFitnessFunctionVersion1"],
  ButtonBox[")",
    ButtonData:>"SexSelFitnessFunctionVersion1",
    ButtonStyle->"Hyperlink"],
  "\n",
  "SexSelFitnessFunctionVersion2",
  "   ",
  ButtonBox["(",
    ButtonData:>"SexSelFitnessFunctionVersion2",
    ButtonStyle->"Hyperlink"],
  
  CounterBox["NumberedEquation", "SexSelFitnessFunctionVersion2"],
  ButtonBox[")",
    ButtonData:>"SexSelFitnessFunctionVersion2",
    ButtonStyle->"Hyperlink"],
  "\n",
  "SexSelSelectionCoefficient",
  "   ",
  ButtonBox["(",
    ButtonData:>"SexSelSelectionCoefficient",
    ButtonStyle->"Hyperlink"],
  
  CounterBox["NumberedEquation", "SexSelSelectionCoefficient"],
  ButtonBox[")",
    ButtonData:>"SexSelSelectionCoefficient",
    ButtonStyle->"Hyperlink"],
  "\n",
  "SexSelGeneticCorrelationInGeneral",
  "   ",
  ButtonBox["(",
    ButtonData:>"SexSelGeneticCorrelationInGeneral",
    ButtonStyle->"Hyperlink"],
  
  CounterBox["NumberedEquation", "SexSelGeneticCorrelationInGeneral"],
  ButtonBox[")",
    ButtonData:>"SexSelGeneticCorrelationInGeneral",
    ButtonStyle->"Hyperlink"],
  "\n",
  "HaploidGeneticVariancesForPandT",
  "   ",
  ButtonBox["(",
    ButtonData:>"HaploidGeneticVariancesForPandT",
    ButtonStyle->"Hyperlink"],
  
  CounterBox["NumberedEquation", "HaploidGeneticVariancesForPandT"],
  ButtonBox[")",
    ButtonData:>"HaploidGeneticVariancesForPandT",
    ButtonStyle->"Hyperlink"],
  "\n",
  "SexSelD",
  "   ",
  ButtonBox["(",
    ButtonData:>"SexSelD",
    ButtonStyle->"Hyperlink"],
  
  CounterBox["NumberedEquation", "SexSelD"],
  ButtonBox[")",
    ButtonData:>"SexSelD",
    ButtonStyle->"Hyperlink"],
  "\n",
  "GPTandrPTInHaploids",
  "   ",
  ButtonBox["(",
    ButtonData:>"GPTandrPTInHaploids",
    ButtonStyle->"Hyperlink"],
  
  CounterBox["NumberedEquation", "GPTandrPTInHaploids"],
  ButtonBox[")",
    ButtonData:>"GPTandrPTInHaploids",
    ButtonStyle->"Hyperlink"],
  "\n",
  "GPTForDiploidAutosomesInTermsOfDs",
  "   ",
  ButtonBox["(",
    ButtonData:>"GPTForDiploidAutosomesInTermsOfDs",
    ButtonStyle->"Hyperlink"],
  
  CounterBox["NumberedEquation", "GPTForDiploidAutosomesInTermsOfDs"],
  ButtonBox[")",
    ButtonData:>"GPTForDiploidAutosomesInTermsOfDs",
    ButtonStyle->"Hyperlink"],
  "\n",
  "TForDiploidAutosomes",
  "   ",
  ButtonBox["(",
    ButtonData:>"TForDiploidAutosomes",
    ButtonStyle->"Hyperlink"],
  
  CounterBox["NumberedEquation", "TForDiploidAutosomes"],
  ButtonBox[")",
    ButtonData:>"TForDiploidAutosomes",
    ButtonStyle->"Hyperlink"],
  "\n",
  "SexSelDForDiploidAutosomes",
  "   ",
  ButtonBox["(",
    ButtonData:>"SexSelDForDiploidAutosomes",
    ButtonStyle->"Hyperlink"],
  
  CounterBox["NumberedEquation", "SexSelDForDiploidAutosomes"],
  ButtonBox[")",
    ButtonData:>"SexSelDForDiploidAutosomes",
    ButtonStyle->"Hyperlink"],
  "\n",
  "GmPTForXLinkageInTermsOfDs",
  "   ",
  ButtonBox["(",
    ButtonData:>"GmPTForXLinkageInTermsOfDs",
    ButtonStyle->"Hyperlink"],
  
  CounterBox["NumberedEquation", "GmPTForXLinkageInTermsOfDs"],
  ButtonBox[")",
    ButtonData:>"GmPTForXLinkageInTermsOfDs",
    ButtonStyle->"Hyperlink"],
  "\n",
  "TsXLinkage",
  "   ",
  ButtonBox["(",
    ButtonData:>"TsXLinkage",
    ButtonStyle->"Hyperlink"],
  
  CounterBox["NumberedEquation", "TsXLinkage"],
  ButtonBox[")",
    ButtonData:>"TsXLinkage",
    ButtonStyle->"Hyperlink"],
  "\n",
  "SexSelDsForXLinkage",
  "   ",
  ButtonBox["(",
    ButtonData:>"SexSelDsForXLinkage",
    ButtonStyle->"Hyperlink"],
  
  CounterBox["NumberedEquation", "SexSelDsForXLinkage"],
  ButtonBox[")",
    ButtonData:>"SexSelDsForXLinkage",
    ButtonStyle->"Hyperlink"],
  "\n",
  "GmPTAndrMPTForXLinkage",
  "   ",
  ButtonBox["(",
    ButtonData:>"GmPTAndrMPTForXLinkage",
    ButtonStyle->"Hyperlink"],
  
  CounterBox["NumberedEquation", "GmPTAndrMPTForXLinkage"],
  ButtonBox[")",
    ButtonData:>"GmPTAndrMPTForXLinkage",
    ButtonStyle->"Hyperlink"],
  "\n",
  "QLE_Christiansen",
  "   ",
  ButtonBox["(",
    ButtonData:>"QLE_Christiansen",
    ButtonStyle->"Hyperlink"],
  
  CounterBox["NumberedEquation", "QLE_Christiansen"],
  ButtonBox[")",
    ButtonData:>"QLE_Christiansen",
    ButtonStyle->"Hyperlink"],
  "\n",
  "QLEChristainsenInOurNotation",
  "   ",
  ButtonBox["(",
    ButtonData:>"QLEChristainsenInOurNotation",
    ButtonStyle->"Hyperlink"],
  
  CounterBox["NumberedEquation", "QLEChristainsenInOurNotation"],
  ButtonBox[")",
    ButtonData:>"QLEChristainsenInOurNotation",
    ButtonStyle->"Hyperlink"],
  "\n",
  "QLEBurger",
  "   ",
  ButtonBox["(",
    ButtonData:>"QLEBurger",
    ButtonStyle->"Hyperlink"],
  
  CounterBox["NumberedEquation", "QLEBurger"],
  ButtonBox[")",
    ButtonData:>"QLEBurger",
    ButtonStyle->"Hyperlink"],
  "\n",
  "FitnessPolynomialFor2Loci",
  "   ",
  ButtonBox["(",
    ButtonData:>"FitnessPolynomialFor2Loci",
    ButtonStyle->"Hyperlink"],
  
  CounterBox["NumberedEquation", "FitnessPolynomialFor2Loci"],
  ButtonBox[")",
    ButtonData:>"FitnessPolynomialFor2Loci",
    ButtonStyle->"Hyperlink"],
  "\n",
  "FitnessDefnFor2Loci",
  "   ",
  ButtonBox["(",
    ButtonData:>"FitnessDefnFor2Loci",
    ButtonStyle->"Hyperlink"],
  
  CounterBox["NumberedEquation", "FitnessDefnFor2Loci"],
  ButtonBox[")",
    ButtonData:>"FitnessDefnFor2Loci",
    ButtonStyle->"Hyperlink"],
  "\n",
  "SelectionCoefs2Loci",
  "   ",
  ButtonBox["(",
    ButtonData:>"SelectionCoefs2Loci",
    ButtonStyle->"Hyperlink"],
  
  CounterBox["NumberedEquation", "SelectionCoefs2Loci"],
  ButtonBox[")",
    ButtonData:>"SelectionCoefs2Loci",
    ButtonStyle->"Hyperlink"],
  "\n",
  "deltaPI2LociVersion1",
  "   ",
  ButtonBox["(",
    ButtonData:>"deltaPI2LociVersion1",
    ButtonStyle->"Hyperlink"],
  
  CounterBox["NumberedEquation", "deltaPI2LociVersion1"],
  ButtonBox[")",
    ButtonData:>"deltaPI2LociVersion1",
    ButtonStyle->"Hyperlink"],
  "\n",
  "Dij2LociQLE",
  "   ",
  ButtonBox["(",
    ButtonData:>"Dij2LociQLE",
    ButtonStyle->"Hyperlink"],
  
  CounterBox["NumberedEquation", "Dij2LociQLE"],
  ButtonBox[")",
    ButtonData:>"Dij2LociQLE",
    ButtonStyle->"Hyperlink"],
  "\n",
  "WBar2LociQLE",
  "   ",
  ButtonBox["(",
    ButtonData:>"WBar2LociQLE",
    ButtonStyle->"Hyperlink"],
  
  CounterBox["NumberedEquation", "WBar2LociQLE"],
  ButtonBox[")",
    ButtonData:>"WBar2LociQLE",
    ButtonStyle->"Hyperlink"],
  "\n",
  "deltaPI2LociVersion2",
  "   ",
  ButtonBox["(",
    ButtonData:>"deltaPI2LociVersion2",
    ButtonStyle->"Hyperlink"],
  
  CounterBox["NumberedEquation", "deltaPI2LociVersion2"],
  ButtonBox[")",
    ButtonData:>"deltaPI2LociVersion2",
    ButtonStyle->"Hyperlink"],
  "\n",
  "DANextByMutationExactlyDefnVersion1",
  "   ",
  ButtonBox["(",
    ButtonData:>"DANextByMutationExactlyDefnVersion1",
    ButtonStyle->"Hyperlink"],
  
  CounterBox["NumberedEquation", "DANextByMutationExactlyDefnVersion1"],
  ButtonBox[")",
    ButtonData:>"DANextByMutationExactlyDefnVersion1",
    ButtonStyle->"Hyperlink"],
  "\n",
  "deltaPiByMutation",
  "   ",
  ButtonBox["(",
    ButtonData:>"deltaPiByMutation",
    ButtonStyle->"Hyperlink"],
  
  CounterBox["NumberedEquation", "deltaPiByMutation"],
  ButtonBox[")",
    ButtonData:>"deltaPiByMutation",
    ButtonStyle->"Hyperlink"],
  "\n",
  "delXForMutation",
  "   ",
  ButtonBox["(",
    ButtonData:>"delXForMutation",
    ButtonStyle->"Hyperlink"],
  
  CounterBox["NumberedEquation", "delXForMutation"],
  ButtonBox[")",
    ButtonData:>"delXForMutation",
    ButtonStyle->"Hyperlink"],
  "\n",
  "DANextByMutationExactlyDefnVersion2",
  "   ",
  ButtonBox["(",
    ButtonData:>"DANextByMutationExactlyDefnVersion2",
    ButtonStyle->"Hyperlink"],
  
  CounterBox["NumberedEquation", "DANextByMutationExactlyDefnVersion2"],
  ButtonBox[")",
    ButtonData:>"DANextByMutationExactlyDefnVersion2",
    ButtonStyle->"Hyperlink"],
  "\n",
  "DAPrimeDefn",
  "   ",
  ButtonBox["(",
    ButtonData:>"DAPrimeDefn",
    ButtonStyle->"Hyperlink"],
  
  CounterBox["NumberedEquation", "DAPrimeDefn"],
  ButtonBox[")",
    ButtonData:>"DAPrimeDefn",
    ButtonStyle->"Hyperlink"],
  "\n",
  "DPrimeInTermsOfDMR",
  "   ",
  ButtonBox["(",
    ButtonData:>"DPrimeInTermsOfDMR",
    ButtonStyle->"Hyperlink"],
  
  CounterBox["NumberedEquation", "DPrimeInTermsOfDMR"],
  ButtonBox[")",
    ButtonData:>"DPrimeInTermsOfDMR",
    ButtonStyle->"Hyperlink"],
  "\n",
  "DMRFormula",
  "   ",
  ButtonBox["(",
    ButtonData:>"DMRFormula",
    ButtonStyle->"Hyperlink"],
  
  CounterBox["NumberedEquation", "DMRFormula"],
  ButtonBox[")",
    ButtonData:>"DMRFormula",
    ButtonStyle->"Hyperlink"],
  "\n",
  "DAPrimeUncenteredResult",
  "   ",
  ButtonBox["(",
    ButtonData:>"DAPrimeUncenteredResult",
    ButtonStyle->"Hyperlink"],
  
  CounterBox["NumberedEquation", "DAPrimeUncenteredResult"],
  ButtonBox[")",
    ButtonData:>"DAPrimeUncenteredResult",
    ButtonStyle->"Hyperlink"]
}]]
}, Closed]]
}, Open  ]]
},
FrontEndVersion->"4.0 for Macintosh",
ScreenRectangle->{{0, 1152}, {0, 748}},
ScreenStyleEnvironment->"Printout",
WindowToolbars->{},
WindowSize->{988, 666},
WindowMargins->{{61, Automatic}, {16, Automatic}},
Visible->True,
PrintingCopies->1,
PrintingPageRange->{1, Automatic},
PageHeaders->{{Cell[ 
        TextData[ {
          ValueBox[ "FileName"]}], "Header"], Cell[ 
        TextData[ {"Multilocus models simplified"}]], Cell[ 
        TextData[ {
          CounterBox[ "Page"]}], "PageNumber"]}, {Cell[ 
        TextData[ {
          ValueBox[ "FileName"]}], "Header"], Cell[ 
        TextData[ {"Multilocus models simplified"}]], Cell[ 
        TextData[ {
          CounterBox[ "Page"]}], "PageNumber"]}},
PrintingOptions->{"FirstPageHeader"->False,
"FirstPageFooter"->False,
"FacingPages"->True},
InputAliases->{"notation"->RowBox[ {"Notation", "[", 
        RowBox[ {
          TagBox[ 
          "\[Placeholder]", NotationBoxTag, TagStyle -> 
            "NotationTemplateStyle"], " ", "\[DoubleLongLeftRightArrow]", " ",
           
          TagBox[ 
          "\[Placeholder]", NotationBoxTag, TagStyle -> 
            "NotationTemplateStyle"]}], "]"}], 
    "notation>"->RowBox[ {"Notation", "[", 
        RowBox[ {
          TagBox[ 
          "\[Placeholder]", NotationBoxTag, TagStyle -> 
            "NotationTemplateStyle"], " ", "\[DoubleLongRightArrow]", " ", 
          TagBox[ 
          "\[Placeholder]", NotationBoxTag, TagStyle -> 
            "NotationTemplateStyle"]}], "]"}], 
    "notation<"->RowBox[ {"Notation", "[", 
        RowBox[ {
          TagBox[ 
          "\[Placeholder]", NotationBoxTag, TagStyle -> 
            "NotationTemplateStyle"], " ", "\[DoubleLongLeftArrow]", " ", 
          TagBox[ 
          "\[Placeholder]", NotationBoxTag, TagStyle -> 
            "NotationTemplateStyle"]}], "]"}], 
    "symb"->RowBox[ {"Symbolize", "[", 
        TagBox[ 
        "\[Placeholder]", NotationBoxTag, TagStyle -> 
          "NotationTemplateStyle"], "]"}], 
    "infixnotation"->RowBox[ {"InfixNotation", "[", 
        RowBox[ {
          TagBox[ 
          "\[Placeholder]", NotationBoxTag, TagStyle -> 
            "NotationTemplateStyle"], ",", "\[Placeholder]"}], "]"}], 
    "addia"->RowBox[ {"AddInputAlias", "[", 
        RowBox[ {"\[Placeholder]", "\[Rule]", 
          TagBox[ 
          "\[Placeholder]", NotationBoxTag, TagStyle -> 
            "NotationTemplateStyle"]}], "]"}], 
    "pattwraper"->TagBox[ 
      "\[Placeholder]", NotationPatternTag, TagStyle -> 
        "NotationPatternWrapperStyle"], 
    "madeboxeswraper"->TagBox[ 
      "\[Placeholder]", NotationMadeBoxesTag, TagStyle -> 
        "NotationMadeBoxesWrapperStyle"]},
PrivateFontOptions->{"FontType"->"Outline"},
Magnification->1,
StyleDefinitions -> Notebook[{
  
  Cell[CellGroupData[{
  Cell["Style Definitions", "Subtitle"],
  
  Cell["\<\
Modify the definitions below to change the default appearance of \
all cells in a given style.  Make modifications to any definition using \
commands in the Format menu.\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell["Style Environment Names", "Section"],
  
  Cell[StyleData[All, "Working"],
    PageWidth->WindowWidth,
    ScriptMinSize->9],
  
  Cell[StyleData[All, "Presentation"],
    PageWidth->WindowWidth,
    ScriptMinSize->12,
    FontSize->16],
  
  Cell[StyleData[All, "Condensed"],
    PageWidth->WindowWidth,
    CellBracketOptions->{"Margins"->{1, 1},
    "Widths"->{0, 5}},
    ScriptMinSize->8,
    FontSize->11],
  
  Cell[StyleData[All, "Printout"],
    PageWidth->PaperWidth,
    ScriptMinSize->5,
    PrivateFontOptions->{"FontType"->"Outline"}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Notebook Options", "Section",
    DefaultNewCellStyle->"Text",
    DefaultDuplicateCellStyle->"Text"],
  
  Cell["\<\
The options defined for the style below will be used at the \
Notebook level.\
\>", "Text",
    DefaultNewCellStyle->"Text",
    DefaultDuplicateCellStyle->"Text"],
  
  Cell[StyleData["Notebook"],
    PageHeaders->{{Cell[ 
            TextData[ {
              CounterBox[ "Page"]}], "PageNumber"], None, Cell[ 
            TextData[ {
              ValueBox[ "FileName"]}], "Header"]}, {Cell[ 
            TextData[ {
              ValueBox[ "FileName"]}], "Header"], None, Cell[ 
            TextData[ {
              CounterBox[ "Page"]}], "PageNumber"]}},
    CellFrameLabelMargins->6,
    DefaultNewCellStyle->"Text",
    DefaultDuplicateCellStyle->"Text",
    StyleMenuListing->None]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Styles for Headings", "Section"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Title"],
    CellMargins->{{12, Inherited}, {20, 40}},
    CellGroupingRules->{"TitleGrouping", 0},
    PageBreakBelow->False,
    CounterIncrements->"Title",
    CounterAssignments->{{"Section", 0}, {"Equation", 0}, {"Figure", 0}, {
        "Subtitle", 0}, {"Subsubtitle", 0}},
    FontFamily->"Times",
    FontSize->18,
    FontWeight->"Bold"],
  
  Cell[StyleData["Title", "Presentation"],
    CellMargins->{{24, 10}, {20, 40}},
    LineSpacing->{1, 0},
    FontFamily->"Times",
    FontSize->18],
  
  Cell[StyleData["Title", "Condensed"],
    CellMargins->{{8, 10}, {4, 8}},
    FontFamily->"Times",
    FontSize->18],
  
  Cell[StyleData["Title", "Printout"],
    CellMargins->{{2, 10}, {15, 30}},
    FontFamily->"Times",
    FontSize->18]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Subtitle"],
    CellMargins->{{12, Inherited}, {10, 15}},
    CellGroupingRules->{"TitleGrouping", 10},
    PageBreakBelow->False,
    CounterIncrements->"Subtitle",
    CounterAssignments->{{"Section", 0}, {"Equation", 0}, {"Figure", 0}, {
        "Subsubtitle", 0}},
    FontFamily->"Times",
    FontSize->12,
    FontWeight->"Plain"],
  
  Cell[StyleData["Subtitle", "Presentation"],
    CellMargins->{{24, 10}, {15, 20}},
    LineSpacing->{1, 0},
    FontFamily->"Times",
    FontSize->12],
  
  Cell[StyleData["Subtitle", "Condensed"],
    CellMargins->{{8, 10}, {4, 4}},
    FontFamily->"Times",
    FontSize->12],
  
  Cell[StyleData["Subtitle", "Printout"],
    CellMargins->{{2, 10}, {10, 15}},
    FontFamily->"Times",
    FontSize->12]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Subsubtitle"],
    CellMargins->{{12, Inherited}, {10, 20}},
    CellGroupingRules->{"TitleGrouping", 20},
    PageBreakBelow->False,
    CounterIncrements->"Subsubtitle",
    CounterAssignments->{{"Section", 0}, {"Equation", 0}, {"Figure", 0}},
    FontFamily->"Times",
    FontSize->12,
    FontSlant->"Italic"],
  
  Cell[StyleData["Subsubtitle", "Presentation"],
    CellMargins->{{24, 10}, {10, 20}},
    LineSpacing->{1, 0},
    FontFamily->"Times",
    FontSize->12],
  
  Cell[StyleData["Subsubtitle", "Condensed"],
    CellMargins->{{8, 10}, {8, 12}},
    FontFamily->"Times",
    FontSize->12],
  
  Cell[StyleData["Subsubtitle", "Printout"],
    CellMargins->{{2, 10}, {8, 10}},
    FontFamily->"Times",
    FontSize->12]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Section"],
    CellDingbat->None,
    CellMargins->{{25, Inherited}, {8, 24}},
    CellGroupingRules->{"SectionGrouping", 30},
    PageBreakBelow->False,
    TextAlignment->Left,
    CounterIncrements->"Section",
    CounterAssignments->{{"Subsection", 0}, {"Subsubsection", 0}},
    FontFamily->"Times",
    FontSize->12,
    FontWeight->"Bold",
    CounterBoxOptions->{CounterStyle->"Section",
    CounterFunction:>Identity}],
  
  Cell[StyleData["Section", "Presentation"],
    CellDingbat->None,
    CellMargins->{{40, 10}, {11, 32}},
    TextAlignment->Left,
    LineSpacing->{1, 0},
    FontFamily->"Times",
    FontSize->12,
    CounterBoxOptions->{CounterStyle->"Section",
    CounterFunction:>Identity}],
  
  Cell[StyleData["Section", "Condensed"],
    CellDingbat->None,
    CellMargins->{{18, Inherited}, {6, 12}},
    TextAlignment->Left,
    FontFamily->"Times",
    FontSize->12,
    CounterBoxOptions->{CounterStyle->"Section",
    CounterFunction:>Identity}],
  
  Cell[StyleData["Section", "Printout"],
    CellDingbat->None,
    CellMargins->{{13, 0}, {7, 22}},
    TextAlignment->Left,
    FontFamily->"Times",
    FontSize->12,
    CounterBoxOptions->{CounterStyle->"Section",
    CounterFunction:>Identity}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Subsection"],
    CellDingbat->None,
    CellMargins->{{22, Inherited}, {8, 20}},
    CellGroupingRules->{"SectionGrouping", 40},
    PageBreakBelow->False,
    CounterIncrements->"Subsection",
    CounterAssignments->{{"Subsubsection", 0}},
    FontSize->12,
    FontWeight->"Plain",
    FontSlant->"Italic"],
  
  Cell[StyleData["Subsection", "Presentation"],
    CellDingbat->None,
    CellMargins->{{36, 10}, {11, 32}},
    LineSpacing->{1, 0},
    FontSize->12,
    FontWeight->"Plain",
    FontSlant->"Italic"],
  
  Cell[StyleData["Subsection", "Condensed"],
    CellDingbat->None,
    CellMargins->{{16, Inherited}, {6, 12}},
    FontSize->12,
    FontWeight->"Plain",
    FontSlant->"Italic"],
  
  Cell[StyleData["Subsection", "Printout"],
    CellDingbat->None,
    CellMargins->{{9, 0}, {7, 22}},
    FontSize->12,
    FontWeight->"Plain",
    FontSlant->"Italic"]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Subsubsection"],
    CellDingbat->None,
    CellMargins->{{22, Inherited}, {8, 18}},
    CellGroupingRules->{"SectionGrouping", 50},
    PageBreakBelow->False,
    CounterIncrements->"Subsubsection",
    FontSize->12,
    FontWeight->"Plain",
    FontSlant->"Italic"],
  
  Cell[StyleData["Subsubsection", "Presentation"],
    CellDingbat->None,
    CellMargins->{{34, 10}, {11, 26}},
    LineSpacing->{1, 0},
    FontWeight->"Plain",
    FontSlant->"Italic"],
  
  Cell[StyleData["Subsubsection", "Condensed"],
    CellDingbat->None,
    CellMargins->{{17, Inherited}, {6, 12}},
    FontWeight->"Plain",
    FontSlant->"Italic"],
  
  Cell[StyleData["Subsubsection", "Printout"],
    CellDingbat->None,
    CellMargins->{{9, 0}, {7, 14}},
    FontWeight->"Plain",
    FontSlant->"Italic"]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Styles for Body Text", "Section"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Text"],
    CellMargins->{{12, 10}, {7, 7}},
    LineSpacing->{1, 3},
    CounterIncrements->"Text"],
  
  Cell[StyleData["Text", "Presentation"],
    CellMargins->{{18, 10}, {10, 10}},
    LineSpacing->{1, 5}],
  
  Cell[StyleData["Text", "Condensed"],
    CellMargins->{{8, 10}, {6, 6}},
    LineSpacing->{1, 1}],
  
  Cell[StyleData["Text", "Printout"],
    CellMargins->{{2, 2}, {6, 6}},
    LineSpacing->{2, 3}]
  }, Open  ]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["SmallText"],
    CellMargins->{{12, 10}, {6, 6}},
    LineSpacing->{1, 3},
    CounterIncrements->"SmallText",
    FontFamily->"Helvetica",
    FontSize->9],
  
  Cell[StyleData["SmallText", "Presentation"],
    CellMargins->{{24, 10}, {8, 8}},
    LineSpacing->{1, 5},
    FontSize->12],
  
  Cell[StyleData["SmallText", "Condensed"],
    CellMargins->{{8, 10}, {5, 5}},
    LineSpacing->{1, 2},
    FontSize->9],
  
  Cell[StyleData["SmallText", "Printout"],
    CellMargins->{{2, 2}, {5, 5}},
    FontSize->7]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Styles for Input/Output", "Section"],
  
  Cell["\<\
The cells in this section define styles used for input and output \
to the kernel.  Be careful when modifying, renaming, or removing these \
styles, because the front end associates special meanings with these style \
names.\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Input"],
    CellMargins->{{45, 10}, {5, 7}},
    Evaluatable->True,
    CellGroupingRules->"InputGrouping",
    CellHorizontalScrolling->True,
    PageBreakWithin->False,
    GroupPageBreakWithin->False,
    CellLabelMargins->{{11, Inherited}, {Inherited, Inherited}},
    DefaultFormatType->DefaultInputFormatType,
    AutoItalicWords->{},
    FormatType->InputForm,
    ShowStringCharacters->True,
    NumberMarks->True,
    CounterIncrements->"Input",
    FontWeight->"Bold"],
  
  Cell[StyleData["Input", "Presentation"],
    CellMargins->{{72, Inherited}, {8, 10}},
    LineSpacing->{1, 0}],
  
  Cell[StyleData["Input", "Condensed"],
    CellMargins->{{40, 10}, {2, 3}}],
  
  Cell[StyleData["Input", "Printout"],
    CellMargins->{{39, 0}, {4, 6}},
    FontSize->9]
  }, Closed]],
  
  Cell[StyleData["InputOnly"],
    Evaluatable->True,
    CellGroupingRules->"InputGrouping",
    CellHorizontalScrolling->True,
    DefaultFormatType->DefaultInputFormatType,
    AutoItalicWords->{},
    FormatType->InputForm,
    ShowStringCharacters->True,
    NumberMarks->True,
    CounterIncrements->"Input",
    StyleMenuListing->None,
    FontWeight->"Bold"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Output"],
    CellMargins->{{47, 10}, {7, 5}},
    CellEditDuplicate->True,
    CellGroupingRules->"OutputGrouping",
    CellHorizontalScrolling->True,
    PageBreakWithin->False,
    GroupPageBreakWithin->False,
    GeneratedCell->True,
    CellAutoOverwrite->True,
    CellLabelMargins->{{11, Inherited}, {Inherited, Inherited}},
    DefaultFormatType->DefaultOutputFormatType,
    AutoItalicWords->{},
    FormatType->InputForm,
    CounterIncrements->"Output"],
  
  Cell[StyleData["Output", "Presentation"],
    CellMargins->{{72, Inherited}, {10, 8}},
    LineSpacing->{1, 0}],
  
  Cell[StyleData["Output", "Condensed"],
    CellMargins->{{41, Inherited}, {3, 2}}],
  
  Cell[StyleData["Output", "Printout"],
    CellMargins->{{39, 0}, {6, 4}},
    FontSize->9]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Message"],
    CellMargins->{{45, Inherited}, {Inherited, Inherited}},
    CellGroupingRules->"OutputGrouping",
    PageBreakWithin->False,
    GroupPageBreakWithin->False,
    GeneratedCell->True,
    CellAutoOverwrite->True,
    ShowCellLabel->False,
    CellLabelMargins->{{11, Inherited}, {Inherited, Inherited}},
    DefaultFormatType->DefaultOutputFormatType,
    AutoItalicWords->{},
    FormatType->InputForm,
    CounterIncrements->"Message",
    StyleMenuListing->None,
    FontColor->RGBColor[0, 0, 1]],
  
  Cell[StyleData["Message", "Presentation"],
    CellMargins->{{72, Inherited}, {Inherited, Inherited}},
    LineSpacing->{1, 0}],
  
  Cell[StyleData["Message", "Condensed"],
    CellMargins->{{41, Inherited}, {Inherited, Inherited}}],
  
  Cell[StyleData["Message", "Printout"],
    CellMargins->{{39, Inherited}, {Inherited, Inherited}},
    FontSize->8,
    FontColor->GrayLevel[0]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Print"],
    CellMargins->{{45, Inherited}, {Inherited, Inherited}},
    CellGroupingRules->"OutputGrouping",
    CellHorizontalScrolling->True,
    PageBreakWithin->False,
    GroupPageBreakWithin->False,
    GeneratedCell->True,
    CellAutoOverwrite->True,
    ShowCellLabel->False,
    CellLabelMargins->{{11, Inherited}, {Inherited, Inherited}},
    DefaultFormatType->DefaultOutputFormatType,
    AutoItalicWords->{},
    FormatType->InputForm,
    CounterIncrements->"Print",
    StyleMenuListing->None],
  
  Cell[StyleData["Print", "Presentation"],
    CellMargins->{{72, Inherited}, {Inherited, Inherited}},
    LineSpacing->{1, 0}],
  
  Cell[StyleData["Print", "Condensed"],
    CellMargins->{{41, Inherited}, {Inherited, Inherited}}],
  
  Cell[StyleData["Print", "Printout"],
    CellMargins->{{39, Inherited}, {Inherited, Inherited}},
    FontSize->8]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Graphics"],
    CellMargins->{{4, Inherited}, {Inherited, Inherited}},
    CellGroupingRules->"GraphicsGrouping",
    CellHorizontalScrolling->True,
    PageBreakWithin->False,
    GeneratedCell->True,
    CellAutoOverwrite->True,
    ShowCellLabel->False,
    DefaultFormatType->DefaultOutputFormatType,
    FormatType->InputForm,
    CounterIncrements->"Graphics",
    ImageMargins->{{43, Inherited}, {Inherited, 0}},
    StyleMenuListing->None],
  
  Cell[StyleData["Graphics", "Presentation"],
    ImageMargins->{{62, Inherited}, {Inherited, 0}}],
  
  Cell[StyleData["Graphics", "Condensed"],
    ImageSize->{175, 175},
    ImageMargins->{{38, Inherited}, {Inherited, 0}}],
  
  Cell[StyleData["Graphics", "Printout"],
    ImageSize->{250, 250},
    ImageMargins->{{30, Inherited}, {Inherited, 0}},
    FontSize->9]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["CellLabel"],
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->9,
    FontColor->RGBColor[0, 0, 1]],
  
  Cell[StyleData["CellLabel", "Presentation"],
    FontSize->12],
  
  Cell[StyleData["CellLabel", "Condensed"],
    FontSize->9],
  
  Cell[StyleData["CellLabel", "Printout"],
    FontFamily->"Courier",
    FontSize->8,
    FontSlant->"Italic",
    FontColor->GrayLevel[0]]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Formulas and Programming", "Section"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["InlineFormula"],
    PageWidth->PaperWidth,
    CellMargins->{{10, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    ScriptLevel->1,
    SingleLetterItalics->True],
  
  Cell[StyleData["InlineFormula", "Presentation"],
    PageWidth->PaperWidth,
    CellMargins->{{24, 10}, {10, 10}},
    LineSpacing->{1, 5}],
  
  Cell[StyleData["InlineFormula", "Condensed"],
    PageWidth->PaperWidth,
    CellMargins->{{8, 10}, {6, 6}},
    LineSpacing->{1, 1}],
  
  Cell[StyleData["InlineFormula", "Printout"],
    PageWidth->PaperWidth,
    CellMargins->{{2, 0}, {6, 6}},
    LineSpacing->{2, 3}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["DisplayFormula"],
    PageWidth->PaperWidth,
    CellMargins->{{42, Inherited}, {Inherited, Inherited}},
    CellHorizontalScrolling->True,
    LineSpacing->{2, 3},
    ScriptLevel->0,
    SingleLetterItalics->True,
    StyleMenuListing->None,
    UnderoverscriptBoxOptions->{LimitsPositioning->True}],
  
  Cell[StyleData["DisplayFormula", "Presentation"],
    PageWidth->PaperWidth,
    LineSpacing->{2, 3}],
  
  Cell[StyleData["DisplayFormula", "Condensed"],
    PageWidth->PaperWidth,
    LineSpacing->{2, 3}],
  
  Cell[StyleData["DisplayFormula", "Printout"],
    PageWidth->PaperWidth,
    LineSpacing->{2, 3}]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Styles for Automatic Numbering", "Section"],
  
  Cell["\<\
The following styles are useful for numbered equations, figures, \
etc.  They automatically give the cell a FrameLabel containing a reference to \
a particular counter, and also increment that counter.\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["NumberedEquation"],
    CellMargins->{{55, 85}, {Inherited, Inherited}},
    CellFrameLabels->{{None, Cell[ 
            TextData[ {"(", 
              CounterBox[ "NumberedEquation"], ")"}]]}, {None, None}},
    DefaultFormatType->DefaultInputFormatType,
    CounterIncrements->"NumberedEquation",
    FormatTypeAutoConvert->False,
    FontFamily->"Times"],
  
  Cell[StyleData["NumberedEquation", "Presentation"],
    CellMargins->{{60, 10}, {Inherited, 6}},
    LineSpacing->{1, 0}],
  
  Cell[StyleData["NumberedEquation", "Printout"],
    CellMargins->{{18, 4}, {4, 4}}]
  }, Open  ]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["NumberedFigure"],
    CellMargins->{{55, 95}, {Inherited, Inherited}},
    CellFrameLabels->{{None, None}, {Cell[ 
            TextData[ {"Figure ", 
              CounterBox[ "NumberedFigure"]}], FontWeight -> "Bold"], None}},
    CounterIncrements->"NumberedFigure",
    FormatTypeAutoConvert->False,
    FontFamily->"Times"],
  
  Cell[StyleData["NumberedFigure", "Presentation"],
    CellMargins->{{60, 80}, {Inherited, 6}},
    LineSpacing->{1, 0}],
  
  Cell[StyleData["NumberedFigure", "Printout"],
    CellMargins->{{18, 80}, {4, 4}},
    FontSize->8]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["NumberedTable"],
    CellMargins->{{55, 95}, {Inherited, Inherited}},
    CellFrameLabels->{{None, None}, {Cell[ 
            TextData[ {"Table ", 
              CounterBox[ "NumberedTable"]}], FontWeight -> "Bold"], None}},
    TextAlignment->Center,
    CounterIncrements->"NumberedTable",
    FormatTypeAutoConvert->False,
    FontFamily->"Times"],
  
  Cell[StyleData["NumberedTable", "Presentation"],
    CellMargins->{{60, 80}, {Inherited, 6}},
    LineSpacing->{1, 0}],
  
  Cell[StyleData["NumberedTable", "Printout"],
    CellMargins->{{18, 80}, {4, 4}},
    FontSize->8]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Styles for Headers and Footers", "Section"],
  
  Cell[StyleData["Header"],
    CellMargins->{{0, 0}, {4, 1}},
    StyleMenuListing->None,
    FontSize->10,
    FontSlant->"Italic"],
  
  Cell[StyleData["Footer"],
    CellMargins->{{0, 0}, {0, 4}},
    StyleMenuListing->None,
    FontSize->9,
    FontSlant->"Italic"],
  
  Cell[StyleData["PageNumber"],
    CellMargins->{{0, 0}, {4, 1}},
    StyleMenuListing->None,
    FontFamily->"Times",
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Palette Styles", "Section"],
  
  Cell["\<\
The cells below define styles that define standard \
ButtonFunctions, for use in palette buttons.\
\>", "Text"],
  
  Cell[StyleData["Paste"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`NotebookApply[ 
          FrontEnd`InputNotebook[ ], #, After]}]&)}],
  
  Cell[StyleData["Evaluate"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`NotebookApply[ 
          FrontEnd`InputNotebook[ ], #, All], 
        SelectionEvaluate[ 
          FrontEnd`InputNotebook[ ], All]}]&)}],
  
  Cell[StyleData["EvaluateCell"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`NotebookApply[ 
          FrontEnd`InputNotebook[ ], #, All], 
        FrontEnd`SelectionMove[ 
          FrontEnd`InputNotebook[ ], All, Cell, 1], 
        FrontEnd`SelectionEvaluateCreateCell[ 
          FrontEnd`InputNotebook[ ], All]}]&)}],
  
  Cell[StyleData["CopyEvaluate"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`SelectionCreateCell[ 
          FrontEnd`InputNotebook[ ], All], 
        FrontEnd`NotebookApply[ 
          FrontEnd`InputNotebook[ ], #, All], 
        FrontEnd`SelectionEvaluate[ 
          FrontEnd`InputNotebook[ ], All]}]&)}],
  
  Cell[StyleData["CopyEvaluateCell"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`SelectionCreateCell[ 
          FrontEnd`InputNotebook[ ], All], 
        FrontEnd`NotebookApply[ 
          FrontEnd`InputNotebook[ ], #, All], 
        FrontEnd`SelectionEvaluateCreateCell[ 
          FrontEnd`InputNotebook[ ], All]}]&)}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Hyperlink Styles", "Section"],
  
  Cell["\<\
The cells below define styles useful for making hypertext \
ButtonBoxes.  The \"Hyperlink\" style is for links within the same Notebook, \
or between Notebooks.\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Hyperlink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontColor->RGBColor[0, 0, 1],
    FontVariations->{"Underline"->True},
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`NotebookLocate[ #2]}]&),
    Active->True,
    ButtonNote->ButtonData}],
  
  Cell[StyleData["Hyperlink", "Presentation"]],
  
  Cell[StyleData["Hyperlink", "Condensed"]],
  
  Cell[StyleData["Hyperlink", "Printout"],
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Open  ]],
  
  Cell["\<\
The following styles are for linking automatically to the on-line \
help system.\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["MainBookLink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontColor->RGBColor[0, 0, 1],
    FontVariations->{"Underline"->True},
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`HelpBrowserLookup[ "MainBook", #]}]&),
    Active->True,
    ButtonFrame->"None"}],
  
  Cell[StyleData["MainBookLink", "Presentation"]],
  
  Cell[StyleData["MainBookLink", "Condensed"]],
  
  Cell[StyleData["MainBookLink", "Printout"],
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["AddOnsLink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontFamily->"Courier",
    FontColor->RGBColor[0, 0, 1],
    FontVariations->{"Underline"->True},
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`HelpBrowserLookup[ "AddOns", #]}]&),
    Active->True,
    ButtonFrame->"None"}],
  
  Cell[StyleData["AddOnsLink", "Presentation"]],
  
  Cell[StyleData["AddOnsLink", "Condensed"]],
  
  Cell[StyleData["AddOnLink", "Printout"],
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["RefGuideLink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontFamily->"Courier",
    FontColor->RGBColor[0, 0, 1],
    FontVariations->{"Underline"->True},
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`HelpBrowserLookup[ "RefGuideLink", #]}]&),
    Active->True,
    ButtonFrame->"None"}],
  
  Cell[StyleData["RefGuideLink", "Presentation"]],
  
  Cell[StyleData["RefGuideLink", "Condensed"]],
  
  Cell[StyleData["RefGuideLink", "Printout"],
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["GettingStartedLink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontColor->RGBColor[0, 0, 1],
    FontVariations->{"Underline"->True},
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`HelpBrowserLookup[ "GettingStarted", #]}]&),
    Active->True,
    ButtonFrame->"None"}],
  
  Cell[StyleData["GettingStartedLink", "Presentation"]],
  
  Cell[StyleData["GettingStartedLink", "Condensed"]],
  
  Cell[StyleData["GettingStartedLink", "Printout"],
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["OtherInformationLink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontColor->RGBColor[0, 0, 1],
    FontVariations->{"Underline"->True},
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`HelpBrowserLookup[ "OtherInformation", #]}]&),
    Active->True,
    ButtonFrame->"None"}],
  
  Cell[StyleData["OtherInformationLink", "Presentation"]],
  
  Cell[StyleData["OtherInformationLink", "Condensed"]],
  
  Cell[StyleData["OtherInformationLink", "Printout"],
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Closed]]
  }, Open  ]],
  
  Cell[CellGroupData[{
  
  Cell["Placeholder Styles", "Section"],
  
  Cell["\<\
The cells below define styles useful for making placeholder \
objects in palette templates.\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Placeholder"],
    Editable->False,
    Selectable->False,
    StyleBoxAutoDelete->True,
    Placeholder->True,
    StyleMenuListing->None],
  
  Cell[StyleData["Placeholder", "Presentation"]],
  
  Cell[StyleData["Placeholder", "Condensed"]],
  
  Cell[StyleData["Placeholder", "Printout"]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["SelectionPlaceholder"],
    Editable->False,
    Selectable->False,
    StyleBoxAutoDelete->True,
    Placeholder->PrimaryPlaceholder,
    StyleMenuListing->None,
    DrawHighlighted->True],
  
  Cell[StyleData["SelectionPlaceholder", "Presentation"]],
  
  Cell[StyleData["SelectionPlaceholder", "Condensed"]],
  
  Cell[StyleData["SelectionPlaceholder", "Printout"]]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["FormatType Styles", "Section"],
  
  Cell["\<\
The cells below define styles that are mixed in with the styles \
of most cells.  If a cell's FormatType matches the name of one of the styles \
defined below, then that style is applied between the cell's style and its \
own options.\
\>", "Text"],
  
  Cell[StyleData["CellExpression"],
    PageWidth->Infinity,
    CellMargins->{{6, Inherited}, {Inherited, Inherited}},
    ShowCellLabel->False,
    ShowSpecialCharacters->False,
    AllowInlineCells->False,
    AutoItalicWords->{},
    StyleMenuListing->None,
    FontFamily->"Courier",
    Background->GrayLevel[1]],
  
  Cell[StyleData["InputForm"],
    AllowInlineCells->False,
    StyleMenuListing->None,
    FontFamily->"Courier"],
  
  Cell[StyleData["OutputForm"],
    PageWidth->Infinity,
    TextAlignment->Left,
    LineSpacing->{1, -5},
    StyleMenuListing->None,
    FontFamily->"Courier"],
  
  Cell[StyleData["StandardForm"],
    LineSpacing->{1.25, 0},
    StyleMenuListing->None,
    FontFamily->"Courier"],
  
  Cell[StyleData["TraditionalForm"],
    LineSpacing->{1.25, 0},
    SingleLetterItalics->True,
    TraditionalFunctionNotation->True,
    DelimiterMatching->None,
    StyleMenuListing->None],
  
  Cell["\<\
The style defined below is mixed in to any cell that is in an \
inline cell within another.\
\>", "Text"],
  
  Cell[StyleData["InlineCell"],
    TextAlignment->Left,
    ScriptLevel->1,
    StyleMenuListing->None],
  
  Cell[StyleData["InlineCellEditing"],
    StyleMenuListing->None,
    Background->RGBColor[1, 0.749996, 0.8]]
  }, Closed]]
  }, Open  ]],
  
  Cell[CellGroupData[{
  
  Cell["Notation Package Styles", "Section",
    GeneratedCell->True,
    CellTags->"NotationPackage"],
  
  Cell["\<\
The cells below define certain styles needed by the Notation \
package. These styles serve to make visible otherwise invisible \
tagboxes.\
\>", "Text",
    GeneratedCell->True,
    CellTags->"NotationPackage"],
  
  Cell[StyleData["NotationTemplateStyle"],
    GeneratedCell->True,
    StyleMenuListing->None,
    Background->RGBColor[1, 1, 0.850004],
    TagBoxOptions->{SyntaxForm->"symbol"},
    CellTags->"NotationPackage"],
  
  Cell[StyleData["NotationPatternWrapperStyle"],
    GeneratedCell->True,
    StyleMenuListing->None,
    Background->RGBColor[1, 0.900008, 0.979995],
    TagBoxOptions->{SyntaxForm->"symbol"},
    CellTags->"NotationPackage"],
  
  Cell[StyleData["NotationMadeBoxesWrapperStyle"],
    GeneratedCell->True,
    StyleMenuListing->None,
    Background->RGBColor[0.900008, 0.889998, 1],
    TagBoxOptions->{SyntaxForm->"symbol"},
    CellTags->"NotationPackage"]
  }, Closed]]
  }],
MacintoshSystemPageSetup->"\<\
00<0004/0B`000002mT8o?mooh<<H`Ui0fL5:0?l0080004/0B`000000]P2:001
0000I00000400`<300000BL?00400@VQQG0000000000060801T1T00000000000
00000000000000000000000000000000\>"
]


(***********************************************************************
Cached data follows.  If you edit this Notebook file directly, not using
Mathematica, you must remove the line containing CacheID at the top of 
the file.  The cache data will then be recreated when you save this file 
from within Mathematica.
***********************************************************************)

(*CellTagsOutline
CellTagsIndex->{
  "Abstract"->{
    Cell[3274, 107, 179, 4, 38, "Subtitle",
      PageBreakAbove->True,
      CellTags->"Abstract"]},
  "Introduction"->{
    Cell[4700, 139, 189, 4, 38, "Subtitle",
      PageBreakAbove->True,
      CellTags->"Introduction"]},
  "A general notation"->{
    Cell[15719, 403, 226, 4, 38, "Subtitle",
      PageBreakAbove->True,
      CellTags->"A general notation"]},
  "Contexts and positions"->{
    Cell[16431, 421, 175, 2, 31, "Subsubtitle",
      CellTags->"Contexts and positions"]},
  "Describing genotypes and populations"->{
    Cell[24306, 597, 176, 2, 31, "Subsubtitle",
      CellTags->"Describing genotypes and populations"]},
  "zetaDefn"->{
    Cell[27840, 678, 348, 9, 76, "NumberedEquation",
      CellTags->"zetaDefn"]},
  "zetaProductDefn"->{
    Cell[29464, 725, 509, 15, 76, "NumberedEquation",
      CellTags->"zetaProductDefn"]},
  "DDefn"->{
    Cell[30606, 756, 549, 16, 76, "NumberedEquation",
      CellTags->"DDefn"]},
  "genoFreqFromMoments"->{
    Cell[36489, 930, 1124, 27, 104, "NumberedEquation",
      CellTags->"genoFreqFromMoments"]},
  "reductionFormula"->{
    Cell[42010, 1070, 740, 14, 92, "NumberedEquation",
      CellTags->"reductionFormula"]},
  "Phenotypes"->{
    Cell[43414, 1105, 160, 2, 31, "Subsubtitle",
      CellTags->"Phenotypes"]},
  "phenotypicDeterminationInGeneral"->{
    Cell[43976, 1119, 582, 16, 47, "NumberedEquation",
      CellTags->"phenotypicDeterminationInGeneral"]},
  "Evolution by selection and transmission"->{
    Cell[49013, 1255, 243, 4, 38, "Subtitle",
      PageBreakAbove->True,
      CellTags->"Evolution by selection and transmission"]},
  "Selection"->{
    Cell[49741, 1274, 121, 2, 31, "Subsubtitle",
      CellTags->"Selection"]},
  "fitnessDefinition"->{
    Cell[55120, 1408, 1394, 37, 83, "NumberedEquation",
      CellTags->"fitnessDefinition"]},
  "CombiningSelectionCoefs"->{
    Cell[62982, 1616, 478, 10, 77, "NumberedEquation",
      CellTags->"CombiningSelectionCoefs"]},
  "exactChangeInDWithSelection"->{
    Cell[66226, 1714, 612, 14, 79, "NumberedEquation",
      CellTags->"exactChangeInDWithSelection"]},
  "ExactDeltaP"->{
    Cell[68582, 1775, 1126, 26, 95, "NumberedEquation",
      CellTags->"ExactDeltaP"]},
  "pqDefinition"->{
    Cell[69711, 1803, 436, 10, 76, "NumberedEquation",
      CellTags->"pqDefinition"]},
  "Transmission"->{
    Cell[71847, 1865, 128, 2, 31, "Subsubtitle",
      CellTags->"Transmission"]},
  "ExactChangeInDWithTransmissionNoVariationInT"->{
    Cell[78110, 2032, 508, 11, 78, "NumberedEquation",
      CellTags->"ExactChangeInDWithTransmissionNoVariationInT"]},
  "transmissionCoefficients"->{
    Cell[80414, 2093, 952, 23, 79, "NumberedEquation",
      CellTags->"transmissionCoefficients"]},
  "ExactChangeInDWithTransmissionWithVariationInT"->{
    Cell[81630, 2125, 1818, 41, 79, "NumberedEquation",
      CellTags->"ExactChangeInDWithTransmissionWithVariationInT"]},
  "Changing reference values"->{
    Cell[85048, 2207, 155, 2, 31, "Subsubtitle",
      CellTags->"Changing reference values"]},
  "ChangeInReferenceValueEquation"->{
    Cell[88020, 2277, 2906, 58, 171, "NumberedEquation",
      CellTags->"ChangeInReferenceValueEquation"]},
  "The QLE approximation"->{
    Cell[93347, 2398, 238, 5, 38, "Subtitle",
      PageBreakAbove->True,
      CellTags->"The QLE approximation"]},
  "Approximations for the disequilibria"->{
    Cell[97786, 2511, 174, 2, 31, "Subsubtitle",
      CellTags->"Approximations for the disequilibria"]},
  "General results"->{
    Cell[98413, 2529, 130, 2, 42, "Subsection",
      CellTags->"General results"]},
  "DPrimeAfterSelectionAtQLE"->{
    Cell[101620, 2614, 795, 15, 113, "NumberedEquation",
      CellTags->"DPrimeAfterSelectionAtQLE"]},
  "DTriplePrimeAtQLE"->{
    Cell[107893, 2800, 610, 13, 79, "NumberedEquation",
      CellTags->"DTriplePrimeAtQLE"]},
  "implicitApproximationForDAtQLE"->{
    Cell[109066, 2838, 638, 13, 79, "NumberedEquation",
      CellTags->"implicitApproximationForDAtQLE"]},
  "Autosomal genes in haploids"->{
    Cell[112432, 2924, 154, 2, 42, "Subsection",
      CellTags->"Autosomal genes in haploids"]},
  "DAtQLEInHaploids"->{
    Cell[117525, 3060, 576, 12, 82, "NumberedEquation",
      CellTags->"DAtQLEInHaploids"]},
  "Autosomal sex-linked and cytoplasmic genes in diploids"->{
    Cell[119232, 3105, 212, 3, 42, "Subsection",
      CellTags->"Autosomal sex-linked and cytoplasmic genes in diploids"]},
  "DatQLECase2"->{
    Cell[121598, 3159, 483, 11, 79, "NumberedEquation",
      CellTags->"DatQLECase2"]},
  "QLECase3Autosomes"->{
    Cell[127847, 3327, 3298, 76, 116, "NumberedEquation",
      CellTags->"QLECase3Autosomes"]},
  "TDefn"->{
    Cell[131232, 3408, 1414, 35, 78, "NumberedEquation",
      CellTags->"TDefn"]},
  "QLECase3XLinkage"->{
    Cell[136460, 3593, 4684, 106, 133, "NumberedEquation",
      CellTags->"QLECase3XLinkage"]},
  "QLECase3CytoplasmicGenes"->{
    Cell[142031, 3732, 1464, 37, 113, "NumberedEquation",
      CellTags->"QLECase3CytoplasmicGenes"]},
  "QLECase3YLinkage"->{
    Cell[144415, 3798, 999, 27, 112, "NumberedEquation",
      CellTags->"QLECase3YLinkage"]},
  "Mutation"->{
    Cell[148774, 3928, 119, 2, 31, "Subsubtitle",
      CellTags->"Mutation"]},
  "deltaPMutation"->{
    Cell[150865, 3978, 403, 10, 76, "NumberedEquation",
      CellTags->"deltaPMutation"]},
  "DAAfterMutation"->{
    Cell[151504, 3999, 500, 12, 78, "NumberedEquation",
      CellTags->"DAAfterMutation"]},
  "Migration"->{
    Cell[152493, 4025, 122, 2, 31, "Subsubtitle",
      CellTags->"Migration"]},
  "deltaPMigration"->{
    Cell[153175, 4044, 751, 19, 77, "NumberedEquation",
      CellTags->"deltaPMigration"]},
  "DAPrimeCentered"->{
    Cell[154727, 4092, 1703, 40, 79, "NumberedEquation",
      CellTags->"DAPrimeCentered"]},
  "dAProductDefn"->{
    Cell[156517, 4137, 829, 20, 77, "NumberedEquation",
      CellTags->"dAProductDefn"]},
  "DijPrimeExactAfterMigration"->{
    Cell[159786, 4228, 1765, 40, 66, "NumberedEquation",
      CellTags->"DijPrimeExactAfterMigration"]},
  "DADoublePrimeNoDisequilibriumAmongMigrants"->{
    Cell[162279, 4290, 570, 11, 64, "NumberedEquation",
      CellTags->"DADoublePrimeNoDisequilibriumAmongMigrants"]},
  "deltaDAMigrationToLeadingOrder"->{
    Cell[164304, 4347, 690, 18, 64, "NumberedEquation",
      CellTags->"deltaDAMigrationToLeadingOrder"]},
  "dAAtQLEFromExactCalculation"->{
    Cell[165945, 4395, 689, 18, 69, "NumberedEquation",
      CellTags->"dAAtQLEFromExactCalculation"]},
  "Applications"->{
    Cell[167388, 4438, 189, 4, 38, "Subtitle",
      PageBreakAbove->True,
      CellTags->"Applications"]},
  "Natural selection on an additive polygenic trait"->{
    Cell[168560, 4466, 223, 5, 31, "Subsubtitle",
      CellTags->"Natural selection on an additive polygenic trait"]},
  "ZTwoLoci"->{
    Cell[170750, 4516, 407, 9, 64, "NumberedEquation",
      CellTags->"ZTwoLoci"]},
  "GaussianFitnessFunction"->{
    Cell[171944, 4550, 311, 7, 69, "NumberedEquation",
      CellTags->"GaussianFitnessFunction"]},
  "wTwoLociAfterZetasReduced"->{
    Cell[173828, 4611, 1237, 27, 136, "NumberedEquation",
      CellTags->"wTwoLociAfterZetasReduced"]},
  "wTwoLociAfterZetasReducedTwo"->{
    Cell[175864, 4668, 1305, 27, 134, "NumberedEquation",
      CellTags->"wTwoLociAfterZetasReducedTwo"]},
  "aiForTwoLoci"->{
    Cell[178035, 4722, 504, 13, 83, "NumberedEquation",
      CellTags->"aiForTwoLoci"]},
  "aijForTwoLoci"->{
    Cell[182163, 4838, 423, 10, 81, "NumberedEquation",
      CellTags->"aijForTwoLoci"]},
  "deltaPTwoLoci"->{
    Cell[184843, 4906, 2769, 56, 192, "NumberedEquation",
      CellTags->"deltaPTwoLoci"]},
  "deltaZBarTwoLoci"->{
    Cell[188967, 5005, 853, 17, 85, "NumberedEquation",
      CellTags->"deltaZBarTwoLoci"]},
  "DijAfterSelection"->{
    Cell[191650, 5074, 2375, 41, 238, "NumberedEquation",
      CellTags->"DijAfterSelection"]},
  "DijAfterChangingReferenceValues"->{
    Cell[194843, 5139, 844, 16, 80, "NumberedEquation",
      CellTags->"DijAfterChangingReferenceValues"]},
  "Sexual selection by female choice"->{
    Cell[196939, 5189, 170, 2, 25, "Subsubtitle",
      CellTags->"Sexual selection by female choice"]},
  "Selection coefficients"->{
    Cell[200844, 5287, 144, 2, 42, "Subsection",
      CellTags->"Selection coefficients"]},
  "SexSelFitnessFunctionVersion1"->{
    Cell[204245, 5403, 943, 17, 177, "NumberedEquation",
      CellTags->"SexSelFitnessFunctionVersion1"]},
  "SexSelFitnessFunctionVersion2"->{
    Cell[205713, 5444, 2456, 58, 88, "NumberedEquation",
      CellTags->"SexSelFitnessFunctionVersion2"]},
  "SexSelSelectionCoefficient"->{
    Cell[209600, 5548, 1533, 40, 88, "NumberedEquation",
      CellTags->"SexSelSelectionCoefficient"]},
  "Haploid autosomal inheritance"->{
    Cell[212694, 5628, 158, 2, 24, "Subsection",
      CellTags->"Haploid autosomal inheritance"],
    Cell[223811, 5931, 158, 2, 42, "Subsection",
      CellTags->"Haploid autosomal inheritance"],
    Cell[238424, 6316, 149, 2, 24, "Subsection",
      CellTags->"Haploid autosomal inheritance"]},
  "SexSelGeneticCorrelationInGeneral"->{
    Cell[213165, 5640, 1564, 38, 87, "NumberedEquation",
      CellTags->"SexSelGeneticCorrelationInGeneral"]},
  "HaploidGeneticVariancesForPandT"->{
    Cell[215011, 5687, 2436, 62, 141, "NumberedEquation",
      CellTags->"HaploidGeneticVariancesForPandT"]},
  "SexSelD"->{
    Cell[218027, 5769, 3120, 80, 87, "NumberedEquation",
      CellTags->"SexSelD"]},
  "GPTandrPTInHaploids"->{
    Cell[221591, 5864, 1331, 34, 81, "NumberedEquation",
      CellTags->"GPTandrPTInHaploids"]},
  "GPTForDiploidAutosomesInTermsOfDs"->{
    Cell[224305, 5943, 3047, 70, 87, "NumberedEquation",
      CellTags->"GPTForDiploidAutosomesInTermsOfDs"]},
  "TForDiploidAutosomes"->{
    Cell[228628, 6059, 3558, 88, 130, "NumberedEquation",
      CellTags->"TForDiploidAutosomes"]},
  "SexSelDForDiploidAutosomes"->{
    Cell[233073, 6178, 4333, 109, 145, "NumberedEquation",
      CellTags->"SexSelDForDiploidAutosomes"]},
  "GmPTForXLinkageInTermsOfDs"->{
    Cell[239135, 6332, 2260, 54, 80, "NumberedEquation",
      CellTags->"GmPTForXLinkageInTermsOfDs"]},
  "TsXLinkage"->{
    Cell[243310, 6449, 3394, 89, 144, "NumberedEquation",
      CellTags->"TsXLinkage"]},
  "SexSelDsForXLinkage"->{
    Cell[246862, 6546, 3909, 95, 144, "NumberedEquation",
      CellTags->"SexSelDsForXLinkage"]},
  "GmPTAndrMPTForXLinkage"->{
    Cell[251013, 6650, 1585, 41, 81, "NumberedEquation",
      CellTags->"GmPTAndrMPTForXLinkage"]},
  "Discussion"->{
    Cell[253144, 6709, 185, 4, 38, "Subtitle",
      PageBreakAbove->True,
      CellTags->"Discussion"]},
  "QLE_Christiansen"->{
    Cell[262734, 6934, 1203, 31, 56, "NumberedEquation",
      CellTags->"QLE_Christiansen"]},
  "QLEChristainsenInOurNotation"->{
    Cell[266244, 7039, 899, 25, 51, "NumberedEquation",
      CellTags->"QLEChristainsenInOurNotation"]},
  "QLEBurger"->{
    Cell[267587, 7083, 914, 27, 54, "NumberedEquation",
      CellTags->"QLEBurger"]},
  "References"->{
    Cell[274410, 7257, 182, 4, 27, "Subtitle",
      PageBreakAbove->True,
      CellTags->"References"],
    Cell[442931, 11751, 178, 4, 38, "Subtitle",
      PageBreakAbove->True,
      CellTags->"References"]},
  "Asmussen & Orive 2000"->{
    Cell[274595, 7263, 500, 15, 93, "Text",
      CellTags->"Asmussen & Orive 2000"]},
  "Baird 1995"->{
    Cell[275098, 7280, 333, 11, 66, "Text",
      CellTags->"Baird 1995"]},
  "Barton 1983"->{
    Cell[275434, 7293, 266, 10, 39, "Text",
      CellTags->"Barton 1983"]},
  "Barton 1986"->{
    Cell[275703, 7305, 318, 11, 66, "Text",
      CellTags->"Barton 1986"]},
  "Barton 1992"->{
    Cell[276024, 7318, 384, 14, 66, "Text",
      CellTags->"Barton 1992"]},
  "Barton 1995"->{
    Cell[276411, 7334, 425, 15, 66, "Text",
      CellTags->"Barton 1995"]},
  "Barton 2000"->{
    Cell[276839, 7351, 290, 10, 39, "Text",
      CellTags->"Barton 2000"]},
  "Barton & Shpak 2000"->{
    Cell[277132, 7363, 378, 14, 66, "Text",
      CellTags->"Barton & Shpak 2000"]},
  "Barton & Turelli 1987"->{
    Cell[277513, 7379, 445, 17, 66, "Text",
      CellTags->"Barton & Turelli 1987"]},
  "Barton & Turelli 1991"->{
    Cell[277961, 7398, 355, 13, 66, "Text",
      CellTags->"Barton & Turelli 1991"]},
  "Baake 2001"->{
    Cell[278319, 7413, 512, 16, 66, "Text",
      CellTags->"Baake 2001"]},
  "Bulmer 1980"->{
    Cell[278834, 7431, 309, 10, 66, "Text",
      CellTags->"Bulmer 1980"]},
  "Burger 1991"->{
    Cell[279146, 7443, 291, 10, 39, "Text",
      CellTags->"Burger 1991"]},
  "Burger 2000"->{
    Cell[279440, 7455, 311, 11, 66, "Text",
      CellTags->"Burger 2000"]},
  "Christiansen 1987"->{
    Cell[279754, 7468, 363, 13, 66, "Text",
      CellTags->"Christiansen 1987"]},
  "Christiansen 1999"->{
    Cell[280120, 7483, 374, 11, 66, "Text",
      CellTags->"Christiansen 1999"]},
  "Dawson 1999"->{
    Cell[280497, 7496, 404, 12, 93, "Text",
      CellTags->"Dawson 1999"]},
  "Doebeli 1996"->{
    Cell[280904, 7510, 307, 11, 66, "Text",
      CellTags->"Doebeli 1996"]},
  "Ewens 1979"->{
    Cell[281214, 7523, 281, 10, 39, "Text",
      CellTags->"Ewens 1979"]},
  "Fisher 1918"->{
    Cell[281498, 7535, 300, 8, 66, "Text",
      CellTags->"Fisher 1918"]},
  "Fisher 1958"->{
    Cell[281801, 7545, 300, 10, 66, "Text",
      CellTags->"Fisher 1958"]},
  "Fisher 1953"->{
    Cell[282104, 7557, 291, 10, 39, "Text",
      CellTags->"Fisher 1953"]},
  "Gillespie 1981"->{
    Cell[282398, 7569, 300, 10, 39, "Text",
      CellTags->"Gillespie 1981"]},
  "Haldane 1927"->{
    Cell[282701, 7581, 351, 11, 66, "Text",
      CellTags->"Haldane 1927"]},
  "Hill & Robertson 1966"->{
    Cell[283055, 7594, 371, 14, 66, "Text",
      CellTags->"Hill & Robertson 1966"]},
  "Hudson 1990"->{
    Cell[283429, 7610, 315, 11, 66, "Text",
      CellTags->"Hudson 1990"]},
  "Kimura 1965"->{
    Cell[283747, 7623, 343, 11, 66, "Text",
      CellTags->"Kimura 1965"]},
  "Kirkpatrick 1982"->{
    Cell[284093, 7636, 306, 11, 39, "Text",
      CellTags->"Kirkpatrick 1982"]},
  "Kirkpatrick & Barton 1997"->{
    Cell[284402, 7649, 405, 14, 66, "Text",
      CellTags->"Kirkpatrick & Barton 1997"]},
  "Kirkpatrick & Ryan 1991"->{
    Cell[284810, 7665, 379, 14, 66, "Text",
      CellTags->"Kirkpatrick & Ryan 1991"]},
  "Kirkpatrick & Servedio 1999"->{
    Cell[285192, 7681, 379, 14, 66, "Text",
      CellTags->"Kirkpatrick & Servedio 1999"]},
  "Kondrashov 1984"->{
    Cell[285574, 7697, 403, 14, 66, "Text",
      CellTags->"Kondrashov 1984"]},
  "Lande 1981"->{
    Cell[285980, 7713, 329, 11, 66, "Text",
      CellTags->"Lande 1981"]},
  "Nagylaki 1976"->{
    Cell[286312, 7726, 294, 10, 39, "Text",
      CellTags->"Nagylaki 1976"]},
  "Nagylaki 1993"->{
    Cell[286609, 7738, 310, 11, 66, "Text",
      CellTags->"Nagylaki 1993"],
    Cell[286922, 7751, 465, 18, 66, "Text",
      CellTags->"Nagylaki 1993"]},
  "Otto & Michalakis 1998"->{
    Cell[287390, 7771, 394, 14, 66, "Text",
      CellTags->"Otto & Michalakis 1998"]},
  "Price 1970"->{
    Cell[287787, 7787, 269, 10, 39, "Text",
      CellTags->"Price 1970"]},
  "Shapiro et al 1994"->{
    Cell[288059, 7799, 524, 20, 66, "Text",
      CellTags->"Shapiro et al 1994"]},
  "Shpak & Kondrashov 1999"->{
    Cell[288586, 7821, 406, 14, 66, "Text",
      CellTags->"Shpak & Kondrashov 1999"]},
  "Sniegowski et al 2000"->{
    Cell[288995, 7837, 435, 17, 66, "Text",
      CellTags->"Sniegowski et al 2000"]},
  "Turelli & Barton 1990"->{
    Cell[289433, 7856, 368, 14, 66, "Text",
      CellTags->"Turelli & Barton 1990"]},
  "Turelli & Barton 1994"->{
    Cell[289804, 7872, 404, 14, 66, "Text",
      CellTags->"Turelli & Barton 1994"]},
  "Wright 1931"->{
    Cell[290211, 7888, 278, 10, 39, "Text",
      CellTags->"Wright 1931"]},
  "Wright 1935"->{
    Cell[290492, 7900, 298, 11, 39, "Text",
      CellTags->"Wright 1935"]},
  "Wolfram 1996"->{
    Cell[290793, 7913, 298, 10, 66, "Text",
      CellTags->"Wolfram 1996"]},
  "Appendices"->{
    Cell[291128, 7928, 182, 4, 38, "Subtitle",
      PageBreakAbove->True,
      CellTags->"Appendices"]},
  "FitnessPolynomialFor2Loci"->{
    Cell[293627, 8004, 3573, 92, 92, "NumberedEquation",
      CellTags->"FitnessPolynomialFor2Loci"]},
  "FitnessDefnFor2Loci"->{
    Cell[297446, 8107, 22274, 494, 412, "NumberedEquation",
      CellTags->"FitnessDefnFor2Loci"]},
  "SelectionCoefs2Loci"->{
    Cell[320308, 8621, 2923, 77, 119, "NumberedEquation",
      CellTags->"SelectionCoefs2Loci"]},
  "deltaPI2LociVersion1"->{
    Cell[325535, 8775, 9534, 213, 287, "NumberedEquation",
      CellTags->"deltaPI2LociVersion1"]},
  "Dij2LociQLE"->{
    Cell[335466, 9000, 2534, 63, 52, "NumberedEquation",
      CellTags->"Dij2LociQLE"]},
  "WBar2LociQLE"->{
    Cell[338612, 9087, 601, 16, 47, "NumberedEquation",
      CellTags->"WBar2LociQLE"]},
  "deltaPI2LociVersion2"->{
    Cell[339480, 9114, 3331, 79, 172, "NumberedEquation",
      CellTags->"deltaPI2LociVersion2"]},
  "Appendix: Mutation"->{
    Cell[342848, 9198, 134, 2, 24, "Section",
      CellTags->"Appendix: Mutation"]},
  "DANextByMutationExactlyDefnVersion1"->{
    Cell[343140, 9208, 595, 13, 78, "NumberedEquation",
      CellTags->"DANextByMutationExactlyDefnVersion1"]},
  "deltaPiByMutation"->{
    Cell[344755, 9253, 425, 10, 77, "NumberedEquation",
      CellTags->"deltaPiByMutation"]},
  "delXForMutation"->{
    Cell[346532, 9312, 383, 7, 57, "NumberedEquation",
      CellTags->"delXForMutation"]},
  "DANextByMutationExactlyDefnVersion2"->{
    Cell[347225, 9332, 1132, 22, 140, "NumberedEquation",
      CellTags->"DANextByMutationExactlyDefnVersion2"]},
  "Appendix: Migration"->{
    Cell[348951, 9377, 136, 2, 42, "Section",
      CellTags->"Appendix: Migration"]},
  "DAPrimeDefn"->{
    Cell[350339, 9417, 865, 21, 78, "NumberedEquation",
      CellTags->"DAPrimeDefn"]},
  "DPrimeInTermsOfDMR"->{
    Cell[351993, 9463, 2512, 55, 124, "NumberedEquation",
      CellTags->"DPrimeInTermsOfDMR"]},
  "DMRFormula"->{
    Cell[356752, 9587, 881, 24, 78, "NumberedEquation",
      CellTags->"DMRFormula"]},
  "DAPrimeUncenteredResult"->{
    Cell[358706, 9647, 1223, 32, 79, "NumberedEquation",
      CellTags->"DAPrimeUncenteredResult"]},
  "Appendix: Mathematica"->{
    Cell[362069, 9755, 212, 7, 42, "Section",
      CellTags->"Appendix: Mathematica"]},
  "Summary of notation"->{
    Cell[395183, 10482, 170, 3, 42, "Subsection",
      PageBreakAbove->True,
      CellTags->"Summary of notation"]},
  "Transmission coefficients for various forms of recombination"->{
    Cell[416273, 11004, 265, 6, 42, "Subsection",
      PageBreakAbove->True,
      CellTags->
      "Transmission coefficients for various forms of recombination"]},
  "Measures of D"->{
    Cell[420081, 11127, 195, 4, 42, "Subsection",
      PageBreakAbove->True,
      CellTags->"Measures of D"]}
  }
*)

(*CellTagsIndex
CellTagsIndex->{
  {"Abstract", 542148, 14429},
  {"Introduction", 542270, 14433},
  {"A general notation", 542402, 14437},
  {"Contexts and positions", 542545, 14441},
  {"Describing genotypes and populations", 542681, 14444},
  {"zetaDefn", 542803, 14447},
  {"zetaProductDefn", 542909, 14450},
  {"DDefn", 543013, 14453},
  {"genoFreqFromMoments", 543121, 14456},
  {"reductionFormula", 543242, 14459},
  {"Phenotypes", 543353, 14462},
  {"phenotypicDeterminationInGeneral", 543474, 14465},
  {"Evolution by selection and transmission", 543630, 14468},
  {"Selection", 543782, 14472},
  {"fitnessDefinition", 543887, 14475},
  {"CombiningSelectionCoefs", 544013, 14478},
  {"exactChangeInDWithSelection", 544148, 14481},
  {"ExactDeltaP", 544271, 14484},
  {"pqDefinition", 544380, 14487},
  {"Transmission", 544489, 14490},
  {"ExactChangeInDWithTransmissionNoVariationInT", 544624, 14493},
  {"transmissionCoefficients", 544777, 14496},
  {"ExactChangeInDWithTransmissionWithVariationInT", 544932, 14499},
  {"Changing reference values", 545089, 14502},
  {"ChangeInReferenceValueEquation", 545223, 14505},
  {"The QLE approximation", 545361, 14508},
  {"Approximations for the disequilibria", 545522, 14512},
  {"General results", 545652, 14515},
  {"DPrimeAfterSelectionAtQLE", 545770, 14518},
  {"DTriplePrimeAtQLE", 545899, 14521},
  {"implicitApproximationForDAtQLE", 546032, 14524},
  {"Autosomal genes in haploids", 546175, 14527},
  {"DAtQLEInHaploids", 546297, 14530},
  {"Autosomal sex-linked and cytoplasmic genes in diploids", 546453, 14533},
  {"DatQLECase2", 546597, 14536},
  {"QLECase3Autosomes", 546711, 14539},
  {"TDefn", 546821, 14542},
  {"QLECase3XLinkage", 546929, 14545},
  {"QLECase3CytoplasmicGenes", 547058, 14548},
  {"QLECase3YLinkage", 547186, 14551},
  {"Mutation", 547297, 14554},
  {"deltaPMutation", 547399, 14557},
  {"DAAfterMutation", 547514, 14560},
  {"Migration", 547624, 14563},
  {"deltaPMigration", 547728, 14566},
  {"DAPrimeCentered", 547844, 14569},
  {"dAProductDefn", 547959, 14572},
  {"DijPrimeExactAfterMigration", 548085, 14575},
  {"DADoublePrimeNoDisequilibriumAmongMigrants", 548241, 14578},
  {"deltaDAMigrationToLeadingOrder", 548399, 14581},
  {"dAAtQLEFromExactCalculation", 548542, 14584},
  {"Applications", 548667, 14587},
  {"Natural selection on an additive polygenic trait", 548832, 14591},
  {"ZTwoLoci", 548968, 14594},
  {"GaussianFitnessFunction", 549084, 14597},
  {"wTwoLociAfterZetasReduced", 549217, 14600},
  {"wTwoLociAfterZetasReducedTwo", 549358, 14603},
  {"aiForTwoLoci", 549486, 14606},
  {"aijForTwoLoci", 549597, 14609},
  {"deltaPTwoLoci", 549709, 14612},
  {"deltaZBarTwoLoci", 549826, 14615},
  {"DijAfterSelection", 549945, 14618},
  {"DijAfterChangingReferenceValues", 550081, 14621},
  {"Sexual selection by female choice", 550231, 14624},
  {"Selection coefficients", 550366, 14627},
  {"SexSelFitnessFunctionVersion1", 550496, 14630},
  {"SexSelFitnessFunctionVersion2", 550641, 14633},
  {"SexSelSelectionCoefficient", 550783, 14636},
  {"Haploid autosomal inheritance", 550925, 14639},
  {"SexSelGeneticCorrelationInGeneral", 551264, 14646},
  {"HaploidGeneticVariancesForPandT", 551415, 14649},
  {"SexSelD", 551541, 14652},
  {"GPTandrPTInHaploids", 551654, 14655},
  {"GPTForDiploidAutosomesInTermsOfDs", 551793, 14658},
  {"TForDiploidAutosomes", 551933, 14661},
  {"SexSelDForDiploidAutosomes", 552067, 14664},
  {"GmPTForXLinkageInTermsOfDs", 552208, 14667},
  {"TsXLinkage", 552331, 14670},
  {"SexSelDsForXLinkage", 552448, 14673},
  {"GmPTAndrMPTForXLinkage", 552577, 14676},
  {"Discussion", 552696, 14679},
  {"QLE_Christiansen", 552827, 14683},
  {"QLEChristainsenInOurNotation", 552958, 14686},
  {"QLEBurger", 553081, 14689},
  {"References", 553186, 14692},
  {"Asmussen & Orive 2000", 553429, 14699},
  {"Baird 1995", 553534, 14702},
  {"Barton 1983", 553629, 14705},
  {"Barton 1986", 553725, 14708},
  {"Barton 1992", 553821, 14711},
  {"Barton 1995", 553917, 14714},
  {"Barton 2000", 554013, 14717},
  {"Barton & Shpak 2000", 554117, 14720},
  {"Barton & Turelli 1987", 554231, 14723},
  {"Barton & Turelli 1991", 554347, 14726},
  {"Baake 2001", 554452, 14729},
  {"Bulmer 1980", 554547, 14732},
  {"Burger 1991", 554643, 14735},
  {"Burger 2000", 554739, 14738},
  {"Christiansen 1987", 554841, 14741},
  {"Christiansen 1999", 554949, 14744},
  {"Dawson 1999", 555051, 14747},
  {"Doebeli 1996", 555148, 14750},
  {"Ewens 1979", 555244, 14753},
  {"Fisher 1918", 555339, 14756},
  {"Fisher 1958", 555434, 14759},
  {"Fisher 1953", 555530, 14762},
  {"Gillespie 1981", 555629, 14765},
  {"Haldane 1927", 555729, 14768},
  {"Hill & Robertson 1966", 555836, 14771},
  {"Hudson 1990", 555942, 14774},
  {"Kimura 1965", 556038, 14777},
  {"Kirkpatrick 1982", 556139, 14780},
  {"Kirkpatrick & Barton 1997", 556254, 14783},
  {"Kirkpatrick & Ryan 1991", 556376, 14786},
  {"Kirkpatrick & Servedio 1999", 556500, 14789},
  {"Kondrashov 1984", 556616, 14792},
  {"Lande 1981", 556715, 14795},
  {"Nagylaki 1976", 556812, 14798},
  {"Nagylaki 1993", 556912, 14801},
  {"Otto & Michalakis 1998", 557099, 14806},
  {"Price 1970", 557205, 14809},
  {"Shapiro et al 1994", 557307, 14812},
  {"Shpak & Kondrashov 1999", 557422, 14815},
  {"Sniegowski et al 2000", 557540, 14818},
  {"Turelli & Barton 1990", 557656, 14821},
  {"Turelli & Barton 1994", 557772, 14824},
  {"Wright 1931", 557878, 14827},
  {"Wright 1935", 557974, 14830},
  {"Wolfram 1996", 558071, 14833},
  {"Appendices", 558167, 14836},
  {"FitnessPolynomialFor2Loci", 558307, 14840},
  {"FitnessDefnFor2Loci", 558438, 14843},
  {"SelectionCoefs2Loci", 558566, 14846},
  {"deltaPI2LociVersion1", 558693, 14849},
  {"Dij2LociQLE", 558813, 14852},
  {"WBar2LociQLE", 558923, 14855},
  {"deltaPI2LociVersion2", 559041, 14858},
  {"Appendix: Mutation", 559167, 14861},
  {"DANextByMutationExactlyDefnVersion1", 559296, 14864},
  {"deltaPiByMutation", 559434, 14867},
  {"delXForMutation", 559552, 14870},
  {"DANextByMutationExactlyDefnVersion2", 559687, 14873},
  {"Appendix: Migration", 559829, 14876},
  {"DAPrimeDefn", 559935, 14879},
  {"DPrimeInTermsOfDMR", 560050, 14882},
  {"DMRFormula", 560166, 14885},
  {"DAPrimeUncenteredResult", 560285, 14888},
  {"Appendix: Mathematica", 560416, 14891},
  {"Summary of notation", 560532, 14894},
  {"Transmission coefficients for various forms of recombination", 560719, \
14898},
  {"Measures of D", 560907, 14903}
  }
*)

(*NotebookFileOutline
Notebook[{

Cell[CellGroupData[{
Cell[1739, 51, 117, 1, 64, "Title"],
Cell[1859, 54, 100, 4, 39, "Text"],

Cell[CellGroupData[{
Cell[1984, 62, 92, 2, 30, "Subtitle",
  CellOpen->False],
Cell[2079, 66, 307, 11, 39, "Text"],
Cell[2389, 79, 85, 4, 66, "Text"],
Cell[2477, 85, 760, 17, 336, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[3274, 107, 179, 4, 38, "Subtitle",
  PageBreakAbove->True,
  CellTags->"Abstract"],
Cell[3456, 113, 1207, 21, 282, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[4700, 139, 189, 4, 38, "Subtitle",
  PageBreakAbove->True,
  CellTags->"Introduction"],
Cell[4892, 145, 1591, 40, 282, "Text"],
Cell[6486, 187, 724, 11, 201, "Text"],
Cell[7213, 200, 4133, 95, 741, "Text"],
Cell[11349, 297, 1800, 47, 282, "Text"],
Cell[13152, 346, 996, 20, 228, "Text"],
Cell[14151, 368, 739, 11, 201, "Text"],
Cell[14893, 381, 789, 17, 201, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[15719, 403, 226, 4, 38, "Subtitle",
  PageBreakAbove->True,
  CellTags->"A general notation"],
Cell[15948, 409, 458, 8, 120, "Text"],

Cell[CellGroupData[{
Cell[16431, 421, 175, 2, 31, "Subsubtitle",
  CellTags->"Contexts and positions"],
Cell[16609, 425, 1511, 23, 417, "Text"],
Cell[18123, 450, 520, 8, 147, "Text"],
Cell[18646, 460, 1676, 33, 363, "Text"],
Cell[20325, 495, 2258, 61, 255, "Text"],
Cell[22586, 558, 1222, 24, 282, "Text"],
Cell[23811, 584, 458, 8, 120, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[24306, 597, 176, 2, 31, "Subsubtitle",
  CellTags->"Describing genotypes and populations"],
Cell[24485, 601, 1673, 37, 282, "Text"],
Cell[26161, 640, 864, 16, 228, "Text"],
Cell[27028, 658, 809, 18, 147, "Text"],
Cell[27840, 678, 348, 9, 76, "NumberedEquation",
  CellTags->"zetaDefn"],
Cell[28191, 689, 1084, 28, 174, "Text"],
Cell[29278, 719, 183, 4, 39, "Text"],
Cell[29464, 725, 509, 15, 76, "NumberedEquation",
  CellTags->"zetaProductDefn"],
Cell[29976, 742, 627, 12, 120, "Text"],
Cell[30606, 756, 549, 16, 76, "NumberedEquation",
  CellTags->"DDefn"],
Cell[31158, 774, 1703, 52, 174, "Text"],
Cell[32864, 828, 2503, 64, 309, "Text"],
Cell[35370, 894, 1116, 34, 147, "Text"],
Cell[36489, 930, 1124, 27, 104, "NumberedEquation",
  CellTags->"genoFreqFromMoments"],
Cell[37616, 959, 1281, 31, 174, "Text"],
Cell[38900, 992, 1393, 33, 174, "Text"],
Cell[40296, 1027, 1224, 24, 255, "Text"],
Cell[41523, 1053, 484, 15, 66, "Text"],
Cell[42010, 1070, 740, 14, 92, "NumberedEquation",
  CellTags->"reductionFormula"],
Cell[42753, 1086, 624, 14, 66, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[43414, 1105, 160, 2, 31, "Subsubtitle",
  CellTags->"Phenotypes"],
Cell[43577, 1109, 396, 8, 92, "Text"],
Cell[43976, 1119, 582, 16, 47, "NumberedEquation",
  CellTags->"phenotypicDeterminationInGeneral"],
Cell[44561, 1137, 1222, 37, 120, "Text"],
Cell[45786, 1176, 2270, 50, 281, "Text"],
Cell[48059, 1228, 905, 21, 200, "Text"]
}, Closed]]
}, Open  ]],

Cell[CellGroupData[{
Cell[49013, 1255, 243, 4, 38, "Subtitle",
  PageBreakAbove->True,
  CellTags->"Evolution by selection and transmission"],
Cell[49259, 1261, 457, 9, 93, "Text"],

Cell[CellGroupData[{
Cell[49741, 1274, 121, 2, 31, "Subsubtitle",
  CellTags->"Selection"],
Cell[49865, 1278, 820, 20, 120, "Text"],
Cell[50688, 1300, 1020, 17, 282, "Text"],
Cell[51711, 1319, 1050, 26, 120, "Text"],
Cell[52764, 1347, 1146, 18, 309, "Text"],
Cell[53913, 1367, 1204, 39, 147, "Text"],
Cell[55120, 1408, 1394, 37, 83, "NumberedEquation",
  CellTags->"fitnessDefinition"],
Cell[56517, 1447, 207, 7, 39, "Text"],
Cell[56727, 1456, 1609, 47, 228, "Text"],
Cell[58339, 1505, 1690, 34, 363, "Text"],
Cell[60032, 1541, 1598, 39, 282, "Text"],
Cell[61633, 1582, 1346, 32, 201, "Text"],
Cell[62982, 1616, 478, 10, 77, "NumberedEquation",
  CellTags->"CombiningSelectionCoefs"],
Cell[63463, 1628, 2330, 71, 174, "Text"],
Cell[65796, 1701, 427, 11, 66, "Text"],
Cell[66226, 1714, 612, 14, 79, "NumberedEquation",
  CellTags->"exactChangeInDWithSelection"],
Cell[66841, 1730, 545, 10, 120, "Text"],
Cell[67389, 1742, 1190, 31, 120, "Text"],
Cell[68582, 1775, 1126, 26, 95, "NumberedEquation",
  CellTags->"ExactDeltaP"],
Cell[69711, 1803, 436, 10, 76, "NumberedEquation",
  CellTags->"pqDefinition"],
Cell[70150, 1815, 630, 15, 93, "Text"],
Cell[70783, 1832, 1027, 28, 147, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[71847, 1865, 128, 2, 31, "Subsubtitle",
  CellTags->"Transmission"],
Cell[71978, 1869, 1127, 20, 228, "Text"],
Cell[73108, 1891, 2168, 67, 174, "Text"],
Cell[75279, 1960, 1181, 26, 228, "Text"],
Cell[76463, 1988, 710, 16, 147, "Text"],
Cell[77176, 2006, 931, 24, 147, "Text"],
Cell[78110, 2032, 508, 11, 78, "NumberedEquation",
  CellTags->"ExactChangeInDWithTransmissionNoVariationInT"],
Cell[78621, 2045, 913, 22, 174, "Text"],
Cell[79537, 2069, 874, 22, 120, "Text"],
Cell[80414, 2093, 952, 23, 79, "NumberedEquation",
  CellTags->"transmissionCoefficients"],
Cell[81369, 2118, 258, 5, 66, "Text"],
Cell[81630, 2125, 1818, 41, 79, "NumberedEquation",
  CellTags->"ExactChangeInDWithTransmissionWithVariationInT"],
Cell[83451, 2168, 1560, 34, 228, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[85048, 2207, 155, 2, 31, "Subsubtitle",
  CellTags->"Changing reference values"],
Cell[85206, 2211, 1244, 18, 363, "Text"],
Cell[86453, 2231, 1564, 44, 147, "Text"],
Cell[88020, 2277, 2906, 58, 171, "NumberedEquation",
  CellTags->"ChangeInReferenceValueEquation"],
Cell[90929, 2337, 498, 11, 66, "Text"],
Cell[91430, 2350, 1868, 42, 282, "Text"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[93347, 2398, 238, 5, 38, "Subtitle",
  PageBreakAbove->True,
  CellTags->"The QLE approximation"],
Cell[93588, 2405, 857, 15, 228, "Text"],
Cell[94448, 2422, 2863, 73, 498, "Text"],
Cell[97314, 2497, 447, 10, 93, "Text"],

Cell[CellGroupData[{
Cell[97786, 2511, 174, 2, 31, "Subsubtitle",
  CellTags->"Approximations for the disequilibria"],
Cell[97963, 2515, 425, 10, 93, "Text"],

Cell[CellGroupData[{
Cell[98413, 2529, 130, 2, 42, "Subsection",
  CellTags->"General results"],
Cell[98546, 2533, 2458, 61, 444, "Text"],
Cell[101007, 2596, 610, 16, 66, "Text"],
Cell[101620, 2614, 795, 15, 113, "NumberedEquation",
  CellTags->"DPrimeAfterSelectionAtQLE"],
Cell[102418, 2631, 793, 23, 93, "Text"],
Cell[103214, 2656, 2293, 73, 120, "Text"],
Cell[105510, 2731, 2380, 67, 228, "Text"],
Cell[107893, 2800, 610, 13, 79, "NumberedEquation",
  CellTags->"DTriplePrimeAtQLE"],
Cell[108506, 2815, 557, 21, 66, "Text"],
Cell[109066, 2838, 638, 13, 79, "NumberedEquation",
  CellTags->"implicitApproximationForDAtQLE"],
Cell[109707, 2853, 790, 17, 147, "Text"],
Cell[110500, 2872, 1895, 47, 255, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[112432, 2924, 154, 2, 42, "Subsection",
  CellTags->"Autosomal genes in haploids"],
Cell[112589, 2928, 690, 18, 93, "Text"],
Cell[113282, 2948, 4103, 107, 309, "Text"],
Cell[117388, 3057, 134, 1, 39, "Text"],
Cell[117525, 3060, 576, 12, 82, "NumberedEquation",
  CellTags->"DAtQLEInHaploids"],
Cell[118104, 3074, 1091, 26, 201, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[119232, 3105, 212, 3, 42, "Subsection",
  CellTags->"Autosomal sex-linked and cytoplasmic genes in diploids"],
Cell[119447, 3110, 694, 11, 201, "Text"],
Cell[120144, 3123, 815, 19, 120, "Text"],
Cell[120962, 3144, 633, 13, 120, "Text"],
Cell[121598, 3159, 483, 11, 79, "NumberedEquation",
  CellTags->"DatQLECase2"],
Cell[122084, 3172, 1014, 20, 228, "Text"],
Cell[123101, 3194, 4297, 116, 336, "Text"],
Cell[127401, 3312, 443, 13, 66, "Text"],
Cell[127847, 3327, 3298, 76, 116, "NumberedEquation",
  CellTags->"QLECase3Autosomes"],
Cell[131148, 3405, 81, 1, 39, "Text"],
Cell[131232, 3408, 1414, 35, 78, "NumberedEquation",
  CellTags->"TDefn"],
Cell[132649, 3445, 3019, 121, 282, "Text"],
Cell[135671, 3568, 786, 23, 93, "Text"],
Cell[136460, 3593, 4684, 106, 133, "NumberedEquation",
  CellTags->"QLECase3XLinkage"],
Cell[141147, 3701, 881, 29, 66, "Text"],
Cell[142031, 3732, 1464, 37, 113, "NumberedEquation",
  CellTags->"QLECase3CytoplasmicGenes"],
Cell[143498, 3771, 593, 16, 93, "Text"],
Cell[144094, 3789, 318, 7, 66, "Text"],
Cell[144415, 3798, 999, 27, 112, "NumberedEquation",
  CellTags->"QLECase3YLinkage"],
Cell[145417, 3827, 511, 16, 39, "Text"],
Cell[145931, 3845, 856, 19, 147, "Text"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[146836, 3870, 124, 1, 31, "Subsubtitle"],
Cell[146963, 3873, 1299, 36, 200, "Text"]
}, Closed]]
}, Open  ]],

Cell[CellGroupData[{
Cell[148311, 3915, 145, 2, 38, "Subtitle"],
Cell[148459, 3919, 290, 5, 93, "Text"],

Cell[CellGroupData[{
Cell[148774, 3928, 119, 2, 31, "Subsubtitle",
  CellTags->"Mutation"],
Cell[148896, 3932, 1966, 44, 336, "Text"],
Cell[150865, 3978, 403, 10, 76, "NumberedEquation",
  CellTags->"deltaPMutation"],
Cell[151271, 3990, 230, 7, 39, "Text"],
Cell[151504, 3999, 500, 12, 78, "NumberedEquation",
  CellTags->"DAAfterMutation"],
Cell[152007, 4013, 449, 7, 120, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[152493, 4025, 122, 2, 31, "Subsubtitle",
  CellTags->"Migration"],
Cell[152618, 4029, 372, 7, 92, "Text"],
Cell[152993, 4038, 179, 4, 38, "Text"],
Cell[153175, 4044, 751, 19, 77, "NumberedEquation",
  CellTags->"deltaPMigration"],
Cell[153929, 4065, 795, 25, 92, "Text"],
Cell[154727, 4092, 1703, 40, 79, "NumberedEquation",
  CellTags->"DAPrimeCentered"],
Cell[156433, 4134, 81, 1, 38, "Text"],
Cell[156517, 4137, 829, 20, 77, "NumberedEquation",
  CellTags->"dAProductDefn"],
Cell[157349, 4159, 2061, 58, 146, "Text"],
Cell[159413, 4219, 370, 7, 92, "Text"],
Cell[159786, 4228, 1765, 40, 66, "NumberedEquation",
  CellTags->"DijPrimeExactAfterMigration"],
Cell[161554, 4270, 324, 6, 92, "Text"],
Cell[161881, 4278, 395, 10, 65, "Text"],
Cell[162279, 4290, 570, 11, 64, "NumberedEquation",
  CellTags->"DADoublePrimeNoDisequilibriumAmongMigrants"],
Cell[162852, 4303, 953, 26, 146, "Text"],
Cell[163808, 4331, 493, 14, 65, "Text"],
Cell[164304, 4347, 690, 18, 64, "NumberedEquation",
  CellTags->"deltaDAMigrationToLeadingOrder"],
Cell[164997, 4367, 945, 26, 146, "Text"],
Cell[165945, 4395, 689, 18, 69, "NumberedEquation",
  CellTags->"dAAtQLEFromExactCalculation"],
Cell[166637, 4415, 702, 17, 146, "Text"]
}, Closed]]
}, Open  ]],

Cell[CellGroupData[{
Cell[167388, 4438, 189, 4, 38, "Subtitle",
  PageBreakAbove->True,
  CellTags->"Applications"],
Cell[167580, 4444, 344, 6, 93, "Text"],
Cell[167927, 4452, 608, 10, 174, "Text"],

Cell[CellGroupData[{
Cell[168560, 4466, 223, 5, 31, "Subsubtitle",
  CellTags->"Natural selection on an additive polygenic trait"],
Cell[168786, 4473, 667, 10, 200, "Text"],
Cell[169456, 4485, 973, 20, 228, "Text"],
Cell[170432, 4507, 315, 7, 66, "Text"],
Cell[170750, 4516, 407, 9, 64, "NumberedEquation",
  CellTags->"ZTwoLoci"],
Cell[171160, 4527, 644, 16, 93, "Text"],
Cell[171807, 4545, 134, 3, 39, "Text"],
Cell[171944, 4550, 311, 7, 69, "NumberedEquation",
  CellTags->"GaussianFitnessFunction"],
Cell[172258, 4559, 925, 27, 147, "Text"],
Cell[173186, 4588, 639, 21, 66, "Text"],
Cell[173828, 4611, 1237, 27, 136, "NumberedEquation",
  CellTags->"wTwoLociAfterZetasReduced"],
Cell[175068, 4640, 260, 9, 38, "Text"],
Cell[175331, 4651, 530, 15, 65, "Text"],
Cell[175864, 4668, 1305, 27, 134, "NumberedEquation",
  CellTags->"wTwoLociAfterZetasReducedTwo"],
Cell[177172, 4697, 860, 23, 92, "Text"],
Cell[178035, 4722, 504, 13, 83, "NumberedEquation",
  CellTags->"aiForTwoLoci"],
Cell[178542, 4737, 2995, 81, 254, "Text"],
Cell[181540, 4820, 620, 16, 65, "Text"],
Cell[182163, 4838, 423, 10, 81, "NumberedEquation",
  CellTags->"aijForTwoLoci"],
Cell[182589, 4850, 1148, 25, 200, "Text"],
Cell[183740, 4877, 613, 10, 173, "Text"],
Cell[184356, 4889, 484, 15, 65, "Text"],
Cell[184843, 4906, 2769, 56, 192, "NumberedEquation",
  CellTags->"deltaPTwoLoci"],
Cell[187615, 4964, 358, 8, 66, "Text"],
Cell[187976, 4974, 988, 29, 93, "Text"],
Cell[188967, 5005, 853, 17, 85, "NumberedEquation",
  CellTags->"deltaZBarTwoLoci"],
Cell[189823, 5024, 1025, 22, 201, "Text"],
Cell[190851, 5048, 796, 24, 66, "Text"],
Cell[191650, 5074, 2375, 41, 238, "NumberedEquation",
  CellTags->"DijAfterSelection"],
Cell[194028, 5117, 812, 20, 120, "Text"],
Cell[194843, 5139, 844, 16, 80, "NumberedEquation",
  CellTags->"DijAfterChangingReferenceValues"],
Cell[195690, 5157, 1212, 27, 174, "Text"]
}, Closed]],

Cell[CellGroupData[{
Cell[196939, 5189, 170, 2, 25, "Subsubtitle",
  CellTags->"Sexual selection by female choice"],
Cell[197112, 5193, 1456, 32, 282, "Text"],
Cell[198571, 5227, 1876, 47, 309, "Text"],
Cell[200450, 5276, 369, 7, 120, "Text"],

Cell[CellGroupData[{
Cell[200844, 5287, 144, 2, 42, "Subsection",
  CellTags->"Selection coefficients"],
Cell[200991, 5291, 2017, 64, 254, "Text"],
Cell[203011, 5357, 1231, 44, 120, "Text"],
Cell[204245, 5403, 943, 17, 177, "NumberedEquation",
  CellTags->"SexSelFitnessFunctionVersion1"],
Cell[205191, 5422, 519, 20, 66, "Text"],
Cell[205713, 5444, 2456, 58, 88, "NumberedEquation",
  CellTags->"SexSelFitnessFunctionVersion2"],
Cell[208172, 5504, 370, 10, 66, "Text"],
Cell[208545, 5516, 1052, 30, 120, "Text"],
Cell[209600, 5548, 1533, 40, 88, "NumberedEquation",
  CellTags->"SexSelSelectionCoefficient"],
Cell[211136, 5590, 444, 11, 93, "Text"],
Cell[211583, 5603, 584, 10, 147, "Text"],
Cell[212170, 5615, 487, 8, 147, "Text"]
}, Closed]],

Cell[CellGroupData[{
Cell[212694, 5628, 158, 2, 24, "Subsection",
  CellTags->"Haploid autosomal inheritance"],
Cell[212855, 5632, 307, 6, 93, "Text"],
Cell[213165, 5640, 1564, 38, 87, "NumberedEquation",
  CellTags->"SexSelGeneticCorrelationInGeneral"],
Cell[214732, 5680, 276, 5, 66, "Text"],
Cell[215011, 5687, 2436, 62, 141, "NumberedEquation",
  CellTags->"HaploidGeneticVariancesForPandT"],
Cell[217450, 5751, 574, 16, 66, "Text"],
Cell[218027, 5769, 3120, 80, 87, "NumberedEquation",
  CellTags->"SexSelD"],
Cell[221150, 5851, 438, 11, 66, "Text"],
Cell[221591, 5864, 1331, 34, 81, "NumberedEquation",
  CellTags->"GPTandrPTInHaploids"],
Cell[222925, 5900, 849, 26, 93, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[223811, 5931, 158, 2, 42, "Subsection",
  CellTags->"Haploid autosomal inheritance"],
Cell[223972, 5935, 330, 6, 93, "Text"],
Cell[224305, 5943, 3047, 70, 87, "NumberedEquation",
  CellTags->"GPTForDiploidAutosomesInTermsOfDs"],
Cell[227355, 6015, 371, 7, 93, "Text"],
Cell[227729, 6024, 896, 33, 66, "Text"],
Cell[228628, 6059, 3558, 88, 130, "NumberedEquation",
  CellTags->"TForDiploidAutosomes"],
Cell[232189, 6149, 881, 27, 66, "Text"],
Cell[233073, 6178, 4333, 109, 145, "NumberedEquation",
  CellTags->"SexSelDForDiploidAutosomes"],
Cell[237409, 6289, 978, 22, 174, "Text"]
}, Closed]],

Cell[CellGroupData[{
Cell[238424, 6316, 149, 2, 24, "Subsection",
  CellTags->"Haploid autosomal inheritance"],
Cell[238576, 6320, 432, 7, 120, "Text"],
Cell[239011, 6329, 121, 1, 39, "Text"],
Cell[239135, 6332, 2260, 54, 80, "NumberedEquation",
  CellTags->"GmPTForXLinkageInTermsOfDs"],
Cell[241398, 6388, 1385, 39, 146, "Text"],
Cell[242786, 6429, 521, 18, 65, "Text"],
Cell[243310, 6449, 3394, 89, 144, "NumberedEquation",
  CellTags->"TsXLinkage"],
Cell[246707, 6540, 152, 4, 38, "Text"],
Cell[246862, 6546, 3909, 95, 144, "NumberedEquation",
  CellTags->"SexSelDsForXLinkage"],
Cell[250774, 6643, 236, 5, 65, "Text"],
Cell[251013, 6650, 1585, 41, 81, "NumberedEquation",
  CellTags->"GmPTAndrMPTForXLinkage"],
Cell[252601, 6693, 482, 9, 120, "Text"]
}, Closed]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[253144, 6709, 185, 4, 38, "Subtitle",
  PageBreakAbove->True,
  CellTags->"Discussion"],
Cell[253332, 6715, 1642, 41, 19, "Text",
  CellOpen->False],
Cell[254977, 6758, 766, 12, 228, "Text"],
Cell[255746, 6772, 1829, 40, 363, "Text"],
Cell[257578, 6814, 825, 16, 201, "Text"],
Cell[258406, 6832, 1102, 21, 255, "Text"],
Cell[259511, 6855, 2209, 50, 390, "Text"],
Cell[261723, 6907, 1008, 25, 174, "Text"],
Cell[262734, 6934, 1203, 31, 56, "NumberedEquation",
  CellTags->"QLE_Christiansen"],
Cell[263940, 6967, 2301, 70, 228, "Text"],
Cell[266244, 7039, 899, 25, 51, "NumberedEquation",
  CellTags->"QLEChristainsenInOurNotation"],
Cell[267146, 7066, 124, 3, 39, "Text"],
Cell[267273, 7071, 311, 10, 39, "Text"],
Cell[267587, 7083, 914, 27, 54, "NumberedEquation",
  CellTags->"QLEBurger"],
Cell[268504, 7112, 1632, 45, 201, "Text"],
Cell[270139, 7159, 1402, 24, 363, "Text"],
Cell[271544, 7185, 1222, 26, 255, "Text"],
Cell[272769, 7213, 826, 16, 174, "Text"],
Cell[273598, 7231, 303, 6, 93, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[273938, 7242, 138, 2, 38, "Subtitle"],
Cell[274079, 7246, 294, 6, 92, "Text"]
}, Closed]],

Cell[CellGroupData[{
Cell[274410, 7257, 182, 4, 27, "Subtitle",
  PageBreakAbove->True,
  CellTags->"References"],
Cell[274595, 7263, 500, 15, 93, "Text",
  CellTags->"Asmussen & Orive 2000"],
Cell[275098, 7280, 333, 11, 66, "Text",
  CellTags->"Baird 1995"],
Cell[275434, 7293, 266, 10, 39, "Text",
  CellTags->"Barton 1983"],
Cell[275703, 7305, 318, 11, 66, "Text",
  CellTags->"Barton 1986"],
Cell[276024, 7318, 384, 14, 66, "Text",
  CellTags->"Barton 1992"],
Cell[276411, 7334, 425, 15, 66, "Text",
  CellTags->"Barton 1995"],
Cell[276839, 7351, 290, 10, 39, "Text",
  CellTags->"Barton 2000"],
Cell[277132, 7363, 378, 14, 66, "Text",
  CellTags->"Barton & Shpak 2000"],
Cell[277513, 7379, 445, 17, 66, "Text",
  CellTags->"Barton & Turelli 1987"],
Cell[277961, 7398, 355, 13, 66, "Text",
  CellTags->"Barton & Turelli 1991"],
Cell[278319, 7413, 512, 16, 66, "Text",
  CellTags->"Baake 2001"],
Cell[278834, 7431, 309, 10, 66, "Text",
  CellTags->"Bulmer 1980"],
Cell[279146, 7443, 291, 10, 39, "Text",
  CellTags->"Burger 1991"],
Cell[279440, 7455, 311, 11, 66, "Text",
  CellTags->"Burger 2000"],
Cell[279754, 7468, 363, 13, 66, "Text",
  CellTags->"Christiansen 1987"],
Cell[280120, 7483, 374, 11, 66, "Text",
  CellTags->"Christiansen 1999"],
Cell[280497, 7496, 404, 12, 93, "Text",
  CellTags->"Dawson 1999"],
Cell[280904, 7510, 307, 11, 66, "Text",
  CellTags->"Doebeli 1996"],
Cell[281214, 7523, 281, 10, 39, "Text",
  CellTags->"Ewens 1979"],
Cell[281498, 7535, 300, 8, 66, "Text",
  CellTags->"Fisher 1918"],
Cell[281801, 7545, 300, 10, 66, "Text",
  CellTags->"Fisher 1958"],
Cell[282104, 7557, 291, 10, 39, "Text",
  CellTags->"Fisher 1953"],
Cell[282398, 7569, 300, 10, 39, "Text",
  CellTags->"Gillespie 1981"],
Cell[282701, 7581, 351, 11, 66, "Text",
  CellTags->"Haldane 1927"],
Cell[283055, 7594, 371, 14, 66, "Text",
  CellTags->"Hill & Robertson 1966"],
Cell[283429, 7610, 315, 11, 66, "Text",
  CellTags->"Hudson 1990"],
Cell[283747, 7623, 343, 11, 66, "Text",
  CellTags->"Kimura 1965"],
Cell[284093, 7636, 306, 11, 39, "Text",
  CellTags->"Kirkpatrick 1982"],
Cell[284402, 7649, 405, 14, 66, "Text",
  CellTags->"Kirkpatrick & Barton 1997"],
Cell[284810, 7665, 379, 14, 66, "Text",
  CellTags->"Kirkpatrick & Ryan 1991"],
Cell[285192, 7681, 379, 14, 66, "Text",
  CellTags->"Kirkpatrick & Servedio 1999"],
Cell[285574, 7697, 403, 14, 66, "Text",
  CellTags->"Kondrashov 1984"],
Cell[285980, 7713, 329, 11, 66, "Text",
  CellTags->"Lande 1981"],
Cell[286312, 7726, 294, 10, 39, "Text",
  CellTags->"Nagylaki 1976"],
Cell[286609, 7738, 310, 11, 66, "Text",
  CellTags->"Nagylaki 1993"],
Cell[286922, 7751, 465, 18, 66, "Text",
  CellTags->"Nagylaki 1993"],
Cell[287390, 7771, 394, 14, 66, "Text",
  CellTags->"Otto & Michalakis 1998"],
Cell[287787, 7787, 269, 10, 39, "Text",
  CellTags->"Price 1970"],
Cell[288059, 7799, 524, 20, 66, "Text",
  CellTags->"Shapiro et al 1994"],
Cell[288586, 7821, 406, 14, 66, "Text",
  CellTags->"Shpak & Kondrashov 1999"],
Cell[288995, 7837, 435, 17, 66, "Text",
  CellTags->"Sniegowski et al 2000"],
Cell[289433, 7856, 368, 14, 66, "Text",
  CellTags->"Turelli & Barton 1990"],
Cell[289804, 7872, 404, 14, 66, "Text",
  CellTags->"Turelli & Barton 1994"],
Cell[290211, 7888, 278, 10, 39, "Text",
  CellTags->"Wright 1931"],
Cell[290492, 7900, 298, 11, 39, "Text",
  CellTags->"Wright 1935"],
Cell[290793, 7913, 298, 10, 66, "Text",
  CellTags->"Wolfram 1996"]
}, Open  ]],

Cell[CellGroupData[{
Cell[291128, 7928, 182, 4, 38, "Subtitle",
  PageBreakAbove->True,
  CellTags->"Appendices"],

Cell[CellGroupData[{
Cell[291335, 7936, 103, 1, 42, "Section"],
Cell[291441, 7939, 418, 7, 120, "Text"],
Cell[291862, 7948, 930, 29, 147, "Text"],
Cell[292795, 7979, 505, 11, 93, "Text"],
Cell[293303, 7992, 321, 10, 66, "Text"],
Cell[293627, 8004, 3573, 92, 92, "NumberedEquation",
  CellTags->"FitnessPolynomialFor2Loci"],
Cell[297203, 8098, 240, 7, 38, "Text"],
Cell[297446, 8107, 22274, 494, 412, "NumberedEquation",
  CellTags->"FitnessDefnFor2Loci"],
Cell[319723, 8603, 582, 16, 92, "Text"],
Cell[320308, 8621, 2923, 77, 119, "NumberedEquation",
  CellTags->"SelectionCoefs2Loci"],
Cell[323234, 8700, 217, 6, 38, "Text"],
Cell[323454, 8708, 2078, 65, 146, "Text"],
Cell[325535, 8775, 9534, 213, 287, "NumberedEquation",
  CellTags->"deltaPI2LociVersion1"],
Cell[335072, 8990, 391, 8, 92, "Text"],
Cell[335466, 9000, 2534, 63, 52, "NumberedEquation",
  CellTags->"Dij2LociQLE"],
Cell[338003, 9065, 606, 20, 92, "Text"],
Cell[338612, 9087, 601, 16, 47, "NumberedEquation",
  CellTags->"WBar2LociQLE"],
Cell[339216, 9105, 261, 7, 65, "Text"],
Cell[339480, 9114, 3331, 79, 172, "NumberedEquation",
  CellTags->"deltaPI2LociVersion2"]
}, Closed]],

Cell[CellGroupData[{
Cell[342848, 9198, 134, 2, 24, "Section",
  CellTags->"Appendix: Mutation"],
Cell[342985, 9202, 152, 4, 39, "Text"],
Cell[343140, 9208, 595, 13, 78, "NumberedEquation",
  CellTags->"DANextByMutationExactlyDefnVersion1"],
Cell[343738, 9223, 1014, 28, 147, "Text"],
Cell[344755, 9253, 425, 10, 77, "NumberedEquation",
  CellTags->"deltaPiByMutation"],
Cell[345183, 9265, 1346, 45, 120, "Text"],
Cell[346532, 9312, 383, 7, 57, "NumberedEquation",
  CellTags->"delXForMutation"],
Cell[346918, 9321, 304, 9, 39, "Text"],
Cell[347225, 9332, 1132, 22, 140, "NumberedEquation",
  CellTags->"DANextByMutationExactlyDefnVersion2"],
Cell[348360, 9356, 554, 16, 66, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[348951, 9377, 136, 2, 42, "Section",
  CellTags->"Appendix: Migration"],
Cell[349090, 9381, 884, 21, 120, "Text"],
Cell[349977, 9404, 359, 11, 39, "Text"],
Cell[350339, 9417, 865, 21, 78, "NumberedEquation",
  CellTags->"DAPrimeDefn"],
Cell[351207, 9440, 783, 21, 93, "Text"],
Cell[351993, 9463, 2512, 55, 124, "NumberedEquation",
  CellTags->"DPrimeInTermsOfDMR"],
Cell[354508, 9520, 1081, 33, 93, "Text"],
Cell[355592, 9555, 1157, 30, 120, "Text"],
Cell[356752, 9587, 881, 24, 78, "NumberedEquation",
  CellTags->"DMRFormula"],
Cell[357636, 9613, 1067, 32, 93, "Text"],
Cell[358706, 9647, 1223, 32, 79, "NumberedEquation",
  CellTags->"DAPrimeUncenteredResult"],
Cell[359932, 9681, 704, 22, 66, "Text"],
Cell[360639, 9705, 1393, 45, 93, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[362069, 9755, 212, 7, 42, "Section",
  CellTags->"Appendix: Mathematica"],
Cell[362284, 9764, 723, 17, 147, "Text"],
Cell[363010, 9783, 127, 2, 39, "Text"],
Cell[363140, 9787, 976, 19, 147, "Text"],
Cell[364119, 9808, 351, 8, 66, "Text"],
Cell[364473, 9818, 435, 10, 123, "InlineFormula"],
Cell[364911, 9830, 153, 4, 39, "Text"],
Cell[365067, 9836, 116, 2, 39, "Text"],
Cell[365186, 9840, 312, 6, 93, "Text"],
Cell[365501, 9848, 240, 4, 42, "InlineFormula"],
Cell[365744, 9854, 351, 5, 42, "InlineFormula"],
Cell[366098, 9861, 531, 14, 93, "Text"],
Cell[366632, 9877, 277, 5, 42, "InlineFormula"],
Cell[366912, 9884, 313, 5, 44, "InlineFormula"],
Cell[367228, 9891, 338, 8, 66, "Text"],
Cell[367569, 9901, 353, 6, 57, "InlineFormula"],
Cell[367925, 9909, 3592, 53, 159, "InlineFormula"],
Cell[371520, 9964, 163, 4, 39, "Text"],
Cell[371686, 9970, 126, 2, 39, "Text"],
Cell[371815, 9974, 331, 6, 93, "Text"],
Cell[372149, 9982, 1002, 20, 96, "InlineFormula"],
Cell[373154, 10004, 267, 7, 66, "Text"],
Cell[373424, 10013, 867, 14, 72, "InlineFormula"],
Cell[374294, 10029, 178, 4, 21, "MathCaption"],
Cell[374475, 10035, 143, 3, 26, "InlineFormula"],
Cell[374621, 10040, 591, 11, 44, "InlineFormula"],
Cell[375215, 10053, 270, 8, 34, "MathCaption"],
Cell[375488, 10063, 352, 7, 56, "InlineFormula"],
Cell[375843, 10072, 1211, 26, 79, "InlineFormula"],
Cell[377057, 10100, 448, 14, 39, "Text"],
Cell[377508, 10116, 154, 4, 39, "Text"],
Cell[377665, 10122, 609, 11, 93, "InlineFormula"],
Cell[378277, 10135, 3491, 55, 163, "InlineFormula"],
Cell[381771, 10192, 593, 12, 120, "Text"],
Cell[382367, 10206, 127, 2, 39, "Text"],
Cell[382497, 10210, 151, 4, 39, "Text"],
Cell[382651, 10216, 558, 10, 101, "InlineFormula"],
Cell[383212, 10228, 871, 15, 174, "Text"],
Cell[384086, 10245, 161, 4, 21, "MathCaption"],
Cell[384250, 10251, 256, 5, 42, "InlineFormula"],
Cell[384509, 10258, 3447, 50, 150, "InlineFormula"],
Cell[387959, 10310, 166, 4, 21, "MathCaption"],
Cell[388128, 10316, 452, 8, 58, "InlineFormula"],
Cell[388583, 10326, 834, 14, 62, "InlineFormula"],
Cell[389420, 10342, 367, 12, 39, "Text"],
Cell[389790, 10356, 118, 2, 39, "Text"],
Cell[389911, 10360, 268, 5, 66, "Text"],
Cell[390182, 10367, 261, 5, 41, "InlineFormula"],
Cell[390446, 10374, 168, 3, 41, "InlineFormula"],
Cell[390617, 10379, 745, 24, 93, "Text"],
Cell[391365, 10405, 385, 8, 93, "Text"],
Cell[391753, 10415, 337, 6, 42, "InlineFormula"],
Cell[392093, 10423, 2396, 35, 92, "InlineFormula"],
Cell[394492, 10460, 465, 9, 120, "Text"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[395006, 10475, 152, 3, 38, "Subtitle",
  PageBreakAbove->True],

Cell[CellGroupData[{
Cell[395183, 10482, 170, 3, 42, "Subsection",
  PageBreakAbove->True,
  CellTags->"Summary of notation"],
Cell[395356, 10487, 20880, 512, 842, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[416273, 11004, 265, 6, 42, "Subsection",
  PageBreakAbove->True,
  CellTags->"Transmission coefficients for various forms of recombination"],
Cell[416541, 11012, 3503, 110, 352, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[420081, 11127, 195, 4, 42, "Subsection",
  PageBreakAbove->True,
  CellTags->"Measures of D"],
Cell[420279, 11133, 18762, 484, 290, "Text"],
Cell[439044, 11619, 673, 18, 147, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[439754, 11642, 121, 1, 42, "Subsection"],
Cell[439878, 11645, 3004, 100, 336, "Text"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[442931, 11751, 178, 4, 38, "Subtitle",
  PageBreakAbove->True,
  CellTags->"References"],

Cell[CellGroupData[{
Cell[443134, 11759, 96, 1, 42, "Subsection"],
Cell[443233, 11762, 514, 8, 147, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[443784, 11775, 90, 1, 42, "Subsection"],
Cell[443877, 11778, 44828, 694, 733, "Text"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[488754, 12478, 165, 3, 37, "Subtitle",
  PageBreakAbove->True],
Cell[488922, 12483, 225, 4, 32, "Input"],
Cell[489150, 12489, 21477, 839, 996, InheritFromParent]
}, Closed]]
}, Open  ]]
}
]
*)




(***********************************************************************
End of Mathematica Notebook file.
***********************************************************************)

