(***********************************************************************

                    Mathematica-Compatible Notebook

This notebook can be used on any computer system with Mathematica 4.0,
MathReader 4.0, or any compatible application. The data for the notebook 
starts with the line containing stars above.

To get the notebook into a Mathematica-compatible application, do one of 
the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing the 
word CacheID, otherwise Mathematica-compatible applications may try to 
use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
***********************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[     99714,       1851]*)
(*NotebookOutlinePosition[    102635,       1930]*)
(*  CellTagsIndexPosition[    102101,       1913]*)
(*WindowFrame->Normal*)



Notebook[{

Cell[CellGroupData[{
Cell["Recombination", "SubsectionIcon"],

Cell[TextData[{
  " ",
  Cell[BoxData[
      FormBox[GridBox[{
            {\(Meiosis[A, 
                B]\), \(the\ set\ A\ of\ genes\ in\ the\ new\ gamete\ pool . \
\ \(\[GothicCapitalG]\^*\), \ 
              derive\ from\ the\ maternal\ genome\ in\ adults, \ \
\[GothicCapitalA]; \ \(\(the\)\(\ \)\(set\)\(\ \)\(B\)\(\ \)\(derives\)\(\ \)\
\(from\)\(\ \)\(the\)\(\ \)\(paternal\)\(\ \)\(genome\)\(\ \)\)\)},
            {\(Meiosis[{\[GothicCapitalA], \(\[GothicCapitalG]\^*\)}, A, 
                B]\), \(specifies\ the\ stages\ \(\(explicitly\)\(.\)\)\)}
            }], TraditionalForm]]]
}], "DefinitionBox",
  CellTags->"Meiosis"],

Cell[TextData[{
  Cell[BoxData[
      \(TraditionalForm\`Meiosis[A, B]\)]],
  " derives genes in the new gamete pool, ",
  Cell[BoxData[
      \(TraditionalForm\`\(\[GothicCapitalG]\^*\)\)]],
  ", from those in the diploid adult, \[GothicCapitalA].  The set A of genes \
in the new gamete pool derive from the maternal genome in adults; the set B \
derives from the paternal genome:"
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \({i\_{\(\[GothicCapitalG]\^*\), \[GothicCapitalM]}, 
        j\_{\(\[GothicCapitalG]\^*\), \[GothicCapitalM]}, 
        k\_{\(\[GothicCapitalG]\^*\), \
\[GothicCapitalM]}}\[CirclePlus]Meiosis[{\[GothicCapitalA], \(\
\[GothicCapitalG]\^*\)}, {i, j}, {k}]\)], "Input",
  CellLabel->"In[37]:="],

Cell[BoxData[
    \({i\_{\[GothicCapitalA], \[GothicCapitalM], \[GothicCapitalF]}, 
      j\_{\[GothicCapitalA], \[GothicCapitalM], \[GothicCapitalF]}, 
      k\_{\[GothicCapitalA], \[GothicCapitalM], \[GothicCapitalM]}}\)], \
"Output",
  CellLabel->"Out[37]="]
}, Open  ]],

Cell[TextData[{
  Cell[BoxData[
      \(TraditionalForm\`Meiosis[{\[GothicCapitalA], \
\(\[GothicCapitalG]\^*\)}, A, B]\ is\)]],
  " just the rule",
  " ",
  Cell[BoxData[
      \({{\(\[GothicCapitalG]\^*\), x___, 
            sex_}\( \[LeftArrow] \+A\){\[GothicCapitalA], x, 
            sex, \[GothicCapitalF]}, {\(\[GothicCapitalG]\^*\), x___, 
            sex_}\( \[LeftArrow] \+B\){\[GothicCapitalA], x, 
            sex, \[GothicCapitalM]}}\)],
    FontFamily->"Times"],
  "."
}], "Text"],

Cell[TextData[{
  "Note: ",
  StyleBox["because Meiosis[] is a ",
    FontWeight->"Plain"],
  ButtonBox["transmission rule",
    ButtonData:>{"Changing contexts", "Transmission vs Mathematica rules"},
    ButtonStyle->"AddOnsLink"],
  StyleBox[", it must be applied using \[CirclePlus] not /.",
    FontWeight->"Plain"]
}], "Text",
  FontWeight->"Bold"],

Cell["\<\
The associations after a particular meiotic event {{j},{k}} are \
complicated by the change in reference point:\
\>", "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(\(\[GothicCapitalD]\_{j\_{\(\[GothicCapitalG]\^*\), \
\[GothicCapitalM]}, 
            k\_{\(\[GothicCapitalG]\^*\), \
\[GothicCapitalM]}}\)\(\[CirclePlus]\)\(Meiosis[{\[GothicCapitalA], \(\
\[GothicCapitalG]\^*\)}, {j}, {k}]\)\(\ \)\)\)], "Input",
  CellLabel->"In[94]:="],

Cell[BoxData[
    \(\[GothicCapitalD]\_{j\_{\[GothicCapitalA], \[GothicCapitalM], \
\[GothicCapitalF]}, k\_{\[GothicCapitalA], \[GothicCapitalM], \
\[GothicCapitalM]}} + \[GothicCapitalD]\_{k\_{\[GothicCapitalA], \
\[GothicCapitalM], \[GothicCapitalM]}}\ \((\(-\[WeierstrassP]\_\(j\_{\(\
\[GothicCapitalG]\^*\), \[GothicCapitalM]}\)\) + \[WeierstrassP]\_\(j\_{\
\[GothicCapitalA], \[GothicCapitalM], \[GothicCapitalF]}\))\) + \
\[GothicCapitalD]\_{j\_{\[GothicCapitalA], \[GothicCapitalM], \
\[GothicCapitalF]}}\ \((\(-\[WeierstrassP]\_\(k\_{\(\[GothicCapitalG]\^*\), \
\[GothicCapitalM]}\)\) + \[WeierstrassP]\_\(k\_{\[GothicCapitalA], \
\[GothicCapitalM], \[GothicCapitalM]}\))\) + \((\(-\[WeierstrassP]\_\(j\_{\(\
\[GothicCapitalG]\^*\), \[GothicCapitalM]}\)\) + \[WeierstrassP]\_\(j\_{\
\[GothicCapitalA], \[GothicCapitalM], \[GothicCapitalF]}\))\)\ \((\(-\
\[WeierstrassP]\_\(k\_{\(\[GothicCapitalG]\^*\), \[GothicCapitalM]}\)\) + \
\[WeierstrassP]\_\(k\_{\[GothicCapitalA], \[GothicCapitalM], \
\[GothicCapitalM]}\))\)\)], "Output",
  CellLabel->"Out[94]="]
}, Open  ]],

Cell[TextData[{
  "Here, {{j},{k}} denotes inheritance of locus ",
  Cell[BoxData[
      \(TraditionalForm\`j\ \ from\ the\ maternal\ genome\)]],
  ", and ",
  Cell[BoxData[
      \(TraditionalForm\`\(\(k\_\ \)\(\ \)\)\)]],
  "from the paternal genome."
}], "Text"],

Cell[TextData[{
  " ",
  Cell[BoxData[
      FormBox[GridBox[{
            {\(Recombination[]\), \(a\ rule\ which\ gives\ the\ mean\ \
contributions\ and\ linkage\ disequilibria\ in\ the\ new\ gamete\ pool, \ \(\
\[GothicCapitalG]\^*\), \ 
              in\ terms\ of\ disequilibria\ in\ the\ pool\ of\ adults, \ \
\[GothicCapitalA]; \ 
              a\ sum\ over\ all\ possible\ recombination\ events, \ \
\[GothicR]\_\(A, B\)\)},
            {\(Recombination[{\[GothicCapitalA], \(\[GothicCapitalG]\^*\)}, 
                RecombinationRate]\), \(specifies\ the\ stages\ and\ \
recombination\ rate\ \(\(explicitly\)\(.\)\)\)},
            {\(\[GothicR]\_\(A, B\)\ or\ RecombinationRate[A, 
                  B]\), \(the\ probability\ of\ a\ recombination\ event\ in\ \
which\ the\ set\ of\ genes\ A\ derive\ from\ the\ maternal\ genome, \ 
              and\ B\ from\ the\ paternal\ genome\)}
            }], TraditionalForm]]]
}], "DefinitionBox",
  CellTags->{"Recombination", "RecombinationRate"}],

Cell[TextData[{
  "This is the disequilibrium among new gametes, ",
  Cell[BoxData[
      \(TraditionalForm\`\(\(\[GothicCapitalG]\^*\)\(,\)\(\ \)\)\)]],
  "after recombination:"
}], "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\[GothicCapitalD]\_{j\_{\(\[GothicCapitalG]\^*\), \[GothicCapitalM]}, k\
\_{\(\[GothicCapitalG]\^*\), \[GothicCapitalM]}} /. 
      Recombination[]\)], "Input",
  CellLabel->"In[47]:="],

Cell[BoxData[
    \(\[GothicR]\_\({j, k}, {}\)\ \
\((\[GothicCapitalD]\_{j\_{\[GothicCapitalA], \[GothicCapitalM], \
\[GothicCapitalF]}, k\_{\[GothicCapitalA], \[GothicCapitalM], \
\[GothicCapitalF]}} + \[GothicCapitalD]\_{k\_{\[GothicCapitalA], \
\[GothicCapitalM], \[GothicCapitalF]}}\ \((\(-\[WeierstrassP]\_\(j\_{\(\
\[GothicCapitalG]\^*\), \[GothicCapitalM]}\)\) + \[WeierstrassP]\_\(j\_{\
\[GothicCapitalA], \[GothicCapitalM], \[GothicCapitalF]}\))\) + \
\[GothicCapitalD]\_{j\_{\[GothicCapitalA], \[GothicCapitalM], \
\[GothicCapitalF]}}\ \((\(-\[WeierstrassP]\_\(k\_{\(\[GothicCapitalG]\^*\), \
\[GothicCapitalM]}\)\) + \[WeierstrassP]\_\(k\_{\[GothicCapitalA], \
\[GothicCapitalM], \[GothicCapitalF]}\))\) + \((\(-\[WeierstrassP]\_\(j\_{\(\
\[GothicCapitalG]\^*\), \[GothicCapitalM]}\)\) + \[WeierstrassP]\_\(j\_{\
\[GothicCapitalA], \[GothicCapitalM], \[GothicCapitalF]}\))\)\ \((\(-\
\[WeierstrassP]\_\(k\_{\(\[GothicCapitalG]\^*\), \[GothicCapitalM]}\)\) + \
\[WeierstrassP]\_\(k\_{\[GothicCapitalA], \[GothicCapitalM], \
\[GothicCapitalF]}\))\))\) + \[GothicR]\_\({k}, {j}\)\ \
\((\[GothicCapitalD]\_{j\_{\[GothicCapitalA], \[GothicCapitalM], \
\[GothicCapitalM]}, k\_{\[GothicCapitalA], \[GothicCapitalM], \
\[GothicCapitalF]}} + \[GothicCapitalD]\_{k\_{\[GothicCapitalA], \
\[GothicCapitalM], \[GothicCapitalF]}}\ \((\(-\[WeierstrassP]\_\(j\_{\(\
\[GothicCapitalG]\^*\), \[GothicCapitalM]}\)\) + \[WeierstrassP]\_\(j\_{\
\[GothicCapitalA], \[GothicCapitalM], \[GothicCapitalM]}\))\) + \
\[GothicCapitalD]\_{j\_{\[GothicCapitalA], \[GothicCapitalM], \
\[GothicCapitalM]}}\ \((\(-\[WeierstrassP]\_\(k\_{\(\[GothicCapitalG]\^*\), \
\[GothicCapitalM]}\)\) + \[WeierstrassP]\_\(k\_{\[GothicCapitalA], \
\[GothicCapitalM], \[GothicCapitalF]}\))\) + \((\(-\[WeierstrassP]\_\(j\_{\(\
\[GothicCapitalG]\^*\), \[GothicCapitalM]}\)\) + \[WeierstrassP]\_\(j\_{\
\[GothicCapitalA], \[GothicCapitalM], \[GothicCapitalM]}\))\)\ \((\(-\
\[WeierstrassP]\_\(k\_{\(\[GothicCapitalG]\^*\), \[GothicCapitalM]}\)\) + \
\[WeierstrassP]\_\(k\_{\[GothicCapitalA], \[GothicCapitalM], \
\[GothicCapitalF]}\))\))\) + \[GothicR]\_\({j}, {k}\)\ \
\((\[GothicCapitalD]\_{j\_{\[GothicCapitalA], \[GothicCapitalM], \
\[GothicCapitalF]}, k\_{\[GothicCapitalA], \[GothicCapitalM], \
\[GothicCapitalM]}} + \[GothicCapitalD]\_{k\_{\[GothicCapitalA], \
\[GothicCapitalM], \[GothicCapitalM]}}\ \((\(-\[WeierstrassP]\_\(j\_{\(\
\[GothicCapitalG]\^*\), \[GothicCapitalM]}\)\) + \[WeierstrassP]\_\(j\_{\
\[GothicCapitalA], \[GothicCapitalM], \[GothicCapitalF]}\))\) + \
\[GothicCapitalD]\_{j\_{\[GothicCapitalA], \[GothicCapitalM], \
\[GothicCapitalF]}}\ \((\(-\[WeierstrassP]\_\(k\_{\(\[GothicCapitalG]\^*\), \
\[GothicCapitalM]}\)\) + \[WeierstrassP]\_\(k\_{\[GothicCapitalA], \
\[GothicCapitalM], \[GothicCapitalM]}\))\) + \((\(-\[WeierstrassP]\_\(j\_{\(\
\[GothicCapitalG]\^*\), \[GothicCapitalM]}\)\) + \[WeierstrassP]\_\(j\_{\
\[GothicCapitalA], \[GothicCapitalM], \[GothicCapitalF]}\))\)\ \((\(-\
\[WeierstrassP]\_\(k\_{\(\[GothicCapitalG]\^*\), \[GothicCapitalM]}\)\) + \
\[WeierstrassP]\_\(k\_{\[GothicCapitalA], \[GothicCapitalM], \
\[GothicCapitalM]}\))\))\) + \[GothicR]\_\({}, {j, k}\)\ \((\[GothicCapitalD]\
\_{j\_{\[GothicCapitalA], \[GothicCapitalM], \[GothicCapitalM]}, k\_{\
\[GothicCapitalA], \[GothicCapitalM], \[GothicCapitalM]}} + \[GothicCapitalD]\
\_{k\_{\[GothicCapitalA], \[GothicCapitalM], \[GothicCapitalM]}}\ \((\(-\
\[WeierstrassP]\_\(j\_{\(\[GothicCapitalG]\^*\), \[GothicCapitalM]}\)\) + \
\[WeierstrassP]\_\(j\_{\[GothicCapitalA], \[GothicCapitalM], \
\[GothicCapitalM]}\))\) + \[GothicCapitalD]\_{j\_{\[GothicCapitalA], \
\[GothicCapitalM], \[GothicCapitalM]}}\ \((\(-\[WeierstrassP]\_\(k\_{\(\
\[GothicCapitalG]\^*\), \[GothicCapitalM]}\)\) + \[WeierstrassP]\_\(k\_{\
\[GothicCapitalA], \[GothicCapitalM], \[GothicCapitalM]}\))\) + \((\(-\
\[WeierstrassP]\_\(j\_{\(\[GothicCapitalG]\^*\), \[GothicCapitalM]}\)\) + \
\[WeierstrassP]\_\(j\_{\[GothicCapitalA], \[GothicCapitalM], \
\[GothicCapitalM]}\))\)\ \
\((\(-\[WeierstrassP]\_\(k\_{\(\[GothicCapitalG]\^*\), \[GothicCapitalM]}\)\) \
+ \[WeierstrassP]\_\(k\_{\[GothicCapitalA], \[GothicCapitalM], \
\[GothicCapitalM]}\))\))\)\)], "Output",
  CellLabel->"Out[47]="]
}, Open  ]],

Cell["This is the mean contribution of a single locus:", "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\[GothicM]\_\(j\_{\(\[GothicCapitalG]\^*\), \[GothicCapitalM]}\) /. 
      Recombination[]\)], "Input",
  CellLabel->"In[207]:="],

Cell[BoxData[
    \(\[GothicM]\_\(j\_{\[GothicCapitalA], \[GothicCapitalM], \
\[GothicCapitalM]}\)\ \[GothicR]\_\({}, {j}\) + \[GothicM]\_\(j\_{\
\[GothicCapitalA], \[GothicCapitalM], \[GothicCapitalF]}\)\ \
\[GothicR]\_\({j}, {}\)\)], "Output",
  CellLabel->"Out[207]="]
}, Open  ]],

Cell[TextData[{
  "The notation ",
  Cell[BoxData[
      \(TraditionalForm\`\[GothicR]\_\(A, B\)\)]],
  " is automatically converted to RecombinationRate[A,B] (",
  "\[GothicR] is entered as \[AliasIndicator]gor\[AliasIndicator]). T",
  "his allows the subscripted notation to be used:"
}], "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\[GothicR]\_\(A, B\) // FullForm\)], "Input",
  CellLabel->"In[44]:="],

Cell[BoxData[
    TagBox[
      StyleBox[\(RecombinationRate[A, B]\),
        ShowStringCharacters->True,
        NumberMarks->True],
      FullForm]], "Output",
  CellLabel->"Out[44]//FullForm="]
}, Open  ]],

Cell[TextData[{
  "By default, Recombination[] relates stages ",
  Cell[BoxData[
      \(TraditionalForm\`{\[GothicCapitalA], \(\[GothicCapitalG]\^*\)}\)]],
  ", and gives the recombination rates in the form ",
  Cell[BoxData[
      \(TraditionalForm\`\[GothicR]\_\(A, B\)\)]],
  ".  "
}], "Text"],

Cell["Other stages and rates can be used:", "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\[GothicCapitalD]\_{j\_{\(\[GothicCapitalG]\^*\), \[GothicCapitalM]}, k\
\_{\(\[GothicCapitalG]\^*\), \[GothicCapitalM]}} /. 
      Recombination[{\[GothicCapitalA], \(\[GothicCapitalG]\^*\)}, 
        rec]\)], "Input",
  CellLabel->"In[42]:="],

Cell[BoxData[
    \(rec[{j, 
            k}, {}]\ \((\[GothicCapitalD]\_{j\_{\[GothicCapitalA], \
\[GothicCapitalM], \[GothicCapitalF]}, k\_{\[GothicCapitalA], \
\[GothicCapitalM], \[GothicCapitalF]}} + \[GothicCapitalD]\_{k\_{\
\[GothicCapitalA], \[GothicCapitalM], \[GothicCapitalF]}}\ \((\(-\
\[WeierstrassP]\_\(j\_{\(\[GothicCapitalG]\^*\), \[GothicCapitalM]}\)\) + \
\[WeierstrassP]\_\(j\_{\[GothicCapitalA], \[GothicCapitalM], \
\[GothicCapitalF]}\))\) + \[GothicCapitalD]\_{j\_{\[GothicCapitalA], \
\[GothicCapitalM], \[GothicCapitalF]}}\ \((\(-\[WeierstrassP]\_\(k\_{\(\
\[GothicCapitalG]\^*\), \[GothicCapitalM]}\)\) + \[WeierstrassP]\_\(k\_{\
\[GothicCapitalA], \[GothicCapitalM], \[GothicCapitalF]}\))\) + \((\(-\
\[WeierstrassP]\_\(j\_{\(\[GothicCapitalG]\^*\), \[GothicCapitalM]}\)\) + \
\[WeierstrassP]\_\(j\_{\[GothicCapitalA], \[GothicCapitalM], \
\[GothicCapitalF]}\))\)\ \
\((\(-\[WeierstrassP]\_\(k\_{\(\[GothicCapitalG]\^*\), \[GothicCapitalM]}\)\) \
+ \[WeierstrassP]\_\(k\_{\[GothicCapitalA], \[GothicCapitalM], \
\[GothicCapitalF]}\))\))\) + 
      rec[{k}, {j}]\ \((\[GothicCapitalD]\_{j\_{\[GothicCapitalA], \
\[GothicCapitalM], \[GothicCapitalM]}, k\_{\[GothicCapitalA], \
\[GothicCapitalM], \[GothicCapitalF]}} + \[GothicCapitalD]\_{k\_{\
\[GothicCapitalA], \[GothicCapitalM], \[GothicCapitalF]}}\ \((\(-\
\[WeierstrassP]\_\(j\_{\(\[GothicCapitalG]\^*\), \[GothicCapitalM]}\)\) + \
\[WeierstrassP]\_\(j\_{\[GothicCapitalA], \[GothicCapitalM], \
\[GothicCapitalM]}\))\) + \[GothicCapitalD]\_{j\_{\[GothicCapitalA], \
\[GothicCapitalM], \[GothicCapitalM]}}\ \((\(-\[WeierstrassP]\_\(k\_{\(\
\[GothicCapitalG]\^*\), \[GothicCapitalM]}\)\) + \[WeierstrassP]\_\(k\_{\
\[GothicCapitalA], \[GothicCapitalM], \[GothicCapitalF]}\))\) + \((\(-\
\[WeierstrassP]\_\(j\_{\(\[GothicCapitalG]\^*\), \[GothicCapitalM]}\)\) + \
\[WeierstrassP]\_\(j\_{\[GothicCapitalA], \[GothicCapitalM], \
\[GothicCapitalM]}\))\)\ \
\((\(-\[WeierstrassP]\_\(k\_{\(\[GothicCapitalG]\^*\), \[GothicCapitalM]}\)\) \
+ \[WeierstrassP]\_\(k\_{\[GothicCapitalA], \[GothicCapitalM], \
\[GothicCapitalF]}\))\))\) + 
      rec[{j}, {k}]\ \((\[GothicCapitalD]\_{j\_{\[GothicCapitalA], \
\[GothicCapitalM], \[GothicCapitalF]}, k\_{\[GothicCapitalA], \
\[GothicCapitalM], \[GothicCapitalM]}} + \[GothicCapitalD]\_{k\_{\
\[GothicCapitalA], \[GothicCapitalM], \[GothicCapitalM]}}\ \((\(-\
\[WeierstrassP]\_\(j\_{\(\[GothicCapitalG]\^*\), \[GothicCapitalM]}\)\) + \
\[WeierstrassP]\_\(j\_{\[GothicCapitalA], \[GothicCapitalM], \
\[GothicCapitalF]}\))\) + \[GothicCapitalD]\_{j\_{\[GothicCapitalA], \
\[GothicCapitalM], \[GothicCapitalF]}}\ \((\(-\[WeierstrassP]\_\(k\_{\(\
\[GothicCapitalG]\^*\), \[GothicCapitalM]}\)\) + \[WeierstrassP]\_\(k\_{\
\[GothicCapitalA], \[GothicCapitalM], \[GothicCapitalM]}\))\) + \((\(-\
\[WeierstrassP]\_\(j\_{\(\[GothicCapitalG]\^*\), \[GothicCapitalM]}\)\) + \
\[WeierstrassP]\_\(j\_{\[GothicCapitalA], \[GothicCapitalM], \
\[GothicCapitalF]}\))\)\ \
\((\(-\[WeierstrassP]\_\(k\_{\(\[GothicCapitalG]\^*\), \[GothicCapitalM]}\)\) \
+ \[WeierstrassP]\_\(k\_{\[GothicCapitalA], \[GothicCapitalM], \
\[GothicCapitalM]}\))\))\) + 
      rec[{}, {j, 
            k}]\ \((\[GothicCapitalD]\_{j\_{\[GothicCapitalA], \
\[GothicCapitalM], \[GothicCapitalM]}, k\_{\[GothicCapitalA], \
\[GothicCapitalM], \[GothicCapitalM]}} + \[GothicCapitalD]\_{k\_{\
\[GothicCapitalA], \[GothicCapitalM], \[GothicCapitalM]}}\ \((\(-\
\[WeierstrassP]\_\(j\_{\(\[GothicCapitalG]\^*\), \[GothicCapitalM]}\)\) + \
\[WeierstrassP]\_\(j\_{\[GothicCapitalA], \[GothicCapitalM], \
\[GothicCapitalM]}\))\) + \[GothicCapitalD]\_{j\_{\[GothicCapitalA], \
\[GothicCapitalM], \[GothicCapitalM]}}\ \((\(-\[WeierstrassP]\_\(k\_{\(\
\[GothicCapitalG]\^*\), \[GothicCapitalM]}\)\) + \[WeierstrassP]\_\(k\_{\
\[GothicCapitalA], \[GothicCapitalM], \[GothicCapitalM]}\))\) + \((\(-\
\[WeierstrassP]\_\(j\_{\(\[GothicCapitalG]\^*\), \[GothicCapitalM]}\)\) + \
\[WeierstrassP]\_\(j\_{\[GothicCapitalA], \[GothicCapitalM], \
\[GothicCapitalM]}\))\)\ \
\((\(-\[WeierstrassP]\_\(k\_{\(\[GothicCapitalG]\^*\), \[GothicCapitalM]}\)\) \
+ \[WeierstrassP]\_\(k\_{\[GothicCapitalA], \[GothicCapitalM], \
\[GothicCapitalM]}\))\))\)\)], "Output",
  CellLabel->"Out[42]="]
}, Closed]],

Cell[TextData[{
  "To use subscripted notation, use the",
  Cell[BoxData[
      FormBox[
        ButtonBox[\(\(\ \)\(Notation\ \(\(Palette\)\(:\)\)\)\),
          ButtonData:>{
            FrontEnd`FileName[ {
              ParentDirectory[ 
                ParentDirectory[ ]], "AddOns", "ExtraPackages", "Utilities"}, 
              "NotationPalette.nb", CharacterEncoding -> "MacintoshRoman"], 
            None},
          ButtonStyle->"Hyperlink"], TraditionalForm]]]
}], "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[{
    RowBox[{
      RowBox[{"Notation", "[", 
        RowBox[{
          TagBox[\(rec\_x___\),
            NotationBoxTag,
            TagStyle->"NotationTemplateStyle"], " ", 
          "\[DoubleLongLeftRightArrow]", " ", 
          TagBox[\(rec[x___]\),
            NotationBoxTag,
            TagStyle->"NotationTemplateStyle"]}], "]"}], 
      ";"}], "\n", \(\[GothicCapitalD]\_{j\_{\(\[GothicCapitalG]\^*\), \
\[GothicCapitalM]}, k\_{\(\[GothicCapitalG]\^*\), \[GothicCapitalM]}} /. 
      Recombination[{\[GothicCapitalA], \(\[GothicCapitalG]\^*\)}, 
        rec]\)}], "Input",
  CellLabel->"In[45]:="],

Cell[BoxData[
    \(rec\_\({j, k}, {}\)\ \((\[GothicCapitalD]\_{j\_{\[GothicCapitalA], \
\[GothicCapitalM], \[GothicCapitalF]}, k\_{\[GothicCapitalA], \
\[GothicCapitalM], \[GothicCapitalF]}} + \[GothicCapitalD]\_{k\_{\
\[GothicCapitalA], \[GothicCapitalM], \[GothicCapitalF]}}\ \((\(-\
\[WeierstrassP]\_\(j\_{\(\[GothicCapitalG]\^*\), \[GothicCapitalM]}\)\) + \
\[WeierstrassP]\_\(j\_{\[GothicCapitalA], \[GothicCapitalM], \
\[GothicCapitalF]}\))\) + \[GothicCapitalD]\_{j\_{\[GothicCapitalA], \
\[GothicCapitalM], \[GothicCapitalF]}}\ \((\(-\[WeierstrassP]\_\(k\_{\(\
\[GothicCapitalG]\^*\), \[GothicCapitalM]}\)\) + \[WeierstrassP]\_\(k\_{\
\[GothicCapitalA], \[GothicCapitalM], \[GothicCapitalF]}\))\) + \((\(-\
\[WeierstrassP]\_\(j\_{\(\[GothicCapitalG]\^*\), \[GothicCapitalM]}\)\) + \
\[WeierstrassP]\_\(j\_{\[GothicCapitalA], \[GothicCapitalM], \
\[GothicCapitalF]}\))\)\ \
\((\(-\[WeierstrassP]\_\(k\_{\(\[GothicCapitalG]\^*\), \[GothicCapitalM]}\)\) \
+ \[WeierstrassP]\_\(k\_{\[GothicCapitalA], \[GothicCapitalM], \
\[GothicCapitalF]}\))\))\) + 
      rec\_\({k}, {j}\)\ \((\[GothicCapitalD]\_{j\_{\[GothicCapitalA], \
\[GothicCapitalM], \[GothicCapitalM]}, k\_{\[GothicCapitalA], \
\[GothicCapitalM], \[GothicCapitalF]}} + \[GothicCapitalD]\_{k\_{\
\[GothicCapitalA], \[GothicCapitalM], \[GothicCapitalF]}}\ \((\(-\
\[WeierstrassP]\_\(j\_{\(\[GothicCapitalG]\^*\), \[GothicCapitalM]}\)\) + \
\[WeierstrassP]\_\(j\_{\[GothicCapitalA], \[GothicCapitalM], \
\[GothicCapitalM]}\))\) + \[GothicCapitalD]\_{j\_{\[GothicCapitalA], \
\[GothicCapitalM], \[GothicCapitalM]}}\ \((\(-\[WeierstrassP]\_\(k\_{\(\
\[GothicCapitalG]\^*\), \[GothicCapitalM]}\)\) + \[WeierstrassP]\_\(k\_{\
\[GothicCapitalA], \[GothicCapitalM], \[GothicCapitalF]}\))\) + \((\(-\
\[WeierstrassP]\_\(j\_{\(\[GothicCapitalG]\^*\), \[GothicCapitalM]}\)\) + \
\[WeierstrassP]\_\(j\_{\[GothicCapitalA], \[GothicCapitalM], \
\[GothicCapitalM]}\))\)\ \
\((\(-\[WeierstrassP]\_\(k\_{\(\[GothicCapitalG]\^*\), \[GothicCapitalM]}\)\) \
+ \[WeierstrassP]\_\(k\_{\[GothicCapitalA], \[GothicCapitalM], \
\[GothicCapitalF]}\))\))\) + 
      rec\_\({j}, {k}\)\ \((\[GothicCapitalD]\_{j\_{\[GothicCapitalA], \
\[GothicCapitalM], \[GothicCapitalF]}, k\_{\[GothicCapitalA], \
\[GothicCapitalM], \[GothicCapitalM]}} + \[GothicCapitalD]\_{k\_{\
\[GothicCapitalA], \[GothicCapitalM], \[GothicCapitalM]}}\ \((\(-\
\[WeierstrassP]\_\(j\_{\(\[GothicCapitalG]\^*\), \[GothicCapitalM]}\)\) + \
\[WeierstrassP]\_\(j\_{\[GothicCapitalA], \[GothicCapitalM], \
\[GothicCapitalF]}\))\) + \[GothicCapitalD]\_{j\_{\[GothicCapitalA], \
\[GothicCapitalM], \[GothicCapitalF]}}\ \((\(-\[WeierstrassP]\_\(k\_{\(\
\[GothicCapitalG]\^*\), \[GothicCapitalM]}\)\) + \[WeierstrassP]\_\(k\_{\
\[GothicCapitalA], \[GothicCapitalM], \[GothicCapitalM]}\))\) + \((\(-\
\[WeierstrassP]\_\(j\_{\(\[GothicCapitalG]\^*\), \[GothicCapitalM]}\)\) + \
\[WeierstrassP]\_\(j\_{\[GothicCapitalA], \[GothicCapitalM], \
\[GothicCapitalF]}\))\)\ \
\((\(-\[WeierstrassP]\_\(k\_{\(\[GothicCapitalG]\^*\), \[GothicCapitalM]}\)\) \
+ \[WeierstrassP]\_\(k\_{\[GothicCapitalA], \[GothicCapitalM], \
\[GothicCapitalM]}\))\))\) + 
      rec\_\({}, {j, k}\)\ \((\[GothicCapitalD]\_{j\_{\[GothicCapitalA], \
\[GothicCapitalM], \[GothicCapitalM]}, k\_{\[GothicCapitalA], \
\[GothicCapitalM], \[GothicCapitalM]}} + \[GothicCapitalD]\_{k\_{\
\[GothicCapitalA], \[GothicCapitalM], \[GothicCapitalM]}}\ \((\(-\
\[WeierstrassP]\_\(j\_{\(\[GothicCapitalG]\^*\), \[GothicCapitalM]}\)\) + \
\[WeierstrassP]\_\(j\_{\[GothicCapitalA], \[GothicCapitalM], \
\[GothicCapitalM]}\))\) + \[GothicCapitalD]\_{j\_{\[GothicCapitalA], \
\[GothicCapitalM], \[GothicCapitalM]}}\ \((\(-\[WeierstrassP]\_\(k\_{\(\
\[GothicCapitalG]\^*\), \[GothicCapitalM]}\)\) + \[WeierstrassP]\_\(k\_{\
\[GothicCapitalA], \[GothicCapitalM], \[GothicCapitalM]}\))\) + \((\(-\
\[WeierstrassP]\_\(j\_{\(\[GothicCapitalG]\^*\), \[GothicCapitalM]}\)\) + \
\[WeierstrassP]\_\(j\_{\[GothicCapitalA], \[GothicCapitalM], \
\[GothicCapitalM]}\))\)\ \
\((\(-\[WeierstrassP]\_\(k\_{\(\[GothicCapitalG]\^*\), \[GothicCapitalM]}\)\) \
+ \[WeierstrassP]\_\(k\_{\[GothicCapitalA], \[GothicCapitalM], \
\[GothicCapitalM]}\))\))\)\)], "Output",
  CellLabel->"Out[46]="]
}, Closed]],

Cell[TextData[{
  "This is a sum over the four possible ways in which loci ",
  Cell[BoxData[
      \(TraditionalForm\`{j, k}\)]],
  " can be derived.  Note that the convention for recombination rates differs \
from BT91.  In general, the contribution of maternal and paternal genes \
differs  ",
  Cell[BoxData[
      \(TraditionalForm\`\((i . e . \ r\_\(A, B\) \[NotEqual] 
          r\_\(B, A\))\)\)]],
  ", and so here, the reciprocal segregations are distinguished.  With \
Mendelian segregation of autosomes, ",
  Cell[BoxData[
      \(TraditionalForm\`r\_\({j}, {k}\) = \(r\_\({k}, {j}\) = \
\[Rho]\/2\)\)]],
  ", where \[Rho] is the usual recombination rate.  In BT91, the reciprocal \
segregations were pooled in one coefficient (",
  Cell[BoxData[
      \(TraditionalForm\`r\_\({j}, {k}\) + r\_\({k}, {j}\)\)]],
  ", say).  The more flexible convention used here can be adapted to ",
  ButtonBox["sex linkage",
    ButtonData:>{"Sex linkage", None},
    ButtonStyle->"AddOnsLink"],
  ", ",
  ButtonBox["cytoplasmic inheritance",
    ButtonData:>{"Cytoplasmic inheritance", None},
    ButtonStyle->"AddOnsLink"],
  ", and meiotic drive."
}], "Text",
  CellTags->"Factors of two"],

Cell[TextData[Cell[BoxData[
    FormBox[GridBox[{
          {\(SymmetricRecombination[]\), \(replaces\ \(\[GothicR]\_\(\
\[Ellipsis], B, A\)\) by\ r\_\(\[Ellipsis], A, B\), \ 
            on\ the\ assumption\ that\ reciprocal\ segregations\ occur\ at\ \
the\ same\ \(\(rate\)\(.\)\)\)},
          {\(SymmetricRecombination[
              rec]\), \(replaces\ rec[\[Ellipsis], B, A] 
              by\ rec[\[Ellipsis], A, B]\)}
          }], TraditionalForm]]]], "DefinitionBox",
  CellTags->"SymmetricRecombination"],

Cell["The expressions can be simplified by assuming symmetry:", "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[
    \(Collect[\(\[GothicCapitalD]\_{j\_{\(\[GothicCapitalG]\^*\), \
\[GothicCapitalM]}, k\_{\(\[GothicCapitalG]\^*\), \[GothicCapitalM]}} /. 
          Recombination[]\) /. 
        SymmetricRecombination[], \[GothicR]\___]\)], "Input",
  CellLabel->"In[58]:="],

Cell[BoxData[
    \(\[GothicR]\_\({j}, {k}\)\ \((\[GothicCapitalD]\_{j\_{\[GothicCapitalA], \
\[GothicCapitalM], \[GothicCapitalF]}, k\_{\[GothicCapitalA], \
\[GothicCapitalM], \[GothicCapitalM]}} + \[GothicCapitalD]\_{j\_{\
\[GothicCapitalA], \[GothicCapitalM], \[GothicCapitalM]}, k\_{\
\[GothicCapitalA], \[GothicCapitalM], \[GothicCapitalF]}} + \[GothicCapitalD]\
\_{k\_{\[GothicCapitalA], \[GothicCapitalM], \[GothicCapitalM]}}\ \((\(-\
\[WeierstrassP]\_\(j\_{\(\[GothicCapitalG]\^*\), \[GothicCapitalM]}\)\) + \
\[WeierstrassP]\_\(j\_{\[GothicCapitalA], \[GothicCapitalM], \
\[GothicCapitalF]}\))\) + \[GothicCapitalD]\_{k\_{\[GothicCapitalA], \
\[GothicCapitalM], \[GothicCapitalF]}}\ \((\(-\[WeierstrassP]\_\(j\_{\(\
\[GothicCapitalG]\^*\), \[GothicCapitalM]}\)\) + \[WeierstrassP]\_\(j\_{\
\[GothicCapitalA], \[GothicCapitalM], \[GothicCapitalM]}\))\) + \
\[GothicCapitalD]\_{j\_{\[GothicCapitalA], \[GothicCapitalM], \
\[GothicCapitalM]}}\ \((\(-\[WeierstrassP]\_\(k\_{\(\[GothicCapitalG]\^*\), \
\[GothicCapitalM]}\)\) + \[WeierstrassP]\_\(k\_{\[GothicCapitalA], \
\[GothicCapitalM], \[GothicCapitalF]}\))\) + \((\(-\[WeierstrassP]\_\(j\_{\(\
\[GothicCapitalG]\^*\), \[GothicCapitalM]}\)\) + \[WeierstrassP]\_\(j\_{\
\[GothicCapitalA], \[GothicCapitalM], \[GothicCapitalM]}\))\)\ \((\(-\
\[WeierstrassP]\_\(k\_{\(\[GothicCapitalG]\^*\), \[GothicCapitalM]}\)\) + \
\[WeierstrassP]\_\(k\_{\[GothicCapitalA], \[GothicCapitalM], \
\[GothicCapitalF]}\))\) + \[GothicCapitalD]\_{j\_{\[GothicCapitalA], \
\[GothicCapitalM], \[GothicCapitalF]}}\ \((\(-\[WeierstrassP]\_\(k\_{\(\
\[GothicCapitalG]\^*\), \[GothicCapitalM]}\)\) + \[WeierstrassP]\_\(k\_{\
\[GothicCapitalA], \[GothicCapitalM], \[GothicCapitalM]}\))\) + \((\(-\
\[WeierstrassP]\_\(j\_{\(\[GothicCapitalG]\^*\), \[GothicCapitalM]}\)\) + \
\[WeierstrassP]\_\(j\_{\[GothicCapitalA], \[GothicCapitalM], \
\[GothicCapitalF]}\))\)\ \
\((\(-\[WeierstrassP]\_\(k\_{\(\[GothicCapitalG]\^*\), \[GothicCapitalM]}\)\) \
+ \[WeierstrassP]\_\(k\_{\[GothicCapitalA], \[GothicCapitalM], \
\[GothicCapitalM]}\))\))\) + \[GothicR]\_\({}, {j, k}\)\ \((\[GothicCapitalD]\
\_{j\_{\[GothicCapitalA], \[GothicCapitalM], \[GothicCapitalF]}, k\_{\
\[GothicCapitalA], \[GothicCapitalM], \[GothicCapitalF]}} + \[GothicCapitalD]\
\_{j\_{\[GothicCapitalA], \[GothicCapitalM], \[GothicCapitalM]}, k\_{\
\[GothicCapitalA], \[GothicCapitalM], \[GothicCapitalM]}} + \[GothicCapitalD]\
\_{k\_{\[GothicCapitalA], \[GothicCapitalM], \[GothicCapitalF]}}\ \((\(-\
\[WeierstrassP]\_\(j\_{\(\[GothicCapitalG]\^*\), \[GothicCapitalM]}\)\) + \
\[WeierstrassP]\_\(j\_{\[GothicCapitalA], \[GothicCapitalM], \
\[GothicCapitalF]}\))\) + \[GothicCapitalD]\_{k\_{\[GothicCapitalA], \
\[GothicCapitalM], \[GothicCapitalM]}}\ \((\(-\[WeierstrassP]\_\(j\_{\(\
\[GothicCapitalG]\^*\), \[GothicCapitalM]}\)\) + \[WeierstrassP]\_\(j\_{\
\[GothicCapitalA], \[GothicCapitalM], \[GothicCapitalM]}\))\) + \
\[GothicCapitalD]\_{j\_{\[GothicCapitalA], \[GothicCapitalM], \
\[GothicCapitalF]}}\ \((\(-\[WeierstrassP]\_\(k\_{\(\[GothicCapitalG]\^*\), \
\[GothicCapitalM]}\)\) + \[WeierstrassP]\_\(k\_{\[GothicCapitalA], \
\[GothicCapitalM], \[GothicCapitalF]}\))\) + \((\(-\[WeierstrassP]\_\(j\_{\(\
\[GothicCapitalG]\^*\), \[GothicCapitalM]}\)\) + \[WeierstrassP]\_\(j\_{\
\[GothicCapitalA], \[GothicCapitalM], \[GothicCapitalF]}\))\)\ \((\(-\
\[WeierstrassP]\_\(k\_{\(\[GothicCapitalG]\^*\), \[GothicCapitalM]}\)\) + \
\[WeierstrassP]\_\(k\_{\[GothicCapitalA], \[GothicCapitalM], \
\[GothicCapitalF]}\))\) + \[GothicCapitalD]\_{j\_{\[GothicCapitalA], \
\[GothicCapitalM], \[GothicCapitalM]}}\ \((\(-\[WeierstrassP]\_\(k\_{\(\
\[GothicCapitalG]\^*\), \[GothicCapitalM]}\)\) + \[WeierstrassP]\_\(k\_{\
\[GothicCapitalA], \[GothicCapitalM], \[GothicCapitalM]}\))\) + \((\(-\
\[WeierstrassP]\_\(j\_{\(\[GothicCapitalG]\^*\), \[GothicCapitalM]}\)\) + \
\[WeierstrassP]\_\(j\_{\[GothicCapitalA], \[GothicCapitalM], \
\[GothicCapitalM]}\))\)\ \
\((\(-\[WeierstrassP]\_\(k\_{\(\[GothicCapitalG]\^*\), \[GothicCapitalM]}\)\) \
+ \[WeierstrassP]\_\(k\_{\[GothicCapitalA], \[GothicCapitalM], \
\[GothicCapitalM]}\))\))\)\)], "Output",
  CellLabel->"Out[58]="]
}, Open  ]],

Cell[TextData[{
  "This expression now involves only the two rates ",
  Cell[BoxData[
      \(\[GothicR]\_\({j}, {k}\)\)]],
  " and ",
  Cell[BoxData[
      \(\[GothicR]\_\({}, {j, k}\)\)]],
  ".  Note however that  ",
  Cell[BoxData[
      \(\(\(\[GothicR]\_\({j}, {k}\)\)\(+\)\)\)]],
  " ",
  Cell[BoxData[
      \(TraditionalForm\`\[GothicR]\_\({}, {j, k}\) = 1\/2\)]],
  ", not 1."
}], "Text"],

Cell[TextData[{
  " ",
  Cell[BoxData[
      FormBox[GridBox[{
            {\(Recombination[{c\_1, \[Ellipsis]}]\), \(a\ rule\ which\ gives\ \
the\ linkage\ disequilibria\ in\ the\ new\ gamete\ pool, \ \
\(\[GothicCapitalG]\^*\), \ 
              in\ terms\ of\ disequilibria\ in\ the\ pool\ of\ adults, \ \
\[GothicCapitalA]; \ 
              recombination\ rates\ \ \[GothicR]\_\(c\_1, \[Ellipsis], A, B\)\
\ depend\ on\ the\ c\_1, \[Ellipsis]\  . \n\ 
                  All\ linkage\ disequilibria\ must\ involve\ genes\ with\ \
the\ same\ c' s\)},
            {\(Recombination[{\[GothicCapitalA], \(\[GothicCapitalG]\^*\)}, 
                RecombinationRate, {c\_1, \[Ellipsis]}]\), \(specifies\ the\ \
stages\ and\ recombination\ rate\ \(\(explicitly\)\(.\)\)\)},
            {\(\[GothicR]\_\(c\_1, \[Ellipsis], A, B\)\ or\ RecombinationRate[
                  c\_1, \[Ellipsis], A, 
                  B]\), \(the\ probability\ of\ a\ recombination\ event\ in\ \
which\ the\ set\ of\ genes\ A\ derive\ from\ the\ maternal\ genome, \ 
              and\ B\ from\ the\ paternal\ genome; \ 
              the\ rate\ depends\ on\ the\ c\_1, \[Ellipsis]\)}
            }], TraditionalForm]]]
}], "DefinitionBox",
  CellTags->"Context-dependent recombination"],

Cell["Here, the recombination rates depend on sex:", "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\[GothicCapitalD]\_{j\_{\(\[GothicCapitalG]\^*\), \[GothicCapitalM]}, k\
\_{\(\[GothicCapitalG]\^*\), \[GothicCapitalM]}} /. 
      Recombination[{Sex}]\)], "Input",
  CellLabel->"In[20]:="],

Cell[BoxData[
    \({\[GothicR]\_\(\[GothicCapitalM], {j, k}, {}\)\ \
\((\[GothicCapitalD]\_{j\_{\[GothicCapitalA], \[GothicCapitalM], \
\[GothicCapitalF]}, k\_{\[GothicCapitalA], \[GothicCapitalM], \
\[GothicCapitalF]}} + \[GothicCapitalD]\_{k\_{\[GothicCapitalA], \
\[GothicCapitalM], \[GothicCapitalF]}}\ \((\(-\[WeierstrassP]\_\(j\_{\(\
\[GothicCapitalG]\^*\), \[GothicCapitalM]}\)\) + \[WeierstrassP]\_\(j\_{\
\[GothicCapitalA], \[GothicCapitalM], \[GothicCapitalF]}\))\) + \
\[GothicCapitalD]\_{j\_{\[GothicCapitalA], \[GothicCapitalM], \
\[GothicCapitalF]}}\ \((\(-\[WeierstrassP]\_\(k\_{\(\[GothicCapitalG]\^*\), \
\[GothicCapitalM]}\)\) + \[WeierstrassP]\_\(k\_{\[GothicCapitalA], \
\[GothicCapitalM], \[GothicCapitalF]}\))\) + \((\(-\[WeierstrassP]\_\(j\_{\(\
\[GothicCapitalG]\^*\), \[GothicCapitalM]}\)\) + \[WeierstrassP]\_\(j\_{\
\[GothicCapitalA], \[GothicCapitalM], \[GothicCapitalF]}\))\)\ \((\(-\
\[WeierstrassP]\_\(k\_{\(\[GothicCapitalG]\^*\), \[GothicCapitalM]}\)\) + \
\[WeierstrassP]\_\(k\_{\[GothicCapitalA], \[GothicCapitalM], \
\[GothicCapitalF]}\))\))\) + \[GothicR]\_\(\[GothicCapitalM], {k}, {j}\)\ \((\
\[GothicCapitalD]\_{j\_{\[GothicCapitalA], \[GothicCapitalM], \
\[GothicCapitalM]}, k\_{\[GothicCapitalA], \[GothicCapitalM], \
\[GothicCapitalF]}} + \[GothicCapitalD]\_{k\_{\[GothicCapitalA], \
\[GothicCapitalM], \[GothicCapitalF]}}\ \((\(-\[WeierstrassP]\_\(j\_{\(\
\[GothicCapitalG]\^*\), \[GothicCapitalM]}\)\) + \[WeierstrassP]\_\(j\_{\
\[GothicCapitalA], \[GothicCapitalM], \[GothicCapitalM]}\))\) + \
\[GothicCapitalD]\_{j\_{\[GothicCapitalA], \[GothicCapitalM], \
\[GothicCapitalM]}}\ \((\(-\[WeierstrassP]\_\(k\_{\(\[GothicCapitalG]\^*\), \
\[GothicCapitalM]}\)\) + \[WeierstrassP]\_\(k\_{\[GothicCapitalA], \
\[GothicCapitalM], \[GothicCapitalF]}\))\) + \((\(-\[WeierstrassP]\_\(j\_{\(\
\[GothicCapitalG]\^*\), \[GothicCapitalM]}\)\) + \[WeierstrassP]\_\(j\_{\
\[GothicCapitalA], \[GothicCapitalM], \[GothicCapitalM]}\))\)\ \((\(-\
\[WeierstrassP]\_\(k\_{\(\[GothicCapitalG]\^*\), \[GothicCapitalM]}\)\) + \
\[WeierstrassP]\_\(k\_{\[GothicCapitalA], \[GothicCapitalM], \
\[GothicCapitalF]}\))\))\) + \[GothicR]\_\(\[GothicCapitalM], {j}, {k}\)\ \((\
\[GothicCapitalD]\_{j\_{\[GothicCapitalA], \[GothicCapitalM], \
\[GothicCapitalF]}, k\_{\[GothicCapitalA], \[GothicCapitalM], \
\[GothicCapitalM]}} + \[GothicCapitalD]\_{k\_{\[GothicCapitalA], \
\[GothicCapitalM], \[GothicCapitalM]}}\ \((\(-\[WeierstrassP]\_\(j\_{\(\
\[GothicCapitalG]\^*\), \[GothicCapitalM]}\)\) + \[WeierstrassP]\_\(j\_{\
\[GothicCapitalA], \[GothicCapitalM], \[GothicCapitalF]}\))\) + \
\[GothicCapitalD]\_{j\_{\[GothicCapitalA], \[GothicCapitalM], \
\[GothicCapitalF]}}\ \((\(-\[WeierstrassP]\_\(k\_{\(\[GothicCapitalG]\^*\), \
\[GothicCapitalM]}\)\) + \[WeierstrassP]\_\(k\_{\[GothicCapitalA], \
\[GothicCapitalM], \[GothicCapitalM]}\))\) + \((\(-\[WeierstrassP]\_\(j\_{\(\
\[GothicCapitalG]\^*\), \[GothicCapitalM]}\)\) + \[WeierstrassP]\_\(j\_{\
\[GothicCapitalA], \[GothicCapitalM], \[GothicCapitalF]}\))\)\ \((\(-\
\[WeierstrassP]\_\(k\_{\(\[GothicCapitalG]\^*\), \[GothicCapitalM]}\)\) + \
\[WeierstrassP]\_\(k\_{\[GothicCapitalA], \[GothicCapitalM], \
\[GothicCapitalM]}\))\))\) + \[GothicR]\_\(\[GothicCapitalM], {}, {j, k}\)\ \
\((\[GothicCapitalD]\_{j\_{\[GothicCapitalA], \[GothicCapitalM], \
\[GothicCapitalM]}, k\_{\[GothicCapitalA], \[GothicCapitalM], \
\[GothicCapitalM]}} + \[GothicCapitalD]\_{k\_{\[GothicCapitalA], \
\[GothicCapitalM], \[GothicCapitalM]}}\ \((\(-\[WeierstrassP]\_\(j\_{\(\
\[GothicCapitalG]\^*\), \[GothicCapitalM]}\)\) + \[WeierstrassP]\_\(j\_{\
\[GothicCapitalA], \[GothicCapitalM], \[GothicCapitalM]}\))\) + \
\[GothicCapitalD]\_{j\_{\[GothicCapitalA], \[GothicCapitalM], \
\[GothicCapitalM]}}\ \((\(-\[WeierstrassP]\_\(k\_{\(\[GothicCapitalG]\^*\), \
\[GothicCapitalM]}\)\) + \[WeierstrassP]\_\(k\_{\[GothicCapitalA], \
\[GothicCapitalM], \[GothicCapitalM]}\))\) + \((\(-\[WeierstrassP]\_\(j\_{\(\
\[GothicCapitalG]\^*\), \[GothicCapitalM]}\)\) + \[WeierstrassP]\_\(j\_{\
\[GothicCapitalA], \[GothicCapitalM], \[GothicCapitalM]}\))\)\ \((\(-\
\[WeierstrassP]\_\(k\_{\(\[GothicCapitalG]\^*\), \[GothicCapitalM]}\)\) + \
\[WeierstrassP]\_\(k\_{\[GothicCapitalA], \[GothicCapitalM], \
\[GothicCapitalM]}\))\))\)}\)], "Output",
  CellLabel->"Out[20]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(\[GothicM]\_\(j\_{\(\[GothicCapitalG]\^*\), \[GothicCapitalM]}\) /. 
      Recombination[{Sex}]\)], "Input",
  CellLabel->"In[233]:="],

Cell[BoxData[
    \(\[GothicM]\_\(j\_{\[GothicCapitalA], \[GothicCapitalM], \
\[GothicCapitalM]}\)\ \[GothicR]\_\(\[GothicCapitalM], {}, {j}\) + \[GothicM]\
\_\(j\_{\[GothicCapitalA], \[GothicCapitalM], \[GothicCapitalF]}\)\ \
\[GothicR]\_\(\[GothicCapitalM], {j}, {}\)\)], "Output",
  CellLabel->"Out[233]="]
}, Open  ]],

Cell["\<\
The associations must involve genes that share the same value for \
the specified components.  Sex is excluded from this rule: as explained \
below, associations can be defined for mixtures of gametes from males and \
females. \
\>", "Text"],

Cell["To see this distinction, define more complex stages:", "MathCaption"],

Cell[BoxData[
    \(DefineContext[new\[GothicCapitalG], {Deme, Sex}]; 
    DefineContext[
      new\[GothicCapitalA], {Deme, Sex, SexOfOrigin}]; \)], "Input",
  CellLabel->"In[236]:="],

Cell["Call Recombination[] with these non-standard stages:", "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\[GothicCapitalD]\_{j\_{new\[GothicCapitalG], 1, \[GothicCapitalM]}, \
k\_{new\[GothicCapitalG], 1, \[GothicCapitalM]}} /. 
      Recombination[{new\[GothicCapitalA], new\[GothicCapitalG]}, 
        RecombinationRate, {Deme}]\)], "Input",
  CellLabel->"In[250]:="],

Cell[BoxData[
    \(\[GothicR]\_\(1, {j, k}, {}\)\ \((\[GothicCapitalD]\_{j\_{new\
\[GothicCapitalA], 1, \[GothicCapitalM], \[GothicCapitalF]}, k\_{new\
\[GothicCapitalA], 1, \[GothicCapitalM], \[GothicCapitalF]}} + \
\[GothicCapitalD]\_{k\_{new\[GothicCapitalA], 1, \[GothicCapitalM], \
\[GothicCapitalF]}}\ \((\(-\[WeierstrassP]\_\(j\_{new\[GothicCapitalG], 1, \
\[GothicCapitalM]}\)\) + \[WeierstrassP]\_\(j\_{new\[GothicCapitalA], 1, \
\[GothicCapitalM], \[GothicCapitalF]}\))\) + \[GothicCapitalD]\_{j\_{new\
\[GothicCapitalA], 1, \[GothicCapitalM], \[GothicCapitalF]}}\ \((\(-\
\[WeierstrassP]\_\(k\_{new\[GothicCapitalG], 1, \[GothicCapitalM]}\)\) + \
\[WeierstrassP]\_\(k\_{new\[GothicCapitalA], 1, \[GothicCapitalM], \
\[GothicCapitalF]}\))\) + \((\(-\[WeierstrassP]\_\(j\_{new\[GothicCapitalG], \
1, \[GothicCapitalM]}\)\) + \[WeierstrassP]\_\(j\_{new\[GothicCapitalA], 1, \
\[GothicCapitalM], \[GothicCapitalF]}\))\)\ \((\(-\[WeierstrassP]\_\(k\_{new\
\[GothicCapitalG], 1, \[GothicCapitalM]}\)\) + \[WeierstrassP]\_\(k\_{new\
\[GothicCapitalA], 1, \[GothicCapitalM], \[GothicCapitalF]}\))\))\) + \
\[GothicR]\_\(1, {k}, {j}\)\ \((\[GothicCapitalD]\_{j\_{new\[GothicCapitalA], \
1, \[GothicCapitalM], \[GothicCapitalM]}, k\_{new\[GothicCapitalA], 1, \
\[GothicCapitalM], \[GothicCapitalF]}} + \[GothicCapitalD]\_{k\_{new\
\[GothicCapitalA], 1, \[GothicCapitalM], \[GothicCapitalF]}}\ \((\(-\
\[WeierstrassP]\_\(j\_{new\[GothicCapitalG], 1, \[GothicCapitalM]}\)\) + \
\[WeierstrassP]\_\(j\_{new\[GothicCapitalA], 1, \[GothicCapitalM], \
\[GothicCapitalM]}\))\) + \[GothicCapitalD]\_{j\_{new\[GothicCapitalA], 1, \
\[GothicCapitalM], \[GothicCapitalM]}}\ \((\(-\[WeierstrassP]\_\(k\_{new\
\[GothicCapitalG], 1, \[GothicCapitalM]}\)\) + \[WeierstrassP]\_\(k\_{new\
\[GothicCapitalA], 1, \[GothicCapitalM], \[GothicCapitalF]}\))\) + \((\(-\
\[WeierstrassP]\_\(j\_{new\[GothicCapitalG], 1, \[GothicCapitalM]}\)\) + \
\[WeierstrassP]\_\(j\_{new\[GothicCapitalA], 1, \[GothicCapitalM], \
\[GothicCapitalM]}\))\)\ \((\(-\[WeierstrassP]\_\(k\_{new\[GothicCapitalG], \
1, \[GothicCapitalM]}\)\) + \[WeierstrassP]\_\(k\_{new\[GothicCapitalA], 1, \
\[GothicCapitalM], \[GothicCapitalF]}\))\))\) + \[GothicR]\_\(1, {j}, {k}\)\ \
\((\[GothicCapitalD]\_{j\_{new\[GothicCapitalA], 1, \[GothicCapitalM], \
\[GothicCapitalF]}, k\_{new\[GothicCapitalA], 1, \[GothicCapitalM], \
\[GothicCapitalM]}} + \[GothicCapitalD]\_{k\_{new\[GothicCapitalA], 1, \
\[GothicCapitalM], \[GothicCapitalM]}}\ \((\(-\[WeierstrassP]\_\(j\_{new\
\[GothicCapitalG], 1, \[GothicCapitalM]}\)\) + \[WeierstrassP]\_\(j\_{new\
\[GothicCapitalA], 1, \[GothicCapitalM], \[GothicCapitalF]}\))\) + \
\[GothicCapitalD]\_{j\_{new\[GothicCapitalA], 1, \[GothicCapitalM], \
\[GothicCapitalF]}}\ \((\(-\[WeierstrassP]\_\(k\_{new\[GothicCapitalG], 1, \
\[GothicCapitalM]}\)\) + \[WeierstrassP]\_\(k\_{new\[GothicCapitalA], 1, \
\[GothicCapitalM], \[GothicCapitalM]}\))\) + \((\(-\[WeierstrassP]\_\(j\_{new\
\[GothicCapitalG], 1, \[GothicCapitalM]}\)\) + \[WeierstrassP]\_\(j\_{new\
\[GothicCapitalA], 1, \[GothicCapitalM], \[GothicCapitalF]}\))\)\ \((\(-\
\[WeierstrassP]\_\(k\_{new\[GothicCapitalG], 1, \[GothicCapitalM]}\)\) + \
\[WeierstrassP]\_\(k\_{new\[GothicCapitalA], 1, \[GothicCapitalM], \
\[GothicCapitalM]}\))\))\) + \[GothicR]\_\(1, {}, {j, k}\)\ \((\
\[GothicCapitalD]\_{j\_{new\[GothicCapitalA], 1, \[GothicCapitalM], \
\[GothicCapitalM]}, k\_{new\[GothicCapitalA], 1, \[GothicCapitalM], \
\[GothicCapitalM]}} + \[GothicCapitalD]\_{k\_{new\[GothicCapitalA], 1, \
\[GothicCapitalM], \[GothicCapitalM]}}\ \((\(-\[WeierstrassP]\_\(j\_{new\
\[GothicCapitalG], 1, \[GothicCapitalM]}\)\) + \[WeierstrassP]\_\(j\_{new\
\[GothicCapitalA], 1, \[GothicCapitalM], \[GothicCapitalM]}\))\) + \
\[GothicCapitalD]\_{j\_{new\[GothicCapitalA], 1, \[GothicCapitalM], \
\[GothicCapitalM]}}\ \((\(-\[WeierstrassP]\_\(k\_{new\[GothicCapitalG], 1, \
\[GothicCapitalM]}\)\) + \[WeierstrassP]\_\(k\_{new\[GothicCapitalA], 1, \
\[GothicCapitalM], \[GothicCapitalM]}\))\) + \((\(-\[WeierstrassP]\_\(j\_{new\
\[GothicCapitalG], 1, \[GothicCapitalM]}\)\) + \[WeierstrassP]\_\(j\_{new\
\[GothicCapitalA], 1, \[GothicCapitalM], \[GothicCapitalM]}\))\)\ \((\(-\
\[WeierstrassP]\_\(k\_{new\[GothicCapitalG], 1, \[GothicCapitalM]}\)\) + \
\[WeierstrassP]\_\(k\_{new\[GothicCapitalA], 1, \[GothicCapitalM], \
\[GothicCapitalM]}\))\))\)\)], "Output",
  CellLabel->"Out[250]="]
}, Closed]],

Cell["\<\
This association involves genes from the same deme, and so \
evaluates correctly, with recombination rates which depend on the deme.\
\>", \
"Text"],

Cell["\<\
This fails, because it involves genes from different demes: \
presumably, these must be in different individuals:\
\>", "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\[GothicCapitalD]\_{j\_{new\[GothicCapitalG], 1, \[GothicCapitalM]}, \
k\_{new\[GothicCapitalG], 2, \[GothicCapitalM]}} /. 
      Recombination[{new\[GothicCapitalA], new\[GothicCapitalG]}, 
        RecombinationRate, {Deme}]\)], "Input",
  CellLabel->"In[251]:="],

Cell[BoxData[
    \(Recombination::"mix" \(\(:\)\(\ \)\) 
      "Mixed contexts in \!\(\[GothicCapitalD]\_\!\({j\_\({new\
\[GothicCapitalG], 1, \[GothicCapitalM]}\), k\_\({new\[GothicCapitalG], 2, \
\[GothicCapitalM]}\)}\)\)/.Recombination[\!\({new\[GothicCapitalA], new\
\[GothicCapitalG]}\),\!\(RecombinationRate\),\!\({Deme}\)]: the relevant \
components \!\({Deme}\) must be the same for all genes."\)], "Message",
  CellLabel->"From In[251]:="],

Cell[BoxData[
    \(\[GothicCapitalD]\_{j\_{new\[GothicCapitalG], 1, \[GothicCapitalM]}, \
k\_{new\[GothicCapitalG], 2, \[GothicCapitalM]}}\)], "Output",
  CellLabel->"Out[251]="]
}, Open  ]],

Cell[TextData[{
  " ",
  Cell[BoxData[
      FormBox[GridBox[{
            {\(\[GothicCapitalD]\_{i\_{\(\[GothicCapitalG]\^*\), \
\[GothicCapitalM]}, i\_{\(\[GothicCapitalG]\^*\), \[GothicCapitalF]}} /. 
                Recombination[]\), \(gives\ the\ association\ between\ genes\ \
in\ two\ gametes, \ 
              derived\ from\ the\ male\ and\ female\ of\ a\ mated\ \(\(pair\)\
\(.\)\)\)},
            {\(\[GothicCapitalD]\_{i\_{\(\[GothicCapitalG]\^*\), \
\[GothicCapitalM]}, i\_{\(\[GothicCapitalG]\^*\), \[GothicCapitalF]}} /. 
                Recombination[{Sex}]\), \(allows\ for\ sex - 
                specific\ recombination\ \(\(rates\)\(.\)\)\)}
            }], TraditionalForm]]]
}], "DefinitionBox",
  CellTags->"Sexual selection"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\[GothicCapitalD]\_{i\_{\(\[GothicCapitalG]\^*\), \[GothicCapitalM]}, j\
\_{\(\[GothicCapitalG]\^*\), \[GothicCapitalF]}, \
k\_{\(\[GothicCapitalG]\^*\), \[GothicCapitalF]}} /. 
      Recombination[]\)], "Input",
  CellLabel->"In[253]:="],

Cell[BoxData[
    \(\[GothicR]\_\({i}, {}\)\ \[GothicR]\_\({j, k}, {}\)\ \((\
\[GothicCapitalD]\_{i\_{\[GothicCapitalA], \[GothicCapitalM], \
\[GothicCapitalF]}, j\_{\[GothicCapitalA], \[GothicCapitalF], \
\[GothicCapitalF]}, k\_{\[GothicCapitalA], \[GothicCapitalF], \
\[GothicCapitalF]}} + \[GothicCapitalD]\_{j\_{\[GothicCapitalA], \
\[GothicCapitalF], \[GothicCapitalF]}, k\_{\[GothicCapitalA], \
\[GothicCapitalF], \[GothicCapitalF]}}\ \((\(-\[WeierstrassP]\_\(i\_{\(\
\[GothicCapitalG]\^*\), \[GothicCapitalM]}\)\) + \[WeierstrassP]\_\(i\_{\
\[GothicCapitalA], \[GothicCapitalM], \[GothicCapitalF]}\))\) + \
\[GothicCapitalD]\_{i\_{\[GothicCapitalA], \[GothicCapitalM], \
\[GothicCapitalF]}, k\_{\[GothicCapitalA], \[GothicCapitalF], \
\[GothicCapitalF]}}\ \((\(-\[WeierstrassP]\_\(j\_{\(\[GothicCapitalG]\^*\), \
\[GothicCapitalF]}\)\) + \[WeierstrassP]\_\(j\_{\[GothicCapitalA], \
\[GothicCapitalF], \[GothicCapitalF]}\))\) + \[GothicCapitalD]\_{k\_{\
\[GothicCapitalA], \[GothicCapitalF], \[GothicCapitalF]}}\ \((\(-\
\[WeierstrassP]\_\(i\_{\(\[GothicCapitalG]\^*\), \[GothicCapitalM]}\)\) + \
\[WeierstrassP]\_\(i\_{\[GothicCapitalA], \[GothicCapitalM], \
\[GothicCapitalF]}\))\)\ \
\((\(-\[WeierstrassP]\_\(j\_{\(\[GothicCapitalG]\^*\), \[GothicCapitalF]}\)\) \
+ \[WeierstrassP]\_\(j\_{\[GothicCapitalA], \[GothicCapitalF], \
\[GothicCapitalF]}\))\) + \[GothicCapitalD]\_{i\_{\[GothicCapitalA], \
\[GothicCapitalM], \[GothicCapitalF]}, j\_{\[GothicCapitalA], \
\[GothicCapitalF], \[GothicCapitalF]}}\ \((\(-\[WeierstrassP]\_\(k\_{\(\
\[GothicCapitalG]\^*\), \[GothicCapitalF]}\)\) + \[WeierstrassP]\_\(k\_{\
\[GothicCapitalA], \[GothicCapitalF], \[GothicCapitalF]}\))\) + \
\[GothicCapitalD]\_{j\_{\[GothicCapitalA], \[GothicCapitalF], \
\[GothicCapitalF]}}\ \((\(-\[WeierstrassP]\_\(i\_{\(\[GothicCapitalG]\^*\), \
\[GothicCapitalM]}\)\) + \[WeierstrassP]\_\(i\_{\[GothicCapitalA], \
\[GothicCapitalM], \[GothicCapitalF]}\))\)\ \((\(-\[WeierstrassP]\_\(k\_{\(\
\[GothicCapitalG]\^*\), \[GothicCapitalF]}\)\) + \[WeierstrassP]\_\(k\_{\
\[GothicCapitalA], \[GothicCapitalF], \[GothicCapitalF]}\))\) + \
\[GothicCapitalD]\_{i\_{\[GothicCapitalA], \[GothicCapitalM], \
\[GothicCapitalF]}}\ \((\(-\[WeierstrassP]\_\(j\_{\(\[GothicCapitalG]\^*\), \
\[GothicCapitalF]}\)\) + \[WeierstrassP]\_\(j\_{\[GothicCapitalA], \
\[GothicCapitalF], \[GothicCapitalF]}\))\)\ \((\(-\[WeierstrassP]\_\(k\_{\(\
\[GothicCapitalG]\^*\), \[GothicCapitalF]}\)\) + \[WeierstrassP]\_\(k\_{\
\[GothicCapitalA], \[GothicCapitalF], \[GothicCapitalF]}\))\) + \((\(-\
\[WeierstrassP]\_\(i\_{\(\[GothicCapitalG]\^*\), \[GothicCapitalM]}\)\) + \
\[WeierstrassP]\_\(i\_{\[GothicCapitalA], \[GothicCapitalM], \
\[GothicCapitalF]}\))\)\ \
\((\(-\[WeierstrassP]\_\(j\_{\(\[GothicCapitalG]\^*\), \[GothicCapitalF]}\)\) \
+ \[WeierstrassP]\_\(j\_{\[GothicCapitalA], \[GothicCapitalF], \
\[GothicCapitalF]}\))\)\ \
\((\(-\[WeierstrassP]\_\(k\_{\(\[GothicCapitalG]\^*\), \[GothicCapitalF]}\)\) \
+ \[WeierstrassP]\_\(k\_{\[GothicCapitalA], \[GothicCapitalF], \
\[GothicCapitalF]}\))\))\) + \[GothicR]\_\({}, {i}\)\ \[GothicR]\_\({j, k}, \
{}\)\ \((\[GothicCapitalD]\_{i\_{\[GothicCapitalA], \[GothicCapitalM], \
\[GothicCapitalM]}, j\_{\[GothicCapitalA], \[GothicCapitalF], \
\[GothicCapitalF]}, k\_{\[GothicCapitalA], \[GothicCapitalF], \
\[GothicCapitalF]}} + \[GothicCapitalD]\_{j\_{\[GothicCapitalA], \
\[GothicCapitalF], \[GothicCapitalF]}, k\_{\[GothicCapitalA], \
\[GothicCapitalF], \[GothicCapitalF]}}\ \((\(-\[WeierstrassP]\_\(i\_{\(\
\[GothicCapitalG]\^*\), \[GothicCapitalM]}\)\) + \[WeierstrassP]\_\(i\_{\
\[GothicCapitalA], \[GothicCapitalM], \[GothicCapitalM]}\))\) + \
\[GothicCapitalD]\_{i\_{\[GothicCapitalA], \[GothicCapitalM], \
\[GothicCapitalM]}, k\_{\[GothicCapitalA], \[GothicCapitalF], \
\[GothicCapitalF]}}\ \((\(-\[WeierstrassP]\_\(j\_{\(\[GothicCapitalG]\^*\), \
\[GothicCapitalF]}\)\) + \[WeierstrassP]\_\(j\_{\[GothicCapitalA], \
\[GothicCapitalF], \[GothicCapitalF]}\))\) + \[GothicCapitalD]\_{k\_{\
\[GothicCapitalA], \[GothicCapitalF], \[GothicCapitalF]}}\ \((\(-\
\[WeierstrassP]\_\(i\_{\(\[GothicCapitalG]\^*\), \[GothicCapitalM]}\)\) + \
\[WeierstrassP]\_\(i\_{\[GothicCapitalA], \[GothicCapitalM], \
\[GothicCapitalM]}\))\)\ \
\((\(-\[WeierstrassP]\_\(j\_{\(\[GothicCapitalG]\^*\), \[GothicCapitalF]}\)\) \
+ \[WeierstrassP]\_\(j\_{\[GothicCapitalA], \[GothicCapitalF], \
\[GothicCapitalF]}\))\) + \[GothicCapitalD]\_{i\_{\[GothicCapitalA], \
\[GothicCapitalM], \[GothicCapitalM]}, j\_{\[GothicCapitalA], \
\[GothicCapitalF], \[GothicCapitalF]}}\ \((\(-\[WeierstrassP]\_\(k\_{\(\
\[GothicCapitalG]\^*\), \[GothicCapitalF]}\)\) + \[WeierstrassP]\_\(k\_{\
\[GothicCapitalA], \[GothicCapitalF], \[GothicCapitalF]}\))\) + \
\[GothicCapitalD]\_{j\_{\[GothicCapitalA], \[GothicCapitalF], \
\[GothicCapitalF]}}\ \((\(-\[WeierstrassP]\_\(i\_{\(\[GothicCapitalG]\^*\), \
\[GothicCapitalM]}\)\) + \[WeierstrassP]\_\(i\_{\[GothicCapitalA], \
\[GothicCapitalM], \[GothicCapitalM]}\))\)\ \((\(-\[WeierstrassP]\_\(k\_{\(\
\[GothicCapitalG]\^*\), \[GothicCapitalF]}\)\) + \[WeierstrassP]\_\(k\_{\
\[GothicCapitalA], \[GothicCapitalF], \[GothicCapitalF]}\))\) + \
\[GothicCapitalD]\_{i\_{\[GothicCapitalA], \[GothicCapitalM], \
\[GothicCapitalM]}}\ \((\(-\[WeierstrassP]\_\(j\_{\(\[GothicCapitalG]\^*\), \
\[GothicCapitalF]}\)\) + \[WeierstrassP]\_\(j\_{\[GothicCapitalA], \
\[GothicCapitalF], \[GothicCapitalF]}\))\)\ \((\(-\[WeierstrassP]\_\(k\_{\(\
\[GothicCapitalG]\^*\), \[GothicCapitalF]}\)\) + \[WeierstrassP]\_\(k\_{\
\[GothicCapitalA], \[GothicCapitalF], \[GothicCapitalF]}\))\) + \((\(-\
\[WeierstrassP]\_\(i\_{\(\[GothicCapitalG]\^*\), \[GothicCapitalM]}\)\) + \
\[WeierstrassP]\_\(i\_{\[GothicCapitalA], \[GothicCapitalM], \
\[GothicCapitalM]}\))\)\ \
\((\(-\[WeierstrassP]\_\(j\_{\(\[GothicCapitalG]\^*\), \[GothicCapitalF]}\)\) \
+ \[WeierstrassP]\_\(j\_{\[GothicCapitalA], \[GothicCapitalF], \
\[GothicCapitalF]}\))\)\ \
\((\(-\[WeierstrassP]\_\(k\_{\(\[GothicCapitalG]\^*\), \[GothicCapitalF]}\)\) \
+ \[WeierstrassP]\_\(k\_{\[GothicCapitalA], \[GothicCapitalF], \
\[GothicCapitalF]}\))\))\) + \[GothicR]\_\({i}, {}\)\ \[GothicR]\_\({k}, \
{j}\)\ \((\[GothicCapitalD]\_{i\_{\[GothicCapitalA], \[GothicCapitalM], \
\[GothicCapitalF]}, j\_{\[GothicCapitalA], \[GothicCapitalF], \
\[GothicCapitalM]}, k\_{\[GothicCapitalA], \[GothicCapitalF], \
\[GothicCapitalF]}} + \[GothicCapitalD]\_{j\_{\[GothicCapitalA], \
\[GothicCapitalF], \[GothicCapitalM]}, k\_{\[GothicCapitalA], \
\[GothicCapitalF], \[GothicCapitalF]}}\ \((\(-\[WeierstrassP]\_\(i\_{\(\
\[GothicCapitalG]\^*\), \[GothicCapitalM]}\)\) + \[WeierstrassP]\_\(i\_{\
\[GothicCapitalA], \[GothicCapitalM], \[GothicCapitalF]}\))\) + \
\[GothicCapitalD]\_{i\_{\[GothicCapitalA], \[GothicCapitalM], \
\[GothicCapitalF]}, k\_{\[GothicCapitalA], \[GothicCapitalF], \
\[GothicCapitalF]}}\ \((\(-\[WeierstrassP]\_\(j\_{\(\[GothicCapitalG]\^*\), \
\[GothicCapitalF]}\)\) + \[WeierstrassP]\_\(j\_{\[GothicCapitalA], \
\[GothicCapitalF], \[GothicCapitalM]}\))\) + \[GothicCapitalD]\_{k\_{\
\[GothicCapitalA], \[GothicCapitalF], \[GothicCapitalF]}}\ \((\(-\
\[WeierstrassP]\_\(i\_{\(\[GothicCapitalG]\^*\), \[GothicCapitalM]}\)\) + \
\[WeierstrassP]\_\(i\_{\[GothicCapitalA], \[GothicCapitalM], \
\[GothicCapitalF]}\))\)\ \
\((\(-\[WeierstrassP]\_\(j\_{\(\[GothicCapitalG]\^*\), \[GothicCapitalF]}\)\) \
+ \[WeierstrassP]\_\(j\_{\[GothicCapitalA], \[GothicCapitalF], \
\[GothicCapitalM]}\))\) + \[GothicCapitalD]\_{i\_{\[GothicCapitalA], \
\[GothicCapitalM], \[GothicCapitalF]}, j\_{\[GothicCapitalA], \
\[GothicCapitalF], \[GothicCapitalM]}}\ \((\(-\[WeierstrassP]\_\(k\_{\(\
\[GothicCapitalG]\^*\), \[GothicCapitalF]}\)\) + \[WeierstrassP]\_\(k\_{\
\[GothicCapitalA], \[GothicCapitalF], \[GothicCapitalF]}\))\) + \
\[GothicCapitalD]\_{j\_{\[GothicCapitalA], \[GothicCapitalF], \
\[GothicCapitalM]}}\ \((\(-\[WeierstrassP]\_\(i\_{\(\[GothicCapitalG]\^*\), \
\[GothicCapitalM]}\)\) + \[WeierstrassP]\_\(i\_{\[GothicCapitalA], \
\[GothicCapitalM], \[GothicCapitalF]}\))\)\ \((\(-\[WeierstrassP]\_\(k\_{\(\
\[GothicCapitalG]\^*\), \[GothicCapitalF]}\)\) + \[WeierstrassP]\_\(k\_{\
\[GothicCapitalA], \[GothicCapitalF], \[GothicCapitalF]}\))\) + \
\[GothicCapitalD]\_{i\_{\[GothicCapitalA], \[GothicCapitalM], \
\[GothicCapitalF]}}\ \((\(-\[WeierstrassP]\_\(j\_{\(\[GothicCapitalG]\^*\), \
\[GothicCapitalF]}\)\) + \[WeierstrassP]\_\(j\_{\[GothicCapitalA], \
\[GothicCapitalF], \[GothicCapitalM]}\))\)\ \((\(-\[WeierstrassP]\_\(k\_{\(\
\[GothicCapitalG]\^*\), \[GothicCapitalF]}\)\) + \[WeierstrassP]\_\(k\_{\
\[GothicCapitalA], \[GothicCapitalF], \[GothicCapitalF]}\))\) + \((\(-\
\[WeierstrassP]\_\(i\_{\(\[GothicCapitalG]\^*\), \[GothicCapitalM]}\)\) + \
\[WeierstrassP]\_\(i\_{\[GothicCapitalA], \[GothicCapitalM], \
\[GothicCapitalF]}\))\)\ \
\((\(-\[WeierstrassP]\_\(j\_{\(\[GothicCapitalG]\^*\), \[GothicCapitalF]}\)\) \
+ \[WeierstrassP]\_\(j\_{\[GothicCapitalA], \[GothicCapitalF], \
\[GothicCapitalM]}\))\)\ \
\((\(-\[WeierstrassP]\_\(k\_{\(\[GothicCapitalG]\^*\), \[GothicCapitalF]}\)\) \
+ \[WeierstrassP]\_\(k\_{\[GothicCapitalA], \[GothicCapitalF], \
\[GothicCapitalF]}\))\))\) + \[GothicR]\_\({}, {i}\)\ \[GothicR]\_\({k}, \
{j}\)\ \((\[GothicCapitalD]\_{i\_{\[GothicCapitalA], \[GothicCapitalM], \
\[GothicCapitalM]}, j\_{\[GothicCapitalA], \[GothicCapitalF], \
\[GothicCapitalM]}, k\_{\[GothicCapitalA], \[GothicCapitalF], \
\[GothicCapitalF]}} + \[GothicCapitalD]\_{j\_{\[GothicCapitalA], \
\[GothicCapitalF], \[GothicCapitalM]}, k\_{\[GothicCapitalA], \
\[GothicCapitalF], \[GothicCapitalF]}}\ \((\(-\[WeierstrassP]\_\(i\_{\(\
\[GothicCapitalG]\^*\), \[GothicCapitalM]}\)\) + \[WeierstrassP]\_\(i\_{\
\[GothicCapitalA], \[GothicCapitalM], \[GothicCapitalM]}\))\) + \
\[GothicCapitalD]\_{i\_{\[GothicCapitalA], \[GothicCapitalM], \
\[GothicCapitalM]}, k\_{\[GothicCapitalA], \[GothicCapitalF], \
\[GothicCapitalF]}}\ \((\(-\[WeierstrassP]\_\(j\_{\(\[GothicCapitalG]\^*\), \
\[GothicCapitalF]}\)\) + \[WeierstrassP]\_\(j\_{\[GothicCapitalA], \
\[GothicCapitalF], \[GothicCapitalM]}\))\) + \[GothicCapitalD]\_{k\_{\
\[GothicCapitalA], \[GothicCapitalF], \[GothicCapitalF]}}\ \((\(-\
\[WeierstrassP]\_\(i\_{\(\[GothicCapitalG]\^*\), \[GothicCapitalM]}\)\) + \
\[WeierstrassP]\_\(i\_{\[GothicCapitalA], \[GothicCapitalM], \
\[GothicCapitalM]}\))\)\ \
\((\(-\[WeierstrassP]\_\(j\_{\(\[GothicCapitalG]\^*\), \[GothicCapitalF]}\)\) \
+ \[WeierstrassP]\_\(j\_{\[GothicCapitalA], \[GothicCapitalF], \
\[GothicCapitalM]}\))\) + \[GothicCapitalD]\_{i\_{\[GothicCapitalA], \
\[GothicCapitalM], \[GothicCapitalM]}, j\_{\[GothicCapitalA], \
\[GothicCapitalF], \[GothicCapitalM]}}\ \((\(-\[WeierstrassP]\_\(k\_{\(\
\[GothicCapitalG]\^*\), \[GothicCapitalF]}\)\) + \[WeierstrassP]\_\(k\_{\
\[GothicCapitalA], \[GothicCapitalF], \[GothicCapitalF]}\))\) + \
\[GothicCapitalD]\_{j\_{\[GothicCapitalA], \[GothicCapitalF], \
\[GothicCapitalM]}}\ \((\(-\[WeierstrassP]\_\(i\_{\(\[GothicCapitalG]\^*\), \
\[GothicCapitalM]}\)\) + \[WeierstrassP]\_\(i\_{\[GothicCapitalA], \
\[GothicCapitalM], \[GothicCapitalM]}\))\)\ \((\(-\[WeierstrassP]\_\(k\_{\(\
\[GothicCapitalG]\^*\), \[GothicCapitalF]}\)\) + \[WeierstrassP]\_\(k\_{\
\[GothicCapitalA], \[GothicCapitalF], \[GothicCapitalF]}\))\) + \
\[GothicCapitalD]\_{i\_{\[GothicCapitalA], \[GothicCapitalM], \
\[GothicCapitalM]}}\ \((\(-\[WeierstrassP]\_\(j\_{\(\[GothicCapitalG]\^*\), \
\[GothicCapitalF]}\)\) + \[WeierstrassP]\_\(j\_{\[GothicCapitalA], \
\[GothicCapitalF], \[GothicCapitalM]}\))\)\ \((\(-\[WeierstrassP]\_\(k\_{\(\
\[GothicCapitalG]\^*\), \[GothicCapitalF]}\)\) + \[WeierstrassP]\_\(k\_{\
\[GothicCapitalA], \[GothicCapitalF], \[GothicCapitalF]}\))\) + \((\(-\
\[WeierstrassP]\_\(i\_{\(\[GothicCapitalG]\^*\), \[GothicCapitalM]}\)\) + \
\[WeierstrassP]\_\(i\_{\[GothicCapitalA], \[GothicCapitalM], \
\[GothicCapitalM]}\))\)\ \
\((\(-\[WeierstrassP]\_\(j\_{\(\[GothicCapitalG]\^*\), \[GothicCapitalF]}\)\) \
+ \[WeierstrassP]\_\(j\_{\[GothicCapitalA], \[GothicCapitalF], \
\[GothicCapitalM]}\))\)\ \
\((\(-\[WeierstrassP]\_\(k\_{\(\[GothicCapitalG]\^*\), \[GothicCapitalF]}\)\) \
+ \[WeierstrassP]\_\(k\_{\[GothicCapitalA], \[GothicCapitalF], \
\[GothicCapitalF]}\))\))\) + \[GothicR]\_\({i}, {}\)\ \[GothicR]\_\({j}, \
{k}\)\ \((\[GothicCapitalD]\_{i\_{\[GothicCapitalA], \[GothicCapitalM], \
\[GothicCapitalF]}, j\_{\[GothicCapitalA], \[GothicCapitalF], \
\[GothicCapitalF]}, k\_{\[GothicCapitalA], \[GothicCapitalF], \
\[GothicCapitalM]}} + \[GothicCapitalD]\_{j\_{\[GothicCapitalA], \
\[GothicCapitalF], \[GothicCapitalF]}, k\_{\[GothicCapitalA], \
\[GothicCapitalF], \[GothicCapitalM]}}\ \((\(-\[WeierstrassP]\_\(i\_{\(\
\[GothicCapitalG]\^*\), \[GothicCapitalM]}\)\) + \[WeierstrassP]\_\(i\_{\
\[GothicCapitalA], \[GothicCapitalM], \[GothicCapitalF]}\))\) + \
\[GothicCapitalD]\_{i\_{\[GothicCapitalA], \[GothicCapitalM], \
\[GothicCapitalF]}, k\_{\[GothicCapitalA], \[GothicCapitalF], \
\[GothicCapitalM]}}\ \((\(-\[WeierstrassP]\_\(j\_{\(\[GothicCapitalG]\^*\), \
\[GothicCapitalF]}\)\) + \[WeierstrassP]\_\(j\_{\[GothicCapitalA], \
\[GothicCapitalF], \[GothicCapitalF]}\))\) + \[GothicCapitalD]\_{k\_{\
\[GothicCapitalA], \[GothicCapitalF], \[GothicCapitalM]}}\ \((\(-\
\[WeierstrassP]\_\(i\_{\(\[GothicCapitalG]\^*\), \[GothicCapitalM]}\)\) + \
\[WeierstrassP]\_\(i\_{\[GothicCapitalA], \[GothicCapitalM], \
\[GothicCapitalF]}\))\)\ \
\((\(-\[WeierstrassP]\_\(j\_{\(\[GothicCapitalG]\^*\), \[GothicCapitalF]}\)\) \
+ \[WeierstrassP]\_\(j\_{\[GothicCapitalA], \[GothicCapitalF], \
\[GothicCapitalF]}\))\) + \[GothicCapitalD]\_{i\_{\[GothicCapitalA], \
\[GothicCapitalM], \[GothicCapitalF]}, j\_{\[GothicCapitalA], \
\[GothicCapitalF], \[GothicCapitalF]}}\ \((\(-\[WeierstrassP]\_\(k\_{\(\
\[GothicCapitalG]\^*\), \[GothicCapitalF]}\)\) + \[WeierstrassP]\_\(k\_{\
\[GothicCapitalA], \[GothicCapitalF], \[GothicCapitalM]}\))\) + \
\[GothicCapitalD]\_{j\_{\[GothicCapitalA], \[GothicCapitalF], \
\[GothicCapitalF]}}\ \((\(-\[WeierstrassP]\_\(i\_{\(\[GothicCapitalG]\^*\), \
\[GothicCapitalM]}\)\) + \[WeierstrassP]\_\(i\_{\[GothicCapitalA], \
\[GothicCapitalM], \[GothicCapitalF]}\))\)\ \((\(-\[WeierstrassP]\_\(k\_{\(\
\[GothicCapitalG]\^*\), \[GothicCapitalF]}\)\) + \[WeierstrassP]\_\(k\_{\
\[GothicCapitalA], \[GothicCapitalF], \[GothicCapitalM]}\))\) + \
\[GothicCapitalD]\_{i\_{\[GothicCapitalA], \[GothicCapitalM], \
\[GothicCapitalF]}}\ \((\(-\[WeierstrassP]\_\(j\_{\(\[GothicCapitalG]\^*\), \
\[GothicCapitalF]}\)\) + \[WeierstrassP]\_\(j\_{\[GothicCapitalA], \
\[GothicCapitalF], \[GothicCapitalF]}\))\)\ \((\(-\[WeierstrassP]\_\(k\_{\(\
\[GothicCapitalG]\^*\), \[GothicCapitalF]}\)\) + \[WeierstrassP]\_\(k\_{\
\[GothicCapitalA], \[GothicCapitalF], \[GothicCapitalM]}\))\) + \((\(-\
\[WeierstrassP]\_\(i\_{\(\[GothicCapitalG]\^*\), \[GothicCapitalM]}\)\) + \
\[WeierstrassP]\_\(i\_{\[GothicCapitalA], \[GothicCapitalM], \
\[GothicCapitalF]}\))\)\ \
\((\(-\[WeierstrassP]\_\(j\_{\(\[GothicCapitalG]\^*\), \[GothicCapitalF]}\)\) \
+ \[WeierstrassP]\_\(j\_{\[GothicCapitalA], \[GothicCapitalF], \
\[GothicCapitalF]}\))\)\ \
\((\(-\[WeierstrassP]\_\(k\_{\(\[GothicCapitalG]\^*\), \[GothicCapitalF]}\)\) \
+ \[WeierstrassP]\_\(k\_{\[GothicCapitalA], \[GothicCapitalF], \
\[GothicCapitalM]}\))\))\) + \[GothicR]\_\({}, {i}\)\ \[GothicR]\_\({j}, \
{k}\)\ \((\[GothicCapitalD]\_{i\_{\[GothicCapitalA], \[GothicCapitalM], \
\[GothicCapitalM]}, j\_{\[GothicCapitalA], \[GothicCapitalF], \
\[GothicCapitalF]}, k\_{\[GothicCapitalA], \[GothicCapitalF], \
\[GothicCapitalM]}} + \[GothicCapitalD]\_{j\_{\[GothicCapitalA], \
\[GothicCapitalF], \[GothicCapitalF]}, k\_{\[GothicCapitalA], \
\[GothicCapitalF], \[GothicCapitalM]}}\ \((\(-\[WeierstrassP]\_\(i\_{\(\
\[GothicCapitalG]\^*\), \[GothicCapitalM]}\)\) + \[WeierstrassP]\_\(i\_{\
\[GothicCapitalA], \[GothicCapitalM], \[GothicCapitalM]}\))\) + \
\[GothicCapitalD]\_{i\_{\[GothicCapitalA], \[GothicCapitalM], \
\[GothicCapitalM]}, k\_{\[GothicCapitalA], \[GothicCapitalF], \
\[GothicCapitalM]}}\ \((\(-\[WeierstrassP]\_\(j\_{\(\[GothicCapitalG]\^*\), \
\[GothicCapitalF]}\)\) + \[WeierstrassP]\_\(j\_{\[GothicCapitalA], \
\[GothicCapitalF], \[GothicCapitalF]}\))\) + \[GothicCapitalD]\_{k\_{\
\[GothicCapitalA], \[GothicCapitalF], \[GothicCapitalM]}}\ \((\(-\
\[WeierstrassP]\_\(i\_{\(\[GothicCapitalG]\^*\), \[GothicCapitalM]}\)\) + \
\[WeierstrassP]\_\(i\_{\[GothicCapitalA], \[GothicCapitalM], \
\[GothicCapitalM]}\))\)\ \
\((\(-\[WeierstrassP]\_\(j\_{\(\[GothicCapitalG]\^*\), \[GothicCapitalF]}\)\) \
+ \[WeierstrassP]\_\(j\_{\[GothicCapitalA], \[GothicCapitalF], \
\[GothicCapitalF]}\))\) + \[GothicCapitalD]\_{i\_{\[GothicCapitalA], \
\[GothicCapitalM], \[GothicCapitalM]}, j\_{\[GothicCapitalA], \
\[GothicCapitalF], \[GothicCapitalF]}}\ \((\(-\[WeierstrassP]\_\(k\_{\(\
\[GothicCapitalG]\^*\), \[GothicCapitalF]}\)\) + \[WeierstrassP]\_\(k\_{\
\[GothicCapitalA], \[GothicCapitalF], \[GothicCapitalM]}\))\) + \
\[GothicCapitalD]\_{j\_{\[GothicCapitalA], \[GothicCapitalF], \
\[GothicCapitalF]}}\ \((\(-\[WeierstrassP]\_\(i\_{\(\[GothicCapitalG]\^*\), \
\[GothicCapitalM]}\)\) + \[WeierstrassP]\_\(i\_{\[GothicCapitalA], \
\[GothicCapitalM], \[GothicCapitalM]}\))\)\ \((\(-\[WeierstrassP]\_\(k\_{\(\
\[GothicCapitalG]\^*\), \[GothicCapitalF]}\)\) + \[WeierstrassP]\_\(k\_{\
\[GothicCapitalA], \[GothicCapitalF], \[GothicCapitalM]}\))\) + \
\[GothicCapitalD]\_{i\_{\[GothicCapitalA], \[GothicCapitalM], \
\[GothicCapitalM]}}\ \((\(-\[WeierstrassP]\_\(j\_{\(\[GothicCapitalG]\^*\), \
\[GothicCapitalF]}\)\) + \[WeierstrassP]\_\(j\_{\[GothicCapitalA], \
\[GothicCapitalF], \[GothicCapitalF]}\))\)\ \((\(-\[WeierstrassP]\_\(k\_{\(\
\[GothicCapitalG]\^*\), \[GothicCapitalF]}\)\) + \[WeierstrassP]\_\(k\_{\
\[GothicCapitalA], \[GothicCapitalF], \[GothicCapitalM]}\))\) + \((\(-\
\[WeierstrassP]\_\(i\_{\(\[GothicCapitalG]\^*\), \[GothicCapitalM]}\)\) + \
\[WeierstrassP]\_\(i\_{\[GothicCapitalA], \[GothicCapitalM], \
\[GothicCapitalM]}\))\)\ \
\((\(-\[WeierstrassP]\_\(j\_{\(\[GothicCapitalG]\^*\), \[GothicCapitalF]}\)\) \
+ \[WeierstrassP]\_\(j\_{\[GothicCapitalA], \[GothicCapitalF], \
\[GothicCapitalF]}\))\)\ \
\((\(-\[WeierstrassP]\_\(k\_{\(\[GothicCapitalG]\^*\), \[GothicCapitalF]}\)\) \
+ \[WeierstrassP]\_\(k\_{\[GothicCapitalA], \[GothicCapitalF], \
\[GothicCapitalM]}\))\))\) + \[GothicR]\_\({}, {j, k}\)\ \[GothicR]\_\({i}, \
{}\)\ \((\[GothicCapitalD]\_{i\_{\[GothicCapitalA], \[GothicCapitalM], \
\[GothicCapitalF]}, j\_{\[GothicCapitalA], \[GothicCapitalF], \
\[GothicCapitalM]}, k\_{\[GothicCapitalA], \[GothicCapitalF], \
\[GothicCapitalM]}} + \[GothicCapitalD]\_{j\_{\[GothicCapitalA], \
\[GothicCapitalF], \[GothicCapitalM]}, k\_{\[GothicCapitalA], \
\[GothicCapitalF], \[GothicCapitalM]}}\ \((\(-\[WeierstrassP]\_\(i\_{\(\
\[GothicCapitalG]\^*\), \[GothicCapitalM]}\)\) + \[WeierstrassP]\_\(i\_{\
\[GothicCapitalA], \[GothicCapitalM], \[GothicCapitalF]}\))\) + \
\[GothicCapitalD]\_{i\_{\[GothicCapitalA], \[GothicCapitalM], \
\[GothicCapitalF]}, k\_{\[GothicCapitalA], \[GothicCapitalF], \
\[GothicCapitalM]}}\ \((\(-\[WeierstrassP]\_\(j\_{\(\[GothicCapitalG]\^*\), \
\[GothicCapitalF]}\)\) + \[WeierstrassP]\_\(j\_{\[GothicCapitalA], \
\[GothicCapitalF], \[GothicCapitalM]}\))\) + \[GothicCapitalD]\_{k\_{\
\[GothicCapitalA], \[GothicCapitalF], \[GothicCapitalM]}}\ \((\(-\
\[WeierstrassP]\_\(i\_{\(\[GothicCapitalG]\^*\), \[GothicCapitalM]}\)\) + \
\[WeierstrassP]\_\(i\_{\[GothicCapitalA], \[GothicCapitalM], \
\[GothicCapitalF]}\))\)\ \
\((\(-\[WeierstrassP]\_\(j\_{\(\[GothicCapitalG]\^*\), \[GothicCapitalF]}\)\) \
+ \[WeierstrassP]\_\(j\_{\[GothicCapitalA], \[GothicCapitalF], \
\[GothicCapitalM]}\))\) + \[GothicCapitalD]\_{i\_{\[GothicCapitalA], \
\[GothicCapitalM], \[GothicCapitalF]}, j\_{\[GothicCapitalA], \
\[GothicCapitalF], \[GothicCapitalM]}}\ \((\(-\[WeierstrassP]\_\(k\_{\(\
\[GothicCapitalG]\^*\), \[GothicCapitalF]}\)\) + \[WeierstrassP]\_\(k\_{\
\[GothicCapitalA], \[GothicCapitalF], \[GothicCapitalM]}\))\) + \
\[GothicCapitalD]\_{j\_{\[GothicCapitalA], \[GothicCapitalF], \
\[GothicCapitalM]}}\ \((\(-\[WeierstrassP]\_\(i\_{\(\[GothicCapitalG]\^*\), \
\[GothicCapitalM]}\)\) + \[WeierstrassP]\_\(i\_{\[GothicCapitalA], \
\[GothicCapitalM], \[GothicCapitalF]}\))\)\ \((\(-\[WeierstrassP]\_\(k\_{\(\
\[GothicCapitalG]\^*\), \[GothicCapitalF]}\)\) + \[WeierstrassP]\_\(k\_{\
\[GothicCapitalA], \[GothicCapitalF], \[GothicCapitalM]}\))\) + \
\[GothicCapitalD]\_{i\_{\[GothicCapitalA], \[GothicCapitalM], \
\[GothicCapitalF]}}\ \((\(-\[WeierstrassP]\_\(j\_{\(\[GothicCapitalG]\^*\), \
\[GothicCapitalF]}\)\) + \[WeierstrassP]\_\(j\_{\[GothicCapitalA], \
\[GothicCapitalF], \[GothicCapitalM]}\))\)\ \((\(-\[WeierstrassP]\_\(k\_{\(\
\[GothicCapitalG]\^*\), \[GothicCapitalF]}\)\) + \[WeierstrassP]\_\(k\_{\
\[GothicCapitalA], \[GothicCapitalF], \[GothicCapitalM]}\))\) + \((\(-\
\[WeierstrassP]\_\(i\_{\(\[GothicCapitalG]\^*\), \[GothicCapitalM]}\)\) + \
\[WeierstrassP]\_\(i\_{\[GothicCapitalA], \[GothicCapitalM], \
\[GothicCapitalF]}\))\)\ \
\((\(-\[WeierstrassP]\_\(j\_{\(\[GothicCapitalG]\^*\), \[GothicCapitalF]}\)\) \
+ \[WeierstrassP]\_\(j\_{\[GothicCapitalA], \[GothicCapitalF], \
\[GothicCapitalM]}\))\)\ \
\((\(-\[WeierstrassP]\_\(k\_{\(\[GothicCapitalG]\^*\), \[GothicCapitalF]}\)\) \
+ \[WeierstrassP]\_\(k\_{\[GothicCapitalA], \[GothicCapitalF], \
\[GothicCapitalM]}\))\))\) + \[GothicR]\_\({}, {i}\)\ \[GothicR]\_\({}, {j, \
k}\)\ \((\[GothicCapitalD]\_{i\_{\[GothicCapitalA], \[GothicCapitalM], \
\[GothicCapitalM]}, j\_{\[GothicCapitalA], \[GothicCapitalF], \
\[GothicCapitalM]}, k\_{\[GothicCapitalA], \[GothicCapitalF], \
\[GothicCapitalM]}} + \[GothicCapitalD]\_{j\_{\[GothicCapitalA], \
\[GothicCapitalF], \[GothicCapitalM]}, k\_{\[GothicCapitalA], \
\[GothicCapitalF], \[GothicCapitalM]}}\ \((\(-\[WeierstrassP]\_\(i\_{\(\
\[GothicCapitalG]\^*\), \[GothicCapitalM]}\)\) + \[WeierstrassP]\_\(i\_{\
\[GothicCapitalA], \[GothicCapitalM], \[GothicCapitalM]}\))\) + \
\[GothicCapitalD]\_{i\_{\[GothicCapitalA], \[GothicCapitalM], \
\[GothicCapitalM]}, k\_{\[GothicCapitalA], \[GothicCapitalF], \
\[GothicCapitalM]}}\ \((\(-\[WeierstrassP]\_\(j\_{\(\[GothicCapitalG]\^*\), \
\[GothicCapitalF]}\)\) + \[WeierstrassP]\_\(j\_{\[GothicCapitalA], \
\[GothicCapitalF], \[GothicCapitalM]}\))\) + \[GothicCapitalD]\_{k\_{\
\[GothicCapitalA], \[GothicCapitalF], \[GothicCapitalM]}}\ \((\(-\
\[WeierstrassP]\_\(i\_{\(\[GothicCapitalG]\^*\), \[GothicCapitalM]}\)\) + \
\[WeierstrassP]\_\(i\_{\[GothicCapitalA], \[GothicCapitalM], \
\[GothicCapitalM]}\))\)\ \
\((\(-\[WeierstrassP]\_\(j\_{\(\[GothicCapitalG]\^*\), \[GothicCapitalF]}\)\) \
+ \[WeierstrassP]\_\(j\_{\[GothicCapitalA], \[GothicCapitalF], \
\[GothicCapitalM]}\))\) + \[GothicCapitalD]\_{i\_{\[GothicCapitalA], \
\[GothicCapitalM], \[GothicCapitalM]}, j\_{\[GothicCapitalA], \
\[GothicCapitalF], \[GothicCapitalM]}}\ \((\(-\[WeierstrassP]\_\(k\_{\(\
\[GothicCapitalG]\^*\), \[GothicCapitalF]}\)\) + \[WeierstrassP]\_\(k\_{\
\[GothicCapitalA], \[GothicCapitalF], \[GothicCapitalM]}\))\) + \
\[GothicCapitalD]\_{j\_{\[GothicCapitalA], \[GothicCapitalF], \
\[GothicCapitalM]}}\ \((\(-\[WeierstrassP]\_\(i\_{\(\[GothicCapitalG]\^*\), \
\[GothicCapitalM]}\)\) + \[WeierstrassP]\_\(i\_{\[GothicCapitalA], \
\[GothicCapitalM], \[GothicCapitalM]}\))\)\ \((\(-\[WeierstrassP]\_\(k\_{\(\
\[GothicCapitalG]\^*\), \[GothicCapitalF]}\)\) + \[WeierstrassP]\_\(k\_{\
\[GothicCapitalA], \[GothicCapitalF], \[GothicCapitalM]}\))\) + \
\[GothicCapitalD]\_{i\_{\[GothicCapitalA], \[GothicCapitalM], \
\[GothicCapitalM]}}\ \((\(-\[WeierstrassP]\_\(j\_{\(\[GothicCapitalG]\^*\), \
\[GothicCapitalF]}\)\) + \[WeierstrassP]\_\(j\_{\[GothicCapitalA], \
\[GothicCapitalF], \[GothicCapitalM]}\))\)\ \((\(-\[WeierstrassP]\_\(k\_{\(\
\[GothicCapitalG]\^*\), \[GothicCapitalF]}\)\) + \[WeierstrassP]\_\(k\_{\
\[GothicCapitalA], \[GothicCapitalF], \[GothicCapitalM]}\))\) + \((\(-\
\[WeierstrassP]\_\(i\_{\(\[GothicCapitalG]\^*\), \[GothicCapitalM]}\)\) + \
\[WeierstrassP]\_\(i\_{\[GothicCapitalA], \[GothicCapitalM], \
\[GothicCapitalM]}\))\)\ \
\((\(-\[WeierstrassP]\_\(j\_{\(\[GothicCapitalG]\^*\), \[GothicCapitalF]}\)\) \
+ \[WeierstrassP]\_\(j\_{\[GothicCapitalA], \[GothicCapitalF], \
\[GothicCapitalM]}\))\)\ \
\((\(-\[WeierstrassP]\_\(k\_{\(\[GothicCapitalG]\^*\), \[GothicCapitalF]}\)\) \
+ \[WeierstrassP]\_\(k\_{\[GothicCapitalA], \[GothicCapitalF], \
\[GothicCapitalM]}\))\))\)\)], "Output",
  CellLabel->"Out[253]="]
}, Closed]],

Cell[TextData[{
  "Note that the expression involves associations between genes in the male \
and the female parent: this allows for ",
  ButtonBox["non-random mating",
    ButtonData:>{"Sexual selection", None},
    ButtonStyle->"AddOnsLink",
    ButtonNote->"non-random mating"],
  "."
}], "Text"],

Cell["\<\
It is assumed that where the association involves genes in the \
male, and genes in the female, these are just two distinct individuals,  The \
algorithm has not yet been extended to allow for multiple individuals to \
contribute.\
\>", "Text"],

Cell["\<\
The association is a sum over the products of recombination rates \
in each sex separately.  Recombination rates can depend on Sex, and on one or \
more other components of the context:\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\[GothicCapitalD]\_{i\_{\(\[GothicCapitalG]\^*\), \[GothicCapitalM]}, j\
\_{\(\[GothicCapitalG]\^*\), \[GothicCapitalF]}, \
k\_{\(\[GothicCapitalG]\^*\), \[GothicCapitalF]}} /. 
      Recombination[{Sex}]\)], "Input",
  CellLabel->"In[254]:="],

Cell[BoxData[
    \(\[GothicR]\_\(\[GothicCapitalF], {j, k}, {}\)\ \[GothicR]\_\(\
\[GothicCapitalM], {i}, {}\)\ \((\[GothicCapitalD]\_{i\_{\[GothicCapitalA], \
\[GothicCapitalM], \[GothicCapitalF]}, j\_{\[GothicCapitalA], \
\[GothicCapitalF], \[GothicCapitalF]}, k\_{\[GothicCapitalA], \
\[GothicCapitalF], \[GothicCapitalF]}} + \[GothicCapitalD]\_{j\_{\
\[GothicCapitalA], \[GothicCapitalF], \[GothicCapitalF]}, k\_{\
\[GothicCapitalA], \[GothicCapitalF], \[GothicCapitalF]}}\ \((\(-\
\[WeierstrassP]\_\(i\_{\(\[GothicCapitalG]\^*\), \[GothicCapitalM]}\)\) + \
\[WeierstrassP]\_\(i\_{\[GothicCapitalA], \[GothicCapitalM], \
\[GothicCapitalF]}\))\) + \[GothicCapitalD]\_{i\_{\[GothicCapitalA], \
\[GothicCapitalM], \[GothicCapitalF]}, k\_{\[GothicCapitalA], \
\[GothicCapitalF], \[GothicCapitalF]}}\ \((\(-\[WeierstrassP]\_\(j\_{\(\
\[GothicCapitalG]\^*\), \[GothicCapitalF]}\)\) + \[WeierstrassP]\_\(j\_{\
\[GothicCapitalA], \[GothicCapitalF], \[GothicCapitalF]}\))\) + \
\[GothicCapitalD]\_{k\_{\[GothicCapitalA], \[GothicCapitalF], \
\[GothicCapitalF]}}\ \((\(-\[WeierstrassP]\_\(i\_{\(\[GothicCapitalG]\^*\), \
\[GothicCapitalM]}\)\) + \[WeierstrassP]\_\(i\_{\[GothicCapitalA], \
\[GothicCapitalM], \[GothicCapitalF]}\))\)\ \((\(-\[WeierstrassP]\_\(j\_{\(\
\[GothicCapitalG]\^*\), \[GothicCapitalF]}\)\) + \[WeierstrassP]\_\(j\_{\
\[GothicCapitalA], \[GothicCapitalF], \[GothicCapitalF]}\))\) + \
\[GothicCapitalD]\_{i\_{\[GothicCapitalA], \[GothicCapitalM], \
\[GothicCapitalF]}, j\_{\[GothicCapitalA], \[GothicCapitalF], \
\[GothicCapitalF]}}\ \((\(-\[WeierstrassP]\_\(k\_{\(\[GothicCapitalG]\^*\), \
\[GothicCapitalF]}\)\) + \[WeierstrassP]\_\(k\_{\[GothicCapitalA], \
\[GothicCapitalF], \[GothicCapitalF]}\))\) + \[GothicCapitalD]\_{j\_{\
\[GothicCapitalA], \[GothicCapitalF], \[GothicCapitalF]}}\ \((\(-\
\[WeierstrassP]\_\(i\_{\(\[GothicCapitalG]\^*\), \[GothicCapitalM]}\)\) + \
\[WeierstrassP]\_\(i\_{\[GothicCapitalA], \[GothicCapitalM], \
\[GothicCapitalF]}\))\)\ \
\((\(-\[WeierstrassP]\_\(k\_{\(\[GothicCapitalG]\^*\), \[GothicCapitalF]}\)\) \
+ \[WeierstrassP]\_\(k\_{\[GothicCapitalA], \[GothicCapitalF], \
\[GothicCapitalF]}\))\) + \[GothicCapitalD]\_{i\_{\[GothicCapitalA], \
\[GothicCapitalM], \[GothicCapitalF]}}\ \((\(-\[WeierstrassP]\_\(j\_{\(\
\[GothicCapitalG]\^*\), \[GothicCapitalF]}\)\) + \[WeierstrassP]\_\(j\_{\
\[GothicCapitalA], \[GothicCapitalF], \[GothicCapitalF]}\))\)\ \((\(-\
\[WeierstrassP]\_\(k\_{\(\[GothicCapitalG]\^*\), \[GothicCapitalF]}\)\) + \
\[WeierstrassP]\_\(k\_{\[GothicCapitalA], \[GothicCapitalF], \
\[GothicCapitalF]}\))\) + \((\(-\[WeierstrassP]\_\(i\_{\(\[GothicCapitalG]\^*\
\), \[GothicCapitalM]}\)\) + \[WeierstrassP]\_\(i\_{\[GothicCapitalA], \
\[GothicCapitalM], \[GothicCapitalF]}\))\)\ \((\(-\[WeierstrassP]\_\(j\_{\(\
\[GothicCapitalG]\^*\), \[GothicCapitalF]}\)\) + \[WeierstrassP]\_\(j\_{\
\[GothicCapitalA], \[GothicCapitalF], \[GothicCapitalF]}\))\)\ \((\(-\
\[WeierstrassP]\_\(k\_{\(\[GothicCapitalG]\^*\), \[GothicCapitalF]}\)\) + \
\[WeierstrassP]\_\(k\_{\[GothicCapitalA], \[GothicCapitalF], \
\[GothicCapitalF]}\))\))\) + \[GothicR]\_\(\[GothicCapitalF], {j, k}, {}\)\ \
\[GothicR]\_\(\[GothicCapitalM], {}, {i}\)\ \((\[GothicCapitalD]\_{i\_{\
\[GothicCapitalA], \[GothicCapitalM], \[GothicCapitalM]}, j\_{\
\[GothicCapitalA], \[GothicCapitalF], \[GothicCapitalF]}, k\_{\
\[GothicCapitalA], \[GothicCapitalF], \[GothicCapitalF]}} + \[GothicCapitalD]\
\_{j\_{\[GothicCapitalA], \[GothicCapitalF], \[GothicCapitalF]}, k\_{\
\[GothicCapitalA], \[GothicCapitalF], \[GothicCapitalF]}}\ \((\(-\
\[WeierstrassP]\_\(i\_{\(\[GothicCapitalG]\^*\), \[GothicCapitalM]}\)\) + \
\[WeierstrassP]\_\(i\_{\[GothicCapitalA], \[GothicCapitalM], \
\[GothicCapitalM]}\))\) + \[GothicCapitalD]\_{i\_{\[GothicCapitalA], \
\[GothicCapitalM], \[GothicCapitalM]}, k\_{\[GothicCapitalA], \
\[GothicCapitalF], \[GothicCapitalF]}}\ \((\(-\[WeierstrassP]\_\(j\_{\(\
\[GothicCapitalG]\^*\), \[GothicCapitalF]}\)\) + \[WeierstrassP]\_\(j\_{\
\[GothicCapitalA], \[GothicCapitalF], \[GothicCapitalF]}\))\) + \
\[GothicCapitalD]\_{k\_{\[GothicCapitalA], \[GothicCapitalF], \
\[GothicCapitalF]}}\ \((\(-\[WeierstrassP]\_\(i\_{\(\[GothicCapitalG]\^*\), \
\[GothicCapitalM]}\)\) + \[WeierstrassP]\_\(i\_{\[GothicCapitalA], \
\[GothicCapitalM], \[GothicCapitalM]}\))\)\ \((\(-\[WeierstrassP]\_\(j\_{\(\
\[GothicCapitalG]\^*\), \[GothicCapitalF]}\)\) + \[WeierstrassP]\_\(j\_{\
\[GothicCapitalA], \[GothicCapitalF], \[GothicCapitalF]}\))\) + \
\[GothicCapitalD]\_{i\_{\[GothicCapitalA], \[GothicCapitalM], \
\[GothicCapitalM]}, j\_{\[GothicCapitalA], \[GothicCapitalF], \
\[GothicCapitalF]}}\ \((\(-\[WeierstrassP]\_\(k\_{\(\[GothicCapitalG]\^*\), \
\[GothicCapitalF]}\)\) + \[WeierstrassP]\_\(k\_{\[GothicCapitalA], \
\[GothicCapitalF], \[GothicCapitalF]}\))\) + \[GothicCapitalD]\_{j\_{\
\[GothicCapitalA], \[GothicCapitalF], \[GothicCapitalF]}}\ \((\(-\
\[WeierstrassP]\_\(i\_{\(\[GothicCapitalG]\^*\), \[GothicCapitalM]}\)\) + \
\[WeierstrassP]\_\(i\_{\[GothicCapitalA], \[GothicCapitalM], \
\[GothicCapitalM]}\))\)\ \
\((\(-\[WeierstrassP]\_\(k\_{\(\[GothicCapitalG]\^*\), \[GothicCapitalF]}\)\) \
+ \[WeierstrassP]\_\(k\_{\[GothicCapitalA], \[GothicCapitalF], \
\[GothicCapitalF]}\))\) + \[GothicCapitalD]\_{i\_{\[GothicCapitalA], \
\[GothicCapitalM], \[GothicCapitalM]}}\ \((\(-\[WeierstrassP]\_\(j\_{\(\
\[GothicCapitalG]\^*\), \[GothicCapitalF]}\)\) + \[WeierstrassP]\_\(j\_{\
\[GothicCapitalA], \[GothicCapitalF], \[GothicCapitalF]}\))\)\ \((\(-\
\[WeierstrassP]\_\(k\_{\(\[GothicCapitalG]\^*\), \[GothicCapitalF]}\)\) + \
\[WeierstrassP]\_\(k\_{\[GothicCapitalA], \[GothicCapitalF], \
\[GothicCapitalF]}\))\) + \((\(-\[WeierstrassP]\_\(i\_{\(\[GothicCapitalG]\^*\
\), \[GothicCapitalM]}\)\) + \[WeierstrassP]\_\(i\_{\[GothicCapitalA], \
\[GothicCapitalM], \[GothicCapitalM]}\))\)\ \((\(-\[WeierstrassP]\_\(j\_{\(\
\[GothicCapitalG]\^*\), \[GothicCapitalF]}\)\) + \[WeierstrassP]\_\(j\_{\
\[GothicCapitalA], \[GothicCapitalF], \[GothicCapitalF]}\))\)\ \((\(-\
\[WeierstrassP]\_\(k\_{\(\[GothicCapitalG]\^*\), \[GothicCapitalF]}\)\) + \
\[WeierstrassP]\_\(k\_{\[GothicCapitalA], \[GothicCapitalF], \
\[GothicCapitalF]}\))\))\) + \[GothicR]\_\(\[GothicCapitalF], {k}, {j}\)\ \
\[GothicR]\_\(\[GothicCapitalM], {i}, {}\)\ \((\[GothicCapitalD]\_{i\_{\
\[GothicCapitalA], \[GothicCapitalM], \[GothicCapitalF]}, j\_{\
\[GothicCapitalA], \[GothicCapitalF], \[GothicCapitalM]}, k\_{\
\[GothicCapitalA], \[GothicCapitalF], \[GothicCapitalF]}} + \[GothicCapitalD]\
\_{j\_{\[GothicCapitalA], \[GothicCapitalF], \[GothicCapitalM]}, k\_{\
\[GothicCapitalA], \[GothicCapitalF], \[GothicCapitalF]}}\ \((\(-\
\[WeierstrassP]\_\(i\_{\(\[GothicCapitalG]\^*\), \[GothicCapitalM]}\)\) + \
\[WeierstrassP]\_\(i\_{\[GothicCapitalA], \[GothicCapitalM], \
\[GothicCapitalF]}\))\) + \[GothicCapitalD]\_{i\_{\[GothicCapitalA], \
\[GothicCapitalM], \[GothicCapitalF]}, k\_{\[GothicCapitalA], \
\[GothicCapitalF], \[GothicCapitalF]}}\ \((\(-\[WeierstrassP]\_\(j\_{\(\
\[GothicCapitalG]\^*\), \[GothicCapitalF]}\)\) + \[WeierstrassP]\_\(j\_{\
\[GothicCapitalA], \[GothicCapitalF], \[GothicCapitalM]}\))\) + \
\[GothicCapitalD]\_{k\_{\[GothicCapitalA], \[GothicCapitalF], \
\[GothicCapitalF]}}\ \((\(-\[WeierstrassP]\_\(i\_{\(\[GothicCapitalG]\^*\), \
\[GothicCapitalM]}\)\) + \[WeierstrassP]\_\(i\_{\[GothicCapitalA], \
\[GothicCapitalM], \[GothicCapitalF]}\))\)\ \((\(-\[WeierstrassP]\_\(j\_{\(\
\[GothicCapitalG]\^*\), \[GothicCapitalF]}\)\) + \[WeierstrassP]\_\(j\_{\
\[GothicCapitalA], \[GothicCapitalF], \[GothicCapitalM]}\))\) + \
\[GothicCapitalD]\_{i\_{\[GothicCapitalA], \[GothicCapitalM], \
\[GothicCapitalF]}, j\_{\[GothicCapitalA], \[GothicCapitalF], \
\[GothicCapitalM]}}\ \((\(-\[WeierstrassP]\_\(k\_{\(\[GothicCapitalG]\^*\), \
\[GothicCapitalF]}\)\) + \[WeierstrassP]\_\(k\_{\[GothicCapitalA], \
\[GothicCapitalF], \[GothicCapitalF]}\))\) + \[GothicCapitalD]\_{j\_{\
\[GothicCapitalA], \[GothicCapitalF], \[GothicCapitalM]}}\ \((\(-\
\[WeierstrassP]\_\(i\_{\(\[GothicCapitalG]\^*\), \[GothicCapitalM]}\)\) + \
\[WeierstrassP]\_\(i\_{\[GothicCapitalA], \[GothicCapitalM], \
\[GothicCapitalF]}\))\)\ \
\((\(-\[WeierstrassP]\_\(k\_{\(\[GothicCapitalG]\^*\), \[GothicCapitalF]}\)\) \
+ \[WeierstrassP]\_\(k\_{\[GothicCapitalA], \[GothicCapitalF], \
\[GothicCapitalF]}\))\) + \[GothicCapitalD]\_{i\_{\[GothicCapitalA], \
\[GothicCapitalM], \[GothicCapitalF]}}\ \((\(-\[WeierstrassP]\_\(j\_{\(\
\[GothicCapitalG]\^*\), \[GothicCapitalF]}\)\) + \[WeierstrassP]\_\(j\_{\
\[GothicCapitalA], \[GothicCapitalF], \[GothicCapitalM]}\))\)\ \((\(-\
\[WeierstrassP]\_\(k\_{\(\[GothicCapitalG]\^*\), \[GothicCapitalF]}\)\) + \
\[WeierstrassP]\_\(k\_{\[GothicCapitalA], \[GothicCapitalF], \
\[GothicCapitalF]}\))\) + \((\(-\[WeierstrassP]\_\(i\_{\(\[GothicCapitalG]\^*\
\), \[GothicCapitalM]}\)\) + \[WeierstrassP]\_\(i\_{\[GothicCapitalA], \
\[GothicCapitalM], \[GothicCapitalF]}\))\)\ \((\(-\[WeierstrassP]\_\(j\_{\(\
\[GothicCapitalG]\^*\), \[GothicCapitalF]}\)\) + \[WeierstrassP]\_\(j\_{\
\[GothicCapitalA], \[GothicCapitalF], \[GothicCapitalM]}\))\)\ \((\(-\
\[WeierstrassP]\_\(k\_{\(\[GothicCapitalG]\^*\), \[GothicCapitalF]}\)\) + \
\[WeierstrassP]\_\(k\_{\[GothicCapitalA], \[GothicCapitalF], \
\[GothicCapitalF]}\))\))\) + \[GothicR]\_\(\[GothicCapitalF], {k}, {j}\)\ \
\[GothicR]\_\(\[GothicCapitalM], {}, {i}\)\ \((\[GothicCapitalD]\_{i\_{\
\[GothicCapitalA], \[GothicCapitalM], \[GothicCapitalM]}, j\_{\
\[GothicCapitalA], \[GothicCapitalF], \[GothicCapitalM]}, k\_{\
\[GothicCapitalA], \[GothicCapitalF], \[GothicCapitalF]}} + \[GothicCapitalD]\
\_{j\_{\[GothicCapitalA], \[GothicCapitalF], \[GothicCapitalM]}, k\_{\
\[GothicCapitalA], \[GothicCapitalF], \[GothicCapitalF]}}\ \((\(-\
\[WeierstrassP]\_\(i\_{\(\[GothicCapitalG]\^*\), \[GothicCapitalM]}\)\) + \
\[WeierstrassP]\_\(i\_{\[GothicCapitalA], \[GothicCapitalM], \
\[GothicCapitalM]}\))\) + \[GothicCapitalD]\_{i\_{\[GothicCapitalA], \
\[GothicCapitalM], \[GothicCapitalM]}, k\_{\[GothicCapitalA], \
\[GothicCapitalF], \[GothicCapitalF]}}\ \((\(-\[WeierstrassP]\_\(j\_{\(\
\[GothicCapitalG]\^*\), \[GothicCapitalF]}\)\) + \[WeierstrassP]\_\(j\_{\
\[GothicCapitalA], \[GothicCapitalF], \[GothicCapitalM]}\))\) + \
\[GothicCapitalD]\_{k\_{\[GothicCapitalA], \[GothicCapitalF], \
\[GothicCapitalF]}}\ \((\(-\[WeierstrassP]\_\(i\_{\(\[GothicCapitalG]\^*\), \
\[GothicCapitalM]}\)\) + \[WeierstrassP]\_\(i\_{\[GothicCapitalA], \
\[GothicCapitalM], \[GothicCapitalM]}\))\)\ \((\(-\[WeierstrassP]\_\(j\_{\(\
\[GothicCapitalG]\^*\), \[GothicCapitalF]}\)\) + \[WeierstrassP]\_\(j\_{\
\[GothicCapitalA], \[GothicCapitalF], \[GothicCapitalM]}\))\) + \
\[GothicCapitalD]\_{i\_{\[GothicCapitalA], \[GothicCapitalM], \
\[GothicCapitalM]}, j\_{\[GothicCapitalA], \[GothicCapitalF], \
\[GothicCapitalM]}}\ \((\(-\[WeierstrassP]\_\(k\_{\(\[GothicCapitalG]\^*\), \
\[GothicCapitalF]}\)\) + \[WeierstrassP]\_\(k\_{\[GothicCapitalA], \
\[GothicCapitalF], \[GothicCapitalF]}\))\) + \[GothicCapitalD]\_{j\_{\
\[GothicCapitalA], \[GothicCapitalF], \[GothicCapitalM]}}\ \((\(-\
\[WeierstrassP]\_\(i\_{\(\[GothicCapitalG]\^*\), \[GothicCapitalM]}\)\) + \
\[WeierstrassP]\_\(i\_{\[GothicCapitalA], \[GothicCapitalM], \
\[GothicCapitalM]}\))\)\ \
\((\(-\[WeierstrassP]\_\(k\_{\(\[GothicCapitalG]\^*\), \[GothicCapitalF]}\)\) \
+ \[WeierstrassP]\_\(k\_{\[GothicCapitalA], \[GothicCapitalF], \
\[GothicCapitalF]}\))\) + \[GothicCapitalD]\_{i\_{\[GothicCapitalA], \
\[GothicCapitalM], \[GothicCapitalM]}}\ \((\(-\[WeierstrassP]\_\(j\_{\(\
\[GothicCapitalG]\^*\), \[GothicCapitalF]}\)\) + \[WeierstrassP]\_\(j\_{\
\[GothicCapitalA], \[GothicCapitalF], \[GothicCapitalM]}\))\)\ \((\(-\
\[WeierstrassP]\_\(k\_{\(\[GothicCapitalG]\^*\), \[GothicCapitalF]}\)\) + \
\[WeierstrassP]\_\(k\_{\[GothicCapitalA], \[GothicCapitalF], \
\[GothicCapitalF]}\))\) + \((\(-\[WeierstrassP]\_\(i\_{\(\[GothicCapitalG]\^*\
\), \[GothicCapitalM]}\)\) + \[WeierstrassP]\_\(i\_{\[GothicCapitalA], \
\[GothicCapitalM], \[GothicCapitalM]}\))\)\ \((\(-\[WeierstrassP]\_\(j\_{\(\
\[GothicCapitalG]\^*\), \[GothicCapitalF]}\)\) + \[WeierstrassP]\_\(j\_{\
\[GothicCapitalA], \[GothicCapitalF], \[GothicCapitalM]}\))\)\ \((\(-\
\[WeierstrassP]\_\(k\_{\(\[GothicCapitalG]\^*\), \[GothicCapitalF]}\)\) + \
\[WeierstrassP]\_\(k\_{\[GothicCapitalA], \[GothicCapitalF], \
\[GothicCapitalF]}\))\))\) + \[GothicR]\_\(\[GothicCapitalF], {j}, {k}\)\ \
\[GothicR]\_\(\[GothicCapitalM], {i}, {}\)\ \((\[GothicCapitalD]\_{i\_{\
\[GothicCapitalA], \[GothicCapitalM], \[GothicCapitalF]}, j\_{\
\[GothicCapitalA], \[GothicCapitalF], \[GothicCapitalF]}, k\_{\
\[GothicCapitalA], \[GothicCapitalF], \[GothicCapitalM]}} + \[GothicCapitalD]\
\_{j\_{\[GothicCapitalA], \[GothicCapitalF], \[GothicCapitalF]}, k\_{\
\[GothicCapitalA], \[GothicCapitalF], \[GothicCapitalM]}}\ \((\(-\
\[WeierstrassP]\_\(i\_{\(\[GothicCapitalG]\^*\), \[GothicCapitalM]}\)\) + \
\[WeierstrassP]\_\(i\_{\[GothicCapitalA], \[GothicCapitalM], \
\[GothicCapitalF]}\))\) + \[GothicCapitalD]\_{i\_{\[GothicCapitalA], \
\[GothicCapitalM], \[GothicCapitalF]}, k\_{\[GothicCapitalA], \
\[GothicCapitalF], \[GothicCapitalM]}}\ \((\(-\[WeierstrassP]\_\(j\_{\(\
\[GothicCapitalG]\^*\), \[GothicCapitalF]}\)\) + \[WeierstrassP]\_\(j\_{\
\[GothicCapitalA], \[GothicCapitalF], \[GothicCapitalF]}\))\) + \
\[GothicCapitalD]\_{k\_{\[GothicCapitalA], \[GothicCapitalF], \
\[GothicCapitalM]}}\ \((\(-\[WeierstrassP]\_\(i\_{\(\[GothicCapitalG]\^*\), \
\[GothicCapitalM]}\)\) + \[WeierstrassP]\_\(i\_{\[GothicCapitalA], \
\[GothicCapitalM], \[GothicCapitalF]}\))\)\ \((\(-\[WeierstrassP]\_\(j\_{\(\
\[GothicCapitalG]\^*\), \[GothicCapitalF]}\)\) + \[WeierstrassP]\_\(j\_{\
\[GothicCapitalA], \[GothicCapitalF], \[GothicCapitalF]}\))\) + \
\[GothicCapitalD]\_{i\_{\[GothicCapitalA], \[GothicCapitalM], \
\[GothicCapitalF]}, j\_{\[GothicCapitalA], \[GothicCapitalF], \
\[GothicCapitalF]}}\ \((\(-\[WeierstrassP]\_\(k\_{\(\[GothicCapitalG]\^*\), \
\[GothicCapitalF]}\)\) + \[WeierstrassP]\_\(k\_{\[GothicCapitalA], \
\[GothicCapitalF], \[GothicCapitalM]}\))\) + \[GothicCapitalD]\_{j\_{\
\[GothicCapitalA], \[GothicCapitalF], \[GothicCapitalF]}}\ \((\(-\
\[WeierstrassP]\_\(i\_{\(\[GothicCapitalG]\^*\), \[GothicCapitalM]}\)\) + \
\[WeierstrassP]\_\(i\_{\[GothicCapitalA], \[GothicCapitalM], \
\[GothicCapitalF]}\))\)\ \
\((\(-\[WeierstrassP]\_\(k\_{\(\[GothicCapitalG]\^*\), \[GothicCapitalF]}\)\) \
+ \[WeierstrassP]\_\(k\_{\[GothicCapitalA], \[GothicCapitalF], \
\[GothicCapitalM]}\))\) + \[GothicCapitalD]\_{i\_{\[GothicCapitalA], \
\[GothicCapitalM], \[GothicCapitalF]}}\ \((\(-\[WeierstrassP]\_\(j\_{\(\
\[GothicCapitalG]\^*\), \[GothicCapitalF]}\)\) + \[WeierstrassP]\_\(j\_{\
\[GothicCapitalA], \[GothicCapitalF], \[GothicCapitalF]}\))\)\ \((\(-\
\[WeierstrassP]\_\(k\_{\(\[GothicCapitalG]\^*\), \[GothicCapitalF]}\)\) + \
\[WeierstrassP]\_\(k\_{\[GothicCapitalA], \[GothicCapitalF], \
\[GothicCapitalM]}\))\) + \((\(-\[WeierstrassP]\_\(i\_{\(\[GothicCapitalG]\^*\
\), \[GothicCapitalM]}\)\) + \[WeierstrassP]\_\(i\_{\[GothicCapitalA], \
\[GothicCapitalM], \[GothicCapitalF]}\))\)\ \((\(-\[WeierstrassP]\_\(j\_{\(\
\[GothicCapitalG]\^*\), \[GothicCapitalF]}\)\) + \[WeierstrassP]\_\(j\_{\
\[GothicCapitalA], \[GothicCapitalF], \[GothicCapitalF]}\))\)\ \((\(-\
\[WeierstrassP]\_\(k\_{\(\[GothicCapitalG]\^*\), \[GothicCapitalF]}\)\) + \
\[WeierstrassP]\_\(k\_{\[GothicCapitalA], \[GothicCapitalF], \
\[GothicCapitalM]}\))\))\) + \[GothicR]\_\(\[GothicCapitalF], {j}, {k}\)\ \
\[GothicR]\_\(\[GothicCapitalM], {}, {i}\)\ \((\[GothicCapitalD]\_{i\_{\
\[GothicCapitalA], \[GothicCapitalM], \[GothicCapitalM]}, j\_{\
\[GothicCapitalA], \[GothicCapitalF], \[GothicCapitalF]}, k\_{\
\[GothicCapitalA], \[GothicCapitalF], \[GothicCapitalM]}} + \[GothicCapitalD]\
\_{j\_{\[GothicCapitalA], \[GothicCapitalF], \[GothicCapitalF]}, k\_{\
\[GothicCapitalA], \[GothicCapitalF], \[GothicCapitalM]}}\ \((\(-\
\[WeierstrassP]\_\(i\_{\(\[GothicCapitalG]\^*\), \[GothicCapitalM]}\)\) + \
\[WeierstrassP]\_\(i\_{\[GothicCapitalA], \[GothicCapitalM], \
\[GothicCapitalM]}\))\) + \[GothicCapitalD]\_{i\_{\[GothicCapitalA], \
\[GothicCapitalM], \[GothicCapitalM]}, k\_{\[GothicCapitalA], \
\[GothicCapitalF], \[GothicCapitalM]}}\ \((\(-\[WeierstrassP]\_\(j\_{\(\
\[GothicCapitalG]\^*\), \[GothicCapitalF]}\)\) + \[WeierstrassP]\_\(j\_{\
\[GothicCapitalA], \[GothicCapitalF], \[GothicCapitalF]}\))\) + \
\[GothicCapitalD]\_{k\_{\[GothicCapitalA], \[GothicCapitalF], \
\[GothicCapitalM]}}\ \((\(-\[WeierstrassP]\_\(i\_{\(\[GothicCapitalG]\^*\), \
\[GothicCapitalM]}\)\) + \[WeierstrassP]\_\(i\_{\[GothicCapitalA], \
\[GothicCapitalM], \[GothicCapitalM]}\))\)\ \((\(-\[WeierstrassP]\_\(j\_{\(\
\[GothicCapitalG]\^*\), \[GothicCapitalF]}\)\) + \[WeierstrassP]\_\(j\_{\
\[GothicCapitalA], \[GothicCapitalF], \[GothicCapitalF]}\))\) + \
\[GothicCapitalD]\_{i\_{\[GothicCapitalA], \[GothicCapitalM], \
\[GothicCapitalM]}, j\_{\[GothicCapitalA], \[GothicCapitalF], \
\[GothicCapitalF]}}\ \((\(-\[WeierstrassP]\_\(k\_{\(\[GothicCapitalG]\^*\), \
\[GothicCapitalF]}\)\) + \[WeierstrassP]\_\(k\_{\[GothicCapitalA], \
\[GothicCapitalF], \[GothicCapitalM]}\))\) + \[GothicCapitalD]\_{j\_{\
\[GothicCapitalA], \[GothicCapitalF], \[GothicCapitalF]}}\ \((\(-\
\[WeierstrassP]\_\(i\_{\(\[GothicCapitalG]\^*\), \[GothicCapitalM]}\)\) + \
\[WeierstrassP]\_\(i\_{\[GothicCapitalA], \[GothicCapitalM], \
\[GothicCapitalM]}\))\)\ \
\((\(-\[WeierstrassP]\_\(k\_{\(\[GothicCapitalG]\^*\), \[GothicCapitalF]}\)\) \
+ \[WeierstrassP]\_\(k\_{\[GothicCapitalA], \[GothicCapitalF], \
\[GothicCapitalM]}\))\) + \[GothicCapitalD]\_{i\_{\[GothicCapitalA], \
\[GothicCapitalM], \[GothicCapitalM]}}\ \((\(-\[WeierstrassP]\_\(j\_{\(\
\[GothicCapitalG]\^*\), \[GothicCapitalF]}\)\) + \[WeierstrassP]\_\(j\_{\
\[GothicCapitalA], \[GothicCapitalF], \[GothicCapitalF]}\))\)\ \((\(-\
\[WeierstrassP]\_\(k\_{\(\[GothicCapitalG]\^*\), \[GothicCapitalF]}\)\) + \
\[WeierstrassP]\_\(k\_{\[GothicCapitalA], \[GothicCapitalF], \
\[GothicCapitalM]}\))\) + \((\(-\[WeierstrassP]\_\(i\_{\(\[GothicCapitalG]\^*\
\), \[GothicCapitalM]}\)\) + \[WeierstrassP]\_\(i\_{\[GothicCapitalA], \
\[GothicCapitalM], \[GothicCapitalM]}\))\)\ \((\(-\[WeierstrassP]\_\(j\_{\(\
\[GothicCapitalG]\^*\), \[GothicCapitalF]}\)\) + \[WeierstrassP]\_\(j\_{\
\[GothicCapitalA], \[GothicCapitalF], \[GothicCapitalF]}\))\)\ \((\(-\
\[WeierstrassP]\_\(k\_{\(\[GothicCapitalG]\^*\), \[GothicCapitalF]}\)\) + \
\[WeierstrassP]\_\(k\_{\[GothicCapitalA], \[GothicCapitalF], \
\[GothicCapitalM]}\))\))\) + \[GothicR]\_\(\[GothicCapitalF], {}, {j, k}\)\ \
\[GothicR]\_\(\[GothicCapitalM], {i}, {}\)\ \((\[GothicCapitalD]\_{i\_{\
\[GothicCapitalA], \[GothicCapitalM], \[GothicCapitalF]}, j\_{\
\[GothicCapitalA], \[GothicCapitalF], \[GothicCapitalM]}, k\_{\
\[GothicCapitalA], \[GothicCapitalF], \[GothicCapitalM]}} + \[GothicCapitalD]\
\_{j\_{\[GothicCapitalA], \[GothicCapitalF], \[GothicCapitalM]}, k\_{\
\[GothicCapitalA], \[GothicCapitalF], \[GothicCapitalM]}}\ \((\(-\
\[WeierstrassP]\_\(i\_{\(\[GothicCapitalG]\^*\), \[GothicCapitalM]}\)\) + \
\[WeierstrassP]\_\(i\_{\[GothicCapitalA], \[GothicCapitalM], \
\[GothicCapitalF]}\))\) + \[GothicCapitalD]\_{i\_{\[GothicCapitalA], \
\[GothicCapitalM], \[GothicCapitalF]}, k\_{\[GothicCapitalA], \
\[GothicCapitalF], \[GothicCapitalM]}}\ \((\(-\[WeierstrassP]\_\(j\_{\(\
\[GothicCapitalG]\^*\), \[GothicCapitalF]}\)\) + \[WeierstrassP]\_\(j\_{\
\[GothicCapitalA], \[GothicCapitalF], \[GothicCapitalM]}\))\) + \
\[GothicCapitalD]\_{k\_{\[GothicCapitalA], \[GothicCapitalF], \
\[GothicCapitalM]}}\ \((\(-\[WeierstrassP]\_\(i\_{\(\[GothicCapitalG]\^*\), \
\[GothicCapitalM]}\)\) + \[WeierstrassP]\_\(i\_{\[GothicCapitalA], \
\[GothicCapitalM], \[GothicCapitalF]}\))\)\ \((\(-\[WeierstrassP]\_\(j\_{\(\
\[GothicCapitalG]\^*\), \[GothicCapitalF]}\)\) + \[WeierstrassP]\_\(j\_{\
\[GothicCapitalA], \[GothicCapitalF], \[GothicCapitalM]}\))\) + \
\[GothicCapitalD]\_{i\_{\[GothicCapitalA], \[GothicCapitalM], \
\[GothicCapitalF]}, j\_{\[GothicCapitalA], \[GothicCapitalF], \
\[GothicCapitalM]}}\ \((\(-\[WeierstrassP]\_\(k\_{\(\[GothicCapitalG]\^*\), \
\[GothicCapitalF]}\)\) + \[WeierstrassP]\_\(k\_{\[GothicCapitalA], \
\[GothicCapitalF], \[GothicCapitalM]}\))\) + \[GothicCapitalD]\_{j\_{\
\[GothicCapitalA], \[GothicCapitalF], \[GothicCapitalM]}}\ \((\(-\
\[WeierstrassP]\_\(i\_{\(\[GothicCapitalG]\^*\), \[GothicCapitalM]}\)\) + \
\[WeierstrassP]\_\(i\_{\[GothicCapitalA], \[GothicCapitalM], \
\[GothicCapitalF]}\))\)\ \
\((\(-\[WeierstrassP]\_\(k\_{\(\[GothicCapitalG]\^*\), \[GothicCapitalF]}\)\) \
+ \[WeierstrassP]\_\(k\_{\[GothicCapitalA], \[GothicCapitalF], \
\[GothicCapitalM]}\))\) + \[GothicCapitalD]\_{i\_{\[GothicCapitalA], \
\[GothicCapitalM], \[GothicCapitalF]}}\ \((\(-\[WeierstrassP]\_\(j\_{\(\
\[GothicCapitalG]\^*\), \[GothicCapitalF]}\)\) + \[WeierstrassP]\_\(j\_{\
\[GothicCapitalA], \[GothicCapitalF], \[GothicCapitalM]}\))\)\ \((\(-\
\[WeierstrassP]\_\(k\_{\(\[GothicCapitalG]\^*\), \[GothicCapitalF]}\)\) + \
\[WeierstrassP]\_\(k\_{\[GothicCapitalA], \[GothicCapitalF], \
\[GothicCapitalM]}\))\) + \((\(-\[WeierstrassP]\_\(i\_{\(\[GothicCapitalG]\^*\
\), \[GothicCapitalM]}\)\) + \[WeierstrassP]\_\(i\_{\[GothicCapitalA], \
\[GothicCapitalM], \[GothicCapitalF]}\))\)\ \((\(-\[WeierstrassP]\_\(j\_{\(\
\[GothicCapitalG]\^*\), \[GothicCapitalF]}\)\) + \[WeierstrassP]\_\(j\_{\
\[GothicCapitalA], \[GothicCapitalF], \[GothicCapitalM]}\))\)\ \((\(-\
\[WeierstrassP]\_\(k\_{\(\[GothicCapitalG]\^*\), \[GothicCapitalF]}\)\) + \
\[WeierstrassP]\_\(k\_{\[GothicCapitalA], \[GothicCapitalF], \
\[GothicCapitalM]}\))\))\) + \[GothicR]\_\(\[GothicCapitalF], {}, {j, k}\)\ \
\[GothicR]\_\(\[GothicCapitalM], {}, {i}\)\ \((\[GothicCapitalD]\_{i\_{\
\[GothicCapitalA], \[GothicCapitalM], \[GothicCapitalM]}, j\_{\
\[GothicCapitalA], \[GothicCapitalF], \[GothicCapitalM]}, k\_{\
\[GothicCapitalA], \[GothicCapitalF], \[GothicCapitalM]}} + \[GothicCapitalD]\
\_{j\_{\[GothicCapitalA], \[GothicCapitalF], \[GothicCapitalM]}, k\_{\
\[GothicCapitalA], \[GothicCapitalF], \[GothicCapitalM]}}\ \((\(-\
\[WeierstrassP]\_\(i\_{\(\[GothicCapitalG]\^*\), \[GothicCapitalM]}\)\) + \
\[WeierstrassP]\_\(i\_{\[GothicCapitalA], \[GothicCapitalM], \
\[GothicCapitalM]}\))\) + \[GothicCapitalD]\_{i\_{\[GothicCapitalA], \
\[GothicCapitalM], \[GothicCapitalM]}, k\_{\[GothicCapitalA], \
\[GothicCapitalF], \[GothicCapitalM]}}\ \((\(-\[WeierstrassP]\_\(j\_{\(\
\[GothicCapitalG]\^*\), \[GothicCapitalF]}\)\) + \[WeierstrassP]\_\(j\_{\
\[GothicCapitalA], \[GothicCapitalF], \[GothicCapitalM]}\))\) + \
\[GothicCapitalD]\_{k\_{\[GothicCapitalA], \[GothicCapitalF], \
\[GothicCapitalM]}}\ \((\(-\[WeierstrassP]\_\(i\_{\(\[GothicCapitalG]\^*\), \
\[GothicCapitalM]}\)\) + \[WeierstrassP]\_\(i\_{\[GothicCapitalA], \
\[GothicCapitalM], \[GothicCapitalM]}\))\)\ \((\(-\[WeierstrassP]\_\(j\_{\(\
\[GothicCapitalG]\^*\), \[GothicCapitalF]}\)\) + \[WeierstrassP]\_\(j\_{\
\[GothicCapitalA], \[GothicCapitalF], \[GothicCapitalM]}\))\) + \
\[GothicCapitalD]\_{i\_{\[GothicCapitalA], \[GothicCapitalM], \
\[GothicCapitalM]}, j\_{\[GothicCapitalA], \[GothicCapitalF], \
\[GothicCapitalM]}}\ \((\(-\[WeierstrassP]\_\(k\_{\(\[GothicCapitalG]\^*\), \
\[GothicCapitalF]}\)\) + \[WeierstrassP]\_\(k\_{\[GothicCapitalA], \
\[GothicCapitalF], \[GothicCapitalM]}\))\) + \[GothicCapitalD]\_{j\_{\
\[GothicCapitalA], \[GothicCapitalF], \[GothicCapitalM]}}\ \((\(-\
\[WeierstrassP]\_\(i\_{\(\[GothicCapitalG]\^*\), \[GothicCapitalM]}\)\) + \
\[WeierstrassP]\_\(i\_{\[GothicCapitalA], \[GothicCapitalM], \
\[GothicCapitalM]}\))\)\ \
\((\(-\[WeierstrassP]\_\(k\_{\(\[GothicCapitalG]\^*\), \[GothicCapitalF]}\)\) \
+ \[WeierstrassP]\_\(k\_{\[GothicCapitalA], \[GothicCapitalF], \
\[GothicCapitalM]}\))\) + \[GothicCapitalD]\_{i\_{\[GothicCapitalA], \
\[GothicCapitalM], \[GothicCapitalM]}}\ \((\(-\[WeierstrassP]\_\(j\_{\(\
\[GothicCapitalG]\^*\), \[GothicCapitalF]}\)\) + \[WeierstrassP]\_\(j\_{\
\[GothicCapitalA], \[GothicCapitalF], \[GothicCapitalM]}\))\)\ \((\(-\
\[WeierstrassP]\_\(k\_{\(\[GothicCapitalG]\^*\), \[GothicCapitalF]}\)\) + \
\[WeierstrassP]\_\(k\_{\[GothicCapitalA], \[GothicCapitalF], \
\[GothicCapitalM]}\))\) + \((\(-\[WeierstrassP]\_\(i\_{\(\[GothicCapitalG]\^*\
\), \[GothicCapitalM]}\)\) + \[WeierstrassP]\_\(i\_{\[GothicCapitalA], \
\[GothicCapitalM], \[GothicCapitalM]}\))\)\ \((\(-\[WeierstrassP]\_\(j\_{\(\
\[GothicCapitalG]\^*\), \[GothicCapitalF]}\)\) + \[WeierstrassP]\_\(j\_{\
\[GothicCapitalA], \[GothicCapitalF], \[GothicCapitalM]}\))\)\ \((\(-\
\[WeierstrassP]\_\(k\_{\(\[GothicCapitalG]\^*\), \[GothicCapitalF]}\)\) + \
\[WeierstrassP]\_\(k\_{\[GothicCapitalA], \[GothicCapitalF], \
\[GothicCapitalM]}\))\))\)\)], "Output",
  CellLabel->"Out[254]="]
}, Closed]],

Cell[TextData[{
  " ",
  Cell[BoxData[
      FormBox[GridBox[{
            {\(Recombination[\[DoubleStruckCapitalR]]\), \(allows\ for\ a\ \
dependence\ of\ recombination\ rate\ on\ the\ set\ of\ genes\ \
\[DoubleStruckCapitalR]\)},
            {\(Recombination[{\[GothicCapitalA], \(\[GothicCapitalG]\^*\)}, 
                RecombinationRate, {c\_1, \[Ellipsis]}, \
\[DoubleStruckCapitalR]]\), \(specifies\ the\ stages\ and\ recombination\ \
rate\ \(\(explicitly\)\(.\)\)\)},
            {\(\[GothicR]\_\(\[DoubleStruckCapitalR], A, B\)\ or\ \
RecombinationRate[\[DoubleStruckCapitalR], A, 
                  B]\), \(is\ the\ dependence\ of\ the\ rate\ on\ the\ set\ \
of\ loci\ \[DoubleStruckCapitalR]\)},
            {\(\[DoubleStruckCapitalR]\_\(\(c\_1\) \[Ellipsis]\)\ or\ \
RecombinationSet[\(c\_1\) \[Ellipsis]]\), \(is\ the\ set\ of\ genes - in - 
                context\ that\ may\ affect\ recombination\ rates\)}
            }], TraditionalForm]]]
}], "DefinitionBox",
  CellTags->{"Genotype-dependent recombination", "RecombinationSet"}],

Cell["\<\
Recombination rates can depend on genotype, in the same way as does \
fitness.\
\>", "Text"],

Cell[TextData[{
  "Note:  ",
  StyleBox["Genotype-dependent recombination is not yet implemented, but will \
follow the same conventions as for selection coefficients etc.",
    FontWeight->"Plain"]
}], "Text",
  FontWeight->"Bold"],

Cell[TextData[Cell[BoxData[
    FormBox[GridBox[{
          {\(UnlinkedRecombination[A, 
              B]\), \(gives\ the\ probability\ that\ A\ is\ derived\ from\ \
the\ maternal\ genome, \ and\ B\ from\ the\ paternal, \ given\ no\ linkage\)}
          }], TraditionalForm]]]], "DefinitionBox",
  CellTags->"UnlinkedRecombination"],

Cell["\<\
There are 8 ways of deriving 3 loci, each with equal probability:\
\
\>", "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[
    \(UnlinkedRecombination[{i, j}, {k}]\)], "Input",
  CellLabel->"In[3]:=  (18:16:44 on 4/10/01)"],

Cell[BoxData[
    \(1\/8\)], "Output",
  CellLabel->"Out[3]=  (18:16:44 on 4/10/01)"]
}, Open  ]],

Cell[TextData[{
  "In general, UnlinkedRecombination[A,B] is just ",
  Cell[BoxData[
      \(TraditionalForm\`2\^\(-n\), \ 
      where\ there\ are\ n\ loci\ \(\(involved\)\(.\)\)\)]]
}], "Text"],

Cell[TextData[Cell[BoxData[
    FormBox[
      RowBox[{GridBox[{
            {\(LinkedRecombination[A, B, {i, j, k\[Ellipsis]}, 
                c]\), \(gives\ the\ recombination\ rate\ \[GothicR]\_\(A, B\)\
\ assuming\ the\ loci\ are\ in\ order\ {i, j, k\[Ellipsis]}, \ 
              in\ terms\ of\ c[i, j], \ c[j, k] \[Ellipsis]\)}
            }], " "}], TraditionalForm]]]], "DefinitionBox",
  CellTags->"LinkedRecombination"],

Cell[TextData[{
  "It is assumed that there is no interference or meiotic drive; all loci are \
autosomal. This is the probability of the recombination event that separates \
",
  Cell[BoxData[
      \(TraditionalForm\`{i, j}\)]],
  " from ",
  Cell[BoxData[
      \(TraditionalForm\`\(\({k}\)\(:\)\)\)]]
}], "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[
    \(LinkedRecombination[{i, j}, {k}, {i, j, k, l}, c]\)], "Input",
  CellLabel->"In[64]:="],

Cell[BoxData[
    \(1\/2\ \((1 - c[i, j])\)\ c[j, k]\)], "Output",
  CellLabel->"Out[64]="]
}, Open  ]],

Cell["\<\
There can be extra loci in the list that specifies their order, but \
none must be left out:\
\>", "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[
    \(LinkedRecombination[{i, j}, {k}, {i, j, l}, c]\)], "Input",
  CellLabel->"In[67]:="],

Cell[BoxData[
    \(LinkedRecombination::"badLoci" \(\(:\)\(\ \)\) 
      "Order of the loci in \!\(\[GothicR]\_\(\!\({i, j}\), \\ \!\({k}\)\)\) \
is not specified by \!\({i, j, l}\)"\)], "Message",
  CellLabel->"From In[67]:="],

Cell[BoxData[
    \(Indeterminate\)], "Output",
  CellLabel->"Out[67]="]
}, Open  ]],

Cell[TextData[{
  "This simplifies the general recombination rate ",
  Cell[BoxData[
      \(TraditionalForm\`\(\(\[GothicR]\_\({i, j}, {k}\)\)\(:\)\)\)]]
}], "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\[GothicR]\_\({i, j}, {k}\) /. {\[GothicR]\_\(A_, B_\) \[RuleDelayed] 
          LinkedRecombination[{i, j}, {k}, {i, j, k}, c]}\)], "Input",
  CellLabel->"In[69]:="],

Cell[BoxData[
    \(1\/2\ \((1 - c[i, j])\)\ c[j, k]\)], "Output",
  CellLabel->"Out[69]="]
}, Open  ]],

Cell[TextData[Cell[BoxData[
    FormBox[GridBox[{
          {\(NetRecombination[{r\_\(1, 2\), 
                r\_\(2, 3\), \[Ellipsis]}]\), \(\(\ \)\(gives\ the\ net\ \
recombination\ rate\ across\ a\ linear\ genetic\ map\)\)}
          }], TraditionalForm]]]], "DefinitionBox",
  CellTags->"NetRecombination"],

Cell[TextData[{
  "This function is used to determine the net recombination rate across a \
series of intervals.  For example, this gives the recombination  ",
  Cell[BoxData[
      \(TraditionalForm\`r\_\(1, 3\)\)]],
  " between loci 1 and 3, where the recombination rates in the two component \
intervals are ",
  Cell[BoxData[
      \(TraditionalForm\`r\_\(1, 2\) = 0.1\)]],
  ", ",
  Cell[BoxData[
      \(TraditionalForm\`r\_\(2, 3\)\)]],
  "=0.2:"
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(NetRecombination[{0.1, 0.2}]\)], "Input",
  CellLabel->"In[70]:="],

Cell[BoxData[
    \(0.26`\)], "Output",
  CellLabel->"Out[70]="]
}, Open  ]],

Cell["This is the more general expression:", "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[
    \(NetRecombination[{r\_\(1, 2\), r\_\(2, 3\)}]\)], "Input",
  CellLabel->"In[71]:="],

Cell[BoxData[
    \(r\_\(1, 2\)\ \((1 - 2\ r\_\(2, 3\))\) + r\_\(2, 3\)\)], "Output",
  CellLabel->"Out[71]="]
}, Open  ]],

Cell["\<\
This function is defined within Multilocus`DataManipulation`.\
\>", \
"Text"]
}, Open  ]]
},
FrontEndVersion->"4.0 for Macintosh",
ScreenRectangle->{{0, 1152}, {0, 748}},
AutoGeneratedPackage->None,
WindowSize->{956, 721},
WindowMargins->{{3, Automatic}, {Automatic, 5}},
StyleDefinitions -> "HelpBrowser.nb",
MacintoshSystemPageSetup->"\<\
00h0001804P000000b02<?oaonl3>@91H`85N0?N0@00005X0FP000003j0:l001
0@00I00100000@0200000BL?00400000000000000000010000000000000@0?ne
oj/@7@]500P1000000000000000001T1\>"
]


(***********************************************************************
Cached data follows.  If you edit this Notebook file directly, not using
Mathematica, you must remove the line containing CacheID at the top of 
the file.  The cache data will then be recreated when you save this file 
from within Mathematica.
***********************************************************************)

(*CellTagsOutline
CellTagsIndex->{
  "Meiosis"->{
    Cell[1781, 53, 641, 14, 72, "DefinitionBox",
      CellTags->"Meiosis"]},
  "Recombination"->{
    Cell[6098, 170, 1002, 20, 110, "DefinitionBox",
      CellTags->{"Recombination", "RecombinationRate"}]},
  "RecombinationRate"->{
    Cell[6098, 170, 1002, 20, 110, "DefinitionBox",
      CellTags->{"Recombination", "RecombinationRate"}]},
  "Factors of two"->{
    Cell[23205, 505, 1188, 29, 67, "Text",
      CellTags->"Factors of two"]},
  "SymmetricRecombination"->{
    Cell[24396, 536, 515, 10, 56, "DefinitionBox",
      CellTags->"SymmetricRecombination"]},
  "Context-dependent recombination"->{
    Cell[29864, 638, 1260, 24, 126, "DefinitionBox",
      CellTags->"Context-dependent recombination"]},
  "Sexual selection"->{
    Cell[42847, 879, 749, 16, 70, "DefinitionBox",
      CellTags->"Sexual selection"]},
  "Genotype-dependent recombination"->{
    Cell[93997, 1660, 1049, 20, 94, "DefinitionBox",
      CellTags->{"Genotype-dependent recombination", "RecombinationSet"}]},
  "RecombinationSet"->{
    Cell[93997, 1660, 1049, 20, 94, "DefinitionBox",
      CellTags->{"Genotype-dependent recombination", "RecombinationSet"}]},
  "UnlinkedRecombination"->{
    Cell[95389, 1695, 332, 6, 37, "DefinitionBox",
      CellTags->"UnlinkedRecombination"]},
  "LinkedRecombination"->{
    Cell[96262, 1726, 430, 8, 38, "DefinitionBox",
      CellTags->"LinkedRecombination"]},
  "NetRecombination"->{
    Cell[98325, 1798, 311, 6, 38, "DefinitionBox",
      CellTags->"NetRecombination"]}
  }
*)

(*CellTagsIndex
CellTagsIndex->{
  {"Meiosis", 100571, 1873},
  {"Recombination", 100670, 1876},
  {"RecombinationRate", 100805, 1879},
  {"Factors of two", 100937, 1882},
  {"SymmetricRecombination", 101046, 1885},
  {"Context-dependent recombination", 101180, 1888},
  {"Sexual selection", 101310, 1891},
  {"Genotype-dependent recombination", 101439, 1894},
  {"RecombinationSet", 101592, 1897},
  {"UnlinkedRecombination", 101750, 1900},
  {"LinkedRecombination", 101871, 1903},
  {"NetRecombination", 101987, 1906}
  }
*)

(*NotebookFileOutline
Notebook[{

Cell[CellGroupData[{
Cell[1739, 51, 39, 0, 36, "SubsectionIcon"],
Cell[1781, 53, 641, 14, 72, "DefinitionBox",
  CellTags->"Meiosis"],
Cell[2425, 69, 395, 9, 36, "Text"],

Cell[CellGroupData[{
Cell[2845, 82, 310, 6, 28, "Input"],
Cell[3158, 90, 261, 5, 22, "Output"]
}, Open  ]],
Cell[3434, 98, 494, 14, 30, "Text"],
Cell[3931, 114, 353, 10, 24, "Text"],
Cell[4287, 126, 142, 3, 28, "MathCaption"],

Cell[CellGroupData[{
Cell[4454, 133, 295, 6, 33, "Input"],
Cell[4752, 141, 1063, 16, 28, "Output"]
}, Open  ]],
Cell[5830, 160, 265, 8, 22, "Text"],
Cell[6098, 170, 1002, 20, 110, "DefinitionBox",
  CellTags->{"Recombination", "RecombinationRate"}],
Cell[7103, 192, 197, 5, 28, "MathCaption"],

Cell[CellGroupData[{
Cell[7325, 201, 205, 4, 33, "Input"],
Cell[7533, 207, 4224, 62, 142, "Output"]
}, Open  ]],
Cell[11772, 272, 71, 0, 28, "MathCaption"],

Cell[CellGroupData[{
Cell[11868, 276, 149, 3, 31, "Input"],
Cell[12020, 281, 271, 5, 25, "Output"]
}, Open  ]],
Cell[12306, 289, 305, 7, 28, "MathCaption"],

Cell[CellGroupData[{
Cell[12636, 300, 90, 2, 27, "Input"],
Cell[12729, 304, 196, 6, 32, "Output"]
}, Open  ]],
Cell[12940, 313, 297, 8, 22, "Text"],
Cell[13240, 323, 58, 0, 28, "MathCaption"],

Cell[CellGroupData[{
Cell[13323, 327, 264, 5, 33, "Input"],
Cell[13590, 334, 4227, 67, 70, "Output"]
}, Closed]],
Cell[17832, 404, 491, 12, 18, "MathCaption"],

Cell[CellGroupData[{
Cell[18348, 420, 622, 15, 51, "Input"],
Cell[18973, 437, 4217, 65, 96, "Output"]
}, Closed]],
Cell[23205, 505, 1188, 29, 67, "Text",
  CellTags->"Factors of two"],
Cell[24396, 536, 515, 10, 56, "DefinitionBox",
  CellTags->"SymmetricRecombination"],
Cell[24914, 548, 78, 0, 28, "MathCaption"],

Cell[CellGroupData[{
Cell[25017, 552, 275, 5, 33, "Input"],
Cell[25295, 559, 4154, 60, 148, "Output"]
}, Open  ]],
Cell[29464, 622, 397, 14, 28, "Text"],
Cell[29864, 638, 1260, 24, 126, "DefinitionBox",
  CellTags->"Context-dependent recombination"],
Cell[31127, 664, 67, 0, 28, "MathCaption"],

Cell[CellGroupData[{
Cell[31219, 668, 210, 4, 33, "Input"],
Cell[31432, 674, 4302, 62, 144, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[35771, 741, 154, 3, 31, "Input"],
Cell[35928, 746, 309, 5, 25, "Output"]
}, Open  ]],
Cell[36252, 754, 251, 5, 36, "Text"],
Cell[36506, 761, 75, 0, 28, "MathCaption"],
Cell[36584, 763, 184, 4, 26, "Input"],
Cell[36771, 769, 75, 0, 28, "MathCaption"],

Cell[CellGroupData[{
Cell[36871, 773, 284, 5, 30, "Input"],
Cell[37158, 780, 4411, 61, 70, "Output"]
}, Closed]],
Cell[41584, 844, 158, 4, 18, "Text"],
Cell[41745, 850, 144, 3, 28, "MathCaption"],

Cell[CellGroupData[{
Cell[41914, 857, 284, 5, 30, "Input"],
Cell[42201, 864, 449, 7, 42, "Message"],
Cell[42653, 873, 179, 3, 27, "Output"]
}, Open  ]],
Cell[42847, 879, 749, 16, 70, "DefinitionBox",
  CellTags->"Sexual selection"],

Cell[CellGroupData[{
Cell[43621, 899, 258, 5, 33, "Input"],
Cell[43882, 906, 24369, 362, 70, "Output"]
}, Closed]],
Cell[68266, 1271, 299, 8, 19, "Text"],
Cell[68568, 1281, 254, 5, 36, "Text"],
Cell[68825, 1288, 209, 4, 22, "Text"],

Cell[CellGroupData[{
Cell[69059, 1296, 263, 5, 33, "Input"],
Cell[69325, 1303, 24657, 354, 550, "Output"]
}, Closed]],
Cell[93997, 1660, 1049, 20, 94, "DefinitionBox",
  CellTags->{"Genotype-dependent recombination", "RecombinationSet"}],
Cell[95049, 1682, 102, 3, 22, "Text"],
Cell[95154, 1687, 232, 6, 24, "Text"],
Cell[95389, 1695, 332, 6, 37, "DefinitionBox",
  CellTags->"UnlinkedRecombination"],
Cell[95724, 1703, 98, 3, 28, "MathCaption"],

Cell[CellGroupData[{
Cell[95847, 1710, 114, 2, 38, "Input"],
Cell[95964, 1714, 85, 2, 48, "Output"]
}, Open  ]],
Cell[96064, 1719, 195, 5, 22, "Text"],
Cell[96262, 1726, 430, 8, 38, "DefinitionBox",
  CellTags->"LinkedRecombination"],
Cell[96695, 1736, 323, 9, 28, "MathCaption"],

Cell[CellGroupData[{
Cell[97043, 1749, 107, 2, 26, "Input"],
Cell[97153, 1753, 91, 2, 36, "Output"]
}, Open  ]],
Cell[97259, 1758, 123, 3, 28, "MathCaption"],

Cell[CellGroupData[{
Cell[97407, 1765, 104, 2, 26, "Input"],
Cell[97514, 1769, 228, 4, 22, "Message"],
Cell[97745, 1775, 72, 2, 20, "Output"]
}, Open  ]],
Cell[97832, 1780, 173, 4, 28, "MathCaption"],

Cell[CellGroupData[{
Cell[98030, 1788, 186, 3, 27, "Input"],
Cell[98219, 1793, 91, 2, 36, "Output"]
}, Open  ]],
Cell[98325, 1798, 311, 6, 38, "DefinitionBox",
  CellTags->"NetRecombination"],
Cell[98639, 1806, 465, 13, 36, "Text"],

Cell[CellGroupData[{
Cell[99129, 1823, 86, 2, 26, "Input"],
Cell[99218, 1827, 64, 2, 20, "Output"]
}, Open  ]],
Cell[99297, 1832, 59, 0, 28, "MathCaption"],

Cell[CellGroupData[{
Cell[99381, 1836, 102, 2, 27, "Input"],
Cell[99486, 1840, 110, 2, 22, "Output"]
}, Open  ]],
Cell[99611, 1845, 87, 3, 22, "Text"]
}, Open  ]]
}
]
*)




(***********************************************************************
End of Mathematica Notebook file.
***********************************************************************)

