(***********************************************************************

                    Mathematica-Compatible Notebook

This notebook can be used on any computer system with Mathematica 4.0,
MathReader 4.0, or any compatible application. The data for the notebook 
starts with the line containing stars above.

To get the notebook into a Mathematica-compatible application, do one of 
the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing the 
word CacheID, otherwise Mathematica-compatible applications may try to 
use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
***********************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[     44677,       1092]*)
(*NotebookOutlinePosition[     47137,       1162]*)
(*  CellTagsIndexPosition[     46744,       1147]*)
(*WindowFrame->Normal*)



Notebook[{

Cell[CellGroupData[{
Cell["Reference points", "SubsectionIcon"],

Cell[TextData[{
  "At each stage in the life cycle, linkage disequilibria are defined \
relative to a set of reference points, ",
  Cell[BoxData[
      \(TraditionalForm\`\[WeierstrassP]\_\[DoubleStruckI]\)]],
  ".  These can take any convenient values: for example, they might be fixed, \
or might equal the mean ",
  Cell[BoxData[
      \(TraditionalForm\`\[LeftAngleBracket]X\_\[DoubleStruckI]\
\[RightAngleBracket]\)]],
  ".  In general, a rule must be supplied which simplifies expressions by \
transforming the reference points, ",
  Cell[BoxData[
      \(TraditionalForm\`\[WeierstrassP]\_\[DoubleStruckI]\)]],
  ", and the single-locus expectations ",
  Cell[BoxData[
      \(TraditionalForm\`\[GothicCapitalD]\_{\[DoubleStruckI]} = \
\[LeftAngleBracket]X\_\[DoubleStruckI] - \[WeierstrassP]\_\[DoubleStruckI]\
\[RightAngleBracket]\)]],
  "."
}], "Text"],

Cell[TextData[{
  "Note:  ",
  ButtonBox["Kirkpatrick et al.",
    ButtonData:>{"Multilocus MS", "Describing genotypes and populations"},
    ButtonStyle->"AddOnsLink"],
  StyleBox[" refer to reference points as 'reference values' - the terms are \
interchangeable. ",
    FontWeight->"Plain"]
}], "Text",
  FontWeight->"Bold"],

Cell[TextData[Cell[BoxData[
    FormBox[GridBox[{
          {\(ReferencePointZero[\[GothicCapitalG]]\), \(is\ a\ rule\ which\ \
sets\ \(\[GothicCapitalD]\_{i\_{\[GothicCapitalG], \[Ellipsis], sex}}\) 
              to\ zero, \ 
            and\ \[WeierstrassP]\_\(i\_{\[GothicCapitalG], \[Ellipsis], \
sex}\)\ to\ equal\ the\ mean, \ \ \[GothicM]\_\(i\_{\[GothicCapitalG], \
\[Ellipsis], sex}\)\)},
          {\(ReferencePointZero[{\[GothicCapitalG], \[GothicCapitalZ]}]\), \
\(applies\ the\ rule\ to\ both\ stages\ \[GothicCapitalG]\ and\ \
\[GothicCapitalZ]\)},
          {\(ReferencePointZero[\[GothicCapitalG], 
              p]\), \(is\ a\ rule\ which\ sets\ \(\[GothicCapitalD]\_{i\_{\
\[GothicCapitalG], \[Ellipsis], sex}}\) to\ zero, \ 
            and\ explicitly\ sets\ the\ reference\ point\ \(\[WeierstrassP]\_\
\(i\_{\[GothicCapitalG], \[Ellipsis], sex}\)\) 
              to\ p[i\_{\[GothicCapitalG], \[Ellipsis], sex}]\)}
          }], TraditionalForm]]]], "DefinitionBox",
  CellTags->"ReferencePointZero"],

Cell[TextData[{
  "The reference point in the gamete pool can be set equal to the mean at \
that stage; with separate sexes, the reference points can equal the \
sex-specific means.  With this definition, ",
  Cell[BoxData[
      \(TraditionalForm\`\[GothicCapitalD]\_{i\_{\[GothicCapitalG], \
\[Ellipsis]}} = 0\)]],
  ".  In zygotes, the reference points can be kept the same, equal to the \
gametic allele frequencies, and different for maternal and paternal alleles.  \
Then, immediately after random union of gametes, ",
  Cell[BoxData[
      \(TraditionalForm\`\[GothicCapitalD]\_{i\_{\[GothicCapitalZ], \
\[Ellipsis]}} = 0\)]],
  " in zygotes. However, after selection, ",
  Cell[BoxData[
      \(TraditionalForm\`\[GothicCapitalD]\_{i\_{\[GothicCapitalA], \
\[Ellipsis]}} \[NotEqual] 0\)]],
  ", and represents the change in allele frequency due to selection.  \
Following through to the next stage in the life cycle, the reference point in \
the new gamete pool can be set equal to the new allele frequencies, after \
selection and segregation (see example below).."
}], "Text"],

Cell[TextData[{
  "ReferencePointZero[\[GothicCapitalG]] is just the rule ",
  Cell[BoxData[
      \({\[GothicCapitalD]\_{_\_{\[GothicCapitalG], _}} \[RuleDelayed] 
          0}\)]],
  ".  Often, there is no need to explicitly define ",
  Cell[BoxData[
      \(TraditionalForm\`\[LeftAngleBracket]X\_\[DoubleStruckI]\
\[RightAngleBracket] = \[GothicM]\_\[DoubleStruckI]\)]],
  ".  However, ",
  Cell[BoxData[
      \(TraditionalForm\`ReferencePointZero[\[GothicCapitalG], p]\)]],
  " can be used to set the reference points explicitly equal to the mean, ",
  Cell[BoxData[
      \(TraditionalForm\`m\)]],
  ".  This is just the rule ",
  Cell[BoxData[
      \({\[GothicCapitalD]\_{_\_{\[GothicCapitalG], _}} \[RuleDelayed] 
          0, \[WeierstrassP]\_{i_\_{\[GothicCapitalG], x_}} \[RuleDelayed] 
          m\_{i\_{\[GothicCapitalG], x}}}\)]],
  ".  Note that ",
  Cell[BoxData[
      \(TraditionalForm\`m\)]],
  " is not a reserved character: ",
  Cell[BoxData[
      \(TraditionalForm\`p, \ u\)]],
  " or any other name could be used instead."
}], "Text"],

Cell[TextData[{
  "This sets the single-locus associations to zero, and sets the reference \
point ",
  Cell[BoxData[
      \(TraditionalForm\`\(\(\[WeierstrassP]\_\[DoubleStruckI]\)\(\ \)\)\)]],
  "to ",
  Cell[BoxData[
      \(TraditionalForm\`\[GothicM]\_\[DoubleStruckI]\)]],
  ":"
}], "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[
    \({\[GothicCapitalD]\_{i\_{\[GothicCapitalG], \[GothicCapitalM]}, j\_{\
\[GothicCapitalG], \[GothicCapitalM]}}, \[GothicCapitalD]\_{i\_{\
\[GothicCapitalG], \[GothicCapitalM]}}, \[WeierstrassP]\_\(i\_{\
\[GothicCapitalG], \[GothicCapitalM]}\)} /. 
      ReferencePointZero[\[GothicCapitalG]]\)], "Input",
  CellLabel->"In[6]:="],

Cell[BoxData[
    \({\[GothicCapitalD]\_{i\_{\[GothicCapitalG], \[GothicCapitalM]}, j\_{\
\[GothicCapitalG], \[GothicCapitalM]}}, 
      0, \[GothicM]\_\(i\_{\[GothicCapitalG], \[GothicCapitalM]}\)}\)], \
"Output",
  CellLabel->"Out[6]="]
}, Open  ]],

Cell["This does the same for several stages:", "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[
    \({\[GothicCapitalD]\_{j\_{\[GothicCapitalZ], \[GothicCapitalM], \
\[GothicCapitalM]}}, \[WeierstrassP]\_\(i\_{\[GothicCapitalZ], \
\[GothicCapitalM], \[GothicCapitalM]}\), \[GothicCapitalD]\_{i\_{\
\[GothicCapitalG], \[GothicCapitalM]}}, \[WeierstrassP]\_\(i\_{\
\[GothicCapitalG], \[GothicCapitalM]}\)} /. 
      ReferencePointZero[{\[GothicCapitalG], \[GothicCapitalZ]}, 
        m]\)], "Input",
  CellLabel->"In[7]:="],

Cell[BoxData[
    \({0, \[GothicM]\_\(i\_{\[GothicCapitalZ], \[GothicCapitalM], \
\[GothicCapitalM]}\), 
      0, \[GothicM]\_\(i\_{\[GothicCapitalG], \[GothicCapitalM]}\)}\)], \
"Output",
  CellLabel->"Out[7]="]
}, Open  ]],

Cell["The mean can be given a different name:", "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[
    \({\[GothicCapitalD]\_{i\_{\[GothicCapitalG], \[GothicCapitalM]}, j\_{\
\[GothicCapitalG], \[GothicCapitalM]}}, \[GothicCapitalD]\_{i\_{\
\[GothicCapitalG], \[GothicCapitalM]}}, \[WeierstrassP]\_\(i\_{\
\[GothicCapitalG], \[GothicCapitalM]}\)} /. 
      ReferencePointZero[\[GothicCapitalG], p]\)], "Input",
  CellLabel->"In[11]:="],

Cell[BoxData[
    \({\[GothicCapitalD]\_{i\_{\[GothicCapitalG], \[GothicCapitalM]}, j\_{\
\[GothicCapitalG], \[GothicCapitalM]}}, 0, 
      p\_\(i\_{\[GothicCapitalG], \[GothicCapitalM]}\)}\)], "Output",
  CellLabel->"Out[11]="]
}, Open  ]],

Cell[TextData[{
  "The default symbol for the mean contribution of gene-in-context \
\[DoubleStruckI] is ",
  Cell[BoxData[
      \(TraditionalForm\`\[GothicM]\_\[DoubleStruckI]\)]],
  "; this is represented internally as MeanContribution[\[DoubleStruckI]].  "
}], "Text"],

Cell[TextData[{
  "If some other subscripted notation is needed, use the",
  Cell[BoxData[
      FormBox[
        ButtonBox[\(\(\ \)\(NotationPalette\)\),
          ButtonData:>{
            FrontEnd`FileName[ {
              ParentDirectory[ 
                ParentDirectory[ ]], "AddOns", "ExtraPackages", "Utilities"}, 
              "NotationPalette.nb", CharacterEncoding -> "MacintoshRoman"], 
            None},
          ButtonStyle->"Hyperlink"], TraditionalForm]]],
  ":"
}], "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[{
    RowBox[{
      RowBox[{"Notation", "[", 
        RowBox[{
          TagBox[\(p\_\[DoubleStruckI]_\),
            NotationBoxTag,
            TagStyle->"NotationTemplateStyle"], " ", 
          "\[DoubleLongLeftRightArrow]", " ", 
          TagBox[\(p[\[DoubleStruckI]_]\),
            NotationBoxTag,
            TagStyle->"NotationTemplateStyle"]}], "]"}], 
      ";"}], "\n", \({\[GothicCapitalD]\_{i\_{\[GothicCapitalG], \
\[GothicCapitalM]}, j\_{\[GothicCapitalG], \[GothicCapitalM]}}, \
\[GothicCapitalD]\_{i\_{\[GothicCapitalG], \[GothicCapitalM]}}, \
\[WeierstrassP]\_\(i\_{\[GothicCapitalG], \[GothicCapitalM]}\)} /. 
      ReferencePointZero[\[GothicCapitalG], p]\)}], "Input",
  CellLabel->"In[18]:="],

Cell[BoxData[
    \({\[GothicCapitalD]\_{i\_{\[GothicCapitalG], \[GothicCapitalM]}, j\_{\
\[GothicCapitalG], \[GothicCapitalM]}}, 0, 
      p\_\(i\_{\[GothicCapitalG], \[GothicCapitalM]}\)}\)], "Output",
  CellLabel->"Out[19]="]
}, Open  ]],

Cell[TextData[Cell[BoxData[
    FormBox[GridBox[{
          {\(ReferencePointSame[\[GothicCapitalG], \[GothicCapitalZ]]\), \(is\
\ a\ rule\ which\ sets\ the\ reference\ pont\ in\ zygotes\ to\ be\ the\ same\ \
as\ in\ the\ corresponding\ genes\ in\ gametes\)},
          {\(ReferencePointSame[\[GothicCapitalG], \[GothicCapitalG]2]\), \
\(is\ a\ rule\ which\ sets\ the\ reference\ pont\ in\ haploid\ stage\ \
\[GothicCapitalG]2\ to\ be\ the\ same\ as\ in\ the\ corresponding\ genes\ in\ \
haploid\ stage\ \(\(\[GothicCapitalG]\)\(.\)\)\)},
          {\(ReferencePointSame[\[GothicCapitalG], {\[GothicCapitalZ], \
\[DoubleStruckCapitalA]}]\), \(is\ a\ rule\ which\ sets\ the\ reference\ \
point\ in\ all\ the\ listed\ stages\ to\ be\ the\ same\ as\ in\ gamete\ stage\
\ \[GothicCapitalG]\)}
          }], TraditionalForm]]]], "DefinitionBox",
  CellTags->"ReferencePointSame"],

Cell["\<\
This sets the reference point in the zygote equal to that in the \
gamete from which the gene derived\
\>", "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\[WeierstrassP]\_\(i\_{\[GothicCapitalZ], \[GothicCapitalM], \
\[GothicCapitalF]}\) /. 
      ReferencePointSame[\[GothicCapitalG], \[GothicCapitalZ]]\)], "Input",
  CellLabel->"In[18]:="],

Cell[BoxData[
    \(\[WeierstrassP]\_\(i\_{\[GothicCapitalG], \[GothicCapitalF]}\)\)], \
"Output",
  CellLabel->"Out[18]="]
}, Open  ]],

Cell["\<\
This just sets the reference point at the haploid stage \
\[GothicCapitalG]2 to equal that in \[GothicCapitalG]:\
\>", "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(DefineContext[\[GothicCapitalG]2, {Sex}];\)\), "\n", 
    \(\[WeierstrassP]\_\(i\_{\[GothicCapitalG]2, \[GothicCapitalF]}\) /. 
      ReferencePointSame[\[GothicCapitalG], \[GothicCapitalG]2]\)}], "Input",
  CellLabel->"In[112]:="],

Cell[BoxData[
    \(\[WeierstrassP]\_\(i\_{\[GothicCapitalG], \[GothicCapitalF]}\)\)], \
"Output",
  CellLabel->"Out[113]="]
}, Open  ]],

Cell["\<\
ReferencePointSame[] determines whether the stage is diploid using \
ContextComponentQ[stage,SexOfOrigin]\
\>", "Text"],

Cell["\<\
This does the same for several stages:\
\>", "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[
    \({\[WeierstrassP]\_\(i\_{\[GothicCapitalZ], \[GothicCapitalM], \
\[GothicCapitalF]}\), \[WeierstrassP]\_\(i\_{\[GothicCapitalA], \
\[GothicCapitalM], \[GothicCapitalF]}\), \[WeierstrassP]\_\(i\_{\
\[GothicCapitalG]2, \[GothicCapitalM]}\)} /. 
      ReferencePointSame[\[GothicCapitalG], {\[GothicCapitalG]2, \
\[GothicCapitalZ], \[GothicCapitalA]}]\)], "Input",
  CellLabel->"In[114]:="],

Cell[BoxData[
    \({\[WeierstrassP]\_\(i\_{\[GothicCapitalG], \[GothicCapitalF]}\), \
\[WeierstrassP]\_\(i\_{\[GothicCapitalG], \[GothicCapitalF]}\), \
\[WeierstrassP]\_\(i\_{\[GothicCapitalG], \[GothicCapitalM]}\)}\)], "Output",
  CellLabel->"Out[114]="]
}, Open  ]],

Cell["For examples, see next section.", "Text"],

Cell[TextData[Cell[BoxData[
    FormBox[GridBox[{
          {\(ReferencePointMean[\[GothicCapitalG]]\), \(is\ a\ rule\ which\ \
sets\ the\ reference\ point\ \(\[WeierstrassP]\_\(i\_{\[GothicCapitalG], \
\[Ellipsis], sex}\)\) 
              to\ the\ mean\ across\ the\ sexes, \ \((m\_\(i\_{\
\[GothicCapitalG], \[Ellipsis], \[GothicCapitalF]}\) + 
                  m\_\(i\_{\[GothicCapitalG], \[Ellipsis], \[GothicCapitalM]}\
\))\)/2, \ 
            and\ sets\ the\ disequilibria\ \[GothicCapitalD]\_\(i\_{\
\[GothicCapitalG], \[Ellipsis]}\)\ \(\(appropriately\)\(.\)\)\)},
          {\(ReferencePointMean[\[GothicCapitalZ]]\), \(is\ a\ rule\ which\ \
sets\ the\ reference\ point\ \(\[WeierstrassP]\_\(i\_{\[GothicCapitalZ], \
\[Ellipsis], soo}\)\) 
              to\ the\ mean\ across\ the\ sex\ of\ origin, \ \((m\_\(i\_{\
\[GothicCapitalZ], \[Ellipsis], \[GothicCapitalF]}\) + 
                  m\_\(i\_{\[GothicCapitalZ], \[Ellipsis], \[GothicCapitalM]}\
\))\)/2, \ 
            and\ sets\ the\ disequilibria\ \[GothicCapitalD]\_\(i\_{\
\[GothicCapitalZ], \[Ellipsis]}\)\ \(\(appropriately\)\(.\)\)\)},
          {\(ReferencePointMean[\[GothicCapitalG], 
              p]\), \(names\ the\ mean\ contribution\ as\ p[\[DoubleStruckI]]\
\)},
          {\(ReferencePointMean[{\[GothicCapitalG], \[GothicCapitalZ]}, \
\[GothicM]]\), \(applies\ the\ rule\ to\ both\ stages\ \[GothicCapitalG]\ and\
\ \[GothicCapitalZ]\)}
          }], TraditionalForm]]]], "DefinitionBox",
  CellTags->"ReferencePointMean"],

Cell[TextData[{
  "An alternative convention would be to set the reference point equal to the \
mean, averaged across the sexes.  Then, we have the rule ",
  Cell[BoxData[
      \(TraditionalForm\`{\[WeierstrassP]\_\(i_\_{\[GothicCapitalG], x___, _}\
\) \[RuleDelayed] \((\[GothicM]\_\(i\_{\[GothicCapitalG], x, \
\[GothicCapitalF]}\) + \[GothicM]\_\(i\_{\[GothicCapitalG], x, \
\[GothicCapitalM]}\))\)/
            2, \[GothicCapitalD]\_{i_\_{\[GothicCapitalG], x__, \
\[GothicCapitalF]}} \[RuleDelayed] \((\[GothicM]\_\(i\_{\[GothicCapitalG], x, \
\[GothicCapitalF]}\) - \[GothicM]\_\(i\_{\[GothicCapitalG], x, \
\[GothicCapitalM]}\))\)/
            2, , \[GothicCapitalD]\_{i_\_{\[GothicCapitalG], x__, \
\[GothicCapitalM]}} \[RuleDelayed] \((\[GothicM]\_\(i\_{\[GothicCapitalG], x, \
\[GothicCapitalM]}\) - \[GothicM]\_\(i\_{\[GothicCapitalG], x, \
\[GothicCapitalF]}\))\)/2}\)]],
  ".  Note that in general, we must provide rules for the reference points, \
",
  Cell[BoxData[
      \(TraditionalForm\`\[WeierstrassP]\_\[DoubleStruckI]\)]],
  ", and for the single-gene disequilibrium coefficients ",
  Cell[BoxData[
      \(TraditionalForm\`\[GothicCapitalD]\_{\[DoubleStruckI]}\)]],
  "."
}], "Text"],

Cell[TextData[{
  "This sets the single-locus associations appropriately, and sets the \
reference points to ",
  Cell[BoxData[
      \(TraditionalForm\`\[GothicM]\_\[DoubleStruckI]\)]],
  ":"
}], "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[
    \({\[GothicCapitalD]\_{i\_{\[GothicCapitalG], \[GothicCapitalM]}, j\_{\
\[GothicCapitalG], \[GothicCapitalM]}}, \[GothicCapitalD]\_{i\_{\
\[GothicCapitalG], \[GothicCapitalM]}}, \[WeierstrassP]\_\(i\_{\
\[GothicCapitalG], \[GothicCapitalM]}\)} /. 
      ReferencePointMean[\[GothicCapitalG]]\)], "Input",
  CellLabel->"In[24]:="],

Cell[BoxData[
    \({\[GothicCapitalD]\_{i\_{\[GothicCapitalG], \[GothicCapitalM]}, j\_{\
\[GothicCapitalG], \[GothicCapitalM]}}, 
      1\/2\ \((\(-\[GothicM]\_\(i\_{\[GothicCapitalG], \[GothicCapitalF]}\)\) \
+ \[GothicM]\_\(i\_{\[GothicCapitalG], \[GothicCapitalM]}\))\), 
      1\/2\ \((\[GothicM]\_\(i\_{\[GothicCapitalG], \[GothicCapitalF]}\) + \
\[GothicM]\_\(i\_{\[GothicCapitalG], \[GothicCapitalM]}\))\)}\)], "Output",
  CellLabel->"Out[24]="]
}, Open  ]],

Cell["This denotes the mean contributions by M:", "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[
    \({\[GothicCapitalD]\_{i\_{\[GothicCapitalG], \[GothicCapitalM]}, j\_{\
\[GothicCapitalG], \[GothicCapitalM]}}, \[GothicCapitalD]\_{i\_{\
\[GothicCapitalG], \[GothicCapitalM]}}, \[WeierstrassP]\_\(i\_{\
\[GothicCapitalG], \[GothicCapitalM]}\)} /. 
      ReferencePointMean[\[GothicCapitalG], M]\)], "Input",
  CellLabel->"In[25]:="],

Cell[BoxData[
    \({\[GothicCapitalD]\_{i\_{\[GothicCapitalG], \[GothicCapitalM]}, j\_{\
\[GothicCapitalG], \[GothicCapitalM]}}, 
      1\/2\ \((\(-M[i\_{\[GothicCapitalG], \[GothicCapitalF]}]\) + 
            M[i\_{\[GothicCapitalG], \[GothicCapitalM]}])\), 
      1\/2\ \((M[i\_{\[GothicCapitalG], \[GothicCapitalF]}] + 
            M[i\_{\[GothicCapitalG], \[GothicCapitalM]}])\)}\)], "Output",
  CellLabel->"Out[25]="]
}, Open  ]],

Cell["This does the same for several stages:", "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[
    \({\[GothicCapitalD]\_{j\_{\[GothicCapitalZ], \[GothicCapitalM], \
\[GothicCapitalM]}}, \[WeierstrassP]\_\(i\_{\[GothicCapitalZ], \
\[GothicCapitalM], \[GothicCapitalM]}\), \[GothicCapitalD]\_{i\_{\
\[GothicCapitalG], \[GothicCapitalM]}}, \[WeierstrassP]\_\(i\_{\
\[GothicCapitalG], \[GothicCapitalM]}\)} /. 
      ReferencePointMean[{\[GothicCapitalG], \[GothicCapitalZ]}]\)], "Input",
  CellLabel->"In[26]:="],

Cell[BoxData[
    \({1\/2\ \((\(-\[GothicM][
                j\_{\[GothicCapitalZ], \[GothicCapitalM], \[GothicCapitalF]}]\
\) + \[GothicM][
              j\_{\[GothicCapitalZ], \[GothicCapitalM], \
\[GothicCapitalM]}])\), 
      1\/2\ \((\[GothicM][
              i\_{\[GothicCapitalZ], \[GothicCapitalM], \[GothicCapitalF]}] + \
\[GothicM][i\_{\[GothicCapitalZ], \[GothicCapitalM], \[GothicCapitalM]}])\), 
      1\/2\ \((\(-\[GothicM][
                i\_{\[GothicCapitalG], \[GothicCapitalF]}]\) + \[GothicM][
              i\_{\[GothicCapitalG], \[GothicCapitalM]}])\), 
      1\/2\ \((\[GothicM][
              i\_{\[GothicCapitalG], \[GothicCapitalF]}] + \[GothicM][
              i\_{\[GothicCapitalG], \[GothicCapitalM]}])\)}\)], "Output",
  CellLabel->"Out[26]="]
}, Open  ]],

Cell["\<\
The reference points for male and female diploids can still differ \
between the sexes:\
\>", "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[
    \({\[WeierstrassP]\_\(i\_{\[GothicCapitalZ], \[GothicCapitalM], \
\[GothicCapitalM]}\), \[WeierstrassP]\_\(i\_{\[GothicCapitalZ], \
\[GothicCapitalM], \[GothicCapitalF]}\), \[WeierstrassP]\_\(i\_{\
\[GothicCapitalZ], \[GothicCapitalF], \[GothicCapitalM]}\), \[WeierstrassP]\_\
\(i\_{\[GothicCapitalZ], \[GothicCapitalF], \[GothicCapitalF]}\)} /. 
      ReferencePointMean[\[GothicCapitalZ]]\)], "Input",
  CellLabel->"In[91]:=  (15:54:40 on 3/4/01)"],

Cell[BoxData[
    \({1\/2\ \((\[GothicM]\_\(i\_{\[GothicCapitalZ], \[GothicCapitalM], \
\[GothicCapitalF]}\) + \[GothicM]\_\(i\_{\[GothicCapitalZ], \
\[GothicCapitalM], \[GothicCapitalM]}\))\), 
      1\/2\ \((\[GothicM]\_\(i\_{\[GothicCapitalZ], \[GothicCapitalM], \
\[GothicCapitalF]}\) + \[GothicM]\_\(i\_{\[GothicCapitalZ], \
\[GothicCapitalM], \[GothicCapitalM]}\))\), 
      1\/2\ \((\[GothicM]\_\(i\_{\[GothicCapitalZ], \[GothicCapitalF], \
\[GothicCapitalF]}\) + \[GothicM]\_\(i\_{\[GothicCapitalZ], \
\[GothicCapitalF], \[GothicCapitalM]}\))\), 
      1\/2\ \((\[GothicM]\_\(i\_{\[GothicCapitalZ], \[GothicCapitalF], \
\[GothicCapitalF]}\) + \[GothicM]\_\(i\_{\[GothicCapitalZ], \
\[GothicCapitalF], \[GothicCapitalM]}\))\)}\)], "Output",
  CellLabel->"Out[91]=  (15:54:40 on 3/4/01)"]
}, Open  ]],

Cell["\<\
Another rule would be needed to force the same reference point \
between the two sexes.\
\>", "Text"],

Cell[TextData[Cell[BoxData[
    FormBox[GridBox[{
          {\(\(ReferencePointMean[\[GothicCapitalG], 
                CytoplasmicLoci -> {i, 
                    j}]\)\(\ \)\(or\)\(\ \)\(ReferencePointMean[\
\[GothicCapitalG], MaternalLoci -> {i, j}]\)\(\ \)\), \(defines\ loci\ i, \ 
            j\ as\ being\ cytoplasmically\ \((i . e . \ 
                  maternally)\)\ inherited\)},
          {\(\(ReferencePointMean[\[GothicCapitalG], 
              PaternalLoci -> {i, j}]\)\(\ \)\), \(defines\ loci\ i, \ 
            j\ as\ being\ paternally\ inherited\)}
          }], TraditionalForm]]]], "DefinitionBox",
  CellTags->{"CytoplasmicLoci", "MaternalLoci", "PaternalLoci"}],

Cell["\<\
ReferencePointZero[] and ReferencePointSame[] apply to \
cytoplasmically inherited and sex-linked genes in just the same way.  \
However, ReferencePointMean[] must be modified, to take the reference point \
to be the mean across only relevant loci.\
\>", "Text"],

Cell["\<\
For cytoplasmically inherited genes, the reference point equals the \
mean of the female gametes, or of the female sex-of-origin in diploid stages:\
\
\>", "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[
    \({\[WeierstrassP]\_\(i\_{\[GothicCapitalG], \[GothicCapitalM]}\), \
\[WeierstrassP]\_\(i\_{\[GothicCapitalG], \[GothicCapitalF]}\)} /. 
      ReferencePointMean[\[GothicCapitalG], 
        CytoplasmicLoci -> {i}]\)], "Input",
  CellLabel->"In[83]:=  (16:27:23 on 3/5/01)"],

Cell[BoxData[
    \({\[GothicM]\_\(i\_{\[GothicCapitalG], \[GothicCapitalF]}\), \
\[GothicM]\_\(i\_{\[GothicCapitalG], \[GothicCapitalF]}\)}\)], "Output",
  CellLabel->"Out[83]=  (16:27:23 on 3/5/01)"]
}, Open  ]],

Cell["MaternalLoci is a synonym for CtytoplasmicLoci:", "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[
    \({\[WeierstrassP]\_\(i\_{\[GothicCapitalG], \[GothicCapitalM]}\), \
\[WeierstrassP]\_\(i\_{\[GothicCapitalG], \[GothicCapitalF]}\)} /. 
      ReferencePointMean[\[GothicCapitalG], MaternalLoci -> {i}]\)], "Input",
  CellLabel->"In[13]:="],

Cell[BoxData[
    \({\[GothicM]\_\(i\_{\[GothicCapitalG], \[GothicCapitalF]}\), \
\[GothicM]\_\(i\_{\[GothicCapitalG], \[GothicCapitalF]}\)}\)], "Output",
  CellLabel->"Out[13]="]
}, Open  ]],

Cell[TextData[{
  "The reference point for a cytoplasmic gene in a male gamete,",
  Cell[BoxData[
      \(\[WeierstrassP]\_\(i\_{\[GothicCapitalG], \[GothicCapitalM]}\)\)]],
  ", is returned, although it does not make much sense."
}], "Text"],

Cell["\<\
For paternally inherited genes, the reference point equals the mean \
of the male gametes, or of the male sex-of-origin in diploid stages:\
\>", \
"MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[
    \({\[WeierstrassP]\_\(i\_{\[GothicCapitalG], \[GothicCapitalM]}\), \
\[WeierstrassP]\_\(i\_{\[GothicCapitalG], \[GothicCapitalF]}\)} /. 
      ReferencePointMean[\[GothicCapitalG], PaternalLoci -> {i}]\)], "Input",
  CellLabel->"In[12]:="],

Cell[BoxData[
    \({\[GothicM]\_\(i\_{\[GothicCapitalG], \[GothicCapitalM]}\), \
\[GothicM]\_\(i\_{\[GothicCapitalG], \[GothicCapitalM]}\)}\)], "Output",
  CellLabel->"Out[12]="]
}, Open  ]],

Cell[TextData[{
  "The one-way association ",
  Cell[BoxData[
      \(\[GothicCapitalD]\_{i\_{\[GothicCapitalG], \[GothicCapitalF]}}\)]],
  "is zero with cytoplasmic inheritance:"
}], "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\[GothicCapitalD]\_{i\_{\[GothicCapitalG], \[GothicCapitalF]}} /. 
      ReferencePointMean[\[GothicCapitalG], 
        CytoplasmicLoci -> {i}]\)], "Input",
  CellLabel->"In[85]:=  (16:30:17 on 3/5/01)"],

Cell[BoxData[
    \(0\)], "Output",
  CellLabel->"Out[85]=  (16:30:18 on 3/5/01)"]
}, Open  ]],

Cell["\<\
An error is returned for associations involving a cytoplasmically \
inherited gene in a male gamete:\
\>", "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\[GothicCapitalD]\_{i\_{\[GothicCapitalG], \[GothicCapitalM]}} /. 
      ReferencePointMean[\[GothicCapitalG], 
        CytoplasmicLoci -> {i}]\)], "Input",
  CellLabel->"In[86]:=  (16:30:28 on 3/5/01)"],

Cell[BoxData[
    \(ReferencePointMean::"CytoplasmicClash" \(\(:\)\(\ \)\) 
      "A cytoplasmically inherited gene cannot be in a male gamete or derive \
from the father: \!\(\[GothicCapitalD]\_\({i\_\({\[GothicCapitalG], \
\[GothicCapitalM]}\)}\)\)"\)], "Message",
  CellLabel->"From In[86]:=  (16:30:28 on 3/5/01)"],

Cell[BoxData[
    \(\[GothicCapitalD]\_{i\_{\[GothicCapitalG], \[GothicCapitalM]}}\)], \
"Output",
  CellLabel->"Out[86]=  (16:30:28 on 3/5/01)"]
}, Open  ]],

Cell["\<\
Reference points and one-way associations are treated \
similarly:\
\>", "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{
        RowBox[{"(", GridBox[{
              {\(\[WeierstrassP]\_\(i\_{\[GothicCapitalZ], \[GothicCapitalM], \
\[GothicCapitalM]}\)\), \(\[WeierstrassP]\_\(i\_{\[GothicCapitalZ], \
\[GothicCapitalM], \[GothicCapitalF]}\)\), \(\[WeierstrassP]\_\(i\_{\
\[GothicCapitalZ], \[GothicCapitalF], \[GothicCapitalM]}\)\), \(\
\[WeierstrassP]\_\(i\_{\[GothicCapitalZ], \[GothicCapitalF], \
\[GothicCapitalF]}\)\)},
              {\(\[GothicCapitalD]\_{i\_{\[GothicCapitalZ], \
\[GothicCapitalM], \[GothicCapitalM]}}\), \(\[GothicCapitalD]\_{i\_{\
\[GothicCapitalZ], \[GothicCapitalM], \[GothicCapitalF]}}\), \(\
\[GothicCapitalD]\_{i\_{\[GothicCapitalZ], \[GothicCapitalF], \
\[GothicCapitalM]}}\), \(\[GothicCapitalD]\_{i\_{\[GothicCapitalZ], \
\[GothicCapitalF], \[GothicCapitalF]}}\)}
              }], ")"}], 
        "/.", \(ReferencePointMean[\[GothicCapitalZ], 
          CytoplasmicLoci -> {i}]\)}], "//", "MatrixForm"}]], "Input",
  CellLabel->"In[88]:=  (16:33:28 on 3/5/01)"],

Cell[BoxData[
    \(ReferencePointMean::"CytoplasmicClash" \(\(:\)\(\ \)\) 
      "A cytoplasmically inherited gene cannot be in a male gamete or derive \
from the father: \!\(\[GothicCapitalD]\_\({i\_\({\[GothicCapitalZ], \
\[GothicCapitalM], \[GothicCapitalM]}\)}\)\)"\)], "Message",
  CellLabel->"From In[88]:=  (16:33:28 on 3/5/01)"],

Cell[BoxData[
    \(ReferencePointMean::"CytoplasmicClash" \(\(:\)\(\ \)\) 
      "A cytoplasmically inherited gene cannot be in a male gamete or derive \
from the father: \!\(\[GothicCapitalD]\_\({i\_\({\[GothicCapitalZ], \
\[GothicCapitalF], \[GothicCapitalM]}\)}\)\)"\)], "Message",
  CellLabel->"From In[88]:=  (16:33:28 on 3/5/01)"],

Cell[BoxData[
    TagBox[
      RowBox[{"(", "\[NoBreak]", GridBox[{
            {\(\[GothicM]\_\(i\_{\[GothicCapitalZ], \[GothicCapitalM], \
\[GothicCapitalF]}\)\), \(\[GothicM]\_\(i\_{\[GothicCapitalZ], \
\[GothicCapitalM], \[GothicCapitalF]}\)\), \(\[GothicM]\_\(i\_{\
\[GothicCapitalZ], \[GothicCapitalF], \[GothicCapitalF]}\)\), \
\(\[GothicM]\_\(i\_{\[GothicCapitalZ], \[GothicCapitalF], \
\[GothicCapitalF]}\)\)},
            {\(\[GothicCapitalD]\_{i\_{\[GothicCapitalZ], \[GothicCapitalM], \
\[GothicCapitalM]}}\), 
              "0", \(\[GothicCapitalD]\_{i\_{\[GothicCapitalZ], \
\[GothicCapitalF], \[GothicCapitalM]}}\), "0"}
            }], "\[NoBreak]", ")"}],
      (MatrixForm[ #]&)]], "Output",
  CellLabel->"Out[88]//MatrixForm=  (16:33:28 on 3/5/01)"]
}, Open  ]],

Cell[TextData[Cell[BoxData[
    FormBox[GridBox[{
          {\(ReferencePointMean[\[GothicCapitalG], 
              YLinkedLoci -> {i, j}]\), \(defined\ loci\ i, \ 
            j\ as\ being\ Y - linked\)}
          }], TraditionalForm]]]], "DefinitionBox",
  CellTags->"YLinkedLoci"],

Cell["Y-linked genes are handled in the converse way:", "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{
        RowBox[{"(", GridBox[{
              {\(\[WeierstrassP]\_\(i\_{\[GothicCapitalG], \[GothicCapitalM]}\
\)\), \(\[WeierstrassP]\_\(i\_{\[GothicCapitalG], \[GothicCapitalF]}\)\), \(\
\[GothicCapitalD]\_{i\_{\[GothicCapitalG], \[GothicCapitalM]}}\), \(\
\[GothicCapitalD]\_{i\_{\[GothicCapitalG], \[GothicCapitalF]}}\)},
              {\(\[WeierstrassP]\_\(i\_{\[GothicCapitalZ], \[GothicCapitalM], \
\[GothicCapitalM]}\)\), \(\[WeierstrassP]\_\(i\_{\[GothicCapitalZ], \
\[GothicCapitalM], \[GothicCapitalF]}\)\), \(\[WeierstrassP]\_\(i\_{\
\[GothicCapitalZ], \[GothicCapitalF], \[GothicCapitalM]}\)\), \(\
\[WeierstrassP]\_\(i\_{\[GothicCapitalZ], \[GothicCapitalF], \
\[GothicCapitalF]}\)\)},
              {\(\[GothicCapitalD]\_{i\_{\[GothicCapitalZ], \
\[GothicCapitalM], \[GothicCapitalM]}}\), \(\[GothicCapitalD]\_{i\_{\
\[GothicCapitalZ], \[GothicCapitalM], \[GothicCapitalF]}}\), \(\
\[GothicCapitalD]\_{i\_{\[GothicCapitalZ], \[GothicCapitalF], \
\[GothicCapitalM]}}\), \(\[GothicCapitalD]\_{i\_{\[GothicCapitalZ], \
\[GothicCapitalF], \[GothicCapitalF]}}\)}
              }], ")"}], 
        "/.", \(ReferencePointMean[{\[GothicCapitalG], \[GothicCapitalZ]}, 
          YLinkedLoci -> {i}]\)}], "//", "MatrixForm"}]], "Input",
  CellLabel->"In[90]:=  (16:35:25 on 3/5/01)"],

Cell[BoxData[
    \(ReferencePointMean::"YlinkageClash" \(\(:\)\(\ \)\) 
      "A Y-linked gene cannot be in a female gamete or derive from the \
mother: \!\(\[GothicCapitalD]\_\({i\_\({\[GothicCapitalG], \[GothicCapitalF]}\
\)}\)\)"\)], "Message",
  CellLabel->"From In[90]:=  (16:35:25 on 3/5/01)"],

Cell[BoxData[
    \(ReferencePointMean::"YlinkageClash" \(\(:\)\(\ \)\) 
      "A Y-linked gene cannot be in a female gamete or derive from the \
mother: \!\(\[GothicCapitalD]\_\({i\_\({\[GothicCapitalZ], \[GothicCapitalM], \
\[GothicCapitalF]}\)}\)\)"\)], "Message",
  CellLabel->"From In[90]:=  (16:35:26 on 3/5/01)"],

Cell[BoxData[
    \(ReferencePointMean::"YlinkageClash" \(\(:\)\(\ \)\) 
      "A Y-linked gene cannot be in a female gamete or derive from the \
mother: \!\(\[GothicCapitalD]\_\({i\_\({\[GothicCapitalZ], \[GothicCapitalF], \
\[GothicCapitalF]}\)}\)\)"\)], "Message",
  CellLabel->"From In[90]:=  (16:35:26 on 3/5/01)"],

Cell[BoxData[
    \(General::"stop" \(\(:\)\(\ \)\) 
      "Further output of \!\(ReferencePointMean :: \"YlinkageClash\"\) will \
be suppressed during this calculation."\)], "Message",
  CellLabel->"From In[90]:=  (16:35:26 on 3/5/01)"],

Cell[BoxData[
    TagBox[
      RowBox[{"(", "\[NoBreak]", GridBox[{
            {\(\[GothicM]\_\(i\_{\[GothicCapitalG], \[GothicCapitalM]}\)\), \
\(\[GothicM]\_\(i\_{\[GothicCapitalG], \[GothicCapitalM]}\)\), 
              "0", \(\[GothicCapitalD]\_{i\_{\[GothicCapitalG], \
\[GothicCapitalF]}}\)},
            {\(\[GothicM]\_\(i\_{\[GothicCapitalZ], \[GothicCapitalM], \
\[GothicCapitalM]}\)\), \(\[GothicM]\_\(i\_{\[GothicCapitalZ], \
\[GothicCapitalM], \[GothicCapitalM]}\)\), \(\[GothicM]\_\(i\_{\
\[GothicCapitalZ], \[GothicCapitalF], \[GothicCapitalM]}\)\), \
\(\[GothicM]\_\(i\_{\[GothicCapitalZ], \[GothicCapitalF], \
\[GothicCapitalM]}\)\)},
            {
              "0", \(\[GothicCapitalD]\_{i\_{\[GothicCapitalZ], \
\[GothicCapitalM], \[GothicCapitalF]}}\), 
              "0", \(\[GothicCapitalD]\_{i\_{\[GothicCapitalZ], \
\[GothicCapitalF], \[GothicCapitalF]}}\)}
            }], "\[NoBreak]", ")"}],
      (MatrixForm[ #]&)]], "Output",
  CellLabel->"Out[90]//MatrixForm=  (16:35:26 on 3/5/01)"]
}, Open  ]],

Cell[TextData[Cell[BoxData[
    FormBox[GridBox[{
          {\(ReferencePointMean[\[GothicCapitalG], 
              XLinkedLoci -> {i, j}]\), \(defined\ loci\ i, \ 
            j\ as\ being\ X - linked\)}
          }], TraditionalForm]]]], "DefinitionBox",
  CellTags->"XLinkedLoci"],

Cell["X-linked genes behave in a slightly more complicated way:", \
"MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{
        RowBox[{"(", GridBox[{
              {\(\[WeierstrassP]\_\(i\_{\[GothicCapitalG], \[GothicCapitalM]}\
\)\), \(\[WeierstrassP]\_\(i\_{\[GothicCapitalG], \[GothicCapitalF]}\)\), \(\
\[GothicCapitalD]\_{i\_{\[GothicCapitalG], \[GothicCapitalM]}}\), \(\
\[GothicCapitalD]\_{i\_{\[GothicCapitalG], \[GothicCapitalF]}}\)},
              {\(\[WeierstrassP]\_\(i\_{\[GothicCapitalZ], \[GothicCapitalM], \
\[GothicCapitalM]}\)\), \(\[WeierstrassP]\_\(i\_{\[GothicCapitalZ], \
\[GothicCapitalM], \[GothicCapitalF]}\)\), \(\[WeierstrassP]\_\(i\_{\
\[GothicCapitalZ], \[GothicCapitalF], \[GothicCapitalM]}\)\), \(\
\[WeierstrassP]\_\(i\_{\[GothicCapitalZ], \[GothicCapitalF], \
\[GothicCapitalF]}\)\)},
              {\(\[GothicCapitalD]\_{i\_{\[GothicCapitalZ], \
\[GothicCapitalM], \[GothicCapitalM]}}\), \(\[GothicCapitalD]\_{i\_{\
\[GothicCapitalZ], \[GothicCapitalM], \[GothicCapitalF]}}\), \(\
\[GothicCapitalD]\_{i\_{\[GothicCapitalZ], \[GothicCapitalF], \
\[GothicCapitalM]}}\), \(\[GothicCapitalD]\_{i\_{\[GothicCapitalZ], \
\[GothicCapitalF], \[GothicCapitalF]}}\)}
              }], ")"}], 
        "/.", \(ReferencePointMean[{\[GothicCapitalG], \[GothicCapitalZ]}, 
          XLinkedLoci -> {i}]\)}], "//", "MatrixForm"}]], "Input",
  CellLabel->"In[213]:=  (16:43:57 on 3/5/01)"],

Cell[BoxData[
    \(ReferencePointMean::"XlinkageClash" \(\(:\)\(\ \)\) 
      "An X-linked gene in a male cannot derive from the father: \!\(\
\[GothicCapitalD]\_\({i\_\({\[GothicCapitalZ], \[GothicCapitalM], \
\[GothicCapitalM]}\)}\)\)"\)], "Message",
  CellLabel->"From In[213]:=  (16:43:57 on 3/5/01)"],

Cell[BoxData[
    TagBox[
      RowBox[{"(", "\[NoBreak]", GridBox[{
            {\(1\/3\ \((2\ \[GothicM]\_\(i\_{\[GothicCapitalG], \
\[GothicCapitalF]}\) + \[GothicM]\_\(i\_{\[GothicCapitalG], \
\[GothicCapitalM]}\))\)\), \(1\/3\ \((2\ \[GothicM]\_\(i\_{\[GothicCapitalG], \
\[GothicCapitalF]}\) + \[GothicM]\_\(i\_{\[GothicCapitalG], \
\[GothicCapitalM]}\))\)\), \(2\/3\ \((\(-\[GothicM]\_\(i\_{\[GothicCapitalG], \
\[GothicCapitalF]}\)\) + \[GothicM]\_\(i\_{\[GothicCapitalG], \
\[GothicCapitalM]}\))\)\), \(1\/3\ \((\[GothicM]\_\(i\_{\[GothicCapitalG], \
\[GothicCapitalF]}\) - \[GothicM]\_\(i\_{\[GothicCapitalG], \
\[GothicCapitalM]}\))\)\)},
            {\(\[GothicM]\_\(i\_{\[GothicCapitalZ], \[GothicCapitalM], \
\[GothicCapitalF]}\)\), \(\[GothicM]\_\(i\_{\[GothicCapitalZ], \
\[GothicCapitalM], \[GothicCapitalF]}\)\), \(1\/2\ \((\[GothicM]\_\(i\_{\
\[GothicCapitalZ], \[GothicCapitalF], \[GothicCapitalF]}\) + \
\[GothicM]\_\(i\_{\[GothicCapitalZ], \[GothicCapitalF], \[GothicCapitalM]}\))\
\)\), \(1\/2\ \((\[GothicM]\_\(i\_{\[GothicCapitalZ], \[GothicCapitalF], \
\[GothicCapitalF]}\) + \[GothicM]\_\(i\_{\[GothicCapitalZ], \
\[GothicCapitalF], \[GothicCapitalM]}\))\)\)},
            {\(\[GothicCapitalD]\_{i\_{\[GothicCapitalZ], \[GothicCapitalM], \
\[GothicCapitalM]}}\), 
              "0", \(1\/2\ \((\(-\[GothicM]\_\(i\_{\[GothicCapitalZ], \
\[GothicCapitalF], \[GothicCapitalF]}\)\) + \[GothicM]\_\(i\_{\
\[GothicCapitalZ], \[GothicCapitalF], \[GothicCapitalM]}\))\)\), \(1\/2\ \((\
\[GothicM]\_\(i\_{\[GothicCapitalZ], \[GothicCapitalF], \[GothicCapitalF]}\) \
- \[GothicM]\_\(i\_{\[GothicCapitalZ], \[GothicCapitalF], \
\[GothicCapitalM]}\))\)\)}
            }], "\[NoBreak]", ")"}],
      (MatrixForm[ #]&)]], "Output",
  CellLabel->"Out[213]//MatrixForm=  (16:43:58 on 3/5/01)"]
}, Open  ]],

Cell["\<\
In gametes, the reference point is weighted towards the \
X-chromosomes in females, which are twice as numerous.  In diploids, the \
reference point for males is just that of the female sex-of-origin (since the \
X can only come from the mother) whereas in females, it is weighted equally \
between the two sexes-of-origin.\
\>", "Text"],

Cell[TextData[{
  "Note:  ",
  StyleBox["A stage is determined to be diploid if it has SexOfOrigin \
defined.  ReferencePointMean would not apply correctly to (say) tetraploids.",
    
    FontWeight->"Plain"]
}], "Text",
  FontWeight->"Bold"],

Cell[TextData[Cell[BoxData[
    FormBox[GridBox[{
          {\(ReferencePointMean[\[GothicCapitalG], ZLinkedLoci -> {i, j}, 
              WLinkedLoci -> {k}]\), \(defined\ loci\ i, \ 
            j\ as\ being\ Z - linked, \ and\ k\ as\ W - linked\)}
          }], TraditionalForm]]]], "DefinitionBox",
  CellTags->{"ZLinkedLoci", "WLinkedLoci"}],

Cell["Z-linkage and W-linkage are also implemented:", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{
        RowBox[{"(", GridBox[{
              {\(\[WeierstrassP]\_\(i\_{\[GothicCapitalG], \[GothicCapitalM]}\
\)\), \(\[WeierstrassP]\_\(i\_{\[GothicCapitalG], \[GothicCapitalF]}\)\), \(\
\[GothicCapitalD]\_{i\_{\[GothicCapitalG], \[GothicCapitalM]}}\), \(\
\[GothicCapitalD]\_{i\_{\[GothicCapitalG], \[GothicCapitalF]}}\)},
              {\(\[WeierstrassP]\_\(i\_{\[GothicCapitalZ], \[GothicCapitalM], \
\[GothicCapitalM]}\)\), \(\[WeierstrassP]\_\(i\_{\[GothicCapitalZ], \
\[GothicCapitalM], \[GothicCapitalF]}\)\), \(\[WeierstrassP]\_\(i\_{\
\[GothicCapitalZ], \[GothicCapitalF], \[GothicCapitalM]}\)\), \(\
\[WeierstrassP]\_\(i\_{\[GothicCapitalZ], \[GothicCapitalF], \
\[GothicCapitalF]}\)\)},
              {\(\[GothicCapitalD]\_{i\_{\[GothicCapitalZ], \
\[GothicCapitalM], \[GothicCapitalM]}}\), \(\[GothicCapitalD]\_{i\_{\
\[GothicCapitalZ], \[GothicCapitalM], \[GothicCapitalF]}}\), \(\
\[GothicCapitalD]\_{i\_{\[GothicCapitalZ], \[GothicCapitalF], \
\[GothicCapitalM]}}\), \(\[GothicCapitalD]\_{i\_{\[GothicCapitalZ], \
\[GothicCapitalF], \[GothicCapitalF]}}\)}
              }], ")"}], 
        "/.", \(ReferencePointMean[{\[GothicCapitalG], \[GothicCapitalZ]}, 
          ZLinkedLoci -> {i}]\)}], "//", "MatrixForm"}]], "Input",
  CellLabel->"In[420]:=  (20:09:21 on 3/5/01)"],

Cell[BoxData[
    \(ReferencePointMean::"ZlinkageClash" \(\(:\)\(\ \)\) 
      "A Z-linked gene in a female cannot derive from the mother: \!\(\
\[GothicCapitalD]\_\({i\_\({\[GothicCapitalZ], \[GothicCapitalF], \
\[GothicCapitalF]}\)}\)\)"\)], "Message",
  CellLabel->"From In[420]:=  (20:09:22 on 3/5/01)"],

Cell[BoxData[
    TagBox[
      RowBox[{"(", "\[NoBreak]", GridBox[{
            {\(1\/3\ \((\[GothicM]\_\(i\_{\[GothicCapitalG], \
\[GothicCapitalF]}\) + 
                    2\ \[GothicM]\_\(i\_{\[GothicCapitalG], \
\[GothicCapitalM]}\))\)\), \(1\/3\ \((\[GothicM]\_\(i\_{\[GothicCapitalG], \
\[GothicCapitalF]}\) + 
                    2\ \[GothicM]\_\(i\_{\[GothicCapitalG], \
\[GothicCapitalM]}\))\)\), \(1\/3\ \((\(-\[GothicM]\_\(i\_{\[GothicCapitalG], \
\[GothicCapitalF]}\)\) + \[GothicM]\_\(i\_{\[GothicCapitalG], \
\[GothicCapitalM]}\))\)\), \(2\/3\ \((\[GothicM]\_\(i\_{\[GothicCapitalG], \
\[GothicCapitalF]}\) - \[GothicM]\_\(i\_{\[GothicCapitalG], \
\[GothicCapitalM]}\))\)\)},
            {\(1\/2\ \((\[GothicM]\_\(i\_{\[GothicCapitalZ], \
\[GothicCapitalM], \[GothicCapitalF]}\) + \
\[GothicM]\_\(i\_{\[GothicCapitalZ], \[GothicCapitalM], \[GothicCapitalM]}\))\
\)\), \(1\/2\ \((\[GothicM]\_\(i\_{\[GothicCapitalZ], \[GothicCapitalM], \
\[GothicCapitalF]}\) + \[GothicM]\_\(i\_{\[GothicCapitalZ], \
\[GothicCapitalM], \[GothicCapitalM]}\))\)\), \(\[GothicM]\_\(i\_{\
\[GothicCapitalZ], \[GothicCapitalF], \[GothicCapitalM]}\)\), \
\(\[GothicM]\_\(i\_{\[GothicCapitalZ], \[GothicCapitalF], \
\[GothicCapitalM]}\)\)},
            {\(1\/2\ \((\(-\[GothicM]\_\(i\_{\[GothicCapitalZ], \
\[GothicCapitalM], \[GothicCapitalF]}\)\) + \[GothicM]\_\(i\_{\
\[GothicCapitalZ], \[GothicCapitalM], \[GothicCapitalM]}\))\)\), \(1\/2\ \((\
\[GothicM]\_\(i\_{\[GothicCapitalZ], \[GothicCapitalM], \[GothicCapitalF]}\) \
- \[GothicM]\_\(i\_{\[GothicCapitalZ], \[GothicCapitalM], \
\[GothicCapitalM]}\))\)\), 
              "0", \(\[GothicCapitalD]\_{i\_{\[GothicCapitalZ], \
\[GothicCapitalF], \[GothicCapitalF]}}\)}
            }], "\[NoBreak]", ")"}],
      (MatrixForm[ #]&)]], "Output",
  CellLabel->"Out[420]//MatrixForm=  (20:09:22 on 3/5/01)"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{
        RowBox[{"(", GridBox[{
              {\(\[WeierstrassP]\_\(i\_{\[GothicCapitalG], \[GothicCapitalM]}\
\)\), \(\[WeierstrassP]\_\(i\_{\[GothicCapitalG], \[GothicCapitalF]}\)\), \(\
\[GothicCapitalD]\_{i\_{\[GothicCapitalG], \[GothicCapitalM]}}\), \(\
\[GothicCapitalD]\_{i\_{\[GothicCapitalG], \[GothicCapitalF]}}\)},
              {\(\[WeierstrassP]\_\(i\_{\[GothicCapitalZ], \[GothicCapitalM], \
\[GothicCapitalM]}\)\), \(\[WeierstrassP]\_\(i\_{\[GothicCapitalZ], \
\[GothicCapitalM], \[GothicCapitalF]}\)\), \(\[WeierstrassP]\_\(i\_{\
\[GothicCapitalZ], \[GothicCapitalF], \[GothicCapitalM]}\)\), \(\
\[WeierstrassP]\_\(i\_{\[GothicCapitalZ], \[GothicCapitalF], \
\[GothicCapitalF]}\)\)},
              {\(\[GothicCapitalD]\_{i\_{\[GothicCapitalZ], \
\[GothicCapitalM], \[GothicCapitalM]}}\), \(\[GothicCapitalD]\_{i\_{\
\[GothicCapitalZ], \[GothicCapitalM], \[GothicCapitalF]}}\), \(\
\[GothicCapitalD]\_{i\_{\[GothicCapitalZ], \[GothicCapitalF], \
\[GothicCapitalM]}}\), \(\[GothicCapitalD]\_{i\_{\[GothicCapitalZ], \
\[GothicCapitalF], \[GothicCapitalF]}}\)}
              }], ")"}], 
        "/.", \(ReferencePointMean[{\[GothicCapitalG], \[GothicCapitalZ]}, 
          WLinkedLoci -> {i}]\)}], "//", "MatrixForm"}]], "Input",
  CellLabel->"In[421]:=  (20:09:30 on 3/5/01)"],

Cell[BoxData[
    \(ReferencePointMean::"WlinkageClash" \(\(:\)\(\ \)\) 
      "A W-linked gene cannot be in a male gamete or derive from the father: \
\!\(\[GothicCapitalD]\_\({i\_\({\[GothicCapitalG], \[GothicCapitalM]}\)}\)\)"\
\)], "Message",
  CellLabel->"From In[421]:=  (20:09:30 on 3/5/01)"],

Cell[BoxData[
    \(ReferencePointMean::"WlinkageClash" \(\(:\)\(\ \)\) 
      "A W-linked gene cannot be in a male gamete or derive from the father: \
\!\(\[GothicCapitalD]\_\({i\_\({\[GothicCapitalZ], \[GothicCapitalM], \
\[GothicCapitalM]}\)}\)\)"\)], "Message",
  CellLabel->"From In[421]:=  (20:09:30 on 3/5/01)"],

Cell[BoxData[
    \(ReferencePointMean::"WlinkageClash" \(\(:\)\(\ \)\) 
      "A W-linked gene cannot be in a male gamete or derive from the father: \
\!\(\[GothicCapitalD]\_\({i\_\({\[GothicCapitalZ], \[GothicCapitalF], \
\[GothicCapitalM]}\)}\)\)"\)], "Message",
  CellLabel->"From In[421]:=  (20:09:30 on 3/5/01)"],

Cell[BoxData[
    \(General::"stop" \(\(:\)\(\ \)\) 
      "Further output of \!\(ReferencePointMean :: \"WlinkageClash\"\) will \
be suppressed during this calculation."\)], "Message",
  CellLabel->"From In[421]:=  (20:09:31 on 3/5/01)"],

Cell[BoxData[
    TagBox[
      RowBox[{"(", "\[NoBreak]", GridBox[{
            {\(\[GothicM]\_\(i\_{\[GothicCapitalG], \[GothicCapitalF]}\)\), \
\(\[GothicM]\_\(i\_{\[GothicCapitalG], \[GothicCapitalF]}\)\), \(\
\[GothicCapitalD]\_{i\_{\[GothicCapitalG], \[GothicCapitalM]}}\), "0"},
            {\(\[GothicM]\_\(i\_{\[GothicCapitalZ], \[GothicCapitalM], \
\[GothicCapitalF]}\)\), \(\[GothicM]\_\(i\_{\[GothicCapitalZ], \
\[GothicCapitalM], \[GothicCapitalF]}\)\), \(\[GothicM]\_\(i\_{\
\[GothicCapitalZ], \[GothicCapitalF], \[GothicCapitalF]}\)\), \
\(\[GothicM]\_\(i\_{\[GothicCapitalZ], \[GothicCapitalF], \
\[GothicCapitalF]}\)\)},
            {\(\[GothicCapitalD]\_{i\_{\[GothicCapitalZ], \[GothicCapitalM], \
\[GothicCapitalM]}}\), 
              "0", \(\[GothicCapitalD]\_{i\_{\[GothicCapitalZ], \
\[GothicCapitalF], \[GothicCapitalM]}}\), "0"}
            }], "\[NoBreak]", ")"}],
      (MatrixForm[ #]&)]], "Output",
  CellLabel->"Out[421]//MatrixForm=  (20:09:31 on 3/5/01)"]
}, Open  ]],

Cell["One cannot define both ZW and XY linkage at the same time:", \
"MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\[GothicCapitalD]\_{i\_{\[GothicCapitalG], \[GothicCapitalM]}} /. 
      ReferencePointMean[{\[GothicCapitalG], \[GothicCapitalZ]}, 
        WLinkedLoci -> {i}, XLinkedLoci -> {j}]\)], "Input",
  CellLabel->"In[422]:=  (20:10:35 on 3/5/01)"],

Cell[BoxData[
    \(ReferencePointMean::"ZWXYmix" \(\(:\)\(\ \)\) 
      "Cannot specify both XY linkage and ZW linkage: \!\({j}\), \
\!\({i}\)"\)], "Message",
  CellLabel->"From In[422]:=  (20:10:36 on 3/5/01)"],

Cell[BoxData[
    \(ReferencePointMean::"ZWXYmix" \(\(:\)\(\ \)\) 
      "Cannot specify both XY linkage and ZW linkage: \!\({j}\), \
\!\({i}\)"\)], "Message",
  CellLabel->"From In[422]:=  (20:10:36 on 3/5/01)"],

Cell[BoxData[
    \(\[GothicCapitalD]\_{i\_{\[GothicCapitalG], \[GothicCapitalM]}}\)], \
"Output",
  CellLabel->"Out[422]=  (20:10:36 on 3/5/01)"]
}, Open  ]]
}, Open  ]]
},
FrontEndVersion->"4.0 for Macintosh",
ScreenRectangle->{{0, 1152}, {0, 748}},
WindowSize->{838, 670},
WindowMargins->{{136, Automatic}, {Automatic, 15}},
StyleDefinitions -> "HelpBrowser.nb",
MacintoshSystemPageSetup->"\<\
00h0001804P000000b02<?oaonl3>@91H`85N0?N0@00005X0FP000003j0:l001
0@00I00100000@0200000BL?00400000000000000000010000000000000@0?ne
oj/@7@]500P1000000000000000001T1\>"
]


(***********************************************************************
Cached data follows.  If you edit this Notebook file directly, not using
Mathematica, you must remove the line containing CacheID at the top of 
the file.  The cache data will then be recreated when you save this file 
from within Mathematica.
***********************************************************************)

(*CellTagsOutline
CellTagsIndex->{
  "ReferencePointZero"->{
    Cell[2979, 86, 1022, 18, 108, "DefinitionBox",
      CellTags->"ReferencePointZero"]},
  "ReferencePointSame"->{
    Cell[10302, 278, 874, 14, 108, "DefinitionBox",
      CellTags->"ReferencePointSame"]},
  "ReferencePointMean"->{
    Cell[13205, 361, 1505, 27, 150, "DefinitionBox",
      CellTags->"ReferencePointMean"]},
  "CytoplasmicLoci"->{
    Cell[20700, 534, 684, 12, 72, "DefinitionBox",
      CellTags->{"CytoplasmicLoci", "MaternalLoci", "PaternalLoci"}]},
  "MaternalLoci"->{
    Cell[20700, 534, 684, 12, 72, "DefinitionBox",
      CellTags->{"CytoplasmicLoci", "MaternalLoci", "PaternalLoci"}]},
  "PaternalLoci"->{
    Cell[20700, 534, 684, 12, 72, "DefinitionBox",
      CellTags->{"CytoplasmicLoci", "MaternalLoci", "PaternalLoci"}]},
  "YLinkedLoci"->{
    Cell[27837, 725, 283, 6, 37, "DefinitionBox",
      CellTags->"YLinkedLoci"]},
  "XLinkedLoci"->{
    Cell[31768, 812, 283, 6, 37, "DefinitionBox",
      CellTags->"XLinkedLoci"]},
  "ZLinkedLoci"->{
    Cell[36218, 907, 346, 6, 52, "DefinitionBox",
      CellTags->{"ZLinkedLoci", "WLinkedLoci"}]},
  "WLinkedLoci"->{
    Cell[36218, 907, 346, 6, 52, "DefinitionBox",
      CellTags->{"ZLinkedLoci", "WLinkedLoci"}]}
  }
*)

(*CellTagsIndex
CellTagsIndex->{
  {"ReferencePointZero", 45520, 1113},
  {"ReferencePointSame", 45637, 1116},
  {"ReferencePointMean", 45755, 1119},
  {"CytoplasmicLoci", 45871, 1122},
  {"MaternalLoci", 46013, 1125},
  {"PaternalLoci", 46155, 1128},
  {"YLinkedLoci", 46296, 1131},
  {"XLinkedLoci", 46398, 1134},
  {"ZLinkedLoci", 46500, 1137},
  {"WLinkedLoci", 46619, 1140}
  }
*)

(*NotebookFileOutline
Notebook[{

Cell[CellGroupData[{
Cell[1739, 51, 42, 0, 36, "SubsectionIcon"],
Cell[1784, 53, 862, 20, 50, "Text"],
Cell[2649, 75, 327, 9, 24, "Text"],
Cell[2979, 86, 1022, 18, 108, "DefinitionBox",
  CellTags->"ReferencePointZero"],
Cell[4004, 106, 1086, 21, 88, "Text"],
Cell[5093, 129, 1060, 27, 62, "Text"],
Cell[6156, 158, 304, 9, 28, "MathCaption"],

Cell[CellGroupData[{
Cell[6485, 171, 346, 6, 30, "Input"],
Cell[6834, 179, 238, 5, 28, "Output"]
}, Open  ]],
Cell[7087, 187, 61, 0, 28, "MathCaption"],

Cell[CellGroupData[{
Cell[7173, 191, 440, 8, 30, "Input"],
Cell[7616, 201, 212, 5, 26, "Output"]
}, Open  ]],
Cell[7843, 209, 62, 0, 28, "MathCaption"],

Cell[CellGroupData[{
Cell[7930, 213, 350, 6, 30, "Input"],
Cell[8283, 221, 228, 4, 28, "Output"]
}, Open  ]],
Cell[8526, 228, 272, 6, 22, "Text"],
Cell[8801, 236, 500, 13, 28, "MathCaption"],

Cell[CellGroupData[{
Cell[9326, 253, 730, 16, 48, "Input"],
Cell[10059, 271, 228, 4, 28, "Output"]
}, Open  ]],
Cell[10302, 278, 874, 14, 108, "DefinitionBox",
  CellTags->"ReferencePointSame"],
Cell[11179, 294, 132, 3, 28, "MathCaption"],

Cell[CellGroupData[{
Cell[11336, 301, 208, 4, 30, "Input"],
Cell[11547, 307, 123, 3, 25, "Output"]
}, Open  ]],
Cell[11685, 313, 143, 3, 28, "MathCaption"],

Cell[CellGroupData[{
Cell[11853, 320, 254, 4, 47, "Input"],
Cell[12110, 326, 124, 3, 25, "Output"]
}, Open  ]],
Cell[12249, 332, 129, 3, 22, "Text"],
Cell[12381, 337, 69, 2, 28, "MathCaption"],

Cell[CellGroupData[{
Cell[12475, 343, 406, 7, 30, "Input"],
Cell[12884, 352, 256, 4, 26, "Output"]
}, Open  ]],
Cell[13155, 359, 47, 0, 22, "Text"],
Cell[13205, 361, 1505, 27, 150, "DefinitionBox",
  CellTags->"ReferencePointMean"],
Cell[14713, 390, 1207, 24, 66, "Text"],
Cell[15923, 416, 211, 6, 28, "MathCaption"],

Cell[CellGroupData[{
Cell[16159, 426, 347, 6, 30, "Input"],
Cell[16509, 434, 453, 7, 36, "Output"]
}, Open  ]],
Cell[16977, 444, 64, 0, 28, "MathCaption"],

Cell[CellGroupData[{
Cell[17066, 448, 350, 6, 30, "Input"],
Cell[17419, 456, 423, 7, 36, "Output"]
}, Open  ]],
Cell[17857, 466, 61, 0, 28, "MathCaption"],

Cell[CellGroupData[{
Cell[17943, 470, 429, 7, 30, "Input"],
Cell[18375, 479, 773, 15, 36, "Output"]
}, Open  ]],
Cell[19163, 497, 118, 3, 28, "MathCaption"],

Cell[CellGroupData[{
Cell[19306, 504, 468, 7, 42, "Input"],
Cell[19777, 513, 794, 13, 48, "Output"]
}, Open  ]],
Cell[20586, 529, 111, 3, 22, "Text"],
Cell[20700, 534, 684, 12, 72, "DefinitionBox",
  CellTags->{"CytoplasmicLoci", "MaternalLoci", "PaternalLoci"}],
Cell[21387, 548, 272, 5, 36, "Text"],
Cell[21662, 555, 180, 4, 28, "MathCaption"],

Cell[CellGroupData[{
Cell[21867, 563, 291, 5, 42, "Input"],
Cell[22161, 570, 201, 3, 38, "Output"]
}, Open  ]],
Cell[22377, 576, 70, 0, 28, "MathCaption"],

Cell[CellGroupData[{
Cell[22472, 580, 257, 4, 30, "Input"],
Cell[22732, 586, 179, 3, 26, "Output"]
}, Open  ]],
Cell[22926, 592, 242, 5, 25, "Text"],
Cell[23171, 599, 171, 4, 28, "MathCaption"],

Cell[CellGroupData[{
Cell[23367, 607, 257, 4, 30, "Input"],
Cell[23627, 613, 179, 3, 26, "Output"]
}, Open  ]],
Cell[23821, 619, 198, 5, 33, "MathCaption"],

Cell[CellGroupData[{
Cell[24044, 628, 223, 4, 42, "Input"],
Cell[24270, 634, 82, 2, 32, "Output"]
}, Open  ]],
Cell[24367, 639, 131, 3, 28, "MathCaption"],

Cell[CellGroupData[{
Cell[24523, 646, 223, 4, 42, "Input"],
Cell[24749, 652, 318, 5, 43, "Message"],
Cell[25070, 659, 145, 3, 39, "Output"]
}, Open  ]],
Cell[25230, 665, 97, 3, 28, "MathCaption"],

Cell[CellGroupData[{
Cell[25352, 672, 1018, 19, 81, "Input"],
Cell[26373, 693, 337, 5, 43, "Message"],
Cell[26713, 700, 337, 5, 43, "Message"],
Cell[27053, 707, 769, 15, 59, "Output"]
}, Open  ]],
Cell[27837, 725, 283, 6, 37, "DefinitionBox",
  CellTags->"YLinkedLoci"],
Cell[28123, 733, 70, 0, 28, "MathCaption"],

Cell[CellGroupData[{
Cell[28218, 737, 1329, 23, 104, "Input"],
Cell[29550, 762, 300, 5, 43, "Message"],
Cell[29853, 769, 319, 5, 43, "Message"],
Cell[30175, 776, 319, 5, 43, "Message"],
Cell[30497, 783, 237, 4, 35, "Message"],
Cell[30737, 789, 1016, 20, 81, "Output"]
}, Open  ]],
Cell[31768, 812, 283, 6, 37, "DefinitionBox",
  CellTags->"XLinkedLoci"],
Cell[32054, 820, 82, 1, 28, "MathCaption"],

Cell[CellGroupData[{
Cell[32161, 825, 1330, 23, 104, "Input"],
Cell[33494, 850, 306, 5, 27, "Message"],
Cell[33803, 857, 1804, 30, 91, "Output"]
}, Open  ]],
Cell[35622, 890, 347, 6, 36, "Text"],
Cell[35972, 898, 243, 7, 24, "Text"],
Cell[36218, 907, 346, 6, 52, "DefinitionBox",
  CellTags->{"ZLinkedLoci", "WLinkedLoci"}],
Cell[36567, 915, 61, 0, 22, "Text"],

Cell[CellGroupData[{
Cell[36653, 919, 1330, 23, 104, "Input"],
Cell[37986, 944, 307, 5, 27, "Message"],
Cell[38296, 951, 1848, 33, 91, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[40181, 989, 1330, 23, 104, "Input"],
Cell[41514, 1014, 299, 5, 43, "Message"],
Cell[41816, 1021, 318, 5, 43, "Message"],
Cell[42137, 1028, 318, 5, 43, "Message"],
Cell[42458, 1035, 238, 4, 35, "Message"],
Cell[42699, 1041, 987, 18, 81, "Output"]
}, Open  ]],
Cell[43701, 1062, 83, 1, 28, "MathCaption"],

Cell[CellGroupData[{
Cell[43809, 1067, 261, 4, 42, "Input"],
Cell[44073, 1073, 212, 4, 20, "Message"],
Cell[44288, 1079, 212, 4, 20, "Message"],
Cell[44503, 1085, 146, 3, 39, "Output"]
}, Open  ]]
}, Open  ]]
}
]
*)




(***********************************************************************
End of Mathematica Notebook file.
***********************************************************************)

