(***********************************************************************

                    Mathematica-Compatible Notebook

This notebook can be used on any computer system with Mathematica 4.0,
MathReader 4.0, or any compatible application. The data for the notebook 
starts with the line containing stars above.

To get the notebook into a Mathematica-compatible application, do one of 
the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing the 
word CacheID, otherwise Mathematica-compatible applications may try to 
use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
***********************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[     28624,        709]*)
(*NotebookOutlinePosition[    100695,       3305]*)
(*  CellTagsIndexPosition[    100488,       3295]*)
(*WindowFrame->Normal*)



Notebook[{

Cell[CellGroupData[{
Cell["Stabilising selection", "SubsectionIcon"],

Cell[CellGroupData[{

Cell["Preparation....", "SubsubsectionIcon"],

Cell["This loads the package:", "MathCaption"],

Cell[BoxData[
    \(\(<< Multilocus`Multilocus`;\)\)], "Input",
  CellLabel->"In[1]:="],

Cell["The simplest diploid life cycle is defined using:", "MathCaption"],

Cell[BoxData[{
    \(\(DefineContext[\[GothicCapitalG], {\ 
          Sex}];\)\), "\[IndentingNewLine]", 
    \(\(DefineContext[\[GothicCapitalZ], {Sex, SexOfOrigin}];\)\), "\n", 
    \(\(DefineContext[\[GothicCapitalA], {Sex, 
          SexOfOrigin}];\)\), "\[IndentingNewLine]", 
    \(\(DefineContext[\(\[GothicCapitalG]\^*\), {\ Sex}];\)\)}], "Input",
  CellLabel->"In[2]:="]
}, Open  ]],

Cell[CellGroupData[{

Cell["Defining fitness", "SubsubsectionIcon",
  CellTags->"Defining fitness"],

Cell[TextData[{
  "Suppose that there is quadratic stabilising selection of strength ",
  Cell[BoxData[
      \(TraditionalForm\`s\)]],
  "  on an additive trait, ",
  Cell[BoxData[
      \(TraditionalForm\`Z, \ with\ optimum\ Z\_opt\)]],
  ".  "
}], "Text"],

Cell[TextData[{
  "The effect of locus ",
  Cell[BoxData[
      \(TraditionalForm\`i\)]],
  "  on the trait is ",
  Cell[BoxData[
      \(TraditionalForm\`b\_i\)]],
  ":"
}], "MathCaption"],

Cell[BoxData[{
    \(\(Z\_sex_ := \[Sum]\+\(i \[Element] Union[\[Gamma][\
\[DoubleStruckCapitalW]\_sex]]\)\(b\_i\) \((X\_\(i\_{\[GothicCapitalZ], sex, \
\[GothicCapitalM]}\) + 
                X\_\(i\_{\[GothicCapitalZ], sex, \[GothicCapitalF]}\) - 
                1)\);\)\), "\[IndentingNewLine]", 
    \(W\_sex_ := 1 - \(s\/2\) \((Z\_sex - Zopt)\)\^2\)}], "Input",
  CellLabel->"In[6]:="],

Cell[TextData[{
  "The trait value, ",
  Cell[BoxData[
      \(TraditionalForm\`Z\)]],
  ", is written as a sum over the set of selected genes, \[Gamma][",
  Cell[BoxData[
      \(\[DoubleStruckCapitalW]\_\[GothicCapitalM]\)]],
  "].  (\[Gamma][",
  Cell[BoxData[
      \(\[DoubleStruckCapitalW]\_\[GothicCapitalM]\)]],
  "] denotes the set of ",
  StyleBox["genes",
    FontSlant->"Italic"],
  "; ",
  Cell[BoxData[
      \(TraditionalForm\`\[DoubleStruckCapitalW]\_\[GothicCapitalM]\)]],
  "is the set of selected ",
  StyleBox["genes-in-context",
    FontSlant->"Italic"],
  ")"
}], "Text"],

Cell["\<\
Although some functions, such as \[LeftAngleBracket] \
\[RightAngleBracket], can deal with sums over unspecified sets of loci, that \
is not possible in general.  However, it is usually possible to find the \
general expression by inspection of particular cases.\
\>", "Text"],

Cell[TextData[{
  "To make progress, we specify that the trait depends on maternal and \
paternal copies of two loci, ",
  Cell[BoxData[
      \(TraditionalForm\`{j, k}\)]],
  ":"
}], "MathCaption"],

Cell[BoxData[
    \(\(\[DoubleStruckCapitalW]\_sex_ := {j\_{\[GothicCapitalZ], sex, \
\[GothicCapitalM]}, j\_{\[GothicCapitalZ], sex, \[GothicCapitalF]}, 
          k\_{\[GothicCapitalZ], sex, \[GothicCapitalM]}, 
          k\_{\[GothicCapitalZ], sex, \[GothicCapitalF]}};\)\)], "Input",
  CellLabel->"In[8]:="],

Cell["\<\
The fitness is now an explicit polynomial function of the states of \
genes in zygotes:\
\>", "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[
    \(W\_\[GothicCapitalM]\)], "Input",
  CellLabel->"In[9]:="],

Cell[BoxData[
    \(1 - 
      1\/2\ s\ \((\(-Zopt\) + \((\(-1\) + X\_\(j\_{\[GothicCapitalZ], \
\[GothicCapitalM], \[GothicCapitalF]}\) + X\_\(j\_{\[GothicCapitalZ], \
\[GothicCapitalM], \[GothicCapitalM]}\))\)\ b\_j + \((\(-1\) + X\_\(k\_{\
\[GothicCapitalZ], \[GothicCapitalM], \[GothicCapitalF]}\) + X\_\(k\_{\
\[GothicCapitalZ], \[GothicCapitalM], \[GothicCapitalM]}\))\)\ b\_k)\)\^2\)], \
"Output",
  CellLabel->"Out[9]="]
}, Open  ]],

Cell["\<\
Since we assume two alleles per locus, the fitness must be \
simplified to remove superfluous higher powers:\
\>", "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(W2\_sex_ := \(W2\_sex = Expand[W\_sex] //. Biallelic[]\);\)\), "\n", 
    \(W2\_\[GothicCapitalM] // Simplify\)}], "Input",
  CellLabel->"In[10]:="],

Cell[BoxData[
    \(1\/2\ \((2 - s\ Zopt\^2 + 
          s\ \((\(-1\) + 
                X\_\(j\_{\[GothicCapitalZ], \[GothicCapitalM], \
\[GothicCapitalF]}\)\ \((1 - 
                      2\ X\_\(j\_{\[GothicCapitalZ], \[GothicCapitalM], \
\[GothicCapitalM]}\))\) + 
                X\_\(j\_{\[GothicCapitalZ], \[GothicCapitalM], \
\[GothicCapitalM]}\))\)\ b\_j\%2 + 
          2\ s\ Zopt\ \((\(-1\) + 
                X\_\(k\_{\[GothicCapitalZ], \[GothicCapitalM], \
\[GothicCapitalF]}\) + 
                X\_\(k\_{\[GothicCapitalZ], \[GothicCapitalM], \
\[GothicCapitalM]}\))\)\ b\_k + 
          s\ \((\(-1\) + 
                X\_\(k\_{\[GothicCapitalZ], \[GothicCapitalM], \
\[GothicCapitalF]}\)\ \((1 - 
                      2\ X\_\(k\_{\[GothicCapitalZ], \[GothicCapitalM], \
\[GothicCapitalM]}\))\) + 
                X\_\(k\_{\[GothicCapitalZ], \[GothicCapitalM], \
\[GothicCapitalM]}\))\)\ b\_k\%2 + 
          2\ s\ \((\(-1\) + 
                X\_\(j\_{\[GothicCapitalZ], \[GothicCapitalM], \
\[GothicCapitalF]}\) + 
                X\_\(j\_{\[GothicCapitalZ], \[GothicCapitalM], \
\[GothicCapitalM]}\))\)\ b\_j\ \((Zopt - \((\(-1\) + 
                      X\_\(k\_{\[GothicCapitalZ], \[GothicCapitalM], \
\[GothicCapitalF]}\) + 
                      X\_\(k\_{\[GothicCapitalZ], \[GothicCapitalM], \
\[GothicCapitalM]}\))\)\ b\_k)\))\)\)], "Output",
  CellLabel->"Out[11]="]
}, Open  ]],

Cell["\<\
It is convenient to define the trait and fitness separately for \
each sex, even though they are in fact the same.  The expressions can be \
simplified later.\
\>", "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Rules for random union, selection and recombination", \
"SubsubsectionIcon",
  CellTags->"Rules"],

Cell["\<\
As in the previous section, define rules connecting the different \
stages of the life cycle, and defining reference points:\
\>", "MathCaption"],

Cell[BoxData[
    \(\(rules = \((Recombination[{\[GothicCapitalA], \
\(\[GothicCapitalG]\^*\)}, 
              RecombinationRate]\[Vee]SymmetricRecombination[]\[Vee]\
ReferencePointSame[\[GothicCapitalG], {\[GothicCapitalA], \[GothicCapitalZ]}]\
\[Vee]ReferencePointZero[{\(\[GothicCapitalG]\^*\), \
\[GothicCapitalG]}]\[Vee]Selection[{Sex}]\[Vee]UnionOfGametes[{\
\[GothicCapitalG], \[GothicCapitalZ]}]\[Vee]RandomUnion[\[GothicCapitalG]]\
\[Vee]Symmetrise[Disequilibrium]\[Vee]SymmetricSexes[])\);\)\)], "Input",
  CellLabel->"In[12]:="],

Cell[TextData[{
  "The mean contributions in the two sexes are assumed equal, as have all the \
linkage disequilibria; thus, SymmetricSexes[] is applied.  Symmetrise[] \
simplifies ",
  Cell[BoxData[
      \(TraditionalForm\`\[GothicCapitalD]\_\(\({\[DoubleStruckK], \
\[DoubleStruckJ]}\)\(\ \)\)\ to\ \(\(\[GothicCapitalD]\_{\[DoubleStruckJ], \
\[DoubleStruckK]}\)\(.\)\)\)]],
  " "
}], "Text"],

Cell[TextData[{
  "Note: ",
  StyleBox[" SymmetricSexes[] applies even when it makes no change, and so ",
    FontWeight->"Plain"],
  ButtonBox["blocks",
    ButtonData:>{"Bugs", "Applying rules"},
    ButtonStyle->"AddOnsLink"],
  StyleBox[" application of other rules.  Thus, it has to go at the end.",
    FontWeight->"Plain"]
}], "Text",
  FontWeight->"Bold"]
}, Open  ]],

Cell[CellGroupData[{

Cell["The new mean", "SubsubsectionIcon",
  CellTags->"New mean"],

Cell["\<\
The new mean depends on selection coefficients up to fourth \
order:\
\>", "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[
    \(nm = \[GothicM]\_\(j\_{\(\[GothicCapitalG]\^*\), \[GothicCapitalM]}\) //. 
          rules // Simplify\)], "Input",
  CellLabel->"In[13]:="],

Cell[BoxData[
    \(1\/2\ \((2\ \[GothicM]\_\(j\_{\[GothicCapitalG], \[GothicCapitalF]}\) + \
\[GothicCapitalD]\_{j\_{\[GothicCapitalG], \[GothicCapitalF]}, k\_{\
\[GothicCapitalG], \[GothicCapitalF]}}\ \[GothicA]\_\(\[GothicCapitalM], \
{k\_{\[GothicCapitalZ], \[GothicCapitalM], \[GothicCapitalF]}}\) + \
\[GothicCapitalD]\_{j\_{\[GothicCapitalG], \[GothicCapitalF]}, k\_{\
\[GothicCapitalG], \[GothicCapitalF]}}\ \[GothicA]\_\(\[GothicCapitalM], \
{k\_{\[GothicCapitalZ], \[GothicCapitalM], \[GothicCapitalM]}}\) + \
\[GothicCapitalD]\_{j\_{\[GothicCapitalG], \[GothicCapitalF]}, j\_{\
\[GothicCapitalG], \[GothicCapitalF]}, k\_{\[GothicCapitalG], \
\[GothicCapitalF]}}\ \[GothicA]\_\(\[GothicCapitalM], {j\_{\[GothicCapitalZ], \
\[GothicCapitalM], \[GothicCapitalF]}, k\_{\[GothicCapitalZ], \
\[GothicCapitalM], \[GothicCapitalF]}}\) + \[GothicCapitalD]\_{j\_{\
\[GothicCapitalG], \[GothicCapitalF]}, j\_{\[GothicCapitalG], \
\[GothicCapitalF]}, k\_{\[GothicCapitalG], \[GothicCapitalF]}}\ \
\[GothicA]\_\(\[GothicCapitalM], {j\_{\[GothicCapitalZ], \[GothicCapitalM], \
\[GothicCapitalM]}, k\_{\[GothicCapitalZ], \[GothicCapitalM], \
\[GothicCapitalM]}}\) + \[GothicCapitalD]\_{j\_{\[GothicCapitalG], \
\[GothicCapitalF]}, j\_{\[GothicCapitalG], \[GothicCapitalF]}}\ \((\[GothicA]\
\_\(\[GothicCapitalM], {j\_{\[GothicCapitalZ], \[GothicCapitalM], \
\[GothicCapitalF]}}\) + \[GothicA]\_\(\[GothicCapitalM], {j\_{\
\[GothicCapitalZ], \[GothicCapitalM], \[GothicCapitalM]}}\) + \
\[GothicCapitalD]\_{j\_{\[GothicCapitalG], \[GothicCapitalF]}, k\_{\
\[GothicCapitalG], \[GothicCapitalF]}}\ \((\[GothicA]\_\(\[GothicCapitalM], \
{j\_{\[GothicCapitalZ], \[GothicCapitalM], \[GothicCapitalF]}, j\_{\
\[GothicCapitalZ], \[GothicCapitalM], \[GothicCapitalM]}, k\_{\
\[GothicCapitalZ], \[GothicCapitalM], \[GothicCapitalF]}}\) + \[GothicA]\_\(\
\[GothicCapitalM], {j\_{\[GothicCapitalZ], \[GothicCapitalM], \
\[GothicCapitalF]}, j\_{\[GothicCapitalZ], \[GothicCapitalM], \
\[GothicCapitalM]}, k\_{\[GothicCapitalZ], \[GothicCapitalM], \
\[GothicCapitalM]}}\))\))\) + \[GothicCapitalD]\_{j\_{\[GothicCapitalG], \
\[GothicCapitalF]}, k\_{\[GothicCapitalG], \[GothicCapitalF]}}\%2\ \[GothicA]\
\_\(\[GothicCapitalM], {j\_{\[GothicCapitalZ], \[GothicCapitalM], \
\[GothicCapitalF]}, k\_{\[GothicCapitalZ], \[GothicCapitalM], \
\[GothicCapitalF]}, k\_{\[GothicCapitalZ], \[GothicCapitalM], \
\[GothicCapitalM]}}\) + \[GothicCapitalD]\_{j\_{\[GothicCapitalG], \
\[GothicCapitalF]}, k\_{\[GothicCapitalG], \[GothicCapitalF]}}\%2\ \[GothicA]\
\_\(\[GothicCapitalM], {j\_{\[GothicCapitalZ], \[GothicCapitalM], \
\[GothicCapitalM]}, k\_{\[GothicCapitalZ], \[GothicCapitalM], \
\[GothicCapitalF]}, k\_{\[GothicCapitalZ], \[GothicCapitalM], \
\[GothicCapitalM]}}\) + 
          2\ \[GothicCapitalD]\_{j\_{\[GothicCapitalG], \[GothicCapitalF]}, k\
\_{\[GothicCapitalG], \[GothicCapitalF]}}\ \[GothicCapitalD]\_{j\_{\
\[GothicCapitalG], \[GothicCapitalF]}, j\_{\[GothicCapitalG], \
\[GothicCapitalF]}, k\_{\[GothicCapitalG], \[GothicCapitalF]}}\ \
\[GothicA]\_\(\[GothicCapitalM], {j\_{\[GothicCapitalZ], \[GothicCapitalM], \
\[GothicCapitalF]}, j\_{\[GothicCapitalZ], \[GothicCapitalM], \
\[GothicCapitalM]}, k\_{\[GothicCapitalZ], \[GothicCapitalM], \
\[GothicCapitalF]}, k\_{\[GothicCapitalZ], \[GothicCapitalM], \
\[GothicCapitalM]}}\))\)\)], "Output",
  CellLabel->"Out[13]="]
}, Open  ]],

Cell["\<\
We now substitute in the selection coefficients for this specific \
scheme:\
\>", "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[
    \(nms = \(nm //. {\[GothicA]\_\(sex_, \[DoubleStruckCapitalU]_\) \
\[RuleDelayed] \((MakeSelectionCoefficient[\[DoubleStruckCapitalU], W2\_sex]/
                      wb)\)}\[Vee]Biallelic[
                MeanContribution]\[Vee]rules\) /. {\[GothicM]\_\
\[DoubleStruckI]_ \[Rule] \[GothicP]\_\[DoubleStruckI]} // 
        Simplify\)], "Input",
  CellLabel->"In[14]:="],

Cell[BoxData[
    \(\[GothicP]\_\(j\_{\[GothicCapitalG], \[GothicCapitalF]}\) + 
      s\/\(\(\ \)\(wb\)\)\ \((\ \(b\_j\) \((1 - \[GothicP]\_\(j\_{\
\[GothicCapitalG], \[GothicCapitalF]}\))\)\ \[GothicP]\_\(j\_{\
\[GothicCapitalG], \[GothicCapitalF]}\)\ \((\ 
                Zopt + \(1\/2\) \((1 - 
                        2\ \[GothicP]\_\(j\_{\[GothicCapitalG], \
\[GothicCapitalF]}\))\)\ b\_j + \ \((1 - 
                        2\ \[GothicP]\_\(k\_{\[GothicCapitalG], \
\[GothicCapitalF]}\))\)\ b\_k)\) + \[GothicCapitalD]\_{j\_{\[GothicCapitalG], \
\[GothicCapitalF]}, k\_{\[GothicCapitalG], \[GothicCapitalF]}}\ b\_k\ \((\ 
                Zopt + \(1\/2\) \((1 - 
                        2\ \[GothicP]\_\(k\_{\[GothicCapitalG], \
\[GothicCapitalF]}\))\)\ b\_k)\))\)\)], "Output",
  CellLabel->"Out[50]=  (13:55:11 on 3/21/01)"]
}, Open  ]],

Cell["\<\
This is the sum of two terms: one due to direct selection, the \
other to linkage disequilibrium.\
\>", "Text"],

Cell[TextData[{
  "Biallelic[MeanContribution] implements the assumption of two alleles.  \
Rather than writing the result in terms of allele frequencies, \[GothicP], at \
this stage, they are left in terms of MeanContribution (represented as \
\[GothicM]).  Applying the ",
  StyleBox["rules",
    FontSlant->"Italic"],
  " then simplifies these further, by writing ",
  Cell[BoxData[
      \(TraditionalForm\`\(\[GothicM]\_\(\(i\_{\[GothicCapitalG], \
\[GothicCapitalM]}\)\(\ \)\)\) 
        as\ \[GothicM]\_\(i\_{\[GothicCapitalG], \[GothicCapitalF]}\)\)]],
  "the means \[GothicM] are rewritten as allele frequencies, \[GothicP].  \
Mean fitness, wb, is left for the moment, to save unnecessary calculation.  \
At the end, the notation is changed by ",
  Cell[BoxData[
      \({\[GothicM]\_\[DoubleStruckI]_ \[Rule] \
\[GothicP]\_\[DoubleStruckI]}\)]],
  "."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
The change in \[GothicCapitalD] under weak selection\
\>", \
"SubsubsectionIcon",
  CellTags->"Change in D"],

Cell["\<\
Calculating the selection coefficients for this specific \
scheme:\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(nds = \(\[GothicCapitalD]\_{j\_{\(\[GothicCapitalG]\^*\), \
\[GothicCapitalM]}, k\_{\(\[GothicCapitalG]\^*\), \[GothicCapitalM]}} //. {\
\[GothicA]\_\(sex_, \[DoubleStruckCapitalU]_\) \[RuleDelayed] \
\((MakeSelectionCoefficient[\[DoubleStruckCapitalU], W2\_sex]/
                      wb)\)}\[Vee]Biallelic[
                MeanContribution]\[Vee]rules\) /. {\[GothicM]\_\
\[DoubleStruckI]_ \[Rule] \[GothicP]\_\[DoubleStruckI]} // 
        Simplify\)], "Input",
  CellLabel->"In[16]:="],

Cell[BoxData[
    \(\(\(1\/\(2\ wb\^2\)\)\((s\ \[GothicR]\_\({j}, {k}\)\ \((4\ wb\ \
\((\(-1\) + \[GothicP]\_\(j\_{\[GothicCapitalG], \[GothicCapitalF]}\))\)\ \
\[GothicP]\_\(j\_{\[GothicCapitalG], \[GothicCapitalF]}\)\ \
\[GothicCapitalD]\_{j\_{\[GothicCapitalG], \[GothicCapitalF]}, k\_{\
\[GothicCapitalG], \[GothicCapitalF]}}\ b\_j\%2 - 
              4\ wb\ \((\(-1\) + \[GothicP]\_\(j\_{\[GothicCapitalG], \
\[GothicCapitalF]}\))\)\ \[GothicP]\_\(j\_{\[GothicCapitalG], \
\[GothicCapitalF]}\)\ \((\(-1\) + \[GothicP]\_\(k\_{\[GothicCapitalG], \
\[GothicCapitalF]}\))\)\ \[GothicP]\_\(k\_{\[GothicCapitalG], \
\[GothicCapitalF]}\)\ b\_j\ b\_k - 
              4\ wb\ \[GothicCapitalD]\_{j\_{\[GothicCapitalG], \
\[GothicCapitalF]}, k\_{\[GothicCapitalG], \[GothicCapitalF]}}\%2\ b\_j\ b\_k \
+ 4\ wb\ \((\(-1\) + \[GothicP]\_\(k\_{\[GothicCapitalG], \
\[GothicCapitalF]}\))\)\ \[GothicP]\_\(k\_{\[GothicCapitalG], \
\[GothicCapitalF]}\)\ \[GothicCapitalD]\_{j\_{\[GothicCapitalG], \
\[GothicCapitalF]}, k\_{\[GothicCapitalG], \[GothicCapitalF]}}\ b\_k\%2 - 
              s\ \((\[GothicCapitalD]\_{j\_{\[GothicCapitalG], \
\[GothicCapitalF]}, k\_{\[GothicCapitalG], \[GothicCapitalF]}}\ b\_j\ \((2\ \
Zopt + \((1 - 
                                2\ \[GothicP]\_\(j\_{\[GothicCapitalG], \
\[GothicCapitalF]}\))\)\ b\_j)\) - \((\(-1\) + \[GothicP]\_\(k\_{\
\[GothicCapitalG], \[GothicCapitalF]}\))\)\ \[GothicP]\_\(k\_{\
\[GothicCapitalG], \[GothicCapitalF]}\)\ b\_k\ \((2\ Zopt + \((2 - 
                                4\ \[GothicP]\_\(j\_{\[GothicCapitalG], \
\[GothicCapitalF]}\))\)\ b\_j + \((1 - 
                                2\ \[GothicP]\_\(k\_{\[GothicCapitalG], \
\[GothicCapitalF]}\))\)\ b\_k)\))\)\ \((2\ \[GothicP]\_j\_{\[GothicCapitalG], \
\[GothicCapitalF]}\%3\ b\_j\%2 + \[GothicCapitalD]\_{j\_{\[GothicCapitalG], \
\[GothicCapitalF]}, k\_{\[GothicCapitalG], \[GothicCapitalF]}}\ b\_k\ \((2\ \
Zopt + \((1 - 
                                2\ \[GothicP]\_\(k\_{\[GothicCapitalG], \
\[GothicCapitalF]}\))\)\ b\_k)\) + \[GothicP]\_\(j\_{\[GothicCapitalG], \
\[GothicCapitalF]}\)\ b\_j\ \((b\_j + 
                          2\ \((Zopt + b\_k - 
                                2\ \[GothicP]\_\(k\_{\[GothicCapitalG], \
\[GothicCapitalF]}\)\ b\_k)\))\) - \[GothicP]\_j\_{\[GothicCapitalG], \
\[GothicCapitalF]}\%2\ b\_j\ \((3\ b\_j + 
                          2\ \((Zopt + b\_k - 
                                2\ \[GothicP]\_\(k\_{\[GothicCapitalG], \
\[GothicCapitalF]}\)\ b\_k)\))\))\))\))\)\) + 
      2\ \[GothicR]\_\({}, {j, k}\)\ \((\[GothicCapitalD]\_{j\_{\
\[GothicCapitalG], \[GothicCapitalF]}, k\_{\[GothicCapitalG], \
\[GothicCapitalF]}} - \(s\ \((\((\(-1\) + \
\[GothicP]\_\(j\_{\[GothicCapitalG], \[GothicCapitalF]}\))\)\ \[GothicP]\_\(j\
\_{\[GothicCapitalG], \[GothicCapitalF]}\)\ \((\(-1\) + \[GothicP]\_\(k\_{\
\[GothicCapitalG], \[GothicCapitalF]}\))\)\ \[GothicP]\_\(k\_{\
\[GothicCapitalG], \[GothicCapitalF]}\) + \((\(-1\) + 2\ \[GothicP]\_\(j\_{\
\[GothicCapitalG], \[GothicCapitalF]}\))\)\ \((\(-1\) + 2\ \[GothicP]\_\(k\_{\
\[GothicCapitalG], \[GothicCapitalF]}\))\)\ \[GothicCapitalD]\_{j\_{\
\[GothicCapitalG], \[GothicCapitalF]}, k\_{\[GothicCapitalG], \
\[GothicCapitalF]}} - \[GothicCapitalD]\_{j\_{\[GothicCapitalG], \
\[GothicCapitalF]}, k\_{\[GothicCapitalG], \[GothicCapitalF]}}\%2)\)\ b\_j\ b\
\_k\)\/wb + \(s\ \((\(-1\) + 2\ \[GothicP]\_\(k\_{\[GothicCapitalG], \
\[GothicCapitalF]}\))\)\ \[GothicCapitalD]\_{j\_{\[GothicCapitalG], \
\[GothicCapitalF]}, k\_{\[GothicCapitalG], \[GothicCapitalF]}}\ b\_k\ \((\(-2\
\)\ Zopt + \((\(-2\) + 4\ \[GothicP]\_\(j\_{\[GothicCapitalG], \
\[GothicCapitalF]}\))\)\ b\_j + \((\(-1\) + 2\ \[GothicP]\_\(k\_{\
\[GothicCapitalG], \[GothicCapitalF]}\))\)\ b\_k)\)\)\/\(2\ wb\) + \(s\ \
\((\(-1\) + 2\ \[GothicP]\_\(j\_{\[GothicCapitalG], \[GothicCapitalF]}\))\)\ \
\[GothicCapitalD]\_{j\_{\[GothicCapitalG], \[GothicCapitalF]}, k\_{\
\[GothicCapitalG], \[GothicCapitalF]}}\ b\_j\ \((\((\(-1\) + 2\ \
\[GothicP]\_\(j\_{\[GothicCapitalG], \[GothicCapitalF]}\))\)\ b\_j - 2\ \
\((Zopt + \((1 - 2\ \[GothicP]\_\(k\_{\[GothicCapitalG], \
\[GothicCapitalF]}\))\)\ b\_k)\))\)\)\/\(2\ wb\) - \(\(1\/\(4\ \
wb\^2\)\)\((s\^2\ \((\[GothicCapitalD]\_{j\_{\[GothicCapitalG], \
\[GothicCapitalF]}, k\_{\[GothicCapitalG], \[GothicCapitalF]}}\ b\_j\ \((2\ \
Zopt + \((1 - 
                                2\ \[GothicP]\_\(j\_{\[GothicCapitalG], \
\[GothicCapitalF]}\))\)\ b\_j)\) - \((\(-1\) + \[GothicP]\_\(k\_{\
\[GothicCapitalG], \[GothicCapitalF]}\))\)\ \[GothicP]\_\(k\_{\
\[GothicCapitalG], \[GothicCapitalF]}\)\ b\_k\ \((2\ Zopt + \((2 - 
                                4\ \[GothicP]\_\(j\_{\[GothicCapitalG], \
\[GothicCapitalF]}\))\)\ b\_j + \((1 - 
                                2\ \[GothicP]\_\(k\_{\[GothicCapitalG], \
\[GothicCapitalF]}\))\)\ b\_k)\))\)\ \((2\ \[GothicP]\_j\_{\[GothicCapitalG], \
\[GothicCapitalF]}\%3\ b\_j\%2 + \[GothicCapitalD]\_{j\_{\[GothicCapitalG], \
\[GothicCapitalF]}, k\_{\[GothicCapitalG], \[GothicCapitalF]}}\ b\_k\ \((2\ \
Zopt + \((1 - 
                                2\ \[GothicP]\_\(k\_{\[GothicCapitalG], \
\[GothicCapitalF]}\))\)\ b\_k)\) + \[GothicP]\_\(j\_{\[GothicCapitalG], \
\[GothicCapitalF]}\)\ b\_j\ \((b\_j + 
                          2\ \((Zopt + b\_k - 
                                2\ \[GothicP]\_\(k\_{\[GothicCapitalG], \
\[GothicCapitalF]}\)\ b\_k)\))\) - \[GothicP]\_j\_{\[GothicCapitalG], \
\[GothicCapitalF]}\%2\ b\_j\ \((3\ b\_j + 
                          2\ \((Zopt + b\_k - 
                                2\ \[GothicP]\_\(k\_{\[GothicCapitalG], \
\[GothicCapitalF]}\)\ b\_k)\))\))\))\)\))\)\)], "Output",
  CellLabel->"Out[16]="]
}, Closed]],

Cell["Assuming weak selection:", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(ndsbw = 
      SlowChange[\(nds - \((1 - 
                      r)\) \[GothicCapitalD]\_{j\_{\[GothicCapitalG], \
\[GothicCapitalF]}, k\_{\[GothicCapitalG], \[GothicCapitalF]}} /. {\[GothicR]\
\_\({}, {j, k}\) \[Rule] \((1 - r)\)\/2, \[GothicR]\_\({j}, {k}\) \[Rule] 
                  r\/2}\) /. wb -> wbar, s, 1] // Simplify\)], "Input",
  CellLabel->"In[17]:="],

Cell[BoxData[
    \(s\ \((\(-\[GothicP]\_\(j\_{\[GothicCapitalG], \[GothicCapitalF]}\)\) \
\((1 - \[GothicP]\_\(j\_{\[GothicCapitalG], \[GothicCapitalF]}\))\)\
\ \ \[GothicP]\_\(k\_{\[GothicCapitalG], \[GothicCapitalF]}\)\ \((1 - \
\[GothicP]\_\(k\_{\[GothicCapitalG], \[GothicCapitalF]}\))\)\ \[Alpha]\_j\ \
\[Alpha]\_k + \[GothicCapitalD]\_{j\_{\[GothicCapitalG], \[GothicCapitalF]}, \
k\_{\[GothicCapitalG], \[GothicCapitalF]}}\ \((\((1 - 
                      r)\)\ Zopt \((\[Alpha]\_j\ \((1 - 
                            2\ \[GothicP]\_\(j\_{\[GothicCapitalG], \
\[GothicCapitalF]}\))\) + \(\[Alpha]\_k\) \((1 - 
                            2\ \[GothicP]\_\(k\_{\[GothicCapitalG], \
\[GothicCapitalF]}\))\))\) + \((\(1 - r\)\/2 - \ \((2 - 
                            r)\)\ \(\[GothicP]\_\(j\_{\[GothicCapitalG], \
\[GothicCapitalF]}\)\) \((1 - \[GothicP]\_\(j\_{\[GothicCapitalG], \
\[GothicCapitalF]}\))\)\ )\)\ \[Alpha]\_j\%2 + \((\(1 - r\)\/2 - \((2 - 
                            r)\)\ \(\[GothicP]\_\(k\_{\[GothicCapitalG], \
\[GothicCapitalF]}\)\) \((1 - \ \[GothicP]\_\(k\_{\[GothicCapitalG], \
\[GothicCapitalF]}\))\))\)\ \[Alpha]\_k\%2 + \((1 - r)\)\ \((1 - 
                      2\ \[GothicP]\_\(j\_{\[GothicCapitalG], \
\[GothicCapitalF]}\))\)\ \((1 - 
                      2\ \[GothicP]\_\(k\_{\[GothicCapitalG], \
\[GothicCapitalF]}\))\)\ \(\[Alpha]\_j\) \[Alpha]\_k)\) + \ \((1 - 
                2\ r)\)\ \[Alpha]\_j\ \(\[Alpha]\_k\) \
\[GothicCapitalD]\_{j\_{\[GothicCapitalG], \[GothicCapitalF]}, k\_{\
\[GothicCapitalG], \[GothicCapitalF]}}\%2)\)\)], "Output",
  CellLabel->"Out[14]=  (14:53:04 on 3/21/01)"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Comparison with Kirkpatrick et al.", "SubsubsectionIcon"],

Cell[TextData[{
  "The directional selection coefficient is given in ",
  ButtonBox["Eq. 39",
    ButtonData:>{"Multilocus MS", "aiForTwoLoci"},
    ButtonStyle->"AddOnsLink"],
  " as:"
}], "MathCaption"],

Cell[TextData[Cell[BoxData[
    \(TraditionalForm\`\(\(\[IndentingNewLine]\)\(a\_\[DoubleStruckI]\ \ \  \
\[TildeTilde] \ \ \ \(-\ 
            b\_\[DoubleStruckI]\)\ Z\&_\/\(\(W\&_\) \[Omega]\^2\)\ \  + \ \ b\
\_\[DoubleStruckI]\%2\ 1\/\(2 \( W\&_\) \[Omega]\^2\)\ \(\((p\_\
\[DoubleStruckI]\  - \ 
                q\_\[DoubleStruckI])\)\(.\)\(\[IndentingNewLine]\)\)\)\)\)]]],\
 "NumberedEquation",
  CellMargins->{{18.1875, 24.375}, {Inherited, Inherited}},
  CellTags->"aiForTwoLoci"],

Cell["The corresponding selection coefficient here is:", "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(MakeSelectionCoefficient[{j\_{\[GothicCapitalZ], \[GothicCapitalM], \
\[GothicCapitalM]}}, W2\_\[GothicCapitalM]] //. 
        rules\) /. \[GothicM]\_\(i_\_{\[GothicCapitalG], \[GothicCapitalF]}\) \
\[Rule] \[GothicP]\_\(i\_{\[GothicCapitalG], \[GothicCapitalF]}\)\)], "Input",\

  CellLabel->"In[19]:="],

Cell[BoxData[
    \(s\ Zopt\ b\_j + \(s\ b\_j\%2\)\/2 - 
      s\ \[GothicP]\_\(j\_{\[GothicCapitalG], \[GothicCapitalF]}\)\ b\_j\%2 + 
      s\ b\_j\ b\_k - 
      2\ s\ \[GothicP]\_\(k\_{\[GothicCapitalG], \[GothicCapitalF]}\)\ b\_j\ \
b\_k\)], "Output",
  CellLabel->"Out[19]="]
}, Open  ]],

Cell[TextData[{
  "These correspond if one substitutes ",
  Cell[BoxData[
      \(TraditionalForm\`Z\_opt = 0, \ 
      Z\&_ = \(b\_j\)(
            2  \[GothicP]\_\(j\_{\[GothicCapitalG], \[GothicCapitalF]}\) - 
              1) + \(b\_k\)(
            2  \[GothicP]\_\(k\_{\[GothicCapitalG], \[GothicCapitalF]}\) - 
              1)\)]],
  ",  ",
  Cell[BoxData[
      \(TraditionalForm\`1\/\(\(W\&_\) \(\[Omega]\^2\)\(\ \)\) \[Rule] s\)]],
  "."
}], "Text"],

Cell[TextData[{
  "Note: ",
  StyleBox[" The coefficient ",
    FontWeight->"Plain"],
  Cell[BoxData[
      \(TraditionalForm\`1\/\[Omega]\^2\)]],
  StyleBox[" was not used here, because ",
    FontWeight->"Plain"],
  StyleBox["Mathematica",
    FontWeight->"Plain",
    FontSlant->"Italic"],
  StyleBox[" expects a polynomial fitness function. ",
    FontWeight->"Plain"]
}], "Text",
  FontWeight->"Bold"],

Cell[TextData[{
  "The epistatic selection coefficient is given in ",
  ButtonBox["Eq. 40",
    ButtonData:>{"Multilocus MS", "aijForTwoLoci"},
    ButtonStyle->"AddOnsLink"],
  " as:"
}], "MathCaption"],

Cell[BoxData[
    \(\(\(\[IndentingNewLine]\)\(a\_\[DoubleStruckI]\[DoubleStruckJ]\ \ \  = \
\ \ \ \(-\(1\/\(\(W\&_\) \[Omega]\^2\)\)\)\ b\_i\ \(\(b\_j\)\(\ \)\(.\)\(\
\[IndentingNewLine]\)\)\)\)\)], "Input"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(MakeSelectionCoefficient[{j\_{\[GothicCapitalZ], \[GothicCapitalM], \
\[GothicCapitalM]}, 
            k\_{\[GothicCapitalZ], \[GothicCapitalM], \[GothicCapitalF]}}, 
          W2\_\[GothicCapitalM]] //. 
        rules\) /. \[GothicM]\_\(i_\_{\[GothicCapitalG], \[GothicCapitalF]}\) \
\[Rule] \[GothicP]\_\(i\_{\[GothicCapitalG], \[GothicCapitalF]}\)\)], "Input",\

  CellLabel->"In[20]:="],

Cell[BoxData[
    \(\(-s\)\ b\_j\ b\_k\)], "Output",
  CellLabel->"Out[20]="]
}, Open  ]],

Cell["These correspond in the same way.", "Text"],

Cell[TextData[{
  "The change in allele frequency is given in ",
  ButtonBox["Eq. 41",
    ButtonData:>{"MultilocusMS.nb", "deltaPTwoLoci"},
    ButtonStyle->"Hyperlink"],
  " as:"
}], "MathCaption"],

Cell[BoxData[
    RowBox[{\(\[CapitalDelta]p\_\[DoubleStruckI]\), " ", "=", " ", 
      RowBox[{
        RowBox[{\(a\_\[DoubleStruckI]\), " ", 
          SubscriptBox[
            StyleBox["pq",
              FontSlant->"Italic"], "\[DoubleStruckI]"]}], "  ", "+", 
        " ", \(\[Sum]\+\(\[DoubleStruckJ] \[NotEqual] \[DoubleStruckI]\)\ \
\((a\_\[DoubleStruckJ]\  - \(a\_\[DoubleStruckI]\[DoubleStruckJ]\) \((p\_\
\[DoubleStruckI] - q\_\[DoubleStruckI])\))\) 
            D\_\[DoubleStruckI]\[DoubleStruckJ]\), "  ", 
        "+", \(\[Sum]\+\(\(\[DoubleStruckJ], \[DoubleStruckK] \[NotEqual] \
\[DoubleStruckI]\)\+\(\[DoubleStruckJ] < \[DoubleStruckK]\)\)\ \ a\_\
\[DoubleStruckJ]\[DoubleStruckK]\ D\_\[DoubleStruckI]\[DoubleStruckJ]\
\[DoubleStruckK]\)}]}]], "NumberedEquation"],

Cell[TextData[{
  "Here, we assume two loci in diploids, random mating (so that cross-genome \
associations are initially zero) and equivalent sexes. Substituting for the \
selection coefficients in terms of the ",
  Cell[BoxData[
      \(TraditionalForm\`b\_\[DoubleStruckI]\)]],
  ", setting ",
  Cell[BoxData[
      \(TraditionalForm\`Z\_opt = 0, \ 
      and\ substituting\ for\ the\ mean\ Z\&_\ \ as\)]],
  " above gives the same resul as produced by the packages."
}], "Text"]
}, Open  ]]
}, Open  ]]
},
FrontEndVersion->"4.0 for Macintosh",
ScreenRectangle->{{0, 1152}, {0, 748}},
AutoGeneratedPackage->None,
WindowSize->{917, 704},
WindowMargins->{{-2, Automatic}, {Automatic, 1}},
Visible->True,
InputAliases->{"notation"->RowBox[ {"Notation", "[", 
        RowBox[ {
          TagBox[ 
          "\[Placeholder]", NotationBoxTag, TagStyle -> 
            "NotationTemplateStyle"], " ", "\[DoubleLongLeftRightArrow]", " ",
           
          TagBox[ 
          "\[Placeholder]", NotationBoxTag, TagStyle -> 
            "NotationTemplateStyle"]}], "]"}], 
    "notation>"->RowBox[ {"Notation", "[", 
        RowBox[ {
          TagBox[ 
          "\[Placeholder]", NotationBoxTag, TagStyle -> 
            "NotationTemplateStyle"], " ", "\[DoubleLongRightArrow]", " ", 
          TagBox[ 
          "\[Placeholder]", NotationBoxTag, TagStyle -> 
            "NotationTemplateStyle"]}], "]"}], 
    "notation<"->RowBox[ {"Notation", "[", 
        RowBox[ {
          TagBox[ 
          "\[Placeholder]", NotationBoxTag, TagStyle -> 
            "NotationTemplateStyle"], " ", "\[DoubleLongLeftArrow]", " ", 
          TagBox[ 
          "\[Placeholder]", NotationBoxTag, TagStyle -> 
            "NotationTemplateStyle"]}], "]"}], 
    "symb"->RowBox[ {"Symbolize", "[", 
        TagBox[ 
        "\[Placeholder]", NotationBoxTag, TagStyle -> 
          "NotationTemplateStyle"], "]"}], 
    "infixnotation"->RowBox[ {"InfixNotation", "[", 
        RowBox[ {
          TagBox[ 
          "\[Placeholder]", NotationBoxTag, TagStyle -> 
            "NotationTemplateStyle"], ",", "\[Placeholder]"}], "]"}], 
    "addia"->RowBox[ {"AddInputAlias", "[", 
        RowBox[ {
          TagBox[ 
          "\[Placeholder]", NotationBoxTag, TagStyle -> 
            "NotationTemplateStyle"], ",", "\[Placeholder]"}], "]"}], 
    "pattwraper"->TagBox[ 
      "\[Placeholder]", NotationPatternTag, TagStyle -> 
        "NotationPatternWrapperStyle"], 
    "madeboxeswraper"->TagBox[ 
      "\[Placeholder]", NotationMadeBoxesTag, TagStyle -> 
        "NotationMadeBoxesWrapperStyle"]},
Magnification->1,
StyleDefinitions -> Notebook[{
  
  Cell[CellGroupData[{
  Cell["Style Definitions for On-line Help", "Subtitle"],
  
  Cell["\<\
These styles are carefully tuned for all aspects of the online \
help. It's recommended that they remain unchanged.\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell["Style Environment Names", "Subsubsection"],
  
  Cell[StyleData[All, "Working"],
    PageWidth->WindowWidth,
    ShowCellBracket->False,
    ShowAutoStyles->False,
    ScriptMinSize->9],
  
  Cell[StyleData[All, "Brackets"],
    PageWidth->WindowWidth,
    ShowAutoStyles->False,
    ScriptMinSize->9],
  
  Cell[StyleData[All, "Printout"],
    PageWidth->PaperWidth,
    ShowAutoStyles->False,
    ScriptMinSize->5,
    PrivateFontOptions->{"FontType"->"Outline"}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Notebook Options", "Subsubsection"],
  
  Cell["\<\
  The options defined for the style below will be used at the \
Notebook level.  \
\>", "Text"],
  
  Cell[StyleData["Notebook"],
    PageHeaders->{{Cell[ 
            TextData[ {
              CounterBox[ "Page"]}], "PageNumber"], None, Cell[ 
            TextData[ {"Printed from the ", 
              StyleBox[ "Mathematica", FontSlant -> "Italic"], 
              " Help Browser"}], "PageHeader"]}, {Cell[ 
            TextData[ {"Printed from the ", 
              StyleBox[ "Mathematica", FontSlant -> "Italic"], 
              " Help Browser"}], "PageHeader"], None, Cell[ 
            TextData[ {
              CounterBox[ "Page"]}], "PageNumber"]}},
    PageFooters->{{None, Cell[ 
            
            TextData[ {
              "\[Copyright]1999 Wolfram Research, Inc. All rights \
reserved."}], "PageFooter"], None}, {None, Cell[ 
            
            TextData[ {
              "\[Copyright]1999 Wolfram Research, Inc. All rights \
reserved."}], "PageFooter"], None}},
    PageHeaderLines->{True, True},
    PageFooterLines->{True, True},
    PrintingOptions->{"FacingPages"->True},
    CellLabelAutoDelete->False,
    StyleMenuListing->None]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Headings", "Subsubsection"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Chapter"],
    CellMargins->{{10, 4}, {4, 24}},
    ConversionRules:>{"HTML" -> {
      "<FONT SIZE=\"+3\" FACE=\"Helvetica, Arial\"><P><B>", 
      "</B></P></FONT>\n"}},
    InputAutoReplacements->{"TeX"->StyleBox[ 
            RowBox[ {"T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.074999999999999997, \
-0.085000000000000006}, {0, 0}}, BoxBaselineShift -> 0.5], "X"}]], 
        "LaTeX"->StyleBox[ 
            RowBox[ {"L", 
              StyleBox[ 
                AdjustmentBox[ 
                "A", BoxMargins -> {{-0.35999999999999999, \
-0.10000000000000001}, {0, 0}}, BoxBaselineShift -> -0.20000000000000001], 
                FontSize -> Smaller], "T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.074999999999999997, \
-0.085000000000000006}, {0, 0}}, BoxBaselineShift -> 0.5], "X"}]], 
        "mma"->"Mathematica", "Mma"->"Mathematica", "MMA"->"Mathematica"},
    FontFamily->"Helvetica",
    FontSize->24,
    FontWeight->"Bold"],
  
  Cell[StyleData["Chapter", "Printout"],
    CellMargins->{{2, 0}, {0, 18}},
    PageBreakBelow->False,
    FontSize->22]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Section"],
    CellMargins->{{10, 4}, {12, 18}},
    ConversionRules:>{"HTML" -> {
      "<FONT SIZE=\"+2\" FACE=\"Helvetica, Arial\"><P><B>", 
      "</B></P></FONT>\n"}},
    InputAutoReplacements->{"TeX"->StyleBox[ 
            RowBox[ {"T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.074999999999999997, \
-0.085000000000000006}, {0, 0}}, BoxBaselineShift -> 0.5], "X"}]], 
        "LaTeX"->StyleBox[ 
            RowBox[ {"L", 
              StyleBox[ 
                AdjustmentBox[ 
                "A", BoxMargins -> {{-0.35999999999999999, \
-0.10000000000000001}, {0, 0}}, BoxBaselineShift -> -0.20000000000000001], 
                FontSize -> Smaller], "T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.074999999999999997, \
-0.085000000000000006}, {0, 0}}, BoxBaselineShift -> 0.5], "X"}]], 
        "mma"->"Mathematica", "Mma"->"Mathematica", "MMA"->"Mathematica"},
    FontFamily->"Helvetica",
    FontSize->20,
    FontWeight->"Bold"],
  
  Cell[StyleData["Section", "Printout"],
    CellMargins->{{2, 0}, {0, 18}},
    PageBreakBelow->False,
    FontSize->18]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Subsection"],
    CellDingbat->"\[FilledSquare]",
    CellMargins->{{24, 4}, {0, 18}},
    CellElementSpacings->{"ClosedGroupTopMargin"->18},
    ConversionRules:>{"HTML" -> {
      "<LI TYPE=\"SQUARE\"><FONT SIZE=\"+1\" FACE=\"Helvetica, \
Arial\"><P><B>", "</B></P></FONT>\n"}},
    CellFrameLabelMargins->6,
    InputAutoReplacements->{"TeX"->StyleBox[ 
            RowBox[ {"T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.074999999999999997, \
-0.085000000000000006}, {0, 0}}, BoxBaselineShift -> 0.5], "X"}]], 
        "LaTeX"->StyleBox[ 
            RowBox[ {"L", 
              StyleBox[ 
                AdjustmentBox[ 
                "A", BoxMargins -> {{-0.35999999999999999, \
-0.10000000000000001}, {0, 0}}, BoxBaselineShift -> -0.20000000000000001], 
                FontSize -> Smaller], "T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.074999999999999997, \
-0.085000000000000006}, {0, 0}}, BoxBaselineShift -> 0.5], "X"}]], 
        "mma"->"Mathematica", "Mma"->"Mathematica", "MMA"->"Mathematica"},
    FontFamily->"Helvetica",
    FontSize->16,
    FontWeight->"Bold"],
  
  Cell[StyleData["Subsection", "Printout"],
    CellMargins->{{16, 0}, {0, 18}},
    PageBreakBelow->False,
    FontSize->14]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Subsubsection"],
    CellMargins->{{10, 4}, {0, 18}},
    CellElementSpacings->{"ClosedGroupTopMargin"->18},
    ConversionRules:>{"HTML" -> {"<FONT FACE=\"Helvetica, Arial\"><P><B>", 
      "</B></P></FONT>\n"}},
    InputAutoReplacements->{"TeX"->StyleBox[ 
            RowBox[ {"T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.074999999999999997, \
-0.085000000000000006}, {0, 0}}, BoxBaselineShift -> 0.5], "X"}]], 
        "LaTeX"->StyleBox[ 
            RowBox[ {"L", 
              StyleBox[ 
                AdjustmentBox[ 
                "A", BoxMargins -> {{-0.35999999999999999, \
-0.10000000000000001}, {0, 0}}, BoxBaselineShift -> -0.20000000000000001], 
                FontSize -> Smaller], "T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.074999999999999997, \
-0.085000000000000006}, {0, 0}}, BoxBaselineShift -> 0.5], "X"}]], 
        "mma"->"Mathematica", "Mma"->"Mathematica", "MMA"->"Mathematica"},
    FontFamily->"Helvetica",
    FontSize->12,
    FontWeight->"Bold"],
  
  Cell[StyleData["Subsubsection", "Printout"],
    CellMargins->{{2, 0}, {0, 18}},
    PageBreakBelow->False,
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["SubsubsectionColor"],
    CellMargins->{{10, 4}, {0, 18}},
    CellElementSpacings->{"ClosedGroupTopMargin"->18},
    ConversionRules:>{"HTML" -> {
      "<FONT FACE=\"Helvetica, Arial\" COLOR=\"660099\"><P><B>", 
      "</B></P></FONT>\n"}},
    InputAutoReplacements->{"TeX"->StyleBox[ 
            RowBox[ {"T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.074999999999999997, \
-0.085000000000000006}, {0, 0}}, BoxBaselineShift -> 0.5], "X"}]], 
        "LaTeX"->StyleBox[ 
            RowBox[ {"L", 
              StyleBox[ 
                AdjustmentBox[ 
                "A", BoxMargins -> {{-0.35999999999999999, \
-0.10000000000000001}, {0, 0}}, BoxBaselineShift -> -0.20000000000000001], 
                FontSize -> Smaller], "T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.074999999999999997, \
-0.085000000000000006}, {0, 0}}, BoxBaselineShift -> 0.5], "X"}]], 
        "mma"->"Mathematica", "Mma"->"Mathematica", "MMA"->"Mathematica"},
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->12,
    FontWeight->"Bold",
    FontColor->RGBColor[0.297993, 0, 0.454994]],
  
  Cell[StyleData["SubsubsectionColor", "Printout"],
    CellMargins->{{2, 0}, {0, 18}},
    PageBreakBelow->False,
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["SubsectionIcon"],
    ShowGroupOpenCloseIcon->True,
    CellMargins->{{24, 4}, {0, 18}},
    CellElementSpacings->{"ClosedGroupTopMargin"->8},
    CellGroupingRules->{"SectionGrouping", 50},
    ConversionRules:>{"HTML" -> {
      "<LI TYPE=\"SQUARE\"><FONT FACE=\"Helvetica, Arial\"><P><B>", 
      "</B></P></FONT>\n"}},
    InputAutoReplacements->{"TeX"->StyleBox[ 
            RowBox[ {"T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.074999999999999997, \
-0.085000000000000006}, {0, 0}}, BoxBaselineShift -> 0.5], "X"}]], 
        "LaTeX"->StyleBox[ 
            RowBox[ {"L", 
              StyleBox[ 
                AdjustmentBox[ 
                "A", BoxMargins -> {{-0.35999999999999999, \
-0.10000000000000001}, {0, 0}}, BoxBaselineShift -> -0.20000000000000001], 
                FontSize -> Smaller], "T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.074999999999999997, \
-0.085000000000000006}, {0, 0}}, BoxBaselineShift -> 0.5], "X"}]], 
        "mma"->"Mathematica", "Mma"->"Mathematica", "MMA"->"Mathematica"},
    CounterIncrements->"Section",
    FontFamily->"Helvetica",
    FontSize->16,
    FontWeight->"Bold"],
  
  Cell[StyleData["SubsectionIcon", "Printout"],
    CellDingbat->"\[FilledSquare]",
    ShowGroupOpenCloseIcon->False,
    CellMargins->{{16, 0}, {0, 18}},
    PageBreakBelow->False,
    FontSize->14]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["SubsubsectionIcon"],
    ShowGroupOpenCloseIcon->True,
    CellMargins->{{24, 4}, {0, 8}},
    CellElementSpacings->{"ClosedGroupTopMargin"->4},
    CellGroupingRules->{"SectionGrouping", 60},
    ConversionRules:>{"HTML" -> {
      "<LI TYPE=\"SQUARE\"><FONT FACE=\"Helvetica, Arial\"><P><B>", 
      "</B></P></FONT>\n"}},
    InputAutoReplacements->{"TeX"->StyleBox[ 
            RowBox[ {"T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.074999999999999997, \
-0.085000000000000006}, {0, 0}}, BoxBaselineShift -> 0.5], "X"}]], 
        "LaTeX"->StyleBox[ 
            RowBox[ {"L", 
              StyleBox[ 
                AdjustmentBox[ 
                "A", BoxMargins -> {{-0.35999999999999999, \
-0.10000000000000001}, {0, 0}}, BoxBaselineShift -> -0.20000000000000001], 
                FontSize -> Smaller], "T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.074999999999999997, \
-0.085000000000000006}, {0, 0}}, BoxBaselineShift -> 0.5], "X"}]], 
        "mma"->"Mathematica", "Mma"->"Mathematica", "MMA"->"Mathematica"},
    CounterIncrements->"Subsection",
    CounterAssignments->{{"Subsubection", 0}},
    FontFamily->"Helvetica",
    FontSize->12,
    FontWeight->"Bold"],
  
  Cell[StyleData["SubsubsectionIcon", "Printout"],
    ShowGroupOpenCloseIcon->False,
    CellMargins->{{2, 0}, {0, 18}},
    PageBreakBelow->False,
    FontSize->10]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Text", "Subsubsection"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Text"],
    CellMargins->{{10, 4}, {0, 8}},
    ConversionRules:>{"HTML" -> {"<P>", "</P>"}},
    CellHorizontalScrolling->True,
    InputAutoReplacements->{"TeX"->StyleBox[ 
            RowBox[ {"T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.074999999999999997, \
-0.085000000000000006}, {0, 0}}, BoxBaselineShift -> 0.5], "X"}]], 
        "LaTeX"->StyleBox[ 
            RowBox[ {"L", 
              StyleBox[ 
                AdjustmentBox[ 
                "A", BoxMargins -> {{-0.35999999999999999, \
-0.10000000000000001}, {0, 0}}, BoxBaselineShift -> -0.20000000000000001], 
                FontSize -> Smaller], "T", 
              AdjustmentBox[ 
              "E", 
                BoxMargins -> {{-0.074999999999999997, \
-0.085000000000000006}, {0, 0}}, BoxBaselineShift -> 0.5], "X"}]], 
        "mma"->"Mathematica", "Mma"->"Mathematica", "MMA"->"Mathematica"},
    Hyphenation->True,
    ParagraphSpacing->{0, 8}],
  
  Cell[StyleData["Text", "Printout"],
    CellMargins->{{2, 0}, {0, 8}},
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["CompactText"],
    CellMargins->{{10, 4}, {0, 8}},
    ConversionRules:>{"HTML" -> {"<FONT SIZE=\"-1\">", "</FONT>\n"}},
    Hyphenation->True,
    ParagraphSpacing->{0, 0},
    StyleMenuListing->None,
    FontSize->10],
  
  Cell[StyleData["CompactText", "Printout"],
    CellMargins->{{2, 0}, {0, 8}},
    FontSize->8]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Compact12Text"],
    CellMargins->{{10, 4}, {0, 8}},
    ConversionRules:>{"HTML" -> {"<P>", "</P>"}},
    Hyphenation->True,
    ParagraphSpacing->{0, 0},
    StyleMenuListing->None],
  
  Cell[StyleData["Compact12Text", "Printout"],
    CellMargins->{{2, 0}, {0, 8}},
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["TextSans"],
    CellMargins->{{10, 4}, {0, 8}},
    ConversionRules:>{"HTML" -> {
      "<FONT SIZE=\"-1\" FACE=\"Helvetica, Arial\">", "</FONT>\n"}},
    CellHorizontalScrolling->True,
    Hyphenation->True,
    ParagraphSpacing->{0, 8},
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->10],
  
  Cell[StyleData["TextSans", "Printout"],
    CellMargins->{{2, 0}, {0, 8}},
    FontSize->8]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["ItemizedText"],
    CellMargins->{{20, 4}, {0, 8}},
    ConversionRules:>{"HTML" -> {"<BLOCKQUOTE>", "</BLOCKQUOTE>"}},
    Hyphenation->True,
    ParagraphSpacing->{0, 8},
    ParagraphIndent->-15,
    StyleMenuListing->None],
  
  Cell[StyleData["ItemizedText", "Printout"],
    CellMargins->{{12, 0}, {0, 8}},
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["ItemizedTextNote"],
    CellMargins->{{35, 4}, {0, 4}},
    ConversionRules:>{"HTML" -> {"<BLOCKQUOTE>", "</BLOCKQUOTE>"}},
    Hyphenation->True,
    ParagraphSpacing->{0, 8},
    StyleMenuListing->None],
  
  Cell[StyleData["ItemizedTextNote", "Printout"],
    CellMargins->{{27, 0}, {0, 4}},
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["IndentedText"],
    CellMargins->{{20, 4}, {0, 6}},
    ConversionRules:>{"HTML" -> {"<BLOCKQUOTE>", "</BLOCKQUOTE>"}},
    Hyphenation->True,
    ParagraphSpacing->{0, 8},
    StyleMenuListing->None],
  
  Cell[StyleData["IndentedText", "Printout"],
    CellMargins->{{12, 0}, {0, 6}},
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["MathCaption"],
    CellDingbat->"\[FilledSmallSquare]",
    CellMargins->{{19, 62}, {0, 14}},
    ConversionRules:>{"HTML" -> {
      "<LI TYPE=\"SQUARE\"><P><FONT COLOR=\"000066\">", "</FONT></P></LI>"}},
    PageBreakBelow->False,
    CellFrameLabelMargins->4,
    Hyphenation->True,
    LineSpacing->{1, 1},
    ParagraphSpacing->{0, 8},
    FontColor->RGBColor[0, 0, 0.4]],
  
  Cell[StyleData["MathCaption", "Printout"],
    CellMargins->{{9, 0}, {0, 14}},
    FontSize->9,
    FontColor->GrayLevel[0]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["SmallText"],
    CellMargins->{{10, 4}, {0, 8}},
    ConversionRules:>{"HTML" -> {"<FONT SIZE=\"1\"><P>", "</P></FONT>"}},
    Hyphenation->True,
    LineSpacing->{1, 3},
    ParagraphSpacing->{0.7, 0},
    CounterIncrements->"SmallText",
    FontSize->9],
  
  Cell[StyleData["SmallText", "Printout"],
    CellMargins->{{2, 0}, {0, 8}},
    TextJustification->1,
    FontSize->7]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Input/Output", "Subsubsection"],
  
  Cell["\<\
The cells in this section define styles used for input and output \
to the kernel.  Be careful when modifying, renaming, or removing these \
styles, because the front end associates special meanings with these style \
names.    \
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Input"],
    ShowCellBracket->True,
    CellMargins->{{46, 4}, {3, 8}},
    Evaluatable->True,
    CellGroupingRules->"InputGrouping",
    PageBreakWithin->False,
    GroupPageBreakWithin->False,
    CellLabelAutoDelete->False,
    CellLabelMargins->{{14, Inherited}, {Inherited, Inherited}},
    DefaultFormatType->DefaultInputFormatType,
    ShowSpecialCharacters->Automatic,
    HyphenationOptions->{"HyphenationCharacter"->"\[Continuation]"},
    LanguageCategory->"Formula",
    FormatType->StandardForm,
    ShowStringCharacters->True,
    NumberMarks->True,
    FontWeight->"Bold"],
  
  Cell[StyleData["Input", "Printout"],
    FontSize->9]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Output"],
    ShowCellBracket->True,
    CellMargins->{{47, 4}, {4, 2}},
    CellEditDuplicate->True,
    CellGroupingRules->"OutputGrouping",
    CellHorizontalScrolling->True,
    PageBreakWithin->False,
    GroupPageBreakWithin->False,
    GeneratedCell->True,
    CellAutoOverwrite->True,
    CellLabelAutoDelete->False,
    CellLabelMargins->{{14, Inherited}, {Inherited, Inherited}},
    DefaultFormatType->DefaultOutputFormatType,
    HyphenationOptions->{"HyphenationCharacter"->"\[Continuation]"},
    LanguageCategory->"Formula",
    FormatType->StandardForm],
  
  Cell[StyleData["Output", "Printout"],
    FontSize->9]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Message"],
    ShowCellBracket->True,
    CellMargins->{{47, 4}, {4, 2}},
    CellGroupingRules->"OutputGrouping",
    PageBreakWithin->False,
    GroupPageBreakWithin->False,
    GeneratedCell->True,
    CellAutoOverwrite->True,
    ShowCellLabel->False,
    CellLabelMargins->{{14, Inherited}, {Inherited, Inherited}},
    DefaultFormatType->DefaultOutputFormatType,
    HyphenationOptions->{"HyphenationCharacter"->"\[Continuation]"},
    FormatType->InputForm,
    StyleMenuListing->None,
    FontColor->RGBColor[0, 0, 1]],
  
  Cell[StyleData["Message", "Printout"],
    FontSize->9,
    FontColor->GrayLevel[0]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Print"],
    ShowCellBracket->True,
    CellMargins->{{47, 4}, {4, 2}},
    CellGroupingRules->"OutputGrouping",
    PageBreakWithin->False,
    GroupPageBreakWithin->False,
    GeneratedCell->True,
    CellAutoOverwrite->True,
    ShowCellLabel->False,
    CellLabelMargins->{{14, Inherited}, {Inherited, Inherited}},
    DefaultFormatType->DefaultOutputFormatType,
    HyphenationOptions->{"HyphenationCharacter"->"\[Continuation]"},
    FormatType->InputForm,
    StyleMenuListing->None],
  
  Cell[StyleData["Print", "Printout"],
    FontSize->9]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Graphics"],
    ShowCellBracket->True,
    CellMargins->{{47, 4}, {4, 2}},
    CellGroupingRules->"GraphicsGrouping",
    PageBreakWithin->False,
    GeneratedCell->True,
    CellAutoOverwrite->True,
    ShowCellLabel->False,
    DefaultFormatType->DefaultFormatTypeForOutput,
    FormatType->InputForm,
    StyleMenuListing->None,
    FontWeight->"Plain"],
  
  Cell[StyleData["Graphics", "Printout"],
    FontSize->9]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["CellLabel"],
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->9,
    FontWeight->"Plain",
    FontColor->RGBColor[0, 0, 1]],
  
  Cell[StyleData["CellLabel", "Printout"],
    FontFamily->"Courier",
    FontSize->7,
    FontSlant->"Italic",
    FontColor->GrayLevel[0]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Name"],
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->9,
    FontWeight->"Plain",
    FontSlant->"Italic",
    FontColor->RGBColor[0, 0, 1]],
  
  Cell[StyleData["Name", "Printout"],
    FontSize->7,
    FontColor->GrayLevel[0]]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Hyperlinks", "Subsubsection"],
  
  Cell["\<\
The cells below define styles useful for making hypertext \
ButtonBoxes.  The \"Hyperlink\" style is for links within the same Notebook, \
or between Notebooks. The others point to the various sections of the help \
browser. These styles will modify individual words or letters in a cell \
exclusive of the cell tag.\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Hyperlink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontColor->RGBColor[0, 0, 1],
    FontVariations->{"Underline"->True},
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`NotebookLocate[ #2]}]&),
    Active->True,
    ButtonFrame->"None",
    ButtonNote->ButtonData}],
  
  Cell[StyleData["Hyperlink", "Printout"],
    FontSize->10,
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["MainBookLink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontColor->RGBColor[0, 0, 1],
    FontVariations->{"Underline"->True},
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`HelpBrowserLookup[ "MainBook", #]}]&),
    Active->True,
    ButtonFrame->"None"}],
  
  Cell[StyleData["MainBookLink", "Printout"],
    FontSize->10,
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["MainBookLinkMR"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontFamily->"Courier",
    FontColor->RGBColor[0, 0, 1],
    FontVariations->{"Underline"->True},
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`HelpBrowserLookup[ "MainBook", #]}]&),
    Active->True,
    ButtonFrame->"None"}],
  
  Cell[StyleData["MainBookLinkMR", "Printout"],
    FontSize->10,
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["AddOnsLink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontFamily->"Courier",
    FontColor->RGBColor[0, 0, 1],
    FontVariations->{"Underline"->True},
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`HelpBrowserLookup[ "AddOns", #]}]&),
    Active->True,
    ButtonFrame->"None"}],
  
  Cell[StyleData["AddOnLink", "Printout"],
    FontSize->10,
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["RefGuideLink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontFamily->"Courier",
    FontColor->RGBColor[0, 0, 1],
    FontVariations->{"Underline"->True},
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`HelpBrowserLookup[ "RefGuideLink", #]}]&),
    Active->True,
    ButtonFrame->"None"}],
  
  Cell[StyleData["RefGuideLink", "Printout"],
    FontSize->10,
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["GettingStartedLink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontColor->RGBColor[0, 0, 1],
    FontVariations->{"Underline"->True},
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`HelpBrowserLookup[ "GettingStarted", #]}]&),
    Active->True,
    ButtonFrame->"None"}],
  
  Cell[StyleData["GettingStartedLink", "Printout"],
    FontSize->10,
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["OtherInformationLink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontColor->RGBColor[0, 0, 1],
    FontVariations->{"Underline"->True},
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`HelpBrowserLookup[ "OtherInformation", #]}]&),
    Active->True,
    ButtonFrame->"None"}],
  
  Cell[StyleData["OtherInformationLink", "Printout"],
    FontSize->10,
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["OtherInformationLinkMR"],
    StyleMenuListing->None,
    FontFamily->"Courier",
    FontColor->RGBColor[0, 0, 1],
    FontVariations->{"Underline"->True},
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`HelpBrowserLookup[ "OtherInformation", #]}]&),
    Active->True,
    ButtonFrame->"None"}],
  
  Cell[StyleData["OtherInformationLinkMR", "Printout"],
    FontSize->10,
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Palette Styles", "Subsubsection"],
  
  Cell["\<\
The cells below define styles that define standard \
ButtonFunctions, for use in palette buttons.\
\>", "Text"],
  
  Cell[StyleData["Paste"],
    StyleMenuListing->Automatic,
    ButtonStyleMenuListing->Automatic,
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`NotebookApply[ 
          FrontEnd`InputNotebook[ ], #, After]}]&)}],
  
  Cell[StyleData["Evaluate"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`NotebookApply[ 
          FrontEnd`InputNotebook[ ], #, All], 
        SelectionEvaluate[ 
          FrontEnd`InputNotebook[ ], All]}]&)}],
  
  Cell[StyleData["EvaluateCell"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`NotebookApply[ 
          FrontEnd`InputNotebook[ ], #, All], 
        FrontEnd`SelectionMove[ 
          FrontEnd`InputNotebook[ ], All, Cell, 1], 
        FrontEnd`SelectionEvaluateCreateCell[ 
          FrontEnd`InputNotebook[ ], All]}]&)}],
  
  Cell[StyleData["CopyEvaluate"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`SelectionCreateCell[ 
          FrontEnd`InputNotebook[ ], All], 
        FrontEnd`NotebookApply[ 
          FrontEnd`InputNotebook[ ], #, All], 
        FrontEnd`SelectionEvaluate[ 
          FrontEnd`InputNotebook[ ], All]}]&)}],
  
  Cell[StyleData["CopyEvaluateCell"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`SelectionCreateCell[ 
          FrontEnd`InputNotebook[ ], All], 
        FrontEnd`NotebookApply[ 
          FrontEnd`InputNotebook[ ], #, All], 
        FrontEnd`SelectionEvaluateCreateCell[ 
          FrontEnd`InputNotebook[ ], All]}]&)}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Inline Formatting", "Subsubsection"],
  
  Cell["\<\
These styles are for modifying individual words or letters in a \
cell exclusive of the cell tag.\
\>", "Text"],
  
  Cell[StyleData["JT"],
    StyleMenuListing->None,
    FontFamily->"JFontText"],
  
  Cell[StyleData["JS"],
    StyleMenuListing->None,
    FontFamily->"JFontSans"],
  
  Cell[StyleData["JSB"],
    StyleMenuListing->None,
    FontFamily->"JFontSansBold"],
  
  Cell[StyleData["RM"],
    StyleMenuListing->None,
    FontWeight->"Plain",
    FontSlant->"Plain"],
  
  Cell[StyleData["BF"],
    StyleMenuListing->None,
    FontWeight->"Bold"],
  
  Cell[StyleData["IT"],
    StyleMenuListing->None,
    FontSlant->"Italic"],
  
  Cell[StyleData["TR"],
    StyleMenuListing->None,
    FontFamily->"Times",
    FontWeight->"Plain",
    FontSlant->"Plain"],
  
  Cell[StyleData["TI"],
    StyleMenuListing->None,
    FontFamily->"Times",
    FontWeight->"Plain",
    FontSlant->"Italic"],
  
  Cell[StyleData["TB"],
    StyleMenuListing->None,
    FontFamily->"Times",
    FontWeight->"Bold",
    FontSlant->"Plain"],
  
  Cell[StyleData["TBI"],
    StyleMenuListing->None,
    FontFamily->"Times",
    FontWeight->"Bold",
    FontSlant->"Italic"],
  
  Cell[StyleData["MR"],
    StyleMenuListing->None,
    FontFamily->"Courier",
    FontWeight->"Plain",
    FontSlant->"Plain"],
  
  Cell[StyleData["MO"],
    StyleMenuListing->None,
    FontFamily->"Courier",
    FontWeight->"Plain",
    FontSlant->"Italic"],
  
  Cell[StyleData["MB"],
    StyleMenuListing->None,
    FontFamily->"Courier",
    FontWeight->"Bold",
    FontSlant->"Plain"],
  
  Cell[StyleData["MBO"],
    StyleMenuListing->None,
    FontFamily->"Courier",
    FontWeight->"Bold",
    FontSlant->"Italic"],
  
  Cell[StyleData["SR"],
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontWeight->"Plain",
    FontSlant->"Plain"],
  
  Cell[StyleData["SO"],
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontWeight->"Plain",
    FontSlant->"Italic"],
  
  Cell[StyleData["SB"],
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontWeight->"Bold",
    FontSlant->"Plain"],
  
  Cell[StyleData["SBO"],
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontWeight->"Bold",
    FontSlant->"Italic"],
  
  Cell[StyleData["M4"],
    ShowCellBracket->True,
    StyleMenuListing->None,
    FontFamily->"Math4",
    CharacterEncoding->"Math4"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["SO10"],
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->10,
    FontWeight->"Plain",
    FontSlant->"Italic"],
  
  Cell[StyleData["SO10", "Printout"],
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->7,
    FontWeight->"Plain",
    FontSlant->"Italic"]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["C1"],
    StyleMenuListing->None,
    FontColor->RGBColor[0.4, 0, 1]],
  
  Cell[StyleData["C1", "Printout"],
    FontColor->GrayLevel[0]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["C1MR"],
    StyleMenuListing->None,
    FontFamily->"Courier",
    FontColor->RGBColor[0.4, 0, 1]],
  
  Cell[StyleData["C1MR", "Printout"],
    FontColor->GrayLevel[0]]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Emphasis Boxes and Pictures", "Subsubsection"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Box"],
    CellMargins->{{10, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    StyleMenuListing->None,
    Background->RGBColor[1, 0.6, 0.6],
    FrameBoxOptions->{BoxMargins->{{1, 1}, {1.5, 1.5}}},
    GridBoxOptions->{ColumnSpacings->1}],
  
  Cell[StyleData["Box", "Printout"],
    CellMargins->{{2, 0}, {0, 8}},
    FontSize->10,
    Background->GrayLevel[0.900008]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["DoubleBox"],
    CellMargins->{{10, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    StyleMenuListing->None,
    Background->RGBColor[1, 0.6, 0.6],
    FrameBoxOptions->{BoxMargins->{{1, 1}, {1.5, 1.5}}},
    GridBoxOptions->{ColumnSpacings->2,
    RowAlignments->Top}],
  
  Cell[StyleData["DoubleBox", "Printout"],
    CellMargins->{{2, 0}, {0, 8}},
    FontSize->10,
    Background->GrayLevel[0.900008]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["1ColumnBox"],
    CellMargins->{{10, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    LineIndent->0,
    StyleMenuListing->None,
    Background->RGBColor[1, 0.6, 0.6],
    FrameBoxOptions->{BoxMargins->{{1, 1}, {1.5, 1.5}}},
    GridBoxOptions->{ColumnSpacings->1}],
  
  Cell[StyleData["1ColumnBox", "Printout"],
    CellMargins->{{2, 0}, {0, 8}},
    FontSize->10,
    Background->GrayLevel[0.900008]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["2ColumnBox"],
    CellMargins->{{10, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    LineIndent->0,
    StyleMenuListing->None,
    Background->RGBColor[1, 0.6, 0.6],
    FrameBoxOptions->{BoxMargins->{{1, 1}, {1.5, 1.5}}},
    GridBoxOptions->{ColumnWidths->{0.31, 0.62}}],
  
  Cell[StyleData["2ColumnBox", "Printout"],
    CellMargins->{{2, 0}, {0, 8}},
    FontSize->10,
    Background->GrayLevel[0.900008]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["2ColumnEvenBox"],
    CellMargins->{{10, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    LineIndent->0,
    StyleMenuListing->None,
    Background->RGBColor[1, 0.6, 0.6],
    FrameBoxOptions->{BoxMargins->{{1, 1}, {1.5, 1.5}}},
    GridBoxOptions->{ColumnWidths->0.46}],
  
  Cell[StyleData["2ColumnEvenBox", "Printout"],
    CellMargins->{{2, 0}, {0, 8}},
    FontSize->10,
    Background->GrayLevel[0.900008]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["2ColumnSmallBox"],
    CellMargins->{{10, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    LineIndent->0,
    StyleMenuListing->None,
    Background->RGBColor[1, 0.6, 0.6],
    FrameBoxOptions->{BoxMargins->{{1, 1}, {1.5, 1.5}}},
    GridBoxOptions->{ColumnSpacings->1.5,
    ColumnWidths->0.35,
    ColumnAlignments->{Right, Left}}],
  
  Cell[StyleData["2ColumnSmallBox", "Printout"],
    CellMargins->{{2, 0}, {0, 8}},
    FontSize->10,
    Background->GrayLevel[0.900008]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["3ColumnBox"],
    CellMargins->{{10, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    LineIndent->0,
    StyleMenuListing->None,
    Background->RGBColor[1, 0.6, 0.6],
    FrameBoxOptions->{BoxMargins->{{1, 1}, {1.5, 1.5}}},
    GridBoxOptions->{ColumnWidths->0.31}],
  
  Cell[StyleData["3ColumnBox", "Printout"],
    CellMargins->{{2, 0}, {0, 8}},
    FontSize->10,
    Background->GrayLevel[0.900008]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["3ColumnSmallBox"],
    CellMargins->{{10, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    LineIndent->0,
    StyleMenuListing->None,
    Background->RGBColor[1, 0.6, 0.6],
    FrameBoxOptions->{BoxMargins->{{1, 1}, {1.5, 1.5}}},
    GridBoxOptions->{ColumnSpacings->1.5,
    ColumnWidths->0.24,
    ColumnAlignments->{Right, Center, Left}}],
  
  Cell[StyleData["3ColumnSmallBox", "Printout"],
    CellMargins->{{2, 0}, {0, 8}},
    FontSize->10,
    Background->GrayLevel[0.900008]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["4ColumnBox"],
    CellMargins->{{10, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    LineIndent->0,
    StyleMenuListing->None,
    Background->RGBColor[1, 0.6, 0.6],
    FrameBoxOptions->{BoxMargins->{{1, 1}, {1.5, 1.5}}},
    GridBoxOptions->{ColumnWidths->{0.13, 0.33, 0.13, 0.33}}],
  
  Cell[StyleData["4ColumnBox", "Printout"],
    CellMargins->{{2, 0}, {0, 8}},
    FontSize->10,
    Background->GrayLevel[0.900008]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["5ColumnBox"],
    CellMargins->{{10, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    LineIndent->0,
    StyleMenuListing->None,
    Background->RGBColor[1, 0.6, 0.6],
    FrameBoxOptions->{BoxMargins->{{1, 1}, {1.5, 1.5}}},
    GridBoxOptions->{ColumnWidths->0.194}],
  
  Cell[StyleData["5ColumnBox", "Printout"],
    CellMargins->{{2, 0}, {0, 8}},
    FontSize->10,
    Background->GrayLevel[0.900008]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["6ColumnBox"],
    CellMargins->{{10, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    LineIndent->0,
    StyleMenuListing->None,
    Background->RGBColor[1, 0.6, 0.6],
    FrameBoxOptions->{BoxMargins->{{1, 1}, {1.5, 1.5}}},
    GridBoxOptions->{ColumnWidths->{0.12, 0.22, 0.12, 0.12, 0.22, 0.12}}],
  
  Cell[StyleData["6ColumnBox", "Printout"],
    CellMargins->{{2, 0}, {0, 8}},
    FontSize->10,
    Background->GrayLevel[0.900008]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["ItemizedNoteBox"],
    CellFrame->0.5,
    CellMargins->{{37, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    LineIndent->0,
    StyleMenuListing->None,
    Background->RGBColor[1, 0.6, 0.6],
    FrameBoxOptions->{BoxMargins->{{1, 1}, {1.5, 1.5}}},
    GridBoxOptions->{ColumnSpacings->1}],
  
  Cell[StyleData["ItemizedNoteBox", "Printout"],
    FontSize->10,
    Background->GrayLevel[0.900008]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["DefinitionBox"],
    CellFrame->0.5,
    CellMargins->{{10, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    AutoIndent->False,
    AutoSpacing->False,
    LineIndent->0,
    FontWeight->"Plain",
    Background->RGBColor[1, 0.6, 0.6],
    GridBoxOptions->{RowSpacings->1.5,
    ColumnSpacings->1,
    ColumnWidths->{0.4, 0.6},
    ColumnAlignments->{Left}}],
  
  Cell[StyleData["DefinitionBox", "Printout"],
    CellMargins->{{2, 4}, {0, 8}},
    FontSize->10,
    Background->GrayLevel[0.900008]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["DefinitionBox3Col"],
    CellFrame->0.5,
    CellMargins->{{10, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    AutoIndent->False,
    AutoSpacing->False,
    LineIndent->0,
    FontWeight->"Plain",
    Background->RGBColor[1, 0.6, 0.6],
    GridBoxOptions->{RowSpacings->1.5,
    ColumnSpacings->1,
    ColumnWidths->{0.35, 0.2, 0.45},
    ColumnAlignments->{Left}}],
  
  Cell[StyleData["DefinitionBox3Col", "Printout"],
    CellMargins->{{2, 4}, {0, 8}},
    FontSize->10,
    Background->GrayLevel[0.900008]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["DefinitionBox4Col"],
    CellFrame->0.5,
    CellMargins->{{10, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    AutoIndent->False,
    AutoSpacing->False,
    LineIndent->0,
    FontWeight->"Plain",
    Background->RGBColor[1, 0.6, 0.6],
    GridBoxOptions->{RowSpacings->1.5,
    ColumnSpacings->1,
    ColumnWidths->{0.15, 0.35, 0.15, 0.35},
    ColumnAlignments->{Left}}],
  
  Cell[StyleData["DefinitionBox4Col", "Printout"],
    CellMargins->{{2, 4}, {0, 8}},
    FontSize->10,
    Background->GrayLevel[0.900008]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["DefinitionBox5Col"],
    CellFrame->0.5,
    CellMargins->{{10, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    AutoIndent->False,
    AutoSpacing->False,
    LineIndent->0,
    FontWeight->"Plain",
    Background->RGBColor[1, 0.6, 0.6],
    GridBoxOptions->{RowSpacings->1.5,
    ColumnSpacings->1,
    ColumnWidths->0.2,
    ColumnAlignments->{Left}}],
  
  Cell[StyleData["DefinitionBox5Col", "Printout"],
    CellMargins->{{2, 4}, {0, 8}},
    FontSize->10,
    Background->GrayLevel[0.900008]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["DefinitionBox6Col"],
    CellFrame->0.5,
    CellMargins->{{10, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    AutoIndent->False,
    AutoSpacing->False,
    LineIndent->0,
    FontWeight->"Plain",
    Background->RGBColor[1, 0.6, 0.6],
    GridBoxOptions->{RowSpacings->1.5,
    ColumnSpacings->1,
    ColumnWidths->{0.13, 0.24, 0.13, 0.13, 0.24, 0.13},
    ColumnAlignments->{Left}}],
  
  Cell[StyleData["DefinitionBox6Col", "Printout"],
    CellMargins->{{2, 4}, {0, 8}},
    FontSize->10,
    Background->GrayLevel[0.900008]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["TopBox"],
    CellFrame->{{0.5, 0.5}, {0, 0.5}},
    CellMargins->{{11, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    PageBreakBelow->False,
    AutoIndent->False,
    AutoSpacing->False,
    LineIndent->0,
    StyleMenuListing->None,
    FontWeight->"Plain",
    Background->RGBColor[1, 0.6, 0.6],
    GridBoxOptions->{RowSpacings->1.5,
    ColumnSpacings->1,
    ColumnWidths->{0.31, 0.62},
    ColumnAlignments->{Left}}],
  
  Cell[StyleData["TopBox", "Printout"],
    CellMargins->{{2, 0}, {0, 8}},
    FontSize->10,
    Background->GrayLevel[0.900008]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["MiddleBox"],
    CellFrame->{{0.5, 0.5}, {0, 0}},
    CellMargins->{{11, 4}, {0, -7}},
    CellHorizontalScrolling->True,
    PageBreakBelow->False,
    AutoIndent->False,
    AutoSpacing->False,
    LineIndent->0,
    StyleMenuListing->None,
    FontWeight->"Plain",
    Background->RGBColor[1, 0.6, 0.6],
    GridBoxOptions->{RowSpacings->1.5,
    ColumnSpacings->1,
    ColumnWidths->{0.31, 0.62},
    ColumnAlignments->{Left}}],
  
  Cell[StyleData["MiddleBox", "Printout"],
    CellMargins->{{2, 0}, {0, 0}},
    FontSize->10,
    Background->GrayLevel[0.900008]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["BottomBox"],
    CellFrame->{{0.5, 0.5}, {0.5, 0}},
    CellMargins->{{11, 4}, {0, -7}},
    CellHorizontalScrolling->True,
    PageBreakBelow->False,
    AutoIndent->False,
    AutoSpacing->False,
    LineIndent->0,
    StyleMenuListing->None,
    FontWeight->"Plain",
    Background->RGBColor[1, 0.6, 0.6],
    GridBoxOptions->{RowSpacings->1.5,
    ColumnSpacings->1,
    ColumnWidths->{0.31, 0.62},
    ColumnAlignments->{Left}}],
  
  Cell[StyleData["BottomBox", "Printout"],
    CellMargins->{{2, 4}, {0, 0}},
    FontSize->10,
    Background->GrayLevel[0.900008]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["TopSpanBox"],
    CellFrame->{{0.5, 0.5}, {0, 0.5}},
    CellMargins->{{11, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    PageBreakBelow->False,
    AutoIndent->False,
    AutoSpacing->False,
    LineIndent->0,
    StyleMenuListing->None,
    FontWeight->"Plain",
    Background->RGBColor[1, 0.6, 0.6],
    GridBoxOptions->{RowSpacings->1.5,
    ColumnSpacings->1,
    ColumnWidths->{0.9, 0.03},
    ColumnAlignments->{Left}}],
  
  Cell[StyleData["TopSpanBox", "Printout"],
    CellMargins->{{2, 0}, {0, 8}},
    FontSize->10,
    Background->GrayLevel[0.900008]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["MiddleSpanBox"],
    CellFrame->{{0.5, 0.5}, {0, 0}},
    CellMargins->{{11, 4}, {0, 0}},
    CellHorizontalScrolling->True,
    PageBreakBelow->False,
    AutoIndent->False,
    AutoSpacing->False,
    LineIndent->0,
    StyleMenuListing->None,
    FontWeight->"Plain",
    Background->RGBColor[1, 0.6, 0.6],
    GridBoxOptions->{RowSpacings->1.5,
    ColumnSpacings->1,
    ColumnWidths->{0.9, 0.03},
    ColumnAlignments->{Left}}],
  
  Cell[StyleData["MiddleSpanBox", "Printout"],
    CellMargins->{{2, 4}, {0, 8}},
    FontSize->10,
    Background->GrayLevel[0.900008]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Picture"],
    CellMargins->{{10, Inherited}, {0, 8}},
    CellHorizontalScrolling->True,
    StyleMenuListing->None],
  
  Cell[StyleData["Picture", "Printout"],
    CellMargins->{{2, 0}, {0, 8}}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["ItemizedPicture"],
    CellMargins->{{35, 4}, {0, 4}},
    CellGroupingRules->"GraphicsGrouping",
    CellHorizontalScrolling->True,
    StyleMenuListing->None],
  
  Cell[StyleData["ItemizedPicture", "Printout"],
    CellMargins->{{27, 0}, {0, 4}},
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["PictureGroup"],
    CellMargins->{{10, Inherited}, {0, 8}},
    CellGroupingRules->"GraphicsGrouping",
    CellHorizontalScrolling->True,
    StyleMenuListing->None],
  
  Cell[StyleData["PictureGroup", "Printout"],
    CellMargins->{{2, 0}, {0, 8}},
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Sound"],
    ShowCellBracket->True,
    CellMargins->{{10, Inherited}, {0, 8}},
    StyleMenuListing->None],
  
  Cell[StyleData["Sound", "Printout"],
    CellMargins->{{2, 0}, {0, 8}},
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Caption"],
    CellMargins->{{10, 4}, {0, 3}},
    PageBreakAbove->False,
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->9],
  
  Cell[StyleData["Caption", "Printout"],
    CellMargins->{{2, 0}, {0, 3}},
    FontSize->7]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Tables", "Subsubsection"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["2ColumnTable"],
    CellMargins->{{10, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    LineIndent->0,
    StyleMenuListing->None,
    GridBoxOptions->{ColumnWidths->{0.34, 0.64},
    ColumnAlignments->{Left}}],
  
  Cell[StyleData["2ColumnTable", "Printout"],
    CellMargins->{{2, 0}, {0, 8}},
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["2ColumnEvenTable"],
    CellMargins->{{10, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    LineIndent->0,
    StyleMenuListing->None,
    GridBoxOptions->{ColumnWidths->0.49,
    ColumnAlignments->{Left}}],
  
  Cell[StyleData["2ColumnEvenTable", "Printout"],
    CellMargins->{{2, 0}, {0, 8}},
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["3ColumnTable"],
    CellMargins->{{10, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    LineIndent->0,
    StyleMenuListing->None,
    GridBoxOptions->{ColumnWidths->{0.28, 0.28, 0.43},
    ColumnAlignments->{Left}}],
  
  Cell[StyleData["3ColumnTable", "Printout"],
    CellMargins->{{2, 0}, {0, 8}},
    FontSize->10]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Formulas and Programming", "Subsubsection"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["InlineFormula"],
    CellMargins->{{10, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    HyphenationOptions->{"HyphenationCharacter"->"\[Continuation]"},
    ScriptLevel->1,
    SingleLetterItalics->True,
    SpanMaxSize->Infinity,
    StyleMenuListing->None,
    GridBoxOptions->{ColumnWidths->Automatic}],
  
  Cell[StyleData["InlineFormula", "Printout"],
    CellMargins->{{2, 0}, {0, 8}},
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["InlineOutput"],
    CellMargins->{{10, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    HyphenationOptions->{"HyphenationCharacter"->"\[Continuation]"},
    StyleMenuListing->None,
    FontFamily->"Courier"],
  
  Cell[StyleData["InlineOutput", "Printout"],
    CellMargins->{{2, 0}, {0, 8}},
    FontSize->9.5]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["DisplayFormula"],
    CellMargins->{{42, Inherited}, {Inherited, 10}},
    CellHorizontalScrolling->True,
    HyphenationOptions->{"HyphenationCharacter"->"\[Continuation]"},
    LanguageCategory->"Formula",
    ScriptLevel->0,
    SingleLetterItalics->True,
    SpanMaxSize->Infinity,
    StyleMenuListing->None,
    UnderoverscriptBoxOptions->{LimitsPositioning->True},
    GridBoxOptions->{ColumnWidths->Automatic}],
  
  Cell[StyleData["DisplayFormula", "Printout"],
    CellMargins->{{34, Inherited}, {Inherited, 10}},
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["DisplayMath"],
    CellMargins->{{42, 10}, {7, 7}},
    Evaluatable->False,
    CellGroupingRules->"InputGrouping",
    CellHorizontalScrolling->True,
    PageBreakWithin->False,
    GroupPageBreakWithin->False,
    DefaultFormatType->DefaultInputFormatType,
    HyphenationOptions->{"HyphenationCharacter"->"\[Continuation]"},
    AutoItalicWords->{},
    LanguageCategory->"Formula",
    FormatType->InputForm,
    ShowStringCharacters->True,
    NumberMarks->True,
    CounterIncrements->"Input"],
  
  Cell[StyleData["DisplayMath", "Printout"],
    CellMargins->{{39, 0}, {6, 6}},
    FontSize->9]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["NumberedEquation"],
    CellMargins->{{42, 10}, {7, 7}},
    CellFrameLabels->{{None, Cell[ 
            TextData[ {"(", 
              CounterBox[ "NumberedEquation"], ")"}]]}, {None, None}},
    DefaultFormatType->DefaultInputFormatType,
    HyphenationOptions->{"HyphenationCharacter"->"\[Continuation]"},
    LanguageCategory->"Formula",
    CounterIncrements->"NumberedEquation",
    FormatTypeAutoConvert->False],
  
  Cell[StyleData["NumberedEquation", "Printout"],
    CellMargins->{{34, 55}, {0, 10}},
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["EquationNumber"],
    LineSpacing->{1.83, 0},
    LanguageCategory->"Formula"],
  
  Cell[StyleData["EquationNumber", "Printout"],
    LineSpacing->{1.7, 0},
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Program"],
    CellMargins->{{16, Inherited}, {Inherited, 10}},
    CellHorizontalScrolling->True,
    LanguageCategory->"Formula",
    StyleMenuListing->None,
    FontFamily->"Courier"],
  
  Cell[StyleData["Program", "Printout"],
    CellMargins->{{8, Inherited}, {Inherited, 10}},
    FontSize->9.5]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Unique Help Browser Styles", "Subsubsection"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["InspectorLevel1"],
    ShowGroupOpenCloseIcon->True,
    CellMargins->{{12, 10}, {2, 7}},
    CellGroupingRules->{"SectionGrouping", 60},
    ParagraphIndent->-38,
    FontFamily->"Helvetica",
    FontSize->16,
    FontWeight->"Bold"],
  
  Cell[StyleData["InspectorLevel1", "Brackets"]],
  
  Cell[StyleData["InspectorLevel1", "Printout"],
    FontSize->14]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["InspectorLevel2"],
    ShowGroupOpenCloseIcon->True,
    CellMargins->{{10, 4}, {0, 14}},
    FontFamily->"Helvetica",
    FontSize->14,
    FontWeight->"Bold"],
  
  Cell[StyleData["InspectorLevel2", "Brackets"],
    ShowGroupOpenCloseIcon->True,
    CellMargins->{{48, 10}, {2, 12}},
    CellGroupingRules->{"SectionGrouping", 70},
    ParagraphIndent->-27,
    FontFamily->"Helvetica",
    FontSize->14,
    FontWeight->"Bold"],
  
  Cell[StyleData["InspectorLevel2", "Printout"],
    FontSize->12]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["ObjectName"],
    CellMargins->{{10, 4}, {1, 10}},
    FontFamily->"Courier",
    FontSize->16,
    FontWeight->"Bold"],
  
  Cell[StyleData["ObjectName", "Brackets"],
    CellMargins->{{72, 4}, {1, 14}},
    CellGroupingRules->{"SectionGrouping", 90},
    StyleMenuListing->None,
    FontFamily->"Courier",
    FontSize->12,
    FontWeight->"Bold"],
  
  Cell[StyleData["ObjectName", "Printout"],
    CellMargins->{{2, 0}, {1, 10}},
    FontSize->12]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["SubObjectNameClosed"],
    ShowGroupOpenCloseIcon->True,
    CellMargins->{{10, 4}, {1, 10}},
    PrivateCellOptions->{"DefaultCellGroupOpen"->False},
    CellGroupingRules->{"SectionGrouping", 90},
    FontFamily->"Courier",
    FontSize->14,
    FontWeight->"Bold"],
  
  Cell[StyleData["SubObjectNameClosed", "Brackets"],
    CellMargins->{{72, 4}, {1, 14}},
    StyleMenuListing->None,
    FontFamily->"Courier",
    FontSize->12,
    FontWeight->"Bold"],
  
  Cell[StyleData["SubObjectNameClosed", "Printout"],
    CellMargins->{{2, 0}, {1, 10}},
    FontSize->12]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["SubObjectName"],
    ShowGroupOpenCloseIcon->True,
    CellMargins->{{24, 4}, {1, 10}},
    FontFamily->"Courier",
    FontSize->16,
    FontWeight->"Bold"],
  
  Cell[StyleData["SubObjectName", "Brackets"],
    ShowGroupOpenCloseIcon->True,
    CellMargins->{{90, 4}, {1, 14}},
    FontFamily->"Courier",
    FontSize->12],
  
  Cell[StyleData["SubObjectName", "Printout"],
    CellMargins->{{2, 0}, {1, 10}},
    FontFamily->"Courier",
    FontSize->12]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["GroupObjectName"],
    ShowGroupOpenCloseIcon->True,
    CellMargins->{{10, 4}, {0, 14}},
    FontFamily->"Courier",
    FontSize->16,
    FontWeight->"Bold"],
  
  Cell[StyleData["GroupObjectName", "Brackets"],
    ShowGroupOpenCloseIcon->True,
    CellMargins->{{72, 10}, {2, 12}},
    CellGroupingRules->{"SectionGrouping", 70},
    ParagraphIndent->-27,
    CounterIncrements->"Outline2",
    FontFamily->"Courier",
    FontSize->12,
    FontWeight->"Bold"],
  
  Cell[StyleData["GroupObjectName", "Printout"],
    FontSize->14]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["GroupObjectNameClosed"],
    ShowGroupOpenCloseIcon->True,
    CellMargins->{{10, 4}, {0, 14}},
    PrivateCellOptions->{"DefaultCellGroupOpen"->False},
    CellGroupingRules->{"SectionGrouping", 80},
    FontFamily->"Courier",
    FontSize->16,
    FontWeight->"Bold"],
  
  Cell[StyleData["GroupObjectNameClosed", "Brackets"],
    ShowGroupOpenCloseIcon->True,
    CellMargins->{{72, 10}, {2, 12}},
    CellGroupingRules->{"SectionGrouping", 70},
    ParagraphIndent->-27,
    CounterIncrements->"Outline2",
    FontFamily->"Courier",
    FontSize->12,
    FontWeight->"Bold"],
  
  Cell[StyleData["GroupObjectNameClosed", "Printout"],
    FontSize->14]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["ObjectNameWarningMessages"],
    CellMargins->{{10, 4}, {1, 10}},
    CellGroupingRules->{"SectionGrouping", 65},
    FontFamily->"Courier",
    FontSize->16,
    FontWeight->"Bold"],
  
  Cell[StyleData["ObjectNameWarningMessages", "Brackets"],
    CellMargins->{{10, 4}, {1, 10}},
    CellGroupingRules->{"SectionGrouping", 65},
    FontFamily->"Courier",
    FontSize->16,
    FontWeight->"Bold"],
  
  Cell[StyleData["ObjectNameWarningMessages", "Printout"],
    CellMargins->{{2, 0}, {1, 10}},
    FontSize->12]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Command"],
    CellMargins->{{10, 4}, {0, 14}},
    CounterIncrements->"Section",
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->16,
    FontWeight->"Bold"],
  
  Cell[StyleData["Command", "Printout"],
    CellMargins->{{2, 0}, {0, 14}},
    PageBreakBelow->False,
    FontSize->14]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["CharacterName"],
    CellFrame->{{0, 0}, {0.5, 0.5}},
    CellMargins->{{10, 4}, {0, 4}},
    CellFrameMargins->4,
    StyleMenuListing->None],
  
  Cell[StyleData["CharacterName", "Brackets"],
    CellMargins->{{72, 4}, {1, 14}},
    CellGroupingRules->{"SectionGrouping", 90},
    StyleMenuListing->None,
    FontFamily->"Courier",
    FontSize->12,
    FontWeight->"Bold"],
  
  Cell[StyleData["CharacterName", "Printout"],
    CellMargins->{{2, 0}, {0, 4}},
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Usage"],
    CellFrame->{{0, 0}, {0.5, 0.5}},
    CellMargins->{{10, 4}, {0, 4}},
    CellFrameMargins->5,
    Hyphenation->True,
    ParagraphSpacing->{0, 6},
    ParagraphIndent->-10,
    StyleMenuListing->None],
  
  Cell[StyleData["Usage", "Brackets"],
    CellFrame->{{0, 0}, {0.5, 0.5}},
    CellMargins->{{72, 4}, {0, 4}},
    CellFrameMargins->5,
    ParagraphSpacing->{0, 6},
    ParagraphIndent->-10,
    StyleMenuListing->None],
  
  Cell[StyleData["Usage", "Printout"],
    CellMargins->{{2, 0}, {0, 4}},
    FontSize->10,
    FontWeight->"Plain"]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["ErrorMessage"],
    CellFrame->{{0, 0}, {0.5, 0.5}},
    ShowCellBracket->True,
    CellMargins->{{10, 4}, {0, 4}},
    CellGroupingRules->"OutputGrouping",
    PageBreakWithin->False,
    GroupPageBreakWithin->False,
    GeneratedCell->True,
    CellAutoOverwrite->True,
    ShowCellLabel->False,
    CellLabelMargins->{{14, Inherited}, {Inherited, Inherited}},
    CellFrameMargins->5,
    DefaultFormatType->DefaultOutputFormatType,
    FormatType->InputForm,
    StyleMenuListing->None,
    FontColor->RGBColor[0, 0, 1]],
  
  Cell[StyleData["ErrorMessage", "Brackets"],
    CellMargins->{{72, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    StyleMenuListing->None],
  
  Cell[StyleData["ErrorMessage", "Printout"],
    FontSize->9,
    FontColor->GrayLevel[0]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Notes"],
    CellMargins->{{10, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    Hyphenation->True,
    ParagraphSpacing->{0, 6},
    ParagraphIndent->-10,
    StyleMenuListing->None,
    FontFamily->"Times"],
  
  Cell[StyleData["Notes", "Brackets"],
    CellMargins->{{72, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    ParagraphSpacing->{0, 6},
    ParagraphIndent->-10,
    StyleMenuListing->None,
    FontFamily->"Times"],
  
  Cell[StyleData["Notes", "Printout"],
    CellMargins->{{2, 0}, {0, 8}},
    FontSize->9]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["NotesList"],
    CellMargins->{{20, 4}, {2, 8}},
    CellHorizontalScrolling->True,
    Hyphenation->True,
    ScriptLevel->1,
    SingleLetterItalics->True,
    StyleMenuListing->None,
    FontFamily->"Times"],
  
  Cell[StyleData["NotesList", "Brackets"],
    CellMargins->{{82, 4}, {2, 8}},
    CellHorizontalScrolling->True,
    ScriptLevel->1,
    SingleLetterItalics->True,
    StyleMenuListing->None,
    FontFamily->"Times"],
  
  Cell[StyleData["NotesList", "Printout"],
    CellMargins->{{12, 0}, {2, 8}},
    FontSize->9]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["ExampleSection"],
    CellFrame->{{0, 0}, {0, 0.5}},
    ShowGroupOpenCloseIcon->True,
    CellMargins->{{11, 4}, {0, 10}},
    CellGroupingRules->{"SectionGrouping", 70},
    CellFrameMargins->12,
    StyleMenuListing->None,
    FontSize->13,
    FontWeight->"Bold",
    FontSlant->"Italic",
    FontColor->RGBColor[0, 0, 0.4]],
  
  Cell[StyleData["ExampleSection", "Printout"],
    CellMargins->{{3, 0}, {0, 10}},
    PageBreakBelow->False,
    FontSize->9,
    FontColor->GrayLevel[0]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["ExampleText"],
    CellMargins->{{20, 40}, {0, 18}},
    Hyphenation->True,
    ParagraphSpacing->{0, 6},
    StyleMenuListing->None,
    FontColor->RGBColor[0, 0, 0.4]],
  
  Cell[StyleData["ExampleText", "Printout"],
    CellMargins->{{2, 80}, {0, 8}},
    PageBreakBelow->False,
    FontSize->8,
    FontColor->GrayLevel[0]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["ExampleSubsection"],
    ShowCellBracket->True,
    CellMargins->{{20, 4}, {0, 16}},
    CellGroupingRules->{"SectionGrouping", 80},
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->10,
    FontWeight->"Bold"],
  
  Cell[StyleData["ExampleSubsection", "Printout"],
    CellMargins->{{12, 0}, {0, 16}},
    PageBreakBelow->False,
    FontSize->7]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["LineHead"],
    CellFrame->{{0, 0}, {0.5, 0}},
    CellMargins->{{10, 4}, {8, 18}},
    CounterIncrements->"Subsection",
    CounterAssignments->{{"Subsubection", 0}},
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->12,
    FontWeight->"Bold"],
  
  Cell[StyleData["LineHead", "Printout"],
    CellMargins->{{2, 0}, {8, 18}},
    PageBreakBelow->False,
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["FlushInput"],
    CellMargins->{{10, 4}, {1, 4}},
    Evaluatable->True,
    CellGroupingRules->"InputGrouping",
    CellHorizontalScrolling->True,
    PageBreakWithin->False,
    GroupPageBreakWithin->False,
    CellLabelAutoDelete->False,
    CellLabelMargins->{{23, Inherited}, {Inherited, Inherited}},
    DefaultFormatType->DefaultInputFormatType,
    ShowSpecialCharacters->Automatic,
    FormatType->StandardForm,
    ShowStringCharacters->True,
    NumberMarks->True,
    StyleMenuListing->None,
    FontWeight->"Bold"],
  
  Cell[StyleData["FlushInput", "Printout"],
    CellMargins->{{2, 0}, {1, 4}},
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["FlushOutput"],
    CellMargins->{{10, Inherited}, {Inherited, Inherited}},
    CellEditDuplicate->True,
    CellGroupingRules->"OutputGrouping",
    CellHorizontalScrolling->True,
    PageBreakWithin->False,
    GroupPageBreakWithin->False,
    GeneratedCell->True,
    CellAutoOverwrite->True,
    CellLabelAutoDelete->False,
    CellLabelMargins->{{23, Inherited}, {Inherited, Inherited}},
    DefaultFormatType->DefaultOutputFormatType,
    FormatType->StandardForm,
    StyleMenuListing->None],
  
  Cell[StyleData["FlushOutput", "Printout"],
    CellMargins->{{2, Inherited}, {Inherited, Inherited}},
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["DialogItem"],
    CellDingbat->"\[EmptyDiamond]",
    CellMargins->{{20, 4}, {0, 12}},
    CellGroupingRules->{"SectionGrouping", 70},
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->10,
    FontWeight->"Bold"],
  
  Cell[StyleData["DialogItem", "Printout"],
    CellMargins->{{12, 0}, {0, 12}},
    PageBreakBelow->False,
    FontSize->8]
  }, Closed]],
  
  Cell[StyleData["GroupDivider"],
    CellMargins->{{10, Inherited}, {Inherited, Inherited}},
    CellEditDuplicate->True,
    CellGroupingRules->{"TitleGrouping", 0},
    StyleMenuListing->None],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Highlight"],
    CellMargins->{{10, 4}, {0, 18}},
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->12,
    Background->GrayLevel[0.900008]],
  
  Cell[StyleData["Highlight", "Printout"],
    CellMargins->{{2, 0}, {0, 18}},
    LineSpacing->{1, 3}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["UserNotes"],
    CellFrame->{{2, 0}, {0, 0.25}},
    CellMargins->{{10, 4}, {0, 4}},
    Hyphenation->True,
    ParagraphIndent->-7,
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->10],
  
  Cell[StyleData["UserNotes", "Printout"],
    CellMargins->{{2, 0}, {0, 4}},
    LineSpacing->{1, 3},
    FontSize->8]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["MoreInfo"],
    CellMargins->{{10, 4}, {0, 4}},
    Hyphenation->True,
    ParagraphIndent->-7,
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->10,
    FontColor->GrayLevel[1],
    Background->RGBColor[0.700008, 0.4, 0.100008]],
  
  Cell[StyleData["MoreInfo", "Printout"],
    CellMargins->{{2, 0}, {0, 4}},
    LineSpacing->{1, 3},
    FontSize->8]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["UserTips"],
    CellFrame->{{2, 0}, {0, 0.25}},
    CellMargins->{{10, 4}, {0, 4}},
    Hyphenation->True,
    ParagraphIndent->-7,
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->10,
    FontColor->GrayLevel[1],
    Background->RGBColor[0.2, 0.500008, 0.700008]],
  
  Cell[StyleData["UserTips", "Printout"],
    CellMargins->{{2, 0}, {0, 4}},
    LineSpacing->{1, 3},
    FontSize->8,
    Background->GrayLevel[0.700008]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Theorem"],
    CellFrame->{{4, 0}, {0, 0}},
    CellMargins->{{12, 62}, {0, 14}},
    CellFrameMargins->4,
    CellFrameColor->RGBColor[0, 0, 0.8],
    LineSpacing->{1, 1},
    ParagraphSpacing->{0, 8}],
  
  Cell[StyleData["Theorem", "Printout"],
    CellMargins->{{2, 0}, {0, 14}},
    CellFrameMargins->3,
    CellFrameColor->GrayLevel[0.8],
    FontSize->9,
    FontColor->GrayLevel[0]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Commentary"],
    CellFrame->{{2, 0}, {0, 0}},
    CellMargins->{{36, 10}, {7, 7}},
    PageBreakBelow->False,
    CellFrameMargins->8,
    CellFrameColor->RGBColor[0, 0.2, 1],
    Hyphenation->True,
    LineSpacing->{1, 3},
    ParagraphSpacing->{0, 8},
    FontSlant->"Italic"],
  
  Cell[StyleData["Commentary", "Printout"],
    CellMargins->{{32, 0}, {6, 6}},
    CellFrameColor->GrayLevel[0.8],
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Level1Icon"],
    ShowGroupOpenCloseIcon->True,
    CellMargins->{{10, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    ParagraphSpacing->{0, 8},
    StyleMenuListing->None],
  
  Cell[StyleData["Level1Icon", "Printout"],
    CellMargins->{{2, 0}, {0, 8}},
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Level2Icon"],
    ShowGroupOpenCloseIcon->True,
    CellMargins->{{10, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    ParagraphSpacing->{0, 8},
    StyleMenuListing->None],
  
  Cell[StyleData["Level2Icon", "Printout"],
    CellMargins->{{2, 0}, {0, 8}},
    FontSize->10]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Contents and Index", "Subsubsection"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["ContentsTitle"],
    CellMargins->{{10, 4}, {0, 18}},
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->18,
    FontWeight->"Bold"],
  
  Cell[StyleData["ContentsTitle", "Printout"],
    CellMargins->{{2, 0}, {0, 18}},
    PageBreakBelow->False,
    FontSize->18]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["ContentsSection"],
    CellDingbat->"\[FilledSquare]",
    CellMargins->{{20, 4}, {3, 18}},
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->12,
    FontWeight->"Bold"],
  
  Cell[StyleData["ContentsSection", "Printout"],
    CellMargins->{{12, 0}, {3, 18}},
    PageBreakBelow->False]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["IndexSection"],
    CellDingbat->"\[FilledSquare]",
    CellMargins->{{20, 4}, {5, 20}},
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->12,
    FontWeight->"Bold"],
  
  Cell[StyleData["IndexSection", "Printout"],
    CellMargins->{{12, 0}, {5, 20}},
    PageBreakBelow->False,
    FontSize->12]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Contents"],
    CellMargins->{{21, 4}, {0, 8}},
    StyleMenuListing->None],
  
  Cell[StyleData["Contents", "Printout"],
    CellMargins->{{13, 0}, {0, 8}},
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Index"],
    CellMargins->{{21, 4}, {0, 0}},
    ParagraphIndent->-48,
    StyleMenuListing->None],
  
  Cell[StyleData["Index", "Printout"],
    CellMargins->{{13, 0}, {0, 0}},
    FontSize->9]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["IndexSubentry"],
    CellMargins->{{36, 4}, {0, 0}},
    ParagraphIndent->-48,
    StyleMenuListing->None],
  
  Cell[StyleData["IndexSubentry", "Printout"],
    CellMargins->{{24, 0}, {0, 0}},
    FontSize->9]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Horizontal Lines", "Subsubsection"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Line1"],
    CellFrame->{{0, 0}, {0, 0.5}},
    CellMargins->{{10, 4}, {-16, 9}},
    StyleMenuListing->None,
    FontSize->2],
  
  Cell[StyleData["Line1", "Printout"],
    CellMargins->{{2, 0}, {-16, 9}}]
  }, Closed]],
  
  Cell["\<\

The item above is horizontal 0.5 pt line\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["ProgramTop"],
    CellFrame->{{0.5, 0.5}, {0, 0.5}},
    CellMargins->{{10, 4}, {-18, 18}},
    LineSpacing->{1, -4},
    StyleMenuListing->None,
    FontSize->4],
  
  Cell[StyleData["ProgramTop", "Printout"],
    CellMargins->{{2, 0}, {-18, 18}}]
  }, Closed]],
  
  Cell["\<\

The item above is a ProgramTop line
\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["ProgramBottom"],
    CellFrame->{{0.5, 0.5}, {0.5, 0}},
    CellMargins->{{10, 4}, {-10, -2}},
    LineSpacing->{1, -4},
    StyleMenuListing->None,
    FontSize->4],
  
  Cell[StyleData["ProgramBottom", "Printout"],
    CellMargins->{{2, 0}, {-10, -2}}]
  }, Closed]],
  
  Cell["\<\

The item above is a ProgramBottom line
\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["SessionLabel"],
    CellFrame->{{0.5, 0}, {0, 0.5}},
    CellMargins->{{10, 4}, {-4, 18}},
    LineSpacing->{1, -3},
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->9],
  
  Cell[StyleData["SessionLabel", "Printout"],
    CellMargins->{{2, 0}, {-4, 18}},
    FontSize->7]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Page Headers and Footers", "Subsubsection"],
  
  Cell[StyleData["PageHeader"],
    CellMargins->{{0, 0}, {2, 0}},
    StyleMenuListing->None,
    FontSize->8,
    FontSlant->"Italic"],
  
  Cell[StyleData["PageNumber"],
    CellMargins->{{0, 0}, {2, 0}},
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->8,
    FontWeight->"Bold"],
  
  Cell[StyleData["PageFooter"],
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->6]
  }, Closed]]
  }, Open  ]],
  
  Cell[CellGroupData[{
  
  Cell["Notation Package Styles", "Section",
    GeneratedCell->True,
    CellTags->"NotationPackage"],
  
  Cell["\<\
The cells below define certain styles needed by the Notation \
package. These styles serve to make visible otherwise invisible \
tagboxes.\
\>", "Text",
    GeneratedCell->True,
    CellTags->"NotationPackage"],
  
  Cell[StyleData["NotationTemplateStyle"],
    GeneratedCell->True,
    StyleMenuListing->None,
    Background->RGBColor[1, 1, 0.850004],
    TagBoxOptions->{SyntaxForm->"symbol"},
    CellTags->"NotationPackage"],
  
  Cell[StyleData["NotationPatternWrapperStyle"],
    GeneratedCell->True,
    StyleMenuListing->None,
    Background->RGBColor[1, 0.900008, 0.979995],
    TagBoxOptions->{SyntaxForm->"symbol"},
    CellTags->"NotationPackage"],
  
  Cell[StyleData["NotationMadeBoxesWrapperStyle"],
    GeneratedCell->True,
    StyleMenuListing->None,
    Background->RGBColor[0.900008, 0.889998, 1],
    TagBoxOptions->{SyntaxForm->"symbol"},
    CellTags->"NotationPackage"]
  }, Closed]]
  }],
MacintoshSystemPageSetup->"\<\
00h0001804P000000b02<?oaonl3>@91H`85N0?N0@00005X0FP000003j0:l001
0@00I00100000@0200000BL?00400000000000000000010000000000000@0?ne
oj/@7@]500P1000000000000000001T1\>"
]


(***********************************************************************
Cached data follows.  If you edit this Notebook file directly, not using
Mathematica, you must remove the line containing CacheID at the top of 
the file.  The cache data will then be recreated when you save this file 
from within Mathematica.
***********************************************************************)

(*CellTagsOutline
CellTagsIndex->{
  "Defining fitness"->{
    Cell[2488, 77, 77, 1, 24, "SubsubsectionIcon",
      CellTags->"Defining fitness"]},
  "Rules"->{
    Cell[7445, 229, 103, 2, 24, "SubsubsectionIcon",
      CellTags->"Rules"]},
  "New mean"->{
    Cell[9049, 275, 65, 1, 24, "SubsubsectionIcon",
      CellTags->"New mean"]},
  "Change in D"->{
    Cell[15185, 405, 118, 4, 24, "SubsubsectionIcon",
      CellTags->"Change in D"]},
  "aiForTwoLoci"->{
    Cell[24045, 575, 488, 9, 68, "NumberedEquation",
      CellTags->"aiForTwoLoci"]}
  }
*)

(*CellTagsIndex
CellTagsIndex->{
  {"Defining fitness", 99970, 3276},
  {"Rules", 100072, 3279},
  {"New mean", 100168, 3282},
  {"Change in D", 100269, 3285},
  {"aiForTwoLoci", 100376, 3288}
  }
*)

(*NotebookFileOutline
Notebook[{

Cell[CellGroupData[{
Cell[1739, 51, 47, 0, 36, "SubsectionIcon"],

Cell[CellGroupData[{
Cell[1811, 55, 44, 0, 24, "SubsubsectionIcon"],
Cell[1858, 57, 46, 0, 28, "MathCaption"],
Cell[1907, 59, 87, 2, 26, "Input"],
Cell[1997, 63, 72, 0, 28, "MathCaption"],
Cell[2072, 65, 379, 7, 74, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[2488, 77, 77, 1, 24, "SubsubsectionIcon",
  CellTags->"Defining fitness"],
Cell[2568, 80, 258, 8, 22, "Text"],
Cell[2829, 90, 189, 8, 28, "MathCaption"],
Cell[3021, 100, 391, 7, 75, "Input"],
Cell[3415, 109, 593, 20, 24, "Text"],
Cell[4011, 131, 286, 5, 36, "Text"],
Cell[4300, 138, 198, 6, 28, "MathCaption"],
Cell[4501, 146, 311, 5, 27, "Input"],
Cell[4815, 153, 118, 3, 28, "MathCaption"],

Cell[CellGroupData[{
Cell[4958, 160, 77, 2, 26, "Input"],
Cell[5038, 164, 428, 8, 36, "Output"]
}, Open  ]],
Cell[5481, 175, 139, 3, 28, "MathCaption"],

Cell[CellGroupData[{
Cell[5645, 182, 171, 3, 43, "Input"],
Cell[5819, 187, 1392, 30, 60, "Output"]
}, Open  ]],
Cell[7226, 220, 182, 4, 22, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[7445, 229, 103, 2, 24, "SubsubsectionIcon",
  CellTags->"Rules"],
Cell[7551, 233, 155, 3, 28, "MathCaption"],
Cell[7709, 238, 539, 9, 58, "Input"],
Cell[8251, 249, 395, 9, 22, "Text"],
Cell[8649, 260, 363, 10, 24, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[9049, 275, 65, 1, 24, "SubsubsectionIcon",
  CellTags->"New mean"],
Cell[9117, 278, 99, 3, 28, "MathCaption"],

Cell[CellGroupData[{
Cell[9241, 285, 160, 3, 31, "Input"],
Cell[9404, 290, 3362, 50, 135, "Output"]
}, Open  ]],
Cell[12781, 343, 106, 3, 28, "MathCaption"],

Cell[CellGroupData[{
Cell[12912, 350, 387, 7, 45, "Input"],
Cell[13302, 359, 833, 14, 48, "Output"]
}, Open  ]],
Cell[14150, 376, 121, 3, 22, "Text"],
Cell[14274, 381, 874, 19, 55, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[15185, 405, 118, 4, 24, "SubsubsectionIcon",
  CellTags->"Change in D"],
Cell[15306, 411, 90, 3, 22, "Text"],

Cell[CellGroupData[{
Cell[15421, 418, 508, 9, 50, "Input"],
Cell[15932, 429, 5688, 89, 397, "Output"]
}, Closed]],
Cell[21635, 521, 40, 0, 18, "Text"],

Cell[CellGroupData[{
Cell[21700, 525, 384, 7, 41, "Input"],
Cell[22087, 534, 1636, 25, 114, "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[23772, 565, 63, 0, 24, "SubsubsectionIcon"],
Cell[23838, 567, 204, 6, 29, "MathCaption"],
Cell[24045, 575, 488, 9, 68, "NumberedEquation",
  CellTags->"aiForTwoLoci"],
Cell[24536, 586, 71, 0, 28, "MathCaption"],

Cell[CellGroupData[{
Cell[24632, 590, 326, 6, 31, "Input"],
Cell[24961, 598, 281, 6, 41, "Output"]
}, Open  ]],
Cell[25257, 607, 460, 13, 29, "Text"],
Cell[25720, 622, 406, 14, 28, "Text"],
Cell[26129, 638, 203, 6, 29, "MathCaption"],
Cell[26335, 646, 208, 3, 78, "Input"],

Cell[CellGroupData[{
Cell[26568, 653, 412, 8, 31, "Input"],
Cell[26983, 663, 77, 2, 22, "Output"]
}, Open  ]],
Cell[27075, 668, 49, 0, 22, "Text"],
Cell[27127, 670, 199, 6, 28, "MathCaption"],
Cell[27329, 678, 782, 14, 56, "NumberedEquation"],
Cell[28114, 694, 482, 11, 38, "Text"]
}, Open  ]]
}, Open  ]]
}
]
*)




(***********************************************************************
End of Mathematica Notebook file.
***********************************************************************)

