(***********************************************************************

                    Mathematica-Compatible Notebook

This notebook can be used on any computer system with Mathematica 4.0,
MathReader 4.0, or any compatible application. The data for the notebook 
starts with the line containing stars above.

To get the notebook into a Mathematica-compatible application, do one of 
the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing the 
word CacheID, otherwise Mathematica-compatible applications may try to 
use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
***********************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[     10202,        270]*)
(*NotebookOutlinePosition[     11229,        304]*)
(*  CellTagsIndexPosition[     11149,        298]*)
(*WindowFrame->Normal*)



Notebook[{

Cell[CellGroupData[{
Cell["Union of Gametes", "SubsectionIcon"],

Cell[TextData[{
  " ",
  Cell[BoxData[
      FormBox[GridBox[{
            {\(UnionOfGametes[]\), \(genes\ in\ zygotes, \ \[GothicCapitalZ], \
\ derive\ from\ gametes, \ \[GothicCapitalG], \ \ of\ the\ appropriate\ \
sex\)},
            {\(\[GothicCapitalD]\_\[DoubleStruckCapitalU] /. 
                UnionOfGametes[]\), \(\(expresses\)\(\ \)\(the\)\(\ \
\)\(associations\)\(\ \)\(in\)\(\ \)\(zygotes\)\(\ \)\(in\)\(\ \)\(terms\)\(\ \
\)\(of\)\(\ \)\(those\)\(\ \)\(in\)\(\ \)\(gametes\)\(\ \)\)},
            {\(UnionOfGametes[{\[GothicCapitalG], \[GothicCapitalZ]}]\), \
\(specifies\ the\ stages\ explicitly; \ 
              allows\ other\ stages\ to\ be\ used\ if\ \(\(necessary\)\(.\)\)\
\)}
            }], TraditionalForm]]]
}], "DefinitionBox",
  CellTags->"UnionOfGametes"],

Cell["\<\
A gene in a female zygote inherited from the male parent must \
derive from a male gamete:\
\>", "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\[GothicM]\_\(i\_{\[GothicCapitalZ], \[GothicCapitalF], \
\[GothicCapitalM]}\) /. UnionOfGametes[]\)], "Input",
  CellLabel->"In[257]:="],

Cell[BoxData[
    \(\[GothicM]\_\(i\_{\[GothicCapitalG], \[GothicCapitalM]}\)\)], "Output",
  CellLabel->"Out[257]="]
}, Open  ]],

Cell["\<\
UnionOfGametes just uses the rule {{\[GothicCapitalZ],sex_,soo_}\
\[LeftArrow]{\[GothicCapitalG],soo}}\
\>", "Text"],

Cell[TextData[{
  "Note:  ",
  StyleBox["UnionOfGametes[] is an ordinary ",
    FontWeight->"Plain"],
  StyleBox["Mathematica",
    FontWeight->"Plain",
    FontSlant->"Italic"],
  StyleBox[" rule, and can be applied using /.  Internally, it applies the \
transmission rule ",
    FontWeight->"Plain"],
  "{\[GothicCapitalZ],sex_,soo_}\[LeftArrow]{\[GothicCapitalG],soo} ",
  StyleBox["using the special operator \[CirclePlus] or ChangeContext.",
    FontWeight->"Plain"]
}], "Text",
  FontWeight->"Bold"],

Cell["\<\
Under random union, the zygotic \[GothicCapitalD] are just products \
of the gametic \[GothicCapitalD] in the male & female gamete pools; in \
general, however, there may be associations in the gamete pool, generated by \
nonrandom mating.  \
\>", "Text"],

Cell["\<\
UnionOfGametes relates associations among a set of genes in zygotes \
to the corresponding association in gametes:\
\>", "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\[GothicCapitalD]\_{i\_{\[GothicCapitalZ], \[GothicCapitalM], \
\[GothicCapitalM]}, k\_{\[GothicCapitalZ], \[GothicCapitalM], \
\[GothicCapitalF]}} /. UnionOfGametes[]\)], "Input",
  CellLabel->"In[258]:="],

Cell[BoxData[
    \(\[GothicCapitalD]\_{i\_{\[GothicCapitalG], \[GothicCapitalM]}, k\_{\
\[GothicCapitalG], \[GothicCapitalF]}} + \[GothicCapitalD]\_{k\_{\
\[GothicCapitalG], \[GothicCapitalF]}}\ \((\[WeierstrassP]\_\(i\_{\
\[GothicCapitalG], \[GothicCapitalM]}\) - \[WeierstrassP]\_\(i\_{\
\[GothicCapitalZ], \[GothicCapitalM], \[GothicCapitalM]}\))\) + \
\[GothicCapitalD]\_{i\_{\[GothicCapitalG], \[GothicCapitalM]}}\ \((\
\[WeierstrassP]\_\(k\_{\[GothicCapitalG], \[GothicCapitalF]}\) - \
\[WeierstrassP]\_\(k\_{\[GothicCapitalZ], \[GothicCapitalM], \
\[GothicCapitalF]}\))\) + \((\[WeierstrassP]\_\(i\_{\[GothicCapitalG], \
\[GothicCapitalM]}\) - \[WeierstrassP]\_\(i\_{\[GothicCapitalZ], \
\[GothicCapitalM], \[GothicCapitalM]}\))\)\ \((\[WeierstrassP]\_\(k\_{\
\[GothicCapitalG], \[GothicCapitalF]}\) - \[WeierstrassP]\_\(k\_{\
\[GothicCapitalZ], \[GothicCapitalM], \[GothicCapitalF]}\))\)\)], "Output",
  CellLabel->"Out[258]="]
}, Open  ]],

Cell["\<\
This is an association among a set of genes in the male gamete, and \
a set of genes in the female gamete: that association may be non-zero if \
there is non-random mating  It involves extra terms due to a possible change \
in reference point.  To simplify, we must use some convention about the \
reference point.  \
\>", "Text"],

Cell[TextData[{
  "Assuming that the reference point is the mean of each sex separately ",
  Cell[BoxData[
      \(TraditionalForm\`\((\[WeierstrassP]\_\[DoubleStruckI] \[Congruent] 
          m\_\[DoubleStruckI]\ among\ gametes)\)\)]],
  ":"
}], "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(\[GothicCapitalD]\_{i\_{\[GothicCapitalZ], \[GothicCapitalM], \
\[GothicCapitalM]}, k\_{\[GothicCapitalZ], \[GothicCapitalM], \
\[GothicCapitalF]}} /. UnionOfGametes[]\) /. 
      ReferencePointZero[\[GothicCapitalG]]\)], "Input",
  CellLabel->"In[259]:="],

Cell[BoxData[
    \(\[GothicCapitalD]\_{i\_{\[GothicCapitalG], \[GothicCapitalM]}, k\_{\
\[GothicCapitalG], \[GothicCapitalF]}} + \((\[GothicM]\_\(i\_{\
\[GothicCapitalG], \[GothicCapitalM]}\) - \[WeierstrassP]\_\(i\_{\
\[GothicCapitalZ], \[GothicCapitalM], \[GothicCapitalM]}\))\)\ \
\((\[GothicM]\_\(k\_{\[GothicCapitalG], \[GothicCapitalF]}\) - \
\[WeierstrassP]\_\(k\_{\[GothicCapitalZ], \[GothicCapitalM], \
\[GothicCapitalF]}\))\)\)], "Output",
  CellLabel->"Out[259]="]
}, Open  ]],

Cell["\<\
This still involves a term due to the change in reference point \
between zygotes and gametes.  Assuming that there is no change, and \
re-applying the rule for gametic reference point, removes these terms:\
\>", \
"MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(\(\(\[GothicCapitalD]\_{i\_{\[GothicCapitalZ], \[GothicCapitalM], \
\[GothicCapitalM]}, k\_{\[GothicCapitalZ], \[GothicCapitalM], \
\[GothicCapitalF]}} /. UnionOfGametes[]\) /. 
          ReferencePointZero[\[GothicCapitalG]]\) /. 
        ReferencePointSame[\[GothicCapitalG], \[GothicCapitalZ]]\) /. 
      ReferencePointZero[\[GothicCapitalG]]\)], "Input",
  CellLabel->"In[105]:="],

Cell[BoxData[
    \(\[GothicCapitalD]\_{i\_{\[GothicCapitalG], \[GothicCapitalM]}, k\_{\
\[GothicCapitalG], \[GothicCapitalF]}}\)], "Output",
  CellLabel->"Out[105]="]
}, Open  ]],

Cell["\<\
Now, consider the calculation with the alternative convention that \
the reference point is equal to the allele frequency in the gamete pool, \
averaged over the sexes:\
\>", "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(\[GothicCapitalD]\_{i\_{\[GothicCapitalZ], \[GothicCapitalM], \
\[GothicCapitalM]}, k\_{\[GothicCapitalZ], \[GothicCapitalM], \
\[GothicCapitalF]}} /. UnionOfGametes[]\) /. 
      ReferencePointMean[\[GothicCapitalG], m]\)], "Input",
  CellLabel->"In[261]:="],

Cell[BoxData[
    \(\[GothicCapitalD]\_{i\_{\[GothicCapitalG], \[GothicCapitalM]}, k\_{\
\[GothicCapitalG], \[GothicCapitalF]}} + 
      1\/2\ \((m[k\_{\[GothicCapitalG], \[GothicCapitalF]}] - 
            m[k\_{\[GothicCapitalG], \[GothicCapitalM]}])\)\ \((1\/2\ \((m[
                    i\_{\[GothicCapitalG], \[GothicCapitalF]}] + 
                  m[i\_{\[GothicCapitalG], \[GothicCapitalM]}])\) - \
\[WeierstrassP]\_\(i\_{\[GothicCapitalZ], \[GothicCapitalM], \
\[GothicCapitalM]}\))\) + 
      1\/2\ \((\(-m[i\_{\[GothicCapitalG], \[GothicCapitalF]}]\) + 
            m[i\_{\[GothicCapitalG], \[GothicCapitalM]}])\)\ \((1\/2\ \((m[
                    k\_{\[GothicCapitalG], \[GothicCapitalF]}] + 
                  m[k\_{\[GothicCapitalG], \[GothicCapitalM]}])\) - \
\[WeierstrassP]\_\(k\_{\[GothicCapitalZ], \[GothicCapitalM], \
\[GothicCapitalF]}\))\) + \((1\/2\ \((m[
                    i\_{\[GothicCapitalG], \[GothicCapitalF]}] + 
                  m[i\_{\[GothicCapitalG], \[GothicCapitalM]}])\) - \
\[WeierstrassP]\_\(i\_{\[GothicCapitalZ], \[GothicCapitalM], \
\[GothicCapitalM]}\))\)\ \((1\/2\ \((m[
                    k\_{\[GothicCapitalG], \[GothicCapitalF]}] + 
                  m[k\_{\[GothicCapitalG], \[GothicCapitalM]}])\) - \
\[WeierstrassP]\_\(k\_{\[GothicCapitalZ], \[GothicCapitalM], \
\[GothicCapitalF]}\))\)\)], "Output",
  CellLabel->"Out[261]="]
}, Open  ]],

Cell["\<\
All the complicated terms vanish when the reference points are \
taken to be the same in zygotes as in gametes:\
\>", "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(\(\[GothicCapitalD]\_{i\_{\[GothicCapitalZ], \[GothicCapitalM], \
\[GothicCapitalM]}, k\_{\[GothicCapitalZ], \[GothicCapitalM], \
\[GothicCapitalF]}} /. UnionOfGametes[]\) /. 
          ReferencePointSame[\[GothicCapitalG], \[GothicCapitalZ]]\) /. 
        ReferencePointMean[\[GothicCapitalG], m] // Simplify\)], "Input",
  CellLabel->"In[48]:=  (18:52:40 on 3/3/01)"],

Cell[BoxData[
    \(\[GothicCapitalD]\_{i\_{\[GothicCapitalG], \[GothicCapitalM]}, k\_{\
\[GothicCapitalG], \[GothicCapitalF]}}\)], "Output",
  CellLabel->"Out[48]=  (18:52:40 on 3/3/01)"]
}, Open  ]]
}, Open  ]]
},
FrontEndVersion->"4.0 for Macintosh",
ScreenRectangle->{{0, 1024}, {0, 748}},
WindowSize->{675, 632},
WindowMargins->{{14, Automatic}, {Automatic, 1}},
StyleDefinitions -> "HelpBrowser.nb",
MacintoshSystemPageSetup->"\<\
00<0001804P000000]P2:?oQon82n@960dL5:0?l0080001804P000000]P2:001
0000I00000400`<300000BL?00400@0000000000000006P801T1T00000000000
00000000000000000000000000000000\>"
]


(***********************************************************************
Cached data follows.  If you edit this Notebook file directly, not using
Mathematica, you must remove the line containing CacheID at the top of 
the file.  The cache data will then be recreated when you save this file 
from within Mathematica.
***********************************************************************)

(*CellTagsOutline
CellTagsIndex->{
  "UnionOfGametes"->{
    Cell[1784, 53, 784, 17, 74, "DefinitionBox",
      CellTags->"UnionOfGametes"]}
  }
*)

(*CellTagsIndex
CellTagsIndex->{
  {"UnionOfGametes", 11039, 291}
  }
*)

(*NotebookFileOutline
Notebook[{

Cell[CellGroupData[{
Cell[1739, 51, 42, 0, 36, "SubsectionIcon"],
Cell[1784, 53, 784, 17, 74, "DefinitionBox",
  CellTags->"UnionOfGametes"],
Cell[2571, 72, 121, 3, 28, "MathCaption"],

Cell[CellGroupData[{
Cell[2717, 79, 157, 3, 31, "Input"],
Cell[2877, 84, 117, 2, 24, "Output"]
}, Open  ]],
Cell[3009, 89, 126, 3, 22, "Text"],
Cell[3138, 94, 505, 14, 40, "Text"],
Cell[3646, 110, 265, 5, 36, "Text"],
Cell[3914, 117, 145, 3, 28, "MathCaption"],

Cell[CellGroupData[{
Cell[4084, 124, 226, 4, 33, "Input"],
Cell[4313, 130, 936, 14, 48, "Output"]
}, Open  ]],
Cell[5264, 147, 340, 6, 50, "Text"],
Cell[5607, 155, 261, 6, 28, "MathCaption"],

Cell[CellGroupData[{
Cell[5893, 165, 278, 5, 33, "Input"],
Cell[6174, 172, 476, 8, 28, "Output"]
}, Open  ]],
Cell[6665, 183, 239, 5, 42, "MathCaption"],

Cell[CellGroupData[{
Cell[6929, 192, 407, 7, 47, "Input"],
Cell[7339, 201, 167, 3, 26, "Output"]
}, Open  ]],
Cell[7521, 207, 199, 4, 42, "MathCaption"],

Cell[CellGroupData[{
Cell[7745, 215, 281, 5, 33, "Input"],
Cell[8029, 222, 1381, 23, 92, "Output"]
}, Open  ]],
Cell[9425, 248, 142, 3, 28, "MathCaption"],

Cell[CellGroupData[{
Cell[9592, 255, 391, 6, 47, "Input"],
Cell[9986, 263, 188, 3, 26, "Output"]
}, Open  ]]
}, Open  ]]
}
]
*)




(***********************************************************************
End of Mathematica Notebook file.
***********************************************************************)

