(***********************************************************************

                    Mathematica-Compatible Notebook

This notebook can be used on any computer system with Mathematica 4.0,
MathReader 4.0, or any compatible application. The data for the notebook 
starts with the line containing stars above.

To get the notebook into a Mathematica-compatible application, do one of 
the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing the 
word CacheID, otherwise Mathematica-compatible applications may try to 
use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
***********************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[    712137,      14944]*)
(*NotebookOutlinePosition[    751166,      16256]*)
(*  CellTagsIndexPosition[    751122,      16252]*)
(*WindowFrame->Normal*)



Notebook[{
Cell[BoxData[
    \(\(BeginPackage["\<Multilocus`EstimatingD`\>", \n\t\
{"\<Algebra`InequalitySolve`\>", "\<Utilities`SetManipulation`\>", \
"\<Utilities`Cumulants`\>", "\<Statistics`DescriptiveStatistics`\>", \
"\<Statistics`MultiDescriptiveStatistics`\>", \
"\<Statistics`ContinuousDistributions`\>", \
"\<Statistics`DataManipulation`\>", "\<Graphics`Graphics`\>", \
"\<Utilities`RandomNumbers`\>", "\<Multilocus`DataManipulation`\>"}];\)\)], \
"Input",
  InitializationCell->True],

Cell[CellGroupData[{

Cell["Public parts", "Section"],

Cell[BoxData[
    \(\(Off[General::spell1, General::spell];\)\)], "Input",
  InitializationCell->True],

Cell[CellGroupData[{

Cell["Obsolete functions", "Subsection"],

Cell[CellGroupData[{

Cell[BoxData[
    StyleBox[\(RandomMating[
          c]\ simplifies\ the\ moments\ c[]\ on\ the\ assumption\ of\ random\ \
mating\ between\ diploids . \ \ For\ example, \ \ c[{i, \(i\^*\), \
\(j\&^\^*\), k\&^\^\[Dagger]}] /. 
        RandomMating[
            c]\ gives\ c[{i, \(i\^*\)}]\ c[{\(j\&^\^*\), k\&^\^\[Dagger]}]\),
      FontFamily->"Times"]], "Subsubsection"],

Cell[BoxData[
    \(\(RandomMating::usage = \*"\"\<RandomMating[c] simplifies the moments \
c[] on the assumption of random mating between diploids.  For example,  c[{i,\
\!\(\(i\^*\)\),\!\(\(j\&^\^*\)\),\!\(k\&^\^\[Dagger]\)}]/.RandomMating[c] \
gives c[{i,\!\(\(i\^*\)\)}] \
c[{\!\(\(j\&^\^*\)\),\!\(k\&^\^\[Dagger]\)}]\>\"";\)\)], "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{

Cell["Recombined", "Subsubsection"],

Cell[BoxData[
    \(\(Recombined::usage = "\<Recombined[c[M],r] gives the value of c[M] \
after recombination; it is a sum over all partitions of M. Note that \
r[{i},{j}], r[{j},{i}] etc are grouped together as a single coefficient.  \
Recombined[c[M],r,d,i] gives the value of c[M] after recombination, with an \
additive modifier of effect d[S,i] at locus i.\>";\)\)], "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    StyleBox[\(ChangeSex[{i, \(j\^*\)}]\ returns\ {\(i\^*\), 
            j} . \ \ Obsolete . \),
      FontFamily->"Times"]], "Subsubsection"],

Cell[BoxData[
    \(\(ChangeSex::usage = \*"\"\<ChangeSex[{i,\!\(\(j\^*\)\)}] returns {\!\(\
\(i\^*\)\),j}.  Obsolete.\>\"";\)\)], "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{

Cell["ShiftCentre", "Subsubsection"],

Cell[BoxData[
    \(\(ShiftCentre::usage = "\<ShiftCentre[c[S],\[CapitalDelta]p] gives \
c[S], relative to a new centre at p-\[CapitalDelta]p\>";\)\)], "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{

Cell["RandomUnionObsolete", "Subsubsection"],

Cell[BoxData[
    \(\(RandomUnionObsolete::usage = \*"\"\<RandomUnionObsolete[c] simplifies \
the moments c[] on the assumption of random union of gametes.  For example,  \
c[{i, \!\(\(i\^*\)\), \!\(\(j\^*\)\), \
\!\(k\^\[Dagger]\)}]/.RandomUnionObsolete[c] gives c[{i, \!\(k\^\[Dagger]\)}] \
c[{\!\(\(i\^*\)\), \!\(\(j\^*\)\)}]\>\"";\)\)], "Input",
  InitializationCell->True]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["Moments from g[X], g[X] from moments & cumulants", "Subsection"],

Cell[CellGroupData[{

Cell["Diploid", "Subsubsection"],

Cell[BoxData[
    \(\(Diploid::usage = "\<Diploid is an option for MomentFromG. \>";\)\)], \
"Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{

Cell["\<\
MomentFromG[{i,j},g,p,S] gives the moment c[{i,j}], relative to \
allele frequencies p[i], as a function of gamete frequencies g[]; S is the \
complete set of loci.\
\>", "Subsubsection"],

Cell[BoxData[
    \(\(MomentFromG::usage = \*"\"\<MomentFromG[{i,j},g,p,S] gives the moment \
c[{i,j}], relative to allele frequencies p[i], as a function of gamete \
frequencies g[]; S is the complete set of loci. \
MomentFromG[{i,\!\(\(j\^*\)\)},g,p,S,Ploidy\[Rule]Diploid] allows for diploid \
genotype frequencies.\>\"";\)\)], "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    \(TextForm
    \`MomentReduced[U, {cw, cb}, \[Delta]p]\ returns\ moments\ in\ terms\ of\ 
        the\ within - \ and\ between - 
      genome\ associations\ of\ order\ n . \ \ For\ example, \ \ 
    MomentReduced[{i, j, k}, {cw, cb}, \[Delta]p]\ gives\ cw[3] \[Delta]p[i] 
      \[Delta]p[j] \[Delta]p[k]; \ 
    MomentReduced[{i, j, \(k*\)}, {cw, cb}, \[Delta]p]\ gives\ cb[3] 
        \[Delta]p[i] \[Delta]p[j] 
        \[Delta]p[k] . \ \ MomentReduced[{kw, kb}, {jU, jV}]\ returns\ an\ 
        expression\ for\ the\ moment\ c[U, \(V*\)]\ in\ terms\ of\ the\ 
        cumulants\ within - \ and\ between - genomes\ kw, \ 
    kb . \ For\ example, \ 
    MomentReduced[{kw, kb}, {2, 2}]\ is\ 2  kb[2\(]\^2\) + kb[4] + 
      kw[2\(]\^2\) . \ \ Stores\ 
        results . \ \ \(MomentReduced[n]\)[{\(cw[2] .. \) cb[2] .. }]\ is\ a\ 
        compiled\ version\ that\ returns\ the\ matrix\ of\ \(moments . \)\)], 
  "Subsubsection"],

Cell[BoxData[
    \(\(MomentReduced::usage = \*"\"\<MomentReduced[U,{cw,cb},\[Delta]p] \
returns moments in terms of the within- and between-genome associations of \
order n.  For example,  MomentReduced[{i,j,k},{cw,cb},\[Delta]p] gives cw[3]\
\[Delta]p[i]\[Delta]p[j]\[Delta]p[k]; \
MomentReduced[{i,j,k*},{cw,cb},\[Delta]p] gives cb[3]\[Delta]p[i]\[Delta]p[j]\
\[Delta]p[k].  MomentReduced[{kw,kb},{jU,jV}] returns an expression for the \
moment c[U,V*] in terms of the cumulants within- and between-genomes kw, kb. \
For example, MomentReduced[{kw,kb},{2,2}] is 2kb[2\!\(\(]\^2\)\)+kb[4]+kw[2\!\
\(\(]\^2\)\).  Stores results.  MomentReduced[n][{cw[2]..cb[2]..}] is a \
compiled version that returns the matrix of moments.\>\"";\)\)], "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    \(TextForm
    \`CumulantReduced[{cw, cb}, {jU, jV}]\ returns\ an\ expression\ for\ the\ 
        cumulant\ \[Kappa][U, \(V*\)]\ in\ terms\ of\ the\ moments\ within - 
      \ and\ between - genomes\ {cw, cb} . \ For\ example, \ 
    CumulantReduced[{cw, cb}, {2, 2}]\ is\  - 2  cb[2\(]\^2\) + cb[4] - 
      cw[2\(]\^2\) . \ \ Stores\ \(results . \)\)], "Subsubsection"],

Cell[BoxData[
    \(\(CumulantReduced::usage = \*"\"\<CumulantReduced[{cw,cb},{jU,jV}] \
returns an expression for the cumulant \[Kappa][U,V*] in terms of the moments \
within- and between-genomes {cw,cb}. For example, \
CumulantReduced[{cw,cb},{2,2}] is -2cb[2\!\(\(]\^2\)\)+cb[4]-cw[2\!\(\(]\^2\)\
\).  Stores results. \>\"";\)\)], "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{

Cell["\<\
HaploidGenotypeFrequency[X,c,p,S] gives an expression for g[X] in \
terms of the moments c[] and allele frequencies p[]. \
HaploidGenotypeFrequency[nloci][p1,..pn,c[{1,2}]...] stores a compiled \
version of g[{1,1..},..], which takes as arguments the n allele frequencies \
and 2^n-n-1 moments.  HaploidGenotypeFrequency[X,c,p] uses this to find the \
frequency of genotype X; c and p must then be given as lists of numbers\
\>", \
"Subsubsection"],

Cell[BoxData[
    \(\(HaploidGenotypeFrequency::usage = \
"\<HaploidGenotypeFrequency[X,c,p,S] gives an expression for g[X] in terms of \
the moments c[] and allele frequencies p[]. \
HaploidGenotypeFrequency[nloci][p1,..pn,c[{1,2}]...] stores a compiled \
version of g[{1,1..},..], which takes as arguments the n allele frequencies \
and 2^n-n-1 moments.  HaploidGenotypeFrequency[X,c,p] uses this to find the \
frequency of genotype X; c and p must then be given as lists of numbers\>";\)\
\)], "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{

Cell["\<\
PossibleDiploidGenotypes[{0,1,0}] gives the list of actual \
genotypes, {{{0,1,0},{0,0,0}},{{{0,0,0},{0,1,0}}}, consistent with this \
diploid genotype. \
\>", "Subsubsection"],

Cell[BoxData[
    \(\(PossibleDiploidGenotypes::usage = \
"\<PossibleDiploidGenotypes[{0,1,0}] gives the list of actual genotypes, \
{{{0,1,0},{0,0,0}},{{{0,0,0},{0,1,0}}}, consistent with this diploid \
genotype. \>";\)\)], "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    \(TextForm
    \`DiploidGenotypeFrequency[{X, \(X\^*\)}, c, p, S]\ gives\ the\ frequency
      \ of\ diploid\ genotype\ {X, \(X\^*\)}\ in\ terms\ of\ the\ moments\ and
      \ allele\ frequencies, \ c[], \ 
    p[] . \ \ DiploidGenotypeFrequency[{X, \(X\^*\)}, c, p]\ uses\ the\ 
      compiled\ version, \ where\ c\ and\ p\ are\ lists\ of\ numbers; \ 
    c\ lists\ the\ moments\ in\ the\ same\ order\ as\ DiploidSubsets[]\)], 
  "Subsubsection"],

Cell[BoxData[
    \(\(DiploidGenotypeFrequency::usage = \
"\<DiploidGenotypeFrequency[{1,2,1},c,p,{i,j,k}] gives the frequency of \
diploid genotype {1,2,1} in terms of the moments and allele frequencies, c[], \
p[].  DiploidGenotypeFrequency[{1,2,1},c,p] uses the compiled version, where \
c and p are lists of numbers; c lists the moments in the same order as \
DiploidSubsets[]\>";\)\)], "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    \(TextForm
    \`DiploidGenotypeFrequencyReduced[{0, 2, 0, 0, 1}, {k\_w, k\_b}, 
        \[Delta]p, p, S]\ gives\ the\ frequency\ of\ the\ diploid\ genotype\ 
      using\ simplified\ cumulants\ k\_w[], \ \(k\_b[] . \)\)], 
  "Subsubsection"],

Cell[BoxData[
    \(\(DiploidGenotypeFrequencyReduced::usage = \
\*"\"\<DiploidGenotypeFrequencyReduced[{0,2,0,0,1},{\!\(k\_w\),\!\(k\_b\)},\
\[Delta]p,p,S] gives the frequency of the diploid genotype using simplified \
cumulants \!\(k\_w\)[], \!\(k\_b\)[]. \>\"";\)\)], "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    \(TextForm
    \`FullGenotypeFrequencyReduced[{X, \(X\^*\)}, {k\_w, k\_b}, \[Delta]p, p, 
        S]\ gives\ the\ frequency\ of\ the\ full\ diploid\ genotype
      \ {X, \ \(X\^*\)} in\ terms\ of\ the\ reduced\ set\ of\ cumulants
      \ {k\_w, k\_b} . \ FullGenotypeFrequencyReduced[X, k, \[Delta]p, p, S]\ 
      gives\ haploid\ genotype\ \(freqiuencies . \)\)], "Subsubsection"],

Cell[BoxData[
    \(\(FullGenotypeFrequencyReduced::usage = \
\*"\"\<FullGenotypeFrequencyReduced[{X,\!\(\(X\^*\)\)},{\!\(k\_w\),\!\(k\_b\)}\
,\[Delta]p,p,S] gives the frequency of the full diploid genotype {X, \
\!\(\(X\^*\)\)}in terms of the reduced set of cumulants \
{\!\(k\_w\),\!\(k\_b\)}. FullGenotypeFrequencyReduced[X,k,\[Delta]p,p,S] \
gives haploid genotype freqiuencies.\>\"";\)\)], "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{

Cell["\<\
DiploidGenotypeFrequencyArguments[nloci][p1,..,q1,..,cw[2],..cb[2]..\
] gives an array listing all the 
  arguments that must be supplied to FullGenotypeFrequencyTable[nloci,1&][] \
to give the genotype 
  frequencies\
\>", "Subsubsection"],

Cell[BoxData[
    \(\(DiploidGenotypeFrequencyArguments::usage = \
"\<DiploidGenotypeFrequencyArguments[nloci][p1,..,q1,..,cw[2],..cb[2]..] \
gives an array listing all the arguments that must be supplied to \
FullGenotypeFrequencyTable[nloci,1&][] to give the genotype \
frequencies.\>";\)\)], "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    \(TextForm
    \`FullGenotypeFrequencyTable[{{0, 1, 0}, {1, 0, 1}}, {k\_w, \ k\_b}, 
          \[Delta]p, p, {i, j, k}]\ gives\ the\ diploid\ genotype\ frequency\ 
        in\ terms\ of\ cumulants\ k\_w[2] .. , \ 
    \(k\_b[2] .. \)\ \ Fast\ method\ which\ works\ by\ storing\ the\ general\ 
      expression\ for\ {{1, 1, 1}, {1, 1, 1}}\ in\ terms\ of\ $p, 
    \ $\[Delta]p, \ 
    and\ then\ permuting\ 
      it . \ FullGenotypeFrequencyTable[, {k\_w, \ k\_b}, {i, j, k}]\ stores\ 
      the\ generic\ solution, \ 
    and\ FullGenotypeFrequencyTable[nloci]\ the\ compiled\ version; \ 
    this\ is\ called\ as\ 
      \(FullGenotypeFrequencyTable[nl]\)[p1,  ... , \(p1*\) ... , 
        \[Delta]p1,  .. , \(\[Delta]p1*\) .. , cw2 ... , cb2 ... ], \ 
    with\ 7  nl - 
        2\ arguments . \ \ 
            FullGenotypeFrequencyTable[nloci, Symmetric \[Rule] True]\ assumes
          \ p = \(p*\ and\ \[Delta]p = 
        1\  . \ \ 
            FullGenotypeFrequencyTable[{{0, 1, 0}, {1, 0, 1}}, {k\_w, \ 
                k\_b}, \[Delta]p, p]\ calls\ the\ compiled\ version\ 
          FullGenotypeFrequencyTable[3] . \ 
            FullGenotypeFrequencyTable[{{0, 1, 0}, {1, 0, 1}}]\ is\ itself\ 
          compiled\); \ assumes\ \[Delta]p = 1, \ and\ takes\ arguments\ p, 
    q, , k\_w, \ 
    k\_b . \ \ FullGenotypeFrequencyTable[nloci, 1&]\ takes\ 
      arguments\ [{p1,  .. }, {\[Delta]p1 .. }, {c .. }]\ but\ is\ 
      slower . \ FullGenotypeFrequencyTable[nloci, Integer \[Rule] True]\ is\ 
      \(fastest : \ assumes\ \[Delta]p\ \(integer . \)\)\)], "Subsubsection"],

Cell[BoxData[
    \(\(FullGenotypeFrequencyTable::usage = \
\*"\"\<FullGenotypeFrequencyTable[{{0,1,0},{1,0,1}},{\!\(k\_w\), \!\(k\_b\)},\
\[Delta]p,p,{i,j,k}] gives the diploid genotype frequency in terms of \
cumulants \!\(k\_w\)[2].., \!\(k\_b\)[2]..  Fast method which works by \
storing the general expression for {{1,1,1},{1,1,1}} in terms of $p, \
$\[Delta]p, and then permuting it. FullGenotypeFrequencyTable[,{\!\(k\_w\), \
\!\(k\_b\)},{i,j,k}] stores the generic solution, and \
FullGenotypeFrequencyTable[nloci] the compiled version; this is called as \
FullGenotypeFrequencyTable[nl][p1,...,p1*...,\[Delta]p1,..,\[Delta]p1*..,cw2..\
.,cb2...], with 7nl-2 arguments.  FullGenotypeFrequencyTable[nloci,Symmetric\
\[Rule]True] assumes p=p* and \[Delta]p=1 .  \
FullGenotypeFrequencyTable[{{0,1,0},{1,0,1}},{\!\(k\_w\), \
\!\(k\_b\)},\[Delta]p,p] calls the compiled version \
FullGenotypeFrequencyTable[3]. FullGenotypeFrequencyTable[{{0,1,0},{1,0,1}}] \
is itself compiled; assumes \[Delta]p=1, and takes arguments p,q,,\!\(k\_w\), \
\!\(k\_b\).  FullGenotypeFrequencyTable[nloci,1&] takes arguments [{p1,..},{\
\[Delta]p1..},{c..}] but is slower. FullGenotypeFrequencyTable[nloci,Integer\
\[Rule]True] is fastest: assumes \[Delta]p integer. \>\"";\)\)], "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    \(TextForm
    \`DiploidGenotypeFrequencyTable[{0, 2, 0}, {k\_w, k\_b}, \[Delta]p, p, S]
          \ gives\ the\ diploid\ genotype\ frequency\ in\ terms\ of\ cumulants
        \ k\_w[2] .. , \ 
    \(k\_b[2] .. \)\ \ Uses\ FullGenotypeFrequencyTable[] . \ \ Also\ can\ use
      \ DiploidGenotypeFrequencyTable[{0, 2, 0}, {k\_w, k\_b}, \[Delta]p, p], 
    \ which\ uses\ the\ compiled\ 
      version . \ \ 
        \(DiploidGenotypeFrequencyTable[{0, 2, 0}, \[Delta]p]\)[p[1] .. , 
          k\_w[2] .. , \ k\_b[2] ... ]\ is\ fully\ 
      compiled . \ \ 
        \(DiploidGenotypeFrequencyTable[\[Delta]p]\)[p[1] .. , k\_w[2] .. , \ 
          k\_b[2] ... ]\ is\ fully\ compiled; \ 
    returns\ the\ complete\ vector\ of\ genotype\ frequencies\)], 
  "Subsubsection"],

Cell[BoxData[
    \(\(DiploidGenotypeFrequencyTable::usage = \
\*"\"\<DiploidGenotypeFrequencyTable[{0,2,0},{\!\(k\_w\),\!\(k\_b\)},\[Delta]\
p,p,S] gives the diploid genotype frequency in terms of cumulants \
\!\(k\_w\)[2].., \!\(k\_b\)[2]..  Uses FullGenotypeFrequencyTable[].  Also \
can use DiploidGenotypeFrequencyTable[{0,2,0},{\!\(k\_w\),\!\(k\_b\)},\[Delta]\
p,p], which uses the compiled version.  \
DiploidGenotypeFrequencyTable[{0,2,0},\[Delta]p][p[1]..,\!\(k\_w\)[2].., \
\!\(k\_b\)[2]...] is fully compiled.  DiploidGenotypeFrequencyTable[nloci,\
\[Delta]p][p[1]..,\!\(k\_w\)[2].., \!\(k\_b\)[2]...] is fully compiled; \
returns the complete vector of genotype frequencies. \>\"";\)\)], "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData[{
  "GenotypeFrequencyFast[3][{{0,1,0},{1,1,1}},{p1..},{\[Delta]p1..},",
  "MomentReduced",
  "[3][cl]] is a compiled function which calculates a specific genotype \
frequency using the matrix method.  Surprisingly, no faster than \
FullGenotypeFrequencyTable[3,int]. "
}], "Subsubsection",
  InitializationCell->True],

Cell[BoxData[
    \(\(GenotypeFrequencyFast::usage = \
"\<GenotypeFrequencyFast[3][{{0,1,0},{1,1,1}},{p1..},{\[Delta]p1..},\
MomentReduced[3][cl]] is a compiled function which calculates a specific \
genotype frequency using the matrix method.  Surprisingly, no faster than \
FullGenotypeFrequencyTable[3,int].  \>";\)\)], "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData[{
  "GenotypeFrequencyFastVector[nloci][{p1..},{\[Delta]p1,..},{cw[1]..cb[1]....\
}] is a compiled function which calculates the 16 by 16 array of genotype \
frequencies as Matrix\[CapitalGamma][n][p,\[Delta]p].",
  "MomentReduced",
  "[n][cl].Matrix\[CapitalGamma][n][p,\[Delta]p]"
}], "Subsubsection",
  InitializationCell->True],

Cell[BoxData[
    \(\(GenotypeFrequencyFastVector::usage = \
"\<GenotypeFrequencyFastVector[nloci][{p1..},{\[Delta]p1,..},{cw[1]..cb[1]....\
}] is a compiled function which calculates the 16 by 16 array of genotype \
frequencies as \
Matrix\[CapitalGamma][n][p,\[Delta]p].MomentReduced[n][cl].Matrix\
\[CapitalGamma][n][p,\[Delta]p].  \
GenotypeFrequencyFastVector[{p1..},{\[Delta]p1,..},{cw[1]..cb[1]....},nloci] \
is not compiled\>";\)\)], "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{

Cell["\<\
SignMask[X] stores the signs associated with the moments of this \
genotype\
\>", "Subsubsection"],

Cell[BoxData[
    \(\(SignMask::usage = "\<SignMask[X] stores the signs associated with the \
moments of this genotype\>";\)\)], "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    \(TextForm\`\(\ 
    Moment[\[Kappa], {jU, jV}]\ returns\ an\ expression\ for\ the\ moment\ 
        c[U, \(V*\)]\ in\ terms\ of\ the\ cumulants\ within - \ 
      and\ between - genomes\ \[Kappa]\_\(j, k\) . \ For\ example, \ 
    Moment[\[Kappa], {2, 2}]\ is\ 2  \[Kappa][1, 1\(]\^2\) + \[Kappa][2, 2] + 
      \[Kappa][0, 2\(]\^2\) . \ \ Stores\ 
        results . \ \ 
          \(Moment[n]\)[{{\[Kappa]\_\(0, 0\), \[Ellipsis]}, \[Ellipsis]}]\ is
        \ a\ compiled\ version\ that\ returns\ the\ matrix\ of\ 
        moments . \ \ Moment[U, c, \[Delta]p]\ returns\ moments\ in\ terms\ of
        \ the\ matrix\ of\ within - \ and\ between - genome\ associations, \ 
    c\_\(j, k\) . \ \ For\ example, \ \ 
    Moment[{i, j, k}, c, \[Delta]p]\ gives\ c[3, 0] \[Delta]p[i] \[Delta]p[j] 
      \[Delta]p[k]; \ 
    Moment[{i, j, \(k*\)}, {cw, cb}, \[Delta]p]\ gives\ c[2, 1] \[Delta]p[i] 
      \[Delta]p[j] \(\[Delta]p[\(k\^*\)] . \)\ \)\)], "Subsubsection"],

Cell[BoxData[
    \(\(Moment::usage = \((Moment::usage)\) <> \*"\"\<  \
Moment[\[Kappa],{jU,jV}] returns an expression for the moment c[U,V*] in \
terms of the cumulants within- and between-genomes \!\(\[Kappa]\_\(j, \\\\\\\ \
k\)\). For example, Moment[\[Kappa],{2,2}] is 2\[Kappa][1,1\!\(\(]\^2\)\)+\
\[Kappa][2,2]+\[Kappa][0,2\!\(\(]\^2\)\).  Stores results.  Moment[n][{{\!\(\
\[Kappa]\_\(0, \\\\\\\ 0\)\),\[Ellipsis]},\[Ellipsis]}] is a compiled version \
that returns the matrix of moments.  Moment[U,c,\[Delta]p] returns moments in \
terms of the matrix of within- and between-genome associations, \!\(c\_\(j, \
\\\\\\\ k\)\).  For example,  Moment[{i,j,k},c,\[Delta]p] gives \
c[3,0]\[Delta]p[i]\[Delta]p[j]\[Delta]p[k]; Moment[{i,j,k*},c,\[Delta]p] \
gives c[2,1]\[Delta]p[i]\[Delta]p[j]\[Delta]p[\!\(\(k\^*\)\)]. \>\"";\)\)], \
"Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    \(TextForm
    \`Cumulant[c, {jU, jV}]\ returns\ an\ expression\ for\ the\ cumulant\ 
        \[Kappa][U, \(V*\)]\ in\ terms\ of\ the\ within - \ and\ between - 
      genome\ moments . \ \ \ For\ example, \ 
    Cumulant[c, {2, 2}]\ is\  - 2  c[1, 1\(]\^2\) + c[2, 2] - 
      cw[0, 2\(]\^2\) . \ \ Stores\ 
        results . \ \ 
          \(Cumulant[n]\)[{{c\_\(0, 0\), \[Ellipsis]}, \[Ellipsis]}]\ is\ a\ 
        compiled\ version\ that\ returns\ the\ matrix\ of\ 
        cumulants . \ \ Cumulant[U, \[Kappa], \[Delta]p]\ returns\ cumulants\ 
        in\ terms\ of\ the\ matrix\ of\ within - \ and\ between - 
      genome\ associations, \ \[Kappa]\_\(j, k\) . \ \ For\ example, \ \ 
    Cumulant[{i, j, k}, \[Kappa], \[Delta]p]\ gives\ \[Kappa][3, 0] 
      \[Delta]p[i] \[Delta]p[j] \[Delta]p[k]; \ 
    Cumulant[{i, j, \(k*\)}, \[Kappa], \[Delta]p]\ gives\ \[Kappa][2, 1] 
      \[Delta]p[i] \[Delta]p[j] \(\[Delta]p[\(k\^*\)] . \)\)], "Subsubsection"],

Cell[BoxData[
    \(\(Cumulant::usage = \((Cumulant::usage)\) <> \*"\"\<  \
Cumulant[c,{jU,jV}] returns an expression for the cumulant \[Kappa][U,V*] in \
terms of the within- and between-genome moments.   For example, \
Cumulant[c,{2,2}] is -2c[1,1\!\(\(]\^2\)\)+c[2,2]-cw[0,2\!\(\(]\^2\)\).  \
Stores results.  Cumulant[n][{{\!\(c\_\(0, \\\\\\\ 0\)\),\[Ellipsis]},\
\[Ellipsis]}] is a compiled version that returns the matrix of cumulants.  \
Cumulant[U,\[Kappa],\[Delta]p] returns cumulants in terms of the matrix of \
within- and between-genome associations, \!\(\[Kappa]\_\(j, \\\\\\\ k\)\).  \
For example,  Cumulant[{i,j,k},\[Kappa],\[Delta]p] gives \
\[Kappa][3,0]\[Delta]p[i]\[Delta]p[j]\[Delta]p[k]; \
Cumulant[{i,j,k*},\[Kappa],\[Delta]p] gives \
\[Kappa][2,1]\[Delta]p[i]\[Delta]p[j]\[Delta]p[\!\(\(k\^*\)\)].\>\"";\)\)], \
"Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{

Cell["\<\
AlleleFrequencyPermutations[{p1..},n] gives the matrix of permuted \
p's & q's for all genotypes: {{q..q},..{p..p}}. \
AlleleFrequencyPermutations[n][{p1..}] is a compiled version.\
\>", 
  "Subsubsection"],

Cell[BoxData[
    \(\(AlleleFrequencyPermutations::usage = \
"\<AlleleFrequencyPermutations[{p1..},n] gives the matrix of permuted p's & \
q's for all genotypes: {{q..q},..{p..p}}. \
AlleleFrequencyPermutations[n][{p1..}] is a compiled version.\>";\)\)], \
"Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData[
"\[Delta]AlleleFrequencyPermutations[\[Delta]p,n] gives the matrix of \
permuted \[Delta]p's for all genotypes: {{-\[Delta]p\[Ellipsis]},..{\[Delta]p\
\[Ellipsis]}}.  \[Delta]AlleleFrequencyPermutations[n][{\[Delta]p1..}] is a \
compiled version."], "Subsubsection"],

Cell[BoxData[
    \(\(\[Delta]AlleleFrequencyPermutations::usage = \
"\<\[Delta]AlleleFrequencyPermutations[\[Delta]p,n] gives the matrix of \
permuted \[Delta]p's for all genotypes: {{-\[Delta]p\[Ellipsis]},..{\[Delta]p\
\[Ellipsis]}}.  \[Delta]AlleleFrequencyPermutations[n][{\[Delta]p1..}] is a \
compiled version.\>";\)\)], "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    \(TextForm
    \`Matrix\[CapitalGamma][{\(p\_1\) \[Ellipsis]}, {\[Delta]p\_1, 
          \[Ellipsis]}, n]\ gives\ the\ matrix\ of\ coefficients, \ 
    constructed\ from\ AlleleFrequencyPermutations[], \ 
    \[Delta]AlleleFrequencyPermutations[] . \ \ 
        Matrix\[CapitalGamma][{p1\[Ellipsis]}, n]\ gives\ the\ matrix\ of\ 
      coefficients, \ 
    with\ \[Delta]p\ assumed\ 1. \ 
      \(Matrix\[CapitalGamma][n]\)[{\(p\_1\) \[Ellipsis]}, {\[Delta]p\_1, 
          \[Ellipsis]}]\ is\ a\ compiled\ \(version . \)\)], "Subsubsection"],

Cell[BoxData[
    \(\(Matrix\[CapitalGamma]::usage = \*"\"\< \
Matrix\[CapitalGamma][{\!\(p\_1\)\[Ellipsis]},{\!\(\[Delta]p\_1\),\[Ellipsis]}\
,n] gives the matrix of coefficients, constructed from \
AlleleFrequencyPermutations[], \[Delta]AlleleFrequencyPermutations[].  Matrix\
\[CapitalGamma][{p1\[Ellipsis]},n] gives the matrix of coefficients, with \
\[Delta]p assumed 1.  Matrix\[CapitalGamma][n][{\!\(p\_1\)\[Ellipsis]},{\!\(\
\[Delta]p\_1\),\[Ellipsis]}] is a compiled version.\>\"";\)\)], "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{

Cell["\<\
PloidyWeightList[n] lists the factor of which weights each diploid  \
frequency: 1 for homozygotes, 2 otherwise\
\>", "Subsubsection",
  InitializationCell->True],

Cell[BoxData[
    \(\(PloidyWeightList::usage = "\<PloidyWeightList[n] lists the factor \
which weights each diploid frequency: 1 for homozygotes, 2 \
otherwise.\>";\)\)], "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData[{
  "PositionsList[n] gives the positions in the ",
  Cell[BoxData[
      \(2\^n\[Times]2\^n\)]],
  " matrix of genotype frequencies of the elements needed to give the diploid \
frequencies."
}], "Subsubsection",
  InitializationCell->True],

Cell[BoxData[
    \(\(PositionsList::usage = "\<PositionsList[n] gives the positions in the \
matrix of genotype frequencies of the elements needed to give the diploid \
frequencies.\>";\)\)], "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    StyleBox[\(PositionsMatrix[
            n]\ constructs\ a\ 3\^n\[Times]2\^\(2  n\)\ matrix\ of\ 0' 
          s\ and\ 1' 
          s\ that\ corresponds\ to\ PositionsList[
              n] . \ \ Only\ feasible\ for\ n \[LessEqual] 6. \),
      FontFamily->"Times"]], "Subsubsection"],

Cell[BoxData[
    \(\(PositionsMatrix::usage = \*"\"\<PositionsMatrix[n] constructs a \!\(3\
\^n\)\[Times]\!\(2\^\(2\\\\\\\ \\\\\\\ n\)\) matrix of 0, 1, 2\[Ellipsis]'s \
that corresponds to PositionsList[n].  Only feasible for n\[LessEqual]6. \
Includes the weighting defined by PloidyWeightList[n], so that \
PositionsMatrix[n].Flatten[g] gives the observed diploid frequencies.\>\"";\)\
\)], "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    \(TextForm
    \`\(GenotypeFrequencyConvert[gM, n]\ converts\ the\ 2\^n\ by\ 2\^n\ matrix
      \ of\ genotype\ frequencies\ to\ the\ 3\^n\ matrix\ of\ diploid\ 
      \(frequencies . \)\ \ \)\)], "Subsubsection",
  InitializationCell->True],

Cell[BoxData[
    \(\(GenotypeFrequencyConvert::usage = \
\*"\"\<GenotypeFrequencyConvert[gM,n] converts the \!\(2\^n\) by \!\(2\^n\) \
matrix of genotype frequencies to the \!\(3\^n\) vector of observed diploid \
frequencies.  \>\"";\)\)], "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{

Cell["\<\
StandardSet[nloci] gives a standard set of dummy variables to \
replace cw[], cb[].\
\>", "Subsubsection",
  InitializationCell->True],

Cell[BoxData[
    \(\(StandardSet::usage = \*"\"\<StandardSet[nloci] gives a standard set \
of dummy variables {{cw$1..},{cb$1..}} to replace cw[], cb[]; there are \
nloci-1 variables cw[], and 2nloci-1 variables cb[].  StandardSet[nloci,f] \
gives n variables of the form {f$1..}.  StandardSet[nloci,f,All] gives \
\!\(2\^nloci\)-nloci-1 variables of the form {f$1..}.\>\"";\)\)], "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    \(TextForm
    \`DiploidGenotypeFrequencyList[{p\_1, \[Ellipsis], 
          p\_n}, {{c\_\(0, 0\), c\_\(1, 0\), \[Ellipsis]}, \[Ellipsis]}]\ 
      calculates\ the\ matrix\ of\ 2\^n\[Times]2\^n\ diploid\ genotype\ 
      frequencies\ from\ the\ allele\ frequencies\ and\ matrix\ of\ moments; 
    \ assumes\ \[Delta]p = 
      1. \ \ DiploidGenotypeFrequencyList[{p\_1, \[Ellipsis], p\_n}, {
            \[Delta]p\_1, 
            \[Ellipsis]}, {{c\_\(0, 0\), c\_\(1, 0\), \[Ellipsis]}, 
            \[Ellipsis]}]\ allows\ divergence\ \[Delta]p\ to\ vary\ across\ 
        loci . \ DiploidGenotypeFrequencyList[{{p\_1, \[Ellipsis], p\_n}, {
                \(p\_1\%*\), \[Ellipsis]}}, {{\[Delta]p\_1, \[Ellipsis]}, {
                \(\[Delta]p\_1\%*\), \[Ellipsis]}}, {{c\_\(0, 0\), 
                c\_\(1, 0\), \[Ellipsis]}, \[Ellipsis]}, 
            Symmetric \[Rule] False]\ allows\ the\ male\ and\ female\ gamete\ 
        pools\ to\ 
        differ . \ 
          \(DiploidGenotypeFrequencyList[n]\)[{p\_1, \[Ellipsis], p\_n}, {
              \[Delta]p\_1, 
              \[Ellipsis]}, {{c\_\(0, 0\), c\_\(1, 0\), \[Ellipsis]}, 
              \[Ellipsis]}], \ 
    \(DiploidGenotypeFrequencyList[n, Symmetric \[Rule] False]
          \)[{{p\_1, \[Ellipsis], p\_n}, {\(p\_1\%*\), \[Ellipsis]}}, {{
            \[Delta]p\_1, \[Ellipsis]}, {\(\[Delta]p\_1\%*\), 
            \[Ellipsis]}}, {{c\_\(0, 0\), c\_\(1, 0\), \[Ellipsis]}, 
          \[Ellipsis]}]\ are\ compiled\ \(versions . \)\)], "Subsubsection"],

Cell[BoxData[
    \(\(DiploidGenotypeFrequencyList::usage = \
\*"\"\<DiploidGenotypeFrequencyList[{\!\(p\_1\),\[Ellipsis],\!\(p\_n\)},{{\!\(\
c\_\(0, \\\\\\\ 0\)\),\!\(c\_\(1, \\\\\\\ 0\)\),\[Ellipsis]},\[Ellipsis]}] \
calculates the matrix of \!\(2\^n\)\[Times]\!\(2\^n\) diploid genotype \
frequencies from the allele frequencies and matrix of moments; assumes \
\[Delta]p=1.  \
DiploidGenotypeFrequencyList[{\!\(p\_1\),\[Ellipsis],\!\(p\_n\)},{\!\(\[Delta]\
p\_1\),\[Ellipsis]},{{\!\(c\_\(0, \\\\\\\ 0\)\),\!\(c\_\(1, \\\\\\\ 0\)\),\
\[Ellipsis]},\[Ellipsis]}] allows divergence \[Delta]p to vary across loci. \
DiploidGenotypeFrequencyList[{{\!\(p\_1\),\[Ellipsis],\!\(p\_n\)},{\!\(\(p\_1\
\%*\)\),\[Ellipsis]}},{{\!\(\[Delta]p\_1\),\[Ellipsis]},{\!\(\(\[Delta]p\_1\%*\
\)\),\[Ellipsis]}},{{\!\(c\_\(0, \\\\\\\ 0\)\),\!\(c\_\(1, \\\\\\\ 0\)\),\
\[Ellipsis]},\[Ellipsis]},Symmetric\[Rule]False] allows the male and female \
gamete pools to differ. DiploidGenotypeFrequencyList[n][{\!\(p\_1\),\
\[Ellipsis],\!\(p\_n\)},{\!\(\[Delta]p\_1\),\[Ellipsis]},{{\!\(c\_\(0, \\\\\\\
\ 0\)\),\!\(c\_\(1, \\\\\\\ 0\)\),\[Ellipsis]},\[Ellipsis]}], \
DiploidGenotypeFrequencyList[n,Symmetric\[Rule]False][{{\!\(p\_1\),\[Ellipsis]\
,\!\(p\_n\)},{\!\(\(p\_1\%*\)\),\[Ellipsis]}},{{\!\(\[Delta]p\_1\),\[Ellipsis]\
},{\!\(\(\[Delta]p\_1\%*\)\),\[Ellipsis]}},{{\!\(c\_\(0, \\\\\\\ \
0\)\),\!\(c\_\(1, \\\\\\\ 0\)\),\[Ellipsis]},\[Ellipsis]}] are compiled \
versions. \>\"";\)\)], "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    \(TextForm
    \`EstimateMoments[g, {p\_1, \[Ellipsis]}, {\[Delta]p, \[Ellipsis]}]\ 
      estimates\ the\ matrix\ of\ moments\ from\ the\ 3\^n\ diploid\ genotype
      \ frequencies, \ 
    assuming\ allele\ frequencies\ p\_i\ and\ divergences\ 
      \[Delta]p\_i . \ \ If\ the\ {\[Delta]p\_i, \[Ellipsis]}\ are\ omitted, 
    \ they\ are\ assumed\ to\ be\ 1. \)], "Subsubsection"],

Cell[BoxData[
    \(\(EstimateMoments::usage = \*"\"\<EstimateMoments[g,{\!\(p\_1\),\
\[Ellipsis]},{\[Delta]p,\[Ellipsis]}] estimates the matrix of moments from \
the \!\(3\^n\) diploid genotype frequencies, assuming allele frequencies \
\!\(p\_i\) and divergences \!\(\[Delta]p\_i\).  If the {\!\(\[Delta]p\_i\),\
\[Ellipsis]} are omitted, they are assumed to be 1.\>\"";\)\)], "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    StyleBox[\(MVariables[
            n]\ lists\ all\ the\ coefficients\ M\_\(S, H, SS, SH, HH\)\ \
needed\ for\ n\ loci . \ 
            MVariables[j, n]\ lists\ those\ of\ order\ j \[LessEqual] 
        4 \( \(n\)\(.\)\)\),
      FontFamily->"Times"]], "Subsubsection"],

Cell[BoxData[
    \(\(MVariables::usage = \*"\"\<MVariables[n] lists all the coefficients \
\!\(m\_\(S, H\)\) needed to describe an n locus diploid genotype. \
MVariables[j,n] lists those of order j\[LessEqual]2n. MVariables[n, Family\
\[Rule]True] lists all the coefficients \!\(m\_\(S, H, SS, SH, HH\)\) needed \
for a pair of n locus  diploid genotypes. MVariables[j,n, Family\[Rule]True] \
lists those of order j\[LessEqual]4n. \>\"";\)\)], "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{

Cell["\<\
MFromC[c,{S,H}] gives the expression for M[S,H] in terms of c[i,j]. \
 MFromC[c,{S,H,SS,SH,SS}] gives the expression for M[S,H,SS,SH,SS] in terms \
of c[i,j,k,l]\
\>", "Subsubsection"],

Cell[BoxData[
    \(\(MFromC::usage = "\<MFromC[c,{S,H}] gives the expression for M[S,H] in \
terms of c[i,j].  MFromC[c,{S,H,SS,SH,SS}] gives the expression for \
M[S,H,SS,SH,SS] in terms of c[i,j,k,l].\>";\)\)], "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    \(MToCEquations[m, c, 
        n]\ gives\ the\ equations\ relating\ the\ coefficients\ m[j, 
        k]\ to\ the\ c[j, k], \ 
    for\ n\ loci . \ \ MToCEquations[M, j, n]\ gives\ only\ the\ j' 
      th\ order\ \(\(equations\)\(.\)\(\ \)\)\)], "Subsubsection"],

Cell[BoxData[
    \(\(MToCEquations::usage = "\<MToCEquations[m,c,n] gives the equations \
relating the coefficients m[S,H] to the c[j,k], for n loci.  \
MToCEquations[m,c,j,n] gives only the j'th order equations. \
MToCEquations[m,c,n,Family\[Rule]True] gives the equations relating the \
coefficients m[S,H,SS,SH,HH] to the c[i,j,k,l]\>";\)\)], "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{

Cell["\<\
Family\[Rule]True is an option for MToC[] which indicates that a \
family is involved\
\>", "Subsubsection"],

Cell[BoxData[
    \(\(Family::usage = "\<Family\[Rule]True is an option for MToC[] which \
indicates that a family is involved\>";\)\)], "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    StyleBox[\(MToC[m, c, n]\ is\ a\ rule\ which\ gives\ the\ moments, \ 
      c[i, j], \ 
      in\ terms\ of\ the\ m[S, 
            H] = \(\(<\)\(\((\[Zeta] + \(\[Zeta]\^*\)\()\^S\)\) \[Zeta]\
\[VeryThinSpace]\(\[Zeta]\^*\)\^H\)\(>\)\), \ 
      where\ {\[Zeta], \(\[Zeta]\^*\)}\ is\ the\ diploid\ genotype . \ \ MToC[
            m, c, j, n]\ gives\ only\ the\ j' 
        th\ order\ terms . \ \ MToC[m, c, n, 
            Family \[Rule] True]\ gives\ the\ moments, \ c[i, j, k, l], \ 
      in\ terms\ of\ the\ m[S, H, SS, SH, 
            HH] = \(\(<\)\(\((\[Zeta] + \(\[Zeta]\^*\) + \(\[Zeta]\^'\) + \
\[Zeta]\^\(\('\)\(*\)\)\()\^S\)\) \((\[Zeta]\[VeryThinSpace]\(\[Zeta]\^*\) + \
\(\[Zeta]\^'\) \[Zeta]\^\(\('\)\(*\)\)\()\^H\)\) \((\((\[Zeta] + \(\[Zeta]\^*\
\))\) \((\(\[Zeta]\^'\) + \[Zeta]\^\(\('\)\(*\)\))\)\()\^SS\)\) \((\((\[Zeta] \
+ \(\[Zeta]\^*\))\) \((\(\[Zeta]\^'\) \[Zeta]\^\(\('\)\(*\)\))\) + \((\[Zeta]\
\[VeryThinSpace]\(\[Zeta]\^*\))\) \((\(\[Zeta]\^'\) + \
\[Zeta]\^\(\('\)\(*\)\))\)\()\^SH\)\) \
\((\[Zeta]\[VeryThinSpace]\(\[Zeta]\^*\) \(\[Zeta]\^'\) \[Zeta]\^\(\('\)\(*\)\
\)\()\^HH\)\)\)\(>\)\(\(.\)\(\ \ \)\(Here\)\)\), \ {\[Zeta], \(\[Zeta]\^*\)}, \
\ {\(\[Zeta]\^'\), \[Zeta]\^\(\('\)\(*\)\)} 
        are\ the\ diploid\ genotypes\ of\ the\ two\ parents\ of\ a\ \
\(\(family\)\(.\)\)\),
      FontFamily->"Times"]], "Subsubsection"],

Cell[BoxData[
    \(\(MToC::usage = \*"\"\<MToC[m,c,n] is a rule which gives the moments, \
c[i,j], in terms of the m[S,H]=<(\[Zeta]+\!\(\(\[Zeta]\^*\)\)\!\(\()\^S\)\)\
\[Zeta]\[VeryThinSpace]\!\(\(\[Zeta]\^*\)\^H\)>, where {\[Zeta],\!\(\(\[Zeta]\
\^*\)\)} is the diploid genotype.  MToC[m,c,j,n] gives only the j'th order \
terms.  MToC[m,c,n,Family\[Rule]True] gives the moments, c[i,j,k,l], in terms \
of the m[S,H,SS,SH,HH]=<(\[Zeta]+\!\(\(\[Zeta]\^*\)\)+\!\(\(\[Zeta]\^'\)\)+\!\
\(\[Zeta]\^\(\('\)\(*\)\)\)\!\(\()\^S\)\)(\[Zeta]\[VeryThinSpace]\!\(\(\[Zeta]\
\^*\)\)+\!\(\(\[Zeta]\^'\)\)\!\(\[Zeta]\^\(\('\)\(*\)\)\)\!\(\()\^H\)\)((\
\[Zeta]+\!\(\(\[Zeta]\^*\)\))(\!\(\(\[Zeta]\^'\)\)+\!\(\[Zeta]\^\(\('\)\(*\)\)\
\))\!\(\()\^SS\)\)((\[Zeta]+\!\(\(\[Zeta]\^*\)\))(\!\(\(\[Zeta]\^'\)\)\!\(\
\[Zeta]\^\(\('\)\(*\)\)\))+(\[Zeta]\[VeryThinSpace]\!\(\(\[Zeta]\^*\)\))(\!\(\
\(\[Zeta]\^'\)\)+\!\(\[Zeta]\^\(\('\)\(*\)\)\))\!\(\()\^SH\)\)(\[Zeta]\
\[VeryThinSpace]\!\(\(\[Zeta]\^*\)\)\!\(\(\[Zeta]\^'\)\)\!\(\[Zeta]\^\(\('\)\(\
*\)\)\)\!\(\()\^HH\)\)>.  Here, {\[Zeta],\!\(\(\[Zeta]\^*\)\)}, \
{\!\(\(\[Zeta]\^'\)\),\!\(\[Zeta]\^\(\('\)\(*\)\)\)}are the diploid genotypes \
of the two parents of a family.\>\"";\)\)], "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    \(TextForm\`MToCOld[m, n]\ gives\ the\ matrix\ of\ moments, \ 
    c\_\(j, k\)\ in\ terms\ of\ m[j, k], \ 
    where\ m[j, 
          k] = \(\(<\)\(\(z\^j\) \[Phi]\^k\)\(>\)\(.\)\)\)], "Subsubsection",
  InitializationCell->True],

Cell[BoxData[
    \(\(MToCOld::usage = \*"\"\<MToC[m,n] gives the matrix of moments, \
\!\(c\_\(j, \\\\\\\ \\\\\\\ k\)\) in terms of m[j,k], where \
m[j,k]=<\!\(z\^j\)\!\(\[Phi]\^k\)>.\>\"";\)\)], "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    \(FamilyM[
        families, {i\_S, i\_H, i\_SS, i\_SH, 
          i\_HH}, {\(p\_1\) \[Ellipsis]}]\ gives\ the\ average\ of\ \
M\_\(i\_S, i\_H, i\_SS, i\_SH, i\_HH\), \ 
    measured\ relative\ to\ allele\ frequencies\ {\(p\_1\) \[Ellipsis]}\)], \
"Subsubsection"],

Cell[BoxData[
    \(\(FamilyM::usage = \*"\"\<FamilyM[families,{\!\(i\_S\),\!\(i\_H\),\!\(i\
\_SS\),\!\(i\_SH\),\!\(i\_HH\)},{\!\(p\_1\)\[Ellipsis]}] gives the average of \
\!\(M\_\(i\_S, \\\\\\\ i\_H, \\\\\\\ i\_SS, \\\\\\\ i\_SH, \\\\\\\ i\_HH\)\), \
measured relative to allele frequencies {\!\(p\_1\)\[Ellipsis]}. \
InferParentalGenotypes\[Rule]True infers parental genotypes rather than \
making estimates from moments of the offspring.\>\"";\)\)], "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{\(FamilyEffects[
          family, \ {p\_1, \[Ellipsis]}]\ gives\ a\ list\ {S, H, SS, SH, 
          HH}\), ",", " ", 
      RowBox[{"which", " ", "estimates", " ", 
        RowBox[{"(", 
          RowBox[{\(\[Zeta]\_i\), "+", \(\[Zeta]\_i\%*\), "+", 
            FormBox[\(\(\[Zeta]\_i\%'\) + \ \[Zeta]\_i\%\(\('\)\(*\)\)\),
              "TraditionalForm"]}], ")"}]}], 
      ",", \((\(\[Zeta]\_i\) \(\[Zeta]\_i\%*\) + \(\[Zeta]\_i\%'\) \[Zeta]\_i\
\%\(\('\)\(*\)\))\), ",", 
      RowBox[{\((\[Zeta]\_i + \(\[Zeta]\_i\%*\))\), 
        RowBox[{"(", 
          FormBox[\(\(\[Zeta]\_i\%'\) + \ \[Zeta]\_i\%\(\('\)\(*\)\)\),
            "TraditionalForm"], ")"}]}], ",", " ", 
      RowBox[{"(", 
        RowBox[{
          RowBox[{
            RowBox[{"(", 
              FormBox[\(\(\[Zeta]\_i\%'\) + \ \[Zeta]\_i\%\(\('\)\(*\)\)\),
                "TraditionalForm"], 
              ")"}], \(\[Zeta]\_i\), \(\[Zeta]\_i\%*\)}], 
          "+", \(\((\[Zeta]\_i + \(\[Zeta]\_i\%*\))\) \(\[Zeta]\_i\%'\) \
\[Zeta]\_i\%\(\('\)\(*\)\)\)}], ")"}], ",", 
      " ", \(\(\[Zeta]\_i\) \(\[Zeta]\_i\%*\) \(\[Zeta]\_i\%'\) \
\[Zeta]\_i\%\(\('\)\(*\)\) . \ \ Here\), ",", 
      " ", \({\[Zeta]\_i, \(\[Zeta]\_i\%*\)}\ are\ the\ contributions\ from\ \
the\ mother\), ",", 
      " ", \(and\ {\(\[Zeta]\_i\%'\), \ \[Zeta]\_i\%\(\('\)\(*\)\)}\ from\ \
the\ father . \ \ {p\_1, \[Ellipsis]}\ is\ a\ list\ of\ allele\ \
\(\(frequencies\)\(.\)\)\)}]], "Subsubsection"],

Cell[BoxData[
    RowBox[{
      RowBox[{\(FamilyEffects::usage\), "=", 
        "\"\<FamilyEffects[family, {\!\(p\_1\),\[Ellipsis]}] gives a list \
{S,H,SS,SH,HH}, which estimates \
(\!\(\[Zeta]\_i\)+\!\(\(\[Zeta]\_i\%*\)\)+\!\(TraditionalForm\`\(\[Zeta]\_i\%'\
\)\\\\\\\  + \\\\\\\ \\\\\\\ \
\[Zeta]\_i\%\(\('\)\(*\)\)\)),(\!\(\[Zeta]\_i\)\!\(\(\[Zeta]\_i\%*\)\)+\!\(\(\
\[Zeta]\_i\%'\)\)\!\(\[Zeta]\_i\%\(\('\)\(*\)\)\)),(\!\(\[Zeta]\_i\)+\!\(\(\
\[Zeta]\_i\%*\)\))(\!\(TraditionalForm\`\(\[Zeta]\_i\%'\)\\\\\\\  + \\\\\\\ \
\\\\\\\ \[Zeta]\_i\%\(\('\)\(*\)\)\)), ((\!\(TraditionalForm\`\(\[Zeta]\_i\%'\
\)\\\\\\\  + \\\\\\\ \\\\\\\ \
\[Zeta]\_i\%\(\('\)\(*\)\)\))\!\(\[Zeta]\_i\)\!\(\(\[Zeta]\_i\%*\)\)+(\!\(\
\[Zeta]\_i\)+\!\(\(\[Zeta]\_i\%*\)\))\!\(\(\[Zeta]\_i\%'\)\)\!\(\[Zeta]\_i\%\(\
\('\)\(*\)\)\)), \!\(\[Zeta]\_i\)\!\(\(\[Zeta]\_i\%*\)\)\!\(\(\[Zeta]\_i\%'\)\
\)\!\(\[Zeta]\_i\%\(\('\)\(*\)\)\).  Here, {\!\(\[Zeta]\_i\),\!\(\(\[Zeta]\_i\
\%*\)\)} are the contributions from the mother, and {\!\(\(\[Zeta]\_i\%'\)\), \
\!\(\[Zeta]\_i\%\(\('\)\(*\)\)\)} from the father.  {\!\(p\_1\),\[Ellipsis]} \
is a list of allele frequencies.  Stores \
results.InferParentalGenotypes\[Rule]True infers parental genotypes rather \
than making estimates from moments of the offspring.\>\""}], ";"}]], "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{

Cell["InferParentalGenotypes", "Subsubsection"],

Cell[BoxData[
    \(\(InferParentalGenotypes::usage = "\<InferParentalGenotypes\[Rule]True \
is an option for FamilyEffects, FamilyM and EstimateFamilyMoments which \
specifies that the joint parental genotypes are inferred from the class of \
segregation rather than from the moments of the offspring \
genotypes.\>";\)\)], "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    \(FamilyAlleleFrequencyEstimate[{family\_1, \[Ellipsis]}]\ gives\ the\ \
average\ allele\ frequency, \ 
    weighting\ each\ family\ \(\(equally\)\(.\)\)\)], "Subsubsection"],

Cell[BoxData[
    \(\(FamilyAlleleFrequencyEstimate::usage = \
\*"\"\<FamilyAlleleFrequencyEstimate[{\!\(family\_1\),\[Ellipsis]}] gives the \
average allele frequency, weighting each family equally.\>\"";\)\)], "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    \(EstimateFamilyMoments[{family\_1, \[Ellipsis]}, 
        c[i, j, k, 
          l], {p\_1, \[Ellipsis]}]\ gives\ an\ estimate\ of\ the\ moment\ \
c[{i, j, k, l}], \ 
    based\ on\ the\ family\ \(\(data\)\(.\)\)\)], "Subsubsection"],

Cell[BoxData[
    \(\(EstimateFamilyMoments::usage = \
\*"\"\<EstimateFamilyMoments[{\!\(family\_1\),\[Ellipsis]},c[i,j,k,l],{\!\(p\_\
1\),\[Ellipsis]}] gives an estimate of the moment c[{i,j,k,l], based on the \
family data. InferParentalGenotypes\[Rule]True infers parental genotypes \
rather than making estimates from moments of the offspring.\>\"";\)\)], \
"Input",
  InitializationCell->True]
}, Closed]]
}, Open  ]],

Cell[CellGroupData[{

Cell["One way and pairwise estimates", "Subsection"],

Cell[CellGroupData[{

Cell[BoxData[
    StyleBox[\(MakeOneWayTable[
          site]\ generates\ a\ table\ of\ estimates\ of\ p\ and\ F, \ 
      for\ each\ locus\ in\ Data[
            site] . \ \ The\ table\ consists\ of\ a\ list\ of\ {p, F\&^, 
          L}, \ where\ L\ is\ the\ log\ likelihood\ ratio\ comparing\ F = \(0\
\ with\ F = F\&^ . \ In\ the\ general\ moment\ notation\), \ 
      F = \(\(c\_\(1, \ 1\)\)\(.\)\)\),
      FontFamily->"Times"]], "Subsubsection"],

Cell[BoxData[
    \(\(MakeOneWayTable::usage = \*"\"\<MakeOneWayTable[site] generates a \
table of estimates of p and F, for each locus in Data[site].  The table \
consists of a list of {p,\!\(F\&^\),L}, where L is the log likelihood ratio \
comparing F=0 with F=\!\(F\&^\). In the general moment notation, \
Fpq=\!\(c\_\(1, \\\\\\\ 1\)\). Generates subsets of the data which are \
labelled {s,{j}}.\>\"";\)\)], "Input",
  InitializationCell->True]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
PresentOneWayTable[site] presents a table of allele frequency, F, \
and log(L) for each locus.\
\>", "Subsubsection"],

Cell[BoxData[
    \(\(PresentOneWayTable::usage = "\<PresentOneWayTable[site] presents a \
table of allele frequency, F, and log(L) for each locus.\>";\)\)], "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    StyleBox[
      RowBox[{\(MakePairwiseTable[
            site]\ generates\ a\ table\ of\ estimates\ of\ F\), ",", 
        " ", \(D\ and\ correlations\ between\ them\), ",", 
        " ", \(for\ each\ pair\ of\ loci\ in\ Data[
              site] . \ \ For\ each\ pair\), ",", " ", 
        RowBox[{
        "the", " ", "table", " ", "contains", "  ", "a", " ", "list", " ", 
          "of", " ", 
          RowBox[{"{", 
            RowBox[{"L", ",", 
              RowBox[{"{", 
                RowBox[{"Fpq", ",", "D", ",", \(cov[Fpq, D]\), ",", 
                  RowBox[{"cov", "[", 
                    RowBox[{
                      SubscriptBox[
                        StyleBox[
                          RowBox[{"F", 
                            StyleBox["pq",
                              FontFamily->"Times"]}]], "1"], ",", 
                      SubscriptBox[
                        StyleBox[
                          RowBox[{"F", 
                            StyleBox["pq",
                              FontFamily->"Times"]}]], "2"]}], "]"}]}], 
                "}"}]}], "}"}]}], ",", 
        " ", \(for\ the\ hypotheses\ that\ all\ F\), ",", " ", \(D = 0; \ 
        that\ F \[NotEqual] 0; \ that\ D \[NotEqual] 0; \ 
        that\ F \[NotEqual] 
          0\ and\ heterozygosities\ are\ correlated\ across\ loci\ \((cov[
                  F\_1, F\_2] \[NotEqual] 0)\); \ 
        and\ that\ all\ associations\ are\ non - 
          zero . \ The\ associated\ #\ of\ degreees\ of\ freedom\ are\ {0, 1, 
                1, 2, 4} . \ \ In\ the\ general\ moment\ notation\), ",", 
        " ", \(Fpq = c\_\(1, 1\)\), ",", \(D = c\_\(0, 2\)\), 
        ",", \(cov[Fpq, D] = c\_\(2, 1\)\), ",", 
        RowBox[{
          RowBox[{"cov", "[", 
            RowBox[{
              SubscriptBox[
                StyleBox[
                  RowBox[{"F", 
                    StyleBox["pq",
                      FontFamily->"Times"]}]], "1"], ",", 
              SubscriptBox[
                StyleBox[
                  RowBox[{"F", 
                    StyleBox["pq",
                      FontFamily->"Times"]}]], "2"]}], "]"}], 
          "=", \(c\_\(2, 2\) . \ \ Generates\ subsets\ of\ the\ data\ which\ \
are\ labelled\ \(\({s, {j, k}}\)\(.\)\)\)}]}],
      FontFamily->"Times"]], "Subsubsection"],

Cell[BoxData[
    \(\(MakePairwiseTable::usage = \*"\"\<MakePairwiseTable[site] generates a \
table of estimates of F, D and correlations between them, for each pair of \
loci in Data[site].  For each pair, the table contains a list of \
{L,{Fpq,D,cov[Fpq,D],cov[\!\(Fpq\_1\),\!\(Fpq\_2\)]}}, for the hypotheses \
that all F, D=0; that F\[NotEqual]0; that D\[NotEqual]0; that F\[NotEqual]0 \
and heterozygosities are correlated across loci (cov[\!\(F\_1\),\!\(F\_2\)]\
\[NotEqual]0); and that all associations are non-zero. The associated # of \
degreees of freedom are {0,1,1,2,4}.  In the general moment notation, \
Fpq=\!\(c\_\(1, \\\\\\\ \(\(\\\\\\\\\)\(\\\\\\\ \)\(1\)\)\)\),D=\!\(c\_\(0, \
\\\\\\\ 2\)\),cov[Fpq,D]=\!\(c\_\(2, \\\\\\\ \\\\\\\ \
1\)\),cov[\!\(Fpq\_1\),\!\(Fpq\_2\)]=\!\(c\_\(2, \\\\\\\ 2\)\).  Generates \
subsets of the data which are labelled {s,{j,k}}.\>\"";\)\)], "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    StyleBox[\(PresentPairwiseTable[
          site]\ presents\ a\ table\ of\ associations\ among\ loci . \ \ \
PresentPairwiseTable[table, \ 
            locusnames]\ works\ from\ the\ table\ generated\ by\ \
MakePairwiseTable[site] . \ \ PresentPairwiseTable[table, \ locusnames, 
            c]\ adds\ the\ overall\ estimates, \ 
      held\ in\ c\  = \ EstimateMoments[gf, {p\_1, \[Ellipsis]}], \ 
      where\ gf\ are\ the\ 3\^n\ genotype\ \(\(frequencies\)\(.\)\)\),
      FontFamily->"Times"]], "Subsubsection"],

Cell[BoxData[
    \(\(PresentPairwiseTable::usage = \*"\"\<PresentPairwiseTable[site] \
presents a table of associations among loci.  PresentPairwiseTable[table, \
locusnames] works from the table generated by MakePairwiseTable[site].  \
PresentPairwiseTable[table, locusnames,c] adds the overall estimates, held in \
c = EstimateMoments[gf,{\!\(p\_1\),\[Ellipsis]}], where gf are the \!\(3\^n\) \
genotype frequencies.\>\"";\)\)], "Input",
  InitializationCell->True]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["Maximum likelihood estimation", "Subsection"],

Cell[CellGroupData[{

Cell[BoxData[
    \(TextForm
    \`LogLikelihoodDisequilibriumReduced[site, {k\_w, k\_b}, \[Delta]p, 
          p, {i, j, k, l}]\ gives\ an\ expression\ for\ the\ log\ likelihood\ 
        of\ the\ reduced\ cumulants
        \ {k\_w, k\_b} . \ 
          LogLikelihoodDisequilibriumReduced[site, {k\_w, k\_b}, \[Delta]p, 
            p, {i, j, k, l}, gdt]\ stores\ the\ definition\ of\ 
        DiploidGenotypeFrequencyTable[X,  .. ]\ in\ 
        gdt[X] . \ \ \ 
          LogLikelihoodDisequilibriumReduced[site, {k\_w, k\_b}, \[Delta]p, p]
            \ uses\ the\ fully\ compiled\ 
        version . \ LogLikelihoodDisequilibriumReduced[site {k\_w, k\_b}, p]\ 
        is\ the\ fastest\ method\ if\ \[Delta]p = 1\)], "Subsubsection"],

Cell[BoxData[
    \(\(LogLikelihoodDisequilibriumReduced::usage = \
\*"\"\<LogLikelihoodDisequilibriumReduced[site,{\!\(k\_w\),\!\(k\_b\)},\
\[Delta]p,p,{i,j,k,l}] gives an expression for the log likelihood of the \
reduced cumulants {\!\(k\_w\),\!\(k\_b\)}. \
LogLikelihoodDisequilibriumReduced[site,{\!\(k\_w\),\!\(k\_b\)},\[Delta]p,p,{\
i,j,k,l},gdt] stores the definition of DiploidGenotypeFrequencyTable[X,..] in \
gdt[X].   LogLikelihoodDisequilibriumReduced[site,{\!\(k\_w\),\!\(k\_b\)},\
\[Delta]p,p] uses the fully compiled version. \
LogLikelihoodDisequilibriumReduced[site{\!\(k\_w\),\!\(k\_b\)},p] is the \
fastest method if \[Delta]p=1\>\"";\)\)], "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    \(TextForm
    \`\(LogLikelihoodDisequilibrium[site, p, \[Delta]p, c]\ gives\ the\ log\ 
      likelihood\ of\ the\ matrix\ of\ moments, \ 
    c\_\(j, k\) . \ \ \ \ 
          LogLikelihoodDisequilibrium[site, p, \[Delta]p, c, 
            Compiled \[Rule] True]\ is\ a\ compiled\ 
        version . \ LogLikelihoodDisequilibrium[p, c, Compiled \[Rule] True]\ 
        is\ the\ fastest\ method\ if\ \[Delta]p = 
      \(1. \ LogLikelihoodDisequilibrium[{p, \(p\^*\)}, {\[Delta]p, 
                \(\[Delta]p\^*\)}, c, Compiled \[Rule] True, 
              Symmetric \[Rule] False]\ allows\ for\ different\ frequencies\ 
            in\ the\ male\ &\)\ female\ gamete\ \(pools . \)\ \)\)], 
  "Subsubsection"],

Cell[BoxData[
    \(\(LogLikelihoodDisequilibrium::usage = \
\*"\"\<LogLikelihoodDisequilibrium[site,p,\[Delta]p,c] gives the log \
likelihood of the matrix of moments, \!\(c\_\(j, \\\\\\\ k\)\).    \
LogLikelihoodDisequilibrium[site,p,\[Delta]p,c,Compiled\[Rule]True] is a \
compiled version. LogLikelihoodDisequilibrium[p,c,Compiled\[Rule]True] is the \
fastest method if \[Delta]p=1. \
LogLikelihoodDisequilibrium[{p,\!\(\(p\^*\)\)},{\[Delta]p,\!\(\(\[Delta]p\^*\)\
\)},c,Compiled\[Rule]True,Symmetric\[Rule]False] allows for different \
frequencies in the male & female gamete pools. \>\"";\)\)], "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData[{
  "MLEDisequilibrium",
  "[site,cw[k],{cw,cb},{{cw[2],..},{cb[2]..}},\[Delta]p,p,S] gives the MLE \
for cw[k], with the remaining c's given numerically by the lists \
{{cw[2],..},{cb[2]..}}."
}], "Subsubsection",
  InitializationCell->True],

Cell[BoxData[
    \(\(MLEDisequilibrium::usage = \
"\<MLEDisequilibrium[site,cw[k],{cw,cb},{{cw[2],..},{cb[2]..}},\[Delta]p,p,S] \
gives the MLE for cw[k], with the remaining c's given numerically by the \
lists {{cw[2],..},{cb[2]..}}. \>";\)\)], "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData[
"MetropolisDisequilibrium[site,T,{ntries,nprint},{Log[L],{{{p[1],..}},{{{\
\[Delta]p[1],..}},{{c[0,0],...}},{{pstep0},{\[Delta]pstep0},cstep0}] applies \
the Metropolis algorithm, using temperature T and  a matrix of moments.   \
step0 gives the initial step size; to fix some variables, set entries to 0. \
It is essential that the top left corner of cstep0 is zero.  Returns a list \
of the same form as its argument. The option Cumulant\[Rule]False fits a \
matrix of moments rather than cumulants."], "Subsubsection"],

Cell[BoxData[
    RowBox[{
      RowBox[{\(MetropolisDisequilibrium::usage\), "=", 
        "\"\<MetropolisDisequilibrium[site,T,{ntries,nprint},{Log[L],{{{p[1],.\
.}},{{{\[Delta]p[1],..}},{{c[0,0],...}},{{pstep0},{\[Delta]pstep0},cstep0}] \
applies the Metropolis algorithm, using temperature T and  a matrix of \
moments.   step0 gives the initial step size; to fix some variables, set \
entries to 0. It is essential that the top left corner of cstep0 is zero.  \
Returns a list of the same form as its argument. \!\(TextForm\`The\\\\\\\ \
option\\\\\\\ Cumulant\\\\\\\  \[Rule] \\\\\\\ False\\\\\\\ fits\\\\\\\ a\\\\\
\\\ matrix\\\\\\\ of\\\\\\\ moments\\\\\\\ rather\\\\\\\ than\\\\\\\ \
\(\(cumulants\)\(\\\\\\\ \)\(.\)\(\\\\\\\ \)\)\)\>\""}], ";"}]], "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData[{
  "MetropolisDisequilibriumReduced",
  "[site,T,{ntries,nprint},{LogLikelihoodDisequilibriumReduced,{{p[1],..},{cw[\
2],..,cb[2]..}},step0}] applies the Metropolis algorithm, using temperature \
T.  Assumes \[Delta]p=1.  step0 gives the initial step size; to fix some \
variables, set entries to 0.  Returns \
{log(L),{{p1,..},{cw[2],..,cb[2]..}},step}. "
}], "Subsubsection"],

Cell[BoxData[
    \(\(MetropolisDisequilibriumReduced::usage = \
"\<MetropolisDisequilibriumReduced[site,T,{ntries,nprint},{Log[L],{{p[1],..},{\
cw[2],..,cb[2]..}},step0}] applies the Metropolis algorithm, using \
temperature T.  Assumes \[Delta]p=1.  step0 gives the initial step size; to \
fix some variables, set entries to 0.  Returns \
{log(L),{{p1,..},{cw[2],..,cb[2]..}},step}..\>";\)\)], "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{

Cell["\<\
$MetropolisAdjustment determines how the step size is adjusted in \
the Metropolis alhgorithm; by default, 0.95\
\>", "Subsubsection"],

Cell[BoxData[
    \(\($MetropolisAdjustment::usage = "\<$MetropolisAdjustment determines \
how the step size is adjusted in the Metropolis alhgorithm; by default, \
0.95\>";\)\)], "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData[{
  "InitialStepReduced",
  "[{cw,cb},cl,\[Delta]p,p,S] sets a sensible initial step size for the \
moments"
}], "Subsubsection"],

Cell[BoxData[
    \(\(InitialStepReduced::usage = \
"\<InitialStepReduced[{cw,cb},cl,\[Delta]p,p,S] sets a sensible initial step \
size for cw,cb.  \>";\)\)], "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{

Cell["\<\
InitialStep[cl,p] sets a sensible initial step size for c's. May \
fail if the cl is incompatible with the allele frequencies.\
\>", 
  "Subsubsection"],

Cell[BoxData[
    \(\(InitialStep::usage = "\<InitialStep[p,\[Delta]p,cl] sets a sensible \
initial step size for c's. May fail if the cl is incompatible with the allele \
frequencies. \>";\)\)], "Input",
  InitializationCell->True]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["Constraints", "Subsection"],

Cell[CellGroupData[{

Cell["\<\
HaploidConstraints[k,\[Delta]p,p,S] gives a list of the constraints \
on gametic frequencies in terms of the reduced set of cumulants.  Stores \
results\
\>", "Subsubsection"],

Cell[BoxData[
    \(\(HaploidConstraints::usage = "\<HaploidConstraints[k,\[Delta]p,p,S] \
gives a list of the constraints on gametic frequencies in terms of the \
reduced set of cumulants.  Stores results\>";\)\)], "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    \(TextForm
    \`\(DiploidConstraints[{k\_w, k\_b}, \[Delta]p, p, S]\ gives\ a\ list\ of
      \ the\ constraints\ on\ diploid\ genotype\ frequencies\ in\ terms\ of\ 
      the\ reduced\ set\ of\ 
      cumulants . \ \ DiploidConstraints[{k\_w, k\_b}, \[Delta]p, p, S, gft]\ 
      stores\ the\ definition\ of\ FullGenotypeFrequencyTable[X,  .. ]\ in\ 
      \(gft[X] . \)\ \ \)\)], "Subsubsection"],

Cell[BoxData[
    \(\(DiploidConstraints::usage = \
\*"\"\<DiploidConstraints[{\!\(k\_w\),\!\(k\_b\)},\[Delta]p,p,S] gives a list \
of the constraints on diploid genotype frequencies in terms of the reduced \
set of cumulants.  \
DiploidConstraints[{\!\(k\_w\),\!\(k\_b\)},\[Delta]p,p,S,gft] stores the \
definition of DiploidGenotypeFrequencyReduced[X,..] in gft[X].  \>\"";\)\)], \
"Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData[{
  "MomentLimitsReduced",
  "[c[k],{c[2],c[3],..},\[Delta]p,p,S] gives the bounds on the values of \
c[k], based on constraints on gamete frequencies, and expressed in terms of \
c[].  The c's are given numerically by the list {c[2],c[3],..}."
}], "Subsubsection",
  InitializationCell->True],

Cell[BoxData[
    \(\(MomentLimitsReduced::usage = \
"\<MomentLimitsReduced[c[k],{c[2],c[3],..},\[Delta]p,p,S] gives the bounds on \
the values of c[k], based on constraints on gamete frequencies, and expressed \
in terms of c[].  The c's are given numerically by the list {c[2],c[3],..}.  \
MomentLimitsReduced[c[k],{c[2],c[3],..},cs] uses pre-calculated \
constraints.\>";\)\)], "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData[
"MomentLimits[{j,k},p.\[Delta]p,c] gives the bounds on the values of c[j,k], \
based on constraints on gamete frequencies, and expressed in terms of c[].  \
The c's are given numerically. If the constraints cannot be satisfied at all, \
returns {0,0}."], "Subsubsection"],

Cell[BoxData[
    \(\(MomentLimits::usage = "\<MomentLimits[{j,k},p,\[Delta]p,c] gives the \
bounds on the values of c[j,k], based on constraints on gamete frequencies, \
and expressed in terms of c[].  The c's are given numerically. If the \
constraints cannot be satisfied at all, returns {0,0}.\>";\)\)], "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{

Cell["\<\
ConstrainedIntervals[expr>0,x] gives a list of the possible \
intervals in which x can lie.\
\>", "Subsubsection"],

Cell[BoxData[
    \(\(ConstrainedIntervals::usage = "\<ConstrainedIntervals[expr>0,x] gives \
a list of the possible intervals in which x can lie.\>";\)\)], "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{

Cell["\<\
IntervalCombine[{{x1,y1},{x2,y2},..},{{X1,Y1},{X2,Y2},..},..] \
combines the lists of intervals\
\>", "Subsubsection"],

Cell[BoxData[
    \(\(IntervalCombine::usage = \
"\<IntervalCombine[{{x1,y1},{x2,y2},..},{{X1,Y1},{X2,Y2},..},..] combines the \
lists of intervals\>";\)\)], "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{

Cell["\<\
IntervalPosition[{{x1,y1},{x2,y2},..},z] returns zero if z is not \
in any interval and the relevant interval.\
\>", "Subsubsection"],

Cell[BoxData[
    \(\(IntervalPosition::usage = "\<IntervalPosition[{{x1,y1},{x2,y2},..},z] \
returns -k if z is just after the k'th interval and +k if it is in the k'th \
interval .\>";\)\)], "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData[{
  "MomentLimitsDiploid",
  "[cb[k],{cw,cb},{{cw[2],cw[3],..},{cb[2]..}},\[Delta]p,p,S] gives the \
bounds on the values of cb[k], based on constraints on diploid genotype \
frequencies, and expressed in terms of {cw[],cb[]}.  The cw's are given \
numerically by the lists {{cw[2],cw[3],..},{cb[2]..}}. "
}], "Subsubsection",
  InitializationCell->True],

Cell[BoxData[
    \(\(MomentLimitsDiploid::usage = \
"\<MomentLimitsDiploid[cb[k],{cw,cb},{{cw[2],cw[3],..},{cb[2]..}},\[Delta]p,p,\
S] gives the bounds on the values of cb[k], based on constraints on diploid \
genotype frequencies, and expressed in terms of {cw[],cb[]}.  The cw's are \
given numerically by the lists {{cw[2],cw[3],..},{cb[2]..}}. \
MomentLimitsDiploid[cb[k],{cw,cb},{{cw[2],cw[3],..},{cb[2]..}},cs] takes \
precalculated constraints.\>";\)\)], "Input",
  InitializationCell->True]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["Admixture models", "Subsection"],

Cell[CellGroupData[{

Cell[BoxData[
    \(TextForm
    \`MomentAfterMigration[U, c[i], {{j, m\_j}}]\ gives\ the\ moment\ after\ 
      migration\ at\ a\ rate\ m\_j\ from\ deme\ j\ into\ deme\ 
      i . \ \ MomentAfterMigration[U, c[i], {{j, m\_j} \[Ellipsis]}]\ allows\ 
      for\ several\ sources\ of\ immigrants . \ \ Expressed\ as\ a\ linear\ 
      mixture\ of\ \(\(c[j]\)[U] . \)\)], "Subsubsection"],

Cell[BoxData[
    \(\(MomentAfterMigration::usage = \*"\"\<MomentAfterMigration[U,c[i],{{j,\
\!\(m\_j\)}}] gives the moment after migration at a rate \!\(m\_j\) from deme \
j into deme i.  MomentAfterMigration[U,c[i],{{j,\!\(m\_j\)}\[Ellipsis]}] \
allows for several sources of immigrants.  Expressed as a linear mixture of \
c[j][U].\>\"";\)\)], "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{

Cell["\<\
MomentAfterRecombination[U,c,r] gives the moment after random \
mating and recombination, in terms of r[S,T].   \
\>", "Subsubsection"],

Cell[BoxData[
    \(\(MomentAfterRecombination::usage = "\<MomentAfterRecombination[U,c,r] \
gives the moment after recombination and random mating, in terms of r[S,T].  \
\>";\)\)], "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData[{
  "MomentSimple[i][U,c,pb,\[Delta]p] simplifies c[i][U] by supposing that \
deme 0 is in HW, and that the source demes are in linkage equilibrium and HW. \
 ",
  "MomentSimple",
  "[i][U,c,pb,\[Delta]pl,\[Delta]ps] allows for two migration rates from \
demes {-2,-1,0,1,2}, with the neighbouring demes {-1,1} now with the same \
c[]'s as deme 0."
}], "Subsubsection"],

Cell[BoxData[
    \(\(MomentSimple::usage = "\<MomentSimple[i][U,c,pb,\[Delta]p] simplifies \
c[i][U] by supposing that deme 0 is in HW, and that the source demes are in \
linkage equilibrium and HW.  MomentSimple[i][U,c,pb,\[Delta]pl,\[Delta]ps] \
allows for two migration rates from demes {-2,-1,0,1,2}, with the \
neighbouring demes {-1,1} now with the same c[]'s as deme 0.\>";\)\)], "Input",\

  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData[{
  "MomentNew[U,c,m,pb,r,\[Delta]p] gives the overall moment, measured after \
short-range migration.  ",
  "MomentNew",
  "[i][U,c,ml,ms,pb,r,\[Delta]pl,\[Delta]ps] allows for two migration rates."
}], "Subsubsection"],

Cell[BoxData[
    \(\(MomentNew::usage = "\<MomentNew[U,c,m,pb,r,\[Delta]p] gives the \
overall moment, measured after short-range migration.  \
MomentNew[i][U,c,ml,ms,pb,r,\[Delta]pl,\[Delta]ps] allows for two migration \
rates.\>";\)\)], "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData[{
  "MomentEquilibrium[U,c,m,pb,r,\[Delta]p] gives the equilibrium moment in \
deme 0, measured after short-range migration.  Stores results.  ",
  "MomentEquilibrium",
  "[U,c,ml,ms,pb,r,\[Delta]pl,\[Delta]ps] allows for two migration rates."
}], "Subsubsection"],

Cell[BoxData[
    \(\(MomentEquilibrium::usage = "\<MomentEquilibrium[U,c,m,pb,r,\[Delta]p] \
gives the equilibrium moment in deme 0, measured after short-range migration. \
 Stores results. MomentEquilibrium[U,c,ml,ms,pb,r,\[Delta]pl,\[Delta]ps] \
allows for two migration rates. \>";\)\)], "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData[{
  "CumulantEquilibrium[U,c,m,pb,r,\[Delta]p] gives the equilibrium cumulant \
in deme 0, measured after short-range migration.  Stores results. ",
  "CumulantEquilibrium",
  "[U,c,ml,ms,pb,r,\[Delta]pl,\[Delta]ps] allows for two migration rates. "
}], "Subsubsection"],

Cell[BoxData[
    \(\(CumulantEquilibrium::usage = "\<CumulantEquilibrium[U,c,m,pb,r,\
\[Delta]p] gives the equilibrium cumulant in deme 0, measured after \
short-range migration.  Stores results. CumulantEquilibrium[U,c,ml,ms,pb,r,\
\[Delta]pl,\[Delta]ps] allows for two migration rates. Gets slow for 8 way \
cumulants: 443s\>";\)\)], "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData[
"AdmixtureFrequency[X,c,ml,ms,pb,p,\[Delta]pl,\[Delta]ps,S] gives the \
frequency of genotype X under an admixture model.  Uses \
PossibleDiploidGenotypes[] and MomentEquilibrium[]."], "Subsubsection",
  InitializationCell->True],

Cell[BoxData[
    \(\(AdmixtureFrequency::usage = "\<AdmixtureFrequency[X,c,ml,ms,pb,p,\
\[Delta]pl,\[Delta]ps,S] gives the frequency of genotype X under an admixture \
model.  Uses DiploidGenotypeFrequency[] and moments MomentEquilibrium[].  \
AdmixtureFrequency[X,c,ml,ms,pb,p,\[Delta]pl,\[Delta]ps,S,Symmetric\[Rule]\
True] assumes loci are equivalent. Stores results.Very slow: better to use \
the compiled version of PossibleDiploidGenotypes[] if possible.\>";\)\)], \
"Input",
  InitializationCell->True]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData[{
  "Estimating ",
  Cell[BoxData[
      \(TraditionalForm\`\[Delta]p\_i\)]]
}], "Subsection"],

Cell[CellGroupData[{

Cell[BoxData[
    \(TraditionalForm
    \`\(\[Delta]pEst[netCV[site]\/\[Alpha], \[Sum]\_\(i\[Delta]p\_i\)]\ gives
      \ the\ list\ of\ \ \[Delta]p\_i\ \)\)], "Subsubsection",
  InitializationCell->True],

Cell[BoxData[
    \(\(\[Delta]pEst::usage = \
"\<\[Delta]pEst[netCV[site]/\[Alpha],\[Delta]pSum] gives the list of \
\[Delta]p's \>";\)\)], "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    \(TraditionalForm
    \`\[Delta]pMax[site]\ gives\ the\ maximum\ \(\[Delta]p\_i\) allowed\ for\ 
      each\ locus\)], "Subsubsection",
  InitializationCell->True],

Cell[BoxData[
    \(\(\[Delta]pMax::usage = \*"\"\<\[Delta]pMax[site] gives the maximum \
\!\(\[Delta]p\_i\)allowed for each locus\>\"";\)\)], "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData[
"\[Delta]pSoln[\[Delta]pS,\[Alpha],netCV[site]] gives the solution for \
\[Delta]pS, given \[Alpha]"], "Subsubsection",
  InitializationCell->True],

Cell[BoxData[
    \(\(\[Delta]pSoln::usage = \
"\<\[Delta]pSoln[\[Delta]pS,\[Alpha],netCV[site]] gives the solution for \
\[Delta]pS, given \[Alpha].\>";\)\)], "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData[
"\[Alpha]\[Delta]pSoln[\[Delta]pS,\[Alpha],site] gives the solution for \
\[Alpha] and \[Delta]pS;"], "Subsubsection",
  InitializationCell->True],

Cell[BoxData[
    \(\(\[Alpha]\[Delta]pSoln::usage = "\<\[Alpha]\[Delta]pSoln[\[Delta]pS,\
\[Alpha],site,{\[Alpha]0,\[Alpha]0'] gives the solution for \[Alpha] and \
\[Delta]pS\>";\)\)], "Input",
  InitializationCell->True]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["Random sampling", "Subsection"],

Cell[CellGroupData[{

Cell["\<\
DrawSamples[s,gF,nloci,{nt,ninds}] sets up nt datasets, stored as \
data[s[1]]..data[s[nt]], sampled from a population with genotype frequencies \
in the list gF, which can be generated by AdmixtureFrequency[]\
\>", 
  "Subsubsection"],

Cell[BoxData[
    \(\(DrawSamples::usage = "\<DrawSamples[s,gF,nloci,{nt,ninds}] sets up nt \
datasets, stored as data[s[1]]..data[s[nt]], sampled from a population with \
genotype frequencies in the list gF, which can be generated by \
AdmixtureFrequency[].  DrawSamples[s,gF,nloci,{{k1,k2},ninds}] sets up \
data[s[k1]]..data[s[k2]] \>";\)\)], "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    \(TextForm
    \`\(FindMLE[s, {Log[L], {{pl}, {\[Delta]p}, \[Kappa]l}, step0}, metList]\ 
            returns\ the\ MLE\ for\ Data[s], \ 
          found\ using\ the\ Metropolis\ algorithm, \ 
          in\ the\ form
            \ {log \((L)\), {{
                  p\_1 .. }, {{\[Delta]p\_1, 
                    \[Ellipsis]}}, {{\[Kappa]\_\(0, 0\), \[Ellipsis]} 
                    \[Ellipsis]}}, step0}}\) . \ step0\ has\ the\ form
      \ {{{\[CapitalDelta]p\_1 .. }}, {{\[CapitalDelta]\[Delta]p\_1, 
            \[Ellipsis]}}, {{\[Kappa]\_\(0, 0\), \[Ellipsis]} \[Ellipsis]}}\ 
      and\ determines\ which\ parameters\ are\ varied . \ metList\ is\ a\ list
      \ of\ the\ form\ {{T, {ntries, nprint}},  .. }\ which\ determines\ the\ 
      annealing\ schedule . \ Calls\ 
      MetropolisDisequilibrium[] . \ FindMLE[s, p, \[Delta]p, \[Kappa]]\ 
      returns\ the\ MLE\ for\ some\ actual\ matrix\ of\ cumulants\ listed\ in
      \ c; \ calls\ LogLikelihoodDisequilibrium[] . \ \ \ FindMLE[s, p]\ gives
        \ the\ HWLE\ estimates . \ \ Cumulant \[Rule] 
      False\ fits\ moments\ rather\ than\ \(cumulants . \)\)], "Subsubsection"],

Cell[BoxData[
    \(\(FindMLE::usage = \
\*"\"\<FindMLE[s,{Log[L],{{pl},{\[Delta]p},\[Kappa]l},step0},metList] returns \
the MLE for Data[s], found using the Metropolis algorithm, in the form \
{log(L),{{\!\(p\_1\)..},{{\!\(\[Delta]p\_1\),\[Ellipsis]}},{{\!\(\[Kappa]\_\(\
0, \\\\\\\ 0\)\),\[Ellipsis]}\[Ellipsis]}},step0}}. step0 has the form \
{{{\!\(\[CapitalDelta]p\_1\)..}},{{\!\(\[CapitalDelta]\[Delta]p\_1\),\
\[Ellipsis]}},{{\!\(\[Kappa]\_\(0, \\\\\\\ 0\)\),\[Ellipsis]}\[Ellipsis]}} \
and determines which parameters are varied. metList is a list of the form \
{{T,{ntries,nprint}},..} which determines the annealing schedule. Calls \
MetropolisDisequilibrium[]. FindMLE[s,p,\[Delta]p,\[Kappa]] returns the MLE \
for some actual matrix of cumulants listed in c; calls \
LogLikelihoodDisequilibrium[].   FindMLE[s,p] gives the HWLE estimates.  \
Cumulant\[Rule]False fits moments rather than cumulants.\>\"";\)\)], "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData[
"MakeRandomWalk[s,{Log[L],{{pl},{\[Delta]p},\[Kappa]l},step0},{T,{ntries,\
nprint}}, nvalues] generates a random walk at temperature T; with T=1, this \
follows the likelihood surface.  Each element of the output list has the same \
form as the second argument.  Output is generated every ntries cycles; the \
total number of elements is nvalues."], "Subsubsection"],

Cell[BoxData[
    \(\(MakeRandomWalk::usage = \
"\<MakeRandomWalk[s,{Log[L],{{pl},{\[Delta]p},\[Kappa]l},step0},{T,{ntries,\
nprint}}, nvalues] generates a random walk at temperature T; with T=1, this \
follows the likelihood surface.  Each element of the output list has the same \
form as the second argument.  Output is generated every ntries cycles; the \
total number of elements is nvalues.\>";\)\)], "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData[{
  "SetData[site,p,\[Delta]p,\[Delta]pV] sets up functions p, \[Delta]p,\
\[Delta]pV which are based on the sampled allele frequency.  ",
  "SetData",
  "[site,p,\[Delta]p] doesn't bother with \[Delta]pV."
}], "Subsubsection"],

Cell[BoxData[
    \(\(SetData::usage = "\<SetData[site,p,\[Delta]p,\[Delta]pV] sets up \
functions p, \[Delta]p,\[Delta]pV which are based on the sampled allele \
frequency.  SetData[site,p,\[Delta]p] doesn't bother with \
\[Delta]pV.\>";\)\)], "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{

Cell["\<\
 CumulantEquilibriumList[m,p,nloci] gives a list of the equilibrium \
cumulants under long 
  range migration\
\>", "Subsubsection"],

Cell[BoxData[
    \(\(CumulantEquilibriumList::usage = \
"\<CumulantEquilibriumList[m,p,nloci] gives a list of the equilibrium \
cumulants under long range migration.  Slow for 4 loci, because it requires \
calculation of an 8-way cumulant.\>";\)\)], "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    \(TextForm
    \`DoReplicates[m, p\&_, nloci, {nreps, ninds}, metK, r, MethodP -> Fit, 
        MethodC -> Fit]\ performs\ various\ tests\ on\ replicate\ samples, \ 
    fitting\ cumulants\ c\_\(j, k\) . \ Replicate\ samples\ are\ stored\ in\ 
      files\ named\ r[m, p], \ where\ m\ p\&_, \ 
    m\ q\&_\ are\ the\ rates\ of\ long - 
      range\ immigration . \ \ Results\ are\ \(\((in\ order)\) : \ HWLE\); 
    \ {optional\ set}; \ 
    true\ model\ \((with\ true\ p)\) . \ MethodP -> 
      Fit\ fits\ allele\ frequencies; \ Sample\ uses\ the\ estimated\ P; \ 
    True\ uses\ the\ actual\ P; \ \ 
    All\ uses\ all\ these\ \((default)\) . \ MethodC -> 
      Fit\ fits\ all\ moments; \ TrueC2\ fixes\ c\_\(1, 1\), \ c\_\(0, 2\); \ 
    True\ uses\ the\ actual\ C' s; \ \ Both\ uses\ True\ and\ Fit; \ 
    All\ uses\ all\ these\ \((default)\) . \ \ Cumulant \[Rule] 
      False\ fits\ moments\ instead\ of\ \(cumulants . \)\)], "Subsubsection"],

Cell[BoxData[
    \(\(DoReplicates::usage = \
\*"\"\<DoReplicates[m,\!\(p\&_\),nloci,{nreps,ninds},metK,r,MethodP->Fit,\
MethodC->Fit] performs various tests on replicate samples, fitting cumulants \
\!\(c\_\(j, \\\\\\\ k\)\). Replicate samples are stored in files named \
r[m,p], where m \!\(p\&_\), m \!\(q\&_\) are the rates of long-range \
immigration.  Results are (in order): HWLE; {optional set}; true model (with \
true p). MethodP->Fit fits allele frequencies; Sample uses the estimated P; \
True uses the actual P;  All uses all these (default). MethodC->Fit fits all \
moments; TrueC2 fixes \!\(c\_\(1, \\\\\\\ 1\)\), \!\(c\_\(0, \\\\\\\ 2\)\); \
True uses the actual C's;  Both uses True and Fit; All uses all these \
(default).  Cumulant\[Rule]False fits moments instead of \
cumulants.\>\"";\)\)], "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{

Cell["\<\
MethodP is an option for DoReplicates[] which determines how allele \
frequencies are to be fitted.\
\>", "Subsubsection"],

Cell[BoxData[
    \(\(MethodP::usage = "\<MethodP is an option for DoReplicates[] which \
determines how allele frequencies are to be fitted.\>";\)\)], "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{

Cell["\<\
Sample is a setting for the option MethodP which ensures that \
DoReplicates[] uses the sampled allele frequencies.\
\>", "Subsubsection"],

Cell[BoxData[
    \(\(Sample::usage = "\<Sample is a setting for the options MethodP, \
MethodC which ensures that DoReplicates[] uses the sampled allele frequencies \
or cumulants.\>";\)\)], "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    \(TextForm\`RandomUnionMethod\ is\ a\ setting\ for\ the\ option\ MethodC\ \
which\ ensures\ that\ DoReplicates[]\ fits\ cumulants\ appropriate\ for\ \
random\ union\ of\ gametes\ \(\((i . e . , \ \[Kappa]\_\(j, k\) \[NotEqual] 
            0\ only\ if\ j\ or\ k\ is\ zero)\)\(.\)\)\)], "Subsubsection"],

Cell[BoxData[
    \(\(RandomUnionMethod::usage = \*"\"\<RandomUnionMethod is a setting for \
the option MethodC which ensures that DoReplicates[] fits cumulants \
appropriate for random union of gametes (i.e., \!\(\[Kappa]\_\(j, \\\\\\\ \
\(\(\\\\\\\\\)\(\\\\\\\ \)\(k\)\)\)\)\[NotEqual]0 only if j or k is \
zero).\>\"";\)\)], "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    \(TextForm
    \`LinkageEquilibrium\ is\ a\ setting\ for\ the\ option\ MethodC\ which\ 
      ensures\ that\ DoReplicates[]\ fits\ cumulants\ appropriate\ for\ 
      linkage\ equilibrium\ 
      \(\((i . e . , \ only\ \[Kappa]\_\(0, 0\), \ 
          \[Kappa]\_\(1, 1\) \[NotEqual] 0)\) . \)\)], "Subsubsection"],

Cell[BoxData[
    \(\(LinkageEquilibrium::usage = \*"\"\<LinkageEquilibrium is a setting \
for the option MethodC which ensures that DoReplicates[] fits cumulants \
appropriate for linkage equilibrium (i.e., only \!\(\[Kappa]\_\(0, \\\\\\\ \
0\)\), \!\(\[Kappa]\_\(1, \\\\\\\ 1\)\)\[NotEqual]0).\>\"";\)\)], "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    \(TextForm
    \`HWLE\ is\ a\ setting\ for\ the\ option\ MethodC\ which\ ensures\ that\ 
        DoReplicates[]\ fits\ cumulants\ appropriate\ for\ Hardy - 
      Weinberg\ and\ linkage\ equilibrium\ 
        \(\((i . e . , \ 
            all\ \[Kappa]\_\(j, k\) = 0\ except\ \[Kappa]\_\(0, 0\))\) . 
          \)\)], "Subsubsection"],

Cell[BoxData[
    \(\(HWLE::usage = \*"\"\<HWLE is a setting for the option MethodC which \
ensures that DoReplicates[] fits cumulants appropriate for Hardy-Weinberg and \
linkage equilibrium (i.e., all \!\(\[Kappa]\_\(j, \\\\\\\ k\)\)=0 except \!\(\
\[Kappa]\_\(0, \\\\\\\ 0\)\)).\>\"";\)\)], "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{

Cell["\<\
MethodC is an option for DoReplicates[] which determines how the \
matrix of moments is to be fitted.\
\>", "Subsubsection"],

Cell[BoxData[
    \(\(MethodC::usage = "\<MethodC is an option for DoReplicates[] which \
determines how the matrix of moments is to be fitted.\>";\)\)], "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    \(TextForm
    \`TrueC2\ is\ a\ setting\ for\ the\ option\ MethodC\ which\ ensures\ that
      \ DoReplicates[]\ fixes\ c\_\(1, 1\)\ and\ c\_\(0, 2\)\ at\ their\ true
      \ values, \ but\ fits\ the\ other\ \(moments . \)\)], "Subsubsection"],

Cell[BoxData[
    \(\(TrueC2::usage = \*"\"\<TrueC2 is a setting for the option MethodC \
which ensures that DoReplicates[] fixes \!\(c\_\(1, \\\\\\\ 1\)\) and \!\(c\_\
\(0, \\\\\\\ 2\)\) at their true values, but fits the other \
moments.\>\"";\)\)], "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{

Cell["\<\
DoReplicatesReduced[m,p,nloci,{nreps,ninds},metK,r] performs \
various tests on replicate  
samples, fitting cumulants cw[j],cb[j]\
\>", "Subsubsection"],

Cell[BoxData[
    \(\(DoReplicatesReduced::usage = \
"\<DoReplicatesReduced[m,p,nloci,{nreps,ninds},metK,r] performs various tests \
on replicate samples. Results are (in order): HWLE; MLE ; actual model \
(fitting p); true model (with true p). All except the last fit allele \
frequencies by MLE.\>";\)\)], "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{

Cell["\<\
MakeSets[nloci] gives an appropriate set of loci for generating the \
expected cumulants.  Works for 2-4 loci.\
\>", "Subsubsection"],

Cell[BoxData[
    \(\(MakeSets::usage = "\<MakeSets[nloci] gives an approriate set of loci \
for generating the expected between-genome cumulants.  Works for 2-4 \
loci.\>";\)\)], "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    \(TextForm
    \`PresentResults[results]\ gives\ a\ table\ which\ presents\ the\ mean\ 
      and\ standard\ deviation\ of\ log \((L)\)\ and\ \[Kappa]\_\(0, 2\), \ 
    \[Kappa]\_\(1, 1\), \ \[Kappa]\_\(1, 2\), \ 
    \[Kappa]\_\(2, 2\) . \ \ The\ same\ set\ of\ options\ should\ be\ given\ 
      as\ for\ the\ run\ of\ DoReplicates[]\ which\ generated\ the\ 
      \(results . \)\)], "Subsubsection"],

Cell[BoxData[
    \(\(PresentResults::usage = \*"\"\<PresentResults[results,{m,p}] gives a \
table which presents the mean and standard deviation of log(L) and \!\(\
\[Kappa]\_\(0, \\\\\\\ 2\)\), \!\(\[Kappa]\_\(1, \\\\\\\ 1\)\), \
\!\(\[Kappa]\_\(1, \\\\\\\ 2\)\), \!\(\[Kappa]\_\(2, \\\\\\\ 2\)\).  The same \
set of options should be given as for the run of DoReplicates[] which \
generated the results.\>\"";\)\)], "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    \(TextForm
    \`CompareLogL[results, {i, j}]\ compares\ the\ likelihood\ of\ method\_i\ 
      with\ that\ of\ method\_j, \ 
    using\ a\ set\ of\ results\ generated\ by\ 
      DoReplicates[] . \ \ \ Returns\ a\ list\ of\ the\ differences\ in\ log 
      \(\((likelihood)\) . \)\)], "Subsubsection"],

Cell[BoxData[
    \(\(CompareLogL::usage = \*"\"\<CompareLogL[results,{i,j}] compares the \
likelihood of \!\(method\_i\) with that of \!\(method\_j\), using a set of \
results generated by DoReplicates[].   Returns a list of the differences in \
log(likelihood).\>\"";\)\)], "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    \(TextForm
    \`PresentLogL[
        results, {{j, k}, \[Ellipsis]}, {df\_\(j, k\), \[Ellipsis]}, {
          name\_\(j, k\), \[Ellipsis]}, P]\ presents\ a\ table\ summarising\ a
      \ list\ of\ comparisons\ based\ on\ results\ produced\ by\ 
      DoReplicates[] . \ \ {{j, k}, \[Ellipsis]}\ is\ a\ list\ of\ comparisons
      \ between\ method\ j\ and\ method\ k\ in\ 
      results . \ {df\_\(j, k\), \[Ellipsis]}\ gives\ the\ corresponding\ 
      degrees\ of\ freedom, \ 
    and\ {\(name\_\(j, k\)\) \[Ellipsis]}\ the\ corresponding\ names . \ \ P\ 
      gives\ the\ significance\ level . \ \ The\ table\ lists\ the\ number\ of
      \ valid\ log \((L)\); \ 
    the\ mean\ and\ variance\ of\ the\ valid\ log \((L)\); \ 
    the\ number\ of\ negative\ \[CapitalDelta]log \((L)\); \ 
    and\ the\ number\ of\ cases\ in\ which\ the\ hypothesis\ was\ rejected\ at
      \ significance\ level\ P, \ 
    based\ on\ the\ asymptotic\ 1/2  \[Chi]\^2\ \(distribution . \)\)], 
  "Subsubsection"],

Cell[BoxData[
    \(\(PresentLogL::usage = \*"\"\<PresentLogL[results,{{j,k},\[Ellipsis]},{\
\!\(df\_\(j, \\\\\\\ k\)\),\[Ellipsis]},{\!\(name\_\(j, \\\\\\\ k\)\),\
\[Ellipsis]},P] presents a table summarising a list of comparisons based on \
results produced by DoReplicates[].  {{j,k},\[Ellipsis]} is a list of \
comparisons between method j and method k in results. {\!\(df\_\(j, \\\\\\\ k\
\)\),\[Ellipsis]} gives the corresponding degrees of freedom, and {\!\(name\_\
\(j, \\\\\\\ k\)\)\[Ellipsis]} the corresponding names.  P gives the \
significance level.  The table lists the number of valid log(L); the mean and \
variance of the valid log(L); the number of negative \[CapitalDelta]log(L); \
and the number of cases in which the hypothesis was rejected at significance \
level P, based on the asymptotic 1/2\!\(\[Chi]\^2\) distribution.\>\"";\)\)], \
"Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    \(TextForm
    \`PlotLogL[results, {{j, k}, \[Ellipsis]}, {\(df\_\(j, k\)\) \[Ellipsis]}]
        \ plots\ the\ cumulative\ distributions\ of\ \[CapitalDelta]log 
      \((L)\), \ 
    and\ the\ asymptotic\ 1/2  \[Chi]\^2\ distribution . \ Uses\ results\ 
      produced\ by\ DoReplicates[] . \ \ {{j, k}, \[Ellipsis]}\ is\ a\ list\ 
      of\ comparisons\ between\ method\ j\ and\ method\ k\ in\ results; \ 
    each\ gives\ a\ graph . \ \ {df\_\(j, k\), \[Ellipsis]}\ gives\ the\ 
      corresponding\ degrees\ of\ \(freedom . \)\)], "Subsubsection"],

Cell[BoxData[
    \(\(PlotLogL::usage = \*"\"\<PlotLogL[results,{{j,k},\[Ellipsis]},{\!\(df\
\_\(j, \\\\\\\ k\)\)\[Ellipsis]}] plots the cumulative distributions of \
\[CapitalDelta]log(L), and the asymptotic 1/2\!\(\[Chi]\^2\) distribution. \
Uses results produced by DoReplicates[].  {{j,k},\[Ellipsis]} is a list of \
comparisons between method j and method k in results; each gives a graph.  \
{\!\(df\_\(j, \\\\\\\ k\)\),\[Ellipsis]} gives the corresponding degrees of \
freedom.\>\"";\)\)], "Input",
  InitializationCell->True]
}, Closed]]
}, Closed]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Private parts", "Section"],

Cell[BoxData[
    \(\(Begin["\<Multilocus`EstimatingD`Private`\>"];\)\)], "Input",
  InitializationCell->True,
  AspectRatioFixed->False],

Cell["\<\
These packages should not need to be reloaded; but perhaps there \
was a bug at some stage....\
\>", "Text"],

Cell[BoxData[
    \(<< Statistics`ContinuousDistributions`; << 
      Graphics`Graphics`;\)], "Input",
  InitializationCell->True],

Cell[CellGroupData[{

Cell["Obsolete functions", "Subsection"],

Cell[CellGroupData[{

Cell[BoxData[
    StyleBox[\(RandomMating[
          c]\ simplifies\ the\ moments\ c[]\ on\ the\ assumption\ of\ random\ \
mating\ between\ diploids . \ \ For\ example, \ \ c[{i, \(i\^*\), \
\(j\&^\^*\), k\&^\^\[Dagger]}] /. 
        RandomMating[
            c]\ gives\ c[{i, \(i\^*\)}]\ c[{\(j\&^\^*\), k\&^\^\[Dagger]}]\),
      FontFamily->"Times"]], "Subsubsection"],

Cell[BoxData[
    \(RandomMating[
        c_] := {c[
            U_] :> \((Module[{uu = \((U /. Separate)\)}, 
                If[Depth[uu] == 4, \n\t\t\t\t\t\tc[uu[\([1]\)] /. Combine]*
                    c[uu[\([2]\)] /. Combine], c[U]]] /. {c[{}] :> 
                  1})\)}\)], "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{

Cell["Recombined", "Subsubsection"],

Cell[BoxData[{
    \(\(Recombined[\(c_[x_]\)[M_List], r_] := 
        Module[{cc}, 
          Recombined[cc[M], r] /. {cc[U_] -> \(c[x]\)[U]}];\)\), "\n", 
    \(\(Recombined[c_[M_List], r_] := 
        Module[{s, t, 
            mm = \((M /. Separate)\) /. {a_List, b_List} -> {a, 
                    b, {}}}, \((\(\(AddUp[
                      AddUp[r[s, TakeAway[mm[\([1]\)], s]] 
                          r[t, TakeAway[mm[\([2]\)], t]] 
                          c[{{s, TakeAway[mm[\([1]\)], s], mm[\([3]\)]}, {t, 
                                TakeAway[mm[\([2]\)], t], {}}}], s, 
                        Subsets[mm[\([1]\)]]], t, Subsets[mm[\([2]\)]]] /. 
                    r[U_List, V_List] \[RuleDelayed] 
                      1\/2\ r @@ Sort[{Union[U], Union[V]}]\) /. {r[{}, {}] -> 
                      1, r[{}, {_}] -> 1}\) /. 
                c[U_List] :> c[U /. Combine])\) If[mm[\([1]\)] === {}, 2, 1] 
            If[mm[\([2]\)] === {}, 2, 1]];\)\)}], "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    StyleBox[\(\(\ \)\(ChangeSex[{i, \(j\^*\)}]\ returns\ {\(i\^*\), 
            j} . \ \ Obsolete . \)\),
      FontFamily->"Times"]], "Subsubsection"],

Cell[BoxData[
    \(\(ChangeSex[U_List] := 
        Module[{t = U /. Separate}, {t[\([2]\)], t[\([1]\)]} /. 
            Combine];\)\)], "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{

Cell["ShiftCentre", "Subsubsection"],

Cell[BoxData[
    \(\(ShiftCentre[c_[U_List], \[CapitalDelta]p_] := 
        Apply[Plus, 
            Map[\((c[TakeAway[U, #]] 
                    Apply[Times, Map[\[CapitalDelta]p[{#}] &, #]])\) &, 
              Subsets[U]]] /. {c[{}] -> 1};\)\)], "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{

Cell["RandomUnionObsolete", "Subsubsection"],

Cell[BoxData[
    \(RandomUnionObsolete[
        c_] := {c[
            U_] :> \((Module[{uu = \((U /. Separate)\)}, \n\t\t\t\t\tIf[
                  Depth[uu] == 3, \n\t\t\t\t\tIf[Length[uu] == 2, 
                    c[{uu[\([1]\)], {}} /. Combine]*
                      c[{{}, uu[\([2]\)]} /. 
                          Combine], \n\t\t\t\t\t\tc[{uu[\([1]\)], {}, 
                            uu[\([3]\)]} /. Combine]*
                      c[{{}, uu[\([2]\)], {}} /. Combine]], c[U]]] /. {c[{}] :> 
                  1})\)}\)], "Input",
  InitializationCell->True]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["Moments from g[X], g[X] from moments & cumulants", "Subsection"],

Cell[CellGroupData[{

Cell["\<\
MomentFromG[{i,j},g,p,S] gives the moment c[{i,j}], relative to \
allele frequencies p[i], as a function of gamete frequencies g[]; S is the \
complete set of loci.\
\>", "Subsubsection"],

Cell[BoxData[
    \(\(Options[MomentFromG] = {Diploid \[Rule] False};\)\)], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(\(MomentFromG[U_List, g_, p_, S_, opts___Rule] := 
        If[\(Diploid /. {opts}\) /. 
            Options[MomentFromG], \n\t\tModule[{n = 
                Length[S]}, \n\t\t\ \ \ MomentFromG[U, g, p, 
                Join[S, ChangeSex[S]]] /. 
              g[x_List] :> g[Partition[x, n]]], \n\t\tModule[{gt = 
                HaploidTypes[Length[S]], pp = Map[p, S], 
              ss = Locations[S, U]}, \n\t\tApply[Plus, 
              Map[g[#] Apply[Times, Extract[\((# - pp)\), ss]] &, 
                gt]]]];\)\)], "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{

Cell["\<\
HaploidGenotypeFrequency[X,c,p,S] gives an expression for g[X] in \
terms of the moments c[] and allele frequencies p[]. \
HaploidGenotypeFrequency[nloci][p1,..pn,c[{1,2}]...] stores a compiled \
version of g[{1,1..},..], which takes as arguments the n allele frequencies \
and 2^n-n-1 moments.  HaploidGenotypeFrequency[X,c,p] uses this to find the \
frequency of genotype X; c and p must then be given as lists of numbers\
\>", \
"Subsubsection"],

Cell[BoxData[
    \(\(HaploidGenotypeFrequency[X_List, cc_, p_, 
          S_] := \(HaploidGenotypeFrequency[X, cc, p, S] = 
          Module[{ii, ll, pql, n = Length[S], n0 = Count[X, 0]}, \n\t\tpql = 
              Table[If[X[\([ii]\)] == 1, p[S[\([ii]\)]], 
                  1 - p[S[\([ii]\)]]], {ii, n}]; \((Times @@ 
                  pql)\) + \(\((\(-1\))\)\^n0\) \((Plus @@ 
                    Map[\((ll = 
                            Locations[S, 
                              TakeAway[
                                S, #]]; \n\t\t\t\t\t\t\t\t\((\((\((\(-1\))\)^
                                  Count[Extract[X, ll], 0])\)*\((Times @@ 
                                  Extract[pql, ll])\) cc[#])\))\) &, 
                      HaploidSubsets[S]])\)]\);\)\)], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(\(HaploidGenotypeFrequency[nl_] := \(HaploidGenotypeFrequency[nl] = 
          Module[{cc, pp, gx, vars, rl, tv}, \n\t\tvars = 
              cc /@ Subsets[Range[nl], 2, nl]; \n\ \ \ \ rl[
                xx_List] := \(({vars, Flatten[xx]} // Transpose)\) /. {x_, 
                    y_} :> \((x -> 
                      y)\); \n\t\tgx = \(HaploidGenotypeFrequency[
                    Table[1, {nl}], cc, pp, Range[nl]] /. 
                  pp[j_] :> \(StandardSet[nl, pp]\)[\([j]\)]\) /. 
                rl[StandardSet[nl, cc, All]]; \n\t\t\ttv = 
              Transpose[{{StandardSet[nl, pp], StandardSet[nl, cc, All]} // 
                    Flatten, Table[_Real, {2\^nl - 1}]}]; \n\t\t\tCompile[
              tv // Evaluate, gx // Evaluate]]\);\)\)], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(\(HaploidGenotypeFrequency[X_List, cl_List, pl_List] := \n\t
        Module[{nl = Length[X], vars, 
            pp}, \n\t\tpp = \((\((1 - X)\) + \((2  X - 1)\) pl)\); \n\t
          HaploidGenotypeFrequency[nl] @@ 
            Flatten[{pp, Flatten[cl]*SignMask[X]}]];\)\)], "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{

Cell["\<\
PossibleDiploidGenotypes[{0,1,0}] gives the list of actual \
genotypes, {{{0,1,0},{0,0,0}},{{{0,0,0},{0,1,0}}}, consistent with this \
diploid genotype. \
\>", "Subsubsection"],

Cell[BoxData[{
    \(\(PossibleDiploidGenotypes[{a___, 0}] := 
        PossibleDiploidGenotypes[{a}, {{{0}, {0}}}];\)\), "\n", 
    \(\(PossibleDiploidGenotypes[{a___, 1}] := 
        PossibleDiploidGenotypes[{a}, {{{0}, {1}}, {{1}, {0}}}];\)\), "\n", 
    \(\(PossibleDiploidGenotypes[{a___, 2}] := 
        PossibleDiploidGenotypes[{a}, {{{1}, {1}}}];\)\), "\n", 
    \(\(PossibleDiploidGenotypes[{}, a_List] := a;\)\)}], "Input",
  InitializationCell->True],

Cell[BoxData[{
    \(\(PossibleDiploidGenotypes[{y___, 0}, x_List] := 
        PossibleDiploidGenotypes[{y}, 
          Map[\((# /. {{a___}, {b___}} -> {{0, a}, {0, b}})\) &, 
            x]];\)\), "\n", 
    \(PossibleDiploidGenotypes[{y___, 1}, x_List] := 
      PossibleDiploidGenotypes[{y}, 
        Flatten[Map[\((# /. {{a___}, {b___}} -> {{{1, a}, {0, b}}, {{0, 
                          a}, {1, b}}})\) &, x], 1]]; 
    PossibleDiploidGenotypes[{y___, 2}, x_List] := 
      PossibleDiploidGenotypes[{y}, 
        Map[\((# /. {{a___}, {b___}} -> {{1, a}, {1, b}})\) &, 
          x]];\)}], "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    \(TextForm\`DiploidGenotypeFrequency[{X, \(X\^*\)}, c, p, 
        S]\ gives\ the\ frequency\ of\ diploid\ genotype\ {X, \(X\^*\)}\ in\ \
terms\ of\ the\ moments\ and\ allele\ frequencies, \ c[], \ 
    p[] . \ \ DiploidGenotypeFrequency[{X, \(X\^*\)}, c, 
          p]\ uses\ the\ compiled\ version, \ 
    where\ c\ and\ p\ are\ lists\ of\ numbers; \ 
    c\ lists\ the\ moments\ in\ the\ same\ order\ as\ DiploidSubsets[]\)], \
"Subsubsection"],

Cell[BoxData[
    \(DiploidGenotypeFrequency[U_, c_, p_, S_] := 
      Plus @@ \((\(\((HaploidGenotypeFrequency[Flatten[#], c, p, 
                    Join[S, ChangeSex[S]]] /. Symmetrise[c])\) &\) /@ 
            PossibleDiploidGenotypes[U])\)\)], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(\(DiploidGenotypeFrequency[U_List, c_List, p_List] := 
        Plus @@ \((\(HaploidGenotypeFrequency[Flatten[#], c, Join[p, p]] &\) /@ 
              PossibleDiploidGenotypes[U])\);\)\)], "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    \(TextForm\`DiploidGenotypeFrequencyList[{p\_1, \[Ellipsis], 
          p\_n}, {{c\_\(0, 0\), 
            c\_\(1, 0\), \[Ellipsis]}, \[Ellipsis]}]\ calculates\ the\ matrix\
\ of\ 2\^n\[Times]2\^n\ diploid\ genotype\ frequencies\ from\ the\ allele\ \
frequencies\ and\ matrix\ of\ moments; \ 
    assumes\ \[Delta]p = 
      1. \ \ DiploidGenotypeFrequencyList[{p\_1, \[Ellipsis], 
            p\_n}, {\[Delta]p\_1, \[Ellipsis]}, {{c\_\(0, 0\), 
              c\_\(1, 0\), \[Ellipsis]}, \[Ellipsis]}]\ allows\ divergence\ \
\[Delta]p\ to\ vary\ across\ loci . \ 
          DiploidGenotypeFrequencyList[{{p\_1, \[Ellipsis], 
                p\_n}, {\(p\_1\%*\), \[Ellipsis]}}, {{\[Delta]p\_1, \
\[Ellipsis]}, {\(\[Delta]p\_1\%*\), \[Ellipsis]}}, {{c\_\(0, 0\), 
                c\_\(1, 0\), \[Ellipsis]}, \[Ellipsis]}, 
            Symmetric \[Rule] 
              False]\ allows\ the\ male\ and\ female\ gamete\ pools\ to\ \
differ . \ \(DiploidGenotypeFrequencyList[n]\)[{p\_1, \[Ellipsis], 
              p\_n}, {\[Delta]p\_1, \[Ellipsis]}, {{c\_\(0, 0\), 
                c\_\(1, 0\), \[Ellipsis]}, \[Ellipsis]}], \ \
\(DiploidGenotypeFrequencyList[n, 
          Symmetric \[Rule] False]\)[{{p\_1, \[Ellipsis], 
            p\_n}, {\(p\_1\%*\), \[Ellipsis]}}, {{\[Delta]p\_1, \[Ellipsis]}, \
{\(\[Delta]p\_1\%*\), \[Ellipsis]}}, {{c\_\(0, 0\), 
            c\_\(1, 0\), \[Ellipsis]}, \[Ellipsis]}]\ are\ compiled\ \
\(\(versions\)\(.\)\)\)], "Subsubsection"],

Cell[BoxData[
    \(\(Options[
          DiploidGenotypeFrequencyList] = {Symmetric \[Rule] 
            True};\)\)], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(\(DiploidGenotypeFrequencyList[pl_List, ce_List, opts___Rule] := \n\t
        Module[{M1, 
            M2}, \n\ \ \ \ \ If[\(Symmetric /. {opts}\) /. 
              Options[DiploidGenotypeFrequencyList], \n\t\t\t\ M1 = \(M2 = 
                Matrix\[CapitalGamma][pl, Length[pl]]\), \n\t\t\t\ M1 = 
              Matrix\[CapitalGamma][
                pl\[LeftDoubleBracket]1\[RightDoubleBracket], 
                Length[pl\[LeftDoubleBracket]1\[RightDoubleBracket]]]; \ 
            M2 = Matrix\[CapitalGamma][
                pl\[LeftDoubleBracket]2\[RightDoubleBracket], 
                Length[pl\[LeftDoubleBracket]2\[RightDoubleBracket]]]]; \n\t\ \
\ M1 . ce . Transpose[M2]];\)\)], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(\(DiploidGenotypeFrequencyList[pl_List, \[Delta]pl_List, ce_List, 
          opts___Rule] := \n\t
        Module[{M1, 
            M2}, \n\t\tIf[\(Symmetric /. {opts}\) /. 
              Options[DiploidGenotypeFrequencyList], \n\t\t\t\ M1 = \(M2 = 
                Matrix\[CapitalGamma][pl, \[Delta]pl, 
                  Length[pl]]\), \n\t\t\t\ M1 = 
              Matrix\[CapitalGamma][
                pl\[LeftDoubleBracket]1\[RightDoubleBracket], \[Delta]pl\
\[LeftDoubleBracket]1\[RightDoubleBracket], 
                Length[pl\[LeftDoubleBracket]1\[RightDoubleBracket]]]; \ 
            M2 = Matrix\[CapitalGamma][
                pl\[LeftDoubleBracket]2\[RightDoubleBracket], \[Delta]pl\
\[LeftDoubleBracket]2\[RightDoubleBracket], 
                Length[pl\[LeftDoubleBracket]2\[RightDoubleBracket]]]]; \n\t\ \
\ M1 . ce . Transpose[M2]];\)\)], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(\(DiploidGenotypeFrequencyList[n_, opts___Rule] := \n\t
        Module[{M1, 
              M2}, \n\ \ \ \ \ If[\(Symmetric /. {opts}\) /. 
                Options[
                  DiploidGenotypeFrequencyList], \n\t\t\t\ M1 = \(M2 = \
\(Matrix\[CapitalGamma][
                      n]\)[#1, #2]\), \n\t\t\t\ M1 = \(Matrix\[CapitalGamma][
                    n]\)[#1\[LeftDoubleBracket]1\[RightDoubleBracket], #2\
\[LeftDoubleBracket]1\[RightDoubleBracket]]; \ 
              M2 = \(Matrix\[CapitalGamma][
                    n]\)[#1\[LeftDoubleBracket]2\[RightDoubleBracket], #2\
\[LeftDoubleBracket]2\[RightDoubleBracket]]]; \n\t\ \ M1 . #3 . 
              Transpose[M2]] &;\)\)], "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{

Cell["\<\
SignMask[X] stores the signs associated with the moments of this \
genotype\
\>", "Subsubsection"],

Cell[BoxData[
    \(\(SignMask[
          X_List] := \(SignMask[
            X] = \(\((Times @@ \((\(\((2  X - 
                              1)\)\[LeftDoubleBracket]#\[RightDoubleBracket] \
&\) /@ #)\))\) &\) /@ HaploidSubsets[Range[Length[X]]]\);\)\)], "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    \(TextForm\`DiploidGenotypeFrequencyReduced[{0, 2, 0, 0, 1}, {k\_w, 
          k\_b}, \[Delta]p, p, 
        S]\ gives\ the\ frequency\ of\ the\ diploid\ genotype\ using\ \
simplified\ cumulants\ k\_w[], \ \(\(k\_b[]\)\(.\)\)\)], "Subsubsection"],

Cell[BoxData[
    \(\(DiploidGenotypeFrequencyReduced[XY_List, {cw_, cb_}, \[Delta]p_, p_, 
          S_] := \(DiploidGenotypeFrequencyReduced[XY, {cw, cb}, \[Delta]p, 
            p, S] = Plus @@ \((\(FullGenotypeFrequencyReduced[#, {cw, 
                      cb}, \[Delta]p, p, S] &\) /@ 
                PossibleDiploidGenotypes[XY])\)\);\)\)], "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{

Cell["Checking DiploidGenotypeFrequencyReduced", "Subsubsection"],

Cell[CellGroupData[{

Cell[BoxData[
    \(Sum[
      DiploidGenotypeFrequencyReduced[{aa, bb}, {cw, cb}, \[Delta]p, 
        p, {i, j}], {aa, 0, 2}, {bb, 0, 2}]\)], "Input"],

Cell[BoxData[
    \(1\)], "Output"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    \(Sum[
        \((aa - 2  p[i])\) 
          DiploidGenotypeFrequencyReduced[{aa, bb}, {cw, cb}, \[Delta]p, 
            p, {i, j}], {aa, 0, 2}, {bb, 0, 2}] // Expand\)], "Input"],

Cell[BoxData[
    \(0\)], "Output"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    \(Sum[
        \((1 - \((aa - 1)\)\^2)\) \((1 - \((bb - 1)\)\^2)\) 
          DiploidGenotypeFrequencyReduced[{aa, bb}, {cw, cb}, \[Delta]p, 
            p, {i, j}], {aa, 0, 2}, {bb, 0, 2}] // Expand\)], "Input"],

Cell[BoxData[
    \(2\ \((
        2\ p[i]\ p[j] - 2\ p[i]\^2\ p[j] - 2\ p[i]\ p[j]\^2 + 
          2\ p[i]\^2\ p[j]\^2 - 2\ cb[2]\ p[j]\ \[Delta]p[i]\^2 + 
          2\ cb[2]\ p[j]\^2\ \[Delta]p[i]\^2 + 
          cb[2]\ \[Delta]p[i]\ \[Delta]p[j] + 
          cw[2]\ \[Delta]p[i]\ \[Delta]p[j] - 
          2\ cb[2]\ p[i]\ \[Delta]p[i]\ \[Delta]p[j] - 
          2\ cw[2]\ p[i]\ \[Delta]p[i]\ \[Delta]p[j] - 
          2\ cb[2]\ p[j]\ \[Delta]p[i]\ \[Delta]p[j] - 
          2\ cw[2]\ p[j]\ \[Delta]p[i]\ \[Delta]p[j] + 
          4\ cb[2]\ p[i]\ p[j]\ \[Delta]p[i]\ \[Delta]p[j] + 
          4\ cw[2]\ p[i]\ p[j]\ \[Delta]p[i]\ \[Delta]p[j] - 
          2\ cb[3]\ \[Delta]p[i]\^2\ \[Delta]p[j] + 
          4\ cb[3]\ p[j]\ \[Delta]p[i]\^2\ \[Delta]p[j] - 
          2\ cb[2]\ p[i]\ \[Delta]p[j]\^2 + 
          2\ cb[2]\ p[i]\^2\ \[Delta]p[j]\^2 - 
          2\ cb[3]\ \[Delta]p[i]\ \[Delta]p[j]\^2 + 
          4\ cb[3]\ p[i]\ \[Delta]p[i]\ \[Delta]p[j]\^2 + 
          2\ cb[4]\ \[Delta]p[i]\^2\ \[Delta]p[j]\^2 + 
          2\ cw[2]\^2\ \[Delta]p[i]\^2\ \[Delta]p[j]\^2)\)\)], "Output"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    \(% /. cb[_] -> 0 // Factor\)], "Input"],

Cell[BoxData[
    \(2\ \((
        2\ \ p[i]\ q[i]\ p[j] q[j] + 
          cw[2]\ \((\ p[i] - q[i])\)\ \((\ p[j] - q[j])\)\ \[Delta]p[i]\ 
            \[Delta]p[j] + 2\ cw[2]\^2\ \[Delta]p[i]\^2\ \[Delta]p[j]\^2)
        \)\)], "Output"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    FormBox[
      FormBox[
        \(FullGenotypeFrequencyReduced[{X, \(X\^*\)}, {k\_w, k\_b}, 
            \[Delta]p, p, S]\ gives\ the\ frequency\ of\ the\ full\ diploid\ 
          genotype\ {X, \ \(X\^*\)} in\ terms\ of\ the\ reduced\ set\ of\ 
          cumulants
          \ {k\_w, k\_b} . \ 
            FullGenotypeFrequencyReduced[X, k, \[Delta]p, p, S]\ gives\ 
          haploid\ genotype\ \(freqiuencies . \)\),
        "TextForm"], TextForm]], "Subsubsection"],

Cell[BoxData[
    \(\(FullGenotypeFrequencyReduced[X : {__Integer}, c_, \[Delta]p_, p_, 
          S_List] := 
        Module[{jj, pt, tpt, sx = Sign[X - 1\/2], n = Length[S], 
            rn}, \n\t\trn = Range[2, n]; \t\n\t\tpt = 
            1 - X + sx \((p /@ S)\); 
          tpt = Times @@ pt; \n\t\tTogether[
            tpt*\((1 + \((\(Moment[c, #, Centred \[Rule] True] &\) /@ 
                        rn)\) . \((\(ProductSum[\((sx*Map[\[Delta]p, S])\)/
                              pt, #] &\) /@ rn)\))\)]];\)\)], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(\(FullGenotypeFrequencyReduced[{X : {__Integer}, 
            Y : {__Integer}}, {cw_, cb_}, \[Delta]p_, p_, S_List] := 
        Module[{j1, j2, ptx, pty, \[Delta]ptx, \[Delta]pty, 
            sx = Sign[X - 1/2], sy = Sign[Y - 1/2], n = Length[S], rn, rn1, 
            mv, a, b, c}, \n\trn = Range[2, n]; 
          rn1 = Range[n]; \n\t\tmv = \(Moment[cw, #, Centred -> True] &\) /@ 
              rn; \n\t\tptx = 1 - X + sx*Map[p, S]; \t
          pty = 1 - Y + 
              sy*Map[p[\(#\^*\)] &, 
                  S]; \n\t\[Delta]ptx = \(Map[\[Delta]p, S]\ sx\)\/ptx; \
\[Delta]pty = \(Map[\[Delta]p[\(#\^*\)] &, S]\ sy\)\/pty; \n\ \ \ \ \ a = 
            mv . \((\(ProductSum[\[Delta]ptx, #] &\) /@ rn)\); \n\t\tb = 
            mv . \((\(ProductSum[\[Delta]pty, #] &\) /@ rn)\); \n\t\ \ \ c = 
            Flatten[Outer[\ MomentReduced[{cw, cb}, {#1, #2}] &, rn1, 
                  rn1]] . \n\t\t\t\t\t\tFlatten[
                Outer[ProductSum[\[Delta]ptx, \[Delta]pty, #1, #2] &, rn1, 
                  rn1]]; \n\t\ \ Together[\((Times @@ ptx)\) \((Times @@ 
                  pty)\) \((1 + a + b + c)\)]];\)\)], "Input",
  InitializationCell->True],

Cell["\<\
For obscure reasons, more direct ways of coding the above gave \
syntax errors\
\>", "Text"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    \(TextForm
    \`MomentReduced[U, {cw, cb}, \[Delta]p]\ returns\ moments\ in\ terms\ of\ 
        the\ within - \ and\ between - 
      genome\ associations\ of\ order\ n . \ \ For\ example, \ \ 
    MomentReduced[{i, j, k}, {cw, cb}, \[Delta]p]\ gives\ cw[3] \[Delta]p[i] 
      \[Delta]p[j] \[Delta]p[k]; \ 
    MomentReduced[{i, j, \(k*\)}, {cw, cb}, \[Delta]p]\ gives\ cb[3] 
        \[Delta]p[i] \[Delta]p[j] 
        \[Delta]p[k] . \ \ MomentReduced[{kw, kb}, {jU, jV}]\ returns\ an\ 
        expression\ for\ the\ moment\ c[U, \(V*\)]\ in\ terms\ of\ the\ 
        cumulants\ within - \ and\ between - genomes\ kw, \ 
    kb . \ For\ example, \ 
    MomentReduced[{kw, kb}, {2, 2}]\ is\ 2  kb[2\(]\^2\) + kb[4] + 
      kw[2\(]\^2\) . \ \ Stores\ 
        results . \ \ \(MomentReduced[n]\)[{\(cw[2] .. \) cb[2] .. }]\ is\ a\ 
        compiled\ version\ that\ returns\ the\ matrix\ of\ \(moments . \)\)], 
  "Subsubsection"],

Cell[BoxData[
    \(\(MomentReduced[{kw_, kb_}, {jU_, 
            jV_}]\  := \(MomentReduced[{kw, kb}, {jU, 
              jV}]\  = \n\t\tModule[{k, u, v, V, x, y}, 
            Moment[k, {Array[u &, jU], Array[v &, jV]} /. Combine, 
                Centred -> 
                  True] /. {k[
                    U_List] :> \((V = 
                      U /. Separate; \(k @@ Sort[Map[Length, V]] /. 
                        k[0, x_] :> kw[x]\) /. 
                      k[x_, y_] :> kb[x + y])\)}]\);\)\)], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(\(MomentReduced[n_Integer] := \(MomentReduced[n] = 
          Module[{cw, cb, 
              cl}, \n\t\t\tCompile[{{cl, _Real, 
                  1}}, \n\t\t\t\t\((Table[
                      MomentReduced[{cw, cb}, {j1, j2}], {j1, 0, n}, {j2, 0, 
                        n}])\) /. {cw[j_] :> 
                      cl\[LeftDoubleBracket]j - 1\[RightDoubleBracket], 
                    cb[j_] :> 
                      cl\[LeftDoubleBracket]j + n - 2\[RightDoubleBracket]} // 
                Evaluate, \n\t\t\t{{MomentReduced[_, _], _Real}}]]\);\)\)], \
"Input",
  InitializationCell->True],

Cell[BoxData[
    \(\(MomentReduced[U_List, {cw_, cb_}, \[Delta]p_] := \n\t
        Module[{ns = Count[U, \(_\^*\)], n = Length[U]}, 
          Apply[Times, Map[\[Delta]p, U /. \(x_\^*\) :> x]] 
            If[\((n == ns)\) || \((ns == 0)\), cw[n], cb[n]]];\)\)], "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    \(TextForm
    \`CumulantReduced[{cw, cb}, {jU, jV}]\ returns\ an\ expression\ for\ the\ 
      cumulant\ \[Kappa][U, \(V\^*\)]\ in\ terms\ of\ the\ moments . \ For\ 
      example, \ 
    CumulantReduced[{cw, cb}, {2, 2}]\ is\ \  - 2\ cb[2]\^2 + cb[4] - 
      cw[2]\^2 . \ \ Stores\ results\)], "Subsubsection"],

Cell[BoxData[
    \(\(CumulantReduced[{cw_, cb_}, {jU_, 
            jV_}]\  := \(CumulantReduced[{cw, cb}, {jU, 
              jV}]\  = \n\t\tModule[{c, u, v, V, x, y}, 
            Cumulant[c, {Array[u &, jU], Array[v &, jV]} /. Combine, 
                Centred -> 
                  True] /. {c[
                    U_List] :> \((V = 
                      U /. Separate; \(c @@ Sort[Map[Length, V]] /. 
                        c[0, x_] :> cw[x]\) /. 
                      c[x_, y_] :> cb[x + y])\)}]\);\)\)], "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    \(TextForm\`\(\(\ \)\(Moment[\[Kappa], {jU, 
            jV}]\ returns\ an\ expression\ for\ the\ moment\ c[
          U, \(\(V\)\(*\)\)]\ in\ terms\ of\ the\ cumulants\ within - \ 
      and\ between - genomes\ \[Kappa]\_\(j, k\) . \ For\ example, \ 
    Moment[\[Kappa], {2, 2}]\ is\ 2  \[Kappa][1, 1\(]\^2\) + \[Kappa][2, 
        2] + \[Kappa][0, 
            2\(]\^2\) . \ \ Stores\ results . \ \ \(Moment[
              n]\)[{{\[Kappa]\_\(0, 0\), \[Ellipsis]}, \[Ellipsis]}]\ is\ a\ \
compiled\ version\ that\ returns\ the\ matrix\ of\ moments . \ \ Moment[U, 
            c, \[Delta]p]\ returns\ moments\ in\ terms\ of\ the\ matrix\ of\ \
within - \ and\ between - genome\ associations, \ 
    c\_\(j, k\) . \ \ For\ example, \ \ Moment[{i, j, k}, 
        c, \[Delta]p]\ gives\ c[3, 0] \[Delta]p[i] \[Delta]p[j] \[Delta]p[
        k]; \ \(\(Moment[{i, j, \(\(k\)\(*\)\)}, {cw, 
          cb}, \[Delta]p]\)\(\ \)\(gives\)\(\ \)\(c[2, 1]\) \(\[Delta]p[
        i]\) \(\[Delta]p[
        j]\) \(\(\[Delta]p[\(k\^*\)]\)\(.\)\)\(\ \)\)\)\)\)], "Subsubsection"],

Cell[BoxData[
    \(\(Options[Moment] = 
        Union[Append[Options[Moment], Symmetric \[Rule] False]];\)\)], "Input",\

  InitializationCell->True],

Cell[BoxData[
    \(\(Moment[k_, {jU_Integer, jV_Integer}, 
          opts___Rule]\  := \(Moment[k, {jU, jV}, 
            opts]\  = \n\t\t\ \ Module[{u, v, V, m}, \n\t\t\tm = 
              Moment[k, {Array[u &, jU], Array[v &, jV]} /. 
                    Combine] /. {k[U_List] :> \((V = U /. Separate; 
                      k @@ Map[Length, 
                          V])\)}; \n\t\tIf[\(Centred /. {opts}\) /. 
                Options[Moment], \n\t\t\tm = 
                m /. {k[0, 1] \[Rule] 0, 
                    k[1, 0] \[Rule] 0}]; \n\t\tIf[\(Symmetric /. {opts}\) /. 
                Options[Moment], \n\t\t\tm = 
                m /. {k[x_, y_] \[RuleDelayed] 
                      k @@ Sort[{x, y}]}]; \n\t\tm]\);\)\)], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(\(Moment[n_Integer, 
          opts___Rule] := \(Moment[n, 
            opts] = \n\t\tModule[{k, cl, cc}, \n\t\t\tOff[Part::partd]; 
            cc = Compile[{{cl, _Real, 
                    2}}, \n\t\t\t\t\((Table[
                        Moment[k, {j1, j2}, opts], {j1, 0, n}, {j2, 0, 
                          n}])\) /. {k[j_, l_] :> 
                        cl\[LeftDoubleBracket]j + 1, 
                          l + 1\[RightDoubleBracket]} // 
                  Evaluate, \n\t\t\t{{Moment[_, __], _Real}}]; \n\t\t\tOn[
              Part::partd]; cc]\);\)\)], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(\(Moment[U_List, c_, \[Delta]p_] := \n\t
        Module[{ns = Count[U, \(_\^*\)], n = Length[U], m}, \n\t\tm = 
            Apply[Times, Map[\[Delta]p, U]] c[n - ns, ns]; \n\t
          If[\(Centred /. {opts}\) /. Options[Moment], \n\t\t\tm = 
              m /. {c[0, 1] \[Rule] 0, 
                  c[1, 0] \[Rule] 0}]; \n\t\tIf[\(Symmetric /. {opts}\) /. 
              Options[Moment], \n\t\t\tm = 
              m /. {c[x_, y_] \[RuleDelayed] 
                    c @@ Sort[{x, y}]}]; \n\t\tm];\)\)], "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    \(TextForm
    \`Cumulant[c, {jU, jV}]\ returns\ an\ expression\ for\ the\ cumulant\ 
        \[Kappa][U, \(V*\)]\ in\ terms\ of\ the\ within - \ and\ between - 
      genome\ moments . \ \ \ For\ example, \ 
    Cumulant[c, {2, 2}]\ is\  - 2  c[1, 1\(]\^2\) + c[2, 2] - 
      cw[0, 2\(]\^2\) . \ \ Stores\ 
        results . \ \ 
          \(Cumulant[n]\)[{{c\_\(0, 0\), \[Ellipsis]}, \[Ellipsis]}]\ is\ a\ 
        compiled\ version\ that\ returns\ the\ matrix\ of\ 
        cumulants . \ \ Cumulant[U, \[Kappa], \[Delta]p]\ returns\ cumulants\ 
        in\ terms\ of\ the\ matrix\ of\ within - \ and\ between - 
      genome\ associations, \ \[Kappa]\_\(j, k\) . \ \ For\ example, \ \ 
    Cumulant[{i, j, k}, \[Kappa], \[Delta]p]\ gives\ \[Kappa][3, 0] 
      \[Delta]p[i] \[Delta]p[j] \[Delta]p[k]; \ 
    Cumulant[{i, j, \(k*\)}, \[Kappa], \[Delta]p]\ gives\ \[Kappa][2, 1] 
      \[Delta]p[i] \[Delta]p[j] \(\[Delta]p[\(k\^*\)] . \)\)], "Subsubsection"],

Cell[BoxData[
    \(\(Options[Cumulant] = 
        Union[Append[Options[Cumulant], 
            Symmetric \[Rule] False]];\)\)], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(\(Cumulant[c_, {jU_Integer, jV_Integer}, 
          opts___Rule]\  := \(Cumulant[c, {jU, jV}, 
            opts]\  = \n\t\t\ \ Module[{u, v, V, m}, \n\t\t\tm = 
              Cumulant[
                  c, {Array[u &, jU], Array[v &, jV]} /. 
                    Combine] /. {c[U_List] :> \((V = U /. Separate; 
                      c @@ Map[Length, 
                          V])\)}; \n\t\tIf[\(Centred /. {opts}\) /. 
                Options[Cumulant], \n\t\t\tm = 
                m /. {c[0, 1] \[Rule] 0, 
                    c[1, 0] \[Rule] 0}]; \n\t\tIf[\(Symmetric /. {opts}\) /. 
                Options[Cumulant], \n\t\t\tm = 
                m /. {c[x_, y_] \[RuleDelayed] 
                      c @@ Sort[{x, y}]}]; \n\t\tm]\);\)\)], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(\(Cumulant[n_Integer, 
          opts___Rule] := \(Cumulant[n, 
            opts] = \n\t\tModule[{c, cl, cc}, \n\t\t\tOff[
              Part::partd]; \n\t\t\tcc = 
              Compile[{{cl, _Real, 
                    2}}, \n\t\t\t\t\((Table[
                        Cumulant[c, {j1, j2}, opts], {j1, 0, n}, {j2, 0, 
                          n}])\) /. {c[j_, l_] :> 
                        cl\[LeftDoubleBracket]j + 1, 
                          l + 1\[RightDoubleBracket]} // 
                  Evaluate, \n\t\t\t{{Cumulant[_, __], _Real}}]; \n\t\t\tOn[
              Part::partd]; cc]\);\)\)], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(\(Cumulant[U_List, k_, \[Delta]p_, opts___Rule] := \n\t
        Module[{ns = Count[U, \(_\^*\)], n = Length[U], 
            m}, \n\t\tm = \((Times @@ \((\[Delta]p /@ U)\))\) 
              k[n - ns, ns]; \n\t
          If[\(Centred /. {opts}\) /. Options[Cumulant], \n\t\t\tm = 
              m /. {k[0, 1] \[Rule] 0, 
                  k[1, 0] \[Rule] 0}]; \n\t\tIf[\(Symmetric /. {opts}\) /. 
              Options[Cumulant], \n\t\t\tm = 
              m /. {c[x_, y_] \[RuleDelayed] 
                    c @@ Sort[{x, y}]}]; \n\t\tm];\)\)], "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{

Cell["Checking FullGenotypeFrequencyReduced", "Subsubsection"],

Cell[CellGroupData[{

Cell[BoxData[
    \(gt = gameteTypes[2]; \n
    Sum[FullGenotypeFrequencyReduced[{gt[\([k]\)], gt[\([l]\)]}, {cw, cb}, 
        \[Delta]p, p, {i, j}], {k, 4}, {l, 4}]\)], "Input"],

Cell[BoxData[
    \(1\)], "Output"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    \(Sum[
        \((\(gt[\([l]\)]\)[\([1]\)] - p[i])\) 
          FullGenotypeFrequencyReduced[{gt[\([k]\)], gt[\([l]\)]}, {cw, cb}, 
            \[Delta]p, p, {i, j}], {k, 4}, {l, 4}] // Expand\)], "Input"],

Cell[BoxData[
    \(0\)], "Output"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    \(Sum[
        \((\(gt[\([k]\)]\)[\([1]\)] - p[i])\) 
          \((\(gt[\([l]\)]\)[\([1]\)] - p[i])\) 
          FullGenotypeFrequencyReduced[{gt[\([k]\)], gt[\([l]\)]}, {cw, cb}, 
            \[Delta]p, p, {i, j}], {k, 4}, {l, 4}] // Expand\)], "Input"],

Cell[BoxData[
    \(cb[2]\ \[Delta]p[i]\^2\)], "Output"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    \(Sum[
        \((\(gt[\([k]\)]\)[\([1]\)] - p[i])\) 
          \((\(gt[\([l]\)]\)[\([2]\)] - p[j])\) 
          FullGenotypeFrequencyReduced[{gt[\([k]\)], gt[\([l]\)]}, {cw, cb}, 
            \[Delta]p, p, {i, j}], {k, 4}, {l, 4}] // Expand\)], "Input"],

Cell[BoxData[
    \(cb[2]\ \[Delta]p[i]\ \[Delta]p[j]\)], "Output"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    \(Sum[
        \((\(gt[\([k]\)]\)[\([1]\)] - p[i])\) 
          \((\(gt[\([k]\)]\)[\([2]\)] - p[j])\) 
          FullGenotypeFrequencyReduced[{gt[\([k]\)], gt[\([l]\)]}, {cw, cb}, 
            \[Delta]p, p, {i, j}], {k, 4}, {l, 4}] // Expand\)], "Input"],

Cell[BoxData[
    \(cw[2]\ \[Delta]p[i]\ \[Delta]p[j]\)], "Output"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    \(Sum[
        \((\(gt[\([k]\)]\)[\([1]\)] - p[i])\) 
          \((\(gt[\([k]\)]\)[\([2]\)] - p[j])\) 
          \((\(gt[\([l]\)]\)[\([2]\)] - p[j])\) 
          FullGenotypeFrequencyReduced[{gt[\([k]\)], gt[\([l]\)]}, {cw, cb}, 
            \[Delta]p, p, {i, j}], {k, 4}, {l, 4}] // Expand\)], "Input"],

Cell[BoxData[
    \(cb[3]\ \[Delta]p[i]\ \[Delta]p[j]\^2\)], "Output"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    \(Sum[
        \((\(gt[\([k]\)]\)[\([1]\)] - p[i])\) 
          \((\(gt[\([k]\)]\)[\([2]\)] - p[j])\) 
          \((\(gt[\([l]\)]\)[\([1]\)] - p[i])\) 
          \((\(gt[\([l]\)]\)[\([2]\)] - p[j])\) 
          FullGenotypeFrequencyReduced[{gt[\([k]\)], gt[\([l]\)]}, {cw, cb}, 
            \[Delta]p, p, {i, j}], {k, 4}, {l, 4}] // Expand\)], "Input"],

Cell[BoxData[
    \(cb[4]\ \[Delta]p[i]\^2\ \[Delta]p[j]\^2 + 
      cw[2]\^2\ \[Delta]p[i]\^2\ \[Delta]p[j]\^2\)], "Output"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    \(TextForm
    \`FullGenotypeFrequencyTable[{{0, 1, 0}, {1, 0, 1}}, {k\_w, \ k\_b}, 
          \[Delta]p, p, {i, j, k}]\ gives\ the\ diploid\ genotype\ frequency\ 
        in\ terms\ of\ cumulants\ k\_w[2] .. , \ 
    \(k\_b[2] .. \)\ \ Fast\ method\ which\ works\ by\ storing\ the\ general\ 
      expression\ for\ {{1, 1, 1}, {1, 1, 1}}\ in\ terms\ of\ $p, 
    \ $\[Delta]p, \ 
    and\ then\ permuting\ 
      it . \ FullGenotypeFrequencyTable[, {k\_w, \ k\_b}, {i, j, k}]\ stores\ 
      the\ generic\ solution, \ 
    and\ FullGenotypeFrequencyTable[nloci]\ the\ compiled\ version; \ 
    this\ is\ called\ as\ 
      \(FullGenotypeFrequencyTable[nl]\)[p1,  ... , \(p1*\) ... , 
        \[Delta]p1,  .. , \(\[Delta]p1*\) .. , cw2 ... , cb2 ... ], \ 
    with\ 7  nl - 
        2\ arguments . \ \ 
            FullGenotypeFrequencyTable[nloci, Symmetric \[Rule] True]\ assumes
          \ p = \(p*\ and\ \[Delta]p = 
        1\  . \ \ 
            FullGenotypeFrequencyTable[{{0, 1, 0}, {1, 0, 1}}, {k\_w, \ 
                k\_b}, \[Delta]p, p]\ calls\ the\ compiled\ version\ 
          FullGenotypeFrequencyTable[3] . \ 
            FullGenotypeFrequencyTable[{{0, 1, 0}, {1, 0, 1}}]\ is\ itself\ 
          compiled\); \ assumes\ \[Delta]p = 1, \ and\ takes\ arguments\ p, 
    q, , k\_w, \ 
    k\_b . \ \ FullGenotypeFrequencyTable[nloci, 1&]\ takes\ 
      arguments\ [{p1,  .. }, {\[Delta]p1 .. }, {c .. }]\ but\ is\ 
      slower . \ FullGenotypeFrequencyTable[nloci, Integer \[Rule] True]\ is\ 
      \(fastest : \ assumes\ \[Delta]p\ \(integer . \)\)\)], "Subsubsection"],

Cell[BoxData[
    \(\(FullGenotypeFrequencyTable[{cw_, cb_}, 
          S_List] := \(FullGenotypeFrequencyTable[{cw, cb}, 
            S] = \n\t\tModule[{ones = Array[1 &, Length[S]]}, 
            FullGenotypeFrequencyReduced[{ones, ones}, {cw, 
                cb}, $\[Delta]p, $p, S]]\);\)\)], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(\(FullGenotypeFrequencyTable[{X_List, Y_List}, {cw_, cb_}, \[Delta]p_, 
          p_, S_List] := 
        Module[{rpx, rpy, r\[Delta]px, r\[Delta]py, 
            n = Length[S], $i}, \n\t\trpx = 
            Table[$p[S\[LeftDoubleBracket]$i\[RightDoubleBracket]] -> 
                If[X\[LeftDoubleBracket]$i\[RightDoubleBracket] == 1, 
                  p[S\[LeftDoubleBracket]$i\[RightDoubleBracket]], 
                  1 - p[S\[LeftDoubleBracket]$i\[RightDoubleBracket]]], {$i, 
                n}]; \n\t\trpy = 
            Table[$p[\(S\[LeftDoubleBracket]$i\[RightDoubleBracket]\^*\)] -> 
                If[Y\[LeftDoubleBracket]$i\[RightDoubleBracket] == 1, 
                  p[S\[LeftDoubleBracket]$i\[RightDoubleBracket]], 
                  1 - p[S\[LeftDoubleBracket]$i\[RightDoubleBracket]]], {$i, 
                n}]; \n\t\tr\[Delta]px = 
            Table[$\[Delta]p[S\[LeftDoubleBracket]$i\[RightDoubleBracket]] -> 
                If[X\[LeftDoubleBracket]$i\[RightDoubleBracket] == 
                    1, \[Delta]p[
                    S\[LeftDoubleBracket]$i\[RightDoubleBracket]], \
\(-\[Delta]p[S\[LeftDoubleBracket]$i\[RightDoubleBracket]]\)], {$i, 
                n}]; \n\t\tr\[Delta]py = 
            Table[$\[Delta]p[\(S\[LeftDoubleBracket]$i\[RightDoubleBracket]\^*\
\)] -> If[Y\[LeftDoubleBracket]$i\[RightDoubleBracket] == 1, \[Delta]p[
                    S\[LeftDoubleBracket]$i\[RightDoubleBracket]], \
\(-\[Delta]p[S\[LeftDoubleBracket]$i\[RightDoubleBracket]]\)], {$i, 
                n}]; \n\t\tFullGenotypeFrequencyTable[{cw, cb}, S] /. 
            Join[rpx, rpy, r\[Delta]px, r\[Delta]py]];\)\)], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(\(FullGenotypeFrequencyTable[
          nl_Integer] := \(FullGenotypeFrequencyTable[nl] = 
          Module[{S = Range[nl], j, vars, gtx, tv, p, \[Delta]p, 
              p2, \[Delta]p2}, \n\ \ vars = 
              Join[Table[cw[j], {j, 2, nl}], Table[cb[j], {j, 2, 2  nl}]]; \n
            rl[xx_List] := \(({vars, Flatten[xx]} // Transpose)\) /. {x_, 
                    y_} :> \((x -> y)\); 
            gtx = \(FullGenotypeFrequencyTable[{cw, cb}, 
                    S] /. {$\[Delta]p[\(x_\^*\)] :> \(StandardSet[
                          nl, \[Delta]p2]\)\[LeftDoubleBracket]
                        x\[RightDoubleBracket], $\[Delta]p[
                        x_] :> \(StandardSet[
                          nl, \[Delta]p]\)\[LeftDoubleBracket]
                        x\[RightDoubleBracket], $p[\(x_\^*\)] :> \
\(StandardSet[nl, p2]\)\[LeftDoubleBracket]x\[RightDoubleBracket], $p[
                        x_] :> \(StandardSet[nl, p]\)\[LeftDoubleBracket]
                        x\[RightDoubleBracket]}\) /. 
                rl[StandardSet[nl]]; \n\t\ttv = 
              Transpose[{{StandardSet[nl, p], StandardSet[nl, p2], 
                      StandardSet[nl, \[Delta]p], 
                      StandardSet[nl, \[Delta]p2], StandardSet[nl]} // 
                    Flatten, Table[_Real, {7  nl - 2}]}]; \n\t\tCompile[
              tv // Evaluate, gtx // Evaluate]]\);\)\)], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(\(FullGenotypeFrequencyTable[nl_Integer, 
          Integer \[Rule] True] := \(FullGenotypeFrequencyTable[nl, 
            Integer \[Rule] True] = 
          Module[{j, vars, gtx, tv, p, \[Delta]p, 
              p2, \[Delta]p2}, \n\ \ vars = 
              Join[Table[cw[j], {j, 2, nl}], Table[cb[j], {j, 2, 2  nl}]]; \n
            rl[xx_List] := \(({vars, Flatten[xx]} // Transpose)\) /. {x_, 
                    y_} :> \((x -> y)\); 
            gtx = \(FullGenotypeFrequencyTable[{cw, cb}, 
                    Range[nl]] /. {$\[Delta]p[\(x_\^*\)] :> \(StandardSet[
                          nl, \[Delta]p2]\)\[LeftDoubleBracket]
                        x\[RightDoubleBracket], $\[Delta]p[
                        x_] :> \(StandardSet[
                          nl, \[Delta]p]\)\[LeftDoubleBracket]
                        x\[RightDoubleBracket], $p[\(x_\^*\)] :> \
\(StandardSet[nl, p2]\)\[LeftDoubleBracket]x\[RightDoubleBracket], $p[
                        x_] :> \(StandardSet[nl, p]\)\[LeftDoubleBracket]
                        x\[RightDoubleBracket]}\) /. 
                rl[StandardSet[nl]]; \n\t\ttv = 
              Transpose[{{StandardSet[nl, p], StandardSet[nl, p2], 
                      StandardSet[nl, \[Delta]p], 
                      StandardSet[nl, \[Delta]p2], StandardSet[nl]} // 
                    Flatten, 
                  Join[Table[_Real, {2  nl}], Table[_Integer, {2  nl}], 
                    Table[_Real, {3  nl - 2}]]}]; \n\t\tCompile[
              tv // Evaluate, gtx // Evaluate]]\);\)\)], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(\(FullGenotypeFrequencyTable[{X_List, Y_List}, cl_, \[Delta]p_, 
          p_] := \n\t
        Module[{nl = Length[X], S}, \n\t\tS = 
            Range[nl]; \n\t\tFullGenotypeFrequencyTable[nl] @@ 
            Flatten[{\((\((1 - 
                        X)\) + \((2  X - 1)\) \((p /@ S)\))\), \((\((1 - 
                        Y)\) + \((2  Y - 1)\) \((p /@ S)\))\), \((2  X - 
                      1)\) \((\[Delta]p /@ S)\), \((2  Y - 1)\) \((\[Delta]p /@ 
                      S)\), cl}]];\)\)], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(\(FullGenotypeFrequencyTable[{X_List, 
            Y_List}] := \(FullGenotypeFrequencyTable[{X, Y}] = \n\t
          Module[{nl = Length[X], pl, cl, pp1, pp2, gtx, rl, vars, 
              j}, \n\t\t\ \ pp1 = \((\((1 - X)\) ql + 
                  X\ pl)\); \n\t\t\tpp2 = \((\((1 - Y)\) ql + 
                  Y\ pl)\); \n\t\t\tvars = 
              Join[Table[cw[j], {j, 2, nl}], Table[cb[j], {j, 2, 2  nl}]]; \n
            rl[xx_List] := \(({vars, Flatten[xx]} // Transpose)\) /. {x_, 
                    y_} :> \((x -> y)\); 
            gtx = \((\(FullGenotypeFrequencyTable[{cw, cb}, 
                      Range[nl]] /. {$\[Delta]p[\(x_\^*\)] :> 
                        1, $\[Delta]p[x_] :> 1, $p[\(x_\^*\)] :> 
                        pp2\[LeftDoubleBracket]x\[RightDoubleBracket], $p[
                          x_] :> pp1\[LeftDoubleBracket]
                          x\[RightDoubleBracket]}\) /. 
                  rl[StandardSet[nl]])\); \n\t
            Compile[{{pl, _Real, 1}, {ql, _Real, 1}, {cl, _Real, 1}}, 
              gtx // Evaluate]]\);\)\)], "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{

Cell["Setting up FullGenotypeFrequencyTable[nloci,compiled]", "Subsubsection"],

Cell[CellGroupData[{

Cell[BoxData[
    \(gt2 = 
      FullGenotypeFrequencyTable[{cw, cb}, 
          Range[2]] /. {$\[Delta]p[\(x_\^*\)] :> $\[Delta]p2
              \[LeftDoubleBracket]x\[RightDoubleBracket], $\[Delta]p[
              x_] :> $\[Delta]p1\[LeftDoubleBracket]x
              \[RightDoubleBracket], $p[\(x_\^*\)] :> $p2\[LeftDoubleBracket]x
              \[RightDoubleBracket], $p[x_] :> $p1\[LeftDoubleBracket]x
              \[RightDoubleBracket], 
          cw[j_] :> $cl\[LeftDoubleBracket]j - 1\[RightDoubleBracket], 
          cb[j_] :> $cl\[LeftDoubleBracket]j\[RightDoubleBracket]}\)], "Input"],

Cell[BoxData[
    \($p1\[LeftDoubleBracket]1\[RightDoubleBracket]\ $p1\[LeftDoubleBracket]2
          \[RightDoubleBracket]\ $p2\[LeftDoubleBracket]1
          \[RightDoubleBracket]\ $p2\[LeftDoubleBracket]2
          \[RightDoubleBracket] + $cl\[LeftDoubleBracket]1
          \[RightDoubleBracket]\ $p2\[LeftDoubleBracket]1
          \[RightDoubleBracket]\ $p2\[LeftDoubleBracket]2
          \[RightDoubleBracket]\ $\[Delta]p1\[LeftDoubleBracket]1
          \[RightDoubleBracket]\ $\[Delta]p1\[LeftDoubleBracket]2
          \[RightDoubleBracket] + $cl\[LeftDoubleBracket]2
          \[RightDoubleBracket]\ $p1\[LeftDoubleBracket]2
          \[RightDoubleBracket]\ $p2\[LeftDoubleBracket]2
          \[RightDoubleBracket]\ $\[Delta]p1\[LeftDoubleBracket]1
          \[RightDoubleBracket]\ $\[Delta]p2\[LeftDoubleBracket]1
          \[RightDoubleBracket] + $cl\[LeftDoubleBracket]2
          \[RightDoubleBracket]\ $p1\[LeftDoubleBracket]1
          \[RightDoubleBracket]\ $p2\[LeftDoubleBracket]2
          \[RightDoubleBracket]\ $\[Delta]p1\[LeftDoubleBracket]2
          \[RightDoubleBracket]\ $\[Delta]p2\[LeftDoubleBracket]1
          \[RightDoubleBracket] + $cl\[LeftDoubleBracket]3
          \[RightDoubleBracket]\ $p2\[LeftDoubleBracket]2
          \[RightDoubleBracket]\ $\[Delta]p1\[LeftDoubleBracket]1
          \[RightDoubleBracket]\ $\[Delta]p1\[LeftDoubleBracket]2
          \[RightDoubleBracket]\ $\[Delta]p2\[LeftDoubleBracket]1
          \[RightDoubleBracket] + $cl\[LeftDoubleBracket]2
          \[RightDoubleBracket]\ $p1\[LeftDoubleBracket]2
          \[RightDoubleBracket]\ $p2\[LeftDoubleBracket]1
          \[RightDoubleBracket]\ $\[Delta]p1\[LeftDoubleBracket]1
          \[RightDoubleBracket]\ $\[Delta]p2\[LeftDoubleBracket]2
          \[RightDoubleBracket] + $cl\[LeftDoubleBracket]2
          \[RightDoubleBracket]\ $p1\[LeftDoubleBracket]1
          \[RightDoubleBracket]\ $p2\[LeftDoubleBracket]1
          \[RightDoubleBracket]\ $\[Delta]p1\[LeftDoubleBracket]2
          \[RightDoubleBracket]\ $\[Delta]p2\[LeftDoubleBracket]2
          \[RightDoubleBracket] + $cl\[LeftDoubleBracket]3
          \[RightDoubleBracket]\ $p2\[LeftDoubleBracket]1
          \[RightDoubleBracket]\ $\[Delta]p1\[LeftDoubleBracket]1
          \[RightDoubleBracket]\ $\[Delta]p1\[LeftDoubleBracket]2
          \[RightDoubleBracket]\ $\[Delta]p2\[LeftDoubleBracket]2
          \[RightDoubleBracket] + $cl\[LeftDoubleBracket]1
          \[RightDoubleBracket]\ $p1\[LeftDoubleBracket]1
          \[RightDoubleBracket]\ $p1\[LeftDoubleBracket]2
          \[RightDoubleBracket]\ $\[Delta]p2\[LeftDoubleBracket]1
          \[RightDoubleBracket]\ $\[Delta]p2\[LeftDoubleBracket]2
          \[RightDoubleBracket] + $cl\[LeftDoubleBracket]3
          \[RightDoubleBracket]\ $p1\[LeftDoubleBracket]2
          \[RightDoubleBracket]\ $\[Delta]p1\[LeftDoubleBracket]1
          \[RightDoubleBracket]\ $\[Delta]p2\[LeftDoubleBracket]1
          \[RightDoubleBracket]\ $\[Delta]p2\[LeftDoubleBracket]2
          \[RightDoubleBracket] + $cl\[LeftDoubleBracket]3
          \[RightDoubleBracket]\ $p1\[LeftDoubleBracket]1
          \[RightDoubleBracket]\ $\[Delta]p1\[LeftDoubleBracket]2
          \[RightDoubleBracket]\ $\[Delta]p2\[LeftDoubleBracket]1
          \[RightDoubleBracket]\ $\[Delta]p2\[LeftDoubleBracket]2
          \[RightDoubleBracket] + $cl\[LeftDoubleBracket]1
            \[RightDoubleBracket]\^2\ $\[Delta]p1\[LeftDoubleBracket]1
          \[RightDoubleBracket]\ $\[Delta]p1\[LeftDoubleBracket]2
          \[RightDoubleBracket]\ $\[Delta]p2\[LeftDoubleBracket]1
          \[RightDoubleBracket]\ $\[Delta]p2\[LeftDoubleBracket]2
          \[RightDoubleBracket] + 
      2\ $cl\[LeftDoubleBracket]2\[RightDoubleBracket]\^2\ $\[Delta]p1
          \[LeftDoubleBracket]1\[RightDoubleBracket]\ $\[Delta]p1
          \[LeftDoubleBracket]2\[RightDoubleBracket]\ $\[Delta]p2
          \[LeftDoubleBracket]1\[RightDoubleBracket]\ $\[Delta]p2
          \[LeftDoubleBracket]2\[RightDoubleBracket] + $cl
          \[LeftDoubleBracket]4\[RightDoubleBracket]\ $\[Delta]p1
          \[LeftDoubleBracket]1\[RightDoubleBracket]\ $\[Delta]p1
          \[LeftDoubleBracket]2\[RightDoubleBracket]\ $\[Delta]p2
          \[LeftDoubleBracket]1\[RightDoubleBracket]\ $\[Delta]p2
          \[LeftDoubleBracket]2\[RightDoubleBracket]\)], "Output"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    \(gt3 = 
      FullGenotypeFrequencyTable[{cw, cb}, 
          Range[3]] /. {$\[Delta]p[\(x_\^*\)] :> $\[Delta]p2
              \[LeftDoubleBracket]x\[RightDoubleBracket], $\[Delta]p[
              x_] :> $\[Delta]p1\[LeftDoubleBracket]x
              \[RightDoubleBracket], $p[\(x_\^*\)] :> $p2\[LeftDoubleBracket]x
              \[RightDoubleBracket], $p[x_] :> $p1\[LeftDoubleBracket]x
              \[RightDoubleBracket], 
          cw[j_] :> $cl\[LeftDoubleBracket]j - 1\[RightDoubleBracket], 
          cb[j_] :> $cl\[LeftDoubleBracket]j\[RightDoubleBracket]}\)], "Input"],

Cell[BoxData[
    \($p1\[LeftDoubleBracket]1\[RightDoubleBracket]\ $p1\[LeftDoubleBracket]2
          \[RightDoubleBracket]\ $p1\[LeftDoubleBracket]3
          \[RightDoubleBracket]\ $p2\[LeftDoubleBracket]1
          \[RightDoubleBracket]\ $p2\[LeftDoubleBracket]2
          \[RightDoubleBracket]\ $p2\[LeftDoubleBracket]3
          \[RightDoubleBracket] + $cl\[LeftDoubleBracket]1
          \[RightDoubleBracket]\ $p1\[LeftDoubleBracket]3
          \[RightDoubleBracket]\ $p2\[LeftDoubleBracket]1
          \[RightDoubleBracket]\ $p2\[LeftDoubleBracket]2
          \[RightDoubleBracket]\ $p2\[LeftDoubleBracket]3
          \[RightDoubleBracket]\ $\[Delta]p1\[LeftDoubleBracket]1
          \[RightDoubleBracket]\ $\[Delta]p1\[LeftDoubleBracket]2
          \[RightDoubleBracket] + $cl\[LeftDoubleBracket]1
          \[RightDoubleBracket]\ $p1\[LeftDoubleBracket]2
          \[RightDoubleBracket]\ $p2\[LeftDoubleBracket]1
          \[RightDoubleBracket]\ $p2\[LeftDoubleBracket]2
          \[RightDoubleBracket]\ $p2\[LeftDoubleBracket]3
          \[RightDoubleBracket]\ $\[Delta]p1\[LeftDoubleBracket]1
          \[RightDoubleBracket]\ $\[Delta]p1\[LeftDoubleBracket]3
          \[RightDoubleBracket] + $cl\[LeftDoubleBracket]1
          \[RightDoubleBracket]\ $p1\[LeftDoubleBracket]1
          \[RightDoubleBracket]\ $p2\[LeftDoubleBracket]1
          \[RightDoubleBracket]\ $p2\[LeftDoubleBracket]2
          \[RightDoubleBracket]\ $p2\[LeftDoubleBracket]3
          \[RightDoubleBracket]\ $\[Delta]p1\[LeftDoubleBracket]2
          \[RightDoubleBracket]\ $\[Delta]p1\[LeftDoubleBracket]3
          \[RightDoubleBracket] + $cl\[LeftDoubleBracket]2
          \[RightDoubleBracket]\ $p2\[LeftDoubleBracket]1
          \[RightDoubleBracket]\ $p2\[LeftDoubleBracket]2
          \[RightDoubleBracket]\ $p2\[LeftDoubleBracket]3
          \[RightDoubleBracket]\ $\[Delta]p1\[LeftDoubleBracket]1
          \[RightDoubleBracket]\ $\[Delta]p1\[LeftDoubleBracket]2
          \[RightDoubleBracket]\ $\[Delta]p1\[LeftDoubleBracket]3
          \[RightDoubleBracket] + $cl\[LeftDoubleBracket]2
          \[RightDoubleBracket]\ $p1\[LeftDoubleBracket]2
          \[RightDoubleBracket]\ $p1\[LeftDoubleBracket]3
          \[RightDoubleBracket]\ $p2\[LeftDoubleBracket]2
          \[RightDoubleBracket]\ $p2\[LeftDoubleBracket]3
          \[RightDoubleBracket]\ $\[Delta]p1\[LeftDoubleBracket]1
          \[RightDoubleBracket]\ $\[Delta]p2\[LeftDoubleBracket]1
          \[RightDoubleBracket] + $cl\[LeftDoubleBracket]2
          \[RightDoubleBracket]\ $p1\[LeftDoubleBracket]1
          \[RightDoubleBracket]\ $p1\[LeftDoubleBracket]3
          \[RightDoubleBracket]\ $p2\[LeftDoubleBracket]2
          \[RightDoubleBracket]\ $p2\[LeftDoubleBracket]3
          \[RightDoubleBracket]\ $\[Delta]p1\[LeftDoubleBracket]2
          \[RightDoubleBracket]\ $\[Delta]p2\[LeftDoubleBracket]1
          \[RightDoubleBracket] + $cl\[LeftDoubleBracket]3
          \[RightDoubleBracket]\ $p1\[LeftDoubleBracket]3
          \[RightDoubleBracket]\ $p2\[LeftDoubleBracket]2
          \[RightDoubleBracket]\ $p2\[LeftDoubleBracket]3
          \[RightDoubleBracket]\ $\[Delta]p1\[LeftDoubleBracket]1
          \[RightDoubleBracket]\ $\[Delta]p1\[LeftDoubleBracket]2
          \[RightDoubleBracket]\ $\[Delta]p2\[LeftDoubleBracket]1
          \[RightDoubleBracket] + $cl\[LeftDoubleBracket]2
          \[RightDoubleBracket]\ $p1\[LeftDoubleBracket]1
          \[RightDoubleBracket]\ $p1\[LeftDoubleBracket]2
          \[RightDoubleBracket]\ $p2\[LeftDoubleBracket]2
          \[RightDoubleBracket]\ $p2\[LeftDoubleBracket]3
          \[RightDoubleBracket]\ $\[Delta]p1\[LeftDoubleBracket]3
          \[RightDoubleBracket]\ $\[Delta]p2\[LeftDoubleBracket]1
          \[RightDoubleBracket] + $cl\[LeftDoubleBracket]3
          \[RightDoubleBracket]\ $p1\[LeftDoubleBracket]2
          \[RightDoubleBracket]\ $p2\[LeftDoubleBracket]2
          \[RightDoubleBracket]\ $p2\[LeftDoubleBracket]3
          \[RightDoubleBracket]\ $\[Delta]p1\[LeftDoubleBracket]1
          \[RightDoubleBracket]\ $\[Delta]p1\[LeftDoubleBracket]3
          \[RightDoubleBracket]\ $\[Delta]p2\[LeftDoubleBracket]1
          \[RightDoubleBracket] + $cl\[LeftDoubleBracket]3
          \[RightDoubleBracket]\ $p1\[LeftDoubleBracket]1
          \[RightDoubleBracket]\ $p2\[LeftDoubleBracket]2
          \[RightDoubleBracket]\ $p2\[LeftDoubleBracket]3
          \[RightDoubleBracket]\ $\[Delta]p1\[LeftDoubleBracket]2
          \[RightDoubleBracket]\ $\[Delta]p1\[LeftDoubleBracket]3
          \[RightDoubleBracket]\ $\[Delta]p2\[LeftDoubleBracket]1
          \[RightDoubleBracket] + 
      3\ $cl\[LeftDoubleBracket]1\[RightDoubleBracket]\ $cl
          \[LeftDoubleBracket]2\[RightDoubleBracket]\ $p2\[LeftDoubleBracket]2
          \[RightDoubleBracket]\ $p2\[LeftDoubleBracket]3
          \[RightDoubleBracket]\ $\[Delta]p1\[LeftDoubleBracket]1
          \[RightDoubleBracket]\ $\[Delta]p1\[LeftDoubleBracket]2
          \[RightDoubleBracket]\ $\[Delta]p1\[LeftDoubleBracket]3
          \[RightDoubleBracket]\ $\[Delta]p2\[LeftDoubleBracket]1
          \[RightDoubleBracket] + $cl\[LeftDoubleBracket]4
          \[RightDoubleBracket]\ $p2\[LeftDoubleBracket]2
          \[RightDoubleBracket]\ $p2\[LeftDoubleBracket]3
          \[RightDoubleBracket]\ $\[Delta]p1\[LeftDoubleBracket]1
          \[RightDoubleBracket]\ $\[Delta]p1\[LeftDoubleBracket]2
          \[RightDoubleBracket]\ $\[Delta]p1\[LeftDoubleBracket]3
          \[RightDoubleBracket]\ $\[Delta]p2\[LeftDoubleBracket]1
          \[RightDoubleBracket] + $cl\[LeftDoubleBracket]2
          \[RightDoubleBracket]\ $p1\[LeftDoubleBracket]2
          \[RightDoubleBracket]\ $p1\[LeftDoubleBracket]3
          \[RightDoubleBracket]\ $p2\[LeftDoubleBracket]1
          \[RightDoubleBracket]\ $p2\[LeftDoubleBracket]3
          \[RightDoubleBracket]\ $\[Delta]p1\[LeftDoubleBracket]1
          \[RightDoubleBracket]\ $\[Delta]p2\[LeftDoubleBracket]2
          \[RightDoubleBracket] + $cl\[LeftDoubleBracket]2
          \[RightDoubleBracket]\ $p1\[LeftDoubleBracket]1
          \[RightDoubleBracket]\ $p1\[LeftDoubleBracket]3
          \[RightDoubleBracket]\ $p2\[LeftDoubleBracket]1
          \[RightDoubleBracket]\ $p2\[LeftDoubleBracket]3
          \[RightDoubleBracket]\ $\[Delta]p1\[LeftDoubleBracket]2
          \[RightDoubleBracket]\ $\[Delta]p2\[LeftDoubleBracket]2
          \[RightDoubleBracket] + $cl\[LeftDoubleBracket]3
          \[RightDoubleBracket]\ $p1\[LeftDoubleBracket]3
          \[RightDoubleBracket]\ $p2\[LeftDoubleBracket]1
          \[RightDoubleBracket]\ $p2\[LeftDoubleBracket]3
          \[RightDoubleBracket]\ $\[Delta]p1\[LeftDoubleBracket]1
          \[RightDoubleBracket]\ $\[Delta]p1\[LeftDoubleBracket]2
          \[RightDoubleBracket]\ $\[Delta]p2\[LeftDoubleBracket]2
          \[RightDoubleBracket] + $cl\[LeftDoubleBracket]2
          \[RightDoubleBracket]\ $p1\[LeftDoubleBracket]1
          \[RightDoubleBracket]\ $p1\[LeftDoubleBracket]2
          \[RightDoubleBracket]\ $p2\[LeftDoubleBracket]1
          \[RightDoubleBracket]\ $p2\[LeftDoubleBracket]3
          \[RightDoubleBracket]\ $\[Delta]p1\[LeftDoubleBracket]3
          \[RightDoubleBracket]\ $\[Delta]p2\[LeftDoubleBracket]2
          \[RightDoubleBracket] + $cl\[LeftDoubleBracket]3
          \[RightDoubleBracket]\ $p1\[LeftDoubleBracket]2
          \[RightDoubleBracket]\ $p2\[LeftDoubleBracket]1
          \[RightDoubleBracket]\ $p2\[LeftDoubleBracket]3
          \[RightDoubleBracket]\ $\[Delta]p1\[LeftDoubleBracket]1
          \[RightDoubleBracket]\ $\[Delta]p1\[LeftDoubleBracket]3
          \[RightDoubleBracket]\ $\[Delta]p2\[LeftDoubleBracket]2
          \[RightDoubleBracket] + $cl\[LeftDoubleBracket]3
          \[RightDoubleBracket]\ $p1\[LeftDoubleBracket]1
          \[RightDoubleBracket]\ $p2\[LeftDoubleBracket]1
          \[RightDoubleBracket]\ $p2\[LeftDoubleBracket]3
          \[RightDoubleBracket]\ $\[Delta]p1\[LeftDoubleBracket]2
          \[RightDoubleBracket]\ $\[Delta]p1\[LeftDoubleBracket]3
          \[RightDoubleBracket]\ $\[Delta]p2\[LeftDoubleBracket]2
          \[RightDoubleBracket] + 
      3\ $cl\[LeftDoubleBracket]1\[RightDoubleBracket]\ $cl
          \[LeftDoubleBracket]2\[RightDoubleBracket]\ $p2\[LeftDoubleBracket]1
          \[RightDoubleBracket]\ $p2\[LeftDoubleBracket]3
          \[RightDoubleBracket]\ $\[Delta]p1\[LeftDoubleBracket]1
          \[RightDoubleBracket]\ $\[Delta]p1\[LeftDoubleBracket]2
          \[RightDoubleBracket]\ $\[Delta]p1\[LeftDoubleBracket]3
          \[RightDoubleBracket]\ $\[Delta]p2\[LeftDoubleBracket]2
          \[RightDoubleBracket] + $cl\[LeftDoubleBracket]4
          \[RightDoubleBracket]\ $p2\[LeftDoubleBracket]1
          \[RightDoubleBracket]\ $p2\[LeftDoubleBracket]3
          \[RightDoubleBracket]\ $\[Delta]p1\[LeftDoubleBracket]1
          \[RightDoubleBracket]\ $\[Delta]p1\[LeftDoubleBracket]2
          \[RightDoubleBracket]\ $\[Delta]p1\[LeftDoubleBracket]3
          \[RightDoubleBracket]\ $\[Delta]p2\[LeftDoubleBracket]2
          \[RightDoubleBracket] + $cl\[LeftDoubleBracket]1
          \[RightDoubleBracket]\ $p1\[LeftDoubleBracket]1
          \[RightDoubleBracket]\ $p1\[LeftDoubleBracket]2
          \[RightDoubleBracket]\ $p1\[LeftDoubleBracket]3
          \[RightDoubleBracket]\ $p2\[LeftDoubleBracket]3
          \[RightDoubleBracket]\ $\[Delta]p2\[LeftDoubleBracket]1
          \[RightDoubleBracket]\ $\[Delta]p2\[LeftDoubleBracket]2
          \[RightDoubleBracket] + $cl\[LeftDoubleBracket]3
          \[RightDoubleBracket]\ $p1\[LeftDoubleBracket]2
          \[RightDoubleBracket]\ $p1\[LeftDoubleBracket]3
          \[RightDoubleBracket]\ $p2\[LeftDoubleBracket]3
          \[RightDoubleBracket]\ $\[Delta]p1\[LeftDoubleBracket]1
          \[RightDoubleBracket]\ $\[Delta]p2\[LeftDoubleBracket]1
          \[RightDoubleBracket]\ $\[Delta]p2\[LeftDoubleBracket]2
          \[RightDoubleBracket] + $cl\[LeftDoubleBracket]3
          \[RightDoubleBracket]\ $p1\[LeftDoubleBracket]1
          \[RightDoubleBracket]\ $p1\[LeftDoubleBracket]3
          \[RightDoubleBracket]\ $p2\[LeftDoubleBracket]3
          \[RightDoubleBracket]\ $\[Delta]p1\[LeftDoubleBracket]2
          \[RightDoubleBracket]\ $\[Delta]p2\[LeftDoubleBracket]1
          \[RightDoubleBracket]\ $\[Delta]p2\[LeftDoubleBracket]2
          \[RightDoubleBracket] + $cl\[LeftDoubleBracket]1
            \[RightDoubleBracket]\^2\ $p1\[LeftDoubleBracket]3
          \[RightDoubleBracket]\ $p2\[LeftDoubleBracket]3
          \[RightDoubleBracket]\ $\[Delta]p1\[LeftDoubleBracket]1
          \[RightDoubleBracket]\ $\[Delta]p1\[LeftDoubleBracket]2
          \[RightDoubleBracket]\ $\[Delta]p2\[LeftDoubleBracket]1
          \[RightDoubleBracket]\ $\[Delta]p2\[LeftDoubleBracket]2
          \[RightDoubleBracket] + 
      2\ $cl\[LeftDoubleBracket]2\[RightDoubleBracket]\^2\ $p1
          \[LeftDoubleBracket]3\[RightDoubleBracket]\ $p2\[LeftDoubleBracket]3
          \[RightDoubleBracket]\ $\[Delta]p1\[LeftDoubleBracket]1
          \[RightDoubleBracket]\ $\[Delta]p1\[LeftDoubleBracket]2
          \[RightDoubleBracket]\ $\[Delta]p2\[LeftDoubleBracket]1
          \[RightDoubleBracket]\ $\[Delta]p2\[LeftDoubleBracket]2
          \[RightDoubleBracket] + $cl\[LeftDoubleBracket]4
          \[RightDoubleBracket]\ $p1\[LeftDoubleBracket]3
          \[RightDoubleBracket]\ $p2\[LeftDoubleBracket]3
          \[RightDoubleBracket]\ $\[Delta]p1\[LeftDoubleBracket]1
          \[RightDoubleBracket]\ $\[Delta]p1\[LeftDoubleBracket]2
          \[RightDoubleBracket]\ $\[Delta]p2\[LeftDoubleBracket]1
          \[RightDoubleBracket]\ $\[Delta]p2\[LeftDoubleBracket]2
          \[RightDoubleBracket] + $cl\[LeftDoubleBracket]3
          \[RightDoubleBracket]\ $p1\[LeftDoubleBracket]1
          \[RightDoubleBracket]\ $p1\[LeftDoubleBracket]2
          \[RightDoubleBracket]\ $p2\[LeftDoubleBracket]3
          \[RightDoubleBracket]\ $\[Delta]p1\[LeftDoubleBracket]3
          \[RightDoubleBracket]\ $\[Delta]p2\[LeftDoubleBracket]1
          \[RightDoubleBracket]\ $\[Delta]p2\[LeftDoubleBracket]2
          \[RightDoubleBracket] + $cl\[LeftDoubleBracket]1
            \[RightDoubleBracket]\^2\ $p1\[LeftDoubleBracket]2
          \[RightDoubleBracket]\ $p2\[LeftDoubleBracket]3
          \[RightDoubleBracket]\ $\[Delta]p1\[LeftDoubleBracket]1
          \[RightDoubleBracket]\ $\[Delta]p1\[LeftDoubleBracket]3
          \[RightDoubleBracket]\ $\[Delta]p2\[LeftDoubleBracket]1
          \[RightDoubleBracket]\ $\[Delta]p2\[LeftDoubleBracket]2
          \[RightDoubleBracket] + 
      2\ $cl\[LeftDoubleBracket]2\[RightDoubleBracket]\^2\ $p1
          \[LeftDoubleBracket]2\[RightDoubleBracket]\ $p2\[LeftDoubleBracket]3
          \[RightDoubleBracket]\ $\[Delta]p1\[LeftDoubleBracket]1
          \[RightDoubleBracket]\ $\[Delta]p1\[LeftDoubleBracket]3
          \[RightDoubleBracket]\ $\[Delta]p2\[LeftDoubleBracket]1
          \[RightDoubleBracket]\ $\[Delta]p2\[LeftDoubleBracket]2
          \[RightDoubleBracket] + $cl\[LeftDoubleBracket]4
          \[RightDoubleBracket]\ $p1\[LeftDoubleBracket]2
          \[RightDoubleBracket]\ $p2\[LeftDoubleBracket]3
          \[RightDoubleBracket]\ $\[Delta]p1\[LeftDoubleBracket]1
          \[RightDoubleBracket]\ $\[Delta]p1\[LeftDoubleBracket]3
          \[RightDoubleBracket]\ $\[Delta]p2\[LeftDoubleBracket]1
          \[RightDoubleBracket]\ $\[Delta]p2\[LeftDoubleBracket]2
          \[RightDoubleBracket] + $cl\[LeftDoubleBracket]1
            \[RightDoubleBracket]\^2\ $p1\[LeftDoubleBracket]1
          \[RightDoubleBracket]\ $p2\[LeftDoubleBracket]3
          \[RightDoubleBracket]\ $\[Delta]p1\[LeftDoubleBracket]2
          \[RightDoubleBracket]\ $\[Delta]p1\[LeftDoubleBracket]3
          \[RightDoubleBracket]\ $\[Delta]p2\[LeftDoubleBracket]1
          \[RightDoubleBracket]\ $\[Delta]p2\[LeftDoubleBracket]2
          \[RightDoubleBracket] + 
      2\ $cl\[LeftDoubleBracket]2\[RightDoubleBracket]\^2\ $p1
          \[LeftDoubleBracket]1\[RightDoubleBracket]\ $p2\[LeftDoubleBracket]3
          \[RightDoubleBracket]\ $\[Delta]p1\[LeftDoubleBracket]2
          \[RightDoubleBracket]\ $\[Delta]p1\[LeftDoubleBracket]3
          \[RightDoubleBracket]\ $\[Delta]p2\[LeftDoubleBracket]1
          \[RightDoubleBracket]\ $\[Delta]p2\[LeftDoubleBracket]2
          \[RightDoubleBracket] + $cl\[LeftDoubleBracket]4
          \[RightDoubleBracket]\ $p1\[LeftDoubleBracket]1
          \[RightDoubleBracket]\ $p2\[LeftDoubleBracket]3
          \[RightDoubleBracket]\ $\[Delta]p1\[LeftDoubleBracket]2
          \[RightDoubleBracket]\ $\[Delta]p1\[LeftDoubleBracket]3
          \[RightDoubleBracket]\ $\[Delta]p2\[LeftDoubleBracket]1
          \[RightDoubleBracket]\ $\[Delta]p2\[LeftDoubleBracket]2
          \[RightDoubleBracket] + $cl\[LeftDoubleBracket]1
          \[RightDoubleBracket]\ $cl\[LeftDoubleBracket]2
          \[RightDoubleBracket]\ $p2\[LeftDoubleBracket]3
          \[RightDoubleBracket]\ $\[Delta]p1\[LeftDoubleBracket]1
          \[RightDoubleBracket]\ $\[Delta]p1\[LeftDoubleBracket]2
          \[RightDoubleBracket]\ $\[Delta]p1\[LeftDoubleBracket]3
          \[RightDoubleBracket]\ $\[Delta]p2\[LeftDoubleBracket]1
          \[RightDoubleBracket]\ $\[Delta]p2\[LeftDoubleBracket]2
          \[RightDoubleBracket] + 
      3\ $cl\[LeftDoubleBracket]1\[RightDoubleBracket]\ $cl
          \[LeftDoubleBracket]3\[RightDoubleBracket]\ $p2\[LeftDoubleBracket]3
          \[RightDoubleBracket]\ $\[Delta]p1\[LeftDoubleBracket]1
          \[RightDoubleBracket]\ $\[Delta]p1\[LeftDoubleBracket]2
          \[RightDoubleBracket]\ $\[Delta]p1\[LeftDoubleBracket]3
          \[RightDoubleBracket]\ $\[Delta]p2\[LeftDoubleBracket]1
          \[RightDoubleBracket]\ $\[Delta]p2\[LeftDoubleBracket]2
          \[RightDoubleBracket] + 
      6\ $cl\[LeftDoubleBracket]2\[RightDoubleBracket]\ $cl
          \[LeftDoubleBracket]3\[RightDoubleBracket]\ $p2\[LeftDoubleBracket]3
          \[RightDoubleBracket]\ $\[Delta]p1\[LeftDoubleBracket]1
          \[RightDoubleBracket]\ $\[Delta]p1\[LeftDoubleBracket]2
          \[RightDoubleBracket]\ $\[Delta]p1\[LeftDoubleBracket]3
          \[RightDoubleBracket]\ $\[Delta]p2\[LeftDoubleBracket]1
          \[RightDoubleBracket]\ $\[Delta]p2\[LeftDoubleBracket]2
          \[RightDoubleBracket] + $cl\[LeftDoubleBracket]5
          \[RightDoubleBracket]\ $p2\[LeftDoubleBracket]3
          \[RightDoubleBracket]\ $\[Delta]p1\[LeftDoubleBracket]1
          \[RightDoubleBracket]\ $\[Delta]p1\[LeftDoubleBracket]2
          \[RightDoubleBracket]\ $\[Delta]p1\[LeftDoubleBracket]3
          \[RightDoubleBracket]\ $\[Delta]p2\[LeftDoubleBracket]1
          \[RightDoubleBracket]\ $\[Delta]p2\[LeftDoubleBracket]2
          \[RightDoubleBracket] + $cl\[LeftDoubleBracket]2
          \[RightDoubleBracket]\ $p1\[LeftDoubleBracket]2
          \[RightDoubleBracket]\ $p1\[LeftDoubleBracket]3
          \[RightDoubleBracket]\ $p2\[LeftDoubleBracket]1
          \[RightDoubleBracket]\ $p2\[LeftDoubleBracket]2
          \[RightDoubleBracket]\ $\[Delta]p1\[LeftDoubleBracket]1
          \[RightDoubleBracket]\ $\[Delta]p2\[LeftDoubleBracket]3
          \[RightDoubleBracket] + $cl\[LeftDoubleBracket]2
          \[RightDoubleBracket]\ $p1\[LeftDoubleBracket]1
          \[RightDoubleBracket]\ $p1\[LeftDoubleBracket]3
          \[RightDoubleBracket]\ $p2\[LeftDoubleBracket]1
          \[RightDoubleBracket]\ $p2\[LeftDoubleBracket]2
          \[RightDoubleBracket]\ $\[Delta]p1\[LeftDoubleBracket]2
          \[RightDoubleBracket]\ $\[Delta]p2\[LeftDoubleBracket]3
          \[RightDoubleBracket] + $cl\[LeftDoubleBracket]3
          \[RightDoubleBracket]\ $p1\[LeftDoubleBracket]3
          \[RightDoubleBracket]\ $p2\[LeftDoubleBracket]1
          \[RightDoubleBracket]\ $p2\[LeftDoubleBracket]2
          \[RightDoubleBracket]\ $\[Delta]p1\[LeftDoubleBracket]1
          \[RightDoubleBracket]\ $\[Delta]p1\[LeftDoubleBracket]2
          \[RightDoubleBracket]\ $\[Delta]p2\[LeftDoubleBracket]3
          \[RightDoubleBracket] + $cl\[LeftDoubleBracket]2
          \[RightDoubleBracket]\ $p1\[LeftDoubleBracket]1
          \[RightDoubleBracket]\ $p1\[LeftDoubleBracket]2
          \[RightDoubleBracket]\ $p2\[LeftDoubleBracket]1
          \[RightDoubleBracket]\ $p2\[LeftDoubleBracket]2
          \[RightDoubleBracket]\ $\[Delta]p1\[LeftDoubleBracket]3
          \[RightDoubleBracket]\ $\[Delta]p2\[LeftDoubleBracket]3
          \[RightDoubleBracket] + $cl\[LeftDoubleBracket]3
          \[RightDoubleBracket]\ $p1\[LeftDoubleBracket]2
          \[RightDoubleBracket]\ $p2\[LeftDoubleBracket]1
          \[RightDoubleBracket]\ $p2\[LeftDoubleBracket]2
          \[RightDoubleBracket]\ $\[Delta]p1\[LeftDoubleBracket]1
          \[RightDoubleBracket]\ $\[Delta]p1\[LeftDoubleBracket]3
          \[RightDoubleBracket]\ $\[Delta]p2\[LeftDoubleBracket]3
          \[RightDoubleBracket] + $cl\[LeftDoubleBracket]3
          \[RightDoubleBracket]\ $p1\[LeftDoubleBracket]1
          \[RightDoubleBracket]\ $p2\[LeftDoubleBracket]1
          \[RightDoubleBracket]\ $p2\[LeftDoubleBracket]2
          \[RightDoubleBracket]\ $\[Delta]p1\[LeftDoubleBracket]2
          \[RightDoubleBracket]\ $\[Delta]p1\[LeftDoubleBracket]3
          \[RightDoubleBracket]\ $\[Delta]p2\[LeftDoubleBracket]3
          \[RightDoubleBracket] + 
      3\ $cl\[LeftDoubleBracket]1\[RightDoubleBracket]\ $cl
          \[LeftDoubleBracket]2\[RightDoubleBracket]\ $p2\[LeftDoubleBracket]1
          \[RightDoubleBracket]\ $p2\[LeftDoubleBracket]2
          \[RightDoubleBracket]\ $\[Delta]p1\[LeftDoubleBracket]1
          \[RightDoubleBracket]\ $\[Delta]p1\[LeftDoubleBracket]2
          \[RightDoubleBracket]\ $\[Delta]p1\[LeftDoubleBracket]3
          \[RightDoubleBracket]\ $\[Delta]p2\[LeftDoubleBracket]3
          \[RightDoubleBracket] + $cl\[LeftDoubleBracket]4
          \[RightDoubleBracket]\ $p2\[LeftDoubleBracket]1
          \[RightDoubleBracket]\ $p2\[LeftDoubleBracket]2
          \[RightDoubleBracket]\ $\[Delta]p1\[LeftDoubleBracket]1
          \[RightDoubleBracket]\ $\[Delta]p1\[LeftDoubleBracket]2
          \[RightDoubleBracket]\ $\[Delta]p1\[LeftDoubleBracket]3
          \[RightDoubleBracket]\ $\[Delta]p2\[LeftDoubleBracket]3
          \[RightDoubleBracket] + $cl\[LeftDoubleBracket]1
          \[RightDoubleBracket]\ $p1\[LeftDoubleBracket]1
          \[RightDoubleBracket]\ $p1\[LeftDoubleBracket]2
          \[RightDoubleBracket]\ $p1\[LeftDoubleBracket]3
          \[RightDoubleBracket]\ $p2\[LeftDoubleBracket]2
          \[RightDoubleBracket]\ $\[Delta]p2\[LeftDoubleBracket]1
          \[RightDoubleBracket]\ $\[Delta]p2\[LeftDoubleBracket]3
          \[RightDoubleBracket] + $cl\[LeftDoubleBracket]3
          \[RightDoubleBracket]\ $p1\[LeftDoubleBracket]2
          \[RightDoubleBracket]\ $p1\[LeftDoubleBracket]3
          \[RightDoubleBracket]\ $p2\[LeftDoubleBracket]2
          \[RightDoubleBracket]\ $\[Delta]p1\[LeftDoubleBracket]1
          \[RightDoubleBracket]\ $\[Delta]p2\[LeftDoubleBracket]1
          \[RightDoubleBracket]\ $\[Delta]p2\[LeftDoubleBracket]3
          \[RightDoubleBracket] + $cl\[LeftDoubleBracket]3
          \[RightDoubleBracket]\ $p1\[LeftDoubleBracket]1
          \[RightDoubleBracket]\ $p1\[LeftDoubleBracket]3
          \[RightDoubleBracket]\ $p2\[LeftDoubleBracket]2
          \[RightDoubleBracket]\ $\[Delta]p1\[LeftDoubleBracket]2
          \[RightDoubleBracket]\ $\[Delta]p2\[LeftDoubleBracket]1
          \[RightDoubleBracket]\ $\[Delta]p2\[LeftDoubleBracket]3
          \[RightDoubleBracket] + $cl\[LeftDoubleBracket]1
            \[RightDoubleBracket]\^2\ $p1\[LeftDoubleBracket]3
          \[RightDoubleBracket]\ $p2\[LeftDoubleBracket]2
          \[RightDoubleBracket]\ $\[Delta]p1\[LeftDoubleBracket]1
          \[RightDoubleBracket]\ $\[Delta]p1\[LeftDoubleBracket]2
          \[RightDoubleBracket]\ $\[Delta]p2\[LeftDoubleBracket]1
          \[RightDoubleBracket]\ $\[Delta]p2\[LeftDoubleBracket]3
          \[RightDoubleBracket] + 
      2\ $cl\[LeftDoubleBracket]2\[RightDoubleBracket]\^2\ $p1
          \[LeftDoubleBracket]3\[RightDoubleBracket]\ $p2\[LeftDoubleBracket]2
          \[RightDoubleBracket]\ $\[Delta]p1\[LeftDoubleBracket]1
          \[RightDoubleBracket]\ $\[Delta]p1\[LeftDoubleBracket]2
          \[RightDoubleBracket]\ $\[Delta]p2\[LeftDoubleBracket]1
          \[RightDoubleBracket]\ $\[Delta]p2\[LeftDoubleBracket]3
          \[RightDoubleBracket] + $cl\[LeftDoubleBracket]4
          \[RightDoubleBracket]\ $p1\[LeftDoubleBracket]3
          \[RightDoubleBracket]\ $p2\[LeftDoubleBracket]2
          \[RightDoubleBracket]\ $\[Delta]p1\[LeftDoubleBracket]1
          \[RightDoubleBracket]\ $\[Delta]p1\[LeftDoubleBracket]2
          \[RightDoubleBracket]\ $\[Delta]p2\[LeftDoubleBracket]1
          \[RightDoubleBracket]\ $\[Delta]p2\[LeftDoubleBracket]3
          \[RightDoubleBracket] + $cl\[LeftDoubleBracket]3
          \[RightDoubleBracket]\ $p1\[LeftDoubleBracket]1
          \[RightDoubleBracket]\ $p1\[LeftDoubleBracket]2
          \[RightDoubleBracket]\ $p2\[LeftDoubleBracket]2
          \[RightDoubleBracket]\ $\[Delta]p1\[LeftDoubleBracket]3
          \[RightDoubleBracket]\ $\[Delta]p2\[LeftDoubleBracket]1
          \[RightDoubleBracket]\ $\[Delta]p2\[LeftDoubleBracket]3
          \[RightDoubleBracket] + $cl\[LeftDoubleBracket]1
            \[RightDoubleBracket]\^2\ $p1\[LeftDoubleBracket]2
          \[RightDoubleBracket]\ $p2\[LeftDoubleBracket]2
          \[RightDoubleBracket]\ $\[Delta]p1\[LeftDoubleBracket]1
          \[RightDoubleBracket]\ $\[Delta]p1\[LeftDoubleBracket]3
          \[RightDoubleBracket]\ $\[Delta]p2\[LeftDoubleBracket]1
          \[RightDoubleBracket]\ $\[Delta]p2\[LeftDoubleBracket]3
          \[RightDoubleBracket] + 
      2\ $cl\[LeftDoubleBracket]2\[RightDoubleBracket]\^2\ $p1
          \[LeftDoubleBracket]2\[RightDoubleBracket]\ $p2\[LeftDoubleBracket]2
          \[RightDoubleBracket]\ $\[Delta]p1\[LeftDoubleBracket]1
          \[RightDoubleBracket]\ $\[Delta]p1\[LeftDoubleBracket]3
          \[RightDoubleBracket]\ $\[Delta]p2\[LeftDoubleBracket]1
          \[RightDoubleBracket]\ $\[Delta]p2\[LeftDoubleBracket]3
          \[RightDoubleBracket] + $cl\[LeftDoubleBracket]4
          \[RightDoubleBracket]\ $p1\[LeftDoubleBracket]2
          \[RightDoubleBracket]\ $p2\[LeftDoubleBracket]2
          \[RightDoubleBracket]\ $\[Delta]p1\[LeftDoubleBracket]1
          \[RightDoubleBracket]\ $\[Delta]p1\[LeftDoubleBracket]3
          \[RightDoubleBracket]\ $\[Delta]p2\[LeftDoubleBracket]1
          \[RightDoubleBracket]\ $\[Delta]p2\[LeftDoubleBracket]3
          \[RightDoubleBracket] + $cl\[LeftDoubleBracket]1
            \[RightDoubleBracket]\^2\ $p1\[LeftDoubleBracket]1
          \[RightDoubleBracket]\ $p2\[LeftDoubleBracket]2
          \[RightDoubleBracket]\ $\[Delta]p1\[LeftDoubleBracket]2
          \[RightDoubleBracket]\ $\[Delta]p1\[LeftDoubleBracket]3
          \[RightDoubleBracket]\ $\[Delta]p2\[LeftDoubleBracket]1
          \[RightDoubleBracket]\ $\[Delta]p2\[LeftDoubleBracket]3
          \[RightDoubleBracket] + 
      2\ $cl\[LeftDoubleBracket]2\[RightDoubleBracket]\^2\ $p1
          \[LeftDoubleBracket]1\[RightDoubleBracket]\ $p2\[LeftDoubleBracket]2
          \[RightDoubleBracket]\ $\[Delta]p1\[LeftDoubleBracket]2
          \[RightDoubleBracket]\ $\[Delta]p1\[LeftDoubleBracket]3
          \[RightDoubleBracket]\ $\[Delta]p2\[LeftDoubleBracket]1
          \[RightDoubleBracket]\ $\[Delta]p2\[LeftDoubleBracket]3
          \[RightDoubleBracket] + $cl\[LeftDoubleBracket]4
          \[RightDoubleBracket]\ $p1\[LeftDoubleBracket]1
          \[RightDoubleBracket]\ $p2\[LeftDoubleBracket]2
          \[RightDoubleBracket]\ $\[Delta]p1\[LeftDoubleBracket]2
          \[RightDoubleBracket]\ $\[Delta]p1\[LeftDoubleBracket]3
          \[RightDoubleBracket]\ $\[Delta]p2\[LeftDoubleBracket]1
          \[RightDoubleBracket]\ $\[Delta]p2\[LeftDoubleBracket]3
          \[RightDoubleBracket] + $cl\[LeftDoubleBracket]1
          \[RightDoubleBracket]\ $cl\[LeftDoubleBracket]2
          \[RightDoubleBracket]\ $p2\[LeftDoubleBracket]2
          \[RightDoubleBracket]\ $\[Delta]p1\[LeftDoubleBracket]1
          \[RightDoubleBracket]\ $\[Delta]p1\[LeftDoubleBracket]2
          \[RightDoubleBracket]\ $\[Delta]p1\[LeftDoubleBracket]3
          \[RightDoubleBracket]\ $\[Delta]p2\[LeftDoubleBracket]1
          \[RightDoubleBracket]\ $\[Delta]p2\[LeftDoubleBracket]3
          \[RightDoubleBracket] + 
      3\ $cl\[LeftDoubleBracket]1\[RightDoubleBracket]\ $cl
          \[LeftDoubleBracket]3\[RightDoubleBracket]\ $p2\[LeftDoubleBracket]2
          \[RightDoubleBracket]\ $\[Delta]p1\[LeftDoubleBracket]1
          \[RightDoubleBracket]\ $\[Delta]p1\[LeftDoubleBracket]2
          \[RightDoubleBracket]\ $\[Delta]p1\[LeftDoubleBracket]3
          \[RightDoubleBracket]\ $\[Delta]p2\[LeftDoubleBracket]1
          \[RightDoubleBracket]\ $\[Delta]p2\[LeftDoubleBracket]3
          \[RightDoubleBracket] + 
      6\ $cl\[LeftDoubleBracket]2\[RightDoubleBracket]\ $cl
          \[LeftDoubleBracket]3\[RightDoubleBracket]\ $p2\[LeftDoubleBracket]2
          \[RightDoubleBracket]\ $\[Delta]p1\[LeftDoubleBracket]1
          \[RightDoubleBracket]\ $\[Delta]p1\[LeftDoubleBracket]2
          \[RightDoubleBracket]\ $\[Delta]p1\[LeftDoubleBracket]3
          \[RightDoubleBracket]\ $\[Delta]p2\[LeftDoubleBracket]1
          \[RightDoubleBracket]\ $\[Delta]p2\[LeftDoubleBracket]3
          \[RightDoubleBracket] + $cl\[LeftDoubleBracket]5
          \[RightDoubleBracket]\ $p2\[LeftDoubleBracket]2
          \[RightDoubleBracket]\ $\[Delta]p1\[LeftDoubleBracket]1
          \[RightDoubleBracket]\ $\[Delta]p1\[LeftDoubleBracket]2
          \[RightDoubleBracket]\ $\[Delta]p1\[LeftDoubleBracket]3
          \[RightDoubleBracket]\ $\[Delta]p2\[LeftDoubleBracket]1
          \[RightDoubleBracket]\ $\[Delta]p2\[LeftDoubleBracket]3
          \[RightDoubleBracket] + $cl\[LeftDoubleBracket]1
          \[RightDoubleBracket]\ $p1\[LeftDoubleBracket]1
          \[RightDoubleBracket]\ $p1\[LeftDoubleBracket]2
          \[RightDoubleBracket]\ $p1\[LeftDoubleBracket]3
          \[RightDoubleBracket]\ $p2\[LeftDoubleBracket]1
          \[RightDoubleBracket]\ $\[Delta]p2\[LeftDoubleBracket]2
          \[RightDoubleBracket]\ $\[Delta]p2\[LeftDoubleBracket]3
          \[RightDoubleBracket] + $cl\[LeftDoubleBracket]3
          \[RightDoubleBracket]\ $p1\[LeftDoubleBracket]2
          \[RightDoubleBracket]\ $p1\[LeftDoubleBracket]3
          \[RightDoubleBracket]\ $p2\[LeftDoubleBracket]1
          \[RightDoubleBracket]\ $\[Delta]p1\[LeftDoubleBracket]1
          \[RightDoubleBracket]\ $\[Delta]p2\[LeftDoubleBracket]2
          \[RightDoubleBracket]\ $\[Delta]p2\[LeftDoubleBracket]3
          \[RightDoubleBracket] + $cl\[LeftDoubleBracket]3
          \[RightDoubleBracket]\ $p1\[LeftDoubleBracket]1
          \[RightDoubleBracket]\ $p1\[LeftDoubleBracket]3
          \[RightDoubleBracket]\ $p2\[LeftDoubleBracket]1
          \[RightDoubleBracket]\ $\[Delta]p1\[LeftDoubleBracket]2
          \[RightDoubleBracket]\ $\[Delta]p2\[LeftDoubleBracket]2
          \[RightDoubleBracket]\ $\[Delta]p2\[LeftDoubleBracket]3
          \[RightDoubleBracket] + $cl\[LeftDoubleBracket]1
            \[RightDoubleBracket]\^2\ $p1\[LeftDoubleBracket]3
          \[RightDoubleBracket]\ $p2\[LeftDoubleBracket]1
          \[RightDoubleBracket]\ $\[Delta]p1\[LeftDoubleBracket]1
          \[RightDoubleBracket]\ $\[Delta]p1\[LeftDoubleBracket]2
          \[RightDoubleBracket]\ $\[Delta]p2\[LeftDoubleBracket]2
          \[RightDoubleBracket]\ $\[Delta]p2\[LeftDoubleBracket]3
          \[RightDoubleBracket] + 
      2\ $cl\[LeftDoubleBracket]2\[RightDoubleBracket]\^2\ $p1
          \[LeftDoubleBracket]3\[RightDoubleBracket]\ $p2\[LeftDoubleBracket]1
          \[RightDoubleBracket]\ $\[Delta]p1\[LeftDoubleBracket]1
          \[RightDoubleBracket]\ $\[Delta]p1\[LeftDoubleBracket]2
          \[RightDoubleBracket]\ $\[Delta]p2\[LeftDoubleBracket]2
          \[RightDoubleBracket]\ $\[Delta]p2\[LeftDoubleBracket]3
          \[RightDoubleBracket] + $cl\[LeftDoubleBracket]4
          \[RightDoubleBracket]\ $p1\[LeftDoubleBracket]3
          \[RightDoubleBracket]\ $p2\[LeftDoubleBracket]1
          \[RightDoubleBracket]\ $\[Delta]p1\[LeftDoubleBracket]1
          \[RightDoubleBracket]\ $\[Delta]p1\[LeftDoubleBracket]2
          \[RightDoubleBracket]\ $\[Delta]p2\[LeftDoubleBracket]2
          \[RightDoubleBracket]\ $\[Delta]p2\[LeftDoubleBracket]3
          \[RightDoubleBracket] + $cl\[LeftDoubleBracket]3
          \[RightDoubleBracket]\ $p1\[LeftDoubleBracket]1
          \[RightDoubleBracket]\ $p1\[LeftDoubleBracket]2
          \[RightDoubleBracket]\ $p2\[LeftDoubleBracket]1
          \[RightDoubleBracket]\ $\[Delta]p1\[LeftDoubleBracket]3
          \[RightDoubleBracket]\ $\[Delta]p2\[LeftDoubleBracket]2
          \[RightDoubleBracket]\ $\[Delta]p2\[LeftDoubleBracket]3
          \[RightDoubleBracket] + $cl\[LeftDoubleBracket]1
            \[RightDoubleBracket]\^2\ $p1\[LeftDoubleBracket]2
          \[RightDoubleBracket]\ $p2\[LeftDoubleBracket]1
          \[RightDoubleBracket]\ $\[Delta]p1\[LeftDoubleBracket]1
          \[RightDoubleBracket]\ $\[Delta]p1\[LeftDoubleBracket]3
          \[RightDoubleBracket]\ $\[Delta]p2\[LeftDoubleBracket]2
          \[RightDoubleBracket]\ $\[Delta]p2\[LeftDoubleBracket]3
          \[RightDoubleBracket] + 
      2\ $cl\[LeftDoubleBracket]2\[RightDoubleBracket]\^2\ $p1
          \[LeftDoubleBracket]2\[RightDoubleBracket]\ $p2\[LeftDoubleBracket]1
          \[RightDoubleBracket]\ $\[Delta]p1\[LeftDoubleBracket]1
          \[RightDoubleBracket]\ $\[Delta]p1\[LeftDoubleBracket]3
          \[RightDoubleBracket]\ $\[Delta]p2\[LeftDoubleBracket]2
          \[RightDoubleBracket]\ $\[Delta]p2\[LeftDoubleBracket]3
          \[RightDoubleBracket] + $cl\[LeftDoubleBracket]4
          \[RightDoubleBracket]\ $p1\[LeftDoubleBracket]2
          \[RightDoubleBracket]\ $p2\[LeftDoubleBracket]1
          \[RightDoubleBracket]\ $\[Delta]p1\[LeftDoubleBracket]1
          \[RightDoubleBracket]\ $\[Delta]p1\[LeftDoubleBracket]3
          \[RightDoubleBracket]\ $\[Delta]p2\[LeftDoubleBracket]2
          \[RightDoubleBracket]\ $\[Delta]p2\[LeftDoubleBracket]3
          \[RightDoubleBracket] + $cl\[LeftDoubleBracket]1
            \[RightDoubleBracket]\^2\ $p1\[LeftDoubleBracket]1
          \[RightDoubleBracket]\ $p2\[LeftDoubleBracket]1
          \[RightDoubleBracket]\ $\[Delta]p1\[LeftDoubleBracket]2
          \[RightDoubleBracket]\ $\[Delta]p1\[LeftDoubleBracket]3
          \[RightDoubleBracket]\ $\[Delta]p2\[LeftDoubleBracket]2
          \[RightDoubleBracket]\ $\[Delta]p2\[LeftDoubleBracket]3
          \[RightDoubleBracket] + 
      2\ $cl\[LeftDoubleBracket]2\[RightDoubleBracket]\^2\ $p1
          \[LeftDoubleBracket]1\[RightDoubleBracket]\ $p2\[LeftDoubleBracket]1
          \[RightDoubleBracket]\ $\[Delta]p1\[LeftDoubleBracket]2
          \[RightDoubleBracket]\ $\[Delta]p1\[LeftDoubleBracket]3
          \[RightDoubleBracket]\ $\[Delta]p2\[LeftDoubleBracket]2
          \[RightDoubleBracket]\ $\[Delta]p2\[LeftDoubleBracket]3
          \[RightDoubleBracket] + $cl\[LeftDoubleBracket]4
          \[RightDoubleBracket]\ $p1\[LeftDoubleBracket]1
          \[RightDoubleBracket]\ $p2\[LeftDoubleBracket]1
          \[RightDoubleBracket]\ $\[Delta]p1\[LeftDoubleBracket]2
          \[RightDoubleBracket]\ $\[Delta]p1\[LeftDoubleBracket]3
          \[RightDoubleBracket]\ $\[Delta]p2\[LeftDoubleBracket]2
          \[RightDoubleBracket]\ $\[Delta]p2\[LeftDoubleBracket]3
          \[RightDoubleBracket] + $cl\[LeftDoubleBracket]1
          \[RightDoubleBracket]\ $cl\[LeftDoubleBracket]2
          \[RightDoubleBracket]\ $p2\[LeftDoubleBracket]1
          \[RightDoubleBracket]\ $\[Delta]p1\[LeftDoubleBracket]1
          \[RightDoubleBracket]\ $\[Delta]p1\[LeftDoubleBracket]2
          \[RightDoubleBracket]\ $\[Delta]p1\[LeftDoubleBracket]3
          \[RightDoubleBracket]\ $\[Delta]p2\[LeftDoubleBracket]2
          \[RightDoubleBracket]\ $\[Delta]p2\[LeftDoubleBracket]3
          \[RightDoubleBracket] + 
      3\ $cl\[LeftDoubleBracket]1\[RightDoubleBracket]\ $cl
          \[LeftDoubleBracket]3\[RightDoubleBracket]\ $p2\[LeftDoubleBracket]1
          \[RightDoubleBracket]\ $\[Delta]p1\[LeftDoubleBracket]1
          \[RightDoubleBracket]\ $\[Delta]p1\[LeftDoubleBracket]2
          \[RightDoubleBracket]\ $\[Delta]p1\[LeftDoubleBracket]3
          \[RightDoubleBracket]\ $\[Delta]p2\[LeftDoubleBracket]2
          \[RightDoubleBracket]\ $\[Delta]p2\[LeftDoubleBracket]3
          \[RightDoubleBracket] + 
      6\ $cl\[LeftDoubleBracket]2\[RightDoubleBracket]\ $cl
          \[LeftDoubleBracket]3\[RightDoubleBracket]\ $p2\[LeftDoubleBracket]1
          \[RightDoubleBracket]\ $\[Delta]p1\[LeftDoubleBracket]1
          \[RightDoubleBracket]\ $\[Delta]p1\[LeftDoubleBracket]2
          \[RightDoubleBracket]\ $\[Delta]p1\[LeftDoubleBracket]3
          \[RightDoubleBracket]\ $\[Delta]p2\[LeftDoubleBracket]2
          \[RightDoubleBracket]\ $\[Delta]p2\[LeftDoubleBracket]3
          \[RightDoubleBracket] + $cl\[LeftDoubleBracket]5
          \[RightDoubleBracket]\ $p2\[LeftDoubleBracket]1
          \[RightDoubleBracket]\ $\[Delta]p1\[LeftDoubleBracket]1
          \[RightDoubleBracket]\ $\[Delta]p1\[LeftDoubleBracket]2
          \[RightDoubleBracket]\ $\[Delta]p1\[LeftDoubleBracket]3
          \[RightDoubleBracket]\ $\[Delta]p2\[LeftDoubleBracket]2
          \[RightDoubleBracket]\ $\[Delta]p2\[LeftDoubleBracket]3
          \[RightDoubleBracket] + $cl\[LeftDoubleBracket]2
          \[RightDoubleBracket]\ $p1\[LeftDoubleBracket]1
          \[RightDoubleBracket]\ $p1\[LeftDoubleBracket]2
          \[RightDoubleBracket]\ $p1\[LeftDoubleBracket]3
          \[RightDoubleBracket]\ $\[Delta]p2\[LeftDoubleBracket]1
          \[RightDoubleBracket]\ $\[Delta]p2\[LeftDoubleBracket]2
          \[RightDoubleBracket]\ $\[Delta]p2\[LeftDoubleBracket]3
          \[RightDoubleBracket] + 
      3\ $cl\[LeftDoubleBracket]1\[RightDoubleBracket]\ $cl
          \[LeftDoubleBracket]2\[RightDoubleBracket]\ $p1\[LeftDoubleBracket]2
          \[RightDoubleBracket]\ $p1\[LeftDoubleBracket]3
          \[RightDoubleBracket]\ $\[Delta]p1\[LeftDoubleBracket]1
          \[RightDoubleBracket]\ $\[Delta]p2\[LeftDoubleBracket]1
          \[RightDoubleBracket]\ $\[Delta]p2\[LeftDoubleBracket]2
          \[RightDoubleBracket]\ $\[Delta]p2\[LeftDoubleBracket]3
          \[RightDoubleBracket] + $cl\[LeftDoubleBracket]4
          \[RightDoubleBracket]\ $p1\[LeftDoubleBracket]2
          \[RightDoubleBracket]\ $p1\[LeftDoubleBracket]3
          \[RightDoubleBracket]\ $\[Delta]p1\[LeftDoubleBracket]1
          \[RightDoubleBracket]\ $\[Delta]p2\[LeftDoubleBracket]1
          \[RightDoubleBracket]\ $\[Delta]p2\[LeftDoubleBracket]2
          \[RightDoubleBracket]\ $\[Delta]p2\[LeftDoubleBracket]3
          \[RightDoubleBracket] + 
      3\ $cl\[LeftDoubleBracket]1\[RightDoubleBracket]\ $cl
          \[LeftDoubleBracket]2\[RightDoubleBracket]\ $p1\[LeftDoubleBracket]1
          \[RightDoubleBracket]\ $p1\[LeftDoubleBracket]3
          \[RightDoubleBracket]\ $\[Delta]p1\[LeftDoubleBracket]2
          \[RightDoubleBracket]\ $\[Delta]p2\[LeftDoubleBracket]1
          \[RightDoubleBracket]\ $\[Delta]p2\[LeftDoubleBracket]2
          \[RightDoubleBracket]\ $\[Delta]p2\[LeftDoubleBracket]3
          \[RightDoubleBracket] + $cl\[LeftDoubleBracket]4
          \[RightDoubleBracket]\ $p1\[LeftDoubleBracket]1
          \[RightDoubleBracket]\ $p1\[LeftDoubleBracket]3
          \[RightDoubleBracket]\ $\[Delta]p1\[LeftDoubleBracket]2
          \[RightDoubleBracket]\ $\[Delta]p2\[LeftDoubleBracket]1
          \[RightDoubleBracket]\ $\[Delta]p2\[LeftDoubleBracket]2
          \[RightDoubleBracket]\ $\[Delta]p2\[LeftDoubleBracket]3
          \[RightDoubleBracket] + $cl\[LeftDoubleBracket]1
          \[RightDoubleBracket]\ $cl\[LeftDoubleBracket]2
          \[RightDoubleBracket]\ $p1\[LeftDoubleBracket]3
          \[RightDoubleBracket]\ $\[Delta]p1\[LeftDoubleBracket]1
          \[RightDoubleBracket]\ $\[Delta]p1\[LeftDoubleBracket]2
          \[RightDoubleBracket]\ $\[Delta]p2\[LeftDoubleBracket]1
          \[RightDoubleBracket]\ $\[Delta]p2\[LeftDoubleBracket]2
          \[RightDoubleBracket]\ $\[Delta]p2\[LeftDoubleBracket]3
          \[RightDoubleBracket] + 
      3\ $cl\[LeftDoubleBracket]1\[RightDoubleBracket]\ $cl
          \[LeftDoubleBracket]3\[RightDoubleBracket]\ $p1\[LeftDoubleBracket]3
          \[RightDoubleBracket]\ $\[Delta]p1\[LeftDoubleBracket]1
          \[RightDoubleBracket]\ $\[Delta]p1\[LeftDoubleBracket]2
          \[RightDoubleBracket]\ $\[Delta]p2\[LeftDoubleBracket]1
          \[RightDoubleBracket]\ $\[Delta]p2\[LeftDoubleBracket]2
          \[RightDoubleBracket]\ $\[Delta]p2\[LeftDoubleBracket]3
          \[RightDoubleBracket] + 
      6\ $cl\[LeftDoubleBracket]2\[RightDoubleBracket]\ $cl
          \[LeftDoubleBracket]3\[RightDoubleBracket]\ $p1\[LeftDoubleBracket]3
          \[RightDoubleBracket]\ $\[Delta]p1\[LeftDoubleBracket]1
          \[RightDoubleBracket]\ $\[Delta]p1\[LeftDoubleBracket]2
          \[RightDoubleBracket]\ $\[Delta]p2\[LeftDoubleBracket]1
          \[RightDoubleBracket]\ $\[Delta]p2\[LeftDoubleBracket]2
          \[RightDoubleBracket]\ $\[Delta]p2\[LeftDoubleBracket]3
          \[RightDoubleBracket] + $cl\[LeftDoubleBracket]5
          \[RightDoubleBracket]\ $p1\[LeftDoubleBracket]3
          \[RightDoubleBracket]\ $\[Delta]p1\[LeftDoubleBracket]1
          \[RightDoubleBracket]\ $\[Delta]p1\[LeftDoubleBracket]2
          \[RightDoubleBracket]\ $\[Delta]p2\[LeftDoubleBracket]1
          \[RightDoubleBracket]\ $\[Delta]p2\[LeftDoubleBracket]2
          \[RightDoubleBracket]\ $\[Delta]p2\[LeftDoubleBracket]3
          \[RightDoubleBracket] + 
      3\ $cl\[LeftDoubleBracket]1\[RightDoubleBracket]\ $cl
          \[LeftDoubleBracket]2\[RightDoubleBracket]\ $p1\[LeftDoubleBracket]1
          \[RightDoubleBracket]\ $p1\[LeftDoubleBracket]2
          \[RightDoubleBracket]\ $\[Delta]p1\[LeftDoubleBracket]3
          \[RightDoubleBracket]\ $\[Delta]p2\[LeftDoubleBracket]1
          \[RightDoubleBracket]\ $\[Delta]p2\[LeftDoubleBracket]2
          \[RightDoubleBracket]\ $\[Delta]p2\[LeftDoubleBracket]3
          \[RightDoubleBracket] + $cl\[LeftDoubleBracket]4
          \[RightDoubleBracket]\ $p1\[LeftDoubleBracket]1
          \[RightDoubleBracket]\ $p1\[LeftDoubleBracket]2
          \[RightDoubleBracket]\ $\[Delta]p1\[LeftDoubleBracket]3
          \[RightDoubleBracket]\ $\[Delta]p2\[LeftDoubleBracket]1
          \[RightDoubleBracket]\ $\[Delta]p2\[LeftDoubleBracket]2
          \[RightDoubleBracket]\ $\[Delta]p2\[LeftDoubleBracket]3
          \[RightDoubleBracket] + $cl\[LeftDoubleBracket]1
          \[RightDoubleBracket]\ $cl\[LeftDoubleBracket]2
          \[RightDoubleBracket]\ $p1\[LeftDoubleBracket]2
          \[RightDoubleBracket]\ $\[Delta]p1\[LeftDoubleBracket]1
          \[RightDoubleBracket]\ $\[Delta]p1\[LeftDoubleBracket]3
          \[RightDoubleBracket]\ $\[Delta]p2\[LeftDoubleBracket]1
          \[RightDoubleBracket]\ $\[Delta]p2\[LeftDoubleBracket]2
          \[RightDoubleBracket]\ $\[Delta]p2\[LeftDoubleBracket]3
          \[RightDoubleBracket] + 
      3\ $cl\[LeftDoubleBracket]1\[RightDoubleBracket]\ $cl
          \[LeftDoubleBracket]3\[RightDoubleBracket]\ $p1\[LeftDoubleBracket]2
          \[RightDoubleBracket]\ $\[Delta]p1\[LeftDoubleBracket]1
          \[RightDoubleBracket]\ $\[Delta]p1\[LeftDoubleBracket]3
          \[RightDoubleBracket]\ $\[Delta]p2\[LeftDoubleBracket]1
          \[RightDoubleBracket]\ $\[Delta]p2\[LeftDoubleBracket]2
          \[RightDoubleBracket]\ $\[Delta]p2\[LeftDoubleBracket]3
          \[RightDoubleBracket] + 
      6\ $cl\[LeftDoubleBracket]2\[RightDoubleBracket]\ $cl
          \[LeftDoubleBracket]3\[RightDoubleBracket]\ $p1\[LeftDoubleBracket]2
          \[RightDoubleBracket]\ $\[Delta]p1\[LeftDoubleBracket]1
          \[RightDoubleBracket]\ $\[Delta]p1\[LeftDoubleBracket]3
          \[RightDoubleBracket]\ $\[Delta]p2\[LeftDoubleBracket]1
          \[RightDoubleBracket]\ $\[Delta]p2\[LeftDoubleBracket]2
          \[RightDoubleBracket]\ $\[Delta]p2\[LeftDoubleBracket]3
          \[RightDoubleBracket] + $cl\[LeftDoubleBracket]5
          \[RightDoubleBracket]\ $p1\[LeftDoubleBracket]2
          \[RightDoubleBracket]\ $\[Delta]p1\[LeftDoubleBracket]1
          \[RightDoubleBracket]\ $\[Delta]p1\[LeftDoubleBracket]3
          \[RightDoubleBracket]\ $\[Delta]p2\[LeftDoubleBracket]1
          \[RightDoubleBracket]\ $\[Delta]p2\[LeftDoubleBracket]2
          \[RightDoubleBracket]\ $\[Delta]p2\[LeftDoubleBracket]3
          \[RightDoubleBracket] + $cl\[LeftDoubleBracket]1
          \[RightDoubleBracket]\ $cl\[LeftDoubleBracket]2
          \[RightDoubleBracket]\ $p1\[LeftDoubleBracket]1
          \[RightDoubleBracket]\ $\[Delta]p1\[LeftDoubleBracket]2
          \[RightDoubleBracket]\ $\[Delta]p1\[LeftDoubleBracket]3
          \[RightDoubleBracket]\ $\[Delta]p2\[LeftDoubleBracket]1
          \[RightDoubleBracket]\ $\[Delta]p2\[LeftDoubleBracket]2
          \[RightDoubleBracket]\ $\[Delta]p2\[LeftDoubleBracket]3
          \[RightDoubleBracket] + 
      3\ $cl\[LeftDoubleBracket]1\[RightDoubleBracket]\ $cl
          \[LeftDoubleBracket]3\[RightDoubleBracket]\ $p1\[LeftDoubleBracket]1
          \[RightDoubleBracket]\ $\[Delta]p1\[LeftDoubleBracket]2
          \[RightDoubleBracket]\ $\[Delta]p1\[LeftDoubleBracket]3
          \[RightDoubleBracket]\ $\[Delta]p2\[LeftDoubleBracket]1
          \[RightDoubleBracket]\ $\[Delta]p2\[LeftDoubleBracket]2
          \[RightDoubleBracket]\ $\[Delta]p2\[LeftDoubleBracket]3
          \[RightDoubleBracket] + 
      6\ $cl\[LeftDoubleBracket]2\[RightDoubleBracket]\ $cl
          \[LeftDoubleBracket]3\[RightDoubleBracket]\ $p1\[LeftDoubleBracket]1
          \[RightDoubleBracket]\ $\[Delta]p1\[LeftDoubleBracket]2
          \[RightDoubleBracket]\ $\[Delta]p1\[LeftDoubleBracket]3
          \[RightDoubleBracket]\ $\[Delta]p2\[LeftDoubleBracket]1
          \[RightDoubleBracket]\ $\[Delta]p2\[LeftDoubleBracket]2
          \[RightDoubleBracket]\ $\[Delta]p2\[LeftDoubleBracket]3
          \[RightDoubleBracket] + $cl\[LeftDoubleBracket]5
          \[RightDoubleBracket]\ $p1\[LeftDoubleBracket]1
          \[RightDoubleBracket]\ $\[Delta]p1\[LeftDoubleBracket]2
          \[RightDoubleBracket]\ $\[Delta]p1\[LeftDoubleBracket]3
          \[RightDoubleBracket]\ $\[Delta]p2\[LeftDoubleBracket]1
          \[RightDoubleBracket]\ $\[Delta]p2\[LeftDoubleBracket]2
          \[RightDoubleBracket]\ $\[Delta]p2\[LeftDoubleBracket]3
          \[RightDoubleBracket] + 
      9\ $cl\[LeftDoubleBracket]1\[RightDoubleBracket]\^2\ $cl
          \[LeftDoubleBracket]2\[RightDoubleBracket]\ $\[Delta]p1
          \[LeftDoubleBracket]1\[RightDoubleBracket]\ $\[Delta]p1
          \[LeftDoubleBracket]2\[RightDoubleBracket]\ $\[Delta]p1
          \[LeftDoubleBracket]3\[RightDoubleBracket]\ $\[Delta]p2
          \[LeftDoubleBracket]1\[RightDoubleBracket]\ $\[Delta]p2
          \[LeftDoubleBracket]2\[RightDoubleBracket]\ $\[Delta]p2
          \[LeftDoubleBracket]3
          \[RightDoubleBracket] + $cl\[LeftDoubleBracket]2
            \[RightDoubleBracket]\^2\ $\[Delta]p1\[LeftDoubleBracket]1
          \[RightDoubleBracket]\ $\[Delta]p1\[LeftDoubleBracket]2
          \[RightDoubleBracket]\ $\[Delta]p1\[LeftDoubleBracket]3
          \[RightDoubleBracket]\ $\[Delta]p2\[LeftDoubleBracket]1
          \[RightDoubleBracket]\ $\[Delta]p2\[LeftDoubleBracket]2
          \[RightDoubleBracket]\ $\[Delta]p2\[LeftDoubleBracket]3
          \[RightDoubleBracket] + 
      6\ $cl\[LeftDoubleBracket]2\[RightDoubleBracket]\^3\ $\[Delta]p1
          \[LeftDoubleBracket]1\[RightDoubleBracket]\ $\[Delta]p1
          \[LeftDoubleBracket]2\[RightDoubleBracket]\ $\[Delta]p1
          \[LeftDoubleBracket]3\[RightDoubleBracket]\ $\[Delta]p2
          \[LeftDoubleBracket]1\[RightDoubleBracket]\ $\[Delta]p2
          \[LeftDoubleBracket]2\[RightDoubleBracket]\ $\[Delta]p2
          \[LeftDoubleBracket]3\[RightDoubleBracket] + 
      9\ $cl\[LeftDoubleBracket]3\[RightDoubleBracket]\^2\ $\[Delta]p1
          \[LeftDoubleBracket]1\[RightDoubleBracket]\ $\[Delta]p1
          \[LeftDoubleBracket]2\[RightDoubleBracket]\ $\[Delta]p1
          \[LeftDoubleBracket]3\[RightDoubleBracket]\ $\[Delta]p2
          \[LeftDoubleBracket]1\[RightDoubleBracket]\ $\[Delta]p2
          \[LeftDoubleBracket]2\[RightDoubleBracket]\ $\[Delta]p2
          \[LeftDoubleBracket]3\[RightDoubleBracket] + 
      6\ $cl\[LeftDoubleBracket]1\[RightDoubleBracket]\ $cl
          \[LeftDoubleBracket]4\[RightDoubleBracket]\ $\[Delta]p1
          \[LeftDoubleBracket]1\[RightDoubleBracket]\ $\[Delta]p1
          \[LeftDoubleBracket]2\[RightDoubleBracket]\ $\[Delta]p1
          \[LeftDoubleBracket]3\[RightDoubleBracket]\ $\[Delta]p2
          \[LeftDoubleBracket]1\[RightDoubleBracket]\ $\[Delta]p2
          \[LeftDoubleBracket]2\[RightDoubleBracket]\ $\[Delta]p2
          \[LeftDoubleBracket]3\[RightDoubleBracket] + 
      9\ $cl\[LeftDoubleBracket]2\[RightDoubleBracket]\ $cl
          \[LeftDoubleBracket]4\[RightDoubleBracket]\ $\[Delta]p1
          \[LeftDoubleBracket]1\[RightDoubleBracket]\ $\[Delta]p1
          \[LeftDoubleBracket]2\[RightDoubleBracket]\ $\[Delta]p1
          \[LeftDoubleBracket]3\[RightDoubleBracket]\ $\[Delta]p2
          \[LeftDoubleBracket]1\[RightDoubleBracket]\ $\[Delta]p2
          \[LeftDoubleBracket]2\[RightDoubleBracket]\ $\[Delta]p2
          \[LeftDoubleBracket]3\[RightDoubleBracket] + $cl
          \[LeftDoubleBracket]6\[RightDoubleBracket]\ $\[Delta]p1
          \[LeftDoubleBracket]1\[RightDoubleBracket]\ $\[Delta]p1
          \[LeftDoubleBracket]2\[RightDoubleBracket]\ $\[Delta]p1
          \[LeftDoubleBracket]3\[RightDoubleBracket]\ $\[Delta]p2
          \[LeftDoubleBracket]1\[RightDoubleBracket]\ $\[Delta]p2
          \[LeftDoubleBracket]2\[RightDoubleBracket]\ $\[Delta]p2
          \[LeftDoubleBracket]3\[RightDoubleBracket]\)], "Output"]
}, Closed]],

Cell[BoxData[
    \(\(gt4 = 
      FullGenotypeFrequencyTable[{cw, cb}, 
          Range[4]] /. {$\[Delta]p[\(x_\^*\)] :> $\[Delta]p2
              \[LeftDoubleBracket]x\[RightDoubleBracket], $\[Delta]p[
              x_] :> $\[Delta]p1\[LeftDoubleBracket]x
              \[RightDoubleBracket], $p[\(x_\^*\)] :> $p2\[LeftDoubleBracket]x
              \[RightDoubleBracket], $p[x_] :> $p1\[LeftDoubleBracket]x
              \[RightDoubleBracket], 
          cw[j_] :> $cl\[LeftDoubleBracket]j - 1\[RightDoubleBracket], 
          cb[j_] :> $cl\[LeftDoubleBracket]j\[RightDoubleBracket]}; \)\)], 
  "Input"],

Cell[BoxData[
    \(Clear[$p1, $p2, $\[Delta]p1, $\[Delta]p2, $cl]\)], "Input"],

Cell[BoxData[
    \(\(FullGenotypeFrequencyTable[4, compiled] = 
      Compile[{{$Z, _Integer, 2}, {$p, _Real, 1}, {$cl, _Real, 1}}, \n\t\t
        \(($q = 1 - $p; $p1 = 
            \((1 - $Z\[LeftDoubleBracket]1\[RightDoubleBracket])\) $q + $Z
                  \[LeftDoubleBracket]1\[RightDoubleBracket] $p; $p2 = 
            \((1 - $Z\[LeftDoubleBracket]2\[RightDoubleBracket])\) $q + $Z
                  \[LeftDoubleBracket]2
                  \[RightDoubleBracket] $p; $\[Delta]p1 = 
            \((2  $Z\[LeftDoubleBracket]1\[RightDoubleBracket] - 1)
              \); $\[Delta]p2 = 
            \((2  $Z\[LeftDoubleBracket]2\[RightDoubleBracket] - 1)\); \n
          \t\t\tgt4 // Evaluate)
          \), {{$q, _Real, 1}, {$p1, _Real, 1}, {$p2, _Real, 
            1}, {$\[Delta]p1, _Integer, 1}, {$\[Delta]p2, _Integer, 1}}]; 
    \)\)], "Input"],

Cell[BoxData[
    \(\(FullGenotypeFrequencyTable[2, compiled] = 
      Compile[{{$Z, _Integer, 2}, {$p, _Real, 1}, {$cl, _Real, 1}}, \n\t\t
        \(($q = 1 - $p; $p1 = 
            \((1 - $Z\[LeftDoubleBracket]1\[RightDoubleBracket])\) $q + $Z
                  \[LeftDoubleBracket]1\[RightDoubleBracket] $p; $p2 = 
            \((1 - $Z\[LeftDoubleBracket]2\[RightDoubleBracket])\) $q + $Z
                  \[LeftDoubleBracket]2
                  \[RightDoubleBracket] $p; $\[Delta]p1 = 
            \((2  $Z\[LeftDoubleBracket]1\[RightDoubleBracket] - 1)
              \); $\[Delta]p2 = 
            \((2  $Z\[LeftDoubleBracket]2\[RightDoubleBracket] - 1)\); \n
          \t\t\t$p1\[LeftDoubleBracket]1\[RightDoubleBracket]\ $p1
                \[LeftDoubleBracket]2\[RightDoubleBracket]\ $p2
                \[LeftDoubleBracket]1\[RightDoubleBracket]\ $p2
                \[LeftDoubleBracket]2\[RightDoubleBracket] + $cl
                \[LeftDoubleBracket]1\[RightDoubleBracket]\ $p2
                \[LeftDoubleBracket]1\[RightDoubleBracket]\ $p2
                \[LeftDoubleBracket]2\[RightDoubleBracket]\ $\[Delta]p1
                \[LeftDoubleBracket]1\[RightDoubleBracket]\ $\[Delta]p1
                \[LeftDoubleBracket]2\[RightDoubleBracket] + $cl
                \[LeftDoubleBracket]2\[RightDoubleBracket]\ $p1
                \[LeftDoubleBracket]2\[RightDoubleBracket]\ $p2
                \[LeftDoubleBracket]2\[RightDoubleBracket]\ $\[Delta]p1
                \[LeftDoubleBracket]1\[RightDoubleBracket]\ $\[Delta]p2
                \[LeftDoubleBracket]1\[RightDoubleBracket] + $cl
                \[LeftDoubleBracket]2\[RightDoubleBracket]\ $p1
                \[LeftDoubleBracket]1\[RightDoubleBracket]\ $p2
                \[LeftDoubleBracket]2\[RightDoubleBracket]\ $\[Delta]p1
                \[LeftDoubleBracket]2\[RightDoubleBracket]\ $\[Delta]p2
                \[LeftDoubleBracket]1\[RightDoubleBracket] + $cl
                \[LeftDoubleBracket]3\[RightDoubleBracket]\ $p2
                \[LeftDoubleBracket]2\[RightDoubleBracket]\ $\[Delta]p1
                \[LeftDoubleBracket]1\[RightDoubleBracket]\ $\[Delta]p1
                \[LeftDoubleBracket]2\[RightDoubleBracket]\ $\[Delta]p2
                \[LeftDoubleBracket]1\[RightDoubleBracket] + $cl
                \[LeftDoubleBracket]2\[RightDoubleBracket]\ $p1
                \[LeftDoubleBracket]2\[RightDoubleBracket]\ $p2
                \[LeftDoubleBracket]1\[RightDoubleBracket]\ $\[Delta]p1
                \[LeftDoubleBracket]1\[RightDoubleBracket]\ $\[Delta]p2
                \[LeftDoubleBracket]2\[RightDoubleBracket] + $cl
                \[LeftDoubleBracket]2\[RightDoubleBracket]\ $p1
                \[LeftDoubleBracket]1\[RightDoubleBracket]\ $p2
                \[LeftDoubleBracket]1\[RightDoubleBracket]\ $\[Delta]p1
                \[LeftDoubleBracket]2\[RightDoubleBracket]\ $\[Delta]p2
                \[LeftDoubleBracket]2\[RightDoubleBracket] + $cl
                \[LeftDoubleBracket]3\[RightDoubleBracket]\ $p2
                \[LeftDoubleBracket]1\[RightDoubleBracket]\ $\[Delta]p1
                \[LeftDoubleBracket]1\[RightDoubleBracket]\ $\[Delta]p1
                \[LeftDoubleBracket]2\[RightDoubleBracket]\ $\[Delta]p2
                \[LeftDoubleBracket]2\[RightDoubleBracket] + $cl
                \[LeftDoubleBracket]1\[RightDoubleBracket]\ $p1
                \[LeftDoubleBracket]1\[RightDoubleBracket]\ $p1
                \[LeftDoubleBracket]2\[RightDoubleBracket]\ $\[Delta]p2
                \[LeftDoubleBracket]1\[RightDoubleBracket]\ $\[Delta]p2
                \[LeftDoubleBracket]2\[RightDoubleBracket] + $cl
                \[LeftDoubleBracket]3\[RightDoubleBracket]\ $p1
                \[LeftDoubleBracket]2\[RightDoubleBracket]\ $\[Delta]p1
                \[LeftDoubleBracket]1\[RightDoubleBracket]\ $\[Delta]p2
                \[LeftDoubleBracket]1\[RightDoubleBracket]\ $\[Delta]p2
                \[LeftDoubleBracket]2\[RightDoubleBracket] + $cl
                \[LeftDoubleBracket]3\[RightDoubleBracket]\ $p1
                \[LeftDoubleBracket]1\[RightDoubleBracket]\ $\[Delta]p1
                \[LeftDoubleBracket]2\[RightDoubleBracket]\ $\[Delta]p2
                \[LeftDoubleBracket]1\[RightDoubleBracket]\ $\[Delta]p2
                \[LeftDoubleBracket]2
                \[RightDoubleBracket] + $cl\[LeftDoubleBracket]1
                  \[RightDoubleBracket]\^2\ $\[Delta]p1\[LeftDoubleBracket]1
                \[RightDoubleBracket]\ $\[Delta]p1\[LeftDoubleBracket]2
                \[RightDoubleBracket]\ $\[Delta]p2\[LeftDoubleBracket]1
                \[RightDoubleBracket]\ $\[Delta]p2\[LeftDoubleBracket]2
                \[RightDoubleBracket] + 
            2\ $cl\[LeftDoubleBracket]2\[RightDoubleBracket]\^2\ $\[Delta]p1
                \[LeftDoubleBracket]1\[RightDoubleBracket]\ $\[Delta]p1
                \[LeftDoubleBracket]2\[RightDoubleBracket]\ $\[Delta]p2
                \[LeftDoubleBracket]1\[RightDoubleBracket]\ $\[Delta]p2
                \[LeftDoubleBracket]2\[RightDoubleBracket] + $cl
                \[LeftDoubleBracket]4\[RightDoubleBracket]\ $\[Delta]p1
                \[LeftDoubleBracket]1\[RightDoubleBracket]\ $\[Delta]p1
                \[LeftDoubleBracket]2\[RightDoubleBracket]\ $\[Delta]p2
                \[LeftDoubleBracket]1\[RightDoubleBracket]\ $\[Delta]p2
                \[LeftDoubleBracket]2\[RightDoubleBracket])
          \), {{$q, _Real, 1}, {$p1, _Real, 1}, {$p2, _Real, 
            1}, {$\[Delta]p1, _Integer, 1}, {$\[Delta]p2, _Integer, 1}}]; 
    \)\)], "Input"],

Cell[BoxData[
    \(\(FullGenotypeFrequencyTable[3, compiled] = 
      Compile[{{$Z, _Integer, 2}, {$p, _Real, 1}, {$cl, _Real, 1}}, \n\t\t
        \(($q = 1 - $p; $p1 = 
            \((1 - $Z\[LeftDoubleBracket]1\[RightDoubleBracket])\) $q + $Z
                  \[LeftDoubleBracket]1\[RightDoubleBracket] $p; $p2 = 
            \((1 - $Z\[LeftDoubleBracket]2\[RightDoubleBracket])\) $q + $Z
                  \[LeftDoubleBracket]2
                  \[RightDoubleBracket] $p; $\[Delta]p1 = 
            \((2  $Z\[LeftDoubleBracket]1\[RightDoubleBracket] - 1)
              \); $\[Delta]p2 = 
            \((2  $Z\[LeftDoubleBracket]2\[RightDoubleBracket] - 1)\); \n
          \t\t$p1\[LeftDoubleBracket]1\[RightDoubleBracket]\ $p1
                \[LeftDoubleBracket]2\[RightDoubleBracket]\ $p1
                \[LeftDoubleBracket]3\[RightDoubleBracket]\ $p2
                \[LeftDoubleBracket]1\[RightDoubleBracket]\ $p2
                \[LeftDoubleBracket]2\[RightDoubleBracket]\ $p2
                \[LeftDoubleBracket]3\[RightDoubleBracket] + $cl
                \[LeftDoubleBracket]1\[RightDoubleBracket]\ $p1
                \[LeftDoubleBracket]3\[RightDoubleBracket]\ $p2
                \[LeftDoubleBracket]1\[RightDoubleBracket]\ $p2
                \[LeftDoubleBracket]2\[RightDoubleBracket]\ $p2
                \[LeftDoubleBracket]3\[RightDoubleBracket]\ $\[Delta]p1
                \[LeftDoubleBracket]1\[RightDoubleBracket]\ $\[Delta]p1
                \[LeftDoubleBracket]2\[RightDoubleBracket] + $cl
                \[LeftDoubleBracket]1\[RightDoubleBracket]\ $p1
                \[LeftDoubleBracket]2\[RightDoubleBracket]\ $p2
                \[LeftDoubleBracket]1\[RightDoubleBracket]\ $p2
                \[LeftDoubleBracket]2\[RightDoubleBracket]\ $p2
                \[LeftDoubleBracket]3\[RightDoubleBracket]\ $\[Delta]p1
                \[LeftDoubleBracket]1\[RightDoubleBracket]\ $\[Delta]p1
                \[LeftDoubleBracket]3\[RightDoubleBracket] + $cl
                \[LeftDoubleBracket]1\[RightDoubleBracket]\ $p1
                \[LeftDoubleBracket]1\[RightDoubleBracket]\ $p2
                \[LeftDoubleBracket]1\[RightDoubleBracket]\ $p2
                \[LeftDoubleBracket]2\[RightDoubleBracket]\ $p2
                \[LeftDoubleBracket]3\[RightDoubleBracket]\ $\[Delta]p1
                \[LeftDoubleBracket]2\[RightDoubleBracket]\ $\[Delta]p1
                \[LeftDoubleBracket]3\[RightDoubleBracket] + $cl
                \[LeftDoubleBracket]2\[RightDoubleBracket]\ $p2
                \[LeftDoubleBracket]1\[RightDoubleBracket]\ $p2
                \[LeftDoubleBracket]2\[RightDoubleBracket]\ $p2
                \[LeftDoubleBracket]3\[RightDoubleBracket]\ $\[Delta]p1
                \[LeftDoubleBracket]1\[RightDoubleBracket]\ $\[Delta]p1
                \[LeftDoubleBracket]2\[RightDoubleBracket]\ $\[Delta]p1
                \[LeftDoubleBracket]3\[RightDoubleBracket] + $cl
                \[LeftDoubleBracket]2\[RightDoubleBracket]\ $p1
                \[LeftDoubleBracket]2\[RightDoubleBracket]\ $p1
                \[LeftDoubleBracket]3\[RightDoubleBracket]\ $p2
                \[LeftDoubleBracket]2\[RightDoubleBracket]\ $p2
                \[LeftDoubleBracket]3\[RightDoubleBracket]\ $\[Delta]p1
                \[LeftDoubleBracket]1\[RightDoubleBracket]\ $\[Delta]p2
                \[LeftDoubleBracket]1\[RightDoubleBracket] + $cl
                \[LeftDoubleBracket]2\[RightDoubleBracket]\ $p1
                \[LeftDoubleBracket]1\[RightDoubleBracket]\ $p1
                \[LeftDoubleBracket]3\[RightDoubleBracket]\ $p2
                \[LeftDoubleBracket]2\[RightDoubleBracket]\ $p2
                \[LeftDoubleBracket]3\[RightDoubleBracket]\ $\[Delta]p1
                \[LeftDoubleBracket]2\[RightDoubleBracket]\ $\[Delta]p2
                \[LeftDoubleBracket]1\[RightDoubleBracket] + $cl
                \[LeftDoubleBracket]3\[RightDoubleBracket]\ $p1
                \[LeftDoubleBracket]3\[RightDoubleBracket]\ $p2
                \[LeftDoubleBracket]2\[RightDoubleBracket]\ $p2
                \[LeftDoubleBracket]3\[RightDoubleBracket]\ $\[Delta]p1
                \[LeftDoubleBracket]1\[RightDoubleBracket]\ $\[Delta]p1
                \[LeftDoubleBracket]2\[RightDoubleBracket]\ $\[Delta]p2
                \[LeftDoubleBracket]1\[RightDoubleBracket] + $cl
                \[LeftDoubleBracket]2\[RightDoubleBracket]\ $p1
                \[LeftDoubleBracket]1\[RightDoubleBracket]\ $p1
                \[LeftDoubleBracket]2\[RightDoubleBracket]\ $p2
                \[LeftDoubleBracket]2\[RightDoubleBracket]\ $p2
                \[LeftDoubleBracket]3\[RightDoubleBracket]\ $\[Delta]p1
                \[LeftDoubleBracket]3\[RightDoubleBracket]\ $\[Delta]p2
                \[LeftDoubleBracket]1\[RightDoubleBracket] + $cl
                \[LeftDoubleBracket]3\[RightDoubleBracket]\ $p1
                \[LeftDoubleBracket]2\[RightDoubleBracket]\ $p2
                \[LeftDoubleBracket]2\[RightDoubleBracket]\ $p2
                \[LeftDoubleBracket]3\[RightDoubleBracket]\ $\[Delta]p1
                \[LeftDoubleBracket]1\[RightDoubleBracket]\ $\[Delta]p1
                \[LeftDoubleBracket]3\[RightDoubleBracket]\ $\[Delta]p2
                \[LeftDoubleBracket]1\[RightDoubleBracket] + $cl
                \[LeftDoubleBracket]3\[RightDoubleBracket]\ $p1
                \[LeftDoubleBracket]1\[RightDoubleBracket]\ $p2
                \[LeftDoubleBracket]2\[RightDoubleBracket]\ $p2
                \[LeftDoubleBracket]3\[RightDoubleBracket]\ $\[Delta]p1
                \[LeftDoubleBracket]2\[RightDoubleBracket]\ $\[Delta]p1
                \[LeftDoubleBracket]3\[RightDoubleBracket]\ $\[Delta]p2
                \[LeftDoubleBracket]1\[RightDoubleBracket] + 
            3\ $cl\[LeftDoubleBracket]1\[RightDoubleBracket]\ $cl
                \[LeftDoubleBracket]2\[RightDoubleBracket]\ $p2
                \[LeftDoubleBracket]2\[RightDoubleBracket]\ $p2
                \[LeftDoubleBracket]3\[RightDoubleBracket]\ $\[Delta]p1
                \[LeftDoubleBracket]1\[RightDoubleBracket]\ $\[Delta]p1
                \[LeftDoubleBracket]2\[RightDoubleBracket]\ $\[Delta]p1
                \[LeftDoubleBracket]3\[RightDoubleBracket]\ $\[Delta]p2
                \[LeftDoubleBracket]1\[RightDoubleBracket] + $cl
                \[LeftDoubleBracket]4\[RightDoubleBracket]\ $p2
                \[LeftDoubleBracket]2\[RightDoubleBracket]\ $p2
                \[LeftDoubleBracket]3\[RightDoubleBracket]\ $\[Delta]p1
                \[LeftDoubleBracket]1\[RightDoubleBracket]\ $\[Delta]p1
                \[LeftDoubleBracket]2\[RightDoubleBracket]\ $\[Delta]p1
                \[LeftDoubleBracket]3\[RightDoubleBracket]\ $\[Delta]p2
                \[LeftDoubleBracket]1\[RightDoubleBracket] + $cl
                \[LeftDoubleBracket]2\[RightDoubleBracket]\ $p1
                \[LeftDoubleBracket]2\[RightDoubleBracket]\ $p1
                \[LeftDoubleBracket]3\[RightDoubleBracket]\ $p2
                \[LeftDoubleBracket]1\[RightDoubleBracket]\ $p2
                \[LeftDoubleBracket]3\[RightDoubleBracket]\ $\[Delta]p1
                \[LeftDoubleBracket]1\[RightDoubleBracket]\ $\[Delta]p2
                \[LeftDoubleBracket]2\[RightDoubleBracket] + $cl
                \[LeftDoubleBracket]2\[RightDoubleBracket]\ $p1
                \[LeftDoubleBracket]1\[RightDoubleBracket]\ $p1
                \[LeftDoubleBracket]3\[RightDoubleBracket]\ $p2
                \[LeftDoubleBracket]1\[RightDoubleBracket]\ $p2
                \[LeftDoubleBracket]3\[RightDoubleBracket]\ $\[Delta]p1
                \[LeftDoubleBracket]2\[RightDoubleBracket]\ $\[Delta]p2
                \[LeftDoubleBracket]2\[RightDoubleBracket] + $cl
                \[LeftDoubleBracket]3\[RightDoubleBracket]\ $p1
                \[LeftDoubleBracket]3\[RightDoubleBracket]\ $p2
                \[LeftDoubleBracket]1\[RightDoubleBracket]\ $p2
                \[LeftDoubleBracket]3\[RightDoubleBracket]\ $\[Delta]p1
                \[LeftDoubleBracket]1\[RightDoubleBracket]\ $\[Delta]p1
                \[LeftDoubleBracket]2\[RightDoubleBracket]\ $\[Delta]p2
                \[LeftDoubleBracket]2\[RightDoubleBracket] + $cl
                \[LeftDoubleBracket]2\[RightDoubleBracket]\ $p1
                \[LeftDoubleBracket]1\[RightDoubleBracket]\ $p1
                \[LeftDoubleBracket]2\[RightDoubleBracket]\ $p2
                \[LeftDoubleBracket]1\[RightDoubleBracket]\ $p2
                \[LeftDoubleBracket]3\[RightDoubleBracket]\ $\[Delta]p1
                \[LeftDoubleBracket]3\[RightDoubleBracket]\ $\[Delta]p2
                \[LeftDoubleBracket]2\[RightDoubleBracket] + $cl
                \[LeftDoubleBracket]3\[RightDoubleBracket]\ $p1
                \[LeftDoubleBracket]2\[RightDoubleBracket]\ $p2
                \[LeftDoubleBracket]1\[RightDoubleBracket]\ $p2
                \[LeftDoubleBracket]3\[RightDoubleBracket]\ $\[Delta]p1
                \[LeftDoubleBracket]1\[RightDoubleBracket]\ $\[Delta]p1
                \[LeftDoubleBracket]3\[RightDoubleBracket]\ $\[Delta]p2
                \[LeftDoubleBracket]2\[RightDoubleBracket] + $cl
                \[LeftDoubleBracket]3\[RightDoubleBracket]\ $p1
                \[LeftDoubleBracket]1\[RightDoubleBracket]\ $p2
                \[LeftDoubleBracket]1\[RightDoubleBracket]\ $p2
                \[LeftDoubleBracket]3\[RightDoubleBracket]\ $\[Delta]p1
                \[LeftDoubleBracket]2\[RightDoubleBracket]\ $\[Delta]p1
                \[LeftDoubleBracket]3\[RightDoubleBracket]\ $\[Delta]p2
                \[LeftDoubleBracket]2\[RightDoubleBracket] + 
            3\ $cl\[LeftDoubleBracket]1\[RightDoubleBracket]\ $cl
                \[LeftDoubleBracket]2\[RightDoubleBracket]\ $p2
                \[LeftDoubleBracket]1\[RightDoubleBracket]\ $p2
                \[LeftDoubleBracket]3\[RightDoubleBracket]\ $\[Delta]p1
                \[LeftDoubleBracket]1\[RightDoubleBracket]\ $\[Delta]p1
                \[LeftDoubleBracket]2\[RightDoubleBracket]\ $\[Delta]p1
                \[LeftDoubleBracket]3\[RightDoubleBracket]\ $\[Delta]p2
                \[LeftDoubleBracket]2\[RightDoubleBracket] + $cl
                \[LeftDoubleBracket]4\[RightDoubleBracket]\ $p2
                \[LeftDoubleBracket]1\[RightDoubleBracket]\ $p2
                \[LeftDoubleBracket]3\[RightDoubleBracket]\ $\[Delta]p1
                \[LeftDoubleBracket]1\[RightDoubleBracket]\ $\[Delta]p1
                \[LeftDoubleBracket]2\[RightDoubleBracket]\ $\[Delta]p1
                \[LeftDoubleBracket]3\[RightDoubleBracket]\ $\[Delta]p2
                \[LeftDoubleBracket]2\[RightDoubleBracket] + $cl
                \[LeftDoubleBracket]1\[RightDoubleBracket]\ $p1
                \[LeftDoubleBracket]1\[RightDoubleBracket]\ $p1
                \[LeftDoubleBracket]2\[RightDoubleBracket]\ $p1
                \[LeftDoubleBracket]3\[RightDoubleBracket]\ $p2
                \[LeftDoubleBracket]3\[RightDoubleBracket]\ $\[Delta]p2
                \[LeftDoubleBracket]1\[RightDoubleBracket]\ $\[Delta]p2
                \[LeftDoubleBracket]2\[RightDoubleBracket] + $cl
                \[LeftDoubleBracket]3\[RightDoubleBracket]\ $p1
                \[LeftDoubleBracket]2\[RightDoubleBracket]\ $p1
                \[LeftDoubleBracket]3\[RightDoubleBracket]\ $p2
                \[LeftDoubleBracket]3\[RightDoubleBracket]\ $\[Delta]p1
                \[LeftDoubleBracket]1\[RightDoubleBracket]\ $\[Delta]p2
                \[LeftDoubleBracket]1\[RightDoubleBracket]\ $\[Delta]p2
                \[LeftDoubleBracket]2\[RightDoubleBracket] + $cl
                \[LeftDoubleBracket]3\[RightDoubleBracket]\ $p1
                \[LeftDoubleBracket]1\[RightDoubleBracket]\ $p1
                \[LeftDoubleBracket]3\[RightDoubleBracket]\ $p2
                \[LeftDoubleBracket]3\[RightDoubleBracket]\ $\[Delta]p1
                \[LeftDoubleBracket]2\[RightDoubleBracket]\ $\[Delta]p2
                \[LeftDoubleBracket]1\[RightDoubleBracket]\ $\[Delta]p2
                \[LeftDoubleBracket]2
                \[RightDoubleBracket] + $cl\[LeftDoubleBracket]1
                  \[RightDoubleBracket]\^2\ $p1\[LeftDoubleBracket]3
                \[RightDoubleBracket]\ $p2\[LeftDoubleBracket]3
                \[RightDoubleBracket]\ $\[Delta]p1\[LeftDoubleBracket]1
                \[RightDoubleBracket]\ $\[Delta]p1\[LeftDoubleBracket]2
                \[RightDoubleBracket]\ $\[Delta]p2\[LeftDoubleBracket]1
                \[RightDoubleBracket]\ $\[Delta]p2\[LeftDoubleBracket]2
                \[RightDoubleBracket] + 
            2\ $cl\[LeftDoubleBracket]2\[RightDoubleBracket]\^2\ $p1
                \[LeftDoubleBracket]3\[RightDoubleBracket]\ $p2
                \[LeftDoubleBracket]3\[RightDoubleBracket]\ $\[Delta]p1
                \[LeftDoubleBracket]1\[RightDoubleBracket]\ $\[Delta]p1
                \[LeftDoubleBracket]2\[RightDoubleBracket]\ $\[Delta]p2
                \[LeftDoubleBracket]1\[RightDoubleBracket]\ $\[Delta]p2
                \[LeftDoubleBracket]2\[RightDoubleBracket] + $cl
                \[LeftDoubleBracket]4\[RightDoubleBracket]\ $p1
                \[LeftDoubleBracket]3\[RightDoubleBracket]\ $p2
                \[LeftDoubleBracket]3\[RightDoubleBracket]\ $\[Delta]p1
                \[LeftDoubleBracket]1\[RightDoubleBracket]\ $\[Delta]p1
                \[LeftDoubleBracket]2\[RightDoubleBracket]\ $\[Delta]p2
                \[LeftDoubleBracket]1\[RightDoubleBracket]\ $\[Delta]p2
                \[LeftDoubleBracket]2\[RightDoubleBracket] + $cl
                \[LeftDoubleBracket]3\[RightDoubleBracket]\ $p1
                \[LeftDoubleBracket]1\[RightDoubleBracket]\ $p1
                \[LeftDoubleBracket]2\[RightDoubleBracket]\ $p2
                \[LeftDoubleBracket]3\[RightDoubleBracket]\ $\[Delta]p1
                \[LeftDoubleBracket]3\[RightDoubleBracket]\ $\[Delta]p2
                \[LeftDoubleBracket]1\[RightDoubleBracket]\ $\[Delta]p2
                \[LeftDoubleBracket]2
                \[RightDoubleBracket] + $cl\[LeftDoubleBracket]1
                  \[RightDoubleBracket]\^2\ $p1\[LeftDoubleBracket]2
                \[RightDoubleBracket]\ $p2\[LeftDoubleBracket]3
                \[RightDoubleBracket]\ $\[Delta]p1\[LeftDoubleBracket]1
                \[RightDoubleBracket]\ $\[Delta]p1\[LeftDoubleBracket]3
                \[RightDoubleBracket]\ $\[Delta]p2\[LeftDoubleBracket]1
                \[RightDoubleBracket]\ $\[Delta]p2\[LeftDoubleBracket]2
                \[RightDoubleBracket] + 
            2\ $cl\[LeftDoubleBracket]2\[RightDoubleBracket]\^2\ $p1
                \[LeftDoubleBracket]2\[RightDoubleBracket]\ $p2
                \[LeftDoubleBracket]3\[RightDoubleBracket]\ $\[Delta]p1
                \[LeftDoubleBracket]1\[RightDoubleBracket]\ $\[Delta]p1
                \[LeftDoubleBracket]3\[RightDoubleBracket]\ $\[Delta]p2
                \[LeftDoubleBracket]1\[RightDoubleBracket]\ $\[Delta]p2
                \[LeftDoubleBracket]2\[RightDoubleBracket] + $cl
                \[LeftDoubleBracket]4\[RightDoubleBracket]\ $p1
                \[LeftDoubleBracket]2\[RightDoubleBracket]\ $p2
                \[LeftDoubleBracket]3\[RightDoubleBracket]\ $\[Delta]p1
                \[LeftDoubleBracket]1\[RightDoubleBracket]\ $\[Delta]p1
                \[LeftDoubleBracket]3\[RightDoubleBracket]\ $\[Delta]p2
                \[LeftDoubleBracket]1\[RightDoubleBracket]\ $\[Delta]p2
                \[LeftDoubleBracket]2
                \[RightDoubleBracket] + $cl\[LeftDoubleBracket]1
                  \[RightDoubleBracket]\^2\ $p1\[LeftDoubleBracket]1
                \[RightDoubleBracket]\ $p2\[LeftDoubleBracket]3
                \[RightDoubleBracket]\ $\[Delta]p1\[LeftDoubleBracket]2
                \[RightDoubleBracket]\ $\[Delta]p1\[LeftDoubleBracket]3
                \[RightDoubleBracket]\ $\[Delta]p2\[LeftDoubleBracket]1
                \[RightDoubleBracket]\ $\[Delta]p2\[LeftDoubleBracket]2
                \[RightDoubleBracket] + 
            2\ $cl\[LeftDoubleBracket]2\[RightDoubleBracket]\^2\ $p1
                \[LeftDoubleBracket]1\[RightDoubleBracket]\ $p2
                \[LeftDoubleBracket]3\[RightDoubleBracket]\ $\[Delta]p1
                \[LeftDoubleBracket]2\[RightDoubleBracket]\ $\[Delta]p1
                \[LeftDoubleBracket]3\[RightDoubleBracket]\ $\[Delta]p2
                \[LeftDoubleBracket]1\[RightDoubleBracket]\ $\[Delta]p2
                \[LeftDoubleBracket]2\[RightDoubleBracket] + $cl
                \[LeftDoubleBracket]4\[RightDoubleBracket]\ $p1
                \[LeftDoubleBracket]1\[RightDoubleBracket]\ $p2
                \[LeftDoubleBracket]3\[RightDoubleBracket]\ $\[Delta]p1
                \[LeftDoubleBracket]2\[RightDoubleBracket]\ $\[Delta]p1
                \[LeftDoubleBracket]3\[RightDoubleBracket]\ $\[Delta]p2
                \[LeftDoubleBracket]1\[RightDoubleBracket]\ $\[Delta]p2
                \[LeftDoubleBracket]2\[RightDoubleBracket] + $cl
                \[LeftDoubleBracket]1\[RightDoubleBracket]\ $cl
                \[LeftDoubleBracket]2\[RightDoubleBracket]\ $p2
                \[LeftDoubleBracket]3\[RightDoubleBracket]\ $\[Delta]p1
                \[LeftDoubleBracket]1\[RightDoubleBracket]\ $\[Delta]p1
                \[LeftDoubleBracket]2\[RightDoubleBracket]\ $\[Delta]p1
                \[LeftDoubleBracket]3\[RightDoubleBracket]\ $\[Delta]p2
                \[LeftDoubleBracket]1\[RightDoubleBracket]\ $\[Delta]p2
                \[LeftDoubleBracket]2\[RightDoubleBracket] + 
            3\ $cl\[LeftDoubleBracket]1\[RightDoubleBracket]\ $cl
                \[LeftDoubleBracket]3\[RightDoubleBracket]\ $p2
                \[LeftDoubleBracket]3\[RightDoubleBracket]\ $\[Delta]p1
                \[LeftDoubleBracket]1\[RightDoubleBracket]\ $\[Delta]p1
                \[LeftDoubleBracket]2\[RightDoubleBracket]\ $\[Delta]p1
                \[LeftDoubleBracket]3\[RightDoubleBracket]\ $\[Delta]p2
                \[LeftDoubleBracket]1\[RightDoubleBracket]\ $\[Delta]p2
                \[LeftDoubleBracket]2\[RightDoubleBracket] + 
            6\ $cl\[LeftDoubleBracket]2\[RightDoubleBracket]\ $cl
                \[LeftDoubleBracket]3\[RightDoubleBracket]\ $p2
                \[LeftDoubleBracket]3\[RightDoubleBracket]\ $\[Delta]p1
                \[LeftDoubleBracket]1\[RightDoubleBracket]\ $\[Delta]p1
                \[LeftDoubleBracket]2\[RightDoubleBracket]\ $\[Delta]p1
                \[LeftDoubleBracket]3\[RightDoubleBracket]\ $\[Delta]p2
                \[LeftDoubleBracket]1\[RightDoubleBracket]\ $\[Delta]p2
                \[LeftDoubleBracket]2\[RightDoubleBracket] + $cl
                \[LeftDoubleBracket]5\[RightDoubleBracket]\ $p2
                \[LeftDoubleBracket]3\[RightDoubleBracket]\ $\[Delta]p1
                \[LeftDoubleBracket]1\[RightDoubleBracket]\ $\[Delta]p1
                \[LeftDoubleBracket]2\[RightDoubleBracket]\ $\[Delta]p1
                \[LeftDoubleBracket]3\[RightDoubleBracket]\ $\[Delta]p2
                \[LeftDoubleBracket]1\[RightDoubleBracket]\ $\[Delta]p2
                \[LeftDoubleBracket]2\[RightDoubleBracket] + $cl
                \[LeftDoubleBracket]2\[RightDoubleBracket]\ $p1
                \[LeftDoubleBracket]2\[RightDoubleBracket]\ $p1
                \[LeftDoubleBracket]3\[RightDoubleBracket]\ $p2
                \[LeftDoubleBracket]1\[RightDoubleBracket]\ $p2
                \[LeftDoubleBracket]2\[RightDoubleBracket]\ $\[Delta]p1
                \[LeftDoubleBracket]1\[RightDoubleBracket]\ $\[Delta]p2
                \[LeftDoubleBracket]3\[RightDoubleBracket] + $cl
                \[LeftDoubleBracket]2\[RightDoubleBracket]\ $p1
                \[LeftDoubleBracket]1\[RightDoubleBracket]\ $p1
                \[LeftDoubleBracket]3\[RightDoubleBracket]\ $p2
                \[LeftDoubleBracket]1\[RightDoubleBracket]\ $p2
                \[LeftDoubleBracket]2\[RightDoubleBracket]\ $\[Delta]p1
                \[LeftDoubleBracket]2\[RightDoubleBracket]\ $\[Delta]p2
                \[LeftDoubleBracket]3\[RightDoubleBracket] + $cl
                \[LeftDoubleBracket]3\[RightDoubleBracket]\ $p1
                \[LeftDoubleBracket]3\[RightDoubleBracket]\ $p2
                \[LeftDoubleBracket]1\[RightDoubleBracket]\ $p2
                \[LeftDoubleBracket]2\[RightDoubleBracket]\ $\[Delta]p1
                \[LeftDoubleBracket]1\[RightDoubleBracket]\ $\[Delta]p1
                \[LeftDoubleBracket]2\[RightDoubleBracket]\ $\[Delta]p2
                \[LeftDoubleBracket]3\[RightDoubleBracket] + $cl
                \[LeftDoubleBracket]2\[RightDoubleBracket]\ $p1
                \[LeftDoubleBracket]1\[RightDoubleBracket]\ $p1
                \[LeftDoubleBracket]2\[RightDoubleBracket]\ $p2
                \[LeftDoubleBracket]1\[RightDoubleBracket]\ $p2
                \[LeftDoubleBracket]2\[RightDoubleBracket]\ $\[Delta]p1
                \[LeftDoubleBracket]3\[RightDoubleBracket]\ $\[Delta]p2
                \[LeftDoubleBracket]3\[RightDoubleBracket] + $cl
                \[LeftDoubleBracket]3\[RightDoubleBracket]\ $p1
                \[LeftDoubleBracket]2\[RightDoubleBracket]\ $p2
                \[LeftDoubleBracket]1\[RightDoubleBracket]\ $p2
                \[LeftDoubleBracket]2\[RightDoubleBracket]\ $\[Delta]p1
                \[LeftDoubleBracket]1\[RightDoubleBracket]\ $\[Delta]p1
                \[LeftDoubleBracket]3\[RightDoubleBracket]\ $\[Delta]p2
                \[LeftDoubleBracket]3\[RightDoubleBracket] + $cl
                \[LeftDoubleBracket]3\[RightDoubleBracket]\ $p1
                \[LeftDoubleBracket]1\[RightDoubleBracket]\ $p2
                \[LeftDoubleBracket]1\[RightDoubleBracket]\ $p2
                \[LeftDoubleBracket]2\[RightDoubleBracket]\ $\[Delta]p1
                \[LeftDoubleBracket]2\[RightDoubleBracket]\ $\[Delta]p1
                \[LeftDoubleBracket]3\[RightDoubleBracket]\ $\[Delta]p2
                \[LeftDoubleBracket]3\[RightDoubleBracket] + 
            3\ $cl\[LeftDoubleBracket]1\[RightDoubleBracket]\ $cl
                \[LeftDoubleBracket]2\[RightDoubleBracket]\ $p2
                \[LeftDoubleBracket]1\[RightDoubleBracket]\ $p2
                \[LeftDoubleBracket]2\[RightDoubleBracket]\ $\[Delta]p1
                \[LeftDoubleBracket]1\[RightDoubleBracket]\ $\[Delta]p1
                \[LeftDoubleBracket]2\[RightDoubleBracket]\ $\[Delta]p1
                \[LeftDoubleBracket]3\[RightDoubleBracket]\ $\[Delta]p2
                \[LeftDoubleBracket]3\[RightDoubleBracket] + $cl
                \[LeftDoubleBracket]4\[RightDoubleBracket]\ $p2
                \[LeftDoubleBracket]1\[RightDoubleBracket]\ $p2
                \[LeftDoubleBracket]2\[RightDoubleBracket]\ $\[Delta]p1
                \[LeftDoubleBracket]1\[RightDoubleBracket]\ $\[Delta]p1
                \[LeftDoubleBracket]2\[RightDoubleBracket]\ $\[Delta]p1
                \[LeftDoubleBracket]3\[RightDoubleBracket]\ $\[Delta]p2
                \[LeftDoubleBracket]3\[RightDoubleBracket] + $cl
                \[LeftDoubleBracket]1\[RightDoubleBracket]\ $p1
                \[LeftDoubleBracket]1\[RightDoubleBracket]\ $p1
                \[LeftDoubleBracket]2\[RightDoubleBracket]\ $p1
                \[LeftDoubleBracket]3\[RightDoubleBracket]\ $p2
                \[LeftDoubleBracket]2\[RightDoubleBracket]\ $\[Delta]p2
                \[LeftDoubleBracket]1\[RightDoubleBracket]\ $\[Delta]p2
                \[LeftDoubleBracket]3\[RightDoubleBracket] + $cl
                \[LeftDoubleBracket]3\[RightDoubleBracket]\ $p1
                \[LeftDoubleBracket]2\[RightDoubleBracket]\ $p1
                \[LeftDoubleBracket]3\[RightDoubleBracket]\ $p2
                \[LeftDoubleBracket]2\[RightDoubleBracket]\ $\[Delta]p1
                \[LeftDoubleBracket]1\[RightDoubleBracket]\ $\[Delta]p2
                \[LeftDoubleBracket]1\[RightDoubleBracket]\ $\[Delta]p2
                \[LeftDoubleBracket]3\[RightDoubleBracket] + $cl
                \[LeftDoubleBracket]3\[RightDoubleBracket]\ $p1
                \[LeftDoubleBracket]1\[RightDoubleBracket]\ $p1
                \[LeftDoubleBracket]3\[RightDoubleBracket]\ $p2
                \[LeftDoubleBracket]2\[RightDoubleBracket]\ $\[Delta]p1
                \[LeftDoubleBracket]2\[RightDoubleBracket]\ $\[Delta]p2
                \[LeftDoubleBracket]1\[RightDoubleBracket]\ $\[Delta]p2
                \[LeftDoubleBracket]3
                \[RightDoubleBracket] + $cl\[LeftDoubleBracket]1
                  \[RightDoubleBracket]\^2\ $p1\[LeftDoubleBracket]3
                \[RightDoubleBracket]\ $p2\[LeftDoubleBracket]2
                \[RightDoubleBracket]\ $\[Delta]p1\[LeftDoubleBracket]1
                \[RightDoubleBracket]\ $\[Delta]p1\[LeftDoubleBracket]2
                \[RightDoubleBracket]\ $\[Delta]p2\[LeftDoubleBracket]1
                \[RightDoubleBracket]\ $\[Delta]p2\[LeftDoubleBracket]3
                \[RightDoubleBracket] + 
            2\ $cl\[LeftDoubleBracket]2\[RightDoubleBracket]\^2\ $p1
                \[LeftDoubleBracket]3\[RightDoubleBracket]\ $p2
                \[LeftDoubleBracket]2\[RightDoubleBracket]\ $\[Delta]p1
                \[LeftDoubleBracket]1\[RightDoubleBracket]\ $\[Delta]p1
                \[LeftDoubleBracket]2\[RightDoubleBracket]\ $\[Delta]p2
                \[LeftDoubleBracket]1\[RightDoubleBracket]\ $\[Delta]p2
                \[LeftDoubleBracket]3\[RightDoubleBracket] + $cl
                \[LeftDoubleBracket]4\[RightDoubleBracket]\ $p1
                \[LeftDoubleBracket]3\[RightDoubleBracket]\ $p2
                \[LeftDoubleBracket]2\[RightDoubleBracket]\ $\[Delta]p1
                \[LeftDoubleBracket]1\[RightDoubleBracket]\ $\[Delta]p1
                \[LeftDoubleBracket]2\[RightDoubleBracket]\ $\[Delta]p2
                \[LeftDoubleBracket]1\[RightDoubleBracket]\ $\[Delta]p2
                \[LeftDoubleBracket]3\[RightDoubleBracket] + $cl
                \[LeftDoubleBracket]3\[RightDoubleBracket]\ $p1
                \[LeftDoubleBracket]1\[RightDoubleBracket]\ $p1
                \[LeftDoubleBracket]2\[RightDoubleBracket]\ $p2
                \[LeftDoubleBracket]2\[RightDoubleBracket]\ $\[Delta]p1
                \[LeftDoubleBracket]3\[RightDoubleBracket]\ $\[Delta]p2
                \[LeftDoubleBracket]1\[RightDoubleBracket]\ $\[Delta]p2
                \[LeftDoubleBracket]3
                \[RightDoubleBracket] + $cl\[LeftDoubleBracket]1
                  \[RightDoubleBracket]\^2\ $p1\[LeftDoubleBracket]2
                \[RightDoubleBracket]\ $p2\[LeftDoubleBracket]2
                \[RightDoubleBracket]\ $\[Delta]p1\[LeftDoubleBracket]1
                \[RightDoubleBracket]\ $\[Delta]p1\[LeftDoubleBracket]3
                \[RightDoubleBracket]\ $\[Delta]p2\[LeftDoubleBracket]1
                \[RightDoubleBracket]\ $\[Delta]p2\[LeftDoubleBracket]3
                \[RightDoubleBracket] + 
            2\ $cl\[LeftDoubleBracket]2\[RightDoubleBracket]\^2\ $p1
                \[LeftDoubleBracket]2\[RightDoubleBracket]\ $p2
                \[LeftDoubleBracket]2\[RightDoubleBracket]\ $\[Delta]p1
                \[LeftDoubleBracket]1\[RightDoubleBracket]\ $\[Delta]p1
                \[LeftDoubleBracket]3\[RightDoubleBracket]\ $\[Delta]p2
                \[LeftDoubleBracket]1\[RightDoubleBracket]\ $\[Delta]p2
                \[LeftDoubleBracket]3\[RightDoubleBracket] + $cl
                \[LeftDoubleBracket]4\[RightDoubleBracket]\ $p1
                \[LeftDoubleBracket]2\[RightDoubleBracket]\ $p2
                \[LeftDoubleBracket]2\[RightDoubleBracket]\ $\[Delta]p1
                \[LeftDoubleBracket]1\[RightDoubleBracket]\ $\[Delta]p1
                \[LeftDoubleBracket]3\[RightDoubleBracket]\ $\[Delta]p2
                \[LeftDoubleBracket]1\[RightDoubleBracket]\ $\[Delta]p2
                \[LeftDoubleBracket]3
                \[RightDoubleBracket] + $cl\[LeftDoubleBracket]1
                  \[RightDoubleBracket]\^2\ $p1\[LeftDoubleBracket]1
                \[RightDoubleBracket]\ $p2\[LeftDoubleBracket]2
                \[RightDoubleBracket]\ $\[Delta]p1\[LeftDoubleBracket]2
                \[RightDoubleBracket]\ $\[Delta]p1\[LeftDoubleBracket]3
                \[RightDoubleBracket]\ $\[Delta]p2\[LeftDoubleBracket]1
                \[RightDoubleBracket]\ $\[Delta]p2\[LeftDoubleBracket]3
                \[RightDoubleBracket] + 
            2\ $cl\[LeftDoubleBracket]2\[RightDoubleBracket]\^2\ $p1
                \[LeftDoubleBracket]1\[RightDoubleBracket]\ $p2
                \[LeftDoubleBracket]2\[RightDoubleBracket]\ $\[Delta]p1
                \[LeftDoubleBracket]2\[RightDoubleBracket]\ $\[Delta]p1
                \[LeftDoubleBracket]3\[RightDoubleBracket]\ $\[Delta]p2
                \[LeftDoubleBracket]1\[RightDoubleBracket]\ $\[Delta]p2
                \[LeftDoubleBracket]3\[RightDoubleBracket] + $cl
                \[LeftDoubleBracket]4\[RightDoubleBracket]\ $p1
                \[LeftDoubleBracket]1\[RightDoubleBracket]\ $p2
                \[LeftDoubleBracket]2\[RightDoubleBracket]\ $\[Delta]p1
                \[LeftDoubleBracket]2\[RightDoubleBracket]\ $\[Delta]p1
                \[LeftDoubleBracket]3\[RightDoubleBracket]\ $\[Delta]p2
                \[LeftDoubleBracket]1\[RightDoubleBracket]\ $\[Delta]p2
                \[LeftDoubleBracket]3\[RightDoubleBracket] + $cl
                \[LeftDoubleBracket]1\[RightDoubleBracket]\ $cl
                \[LeftDoubleBracket]2\[RightDoubleBracket]\ $p2
                \[LeftDoubleBracket]2\[RightDoubleBracket]\ $\[Delta]p1
                \[LeftDoubleBracket]1\[RightDoubleBracket]\ $\[Delta]p1
                \[LeftDoubleBracket]2\[RightDoubleBracket]\ $\[Delta]p1
                \[LeftDoubleBracket]3\[RightDoubleBracket]\ $\[Delta]p2
                \[LeftDoubleBracket]1\[RightDoubleBracket]\ $\[Delta]p2
                \[LeftDoubleBracket]3\[RightDoubleBracket] + 
            3\ $cl\[LeftDoubleBracket]1\[RightDoubleBracket]\ $cl
                \[LeftDoubleBracket]3\[RightDoubleBracket]\ $p2
                \[LeftDoubleBracket]2\[RightDoubleBracket]\ $\[Delta]p1
                \[LeftDoubleBracket]1\[RightDoubleBracket]\ $\[Delta]p1
                \[LeftDoubleBracket]2\[RightDoubleBracket]\ $\[Delta]p1
                \[LeftDoubleBracket]3\[RightDoubleBracket]\ $\[Delta]p2
                \[LeftDoubleBracket]1\[RightDoubleBracket]\ $\[Delta]p2
                \[LeftDoubleBracket]3\[RightDoubleBracket] + 
            6\ $cl\[LeftDoubleBracket]2\[RightDoubleBracket]\ $cl
                \[LeftDoubleBracket]3\[RightDoubleBracket]\ $p2
                \[LeftDoubleBracket]2\[RightDoubleBracket]\ $\[Delta]p1
                \[LeftDoubleBracket]1\[RightDoubleBracket]\ $\[Delta]p1
                \[LeftDoubleBracket]2\[RightDoubleBracket]\ $\[Delta]p1
                \[LeftDoubleBracket]3\[RightDoubleBracket]\ $\[Delta]p2
                \[LeftDoubleBracket]1\[RightDoubleBracket]\ $\[Delta]p2
                \[LeftDoubleBracket]3\[RightDoubleBracket] + $cl
                \[LeftDoubleBracket]5\[RightDoubleBracket]\ $p2
                \[LeftDoubleBracket]2\[RightDoubleBracket]\ $\[Delta]p1
                \[LeftDoubleBracket]1\[RightDoubleBracket]\ $\[Delta]p1
                \[LeftDoubleBracket]2\[RightDoubleBracket]\ $\[Delta]p1
                \[LeftDoubleBracket]3\[RightDoubleBracket]\ $\[Delta]p2
                \[LeftDoubleBracket]1\[RightDoubleBracket]\ $\[Delta]p2
                \[LeftDoubleBracket]3\[RightDoubleBracket] + $cl
                \[LeftDoubleBracket]1\[RightDoubleBracket]\ $p1
                \[LeftDoubleBracket]1\[RightDoubleBracket]\ $p1
                \[LeftDoubleBracket]2\[RightDoubleBracket]\ $p1
                \[LeftDoubleBracket]3\[RightDoubleBracket]\ $p2
                \[LeftDoubleBracket]1\[RightDoubleBracket]\ $\[Delta]p2
                \[LeftDoubleBracket]2\[RightDoubleBracket]\ $\[Delta]p2
                \[LeftDoubleBracket]3\[RightDoubleBracket] + $cl
                \[LeftDoubleBracket]3\[RightDoubleBracket]\ $p1
                \[LeftDoubleBracket]2\[RightDoubleBracket]\ $p1
                \[LeftDoubleBracket]3\[RightDoubleBracket]\ $p2
                \[LeftDoubleBracket]1\[RightDoubleBracket]\ $\[Delta]p1
                \[LeftDoubleBracket]1\[RightDoubleBracket]\ $\[Delta]p2
                \[LeftDoubleBracket]2\[RightDoubleBracket]\ $\[Delta]p2
                \[LeftDoubleBracket]3\[RightDoubleBracket] + $cl
                \[LeftDoubleBracket]3\[RightDoubleBracket]\ $p1
                \[LeftDoubleBracket]1\[RightDoubleBracket]\ $p1
                \[LeftDoubleBracket]3\[RightDoubleBracket]\ $p2
                \[LeftDoubleBracket]1\[RightDoubleBracket]\ $\[Delta]p1
                \[LeftDoubleBracket]2\[RightDoubleBracket]\ $\[Delta]p2
                \[LeftDoubleBracket]2\[RightDoubleBracket]\ $\[Delta]p2
                \[LeftDoubleBracket]3
                \[RightDoubleBracket] + $cl\[LeftDoubleBracket]1
                  \[RightDoubleBracket]\^2\ $p1\[LeftDoubleBracket]3
                \[RightDoubleBracket]\ $p2\[LeftDoubleBracket]1
                \[RightDoubleBracket]\ $\[Delta]p1\[LeftDoubleBracket]1
                \[RightDoubleBracket]\ $\[Delta]p1\[LeftDoubleBracket]2
                \[RightDoubleBracket]\ $\[Delta]p2\[LeftDoubleBracket]2
                \[RightDoubleBracket]\ $\[Delta]p2\[LeftDoubleBracket]3
                \[RightDoubleBracket] + 
            2\ $cl\[LeftDoubleBracket]2\[RightDoubleBracket]\^2\ $p1
                \[LeftDoubleBracket]3\[RightDoubleBracket]\ $p2
                \[LeftDoubleBracket]1\[RightDoubleBracket]\ $\[Delta]p1
                \[LeftDoubleBracket]1\[RightDoubleBracket]\ $\[Delta]p1
                \[LeftDoubleBracket]2\[RightDoubleBracket]\ $\[Delta]p2
                \[LeftDoubleBracket]2\[RightDoubleBracket]\ $\[Delta]p2
                \[LeftDoubleBracket]3\[RightDoubleBracket] + $cl
                \[LeftDoubleBracket]4\[RightDoubleBracket]\ $p1
                \[LeftDoubleBracket]3\[RightDoubleBracket]\ $p2
                \[LeftDoubleBracket]1\[RightDoubleBracket]\ $\[Delta]p1
                \[LeftDoubleBracket]1\[RightDoubleBracket]\ $\[Delta]p1
                \[LeftDoubleBracket]2\[RightDoubleBracket]\ $\[Delta]p2
                \[LeftDoubleBracket]2\[RightDoubleBracket]\ $\[Delta]p2
                \[LeftDoubleBracket]3\[RightDoubleBracket] + $cl
                \[LeftDoubleBracket]3\[RightDoubleBracket]\ $p1
                \[LeftDoubleBracket]1\[RightDoubleBracket]\ $p1
                \[LeftDoubleBracket]2\[RightDoubleBracket]\ $p2
                \[LeftDoubleBracket]1\[RightDoubleBracket]\ $\[Delta]p1
                \[LeftDoubleBracket]3\[RightDoubleBracket]\ $\[Delta]p2
                \[LeftDoubleBracket]2\[RightDoubleBracket]\ $\[Delta]p2
                \[LeftDoubleBracket]3
                \[RightDoubleBracket] + $cl\[LeftDoubleBracket]1
                  \[RightDoubleBracket]\^2\ $p1\[LeftDoubleBracket]2
                \[RightDoubleBracket]\ $p2\[LeftDoubleBracket]1
                \[RightDoubleBracket]\ $\[Delta]p1\[LeftDoubleBracket]1
                \[RightDoubleBracket]\ $\[Delta]p1\[LeftDoubleBracket]3
                \[RightDoubleBracket]\ $\[Delta]p2\[LeftDoubleBracket]2
                \[RightDoubleBracket]\ $\[Delta]p2\[LeftDoubleBracket]3
                \[RightDoubleBracket] + 
            2\ $cl\[LeftDoubleBracket]2\[RightDoubleBracket]\^2\ $p1
                \[LeftDoubleBracket]2\[RightDoubleBracket]\ $p2
                \[LeftDoubleBracket]1\[RightDoubleBracket]\ $\[Delta]p1
                \[LeftDoubleBracket]1\[RightDoubleBracket]\ $\[Delta]p1
                \[LeftDoubleBracket]3\[RightDoubleBracket]\ $\[Delta]p2
                \[LeftDoubleBracket]2\[RightDoubleBracket]\ $\[Delta]p2
                \[LeftDoubleBracket]3\[RightDoubleBracket] + $cl
                \[LeftDoubleBracket]4\[RightDoubleBracket]\ $p1
                \[LeftDoubleBracket]2\[RightDoubleBracket]\ $p2
                \[LeftDoubleBracket]1\[RightDoubleBracket]\ $\[Delta]p1
                \[LeftDoubleBracket]1\[RightDoubleBracket]\ $\[Delta]p1
                \[LeftDoubleBracket]3\[RightDoubleBracket]\ $\[Delta]p2
                \[LeftDoubleBracket]2\[RightDoubleBracket]\ $\[Delta]p2
                \[LeftDoubleBracket]3
                \[RightDoubleBracket] + $cl\[LeftDoubleBracket]1
                  \[RightDoubleBracket]\^2\ $p1\[LeftDoubleBracket]1
                \[RightDoubleBracket]\ $p2\[LeftDoubleBracket]1
                \[RightDoubleBracket]\ $\[Delta]p1\[LeftDoubleBracket]2
                \[RightDoubleBracket]\ $\[Delta]p1\[LeftDoubleBracket]3
                \[RightDoubleBracket]\ $\[Delta]p2\[LeftDoubleBracket]2
                \[RightDoubleBracket]\ $\[Delta]p2\[LeftDoubleBracket]3
                \[RightDoubleBracket] + 
            2\ $cl\[LeftDoubleBracket]2\[RightDoubleBracket]\^2\ $p1
                \[LeftDoubleBracket]1\[RightDoubleBracket]\ $p2
                \[LeftDoubleBracket]1\[RightDoubleBracket]\ $\[Delta]p1
                \[LeftDoubleBracket]2\[RightDoubleBracket]\ $\[Delta]p1
                \[LeftDoubleBracket]3\[RightDoubleBracket]\ $\[Delta]p2
                \[LeftDoubleBracket]2\[RightDoubleBracket]\ $\[Delta]p2
                \[LeftDoubleBracket]3\[RightDoubleBracket] + $cl
                \[LeftDoubleBracket]4\[RightDoubleBracket]\ $p1
                \[LeftDoubleBracket]1\[RightDoubleBracket]\ $p2
                \[LeftDoubleBracket]1\[RightDoubleBracket]\ $\[Delta]p1
                \[LeftDoubleBracket]2\[RightDoubleBracket]\ $\[Delta]p1
                \[LeftDoubleBracket]3\[RightDoubleBracket]\ $\[Delta]p2
                \[LeftDoubleBracket]2\[RightDoubleBracket]\ $\[Delta]p2
                \[LeftDoubleBracket]3\[RightDoubleBracket] + $cl
                \[LeftDoubleBracket]1\[RightDoubleBracket]\ $cl
                \[LeftDoubleBracket]2\[RightDoubleBracket]\ $p2
                \[LeftDoubleBracket]1\[RightDoubleBracket]\ $\[Delta]p1
                \[LeftDoubleBracket]1\[RightDoubleBracket]\ $\[Delta]p1
                \[LeftDoubleBracket]2\[RightDoubleBracket]\ $\[Delta]p1
                \[LeftDoubleBracket]3\[RightDoubleBracket]\ $\[Delta]p2
                \[LeftDoubleBracket]2\[RightDoubleBracket]\ $\[Delta]p2
                \[LeftDoubleBracket]3\[RightDoubleBracket] + 
            3\ $cl\[LeftDoubleBracket]1\[RightDoubleBracket]\ $cl
                \[LeftDoubleBracket]3\[RightDoubleBracket]\ $p2
                \[LeftDoubleBracket]1\[RightDoubleBracket]\ $\[Delta]p1
                \[LeftDoubleBracket]1\[RightDoubleBracket]\ $\[Delta]p1
                \[LeftDoubleBracket]2\[RightDoubleBracket]\ $\[Delta]p1
                \[LeftDoubleBracket]3\[RightDoubleBracket]\ $\[Delta]p2
                \[LeftDoubleBracket]2\[RightDoubleBracket]\ $\[Delta]p2
                \[LeftDoubleBracket]3\[RightDoubleBracket] + 
            6\ $cl\[LeftDoubleBracket]2\[RightDoubleBracket]\ $cl
                \[LeftDoubleBracket]3\[RightDoubleBracket]\ $p2
                \[LeftDoubleBracket]1\[RightDoubleBracket]\ $\[Delta]p1
                \[LeftDoubleBracket]1\[RightDoubleBracket]\ $\[Delta]p1
                \[LeftDoubleBracket]2\[RightDoubleBracket]\ $\[Delta]p1
                \[LeftDoubleBracket]3\[RightDoubleBracket]\ $\[Delta]p2
                \[LeftDoubleBracket]2\[RightDoubleBracket]\ $\[Delta]p2
                \[LeftDoubleBracket]3\[RightDoubleBracket] + $cl
                \[LeftDoubleBracket]5\[RightDoubleBracket]\ $p2
                \[LeftDoubleBracket]1\[RightDoubleBracket]\ $\[Delta]p1
                \[LeftDoubleBracket]1\[RightDoubleBracket]\ $\[Delta]p1
                \[LeftDoubleBracket]2\[RightDoubleBracket]\ $\[Delta]p1
                \[LeftDoubleBracket]3\[RightDoubleBracket]\ $\[Delta]p2
                \[LeftDoubleBracket]2\[RightDoubleBracket]\ $\[Delta]p2
                \[LeftDoubleBracket]3\[RightDoubleBracket] + $cl
                \[LeftDoubleBracket]2\[RightDoubleBracket]\ $p1
                \[LeftDoubleBracket]1\[RightDoubleBracket]\ $p1
                \[LeftDoubleBracket]2\[RightDoubleBracket]\ $p1
                \[LeftDoubleBracket]3\[RightDoubleBracket]\ $\[Delta]p2
                \[LeftDoubleBracket]1\[RightDoubleBracket]\ $\[Delta]p2
                \[LeftDoubleBracket]2\[RightDoubleBracket]\ $\[Delta]p2
                \[LeftDoubleBracket]3\[RightDoubleBracket] + 
            3\ $cl\[LeftDoubleBracket]1\[RightDoubleBracket]\ $cl
                \[LeftDoubleBracket]2\[RightDoubleBracket]\ $p1
                \[LeftDoubleBracket]2\[RightDoubleBracket]\ $p1
                \[LeftDoubleBracket]3\[RightDoubleBracket]\ $\[Delta]p1
                \[LeftDoubleBracket]1\[RightDoubleBracket]\ $\[Delta]p2
                \[LeftDoubleBracket]1\[RightDoubleBracket]\ $\[Delta]p2
                \[LeftDoubleBracket]2\[RightDoubleBracket]\ $\[Delta]p2
                \[LeftDoubleBracket]3\[RightDoubleBracket] + $cl
                \[LeftDoubleBracket]4\[RightDoubleBracket]\ $p1
                \[LeftDoubleBracket]2\[RightDoubleBracket]\ $p1
                \[LeftDoubleBracket]3\[RightDoubleBracket]\ $\[Delta]p1
                \[LeftDoubleBracket]1\[RightDoubleBracket]\ $\[Delta]p2
                \[LeftDoubleBracket]1\[RightDoubleBracket]\ $\[Delta]p2
                \[LeftDoubleBracket]2\[RightDoubleBracket]\ $\[Delta]p2
                \[LeftDoubleBracket]3\[RightDoubleBracket] + 
            3\ $cl\[LeftDoubleBracket]1\[RightDoubleBracket]\ $cl
                \[LeftDoubleBracket]2\[RightDoubleBracket]\ $p1
                \[LeftDoubleBracket]1\[RightDoubleBracket]\ $p1
                \[LeftDoubleBracket]3\[RightDoubleBracket]\ $\[Delta]p1
                \[LeftDoubleBracket]2\[RightDoubleBracket]\ $\[Delta]p2
                \[LeftDoubleBracket]1\[RightDoubleBracket]\ $\[Delta]p2
                \[LeftDoubleBracket]2\[RightDoubleBracket]\ $\[Delta]p2
                \[LeftDoubleBracket]3\[RightDoubleBracket] + $cl
                \[LeftDoubleBracket]4\[RightDoubleBracket]\ $p1
                \[LeftDoubleBracket]1\[RightDoubleBracket]\ $p1
                \[LeftDoubleBracket]3\[RightDoubleBracket]\ $\[Delta]p1
                \[LeftDoubleBracket]2\[RightDoubleBracket]\ $\[Delta]p2
                \[LeftDoubleBracket]1\[RightDoubleBracket]\ $\[Delta]p2
                \[LeftDoubleBracket]2\[RightDoubleBracket]\ $\[Delta]p2
                \[LeftDoubleBracket]3\[RightDoubleBracket] + $cl
                \[LeftDoubleBracket]1\[RightDoubleBracket]\ $cl
                \[LeftDoubleBracket]2\[RightDoubleBracket]\ $p1
                \[LeftDoubleBracket]3\[RightDoubleBracket]\ $\[Delta]p1
                \[LeftDoubleBracket]1\[RightDoubleBracket]\ $\[Delta]p1
                \[LeftDoubleBracket]2\[RightDoubleBracket]\ $\[Delta]p2
                \[LeftDoubleBracket]1\[RightDoubleBracket]\ $\[Delta]p2
                \[LeftDoubleBracket]2\[RightDoubleBracket]\ $\[Delta]p2
                \[LeftDoubleBracket]3\[RightDoubleBracket] + 
            3\ $cl\[LeftDoubleBracket]1\[RightDoubleBracket]\ $cl
                \[LeftDoubleBracket]3\[RightDoubleBracket]\ $p1
                \[LeftDoubleBracket]3\[RightDoubleBracket]\ $\[Delta]p1
                \[LeftDoubleBracket]1\[RightDoubleBracket]\ $\[Delta]p1
                \[LeftDoubleBracket]2\[RightDoubleBracket]\ $\[Delta]p2
                \[LeftDoubleBracket]1\[RightDoubleBracket]\ $\[Delta]p2
                \[LeftDoubleBracket]2\[RightDoubleBracket]\ $\[Delta]p2
                \[LeftDoubleBracket]3\[RightDoubleBracket] + 
            6\ $cl\[LeftDoubleBracket]2\[RightDoubleBracket]\ $cl
                \[LeftDoubleBracket]3\[RightDoubleBracket]\ $p1
                \[LeftDoubleBracket]3\[RightDoubleBracket]\ $\[Delta]p1
                \[LeftDoubleBracket]1\[RightDoubleBracket]\ $\[Delta]p1
                \[LeftDoubleBracket]2\[RightDoubleBracket]\ $\[Delta]p2
                \[LeftDoubleBracket]1\[RightDoubleBracket]\ $\[Delta]p2
                \[LeftDoubleBracket]2\[RightDoubleBracket]\ $\[Delta]p2
                \[LeftDoubleBracket]3\[RightDoubleBracket] + $cl
                \[LeftDoubleBracket]5\[RightDoubleBracket]\ $p1
                \[LeftDoubleBracket]3\[RightDoubleBracket]\ $\[Delta]p1
                \[LeftDoubleBracket]1\[RightDoubleBracket]\ $\[Delta]p1
                \[LeftDoubleBracket]2\[RightDoubleBracket]\ $\[Delta]p2
                \[LeftDoubleBracket]1\[RightDoubleBracket]\ $\[Delta]p2
                \[LeftDoubleBracket]2\[RightDoubleBracket]\ $\[Delta]p2
                \[LeftDoubleBracket]3\[RightDoubleBracket] + 
            3\ $cl\[LeftDoubleBracket]1\[RightDoubleBracket]\ $cl
                \[LeftDoubleBracket]2\[RightDoubleBracket]\ $p1
                \[LeftDoubleBracket]1\[RightDoubleBracket]\ $p1
                \[LeftDoubleBracket]2\[RightDoubleBracket]\ $\[Delta]p1
                \[LeftDoubleBracket]3\[RightDoubleBracket]\ $\[Delta]p2
                \[LeftDoubleBracket]1\[RightDoubleBracket]\ $\[Delta]p2
                \[LeftDoubleBracket]2\[RightDoubleBracket]\ $\[Delta]p2
                \[LeftDoubleBracket]3\[RightDoubleBracket] + $cl
                \[LeftDoubleBracket]4\[RightDoubleBracket]\ $p1
                \[LeftDoubleBracket]1\[RightDoubleBracket]\ $p1
                \[LeftDoubleBracket]2\[RightDoubleBracket]\ $\[Delta]p1
                \[LeftDoubleBracket]3\[RightDoubleBracket]\ $\[Delta]p2
                \[LeftDoubleBracket]1\[RightDoubleBracket]\ $\[Delta]p2
                \[LeftDoubleBracket]2\[RightDoubleBracket]\ $\[Delta]p2
                \[LeftDoubleBracket]3\[RightDoubleBracket] + $cl
                \[LeftDoubleBracket]1\[RightDoubleBracket]\ $cl
                \[LeftDoubleBracket]2\[RightDoubleBracket]\ $p1
                \[LeftDoubleBracket]2\[RightDoubleBracket]\ $\[Delta]p1
                \[LeftDoubleBracket]1\[RightDoubleBracket]\ $\[Delta]p1
                \[LeftDoubleBracket]3\[RightDoubleBracket]\ $\[Delta]p2
                \[LeftDoubleBracket]1\[RightDoubleBracket]\ $\[Delta]p2
                \[LeftDoubleBracket]2\[RightDoubleBracket]\ $\[Delta]p2
                \[LeftDoubleBracket]3\[RightDoubleBracket] + 
            3\ $cl\[LeftDoubleBracket]1\[RightDoubleBracket]\ $cl
                \[LeftDoubleBracket]3\[RightDoubleBracket]\ $p1
                \[LeftDoubleBracket]2\[RightDoubleBracket]\ $\[Delta]p1
                \[LeftDoubleBracket]1\[RightDoubleBracket]\ $\[Delta]p1
                \[LeftDoubleBracket]3\[RightDoubleBracket]\ $\[Delta]p2
                \[LeftDoubleBracket]1\[RightDoubleBracket]\ $\[Delta]p2
                \[LeftDoubleBracket]2\[RightDoubleBracket]\ $\[Delta]p2
                \[LeftDoubleBracket]3\[RightDoubleBracket] + 
            6\ $cl\[LeftDoubleBracket]2\[RightDoubleBracket]\ $cl
                \[LeftDoubleBracket]3\[RightDoubleBracket]\ $p1
                \[LeftDoubleBracket]2\[RightDoubleBracket]\ $\[Delta]p1
                \[LeftDoubleBracket]1\[RightDoubleBracket]\ $\[Delta]p1
                \[LeftDoubleBracket]3\[RightDoubleBracket]\ $\[Delta]p2
                \[LeftDoubleBracket]1\[RightDoubleBracket]\ $\[Delta]p2
                \[LeftDoubleBracket]2\[RightDoubleBracket]\ $\[Delta]p2
                \[LeftDoubleBracket]3\[RightDoubleBracket] + $cl
                \[LeftDoubleBracket]5\[RightDoubleBracket]\ $p1
                \[LeftDoubleBracket]2\[RightDoubleBracket]\ $\[Delta]p1
                \[LeftDoubleBracket]1\[RightDoubleBracket]\ $\[Delta]p1
                \[LeftDoubleBracket]3\[RightDoubleBracket]\ $\[Delta]p2
                \[LeftDoubleBracket]1\[RightDoubleBracket]\ $\[Delta]p2
                \[LeftDoubleBracket]2\[RightDoubleBracket]\ $\[Delta]p2
                \[LeftDoubleBracket]3\[RightDoubleBracket] + $cl
                \[LeftDoubleBracket]1\[RightDoubleBracket]\ $cl
                \[LeftDoubleBracket]2\[RightDoubleBracket]\ $p1
                \[LeftDoubleBracket]1\[RightDoubleBracket]\ $\[Delta]p1
                \[LeftDoubleBracket]2\[RightDoubleBracket]\ $\[Delta]p1
                \[LeftDoubleBracket]3\[RightDoubleBracket]\ $\[Delta]p2
                \[LeftDoubleBracket]1\[RightDoubleBracket]\ $\[Delta]p2
                \[LeftDoubleBracket]2\[RightDoubleBracket]\ $\[Delta]p2
                \[LeftDoubleBracket]3\[RightDoubleBracket] + 
            3\ $cl\[LeftDoubleBracket]1\[RightDoubleBracket]\ $cl
                \[LeftDoubleBracket]3\[RightDoubleBracket]\ $p1
                \[LeftDoubleBracket]1\[RightDoubleBracket]\ $\[Delta]p1
                \[LeftDoubleBracket]2\[RightDoubleBracket]\ $\[Delta]p1
                \[LeftDoubleBracket]3\[RightDoubleBracket]\ $\[Delta]p2
                \[LeftDoubleBracket]1\[RightDoubleBracket]\ $\[Delta]p2
                \[LeftDoubleBracket]2\[RightDoubleBracket]\ $\[Delta]p2
                \[LeftDoubleBracket]3\[RightDoubleBracket] + 
            6\ $cl\[LeftDoubleBracket]2\[RightDoubleBracket]\ $cl
                \[LeftDoubleBracket]3\[RightDoubleBracket]\ $p1
                \[LeftDoubleBracket]1\[RightDoubleBracket]\ $\[Delta]p1
                \[LeftDoubleBracket]2\[RightDoubleBracket]\ $\[Delta]p1
                \[LeftDoubleBracket]3\[RightDoubleBracket]\ $\[Delta]p2
                \[LeftDoubleBracket]1\[RightDoubleBracket]\ $\[Delta]p2
                \[LeftDoubleBracket]2\[RightDoubleBracket]\ $\[Delta]p2
                \[LeftDoubleBracket]3\[RightDoubleBracket] + $cl
                \[LeftDoubleBracket]5\[RightDoubleBracket]\ $p1
                \[LeftDoubleBracket]1\[RightDoubleBracket]\ $\[Delta]p1
                \[LeftDoubleBracket]2\[RightDoubleBracket]\ $\[Delta]p1
                \[LeftDoubleBracket]3\[RightDoubleBracket]\ $\[Delta]p2
                \[LeftDoubleBracket]1\[RightDoubleBracket]\ $\[Delta]p2
                \[LeftDoubleBracket]2\[RightDoubleBracket]\ $\[Delta]p2
                \[LeftDoubleBracket]3\[RightDoubleBracket] + 
            9\ $cl\[LeftDoubleBracket]1\[RightDoubleBracket]\^2\ $cl
                \[LeftDoubleBracket]2\[RightDoubleBracket]\ $\[Delta]p1
                \[LeftDoubleBracket]1\[RightDoubleBracket]\ $\[Delta]p1
                \[LeftDoubleBracket]2\[RightDoubleBracket]\ $\[Delta]p1
                \[LeftDoubleBracket]3\[RightDoubleBracket]\ $\[Delta]p2
                \[LeftDoubleBracket]1\[RightDoubleBracket]\ $\[Delta]p2
                \[LeftDoubleBracket]2\[RightDoubleBracket]\ $\[Delta]p2
                \[LeftDoubleBracket]3
                \[RightDoubleBracket] + $cl\[LeftDoubleBracket]2
                  \[RightDoubleBracket]\^2\ $\[Delta]p1\[LeftDoubleBracket]1
                \[RightDoubleBracket]\ $\[Delta]p1\[LeftDoubleBracket]2
                \[RightDoubleBracket]\ $\[Delta]p1\[LeftDoubleBracket]3
                \[RightDoubleBracket]\ $\[Delta]p2\[LeftDoubleBracket]1
                \[RightDoubleBracket]\ $\[Delta]p2\[LeftDoubleBracket]2
                \[RightDoubleBracket]\ $\[Delta]p2\[LeftDoubleBracket]3
                \[RightDoubleBracket] + 
            6\ $cl\[LeftDoubleBracket]2\[RightDoubleBracket]\^3\ $\[Delta]p1
                \[LeftDoubleBracket]1\[RightDoubleBracket]\ $\[Delta]p1
                \[LeftDoubleBracket]2\[RightDoubleBracket]\ $\[Delta]p1
                \[LeftDoubleBracket]3\[RightDoubleBracket]\ $\[Delta]p2
                \[LeftDoubleBracket]1\[RightDoubleBracket]\ $\[Delta]p2
                \[LeftDoubleBracket]2\[RightDoubleBracket]\ $\[Delta]p2
                \[LeftDoubleBracket]3\[RightDoubleBracket] + 
            9\ $cl\[LeftDoubleBracket]3\[RightDoubleBracket]\^2\ $\[Delta]p1
                \[LeftDoubleBracket]1\[RightDoubleBracket]\ $\[Delta]p1
                \[LeftDoubleBracket]2\[RightDoubleBracket]\ $\[Delta]p1
                \[LeftDoubleBracket]3\[RightDoubleBracket]\ $\[Delta]p2
                \[LeftDoubleBracket]1\[RightDoubleBracket]\ $\[Delta]p2
                \[LeftDoubleBracket]2\[RightDoubleBracket]\ $\[Delta]p2
                \[LeftDoubleBracket]3\[RightDoubleBracket] + 
            6\ $cl\[LeftDoubleBracket]1\[RightDoubleBracket]\ $cl
                \[LeftDoubleBracket]4\[RightDoubleBracket]\ $\[Delta]p1
                \[LeftDoubleBracket]1\[RightDoubleBracket]\ $\[Delta]p1
                \[LeftDoubleBracket]2\[RightDoubleBracket]\ $\[Delta]p1
                \[LeftDoubleBracket]3\[RightDoubleBracket]\ $\[Delta]p2
                \[LeftDoubleBracket]1\[RightDoubleBracket]\ $\[Delta]p2
                \[LeftDoubleBracket]2\[RightDoubleBracket]\ $\[Delta]p2
                \[LeftDoubleBracket]3\[RightDoubleBracket] + 
            9\ $cl\[LeftDoubleBracket]2\[RightDoubleBracket]\ $cl
                \[LeftDoubleBracket]4\[RightDoubleBracket]\ $\[Delta]p1
                \[LeftDoubleBracket]1\[RightDoubleBracket]\ $\[Delta]p1
                \[LeftDoubleBracket]2\[RightDoubleBracket]\ $\[Delta]p1
                \[LeftDoubleBracket]3\[RightDoubleBracket]\ $\[Delta]p2
                \[LeftDoubleBracket]1\[RightDoubleBracket]\ $\[Delta]p2
                \[LeftDoubleBracket]2\[RightDoubleBracket]\ $\[Delta]p2
                \[LeftDoubleBracket]3\[RightDoubleBracket] + $cl
                \[LeftDoubleBracket]6\[RightDoubleBracket]\ $\[Delta]p1
                \[LeftDoubleBracket]1\[RightDoubleBracket]\ $\[Delta]p1
                \[LeftDoubleBracket]2\[RightDoubleBracket]\ $\[Delta]p1
                \[LeftDoubleBracket]3\[RightDoubleBracket]\ $\[Delta]p2
                \[LeftDoubleBracket]1\[RightDoubleBracket]\ $\[Delta]p2
                \[LeftDoubleBracket]2\[RightDoubleBracket]\ $\[Delta]p2
                \[LeftDoubleBracket]3\[RightDoubleBracket])
          \), {{$q, _Real, 1}, {$p1, _Real, 1}, {$p2, _Real, 
            1}, {$\[Delta]p1, _Integer, 1}, {$\[Delta]p2, _Integer, 1}}]; 
    \)\)], "Input"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(FullGenotypeFrequencyTable[4, compiled]
        \)[{{0, 1, 0, 0}, {0, 1, 1, 1}}, {0.4, 0.5, 0.6, 0.45}, {0.01, 0, 0, 
        0.01, 0, 0, 0, 0, 0, 0}]\)], "Input"],

Cell[BoxData[
    \(0.0187249999999999943`\)], "Output"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    \(TextForm
    \`DiploidGenotypeFrequencyTable[{0, 2, 0}, {k\_w, k\_b}, \[Delta]p, p, S]
          \ gives\ the\ diploid\ genotype\ frequency\ in\ terms\ of\ cumulants
        \ k\_w[2] .. , \ 
    \(k\_b[2] .. \)\ \ Uses\ FullGenotypeFrequencyTable[] . \ \ Also\ can\ use
      \ DiploidGenotypeFrequencyTable[{0, 2, 0}, {k\_w, k\_b}, \[Delta]p, p], 
    \ which\ uses\ the\ compiled\ 
      version . \ \ 
        \(DiploidGenotypeFrequencyTable[{0, 2, 0}, \[Delta]p]\)[p[1] .. , 
          k\_w[2] .. , \ k\_b[2] ... ]\ is\ fully\ 
      compiled . \ \ 
        \(DiploidGenotypeFrequencyTable[\[Delta]p]\)[p[1] .. , k\_w[2] .. , \ 
          k\_b[2] ... ]\ is\ fully\ compiled; \ 
    returns\ the\ complete\ vector\ of\ genotype\ frequencies\)], 
  "Subsubsection"],

Cell[BoxData[
    \(\(DiploidGenotypeFrequencyTable[X_, {cw_, cb_}, \[Delta]p_, p_, 
          S_List] := 
        Module[{gL, 
            gg}, \n\t\tgL[Y_] := \(gL[Y] = 
              FullGenotypeFrequencyTable[Y, {cw, cb}, \[Delta]p, p, 
                S]\); \n\t\tgg = 
            Plus @@ \((\(gL[Sort[#]] &\) /@ 
                  PossibleDiploidGenotypes[X])\); \n\tClear[gL]; 
          gg];\)\)], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(\(DiploidGenotypeFrequencyTable[X_, cl_, \[Delta]p_, p_] := 
        Module[{gL, 
            gg}, \n\t\t\tgL[Y_] := \(gL[Y] = 
              FullGenotypeFrequencyTable[Y, cl, \[Delta]p, p]\); \n\t\tgg = 
            Plus @@ \((\(gL[Sort[#]] &\) /@ 
                  PossibleDiploidGenotypes[X])\); \n\tClear[gL]; 
          gg];\)\)], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(\(DiploidGenotypeFrequencyTable[
          X_List, \[Delta]p_] := \(DiploidGenotypeFrequencyTable[
            X, \[Delta]p] = \n\t\tModule[{nl = Length[X], pp, vars, sv, tv, 
              j, rl}, \n\t\t\tsv = 
              Join[StandardSet[nl, ppp], StandardSet[nl]] // 
                Flatten; \n\ \ \ \ \ \ vars = 
              Join[Table[pp[j], {j, nl}], Table[cw[j], {j, 2, nl}], 
                Table[cb[j], {j, 2, 2  nl}]]; \n\t\trl[
                xx_List] := \(({vars, Flatten[xx]} // Transpose)\) /. {x_, 
                    y_} :> \((x -> y)\); \t\n\t
            tv = Transpose[{sv, Table[_Real, {4  nl - 2}]}]; \n\t\tCompile[
              tv // Evaluate, \ 
              DiploidGenotypeFrequencyTable[X, {cw, cb}, \[Delta]p, pp, 
                    Range[nl]] /. rl[sv] // Evaluate]]\);\)\)], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(\(DiploidGenotypeFrequencyTable[
          nl_Integer, \[Delta]p_] := \(DiploidGenotypeFrequencyTable[
            nl, \[Delta]p] = \n\t\tModule[{pp, ppp, vars, sv, tv, j, rl, 
              dt = DiploidTypes[
                    nl] /. {{a_Integer, b_Integer} :> a + b}}, \n\t\t\tsv = 
              Join[StandardSet[nl, ppp], StandardSet[nl]] // 
                Flatten; \n\ \ \ \ \ \ vars = 
              Join[Table[pp[j], {j, nl}], Table[cw[j], {j, 2, nl}], 
                Table[cb[j], {j, 2, 2  nl}]]; \n\t\trl[
                xx_List] := \(({vars, Flatten[xx]} // Transpose)\) /. {x_, 
                    y_} :> \((x -> y)\); \t\n\t
            tv = Transpose[{sv, Table[_Real, {4  nl - 2}]}]; \n\t\tCompile[
              tv // Evaluate, \ \((\(\((DiploidGenotypeFrequencyTable[#, {cw, 
                              cb}, \[Delta]p, pp, Range[nl]] /. 
                          rl[sv])\) &\) /@ dt)\) // 
                Evaluate]]\);\)\)], "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{

Cell["\<\
DiploidGenotypeFrequencyArguments[nloci][p1,..,q1,..,cw[2],..cb[2]..\
] gives an array listing all the 
  arguments that must be supplied to FullGenotypeFrequencyTable[nloci,1&][] \
to give the genotype 
  frequencies\
\>", "Subsubsection"],

Cell[BoxData[
    \(\(DiploidGenotypeFrequencyArguments[
          nl_] := \(DiploidGenotypeFrequencyArguments[nl] = 
          Module[{al, tv, pl = StandardSet[nl, p], ql = StandardSet[nl, q], 
              cl = StandardSet[nl], pl2, ql2}, \n\t\tpl2 = Join[pl, pl]; 
            ql2 = Join[ql, 
                ql]; \n\t\t\tal = \(Flatten[{pl2*# + ql2 \((1 - #\ )\), 
                      2  # - 1, cl}] &\) /@ HaploidTypes[2  nl]; \n\t\ttv = 
              Transpose[{Flatten[{pl, ql, cl}], 
                  Table[_Real, {5  nl - 2}]}]; \n\t\tCompile[tv // Evaluate, 
              al // Evaluate]]\);\)\)], "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData[{
  "GenotypeFrequencyFast[3][{{0,1,0},{1,1,1}},{p1..},{\[Delta]p1..},",
  "MomentReduced",
  "[3][cl]] is a compiled function which calculates a specific genotype \
frequency using the matrix method.  Surprisingly, no faster than \
FullGenotypeFrequencyTable[3,int]. "
}], "Subsubsection",
  InitializationCell->True],

Cell[BoxData[
    \(\(GenotypeFrequencyFast[n_Integer] := \(GenotypeFrequencyFast[n] = 
          Module[{ptx, pty, sx, sy, \[Delta]ptx, \[Delta]pty, psx, psy, 
              j}, \n\tCompile[{{XY, \ _Integer, 2}, \ {p, \ _Real, \ 
                  1}, \ {\[Delta]p, \ _Real, \ 1}, \ {mm, \ _Real, \ 2}}, \ 
              sx\  = \ 2  XY\[LeftDoubleBracket]1\[RightDoubleBracket]\  - \ 
                  1; \ sy\  = \ 
                2  XY\[LeftDoubleBracket]2\[RightDoubleBracket]\  - \ 1; \ 
              ptx\  = \ 
                1\  - XY\[LeftDoubleBracket]1\[RightDoubleBracket]\  + \ 
                  sx*p; \ pty\  = \ 
                1\  - XY\[LeftDoubleBracket]2\[RightDoubleBracket]\  + \ 
                  sy*p; \ \[Delta]ptx\  = \ \((\[Delta]p*sx)\)/
                  ptx; \ \[Delta]pty\  = \ \((\[Delta]p*sy)\)/pty; \ 
              psx\  = \ 
                Table[\(ProductSum[j]\)[\[Delta]ptx], \ {j, \ 0, \ n}]; \ 
              psy\  = \ 
                Table[\(ProductSum[j]\)[\[Delta]pty], \ {j, \ 0, \ 
                    n}]; \n\t\t\t\t\ Times\  @@ \ ptx*Times\  @@ \ pty*
                psx\  . \ mm\  . \ 
                  psy, \ {{\(ProductSum[_]\)[_], \ _Real}, \ {sx, \ _Integer, \
\ 1}, \ {sy, \ _Integer, \ 1}, \ {ptx, \ _Real, \ 1}, \ {pty, \ _Real, \ 
                  1}, \ {psx, \ _Real, \ 1}, \ {psy, \ _Real, \ 
                  1}, \ {\[Delta]ptx, \ _Real, \ 
                  1}, \ {\[Delta]pty, \ _Real, \ 
                  1}, \ {j, \ _Integer}}]]\);\)\)], "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData[{
  "GenotypeFrequencyFastVector[nloci][{p1..},{\[Delta]p1,..},{cw[1]..cb[1]....\
}] is a compiled function which calculates the 16 by 16 array of genotype \
frequencies as Matrix\[CapitalGamma][n][p,\[Delta]p].",
  "MomentReduced",
  "[n][cl].Matrix\[CapitalGamma][n][p,\[Delta]p]"
}], "Subsubsection",
  InitializationCell->True],

Cell[BoxData[
    \(\(GenotypeFrequencyFastVector[
          n_Integer] := \(GenotypeFrequencyFastVector[n] = 
          Module[{tt}, \n\t
            Compile[{\ {p, \ _Real, \ 1}, \ {\[Delta]p, \ _Real, \ 
                  1}, \ {cl, \ _Real, \ 
                  1}}, \n\t\t\t\ttt = \(Matrix\[CapitalGamma][n]\)[
                  p, \[Delta]p]; \n\t\t\ttt . \(MomentReduced[n]\)[cl] . 
                Transpose[tt], \ {{\(MomentReduced[_]\)[_], _Real, 
                  2}, {tt, _Real, 
                  2}, {\(Matrix\[CapitalGamma][_]\)[_], _Real, 
                  1}}]]\);\)\)], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(\(GenotypeFrequencyFastVector[p_List, \[Delta]p_List, cl_List, 
          n_Integer] := 
        Module[{tt = Matrix\[CapitalGamma][p, \[Delta]p, n]}, \n
          tt . MomentReduced[cl, n] . Transpose[tt]];\)\)], "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{

Cell["\<\
AlleleFrequencyPermutations[{p1..},n] gives the matrix of permuted \
p's & q's for all genotypes: {{q..q},..{p..p}}. \
AlleleFrequencyPermutations[n][{p1..}] is a compiled version.\
\>", 
  "Subsubsection"],

Cell[BoxData[
    \(\(AlleleFrequencyPermutations[p_List, 
          n_Integer] := \(\((\((1\  - #)\)\  + \ \((2  # - 1)\) p)\) &\) /@ 
          HaploidTypes[n];\)\)], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(\(AlleleFrequencyPermutations[
          n_Integer] := \(AlleleFrequencyPermutations[n] = \n\t
          Compile[{{p, _Real, 
                1}}, \n\t\t\t\(\((\((1\  - #)\)\  + \ \((2  # - 1)\) 
                      p)\) &\) /@ 
              HaploidTypes[n], {{HaploidTypes[_], _Integer, 
                2}}]\);\)\)], "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData[
"\[Delta]AlleleFrequencyPermutations[\[Delta]p,n] gives the matrix of \
permuted \[Delta]p's for all genotypes: {{-\[Delta]p\[Ellipsis]},..{\[Delta]p\
\[Ellipsis]}}.  \[Delta]AlleleFrequencyPermutations[n][{\[Delta]p1..}] is a \
compiled version."], "Subsubsection"],

Cell[BoxData[
    \(\(\[Delta]AlleleFrequencyPermutations[
          n_Integer] := \(\[Delta]AlleleFrequencyPermutations[
            n] = \n\t\tCompile[{{\[Delta]p, _Real, 
                1}}, \n\t\t\(\((\((2  # - 1)\) \[Delta]p)\) &\) /@ 
              HaploidTypes[n], \n\t\t\t{{HaploidTypes[_], _Integer, 
                2}}]\);\)\)], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(\(\[Delta]AlleleFrequencyPermutations[\[Delta]p_List, 
          n_Integer] := \(\[Delta]AlleleFrequencyPermutations[\[Delta]p, 
            n] = \n\t\t\(\((\((2  # - 1)\) \[Delta]p)\) &\) /@ 
            HaploidTypes[n]\);\)\)], "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    \(TextForm
    \`Matrix\[CapitalGamma][{\(p\_1\) \[Ellipsis]}, {\[Delta]p\_1, 
          \[Ellipsis]}, n]\ gives\ the\ matrix\ of\ coefficients, \ 
    constructed\ from\ AlleleFrequencyPermutations[], \ 
    \[Delta]AlleleFrequencyPermutations[] . \ \ 
        Matrix\[CapitalGamma][{p1\[Ellipsis]}, n]\ gives\ the\ matrix\ of\ 
      coefficients, \ 
    with\ \[Delta]p\ assumed\ 1. \ 
      \(Matrix\[CapitalGamma][n]\)[{\(p\_1\) \[Ellipsis]}, {\[Delta]p\_1, 
          \[Ellipsis]}]\ is\ a\ compiled\ \(version . \)\)], "Subsubsection"],

Cell[BoxData[
    \(\(Matrix\[CapitalGamma][p_List, \[Delta]p_List, n_Integer] := 
        Module[{pv = 
              AlleleFrequencyPermutations[p, 
                n]}, \n\((\(\((Times @@ #)\) &\) /@ 
                pv)\)*\((\(Table[
                    ProductSum[#, j], {j, 0, 
                      n}] &\) /@ \((\[Delta]AlleleFrequencyPermutations[\
\[Delta]p, n]/pv)\))\)];\)\)], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(\(Matrix\[CapitalGamma][p_List, n_Integer] := 
        Module[{pv = 
              AlleleFrequencyPermutations[p, 
                n]}, \n\((\(\((Times @@ #)\) &\) /@ 
                pv)\)*\((\(Table[
                    ProductSum[#, j], {j, 0, 
                      n}] &\) /@ \((\[Delta]AlleleFrequencyPermutations[
                      Array[1 &, {n}], n]/pv)\))\)];\)\)], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(\(\(Matrix\[CapitalGamma][n_Integer]\)[
          p_List, \[Delta]p_List] := \n\t\tModule[{pv = \
\(AlleleFrequencyPermutations[n]\)[p], 
            j}, \n\((\(\((Times @@ #)\) &\) /@ 
                pv)\)*\((\(Table[\(ProductSum[j]\)[#], {j, 0, 
                      n}] &\) /@ \((\(\[Delta]AlleleFrequencyPermutations[
                        n]\)[\[Delta]p]/pv)\))\)];\)\)], "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{

Cell["\<\
PloidyWeightList[n] lists the factor of which weights each diploid  \
frequency: 1 for homozygotes, 2 otherwise\
\>", "Subsubsection",
  InitializationCell->True],

Cell[BoxData[
    \(\(PloidyWeightList[
          n_Integer] := \(PloidyWeightList[
            n] = \(If[Count[#, {0, 1}] == 0, 1, 2] &\) /@ 
            DiploidTypes[n]\);\)\)], "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData[{
  "PositionsList[n] gives the positions in the ",
  Cell[BoxData[
      \(TraditionalForm\`2\^n\)]],
  " x ",
  Cell[BoxData[
      \(TraditionalForm\`2\^n\)]],
  " matrix of genotype frequencies of the elements needed to give the diploid \
frequencies."
}], "Subsubsection",
  InitializationCell->True],

Cell[BoxData[
    \(\(PositionsList[
          n_Integer] := \(PositionsList[
            n] = \(PositionsList[#, 
                n] &\) /@ \((DiploidTypes[
                  n] /. {{a_Integer, b_Integer} :> a + b})\)\);\)\)], "Input",\

  InitializationCell->True],

Cell[BoxData[
    \(\(PositionsList[j_Integer, 
          n_Integer] := \(PositionsList[j, 
            n] = \(PositionsList[n]\)\[LeftDoubleBracket]
            j\[RightDoubleBracket]\);\)\)], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(\(PositionsList[X_List, 
          n_Integer] := \(PositionsList[X, 
            n] = \((\(\((Sort[\(\(Position[HaploidTypes[n], #]\)[\([1, 
                            1]\)] &\) /@ #])\) &\) /@ 
              Union[Sort /@ PossibleDiploidGenotypes[X]])\)\);\)\)], "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    \(TextForm\`GenotypeFrequencyConvert[gM, 
        n]\ converts\ the\ 2\^n\ by\ 2\^n\ matrix\ of\ genotype\ frequencies\ \
to\ the\ 3\^n\ matrix\ of\ diploid\ frequencies . \ Takes\ 0.08  
      s\ for\ 4\ loci, \ 14  s\ for\ 6\ \(\(loci\)\(.\)\)\)], "Subsubsection",\

  InitializationCell->True],

Cell[BoxData[
    \(\(GenotypeFrequencyConvert[gm_List, n_Integer] := 
        PloidyWeightList[
            n]*\((\(\((Plus @@ Extract[gm, #])\) &\) /@ 
              PositionsList[n])\);\)\)], "Input",
  InitializationCell->True],

Cell["\<\
 It does not seem feasible to save time by compiling: the code cc[] \
takes just as long as GenotypeFrequencyConvert[]\
\>", "Text"],

Cell[BoxData[
    \(\(cc = 
        Compile[{{gg, _Real, 
              2}, {n, _Integer}}, \[IndentingNewLine]Module[{j, k, 
              pl}, \[IndentingNewLine]PloidyWeightList[n] 
              Table[\[IndentingNewLine]pl = 
                  PositionsList[j, n]; \[IndentingNewLine]Sum[
                  Extract[gg, 
                    pl\[LeftDoubleBracket]k\[RightDoubleBracket]], {k, 
                    Length[pl]}], {j, 
                  3\^n}]], \[IndentingNewLine]{{PloidyWeightList[_], \
_Integer, 1}, {PositionsList[_, _], _Integer, 2}, {pl, _Integer, 
              2}, {Extract[_, _], _Real}, {j, _Integer}, {k, \
_Integer}}];\)\)], "Input"],

Cell[CellGroupData[{

Cell[BoxData[
    \(Timing[\(GenotypeFrequencyConvert[dl, 6];\)]\)], "Input"],

Cell[BoxData[
    \({9.25`\ Second, Null}\)], "Output"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    \(Timing[\(cc[dl, 6];\)]\)], "Input"],

Cell[BoxData[
    \({9.599999999998545`\ Second, Null}\)], "Output"]
}, Closed]],

Cell[BoxData[
    RowBox[{
      RowBox[{
      "The", " ", "alternative", " ", "strategy", " ", "of", " ", 
        "constructing", " ", "a", 
        FormBox[\(\(3\^n\)\(\[Times]\)\(2\^n\)\(\[Times]\)\(2\^n\)\(\ \)\),
          "TraditionalForm"], "matrix", " ", "of", " ", "0"}], 
      ",", \(1\ that\ connects\ the\ observed\ frequencies\ with\ the\ full\ \
frequency\ array\ uses\ a\ lot\ of\ memory\), ",", 
      " ", \(but\ is\ much\ faster\)}]], "Text"],

Cell[BoxData[
    \(\(GenotypeFrequencyConvert[
          n_Integer] := \(GenotypeFrequencyConvert[
            n] = \[IndentingNewLine]Compile[{{gm, _Real, 
                2}}, \[IndentingNewLine]PositionsMatrix[n] . 
              Flatten[gm], \[IndentingNewLine]{{PositionsMatrix[_], _Integer, 
                2}}]\);\)\)], "Input",
  InitializationCell->True],

Cell[CellGroupData[{

Cell[BoxData[
    \(Timing[\(\(GenotypeFrequencyConvert[6]\)[dl];\)]\)], "Input"],

Cell[BoxData[
    \({0.9166666666666856`\ Second, Null}\)], "Output"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    StyleBox[\(PositionsMatrix[
            n]\ constructs\ a\ 3\^n\[Times]2\^\(2  n\)\ matrix\ of\ 0' 
          s\ and\ 1' 
          s\ that\ corresponds\ to\ PositionsList[
              n] . \ \ Only\ feasible\ for\ n \[LessEqual] 6. \),
      FontFamily->"Times"]], "Subsubsection"],

Cell[BoxData[
    \(\(PositionsMatrix[
          n_Integer] := \(PositionsMatrix[n] = \[IndentingNewLine]MapThread[
            Flatten[ReplacePart[
                  Array[0 &, {2\^n, 2\^n}], #2, #1]] &, {PositionsList[n], 
              PloidyWeightList[n]}]\);\)\)], "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{

Cell["\<\
StandardSet[nloci] gives a standard set of dummy variables to \
replace cw[], cb[].\
\>", "Subsubsection",
  InitializationCell->True],

Cell[BoxData[
    \(\(StandardSet[nl_, f_] := \(StandardSet[nl, f] = 
          Table[Unique[f], {nl}]\);\)\)], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(\(StandardSet[
          nl_] := \(StandardSet[nl] = {StandardSet[nl - 1, cw], 
            StandardSet[2  nl - 1, cb]}\);\)\)], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(\(StandardSet[nl_, c_, 
          All] := \(StandardSet[nl, c, All] = \n\t\tStandardSet[
            2\^nl - nl - 1, c]\);\)\)], "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    StyleBox[\(MVariables[
            n]\ lists\ all\ the\ coefficients\ M\_\(S, H, SS, SH, HH\)\ \
needed\ for\ n\ loci . \ 
            MVariables[j, n]\ lists\ those\ of\ order\ j \[LessEqual] 
        4 \( \(n\)\(.\)\)\),
      FontFamily->"Times"]], "Subsubsection"],

Cell[BoxData[
    \(\(MVariables::usage = \*"\"\<MVariables[n] lists all the coefficients \
\!\(m\_\(S, H\)\) needed to describe an n locus diploid genotype. \
MVariables[j,n] lists those of order j\[LessEqual]2n. MVariables[n, Family\
\[Rule]True] lists all the coefficients \!\(m\_\(S, H, SS, SH, HH\)\) needed \
for a pair of n locus  diploid genotypes. MVariables[j,n, Family\[Rule]True] \
lists those of order j\[LessEqual]4n. \>\"";\)\)], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(\(Options[MVariables] = {Family \[Rule] False};\)\)], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(\(MVariables[n_Integer, 
          opts___Rule] := \(MVariables[n, 
            opts] = \[IndentingNewLine]If[\(Family /. {opts}\) /. 
              Options[MVariables], \[IndentingNewLine]Module[{S, H, SS, SH, 
                HH}, \[IndentingNewLine]Flatten[
                Table[{S, H, SS, SH, HH}, {S, 0, n}, {H, 0, n - S}, {SS, 0, 
                    n - S - H}, {SH, 0, n - S - H - SS}, {HH, 0, 
                    n - S - H - SS - SH}], 4]], \[IndentingNewLine]Module[{S, 
                H}, \[IndentingNewLine]Flatten[
                Table[{S, H}, {S, 0, n}, {H, 0, n - S}], 1]]]\);\)\)], "Input",\

  InitializationCell->True],

Cell[BoxData[
    \(\(MVariables[j_Integer, n_Integer, 
          opts___Rule] := \(MVariables[j, n, 
            opts] = \[IndentingNewLine]If[\(Family /. {opts}\) /. 
              Options[MVariables], \[IndentingNewLine]Select[
              MVariables[n, 
                opts], \((# . {1, 2, 2, 3, 4} \[Equal] 
                    j)\) &], \[IndentingNewLine]Select[
              MVariables[n, 
                opts], \((# . {1, 2} \[Equal] j)\) &]]\);\)\)], "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{

Cell["\<\
MFromC[c,{S,H}] gives the expression for M[S,H] in terms of c[i,j]. \
 MFromC[c,{S,H,SS,SH,SS}] gives the expression for M[S,H,SS,SH,SS] in terms \
of c[i,j,k,l]\
\>", "Subsubsection"],

Cell[BoxData[
    \(\(MFromC::usage = "\<MFromC[c,{S,H}] gives the expression for M[S,H] in \
terms of c[i,j].  MFromC[c,{S,H,SS,SH,SS}] gives the expression for \
M[S,H,SS,SH,SS] in terms of c[i,j,k,l].\>";\)\)], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(\(MFromC[c_, {S_, H_}] := 
        Module[{S1, 
            S2}, \[IndentingNewLine]\[Sum]\+\(S1 = 0\)\%S Binomial[S, S1] 
                c[S1 + H, S - S1 + H] /. 
            c[i_, j_] \[RuleDelayed] c @@ Sort[{i, j}]];\)\)], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(\(MFromC[c_, {S_, H_, SS_, SH_, HH_}] := 
        Module[{S1, S2, S3, H1, SS1, SS2, SS3, SH1, SH2, 
            SH3}, \[IndentingNewLine]\[Sum]\+\(S1 = 0\)\%S\(\[Sum]\+\(S2 = \
0\)\%\(S - S1\)\(\[Sum]\+\(S3 = 0\)\%\(S - S1 - S2\)\(\[Sum]\+\(H1 = 0\)\%H\(\
\[Sum]\+\(SS1 = 0\)\%SS\(\[Sum]\+\(SS2 = 0\)\%\(SS - SS1\)\(\[Sum]\+\(SS3 = 0\
\)\%\(SS - SS1 - SS2\)\(\[Sum]\+\(SH1 = 0\)\%SH\(\[Sum]\+\(SH2 = 0\)\%\(SH - \
SH1\)\(\[Sum]\+\(SH3 = 0\)\%\(SH - SH1 - SH2\)Multinomial[S1, S2, S3, 
                                    S - S1 - S2 - S3\ ] Binomial[H, H1] 
                                  Multinomial[SS1, SS2, SS3, 
                                    SS - SS1 - SS2 - SS3\ ] 
                                  Multinomial[SH1, SH2, SH3, 
                                    SH - SH1 - SH2 - SH3\ ] 
                                  c[S1 + H1 + SS1 + SS3 + SH1 + SH2 + SH3 + 
                                      HH, S2 + H1 + SS - SS1 - SS3 + SH - 
                                      SH3 + HH, 
                                    S3 + H - H1 + SS1 + SS2 + SH - SH2 + HH, 
                                    S - S1 - S2 - S3 + H - H1 + SS - SS1 - 
                                      SS2 + SH - SH1 + HH]\)\)\)\)\)\)\)\)\) /. 
            c[i_, j_, k_, l_] \[RuleDelayed] 
              c @@ Flatten[Sort[{Sort[{i, j}], Sort[{k, l}]}]]];\)\)], "Input",\

  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    \(MToCEquations[m, c, 
        n]\ gives\ the\ equations\ relating\ the\ coefficients\ m[j, 
        k]\ to\ the\ c[j, k], \ 
    for\ n\ loci . \ \ MToCEquations[M, j, n]\ gives\ only\ the\ j' 
      th\ order\ \(\(equations\)\(.\)\(\ \)\)\)], "Subsubsection"],

Cell[BoxData[
    \(\(MToCEquations::usage = "\<MToCEquations[m,c,n] gives the equations \
relating the coefficients m[S,H] to the c[j,k], for n loci.  \
MToCEquations[m,c,j,n] gives only the j'th order equations. \
MToCEquations[m,c,n,Family\[Rule]True] gives the equations relating the \
coefficients m[S,H,SS,SH,HH] to the c[i,j,k,l]\>";\)\)], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(\(MToCEquations[m_, c_, jn__Integer, 
          opts___Rule] := \(MToCEquations[m, c, jn, 
            opts] = \[IndentingNewLine]\(\((\((m @@ #)\) == 
                  MFromC[c, #])\) &\) /@ MVariables[jn, opts]\);\)\)], "Input",\

  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{

Cell["\<\
Family\[Rule]True is an option for MToC[] which indicates that a \
family is involved\
\>", "Subsubsection"],

Cell[BoxData[
    \(\(Family::usage = "\<Family\[Rule]True is an option for MToC[] which \
indicates that a family is involved\>";\)\)], "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    StyleBox[\(MToC[m, c, n]\ is\ a\ rule\ which\ gives\ the\ moments, \ 
      c[i, j], \ 
      in\ terms\ of\ the\ m[S, 
            H] = \(\(<\)\(\((\[Zeta] + \(\[Zeta]\^*\)\()\^S\)\) \[Zeta]\
\[VeryThinSpace]\(\[Zeta]\^*\)\^H\)\(>\)\), \ 
      where\ {\[Zeta], \(\[Zeta]\^*\)}\ is\ the\ diploid\ genotype . \ \ MToC[
            m, c, j, n]\ gives\ only\ the\ j' 
        th\ order\ terms . \ \ MToC[m, c, n, 
            Family \[Rule] True]\ gives\ the\ moments, \ c[i, j, k, l], \ 
      in\ terms\ of\ the\ m[S, H, SS, SH, 
            HH] = \(\(<\)\(\((\[Zeta] + \(\[Zeta]\^*\) + \(\[Zeta]\^'\) + \
\[Zeta]\^\(\('\)\(*\)\)\()\^S\)\) \((\[Zeta]\[VeryThinSpace]\(\[Zeta]\^*\) + \
\(\[Zeta]\^'\) \[Zeta]\^\(\('\)\(*\)\)\()\^H\)\) \((\((\[Zeta] + \(\[Zeta]\^*\
\))\) \((\(\[Zeta]\^'\) + \[Zeta]\^\(\('\)\(*\)\))\)\()\^SS\)\) \((\((\[Zeta] \
+ \(\[Zeta]\^*\))\) \((\(\[Zeta]\^'\) \[Zeta]\^\(\('\)\(*\)\))\) + \((\[Zeta]\
\[VeryThinSpace]\(\[Zeta]\^*\))\) \((\(\[Zeta]\^'\) + \
\[Zeta]\^\(\('\)\(*\)\))\)\()\^SH\)\) \
\((\[Zeta]\[VeryThinSpace]\(\[Zeta]\^*\) \(\[Zeta]\^'\) \[Zeta]\^\(\('\)\(*\)\
\)\()\^HH\)\)\)\(>\)\(\(.\)\(\ \ \)\(Here\)\)\), \ {\[Zeta], \(\[Zeta]\^*\)}, \
\ {\(\[Zeta]\^'\), \[Zeta]\^\(\('\)\(*\)\)} 
        are\ the\ diploid\ genotypes\ of\ the\ two\ parents\ of\ a\ \
\(\(family\)\(.\)\)\),
      FontFamily->"Times"]], "Subsubsection"],

Cell[BoxData[
    \(\(MToC[m_, c_, jn__Integer, 
          opts___Rule] := \(MToC[m, c, jn, 
            opts] = \[IndentingNewLine]Module[{eqns = 
                MToCEquations[m, c, jn, opts], ne, nv, 
              vars}, \[IndentingNewLine]vars = 
              Union[Extract[eqns, 
                  Position[eqns, c[__]]]]; \[IndentingNewLine]nv = 
              Length[vars]; 
            ne = Length[eqns]; \[IndentingNewLine]If[
              ne > nv, \[IndentingNewLine]Print["\<WARNING: more equations \
than variables for {j,n}=\>", {jn}]; \[IndentingNewLine]Print[
                TableForm[
                  Eliminate[eqns, vars]]]; {}, \[IndentingNewLine]\(Solve[
                  eqns, vars]\)\[LeftDoubleBracket]1\[RightDoubleBracket]]]\);\
\)\)], "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    \(TextForm\`MToCOld[m, n]\ gives\ the\ matrix\ of\ moments, \ 
    c\_\(j, k\)\ in\ terms\ of\ m[j, k], \ 
    where\ m[j, 
          k] = \(\(<\)\(\(z\^j\) \[Phi]\^k\)\(>\)\(.\)\)\)], "Subsubsection",
  InitializationCell->True],

Cell[BoxData[
    \(MToCOld[m_, n_] := 
      Module[{a, b, j, eqns, vars, mat, 
          c}, \n\t\t\t\teqns = \((Table[
                  m[a, b] == 
                    Sum[Binomial[a, j] c[j + b, a - j + b], {j, 0, a}], {a, 
                    0, n}, {b, 0, n - a}] // Flatten)\) /. 
            c[i_, j_] :> c @@ Sort[{i, j}]; \n\t
        eqns = DeleteCases[DeleteCases[eqns, m[0, 0] == _], 
            m[1, 0] == _]\ ; \n
        mat = Table[c[j, k], {j, 0, n}, {k, 0, n}] /. 
            c[i_, j_] :> c @@ Sort[{i, j}]; \nvars = Union[mat // Flatten]; \n
        vars = DeleteCases[DeleteCases[vars, c[0, 0]], 
            c[0, 1]]; \n\(mat /. \(Solve[eqns, 
                vars]\)\[LeftDoubleBracket]1\[RightDoubleBracket]\) /. {c[0, 
                0] \[Rule] 1, c[0, 1] \[Rule] 0}]\)], "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    \(TextForm
    \`EstimateMoments[g, {p\_1, \[Ellipsis]}, {\[Delta]p, \[Ellipsis]}]\ 
      estimates\ the\ matrix\ of\ moments\ from\ the\ 3\^n\ diploid\ genotype
      \ frequencies, \ 
    assuming\ allele\ frequencies\ p\_i\ and\ divergences\ 
      \[Delta]p\_i . \ \ If\ the\ {\[Delta]p\_i, \[Ellipsis]}\ are\ omitted, 
    \ they\ are\ assumed\ to\ be\ 1. \)], "Subsubsection"],

Cell[BoxData[
    \(\(EstimateMoments[g_List, p_List] := 
        EstimateMoments[g, p, Array[1 &, Length[p]]];\)\)], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(\(EstimateMoments[g_List, p_List, \[Delta]p_List] := 
        Module[{nl = Length[p], z, \[Phi], dt, f, m, c}, \n\t
          dt = DiploidTypes[nl] /. {{a_Integer, b_Integer} :> a + b}; \n\t
          z = \(\((\((# - 2  p)\)/\[Delta]p)\) &\) /@ 
              dt; \n\t\[Phi] = \(\((\((Expand /@ \((p\^2 - # \((p + 
                                  1\/2)\) + #\^2\/2)\))\)/\[Delta]p\^2)\) &\) \
/@ dt; \nf[a_, b_] := \(f[a, b] = 
              g . Table[
                    ProductSum[{z\[LeftDoubleBracket]
                          j\[RightDoubleBracket], \[Phi]\[LeftDoubleBracket]
                          j\[RightDoubleBracket]}, {a, b}], {j, 
                      Length[dt]}]/\((\(nl!\)\/\(\(a!\) \(b!\) \(\((nl - a - \
b)\)!\)\))\)\); \n\t\(\(Array[c, {nl + 1, nl + 1}, 0] /. 
                c[i_, j_] \[RuleDelayed] c @@ Sort[{i, j}]\) /. 
              MToC[m, c, nl]\) /. m \[Rule] f];\)\)], "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    \(FamilyM[
        families, {i\_S, i\_H, i\_SS, i\_SH, 
          i\_HH}, {\(p\_1\) \[Ellipsis]}]\ gives\ the\ average\ of\ \
M\_\(i\_S, i\_H, i\_SS, i\_SH, i\_HH\), \ 
    measured\ relative\ to\ allele\ frequencies\ {\(p\_1\) \[Ellipsis]}\)], \
"Subsubsection"],

Cell[BoxData[
    \(\(FamilyM[ff_List, j_List, p_List, 
          opts___Rule] := \(FamilyM[ff, j, p, 
            opts] = \[IndentingNewLine]Mean[\(ProductSum[FamilyEffects[#, p, \
opts], j]\/Multinomial @@ Append[j, Length[p] - \((Plus @@ j)\)] &\) /@ 
              ff]\);\)\)], "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{\(FamilyEffects[
          family, \ {p\_1, \[Ellipsis]}]\ gives\ a\ list\ {S, H, SS, SH, 
          HH}\), ",", " ", 
      RowBox[{"which", " ", "estimates", " ", 
        RowBox[{"(", 
          RowBox[{\(\[Zeta]\_i\), "+", \(\[Zeta]\_i\%*\), "+", 
            FormBox[\(\(\[Zeta]\_i\%'\) + \ \[Zeta]\_i\%\(\('\)\(*\)\)\),
              "TraditionalForm"]}], ")"}]}], 
      ",", \((\(\[Zeta]\_i\) \(\[Zeta]\_i\%*\) + \(\[Zeta]\_i\%'\) \[Zeta]\_i\
\%\(\('\)\(*\)\))\), ",", 
      RowBox[{\((\[Zeta]\_i + \(\[Zeta]\_i\%*\))\), 
        RowBox[{"(", 
          FormBox[\(\(\[Zeta]\_i\%'\) + \ \[Zeta]\_i\%\(\('\)\(*\)\)\),
            "TraditionalForm"], ")"}]}], ",", " ", 
      RowBox[{"(", 
        RowBox[{
          RowBox[{
            RowBox[{"(", 
              FormBox[\(\(\[Zeta]\_i\%'\) + \ \[Zeta]\_i\%\(\('\)\(*\)\)\),
                "TraditionalForm"], 
              ")"}], \(\[Zeta]\_i\), \(\[Zeta]\_i\%*\)}], 
          "+", \(\((\[Zeta]\_i + \(\[Zeta]\_i\%*\))\) \(\[Zeta]\_i\%'\) \
\[Zeta]\_i\%\(\('\)\(*\)\)\)}], ")"}], ",", 
      " ", \(\(\[Zeta]\_i\) \(\[Zeta]\_i\%*\) \(\[Zeta]\_i\%'\) \
\(\(\[Zeta]\_i\%\(\('\)\(*\)\)\)\(.\)\(\ \)\)\)}]], "Subsubsection"],

Cell[BoxData[
    \(\(Options[
          FamilyEffects] = {InferParentalGenotypes \[Rule] 
            False};\)\)], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(\(FamilyEffects[f_, pp_, opts___Rule] := \(FamilyEffects[f, pp, opts] = 
          Module[{z, y, mz, vz, czy, dz, dy, my, vy, n = Length[f], jpg, 
              ipg = \(InferParentalGenotypes /. {opts}\) /. 
                  Options[FamilyEffects]}, \[IndentingNewLine]If[
              ipg, \[IndentingNewLine]jpg = 
                ParentalGenotypes[f] /. {0 \[Rule] {0, 0}, 1 \[Rule] {0, 1}, 
                    2 \[Rule] {1, 1}}; \[IndentingNewLine]Transpose[
                Replace[\((\((Flatten /@ jpg)\) - 
                      pp)\), {\[Zeta]11_, \[Zeta]12_, \[Zeta]21_, \[Zeta]22_} \
\[Rule] {\[Zeta]11 + \[Zeta]12 + \[Zeta]21 + \[Zeta]22, \[Zeta]11\ \[Zeta]12 \
+ \[Zeta]21\ \[Zeta]22, \((\[Zeta]11 + \[Zeta]12)\) \((\[Zeta]21 + \[Zeta]22)\
\), \((\[Zeta]11 + \[Zeta]12)\) \[Zeta]21\ \[Zeta]22 + \[Zeta]11\ \[Zeta]12 \
\((\[Zeta]21 + \ \[Zeta]22)\), \[Zeta]11\ \[Zeta]12\ \[Zeta]21\ \[Zeta]22}, \
\(-1\)]], \[IndentingNewLine]z = 
                Replace[\((\(\((# - 2  pp)\) &\) /@ 
                      f)\), {_?\((\((\(! FreeQ[#, \[EmptySet]]\))\) &)\) \
\[RuleDelayed] \[EmptySet]}, {2}]; \[IndentingNewLine]y = 
                Replace[\((\(\((#\^2 - # \((1 + 2  pp)\) + 2  pp\^2)\) &\) /@ 
                      f)\), {_?\((\((\(! FreeQ[#, \[EmptySet]]\))\) &)\) \
\[RuleDelayed] \[EmptySet]}, {2}]; \[IndentingNewLine]dz = 
                DeleteCases[Transpose[z], \[EmptySet], 
                  2]; \[IndentingNewLine]dy = 
                DeleteCases[Transpose[y], \[EmptySet], 2]/
                  2; \[IndentingNewLine]mz = Mean /@ dz; 
              vz = VarianceMLE /@ dz; \[IndentingNewLine]my = Mean /@ dy; 
              vy = VarianceMLE /@ dy; \[IndentingNewLine]czy = 
                MapThread[
                  CovarianceMLE[#1, #2] &, {dz, dy}]; \[IndentingNewLine]{2  
                  mz, \[IndentingNewLine]mz\^2 - 
                  2  my - \((\(n + 1\)\/\(n - 1\))\) vz, \[IndentingNewLine]4 
                   my, \[IndentingNewLine]2  mz\ my - 
                  2 \((\(n + 1\)\/\(n - 1\))\) czy, \[IndentingNewLine]vy + 
                  my\^2 + 
                  2 \( n\/\(n - 1\)\) \((my\ vz - 
                        mz\ czy)\)}]]\);\)\)], "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    \(FamilyAlleleFrequencyEstimate[{family\_1, \[Ellipsis]}]\ gives\ the\ \
average\ allele\ frequency, \ 
    weighting\ each\ family\ \(\(equally\)\(.\)\)\)], "Subsubsection"],

Cell[BoxData[
    \(\(FamilyAlleleFrequencyEstimate[f_] := 
        Mean[\(\((Mean /@ DeleteCases[Transpose[#], \[EmptySet], 2]/2)\) &\) /@ 
            f];\)\)], "Input",
  InitializationCell->True]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(EstimateFamilyMoments[{family\_1, \[Ellipsis]}, 
        c[i, j, k, 
          l], {p\_1, \[Ellipsis]}]\ gives\ an\ estimate\ of\ the\ moment\ \
c[{i, j, k, l}], \ 
    based\ on\ the\ family\ \(\(data\)\(.\)\)\)], "Subsubsection"],

Cell[BoxData[
    \(\(EstimateFamilyMoments[families_, c_[i_, j_, k_, l_], pp_, 
          opts___Rule] := 
        Module[{m}, \[IndentingNewLine]\(\((c\  @@ 
                  Flatten[Sort[{Sort[{i, j}], Sort[{k, l}]}]])\) /. 
              MToC[m, c, i + j + k + l, Length[pp], Family \[Rule] True]\) /. 
            m[x__] \[RuleDelayed] 
              FamilyM[families, {x}, pp, opts]];\)\)], "Input",
  InitializationCell->True]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Working", "Subsection"],

Cell[CellGroupData[{

Cell[TextData[{
  "Testing FullGenotypeFrequencyTable[4]\nDiploidGenotypeFrequencyArguments",
  StyleBox["[4] takes 0.7s to generate; (",
    FontWeight->"Plain"],
  "FullGenotypeFrequencyTable",
  StyleBox["[4]@@#)&/@",
    FontWeight->"Plain"],
  "DiploidGenotypeFrequencyArguments",
  StyleBox["[4] takes 3.6s",
    FontWeight->"Plain"]
}], "Subsubsection"],

Cell[CellGroupData[{

Cell[BoxData[
    \(Timing[
      args = \(DiploidGenotypeFrequencyArguments[4]\)[0.4, 0.45, 0.6, 0.55, 
          0.6, 0.55, 0.4, 0.45, 0.02, 0, 0, 0.01, 0, 0, 0, 0, 0, 0]; ]\)], 
  "Input"],

Cell[BoxData[
    \({0.116666666666787932`\ Second, Null}\)], "Output"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    \(Timing[
      Table[\(FullGenotypeFrequencyTable[4, int]\)[0.4, 0.45, 0.6, 0.55, 0.6, 
          0.55, 0.4, 0.45, 1, 1, 1, 1, 1, 1, 1, 1, \n\t\t\t0.02, 0, 0, 0.01, 
          0, 0, 0, 0, 0, 0], {100}]; ]\)], "Input"],

Cell[BoxData[
    \({2.31666666666751552`\ Second, Null}\)], "Output"]
}, Closed]],

Cell["FullGenotypeFrequencyTable[4][] takes 0.01s to evaluate.", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(Timing[
      Table[\(FullGenotypeFrequencyTable[4, 1&]\)[0.4, 0.5, 0.6, 0.45, 0.4, 
          0.5, 0.6, 0.45, 1, 1, 1, 1, 1, 1, 1, 1, 0.01, 0, 0, 0.01, 0, 0, 0, 
          0, 0, 0], {100}]; ]\)], "Input"],

Cell[BoxData[
    \({2.43333333333339396`\ Second, Null}\)], "Output"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    \(Timing[
      Table[\(FullGenotypeFrequencyTable[4]\)[0.4, 0.5, 0.6, 0.45, 0.4, 0.5, 
          0.6, 0.45, 1, 1, 1, 1, 1, 1, 1, 1, 0.01, 0, 0, 0.01, 0, 0, 0, 0, 0, 
          0], {100}]; ]\)], "Input"],

Cell[BoxData[
    \({1.21666666666669698`\ Second, Null}\)], "Output"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["Testing FullGenotypeFrequencyTable - compiled versions", "Subsubsection"],

Cell["\<\
The routine is greatly speeded up if q & p are treated separately\
\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(Timing[
          Table[\(FullGenotypeFrequencyTable[{{0, 0, 0, 1}, {0, 1, 1, 0}}]\)[
              0.4,  .5, 0.4, 0.45, 0.6, 0.5, 0.6, 0.55, 0.01, 0, 0, 0.01, 0, 
              0, 0, 0, 0, 0], {100}]; ]\)[\([1]\)]/100\)], "Input"],

Cell[BoxData[
    \(0.00900000000000090949`\ Second\)], "Output"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    \(ByteCount[FullGenotypeFrequencyTable[{{0, 0, 0, 1}, {0, 1, 0, 0}}]]\)], 
  "Input"],

Cell[BoxData[
    \(282096\)], "Output"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    \(Timing[
      \(FullGenotypeFrequencyTable[4, symm]\)[0.4, 0.4, 0.4, 0.4, 0.01, 0, 0, 
        0.01, 0, 0, 0, 0, 0, 0]]\)], "Input"],

Cell[BoxData[
    \({119.84999999999999`\ Second, 0.00240809000000000139`}\)], "Output"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    \(Timing[
      \(FullGenotypeFrequencyTable[4, symm]\)[0.4, 0.4, 0.4, 0.4, 0.01, 0, 0, 
        0.01, 0, 0, 0, 0, 0, 0]]\)], "Input"],

Cell[BoxData[
    \({0.0166666666667083518`\ Second, 0.00240809000000000139`}\)], "Output"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    \(Timing[
      Table[\(\(FullGenotypeFrequencyTable[{{0, 0, 1, 1}, {0, 1, 0, 1}}]\)[
            0.2, 0.2, 0.2, 0.2, 1, 1, 1, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0];
          \), {100}]]\)], "Input"],

Cell[BoxData[
    \({2.88333333333332575`\ Second, {Null, Null, Null, Null, Null, Null, 
        Null, Null, Null, Null, Null, Null, Null, Null, Null, Null, Null, 
        Null, Null, Null, Null, Null, Null, Null, Null, Null, Null, Null, 
        Null, Null, Null, Null, Null, Null, Null, Null, Null, Null, Null, 
        Null, Null, Null, Null, Null, Null, Null, Null, Null, Null, Null, 
        Null, Null, Null, Null, Null, Null, Null, Null, Null, Null, Null, 
        Null, Null, Null, Null, Null, Null, Null, Null, Null, Null, Null, 
        Null, Null, Null, Null, Null, Null, Null, Null, Null, Null, Null, 
        Null, Null, Null, Null, Null, Null, Null, Null, Null, Null, Null, 
        Null, Null, Null, Null, Null, Null}}\)], "Output"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    \(Timing[
      Table[\(FullGenotypeFrequencyTable[{{0, 0, 1, 1}, {0, 1, 0, 1}}, \n
            \t\t\t{0, 0, 0, 0, 0, 0, 0, 0, 0, 0}, 1&, 0.2&];\), {100}]]\)], 
  "Input"],

Cell[BoxData[
    \({3.`\ Second, {Null, Null, Null, Null, Null, Null, Null, Null, Null, 
        Null, Null, Null, Null, Null, Null, Null, Null, Null, Null, Null, 
        Null, Null, Null, Null, Null, Null, Null, Null, Null, Null, Null, 
        Null, Null, Null, Null, Null, Null, Null, Null, Null, Null, Null, 
        Null, Null, Null, Null, Null, Null, Null, Null, Null, Null, Null, 
        Null, Null, Null, Null, Null, Null, Null, Null, Null, Null, Null, 
        Null, Null, Null, Null, Null, Null, Null, Null, Null, Null, Null, 
        Null, Null, Null, Null, Null, Null, Null, Null, Null, Null, Null, 
        Null, Null, Null, Null, Null, Null, Null, Null, Null, Null, Null, 
        Null, Null, Null}}\)], "Output"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["Speeding up DiploidGenotypeFrequencyTable", "Subsubsection"],

Cell[BoxData[
    \(\(\(PossibleDiploidGenotypes/@diploidTypes[4]; \) (*\ 2\ secs*) \)\)], 
  "Input"],

Cell[BoxData[
    \(\(\(\(DiploidGenotypeFrequencyTable[#, {{0, 0, 0}, {0, 0, 0, 0, 0, 0, 
              0}}, 1&, pE[0, 0.5, 1]]&\)/@diploidTypes[4]; 
    \) (*\ 35\ secs*) \)\)], "Input"],

Cell[BoxData[
    \(\(\(DiploidGenotypeFrequencyTable[{0, 2, 0, 0}, {cw, cb}, 1&, 
      pE[0, 0.5, 1], S]; \) (*2\ secs*) \)\)], "Input"],

Cell[BoxData[
    \(\(\(ve = 
      \(DiploidGenotypeFrequencyTable[#, {cw, cb}, 1&, pE[0, 0.5, 1], S]&\)/@
        rd\[LeftDoubleBracket]2\[RightDoubleBracket]; \) (*\ 244  s*) \)\)], 
  "Input"],

Cell[BoxData[
    \(rd = 
      Transpose[
        Select[reducedData[\(r[0, 0.5]\)[1]], \((#[\([1]\)] > 0)\)&]]; \n
    \t\ \ \ nt = Plus@@rd\[LeftDoubleBracket]1\[RightDoubleBracket]; \)], 
  "Input"],

Cell[BoxData[
    \(nt\ Log[nt] + 
        rd\[LeftDoubleBracket]1\[RightDoubleBracket] . 
          Log[ve\/rd\[LeftDoubleBracket]1\[RightDoubleBracket]] /. {
        cw[_] -> 0, cb[_] -> 0}\)], "Input"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(Timing[
      ll = LogLikelihoodDisequilibrium[\(r[0, 0.5]\)[1], {cw, cb}, 1&, 
          pE[0, 0.5, 1], S, gdt]; ]; \)\)], "Input"],

Cell[BoxData[
    \({150.700000000011646`\ Second, Null}\)], "Output"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(Timing[
      DiploidConstraints[\(r[0, 0.5]\)[1], {cw, cb}, 1&, pE[0, 0.5, 1], S, 
        gdt]; ]; \)\)], "Input"],

Cell[BoxData[
    \({0.`\ Second, Null}\)], "Output"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["\<\
Trying compiling DiploidGenotypeFrequencyTable
Takes 0.015s.  For 1063, LogLikelihoodDisequilibrium takes 124s to set up, \
0.017s therafter.\
\>", "Subsubsection"],

Cell[CellGroupData[{

Cell[BoxData[
    \(pl = ptable[data[1063]]; \n
    vv = Flatten[{pl, {{0.01, 0, 0}, {0.01, 0, 0, 0, 0, 0, 0}}}]; \n
    Timing[DiploidGenotypeFrequencyTable[{0, 2, 0, 0}, 1&]@@vv]\)], "Input"],

Cell[BoxData[
    \({125.36666666666667`\ Second, 0.00193966099006786212`}\)], "Output"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    \(Timing[DiploidGenotypeFrequencyTable[{0, 2, 0, 0}, 1&]@@vv]\)], "Input"],

Cell[BoxData[
    \({0.0166666666666515084`\ Second, 0.00193966099006786212`}\)], "Output"]
}, Closed]],

Cell["\<\
The problem with using the compiled version of \
DiploidGenotypeFrequencyTable is that it is irreducibly HUGE\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(cd = DiploidGenotypeFrequencyTable[{0, 2, 0, 0}, 1&]; 
    \n{ByteCount[cd], ByteCount[cd[\([4]\)]], 
      ByteCount[ReplacePart[cd, Function[{}, 1], 4]]}\)], "Input"],

Cell[BoxData[
    \({416528, 73648, 342936}\)], "Output"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["Compiling LogLikelihoodDisequilibrium", "Subsubsection"],

Cell[CellGroupData[{

Cell[BoxData[
    \(Timing[
      LogLikelihoodDisequilibrium[
        1063, {{0.01, 0, 0}, {0.01, 0, 0, 0, 0, 0, 0}}, 1&, 0.5&]]\)], "Input"],

Cell[BoxData[
    \({197.550000000000025`\ Second, \(-64.8127141276865437`\)}\)], "Output"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    \(Timing[
      LogLikelihoodDisequilibrium[
        1063, {{0.01, 0, 0}, {0.01, 0, 0, 0, 0, 0, 0}}, 1&, 0.4&]]\)], "Input"],

Cell[BoxData[
    \({0.816666666666662877`\ Second, \(-50.1664209309680853`\)}\)], "Output"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    \(rd = Transpose[Select[reducedData[1063], \((#[\([1]\)] > 0)\)&]]; \n\t
    nl = Length[rd\[LeftDoubleBracket]2, 1\[RightDoubleBracket]]; \ 
    nt = Plus@@rd\[LeftDoubleBracket]1\[RightDoubleBracket]; \n\t\t
    vv = Flatten[{pl, {{0.01, 0, 0}, {0.01, 0, 0, 0, 0, 0, 0}}}]\)], "Input"],

Cell[BoxData[
    RowBox[{"{", 
      RowBox[{
      \(29\/74\), ",", \(13\/74\), ",", \(12\/37\), ",", \(23\/74\), ",", 
        StyleBox["0.01`",
          StyleBoxAutoDelete->True,
          PrintPrecision->1], ",", "0", ",", "0", ",", 
        StyleBox["0.01`",
          StyleBoxAutoDelete->True,
          PrintPrecision->1], ",", "0", ",", "0", ",", "0", ",", "0", ",", 
        "0", ",", "0"}], "}"}]], "Output"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    \(Timing[
      nt\ Log[nt] + 
        rd\[LeftDoubleBracket]1\[RightDoubleBracket] . 
          Log[\(\(1\/rd\[LeftDoubleBracket]1\[RightDoubleBracket]\) 
                  \((DiploidGenotypeFrequencyTable[#, 1&]@@vv)\)&\)/@
              rd\[LeftDoubleBracket]2\[RightDoubleBracket]]]\)], "Input"],

Cell[BoxData[
    \({0.583333333333371228`\ Second, \(-38.8249180389305781`\)}\)], "Output"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    \(Length[rd[\([1]\)]]*0.01666\)], "Input"],

Cell[BoxData[
    \(0.316540000000000043`\)], "Output"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    \(\( (*\ Compiling\ seems\ to\ slow\ this\ \(down!\)*) \n
    cc = Compile[{p1, p2, p3, p4, cw2, cw3, cw4, cb2, cb3, cb4, cb5, cb6, 
          cb7, cb8}, 
        37\ Log[37] + {9, 2, 1, 2, 1, 1, 4, 1, 2, 1, 1, 1, 1, 1, 1, 4, 1, 2, 
              1} . Log[
              \(1\/{9, 2, 1, 2, 1, 1, 4, 1, 2, 1, 1, 1, 1, 1, 1, 4, 1, 2, 1}
                      \) \((\(\(DiploidGenotypeFrequencyTable[#, 1&]\)[p1, 
                        p2, p3, p4, cw2, cw3, cw4, cb2, cb3, cb4, cb5, cb6, 
                        cb7, cb8]&
                      \)/@{{0, 0, 0, 0}, {0, 0, 1, 0}, {0, 1, 1, 0}, {0, 1, 
                        2, 1}, {0, 1, 2, 2}, {0, 2, 2, 1}, {1, 0, 0, 0}, {1, 
                        0, 0, 1}, {1, 0, 0, 2}, {1, 0, 1, 1}, {1, 0, 1, 2}, {
                        1, 0, 2, 1}, {1, 1, 0, 1}, {1, 1, 1, 1}, {1, 1, 1, 
                        2}, {2, 0, 1, 0}, {2, 1, 0, 1}, {2, 1, 1, 1}, {2, 1, 
                        1, 2}})\)]]\)\)], "Input"],

Cell[BoxData[
    TagBox[\(CompiledFunction[{p1, p2, p3, p4, cw2, cw3, cw4, cb2, cb3, cb4, 
          cb5, cb6, cb7, cb8}, 
        37\ Log[37] + {9, 2, 1, 2, 1, 1, 4, 1, 2, 1, 1, 1, 1, 1, 1, 4, 1, 2, 
              1} . Log[\((\(gDipTable[#1, 1 &]\)[p1, p2, p3, p4, cw2, cw3, 
                        cw4, cb2, cb3, cb4, cb5, cb6, cb7, cb8] &)\) /@ {{0, 
                      0, 0, 0}, {0, 0, 1, 0}, {0, 1, 1, 0}, {0, 1, 2, 1}, {0, 
                      1, 2, 2}, {0, 2, 2, 1}, {1, 0, 0, 0}, {1, 0, 0, 1}, {1, 
                      0, 0, 2}, {1, 0, 1, 1}, {1, 0, 1, 2}, {1, 0, 2, 1}, {1, 
                      1, 0, 1}, {1, 1, 1, 1}, {1, 1, 1, 2}, {2, 0, 1, 0}, {2, 
                      1, 0, 1}, {2, 1, 1, 1}, {2, 1, 1, 2}}/{9, 2, 1, 2, 1, 
                  1, 4, 1, 2, 1, 1, 1, 1, 1, 1, 4, 1, 2, 1}], 
        "-CompiledCode-"]\),
      False,
      Editable->False]], "Output"]
}, Closed]],

Cell[BoxData[
    TagBox[\(CompiledFunction[{p1, p2, p3, p4, cw2, cw3, cw4, cb2, cb3, cb4, 
          cb5, cb6, cb7, cb8}, 
        37\ Log[37] + {9, 2, 1, 2, 1, 1, 4, 1, 2, 1, 1, 1, 1, 1, 1, 4, 1, 2, 
              1} . Log[\((\(gDipTable[#1, 1 &]\)[p1, p2, p3, p4, cw2, cw3, 
                        cw4, cb2, cb3, cb4, cb5, cb6, cb7, cb8] &)\) /@ {{0, 
                      0, 0, 0}, {0, 0, 1, 0}, {0, 1, 1, 0}, {0, 1, 2, 1}, {0, 
                      1, 2, 2}, {0, 2, 2, 1}, {1, 0, 0, 0}, {1, 0, 0, 1}, {1, 
                      0, 0, 2}, {1, 0, 1, 1}, {1, 0, 1, 2}, {1, 0, 2, 1}, {1, 
                      1, 0, 1}, {1, 1, 1, 1}, {1, 1, 1, 2}, {2, 0, 1, 0}, {2, 
                      1, 0, 1}, {2, 1, 1, 1}, {2, 1, 1, 2}}/{9, 2, 1, 2, 1, 
                  1, 4, 1, 2, 1, 1, 1, 1, 1, 1, 4, 1, 2, 
                  1}], "\<-CompiledCode-\>"]\),
      False,
      Editable->False]], "Input"],

Cell[BoxData[
    TagBox[\(CompiledFunction[{p1, p2, p3, p4, cw2, cw3, cw4, cb2, cb3, cb4, 
          cb5, cb6, cb7, cb8}, 
        37\ Log[37] + {9, 2, 1, 2, 1, 1, 4, 1, 2, 1, 1, 1, 1, 1, 1, 4, 1, 2, 
              1} . Log[\((\(gDipTable[#1, 1 &]\)[p1, p2, p3, p4, cw2, cw3, 
                        cw4, cb2, cb3, cb4, cb5, cb6, cb7, cb8] &)\) /@ {{0, 
                      0, 0, 0}, {0, 0, 1, 0}, {0, 1, 1, 0}, {0, 1, 2, 1}, {0, 
                      1, 2, 2}, {0, 2, 2, 1}, {1, 0, 0, 0}, {1, 0, 0, 1}, {1, 
                      0, 0, 2}, {1, 0, 1, 1}, {1, 0, 1, 2}, {1, 0, 2, 1}, {1, 
                      1, 0, 1}, {1, 1, 1, 1}, {1, 1, 1, 2}, {2, 0, 1, 0}, {2, 
                      1, 0, 1}, {2, 1, 1, 1}, {2, 1, 1, 2}}/{9, 2, 1, 2, 1, 
                  1, 4, 1, 2, 1, 1, 1, 1, 1, 1, 4, 1, 2, 
                  1}], "\<-CompiledCode-\>"]\),
      False,
      Editable->False]], "Input"],

Cell[CellGroupData[{

Cell[BoxData[
    \(Timing[Table[cc@@vv, {10}]; ]\)], "Input"],

Cell[BoxData[
    \({14.1166666666667879`\ Second, Null}\)], "Output"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["Compiling constraints", "Subsubsection"],

Cell[BoxData[
    \(Timing[
      \(DiploidGenotypeFrequencyTable[4, 1&]\)[0.4, 0.4, 0.5, 0.5, 0.01, 0, 
        0, 0.01, 0, 0, 0, 0, 0, 0]]\)], "Input"],

Cell[BoxData[
    \(\(Timing[
      FullGenotypeFrequencyTable[
        \({{0, 0, 0, 0}, {0, 0, 0, 0}]\)[1, 1, 1, 1, 0.4, 0.4, 0.5, 0.5, 
          0.01, 0, 0, 0.01, 0, 0, 0, 0, 0, 0]]\)\)], "Input"],

Cell[CellGroupData[{

Cell[BoxData[
    \(Timing[
      \(DiploidGenotypeFrequencyTable[\(diploidTypes[4]\)[\([1]\)], 1&]\)[
        0.4, 0.4, 0.5, 0.5, 0.01, 0, 0, 0.01, 0, 0, 0, 0, 0, 0]]\)], "Input"],

Cell[BoxData[
    \({124.349999999999982`\ Second, 0.0177499799999999989`}\)], "Output"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    \(MemoryInUse[]\)], "Input"],

Cell[BoxData[
    \(3922064\)], "Output"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    \(Timing[
      \(DiploidGenotypeFrequencyTable[\(diploidTypes[4]\)[\([2]\)], 1&]\)[
        0.4, 0.4, 0.5, 0.5, 0.01, 0, 0, 0.01, 0, 0, 0, 0, 0, 0]]\)], "Input"],

Cell[BoxData[
    \({6.98333333333329164`\ Second, 0.0228824400000000016`}\)], "Output"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    \(Timing[
      \(DiploidGenotypeFrequencyTable[\(diploidTypes[4]\)[\([2]\)], 1&]\)[
        0.4, 0.4, 0.5, 0.5, 0.02, 0, 0, 0.01, 0, 0, 0, 0, 0, 0]]\)], "Input"],

Cell[BoxData[
    \({0.0333333333333030168`\ Second, 0.0254674800000000001`}\)], "Output"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    \(MemoryInUse[]\)], "Input"],

Cell[BoxData[
    \(4266512\)], "Output"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    \(\((% - %%%)\) 81\)], "Input"],

Cell[BoxData[
    \(27900288\)], "Output"]
}, Closed]],

Cell[BoxData[
    \(\((k = 1; dt = diploidTypes[4]; \n
      While[If[k \[LessEqual] 81, 
          gg = \(DiploidGenotypeFrequencyTable[dt[\([k]\)], 1&]\)[0.4, 0.4, 
                0.5, 0.5, 0.01, 0, 0, 0.01, 0, 0, 0, 0, 0, 0] \[GreaterEqual] 
              0, False], If[k <= 81, Print[k, Tab, dt[\([k]\)], Tab, gg]]; 
        \(k++\)]; k > 81)\)\)], "Input"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\( (*164  s*) \n
    DiploidGenotypeFrequencyTable[{0, 0, 1, 0}, 1&]@@{0.4, 0.4, 0.5, 0.5, 
        0.01, 0, 0, 0.01, 0, 0, 0, 0, 0, 0}\)\)], "Input"],

Cell[BoxData[
    \(0.0228824400000000016`\)], "Output"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    \(\( (*16  s*) 
      DiploidGenotypeFrequencyTable[{0, 1, 1, 0}, 1&]@@{0.4, 0.4, 0.5, 0.5, 
        0.01, 0, 0, 0.01, 0, 0, 0, 0, 0, 0}\)\)], "Input"],

Cell[BoxData[
    \(0.0221119200000000004`\)], "Output"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(\((
          DiploidGenotypeFrequencyTable[#, 1&]@@
              Flatten[{
                  \(0.5&\)/@Range[4], {0.01, 0, 0, 0.01, 0, 0, 0, 0, 0, 
                    0}}] > 0)\)&\)/@{{0, 1, 1, 0}, {0, 0, 1, 0}}\)], "Input"],

Cell[BoxData[
    \({True, True}\)], "Output"]
}, Closed]],

Cell[BoxData[
    \(constraintsCheck[{0.01, 0, 0, 0.01, 0, 0, 0, 0, 0, 0}, 1&, 0.4&, 4]\)], 
  "Input"],

Cell[BoxData[
    \(Timing[
      constraintsCheck[{0.01, 0, 0, 0.01, 0, 0, 0, 0, 0, 0}, 1&, 0.4&, 4]]
      \)], "Input"],

Cell[BoxData[
    \(\(constraintsCheck[cl_List, \[Delta]p_, p_, nl_Integer] := 
      And@@\((\(\((
                DiploidGenotypeFrequencyTable[#, \[Delta]p]@@
                    Flatten[{p/@Range[nl], cl}] > 0)\)&\)/@diploidTypes[nl])
          \); \)\)], "Input"],

Cell[BoxData[
    \(Timing[
      \((And@@DiploidConstraints[{{0.01, 0, 0}, {0.01, 0, 0, 0, 0, 0, 0}}, 
            1&, 0.4&, 4])\)]\)], "Input"]
}, Closed]],

Cell[CellGroupData[{

Cell["Trying to simplify", "Subsubsection"],

Cell[TextData[{
  "I had hoped that the expression would simplify for cw=cb, and that the \
full expression could then be obtained by subtraction.  BUT that doesn't seem \
to work - I thhink because the actors are like ",
  Cell[BoxData[
      \(TraditionalForm\`\((\[Sum]p)\)\^k\)]],
  " but with coincident terms dropped."
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(g3 = 
      FullGenotypeFrequencyTable[{{1, 1, 1}, {1, 1, 1}}, {c, c}, 1&, 
        p, {1, 2, 3}]\)], "Input"],

Cell[BoxData[
    \(15\ c[2]\^3 + 10\ c[3]\^2 + 15\ c[2]\ c[4] + c[6] + 
      20\ c[2]\ c[3]\ p[1] + 2\ c[5]\ p[1] + 3\ c[2]\^2\ p[1]\^2 + 
      c[4]\ p[1]\^2 + 20\ c[2]\ c[3]\ p[2] + 2\ c[5]\ p[2] + 
      12\ c[2]\^2\ p[1]\ p[2] + 4\ c[4]\ p[1]\ p[2] + 
      2\ c[3]\ p[1]\^2\ p[2] + 3\ c[2]\^2\ p[2]\^2 + c[4]\ p[2]\^2 + 
      2\ c[3]\ p[1]\ p[2]\^2 + c[2]\ p[1]\^2\ p[2]\^2 + 
      20\ c[2]\ c[3]\ p[3] + 2\ c[5]\ p[3] + 12\ c[2]\^2\ p[1]\ p[3] + 
      4\ c[4]\ p[1]\ p[3] + 2\ c[3]\ p[1]\^2\ p[3] + 
      12\ c[2]\^2\ p[2]\ p[3] + 4\ c[4]\ p[2]\ p[3] + 
      8\ c[3]\ p[1]\ p[2]\ p[3] + 4\ c[2]\ p[1]\^2\ p[2]\ p[3] + 
      2\ c[3]\ p[2]\^2\ p[3] + 4\ c[2]\ p[1]\ p[2]\^2\ p[3] + 
      3\ c[2]\^2\ p[3]\^2 + c[4]\ p[3]\^2 + 2\ c[3]\ p[1]\ p[3]\^2 + 
      c[2]\ p[1]\^2\ p[3]\^2 + 2\ c[3]\ p[2]\ p[3]\^2 + 
      4\ c[2]\ p[1]\ p[2]\ p[3]\^2 + c[2]\ p[2]\^2\ p[3]\^2 + 
      p[1]\^2\ p[2]\^2\ p[3]\^2\)], "Output"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(Drop[CoefficientList[g3, c[4]], 1]\)[\([1]\)] // Factor\)], "Input"],

Cell[BoxData[
    \(15\ c[2] + p[1]\^2 + 4\ p[1]\ p[2] + p[2]\^2 + 4\ p[1]\ p[3] + 
      4\ p[2]\ p[3] + p[3]\^2\)], "Output"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    \(Drop[CoefficientList[g3, c[2]], 1]\)], "Input"],

Cell[BoxData[
    \({15\ c[4] + 20\ c[3]\ p[1] + 20\ c[3]\ p[2] + p[1]\^2\ p[2]\^2 + 
        20\ c[3]\ p[3] + 4\ p[1]\^2\ p[2]\ p[3] + 4\ p[1]\ p[2]\^2\ p[3] + 
        p[1]\^2\ p[3]\^2 + 4\ p[1]\ p[2]\ p[3]\^2 + p[2]\^2\ p[3]\^2, 
      3\ p[1]\^2 + 12\ p[1]\ p[2] + 3\ p[2]\^2 + 12\ p[1]\ p[3] + 
        12\ p[2]\ p[3] + 3\ p[3]\^2, 15}\)], "Output"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    \(Factor[
      p[1]\^2\ p[2]\^2 + 4\ p[1]\^2\ p[2]\ p[3] + 4\ p[1]\ p[2]\^2\ p[3] + 
        p[1]\^2\ p[3]\^2 + 4\ p[1]\ p[2]\ p[3]\^2 + p[2]\^2\ p[3]\^2]\)], 
  "Input"],

Cell[BoxData[
    \(p[1]\^2\ p[2]\^2 + 4\ p[1]\^2\ p[2]\ p[3] + 4\ p[1]\ p[2]\^2\ p[3] + 
      p[1]\^2\ p[3]\^2 + 4\ p[1]\ p[2]\ p[3]\^2 + p[2]\^2\ p[3]\^2\)], 
  "Output"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["Making a vector: too slow", "Subsubsection"],

Cell["\<\
Each call of FullGenotypeFrequencyTable[4,int] takes 0.023s; in \
principle, finding the 256 genotype frequencies should take 6s.  Constructing \
a matrix of 256 arguments takes 0.4s, and then applying \
FullGenotypeFrequencyTable[4,int] takes 5.7s as expected.  Time could be \
saved by finding only the 136 distinct frequencies, and by aborting if any \
one genotype frequency is negative.  However, at best that could only cut the \
time down to (say) 2s, implying 3000s per replicate, or 80 hours per set of \
runs.  \
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(Timing[
      Table[\(FullGenotypeFrequencyTable[4, int]\)[0.4, 0.45, 0.6, 0.55, 0.6, 
          0.55, 0.4, 0.45, 1, 1, 1, 1, 1, 1, 1, 1, \n\t\t\t0.02, 0, 0, 0.01, 
          0, 0, 0, 0, 0, 0], {100}]; ]\)], "Input"],

Cell[BoxData[
    \({2.31666666666751552`\ Second, Null}\)], "Output"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    \(Timing[
      args = \(arguments[4]\)[0.4, 0.45, 0.6, 0.55, 0.6, 0.55, 0.4, 0.45, 
            0.02, 0, 0, 0.01, 0, 0, 0, 0, 0, 0] /. {\(-1. \) -> \(-1\), 
            1.  -> 1}; ]\)], "Input"],

Cell[BoxData[
    \({0.433333333332484471`\ Second, Null}\)], "Output"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    \(Timing[gv = \(\((FullGenotypeFrequencyTable[4, int]@@#)\)&\)/@args; ]
      \)], "Input"],

Cell[BoxData[
    \({5.70000000000072759`\ Second, Null}\)], "Output"]
}, Closed]],

Cell[BoxData[
    \(Clear[gVector]; \n
    gVector[Z_, nl_] := 
      \(gVector[Z, nl] = 
        Module[{fZ, pl2, ql2}, \n\t\t\t\tfZ = Flatten[Z]; \n\t\t\t
          Compile[{{pl, _Real, 1}, {cl, _Real, 1}}, \n\t\t
            FullGenotypeFrequencyTable[nl, int]@@
              Join[pl2*fZ + \((1 - fZ)\) ql2, 2  fZ - 1, cl], \n
            \t\t{{pl2, _Real, 1}, {ql2, _Real, 1}, {fZ, _Integer, 1}}]]\); 
    \)], "Input"],

Cell[BoxData[
    \(\(gVector[{{0, 0, 1, 1}, {0, 0, 0, 0}}, 4]\)[{0.4, 0.45, 0.6, 0.55}, {\t
        0.02, 0, 0, 0.01, 0, 0, 0, 0, 0, 0}]\)], "Input"]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData[{
  "Failing to write a compiled version of ",
  "Matrix\[CapitalGamma]."
}], "Subsubsection"],

Cell[BoxData[
    \(Matrix\[CapitalGamma][2, v\[Delta]] = \n\t\t
      Compile[\ {{p, _Real, 1}, {\[Delta]p, _Real, 1}}, \n\t\t\t
        pv = \(AlleleFrequencyPermutations[2]\)[p]; \n\t\t\t
        \((\(\((Times@@#)\)&\)/@pv)\)*
          \((\({1, \(ProductSum[1]\)[#], \(ProductSum[2]\)[#]}&\)/@
              \((\(\[Delta]AlleleFrequencyPermutations[2, 
                      Compiled \[Rule] True]\)[\[Delta]p]/
                  \(AlleleFrequencyPermutations[2]\)[p])\))\), \n
        \t\t\t{{\(AlleleFrequencyPermutations[_]\)[_], _Real, 2}, {
            \(\[Delta]AlleleFrequencyPermutations[_, _]\)[_], _Real, 2}, {
            \(ProductSum[_]\)[_], _Real}, {pv, _Real, 2}}]; \n
    Matrix\[CapitalGamma][3, v\[Delta]] = \n\t\t
      Compile[\ {{p, _Real, 1}, {\[Delta]p, _Real, 1}}, \n\t\t
        pv = \(AlleleFrequencyPermutations[3]\)[p]; \n\t\t\t\t
        \((\(\((Times@@#)\)&\)/@pv)\)*
          \((\({1, \(ProductSum[1]\)[#], \(ProductSum[2]\)[#], 
                  \(ProductSum[3]\)[#]}&\)/@
              \((\(\[Delta]AlleleFrequencyPermutations[3, 
                      Compiled \[Rule] True]\)[\[Delta]p]/
                  \(AlleleFrequencyPermutations[3]\)[p])\))\), \n
        \t\t\t{{\(AlleleFrequencyPermutations[_]\)[_], _Real, 2}, {
            \(\[Delta]AlleleFrequencyPermutations[_, _]\)[_], _Real, 2}, {
            \(ProductSum[_]\)[_], _Real}, {pv, _Real, 2}}]; \n
    Matrix\[CapitalGamma][4, v\[Delta]] = \n\t\t
      Compile[\ {{p, _Real, 1}, {\[Delta]p, _Real, 1}}, \n\t\t
        pv = \(AlleleFrequencyPermutations[4]\)[p]; \n\t\t
        \((\(\((Times@@#)\)&\)/@pv)\)*
          \((\({1, \(ProductSum[1]\)[#], \(ProductSum[2]\)[#], 
                  \(ProductSum[3]\)[#], \(ProductSum[4]\)[#]}&\)/@
              \((\(\[Delta]AlleleFrequencyPermutations[4, 
                      Compiled \[Rule] True]\)[\[Delta]p]/pv)\))\), \n
        \t\t\t{{\(AlleleFrequencyPermutations[_]\)[_], _Real, 2}, {
            \(\[Delta]AlleleFrequencyPermutations[_, _]\)[_], _Real, 2}, {
            \(ProductSum[_]\)[_], _Real}, {pv, _Real, 2}}]; \n
    Matrix\[CapitalGamma][5, v\[Delta]] = \n\t\t
      Compile[\ {{p, _Real, 1}, {\[Delta]p, _Real, 1}}, \n\t\t
        pv = \(AlleleFrequencyPermutations[5]\)[p]; \n\t\t
        \((\(\((Times@@#)\)&\)/@pv)\)*
          \((\({1, \(ProductSum[1]\)[#], \(ProductSum[2]\)[#], 
                  \(ProductSum[3]\)[#], \(ProductSum[4]\)[#], 
                  \(ProductSum[5]\)[#]}&\)/@
              \((\(\[Delta]AlleleFrequencyPermutations[5, 
                      Compiled \[Rule] True]\)[\[Delta]p]/pv)\))\), \n
        \t\t\t{{\(AlleleFrequencyPermutations[_]\)[_], _Real, 2}, {
            \(\[Delta]AlleleFrequencyPermutations[_, _]\)[_], _Real, 2}, {
            \(ProductSum[_]\)[_], _Real}, {pv, _Real, 2}}]; \)], "Input"],

Cell[BoxData[
    \(\(Matrix\[CapitalGamma][4] = \n\t\t
      Compile[\ {{p, _Real, 1}}, \n\t\t
        pv = \(AlleleFrequencyPermutations[4]\)[p]; \n\t\t
        \((\(\((Times@@#)\)&\)/@pv)\)*
          \((\({1, \(ProductSum[1]\)[#], \(ProductSum[2]\)[#], 
                  \(ProductSum[3]\)[#], \(ProductSum[4]\)[#]}&\)/@
              \((\[Delta]AlleleFrequencyPermutations[4]/pv)\))\), \n
        \t\t\t{{\(AlleleFrequencyPermutations[_]\)[_], _Real, 2}, {
            \[Delta]AlleleFrequencyPermutations[_], _Integer, 2}, {
            \(ProductSum[_]\)[_], _Real}, {pv, _Real, 2}}]; \)\)], "Input"],

Cell[CellGroupData[{

Cell[BoxData[
    \(Timing[pv = \(AlleleFrequencyPermutations[4]\)[pl]; \n
      \((\(\((Times@@#)\)&\)/@pv)\)*
        \((\(Table[\(ProductSum[j]\)[#], {j, 4}]&\)/@
            \((\[Delta]AlleleFrequencyPermutations[4]/pv)\))\); ]\)], "Input"],

Cell[BoxData[
    \({0.266666666670062113`\ Second, Null}\)], "Output"]
}, Closed]],

Cell[BoxData[
    \(\(\(cf = 
      Compile[{{p, _Real, 1}}, pv = \(AlleleFrequencyPermutations[4]\)[pl]; 
        xx = \((\[Delta]AlleleFrequencyPermutations[4]/pv)\); \n\t\t
        \((\(\((Times@@#)\)&\)/@pv)\)*
          \((\({1, \(ProductSum[1]\)[#], \(ProductSum[2]\)[#], 
                  \(ProductSum[3]\)[#], \(ProductSum[4]\)[#]}&\)/@xx)\), 
        \t{{\(AlleleFrequencyPermutations[_]\)[_], _Real, 2}, {
            \[Delta]AlleleFrequencyPermutations[_], _Integer, 2}, {
            \(ProductSum[_]\)[_], _Real}, {pv, _Real, 2}, {xx, _Real, 2}}]; 
    \)\n\)\)], "Input"],

Cell[CellGroupData[{

Cell[BoxData[
    \(Timing[cf[pl]; ]\)], "Input"],

Cell[BoxData[
    \({6.`\ Second, Null}\)], "Output"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["Timings: overall, 0.32s for 4 loci", "Subsubsection"],

Cell[CellGroupData[{

Cell[BoxData[
    \(Timing[tt = Matrix\[CapitalGamma][pl, 4]; ]\)], "Input"],

Cell[BoxData[
    \({0.233333333329937886`\ Second, Null}\)], "Output"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    \(Timing[gg = tt . \(MomentReduced[4]\)[cl] . Transpose[tt]; ]\)], "Input"],

Cell[BoxData[
    \({0.0166666666627861559`\ Second, Null}\)], "Output"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    \(Timing[gv = GenotypeFrequencyConvert[gg, 4]; ]\)], "Input"],

Cell[BoxData[
    \({0.0833333333284826949`\ Second, Null}\)], "Output"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    \(Timing[
      gv = GenotypeFrequencyConvert[
          \((tt = Matrix\[CapitalGamma][pl, 4]; 
            tt . \(MomentReduced[4]\)[cl] . Transpose[tt])\), 4]; ]\)], 
  "Input"],

Cell[BoxData[
    \({0.316666666665696538`\ Second, Null}\)], "Output"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    \(gg // MatrixForm\)], "Input"],

Cell[BoxData[
    TagBox[
      RowBox[{"(", GridBox[{
            {"0.0123947362500000024`", "0.00995290125000000358`", 
              "0.00800638875000000282`", "0.00857622375000000225`", 
              "0.00501763875000000059`", "0.00553647374999999897`", 
              "0.00446873625000000096`", "0.00633190125000000314`", 
              "0.00383987625000000143`", "0.00437761125000000106`", 
              "0.00353574875000000066`", "0.00508401375000000133`", 
              "0.00230299875000000042`", "0.00331026375000000028`", 
              "0.0026488762500000007`", "0.00496561125000000203`"},
            {"0.00995290125000000003`", "0.00903327374999999932`", 
              "0.00728322375000000121`", "0.00873160124999999887`", 
              "0.00463947375000000139`", "0.00566635124999999906`", 
              "0.00456190125000000001`", "0.00722127375000000171`", 
              "0.00361054874999999997`", "0.00451690125000000008`", 
              "0.0036378262500000007`", "0.00581622374999999891`", 
              "0.00237557625000000038`", "0.00377247374999999962`", 
              "0.00299854875000000031`", "0.00633190124999999959`"},
            {"0.00800638875000000282`", "0.00728322375000000121`", 
              "0.00587298625000000029`", "0.00704215125000000163`", 
              "0.00374273625000000054`", "0.00457090125000000035`", 
              "0.00368038875000000142`", "0.00581622375000000157`", 
              "0.00291374875000000024`", "0.00364401375000000005`", 
              "0.0029351262500000006`", "0.00468486125000000086`", 
              "0.0019168762500000005`", "0.0030396112499999992`", 
              "0.00241674875`", "0.00508401375000000221`"},
            {"0.00857622375000000047`", "0.00873160125000000064`", 
              "0.00704215125000000341`", "0.00943902375000000226`", 
              "0.00453490125000000166`", "0.00613527375000000141`", 
              "0.00491922375000000133`", "0.00873160125000000419`", 
              "0.00357182625000000086`", "0.00491922375000000045`", 
              "0.00394529875000000274`", "0.00704215125000000341`", 
              "0.00257854875000000083`", "0.00453490125000000077`", 
              "0.00357182625000000131`", "0.00857622375000000225`"},
            {"0.00501763875000000147`", "0.00463947375000000139`", 
              "0.00374273625000000054`", "0.00453490125000000077`", 
              "0.00239048625000000081`", "0.00294565125000000005`", 
              "0.00237163875000000068`", "0.00377247375000000051`", 
              "0.0018649987500000007`", "0.00235026375000000076`", 
              "0.00189287625000000065`", "0.00303961125000000054`", 
              "0.00123662625000000003`", "0.00197236124999999908`", 
              "0.00156799875000000055`", "0.00331026375000000072`"},
            {"0.00553647374999999897`", "0.00566635124999999906`", 
              "0.00457090125000000035`", "0.00613527374999999963`", 
              "0.00294565125000000005`", "0.00398952374999999861`", 
              "0.00319947375000000011`", "0.00566635124999999995`", 
              "0.00232157625000000011`", "0.00319947374999999922`", 
              "0.00256654875000000082`", "0.00457090125000000035`", 
              "0.00167779874999999956`", "0.00294565125000000005`", 
              "0.00232157625000000011`", "0.00553647375000000074`"},
            {"0.00446873625000000185`", "0.00456190125000000001`", 
              "0.00368038875000000098`", "0.00491922375000000045`", 
              "0.00237163875000000023`", "0.00319947375000000011`", 
              "0.00256673625000000127`", "0.00451690125000000008`", 
              "0.00186887625000000046`", "0.00256561125000000078`", 
              "0.00205874875000000079`", "0.00364401375000000005`", 
              "0.00134599875000000035`", "0.00235026375000000076`", 
              "0.00185387625000000113`", "0.00437761125000000195`"},
            {"0.00633190125000000048`", "0.00722127375000000171`", 
              "0.00581622375000000157`", "0.00873160125000000064`", 
              "0.00377247374999999962`", "0.00566635124999999995`", 
              "0.00451690125000000008`", "0.00903327375000000287`", 
              "0.00299854875000000031`", "0.0045619012500000009`", 
              "0.00363782625000000159`", "0.0072832237500000021`", 
              "0.00237557625000000038`", "0.00463947375000000139`", 
              "0.00361054875000000041`", "0.0099529012500000018`"},
            {"0.00383987625000000054`", "0.00361054874999999997`", 
              "0.00291374875000000077`", "0.00357182625000000086`", 
              "0.00186499874999999981`", "0.00232157625000000011`", 
              "0.00186887625000000099`", "0.00299854875000000085`", 
              "0.00145807375000000005`", "0.00185387624999999989`", 
              "0.0014928012500000003`", "0.00241674875000000088`", 
              "0.00097555125000000018`", "0.00156799874999999966`", 
              "0.00124607375000000009`", "0.0026488762500000007`"},
            {"0.00437761124999999928`", "0.00451690125000000008`", 
              "0.00364401375000000005`", "0.00491922375000000045`", 
              "0.00235026375000000076`", "0.00319947374999999922`", 
              "0.00256561125000000078`", "0.00456190125000000001`", 
              "0.00185387625000000042`", "0.00256673624999999994`", 
              "0.00205874875000000079`", "0.00368038874999999965`", 
              "0.00134599874999999968`", "0.00237163874999999979`", 
              "0.00186887625000000046`", "0.00446873625000000185`"},
            {"0.00353574875000000066`", "0.0036378262500000007`", 
              "0.00293512625000000149`", "0.00394529875000000096`", 
              "0.00189287625000000065`", "0.00256654875000000082`", 
              "0.00205874875000000079`", "0.00363782625000000159`", 
              "0.0014928012500000003`", "0.00205874875000000034`", 
              "0.00165182375000000103`", "0.00293512625000000149`", 
              "0.0010800737500000006`", "0.00189287625000000048`", 
              "0.00149280125000000074`", "0.0035357487500000011`"},
            {"0.00508401375000000044`", "0.00581622375000000069`", 
              "0.00468486125000000086`", "0.00704215125000000163`", 
              "0.00303961125000000054`", "0.00457090125000000035`", 
              "0.00364401375000000182`", "0.0072832237500000021`", 
              "0.00241674875`", "0.00368038875000000098`", 
              "0.0029351262500000006`", "0.00587298625000000029`", 
              "0.0019168762500000005`", "0.00374273625000000009`", 
              "0.00291374875000000077`", "0.00800638875000000282`"},
            {"0.00230299875000000042`", "0.00237557625000000038`", 
              "0.0019168762500000005`", "0.00257854875000000038`", 
              "0.00123662625000000025`", "0.00167779875000000018`", 
              "0.00134599875000000035`", "0.00237557625000000038`", 
              "0.00097555125000000018`", "0.00134599874999999968`", 
              "0.00108007375000000038`", "0.0019168762500000005`", 
              "0.000706323750000000138`", "0.00123662625000000003`", 
              "0.000975551250000000536`", "0.00230299875000000087`"},
            {"0.00331026374999999983`", "0.00377247374999999873`", 
              "0.00303961125000000054`", "0.00453490124999999988`", 
              "0.00197236124999999908`", "0.00294565125000000005`", 
              "0.00235026375000000076`", "0.00463947375000000139`", 
              "0.00156799874999999966`", "0.00237163874999999979`", 
              "0.00189287625000000012`", "0.00374273625000000009`", 
              "0.00123662625000000003`", "0.00239048624999999992`", 
              "0.0018649987500000007`", "0.00501763875000000147`"},
            {"0.0026488762500000007`", "0.0029985487500000012`", 
              "0.00241674875000000133`", "0.00357182625000000131`", 
              "0.00156799875000000028`", "0.00232157625000000056`", 
              "0.0018538762500000006`", "0.00361054875000000219`", 
              "0.00124607375000000009`", "0.00186887625000000046`", 
              "0.00149280125000000074`", "0.00291374875000000077`", 
              "0.00097555125000000018`", "0.00186499875000000017`", 
              "0.00145807375000000094`", "0.00383987625000000143`"},
            {"0.00496561125000000203`", "0.00633190125000000314`", 
              "0.00508401375000000399`", "0.00857622375000000225`", 
              "0.00331026375000000072`", "0.00553647375000000074`", 
              "0.00437761125000000284`", "0.00995290125000000536`", 
              "0.00264887625000000115`", "0.00446873625000000096`", 
              "0.00353574875000000155`", "0.0080063887500000046`", 
              "0.00230299875000000087`", "0.00501763875000000059`", 
              "0.00383987625000000285`", "0.0123947362500000046`"}
            }], ")"}],
      (MatrixForm[ #]&)]], "Output"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    \(Timing[Table[\(ProductSumVector[4]\)[pl], {16}]; ]\)], "Input"],

Cell[BoxData[
    \({0.233333333333575865`\ Second, Null}\)], "Output"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    \(Timing[
      Table[{\(ProductSum[0]\)[pl], \(ProductSum[1]\)[pl], 
          \(ProductSum[2]\)[pl], \(ProductSum[3]\)[pl], 
          \(ProductSum[4]\)[pl]}, {16}]; ]\)], "Input"],

Cell[BoxData[
    \({0.150000000001455191`\ Second, Null}\)], "Output"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(ProductSum[4]\)[pl]\)], "Input"],

Cell[BoxData[
    \(0.0594000000000001193`\)], "Output"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(Table[\(ProductSum[j]\)[#], \ {j, \ 0, 4}]&\)/@%%%\)], "Input"],

Cell[BoxData[
    \({{1, \(-8.20707070707070762`\), 25.0420875420875432`, 
        \(-33.6700336700336766`\), 16.8350168350168871`}, {1, 
        \(-4.04040404040404066`\), 1.26262626262626298`, 
        11.2233445566778899`, \(-11.223344556677901`\)}, {1, 
        \(-4.16666666666666696`\), 0.860881542699726054`, 
        13.7741046831955915`, \(-13.7741046831956026`\)}, {1, 0.`, 
        \(-6.08356290174472036`\), 0.`, 9.18273645546373273`}, {1, 
        \(-4.16666666666666696`\), \(-0.771604938271604368`\), 
        20.5761316872427979`, \(-20.5761316872428068`\)}, {1, 0.`, 
        \(-7.71604938271605078`\), 0.`, 13.7174211248285393`}, {1, 
        \(-0.126262626262626298`\), \(-8.62794612794612802`\), 
        4.44089209850062616`*^-16, 16.8350168350168294`}, {1, 
        4.04040404040404066`, 1.26262626262626298`, 
        \(-11.2233445566778899`\), \(-11.223344556677901`\)}, {1, 
        \(-4.04040404040404066`\), \(-2.20959595959595844`\), 
        25.2525252525252508`, \(-25.2525252525252508`\)}, {1, 
        0.126262626262626298`, \(-8.62794612794612802`\), 
        \(-7.40148683083437575`*^-16\), 16.8350168350168294`}, {1, 0.`, 
        \(-9.55578512396694179`\), 0.`, 20.6611570247933817`}, {1, 
        4.16666666666666696`, 0.860881542699726054`, 
        \(-13.7741046831955915`\), \(-13.7741046831955982`\)}, {1, 0.`, 
        \(-11.1882716049382713`\), 0.`, 30.8641975308642013`}, {1, 
        4.16666666666666696`, \(-0.771604938271604368`\), 
        \(-20.5761316872427979`\), \(-20.5761316872428068`\)}, {1, 
        4.04040404040404066`, \(-2.20959595959595844`\), 
        \(-25.2525252525252508`\), \(-25.2525252525252508`\)}, {1, 
        8.20707070707070762`, 25.0420875420875432`, 33.6700336700336766`, 
        16.8350168350168871`}}\)], "Output"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    \(\((\(\[Delta]AlleleFrequencyPermutations[4]\)[\[Delta]pl]/
        \(AlleleFrequencyPermutations[4]\)[pl])\)\)], "Input"],

Cell[BoxData[
    \({{\(-1.66666666666666678`\), \(-1.81818181818181816`\), 
        \(-2.22222222222222232`\), \(-2.5`\)}, {\(-1.66666666666666678`\), 
        \(-1.81818181818181816`\), \(-2.22222222222222232`\), 
        1.66666666666666678`}, {\(-1.66666666666666678`\), 
        \(-1.81818181818181816`\), 1.81818181818181816`, \(-2.5`\)}, {
        \(-1.66666666666666678`\), \(-1.81818181818181816`\), 
        1.81818181818181816`, 1.66666666666666678`}, {
        \(-1.66666666666666678`\), 2.22222222222222232`, 
        \(-2.22222222222222232`\), \(-2.5`\)}, {\(-1.66666666666666678`\), 
        2.22222222222222232`, \(-2.22222222222222232`\), 
        1.66666666666666678`}, {\(-1.66666666666666678`\), 
        2.22222222222222232`, 1.81818181818181816`, \(-2.5`\)}, {
        \(-1.66666666666666678`\), 2.22222222222222232`, 
        1.81818181818181816`, 1.66666666666666678`}, {2.5`, 
        \(-1.81818181818181816`\), \(-2.22222222222222232`\), \(-2.5`\)}, {
        2.5`, \(-1.81818181818181816`\), \(-2.22222222222222232`\), 
        1.66666666666666678`}, {2.5`, \(-1.81818181818181816`\), 
        1.81818181818181816`, \(-2.5`\)}, {2.5`, \(-1.81818181818181816`\), 
        1.81818181818181816`, 1.66666666666666678`}, {2.5`, 
        2.22222222222222232`, \(-2.22222222222222232`\), \(-2.5`\)}, {2.5`, 
        2.22222222222222232`, \(-2.22222222222222232`\), 
        1.66666666666666678`}, {2.5`, 2.22222222222222232`, 
        1.81818181818181816`, \(-2.5`\)}, {2.5`, 2.22222222222222232`, 
        1.81818181818181816`, 1.66666666666666678`}}\)], "Output"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    \(Timing[\(Matrix\[CapitalGamma][4]\)[pl, \[Delta]pl]; ]\)], "Input"],

Cell[BoxData[
    \({0.233333333333575865`\ Second, Null}\)], "Output"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(\[Delta]AlleleFrequencyPermutations[4]\)[{1, 1, 1, 1}]/
      \(AlleleFrequencyPermutations[4]\)[{0.4, 0.45, 0.5, 0.6}]\)], "Input"],

Cell[BoxData[
    \({{\(-1.66666666666666678`\), \(-1.81818181818181816`\), \(-2.`\), 
        \(-2.5`\)}, {\(-1.66666666666666678`\), \(-1.81818181818181816`\), 
        \(-2.`\), 1.66666666666666678`}, {\(-1.66666666666666678`\), 
        \(-1.81818181818181816`\), 2.`, \(-2.5`\)}, {
        \(-1.66666666666666678`\), \(-1.81818181818181816`\), 2.`, 
        1.66666666666666678`}, {\(-1.66666666666666678`\), 
        2.22222222222222232`, \(-2.`\), \(-2.5`\)}, {
        \(-1.66666666666666678`\), 2.22222222222222232`, \(-2.`\), 
        1.66666666666666678`}, {\(-1.66666666666666678`\), 
        2.22222222222222232`, 2.`, \(-2.5`\)}, {\(-1.66666666666666678`\), 
        2.22222222222222232`, 2.`, 1.66666666666666678`}, {2.5`, 
        \(-1.81818181818181816`\), \(-2.`\), \(-2.5`\)}, {2.5`, 
        \(-1.81818181818181816`\), \(-2.`\), 1.66666666666666678`}, {2.5`, 
        \(-1.81818181818181816`\), 2.`, \(-2.5`\)}, {2.5`, 
        \(-1.81818181818181816`\), 2.`, 1.66666666666666678`}, {2.5`, 
        2.22222222222222232`, \(-2.`\), \(-2.5`\)}, {2.5`, 
        2.22222222222222232`, \(-2.`\), 1.66666666666666678`}, {2.5`, 
        2.22222222222222232`, 2.`, \(-2.5`\)}, {2.5`, 2.22222222222222232`, 
        2.`, 1.66666666666666678`}}\)], "Output"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    \(Clear[GenotypeFrequencyFast]\)], "Input"],

Cell[BoxData[
    StyleBox[
      \(GenotypeFrequencyFast[4]\  = \ 
        \(CompiledFunction[{{_Integer, \ 1}, \ {_Integer, \ 1}, 
            \ {_Real, \ 1}, \ {_Real, \ 1}, \ {_Real, \ 2}}, 
          \ {0, \ 20, \ 7, \ 0, \ 24}, 
          \ {{1, \ 2}, \ {6, \ 1, \ 1, \ 2, \ 0}, \ {6, \ 2, \ 1, \ 2, \ 1}, 
            \ {6, \ 3, \ 1, \ 3, \ 2}, \ {6, \ 4, \ 1, \ 3, \ 3}, 
            \ {6, \ 5, \ 2, \ 3, \ 4}, 
            \ {31, \ FuncFast[n_Integer]\  := \ 
                \(GenotypeFrequencyFast[n]\  = \ 
                  Module[{ptx, \ pty, \ sx, \ sy, \ psx, \ psy, \ 
                      \[Delta]ptx, \ \[Delta]pty, \ j}, \ 
                    Compile[{{X, \ _Integer, \ 1}, \ {Y, \ _Integer, \ 1}, 
                        \ {p, \ _Real, \ 1}, \ {\[Delta]p, \ _Real, \ 1}, 
                        \ {mm, \ _Real, \ 2}}, \ sx\  = \ 2*X\  - \ 1; \ 
                      sy\  = \ 2*Y\  - \ 1; \ ptx\  = \ 1\  - \ X\  + \ sx*p; 
                      \ pty\  = \ 1\  - \ Y\  + \ sy*p; \ 
                      \[Delta]ptx\  = \ \((\[Delta]p*sx)\)/ptx; \ 
                      \[Delta]pty\  = \ \((\[Delta]p*sy)\)/pty; \ 
                      psx\  = \ 
                        Table[\(ProductSum[j]\)[\[Delta]ptx], 
                          \ {j, \ 0, \ n}]; \ 
                      psy\  = \ 
                        Table[\(ProductSum[j]\)[\[Delta]pty], 
                          \ {j, \ 0, \ n}]; \ 
                      Times\ @@\ ptx*Times\ @@\ pty*psx\  . \ mm\  . \ psy, 
                      \ {{\(ProductSum[_]\)[_], \ _Real}, 
                        \ {sx, \ _Integer, \ 1}, \ {sy, \ _Integer, \ 1}, 
                        \ {ptx, \ _Real, \ 1}, \ {pty, \ _Real, \ 1}, 
                        \ {psx, \ _Real, \ 1}, \ {psy, \ _Real, \ 1}, 
                        \ {\[Delta]ptx, \ _Real, \ 1}, 
                        \ {\[Delta]pty, \ _Real, \ 1}, \ {j, \ _Integer}}]]
                    \)\)\),
      ShowStringCharacters->True,
      NumberMarks->True]], "Print",
  GeneratedCell->False,
  CellAutoOverwrite->False]
}, Closed]],

Cell[BoxData[
    \(\(mm = \(MomentReduced[4]\)[{0.02, 0, 0, 0.01, 0, 0, 0, 0, 0, 0}]; 
    \)\)], "Input"],

Cell[CellGroupData[{

Cell[BoxData[
    \(Timing[
      Table[mm = \(MomentReduced[4]\)[{0.02, 0, 0, 0.01, 0, 0, 0, 0, 0, 0}], {
          100}]; ]\)], "Input"],

Cell[BoxData[
    \({0.283333333336486248`\ Second, Null}\)], "Output"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    \(Timing[
      Table[\(GenotypeFrequencyFast[4]\)[{{0, 0, 1, 1}, {0, 1, 0, 0}}, {0.4, 
            0.45, 0.5, 0.55}, {1, 1, 1, 1}, mm], {100}]; ]\)], "Input"],

Cell[BoxData[
    \({4.`\ Second, Null}\)], "Output"]
}, Closed]],

Cell[BoxData[
    \(\(ft = Flatten[PossibleDiploidGenotypes/@diploidTypes[4], 1]; \)\)], 
  "Input"],

Cell[CellGroupData[{

Cell[BoxData[
    \(Timing[
      gv = \(\(GenotypeFrequencyFast[4]\)[#, {0.4, 0.45, 0.5, 0.55}, {1, 1, 
                1, 1}, mm]&\)/@ft; ]\)], "Input"],

Cell[BoxData[
    \({10.7000000000007267`\ Second, Null}\)], "Output"]
}, Closed]],

Cell[BoxData[
    \(gv\)], "Input"],

Cell[CellGroupData[{

Cell[BoxData[
    \(Timing[Table[\(ProductSum[4]\)[{0.4, 0.45, 0.5, 0.55}], {100}]; ]\)], 
  "Input"],

Cell[BoxData[
    \({0.516666666666424134`\ Second, Null}\)], "Output"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    \(Timing[Table[\(ProductSum[3]\)[{0.4, 0.45, 0.5, 0.55}], {100}]; ]\)], 
  "Input"],

Cell[BoxData[
    \({0.25`\ Second, Null}\)], "Output"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    \(Timing[Table[\(ProductSum[2]\)[{0.4, 0.45, 0.5, 0.55}], {100}]; ]\)], 
  "Input"],

Cell[BoxData[
    \({0.050000000002910383`\ Second, Null}\)], "Output"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(FullGenotypeFrequencyTable[{{0, 0, 1, 1}, {0, 1, 0, 0}}, {cw, cb}, 
          1&, \(({0.4, 0.45, 0.5, 0.55}[\([#]\)])\)&, {1, 2, 3, 4}] /. {
          cb[2] -> 0.01, cw[2] -> 0.02}\) /. {cb[_] -> 0, cw[_] -> 0}\)], 
  "Input"],

Cell[BoxData[
    \(0.00458431687499999984`\)], "Output"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["Testing genotype frequencies", "Subsubsection"],

Cell[BoxData[
    \(pl = {0.4, 0.45, 0.51, 0.55}; \n
    cl = {0.02, 0.01, 0.004, 0.01, 0.005, 0.002, 0.001, 0.0005, 0.0002, 
        0.0001}; \)], "Input"],

Cell[CellGroupData[{

Cell[BoxData[
    \(Timing[
      gv = GenotypeFrequencyConvert[
          \((tt = Matrix\[CapitalGamma][pl, 4]; 
            tt . \(MomentReduced[4]\)[cl] . Transpose[tt])\), 4]; ]\)], 
  "Input"],

Cell[BoxData[
    \({17.2500000000000008`\ Second, Null}\)], "Output"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    \(Timing[
      gv = GenotypeFrequencyConvert[
          \((tt = Matrix\[CapitalGamma][pl, 4]; 
            tt . \(MomentReduced[4]\)[cl] . Transpose[tt])\), 4]; ]\)], 
  "Input"],

Cell[BoxData[
    \({0.350000000000022737`\ Second, Null}\)], "Output"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    \(Partition[\(PaddedForm[#, 2]&\)/@gv, 9] // TableForm\)], "Input"],

Cell[BoxData[
    TagBox[GridBox[{
          {
            TagBox[
              InterpretationBox["\<\" 0.007\"\>",
                0.0070059007562500034,
                AutoDelete->True],
              (PaddedForm[ #, 2]&)], 
            TagBox[
              InterpretationBox["\<\" 0.017\"\>",
                0.017141302237500003,
                AutoDelete->True],
              (PaddedForm[ #, 2]&)], 
            TagBox[
              InterpretationBox["\<\" 0.0097\"\>",
                0.0097253895062500029,
                AutoDelete->True],
              (PaddedForm[ #, 2]&)], 
            TagBox[
              InterpretationBox["\<\" 0.015\"\>",
                0.014649697237500002,
                AutoDelete->True],
              (PaddedForm[ #, 2]&)], 
            TagBox[
              InterpretationBox["\<\" 0.033\"\>",
                0.03315364802500001,
                AutoDelete->True],
              (PaddedForm[ #, 2]&)], 
            TagBox[
              InterpretationBox["\<\" 0.016\"\>",
                0.016352969737500011,
                AutoDelete->True],
              (PaddedForm[ #, 2]&)], 
            TagBox[
              InterpretationBox["\<\" 0.0071\"\>",
                0.0071432145062500013,
                AutoDelete->True],
              (PaddedForm[ #, 2]&)], 
            TagBox[
              InterpretationBox["\<\" 0.014\"\>",
                0.013894924737500007,
                AutoDelete->True],
              (PaddedForm[ #, 2]&)], 
            TagBox[
              InterpretationBox["\<\" 0.0074\"\>",
                0.0073579532562500017,
                AutoDelete->True],
              (PaddedForm[ #, 2]&)]},
          {
            TagBox[
              InterpretationBox["\<\" 0.012\"\>",
                0.011569064737500001,
                AutoDelete->True],
              (PaddedForm[ #, 2]&)], 
            TagBox[
              InterpretationBox["\<\" 0.026\"\>",
                0.026201493025000005,
                AutoDelete->True],
              (PaddedForm[ #, 2]&)], 
            TagBox[
              InterpretationBox["\<\" 0.013\"\>",
                0.012701557237500006,
                AutoDelete->True],
              (PaddedForm[ #, 2]&)], 
            TagBox[
              InterpretationBox["\<\" 0.022\"\>",
                0.022437623024999999,
                AutoDelete->True],
              (PaddedForm[ #, 2]&)], 
            TagBox[
              InterpretationBox["\<\" 0.044\"\>",
                0.04384100895000001,
                AutoDelete->True],
              (PaddedForm[ #, 2]&)], 
            TagBox[
              InterpretationBox["\<\" 0.024\"\>",
                0.023914138025000004,
                AutoDelete->True],
              (PaddedForm[ #, 2]&)], 
            TagBox[
              InterpretationBox["\<\" 0.0091\"\>",
                0.0091081872375000025,
                AutoDelete->True],
              (PaddedForm[ #, 2]&)], 
            TagBox[
              InterpretationBox["\<\" 0.02\"\>",
                0.020452748025000002,
                AutoDelete->True],
              (PaddedForm[ #, 2]&)], 
            TagBox[
              InterpretationBox["\<\" 0.0099\"\>",
                0.0099241797375000003,
                AutoDelete->True],
              (PaddedForm[ #, 2]&)]},
          {
            TagBox[
              InterpretationBox["\<\" 0.0045\"\>",
                0.0044936670062500003,
                AutoDelete->True],
              (PaddedForm[ #, 2]&)], 
            TagBox[
              InterpretationBox["\<\" 0.0084\"\>",
                0.0083818397375000023,
                AutoDelete->True],
              (PaddedForm[ #, 2]&)], 
            TagBox[
              InterpretationBox["\<\" 0.0046\"\>",
                0.0045567857562500026,
                AutoDelete->True],
              (PaddedForm[ #, 2]&)], 
            TagBox[
              InterpretationBox["\<\" 0.0071\"\>",
                0.0070689147374999994,
                AutoDelete->True],
              (PaddedForm[ #, 2]&)], 
            TagBox[
              InterpretationBox["\<\" 0.016\"\>",
                0.016189073025000004,
                AutoDelete->True],
              (PaddedForm[ #, 2]&)], 
            TagBox[
              InterpretationBox["\<\" 0.0074\"\>",
                0.007438927237500002,
                AutoDelete->True],
              (PaddedForm[ #, 2]&)], 
            TagBox[
              InterpretationBox["\<\" 0.0033\"\>",
                0.00334873075625,
                AutoDelete->True],
              (PaddedForm[ #, 2]&)], 
            TagBox[
              InterpretationBox["\<\" 0.0061\"\>",
                0.0060939622375000011,
                AutoDelete->True],
              (PaddedForm[ #, 2]&)], 
            TagBox[
              InterpretationBox["\<\" 0.0059\"\>",
                0.0058530995062500034,
                AutoDelete->True],
              (PaddedForm[ #, 2]&)]},
          {
            TagBox[
              InterpretationBox["\<\" 0.0095\"\>",
                0.0094559179875000014,
                AutoDelete->True],
              (PaddedForm[ #, 2]&)], 
            TagBox[
              InterpretationBox["\<\" 0.021\"\>",
                0.021436541525000005,
                AutoDelete->True],
              (PaddedForm[ #, 2]&)], 
            TagBox[
              InterpretationBox["\<\" 0.01\"\>",
                0.010205655487500007,
                AutoDelete->True],
              (PaddedForm[ #, 2]&)], 
            TagBox[
              InterpretationBox["\<\" 0.018\"\>",
                0.018378391525000003,
                AutoDelete->True],
              (PaddedForm[ #, 2]&)], 
            TagBox[
              InterpretationBox["\<\" 0.035\"\>",
                0.035000961950000013,
                AutoDelete->True],
              (PaddedForm[ #, 2]&)], 
            TagBox[
              InterpretationBox["\<\" 0.019\"\>",
                0.019311416525000003,
                AutoDelete->True],
              (PaddedForm[ #, 2]&)], 
            TagBox[
              InterpretationBox["\<\" 0.0073\"\>",
                0.0073005654875000041,
                AutoDelete->True],
              (PaddedForm[ #, 2]&)], 
            TagBox[
              InterpretationBox["\<\" 0.017\"\>",
                0.016567746525000007,
                AutoDelete->True],
              (PaddedForm[ #, 2]&)], 
            TagBox[
              InterpretationBox["\<\" 0.0075\"\>",
                0.0074928029875000034,
                AutoDelete->True],
              (PaddedForm[ #, 2]&)]},
          {
            TagBox[
              InterpretationBox["\<\" 0.015\"\>",
                0.014599996524999999,
                AutoDelete->True],
              (PaddedForm[ #, 2]&)], 
            TagBox[
              InterpretationBox["\<\" 0.027\"\>",
                0.02680259195000001,
                AutoDelete->True],
              (PaddedForm[ #, 2]&)], 
            TagBox[
              InterpretationBox["\<\" 0.015\"\>",
                0.015024581525000006,
                AutoDelete->True],
              (PaddedForm[ #, 2]&)], 
            TagBox[
              InterpretationBox["\<\" 0.022\"\>",
                0.022369051950000003,
                AutoDelete->True],
              (PaddedForm[ #, 2]&)], 
            TagBox[
              InterpretationBox["\<\" 0.058\"\>",
                0.058119726100000033,
                AutoDelete->True],
              (PaddedForm[ #, 2]&)], 
            TagBox[
              InterpretationBox["\<\" 0.027\"\>",
                0.02740288195000002,
                AutoDelete->True],
              (PaddedForm[ #, 2]&)], 
            TagBox[
              InterpretationBox["\<\" 0.011\"\>",
                0.010986201524999999,
                AutoDelete->True],
              (PaddedForm[ #, 2]&)], 
            TagBox[
              InterpretationBox["\<\" 0.022\"\>",
                0.022017181950000006,
                AutoDelete->True],
              (PaddedForm[ #, 2]&)], 
            TagBox[
              InterpretationBox["\<\" 0.026\"\>",
                0.026377786525000006,
                AutoDelete->True],
              (PaddedForm[ #, 2]&)]},
          {
            TagBox[
              InterpretationBox["\<\" 0.0043\"\>",
                0.0043395204875000017,
                AutoDelete->True],
              (PaddedForm[ #, 2]&)], 
            TagBox[
              InterpretationBox["\<\" 0.01\"\>",
                0.010400196525000002,
                AutoDelete->True],
              (PaddedForm[ #, 2]&)], 
            TagBox[
              InterpretationBox["\<\" 0.0037\"\>",
                0.003700997987500002,
                AutoDelete->True],
              (PaddedForm[ #, 2]&)], 
            TagBox[
              InterpretationBox["\<\" 0.0089\"\>",
                0.0088846865250000011,
                AutoDelete->True],
              (PaddedForm[ #, 2]&)], 
            TagBox[
              InterpretationBox["\<\" 0.016\"\>",
                0.015514651950000001,
                AutoDelete->True],
              (PaddedForm[ #, 2]&)], 
            TagBox[
              InterpretationBox["\<\" 0.022\"\>",
                0.021886231525000015,
                AutoDelete->True],
              (PaddedForm[ #, 2]&)], 
            TagBox[
              InterpretationBox["\<\" 0.002\"\>",
                0.0020356679874999999,
                AutoDelete->True],
              (PaddedForm[ #, 2]&)], 
            TagBox[
              InterpretationBox["\<\" 0.019\"\>",
                0.019440401525000005,
                AutoDelete->True],
              (PaddedForm[ #, 2]&)], 
            TagBox[
              InterpretationBox["\<\" 0.0049\"\>",
                0.0049476454874999949,
                AutoDelete->True],
              (PaddedForm[ #, 2]&)]},
          {
            TagBox[
              InterpretationBox["\<\" 0.003\"\>",
                0.0030288693812499999,
                AutoDelete->True],
              (PaddedForm[ #, 2]&)], 
            TagBox[
              InterpretationBox["\<\" 0.0054\"\>",
                0.0053562049875000017,
                AutoDelete->True],
              (PaddedForm[ #, 2]&)], 
            TagBox[
              InterpretationBox["\<\" 0.0031\"\>",
                0.0030704681312500007,
                AutoDelete->True],
              (PaddedForm[ #, 2]&)], 
            TagBox[
              InterpretationBox["\<\" 0.0045\"\>",
                0.004496659987500002,
                AutoDelete->True],
              (PaddedForm[ #, 2]&)], 
            TagBox[
              InterpretationBox["\<\" 0.011\"\>",
                0.010880042525000001,
                AutoDelete->True],
              (PaddedForm[ #, 2]&)], 
            TagBox[
              InterpretationBox["\<\" 0.0042\"\>",
                0.0041737124875000026,
                AutoDelete->True],
              (PaddedForm[ #, 2]&)], 
            TagBox[
              InterpretationBox["\<\" 0.0023\"\>",
                0.0022970331312500004,
                AutoDelete->True],
              (PaddedForm[ #, 2]&)], 
            TagBox[
              InterpretationBox["\<\" 0.0033\"\>",
                0.0033061274875000016,
                AutoDelete->True],
              (PaddedForm[ #, 2]&)], 
            TagBox[
              InterpretationBox["\<\" 0.0043\"\>",
                0.0043158818812500024,
                AutoDelete->True],
              (PaddedForm[ #, 2]&)]},
          {
            TagBox[
              InterpretationBox["\<\" 0.0034\"\>",
                0.0034346374875000008,
                AutoDelete->True],
              (PaddedForm[ #, 2]&)], 
            TagBox[
              InterpretationBox["\<\" 0.0087\"\>",
                0.008662667524999999,
                AutoDelete->True],
              (PaddedForm[ #, 2]&)], 
            TagBox[
              InterpretationBox["\<\" 0.0027\"\>",
                0.0026609099875000023,
                AutoDelete->True],
              (PaddedForm[ #, 2]&)], 
            TagBox[
              InterpretationBox["\<\" 0.0075\"\>",
                0.0074586775249999987,
                AutoDelete->True],
              (PaddedForm[ #, 2]&)], 
            TagBox[
              InterpretationBox["\<\" 0.011\"\>",
                0.010930259950000009,
                AutoDelete->True],
              (PaddedForm[ #, 2]&)], 
            TagBox[
              InterpretationBox["\<\" 0.02\"\>",
                0.019711632525000002,
                AutoDelete->True],
              (PaddedForm[ #, 2]&)], 
            TagBox[
              InterpretationBox["\<\" 0.0013\"\>",
                0.0012740599874999999,
                AutoDelete->True],
              (PaddedForm[ #, 2]&)], 
            TagBox[
              InterpretationBox["\<\" 0.018\"\>",
                0.017997322525000005,
                AutoDelete->True],
              (PaddedForm[ #, 2]&)], 
            TagBox[
              InterpretationBox["\<\"-0.00098\"\>",
                -0.00098016751249999936,
                AutoDelete->True],
              (PaddedForm[ #, 2]&)]},
          {
            TagBox[
              InterpretationBox["\<\" 0.0015\"\>",
                0.0015486756312499998,
                AutoDelete->True],
              (PaddedForm[ #, 2]&)], 
            TagBox[
              InterpretationBox["\<\" 0.0012\"\>",
                0.0011546624875000016,
                AutoDelete->True],
              (PaddedForm[ #, 2]&)], 
            TagBox[
              InterpretationBox["\<\" 0.0034\"\>",
                0.00343990438125,
                AutoDelete->True],
              (PaddedForm[ #, 2]&)], 
            TagBox[
              InterpretationBox["\<\" 0.00055\"\>",
                0.00055379748749999921,
                AutoDelete->True],
              (PaddedForm[ #, 2]&)], 
            TagBox[
              InterpretationBox["\<\" 0.017\"\>",
                0.016795627524999999,
                AutoDelete->True],
              (PaddedForm[ #, 2]&)], 
            TagBox[
              InterpretationBox["\<\"-0.0071\"\>",
                -0.0071144100124999922,
                AutoDelete->True],
              (PaddedForm[ #, 2]&)], 
            TagBox[
              InterpretationBox["\<\" 0.0032\"\>",
                0.0032325893812500022,
                AutoDelete->True],
              (PaddedForm[ #, 2]&)], 
            TagBox[
              InterpretationBox["\<\"-0.011\"\>",
                -0.010732915012500011,
                AutoDelete->True],
              (PaddedForm[ #, 2]&)], 
            TagBox[
              InterpretationBox["\<\" 0.049\"\>",
                0.04904706813125001,
                AutoDelete->True],
              (PaddedForm[ #, 2]&)]}
          },
        RowSpacings->1,
        ColumnSpacings->3,
        RowAlignments->Baseline,
        ColumnAlignments->{Left}],
      (TableForm[ #]&)]], "Output"]
}, Closed]],

Cell[BoxData[
    \(\(args = 
      DiploidGenotypeFrequencyArguments[4]@@Flatten[{pl, 1 - pl, cl}] /. {
          1.  -> 1, \(-1. \) -> \(-1\)}; \)\)], "Input"],

Cell[BoxData[
    \(\(gv2 = \(\((FullGenotypeFrequencyTable[4, int]@@#)\)&\)/@args; \)\)], 
  "Input"],

Cell[BoxData[
    \(\(gv3 = GenotypeFrequencyConvert[Partition[gv2, 16], 4]; \)\)], "Input"],

Cell[CellGroupData[{

Cell[BoxData[
    \(Partition[\(PaddedForm[#, 2]&\)/@gv3, 9] // TableForm\)], "Input"],

Cell[BoxData[
    TagBox[GridBox[{
          {
            TagBox[
              InterpretationBox["\<\" 0.007\"\>",
                0.0070059007562499982,
                AutoDelete->True],
              (PaddedForm[ #, 2]&)], 
            TagBox[
              InterpretationBox["\<\" 0.017\"\>",
                0.017141302237500006,
                AutoDelete->True],
              (PaddedForm[ #, 2]&)], 
            TagBox[
              InterpretationBox["\<\" 0.0097\"\>",
                0.0097253895062499995,
                AutoDelete->True],
              (PaddedForm[ #, 2]&)], 
            TagBox[
              InterpretationBox["\<\" 0.015\"\>",
                0.014649697237500009,
                AutoDelete->True],
              (PaddedForm[ #, 2]&)], 
            TagBox[
              InterpretationBox["\<\" 0.033\"\>",
                0.03315364802499994,
                AutoDelete->True],
              (PaddedForm[ #, 2]&)], 
            TagBox[
              InterpretationBox["\<\" 0.016\"\>",
                0.016352969737500004,
                AutoDelete->True],
              (PaddedForm[ #, 2]&)], 
            TagBox[
              InterpretationBox["\<\" 0.0071\"\>",
                0.0071432145062499909,
                AutoDelete->True],
              (PaddedForm[ #, 2]&)], 
            TagBox[
              InterpretationBox["\<\" 0.014\"\>",
                0.013894924737499998,
                AutoDelete->True],
              (PaddedForm[ #, 2]&)], 
            TagBox[
              InterpretationBox["\<\" 0.0074\"\>",
                0.0073579532562500121,
                AutoDelete->True],
              (PaddedForm[ #, 2]&)]},
          {
            TagBox[
              InterpretationBox["\<\" 0.012\"\>",
                0.011569064737499989,
                AutoDelete->True],
              (PaddedForm[ #, 2]&)], 
            TagBox[
              InterpretationBox["\<\" 0.026\"\>",
                0.026201493025000026,
                AutoDelete->True],
              (PaddedForm[ #, 2]&)], 
            TagBox[
              InterpretationBox["\<\" 0.013\"\>",
                0.012701557237500008,
                AutoDelete->True],
              (PaddedForm[ #, 2]&)], 
            TagBox[
              InterpretationBox["\<\" 0.022\"\>",
                0.022437623024999999,
                AutoDelete->True],
              (PaddedForm[ #, 2]&)], 
            TagBox[
              InterpretationBox["\<\" 0.044\"\>",
                0.043841008949999927,
                AutoDelete->True],
              (PaddedForm[ #, 2]&)], 
            TagBox[
              InterpretationBox["\<\" 0.024\"\>",
                0.023914138025000035,
                AutoDelete->True],
              (PaddedForm[ #, 2]&)], 
            TagBox[
              InterpretationBox["\<\" 0.0091\"\>",
                0.0091081872375000008,
                AutoDelete->True],
              (PaddedForm[ #, 2]&)], 
            TagBox[
              InterpretationBox["\<\" 0.02\"\>",
                0.020452748025000026,
                AutoDelete->True],
              (PaddedForm[ #, 2]&)], 
            TagBox[
              InterpretationBox["\<\" 0.0099\"\>",
                0.0099241797374999795,
                AutoDelete->True],
              (PaddedForm[ #, 2]&)]},
          {
            TagBox[
              InterpretationBox["\<\" 0.0045\"\>",
                0.0044936670062500125,
                AutoDelete->True],
              (PaddedForm[ #, 2]&)], 
            TagBox[
              InterpretationBox["\<\" 0.0084\"\>",
                0.0083818397375000214,
                AutoDelete->True],
              (PaddedForm[ #, 2]&)], 
            TagBox[
              InterpretationBox["\<\" 0.0046\"\>",
                0.0045567857562499731,
                AutoDelete->True],
              (PaddedForm[ #, 2]&)], 
            TagBox[
              InterpretationBox["\<\" 0.0071\"\>",
                0.0070689147374999898,
                AutoDelete->True],
              (PaddedForm[ #, 2]&)], 
            TagBox[
              InterpretationBox["\<\" 0.016\"\>",
                0.016189073024999986,
                AutoDelete->True],
              (PaddedForm[ #, 2]&)], 
            TagBox[
              InterpretationBox["\<\" 0.0074\"\>",
                0.0074389272375000245,
                AutoDelete->True],
              (PaddedForm[ #, 2]&)], 
            TagBox[
              InterpretationBox["\<\" 0.0033\"\>",
                0.0033487307562499952,
                AutoDelete->True],
              (PaddedForm[ #, 2]&)], 
            TagBox[
              InterpretationBox["\<\" 0.0061\"\>",
                0.0060939622375000132,
                AutoDelete->True],
              (PaddedForm[ #, 2]&)], 
            TagBox[
              InterpretationBox["\<\" 0.0059\"\>",
                0.005853099506249999,
                AutoDelete->True],
              (PaddedForm[ #, 2]&)]},
          {
            TagBox[
              InterpretationBox["\<\" 0.0095\"\>",
                0.0094559179874999979,
                AutoDelete->True],
              (PaddedForm[ #, 2]&)], 
            TagBox[
              InterpretationBox["\<\" 0.021\"\>",
                0.021436541525000012,
                AutoDelete->True],
              (PaddedForm[ #, 2]&)], 
            TagBox[
              InterpretationBox["\<\" 0.01\"\>",
                0.010205655487500001,
                AutoDelete->True],
              (PaddedForm[ #, 2]&)], 
            TagBox[
              InterpretationBox["\<\" 0.018\"\>",
                0.018378391525000003,
                AutoDelete->True],
              (PaddedForm[ #, 2]&)], 
            TagBox[
              InterpretationBox["\<\" 0.035\"\>",
                0.035000961949999992,
                AutoDelete->True],
              (PaddedForm[ #, 2]&)], 
            TagBox[
              InterpretationBox["\<\" 0.019\"\>",
                0.019311416525000024,
                AutoDelete->True],
              (PaddedForm[ #, 2]&)], 
            TagBox[
              InterpretationBox["\<\" 0.0073\"\>",
                0.0073005654874999798,
                AutoDelete->True],
              (PaddedForm[ #, 2]&)], 
            TagBox[
              InterpretationBox["\<\" 0.017\"\>",
                0.016567746525000017,
                AutoDelete->True],
              (PaddedForm[ #, 2]&)], 
            TagBox[
              InterpretationBox["\<\" 0.0075\"\>",
                0.0074928029874999965,
                AutoDelete->True],
              (PaddedForm[ #, 2]&)]},
          {
            TagBox[
              InterpretationBox["\<\" 0.015\"\>",
                0.014599996525000006,
                AutoDelete->True],
              (PaddedForm[ #, 2]&)], 
            TagBox[
              InterpretationBox["\<\" 0.027\"\>",
                0.026802591949999982,
                AutoDelete->True],
              (PaddedForm[ #, 2]&)], 
            TagBox[
              InterpretationBox["\<\" 0.015\"\>",
                0.01502458152499998,
                AutoDelete->True],
              (PaddedForm[ #, 2]&)], 
            TagBox[
              InterpretationBox["\<\" 0.022\"\>",
                0.022369051949999972,
                AutoDelete->True],
              (PaddedForm[ #, 2]&)], 
            TagBox[
              InterpretationBox["\<\" 0.058\"\>",
                0.058119726100000012,
                AutoDelete->True],
              (PaddedForm[ #, 2]&)], 
            TagBox[
              InterpretationBox["\<\" 0.027\"\>",
                0.027402881950000013,
                AutoDelete->True],
              (PaddedForm[ #, 2]&)], 
            TagBox[
              InterpretationBox["\<\" 0.011\"\>",
                0.010986201525000013,
                AutoDelete->True],
              (PaddedForm[ #, 2]&)], 
            TagBox[
              InterpretationBox["\<\" 0.022\"\>",
                0.022017181950000013,
                AutoDelete->True],
              (PaddedForm[ #, 2]&)], 
            TagBox[
              InterpretationBox["\<\" 0.026\"\>",
                0.026377786525000009,
                AutoDelete->True],
              (PaddedForm[ #, 2]&)]},
          {
            TagBox[
              InterpretationBox["\<\" 0.0043\"\>",
                0.0043395204875000051,
                AutoDelete->True],
              (PaddedForm[ #, 2]&)], 
            TagBox[
              InterpretationBox["\<\" 0.01\"\>",
                0.010400196524999983,
                AutoDelete->True],
              (PaddedForm[ #, 2]&)], 
            TagBox[
              InterpretationBox["\<\" 0.0037\"\>",
                0.0037009979875000094,
                AutoDelete->True],
              (PaddedForm[ #, 2]&)], 
            TagBox[
              InterpretationBox["\<\" 0.0089\"\>",
                0.0088846865249999941,
                AutoDelete->True],
              (PaddedForm[ #, 2]&)], 
            TagBox[
              InterpretationBox["\<\" 0.016\"\>",
                0.015514651950000024,
                AutoDelete->True],
              (PaddedForm[ #, 2]&)], 
            TagBox[
              InterpretationBox["\<\" 0.022\"\>",
                0.021886231525000008,
                AutoDelete->True],
              (PaddedForm[ #, 2]&)], 
            TagBox[
              InterpretationBox["\<\" 0.002\"\>",
                0.002035667987500002,
                AutoDelete->True],
              (PaddedForm[ #, 2]&)], 
            TagBox[
              InterpretationBox["\<\" 0.019\"\>",
                0.019440401524999998,
                AutoDelete->True],
              (PaddedForm[ #, 2]&)], 
            TagBox[
              InterpretationBox["\<\" 0.0049\"\>",
                0.0049476454874999845,
                AutoDelete->True],
              (PaddedForm[ #, 2]&)]},
          {
            TagBox[
              InterpretationBox["\<\" 0.003\"\>",
                0.0030288693812499982,
                AutoDelete->True],
              (PaddedForm[ #, 2]&)], 
            TagBox[
              InterpretationBox["\<\" 0.0054\"\>",
                0.0053562049875,
                AutoDelete->True],
              (PaddedForm[ #, 2]&)], 
            TagBox[
              InterpretationBox["\<\" 0.0031\"\>",
                0.003070468131249999,
                AutoDelete->True],
              (PaddedForm[ #, 2]&)], 
            TagBox[
              InterpretationBox["\<\" 0.0045\"\>",
                0.0044966599875000002,
                AutoDelete->True],
              (PaddedForm[ #, 2]&)], 
            TagBox[
              InterpretationBox["\<\" 0.011\"\>",
                0.010880042525,
                AutoDelete->True],
              (PaddedForm[ #, 2]&)], 
            TagBox[
              InterpretationBox["\<\" 0.0042\"\>",
                0.0041737124875000017,
                AutoDelete->True],
              (PaddedForm[ #, 2]&)], 
            TagBox[
              InterpretationBox["\<\" 0.0023\"\>",
                0.0022970331312500074,
                AutoDelete->True],
              (PaddedForm[ #, 2]&)], 
            TagBox[
              InterpretationBox["\<\" 0.0033\"\>",
                0.0033061274874999947,
                AutoDelete->True],
              (PaddedForm[ #, 2]&)], 
            TagBox[
              InterpretationBox["\<\" 0.0043\"\>",
                0.0043158818812500024,
                AutoDelete->True],
              (PaddedForm[ #, 2]&)]},
          {
            TagBox[
              InterpretationBox["\<\" 0.0034\"\>",
                0.0034346374874999973,
                AutoDelete->True],
              (PaddedForm[ #, 2]&)], 
            TagBox[
              InterpretationBox["\<\" 0.0087\"\>",
                0.0086626675249999903,
                AutoDelete->True],
              (PaddedForm[ #, 2]&)], 
            TagBox[
              InterpretationBox["\<\" 0.0027\"\>",
                0.0026609099874999988,
                AutoDelete->True],
              (PaddedForm[ #, 2]&)], 
            TagBox[
              InterpretationBox["\<\" 0.0075\"\>",
                0.0074586775250000022,
                AutoDelete->True],
              (PaddedForm[ #, 2]&)], 
            TagBox[
              InterpretationBox["\<\" 0.011\"\>",
                0.010930259950000028,
                AutoDelete->True],
              (PaddedForm[ #, 2]&)], 
            TagBox[
              InterpretationBox["\<\" 0.02\"\>",
                0.019711632525000019,
                AutoDelete->True],
              (PaddedForm[ #, 2]&)], 
            TagBox[
              InterpretationBox["\<\" 0.0013\"\>",
                0.0012740599875000094,
                AutoDelete->True],
              (PaddedForm[ #, 2]&)], 
            TagBox[
              InterpretationBox["\<\" 0.018\"\>",
                0.017997322525000008,
                AutoDelete->True],
              (PaddedForm[ #, 2]&)], 
            TagBox[
              InterpretationBox["\<\"-0.00098\"\>",
                -0.00098016751249999047,
                AutoDelete->True],
              (PaddedForm[ #, 2]&)]},
          {
            TagBox[
              InterpretationBox["\<\" 0.0015\"\>",
                0.0015486756312500024,
                AutoDelete->True],
              (PaddedForm[ #, 2]&)], 
            TagBox[
              InterpretationBox["\<\" 0.0012\"\>",
                0.001154662487499999,
                AutoDelete->True],
              (PaddedForm[ #, 2]&)], 
            TagBox[
              InterpretationBox["\<\" 0.0034\"\>",
                0.0034399043812499957,
                AutoDelete->True],
              (PaddedForm[ #, 2]&)], 
            TagBox[
              InterpretationBox["\<\" 0.00055\"\>",
                0.00055379748750000767,
                AutoDelete->True],
              (PaddedForm[ #, 2]&)], 
            TagBox[
              InterpretationBox["\<\" 0.017\"\>",
                0.016795627524999995,
                AutoDelete->True],
              (PaddedForm[ #, 2]&)], 
            TagBox[
              InterpretationBox["\<\"-0.0071\"\>",
                -0.0071144100125000546,
                AutoDelete->True],
              (PaddedForm[ #, 2]&)], 
            TagBox[
              InterpretationBox["\<\" 0.0032\"\>",
                0.0032325893812500013,
                AutoDelete->True],
              (PaddedForm[ #, 2]&)], 
            TagBox[
              InterpretationBox["\<\"-0.011\"\>",
                -0.010732915012500014,
                AutoDelete->True],
              (PaddedForm[ #, 2]&)], 
            TagBox[
              InterpretationBox["\<\" 0.049\"\>",
                0.04904706813125001,
                AutoDelete->True],
              (PaddedForm[ #, 2]&)]}
          },
        RowSpacings->1,
        ColumnSpacings->3,
        RowAlignments->Baseline,
        ColumnAlignments->{Left}],
      (TableForm[ #]&)]], "Output"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(\((Plus@@\(Plus@@#\))\)&\)/@{gv, gv2}\)], "Input"],

Cell[BoxData[
    \({1.`, 0.999999999999999644`}\)], "Output"]
}, Closed]]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["Working: using moments", "Subsection"],

Cell[CellGroupData[{

Cell["Making a table of MomentEquilibrium[]", "Subsubsection"],

Cell[CellGroupData[{

Cell[BoxData[
    \(Table[
        MomentEquilibrium[{Range[j], Range[k]} /. Combine, c, 0.2, 0, 0.5, 
          UnlinkedRecombination, 1&, 0&], {j, 0, 4}, {k, 0, 4}] // MatrixForm
      \)], "Input"],

Cell[BoxData[
    TagBox[
      RowBox[{"(", GridBox[{
            {"1.`", "0.`", "0.116666666666666674`", "0.`", 
              "0.0254629629629629672`"},
            {"0.`", "0.05`", "0.`", "0.0125`", "0.`"},
            {"0.116666666666666674`", "0.`", "0.0180555555555555571`", "0.`", 
              "0.00420524691358024682`"},
            {"0.`", "0.0125`", "0.`", "0.003125`", "0.`"},
            {"0.0254629629629629672`", "0.`", "0.00420524691358024682`", 
              "0.`", "0.00099129801097393706`"}
            }], ")"}],
      (MatrixForm[ #]&)]], "Output"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData[{
  "Speeding up GenotypeFrequencyConvert[]\nCompiling doesn't speed \
\[CapitalGamma]v.cc.Transpose[\[CapitalGamma]v] - only takes 0.006s either \
way\nGenotypeFrequencyConvert[] takes 0.085s, ",
  "LogLikelihoodDisequilibrium",
  "[][] 0.01s, Matrix\[CapitalGamma][] 0.2s"
}], "Subsubsection"],

Cell[BoxData[
    \(pE = {0.4, 0.45,  .51, 0.58}; 
    cc = ReplacePart[Array[0&, {5, 5}], 1, {1, 1}]; \)], "Input"],

Cell[CellGroupData[{

Cell[BoxData[
    \(Timing[Table[\(Matrix\[CapitalGamma][pE, 4];\), {100}]; ]\)], "Input"],

Cell[BoxData[
    \({21.9499999999998163`\ Second, Null}\)], "Output"]
}, Closed]],

Cell[BoxData[
    \(Matrix\[CapitalGamma]v = Matrix\[CapitalGamma][pE, 4]; \n
    cf = Compile[{{Matrix\[CapitalGamma]v, _Real, 2}, {cc, _Real, 2}}, 
        Matrix\[CapitalGamma]v . cc . Transpose[Matrix\[CapitalGamma]v]]; 
    \)], "Input"],

Cell[CellGroupData[{

Cell[BoxData[
    \({Timing[Table[\(gv = cf[Matrix\[CapitalGamma]v, cc];\), {100}]; ], 
      Timing[Table[
          \(gv = Matrix\[CapitalGamma]v . cc . 
                Transpose[Matrix\[CapitalGamma]v];\), {100}]; ]}\)], "Input"],

Cell[BoxData[
    \({{0.616666666666674245`\ Second, Null}, {0.699999999999988631`\ Second, 
        Null}}\)], "Output"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    \(Timing[Table[\(dgv = GenotypeFrequencyConvert[gv, 4];\), {100}]; ]\)], 
  "Input"],

Cell[BoxData[
    \({8.5166666666666515`\ Second, Null}\)], "Output"]
}, Closed]],

Cell[BoxData[
    \(\(\ rd = reducedData[1063, simple]; 
    nz = Position[rd, _?\((\((# > 0)\)&)\)]; \nobs = Extract[rd, nz]; \ 
    ntot = Plus@@obs; \)\)], "Input"],

Cell[CellGroupData[{

Cell[BoxData[
    \(Timing[
      Table[\(\(LogLikelihoodDisequilibrium[ntot]\)[obs, Extract[dgv, nz]];
          \), {100}]; ]\)], "Input"],

Cell[BoxData[
    \({0.133333333333325754`\ Second, Null}\)], "Output"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(LogLikelihoodDisequilibrium[37][\)\)], "Input"],

Cell[BoxData[
    \("LogLikelihoodDisequilibrium[site,{cw,cb},\[Delta]p,p,{i,j,k,l}] gives \
an expression for the log likelihood of {cw,cb}. \
LogLikelihoodDisequilibrium[site,{cw,cb},\[Delta]p,p,{i,j,k,l},gdt] stores \
the definition of DiploidGenotypeFrequencyTable[X,..] in gdt[X].   \
LogLikelihoodDisequilibrium[site,{cw,cb},\[Delta]p,p] uses the fully compiled \
version but cannot itself be compiled. \
LogLikelihoodDisequilibrium[ntot][{obs..},{exp}] is a compiled function; obs \
must be nonzero.  LogLikelihoodDisequilibrium[site,{cw,cb},p] uses this: \
fastest method if \[Delta]p=1"\)], "Print",
  GeneratedCell->False,
  CellAutoOverwrite->False]
}, Closed]]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["One way and pairwise estimates", "Subsection"],

Cell[CellGroupData[{

Cell[BoxData[
    StyleBox[\(MakeOneWayTable[
          site]\ generates\ a\ table\ of\ estimates\ of\ p\ and\ F, \ 
      for\ each\ locus\ in\ Data[
            site] . \ \ The\ table\ consists\ of\ a\ list\ of\ {p, F\&^, 
          L}, \ where\ L\ is\ the\ log\ likelihood\ ratio\ comparing\ F = \(0\
\ with\ F = F\&^ . \ In\ the\ general\ moment\ notation\), \ 
      F = \(\(c\_\(1, \ 1\)\)\(.\)\)\),
      FontFamily->"Times"]], "Subsubsection"],

Cell[BoxData[
    RowBox[{
      RowBox[{\(MakeOneWayTable[s_]\), ":=", 
        RowBox[{"Module", "[", 
          
          RowBox[{\({pl, j, nl = NumberOfLoci[s], lf, f}\), ",", 
            "\[IndentingNewLine]", 
            
            RowBox[{\(pl = \(\(AlleleFrequencyTable[s, nl] // N\) // 
                    Transpose\) // Last\), ";", "\[IndentingNewLine]", 
              RowBox[{\(lf[j_Integer, f_]\), ":=", 
                RowBox[{"(", 
                  RowBox[{\(SelectLoci[{s, {j}}, s, {j}]\), ";", 
                    RowBox[{"-", 
                      RowBox[{"LogLikelihoodDisequilibrium", "[", 
                        
                        RowBox[{\({s, {j}}\), 
                          ",", \(pl\[LeftDoubleBracket]{j}\
\[RightDoubleBracket]\), ",", \({1}\), ",", 
                          RowBox[{"(", GridBox[{
                                {"1", "0"},
                                {"0", "f"}
                                }], ")"}], ",", \(Compiled \[Rule] True\)}], 
                        "]"}]}]}], ")"}]}], ";", "\[IndentingNewLine]", 
              RowBox[{"Table", "[", "\[IndentingNewLine]", 
                RowBox[{
                  RowBox[{
                    RowBox[{"fm", "=", 
                      RowBox[{"FindMinimum", "[", 
                        RowBox[{\(lf[j, f]\), ",", 
                          RowBox[{"{", 
                            RowBox[{"f", ",", 
                              RowBox[{
                                RowBox[{"MomentLimits", "[", 
                                  
                                  RowBox[{\({1, 1}\), 
                                    ",", \(pl\[LeftDoubleBracket]{j}\
\[RightDoubleBracket]\), ",", \({1}\), ",", 
                                    RowBox[{"(", GridBox[{
                                        {"1", "0"},
                                        {"0", "0"}
                                        }], ")"}]}], "]"}], "/", "2"}]}], 
                            "}"}]}], "]"}]}], ";", 
                    "\[IndentingNewLine]", \({pl\[LeftDoubleBracket]
                        j\[RightDoubleBracket], \(f /. \
fm\[LeftDoubleBracket]2\[RightDoubleBracket]\)\/\(pl\[LeftDoubleBracket]j\
\[RightDoubleBracket] \((1 - \
pl\[LeftDoubleBracket]j\[RightDoubleBracket])\)\), lf[j, 0]}\)}], 
                  ",", \({j, NumberOfLoci[s]}\)}], "]"}]}]}], "]"}]}], 
      ";"}]], "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{

Cell["\<\
PresentOneWayTable[site] presents a table of allele frequency, F, \
and log(L) for each locus.\
\>", "Subsubsection"],

Cell[BoxData[
    \(\(PresentOneWayTable[s_] := 
        Prepend[Transpose[
            Prepend[Transpose[MakeOneWayTable[s]], 
              LocusNames[
                s]]], {"\<Locus\>", "\<p\>", \*"\"\<\!\(\(F\&^\)\)\>\"", "\<L\
\>"}];\)\)], "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    StyleBox[\(MakePairwiseTable[
          site]\ generates\ a\ table\ of\ estimates\ of\ F, \ 
      D\ and\ correlations\ between\ them, \ 
      for\ each\ pair\ of\ loci\ in\ Data[site] . \ \ For\ each\ pair, \ 
      the\ table\ contains\ \ a\ list\ of\ {L, {F, D, cov[F, D], 
            cov[F\_1, F\_2]}}, \ for\ the\ hypotheses\ that\ all\ F, \ 
      D = 0; \ that\ F \[NotEqual] 0; \ that\ D \[NotEqual] 0; \ 
      that\ F \[NotEqual] 
        0\ and\ heterozygosities\ are\ correlated\ across\ loci\ \((cov[F\_1, 
                F\_2] \[NotEqual] 0)\); \ 
      and\ that\ all\ associations\ are\ non - 
        zero . \ The\ associated\ #\ of\ degreees\ of\ freedom\ are\ {0, 1, 
              1, 2, 4} . \ \ In\ the\ general\ moment\ notation, \ 
      F = c\_\(1, 1\), D = c\_\(0, 2\), cov[F, D] = c\_\(2, 1\), 
      cov[F\_1, F\_2] = 
        c\_\(2, 2\) . \ \ Generates\ subsets\ of\ the\ data\ which\ are\ \
labelled\ \(\({s, {j, k}}\)\(.\)\)\),
      FontFamily->"Times"]], "Subsubsection"],

Cell[BoxData[
    RowBox[{
      RowBox[{\(MakePairwiseTable[s_]\), ":=", 
        RowBox[{"Module", "[", 
          
          RowBox[{\({pl, j, k, nl = NumberOfLoci[s], lf, fmA, fmF, fmD, fmFC, 
              mlF, mlD, mlFC, mlFD}\), ",", "\[IndentingNewLine]", 
            
            RowBox[{\(pl = \(\(AlleleFrequencyTable[s, nl] // N\) // 
                    Transpose\) // Last\), ";", 
              "\[IndentingNewLine]", \(lf[{j_Integer, k_Integer}, 
                  c_] := \((SelectLoci[{s, {j, k}}, s, {j, k}]; 
                  LogLikelihoodDisequilibrium[{s, {j, k}}, 
                    pl\[LeftDoubleBracket]{j, k}\[RightDoubleBracket], {1, 
                      1}, c, Compiled \[Rule] True])\)\), ";", 
              "\[IndentingNewLine]", 
              RowBox[{"Table", "[", "\[IndentingNewLine]", 
                RowBox[{
                  RowBox[{
                    RowBox[{"mlF", "=", 
                      RowBox[{
                        RowBox[{"MomentLimits", "[", 
                          
                          RowBox[{\({1, 1}\), 
                            ",", \(pl\[LeftDoubleBracket]{j, 
                                k}\[RightDoubleBracket]\), ",", \({1, 1}\), 
                            ",", 
                            RowBox[{"(", GridBox[{
                                  {"1", "0", "0"},
                                  {"0", "0", "0"},
                                  {"0", "0", "0"}
                                  }], ")"}]}], "]"}], "/", "2"}]}], ";", 
                    "\[IndentingNewLine]", 
                    RowBox[{"fmF", "=", 
                      RowBox[{"FindMinimum", "[", 
                        RowBox[{
                          RowBox[{"-", 
                            RowBox[{"lf", "[", 
                              RowBox[{\({j, k}\), ",", 
                                RowBox[{"(", GridBox[{
                                      {"1", "0", "0"},
                                      {"0", "f", "0"},
                                      {"0", "0", "0"}
                                      }], ")"}]}], "]"}]}], 
                          ",", \({f, mlF}\)}], "]"}]}], ";", 
                    "\[IndentingNewLine]", 
                    RowBox[{"mlFC", "=", 
                      RowBox[{
                        RowBox[{"MomentLimits", "[", 
                          
                          RowBox[{\({2, 2}\), 
                            ",", \(pl\[LeftDoubleBracket]{j, 
                                k}\[RightDoubleBracket]\), ",", \({1, 1}\), 
                            ",", 
                            RowBox[{"(", GridBox[{
                                  {"1", "0", "0"},
                                  {"0", "0", "0"},
                                  {"0", "0", "0"}
                                  }], ")"}]}], "]"}], "/", "2"}]}], ";", 
                    "\[IndentingNewLine]", 
                    RowBox[{"fmFC", "=", 
                      RowBox[{"FindMinimum", "[", 
                        RowBox[{
                          RowBox[{"-", 
                            RowBox[{"lf", "[", 
                              RowBox[{\({j, k}\), ",", 
                                RowBox[{"(", GridBox[{
                                      {"1", "0", "0"},
                                      {"0", "f", "0"},
                                      {"0", "0", "fc"}
                                      }], ")"}]}], "]"}]}], ",", \({f, mlF}\),
                           ",", \({fc, mlFC}\)}], "]"}]}], ";", 
                    "\[IndentingNewLine]", 
                    RowBox[{"mlD", "=", 
                      RowBox[{
                        RowBox[{"MomentLimits", "[", 
                          
                          RowBox[{\({0, 2}\), 
                            ",", \(pl\[LeftDoubleBracket]{j, 
                                k}\[RightDoubleBracket]\), ",", \({1, 1}\), 
                            ",", 
                            RowBox[{"(", GridBox[{
                                  {"1", "0", "0"},
                                  {"0", "0", "0"},
                                  {"0", "0", "0"}
                                  }], ")"}]}], "]"}], "/", "2"}]}], ";", 
                    "\[IndentingNewLine]", 
                    RowBox[{"fmD", "=", 
                      RowBox[{"FindMinimum", "[", 
                        RowBox[{
                          RowBox[{"-", 
                            RowBox[{"lf", "[", 
                              RowBox[{\({j, k}\), ",", 
                                RowBox[{"(", GridBox[{
                                      {"1", "0", "d"},
                                      {"0", "0", "0"},
                                      {"d", "0", \(d\^2\)}
                                      }], ")"}]}], "]"}]}], 
                          ",", \({d, mlD}\)}], "]"}]}], ";", 
                    "\[IndentingNewLine]", "\[IndentingNewLine]", 
                    RowBox[{"mlFD", "=", 
                      RowBox[{
                        RowBox[{"MomentLimits", "[", 
                          
                          RowBox[{\({1, 2}\), 
                            ",", \(pl\[LeftDoubleBracket]{j, 
                                k}\[RightDoubleBracket]\), ",", \({1, 1}\), 
                            ",", 
                            RowBox[{"(", GridBox[{
                                  {"1", "0", "0"},
                                  {"0", "0", "0"},
                                  {"0", "0", "0"}
                                  }], ")"}]}], "]"}], "/", "2"}]}], ";", 
                    "\[IndentingNewLine]", 
                    RowBox[{"fmA", "=", 
                      RowBox[{"FindMinimum", "[", 
                        RowBox[{
                          RowBox[{"-", 
                            RowBox[{"lf", "[", 
                              RowBox[{\({j, k}\), ",", 
                                RowBox[{"(", GridBox[{
                                      {"1", "0", "d"},
                                      {"0", "f", "df"},
                                      {"d", "df", "fc"}
                                      }], ")"}]}], "]"}]}], ",", \({f, mlF}\),
                           ",", \({fc, mlFC}\), ",", \({d, mlD}\), 
                          ",", \({df, mlFD}\), 
                          ",", \(MaxIterations \[Rule] 100\)}], "]"}]}], ";", 
                    "\[IndentingNewLine]", 
                    RowBox[{"{", 
                      RowBox[{
                        RowBox[{"{", 
                          RowBox[{
                            RowBox[{"lf", "[", 
                              RowBox[{\({j, k}\), ",", 
                                RowBox[{"(", GridBox[{
                                      {"1", "0", "0"},
                                      {"0", "0", "0"},
                                      {"0", "0", "0"}
                                      }], ")"}]}], "]"}], 
                            ",", \({0, 0, 0, 0}\)}], "}"}], ",", 
                        "\[IndentingNewLine]", \({\(-fmF\[LeftDoubleBracket]1\
\[RightDoubleBracket]\), {f, 0, 0, 0} /. 
                            fmF\[LeftDoubleBracket]2\[RightDoubleBracket]}\), 
                        ",", "\[IndentingNewLine]", \({\(-fmD\
\[LeftDoubleBracket]1\[RightDoubleBracket]\), {0, d, 0, 0} /. 
                            fmD\[LeftDoubleBracket]2\[RightDoubleBracket]}\), 
                        ",", "\[IndentingNewLine]", \({\(-fmFC\
\[LeftDoubleBracket]1\[RightDoubleBracket]\), {f, 0, 0, fc} /. 
                            fmFC\[LeftDoubleBracket]2\[RightDoubleBracket]}\),
                         ",", "\[IndentingNewLine]", \({\(-fmA\
\[LeftDoubleBracket]1\[RightDoubleBracket]\), {f, d, df, fc} /. 
                            fmA\[LeftDoubleBracket]2\[RightDoubleBracket]}\)}]\
, "}"}]}], ",", \({j, 2, nl}\), ",", \({k, j - 1}\)}], "]"}]}]}], "]"}]}], 
      ";"}]], "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    StyleBox[\(PresentPairwiseTable[
          site]\ presents\ a\ table\ of\ associations\ among\ loci . \ \ \
PresentPairwiseTable[table, \ 
            locusnames]\ works\ from\ the\ table\ generated\ by\ \
MakePairwiseTable[site] . \ \ PresentPairwiseTable[table, \ locusnames, 
            c]\ adds\ the\ overall\ estimates, \ 
      held\ in\ c\  = \ EstimateMoments[gf, {p\_1, \[Ellipsis]}], \ 
      where\ gf\ are\ the\ 3\^n\ genotype\ \(\(frequencies\)\(.\)\)\),
      FontFamily->"Times"]], "Subsubsection"],

Cell[BoxData[
    \(\(PresentPairwiseTable[s_] := 
        Module[{nl = NumberOfLoci[s], rd, pl}, \[IndentingNewLine]rd = 
            ReducedData[s, 
              nl]; \[IndentingNewLine]pl = \(\(AlleleFrequencyTable[s, nl] // 
                  N\) // Transpose\) // 
              Last; \[IndentingNewLine]PresentPairwiseTable[
            MakePairwiseTable[s], LocusNames[s], 
            EstimateMoments[rd\/Plus @@ rd, pl]]];\)\)], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(\(PresentPairwiseTable[tbl_List, 
          ln_List] := \[IndentingNewLine]Module[{j, k, 
            t}, \[IndentingNewLine]Prepend[\[IndentingNewLine]Flatten[
              Table[\[IndentingNewLine]t = 
                  tbl\[LeftDoubleBracket]j - 1, k\[RightDoubleBracket]; 
                l0 = t\[LeftDoubleBracket]1, 
                    1\[RightDoubleBracket]; \[IndentingNewLine]Flatten[{ln\
\[LeftDoubleBracket]j\[RightDoubleBracket], 
                    ln\[LeftDoubleBracket]
                      k\[RightDoubleBracket], \[IndentingNewLine]t\
\[LeftDoubleBracket]2, 2, 1\[RightDoubleBracket], 
                    t\[LeftDoubleBracket]2, 1\[RightDoubleBracket] - 
                      l0, \[IndentingNewLine]t\[LeftDoubleBracket]3, 2, 
                      2\[RightDoubleBracket], 
                    t\[LeftDoubleBracket]3, 1\[RightDoubleBracket] - 
                      l0, \[IndentingNewLine]t\[LeftDoubleBracket]4, 2, 
                      1\[RightDoubleBracket], 
                    t\[LeftDoubleBracket]4, 2, 4\[RightDoubleBracket], 
                    t\[LeftDoubleBracket]4, 1\[RightDoubleBracket] - 
                      l0, \[IndentingNewLine]t\[LeftDoubleBracket]5, 
                      2\[RightDoubleBracket], 
                    t\[LeftDoubleBracket]5, 1\[RightDoubleBracket] - 
                      l0}], \[IndentingNewLine]{j, 2, Length[tbl] + 1}, {k, 
                  j - 1}], 
              1], \[IndentingNewLine]{"\<Locus 1\>", "\<Locus 2\>", "\<F\>", \
"\<L\>", "\<D\>", "\<L\>", "\<F\>", \*"\"\<cov[\!\(F\_1\),\!\(F\_2\)]\>\"", "\
\<L\>", "\<F\>", "\<D\>", "\<cov[F,D]\>", \*"\"\<cov[\!\(F\_1\),\!\(F\_2\)]\>\
\"", "\<L\>"}]];\)\)], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(\(PresentPairwiseTable[tbl_List, ln_List, 
          c_List] := \[IndentingNewLine]Append[
          PresentPairwiseTable[tbl, ln], {"\<All\>", "\<\>", 
            c\[LeftDoubleBracket]2, 2\[RightDoubleBracket], "\<\>", 
            c\[LeftDoubleBracket]1, 3\[RightDoubleBracket], "\<\>", 
            c\[LeftDoubleBracket]2, 2\[RightDoubleBracket], 
            c\[LeftDoubleBracket]3, 3\[RightDoubleBracket], "\<\>", 
            c\[LeftDoubleBracket]2, 2\[RightDoubleBracket], 
            c\[LeftDoubleBracket]1, 3\[RightDoubleBracket], 
            c\[LeftDoubleBracket]2, 3\[RightDoubleBracket], 
            c\[LeftDoubleBracket]3, 
              3\[RightDoubleBracket], "\<\>"}];\)\)], "Input",
  InitializationCell->True]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["Maximum likelihood estimation", "Subsection"],

Cell[CellGroupData[{

Cell[BoxData[
    \(TextForm
    \`LogLikelihoodDisequilibriumReduced[site, {k\_w, k\_b}, \[Delta]p, 
          p, {i, j, k, l}]\ gives\ an\ expression\ for\ the\ log\ likelihood\ 
        of\ the\ reduced\ cumulants
        \ {k\_w, k\_b} . \ 
          LogLikelihoodDisequilibriumReduced[site, {k\_w, k\_b}, \[Delta]p, 
            p, {i, j, k, l}, gdt]\ stores\ the\ definition\ of\ 
        DiploidGenotypeFrequencyTable[X,  .. ]\ in\ 
        gdt[X] . \ \ \ 
          LogLikelihoodDisequilibriumReduced[site, {k\_w, k\_b}, \[Delta]p, p]
            \ uses\ the\ fully\ compiled\ 
        version . \ LogLikelihoodDisequilibriumReduced[site {k\_w, k\_b}, p]\ 
        is\ the\ fastest\ method\ if\ \[Delta]p = 1\)], "Subsubsection"],

Cell[BoxData[
    \(\(LogLikelihoodDisequilibriumReduced[s_, cl_, p_] := 
        Module[{M, \[CapitalGamma], gv, nl = Length[p], rd}, \n\t
          rd = ReducedData[s, nl]; \n\t\tM = \(MomentReduced[nl]\)[
              cl // Flatten]; \[CapitalGamma] = 
            Matrix\[CapitalGamma][p, nl]; \n\t\tgv = 
            GenotypeFrequencyConvert[\[CapitalGamma] . M . 
                Transpose[\[CapitalGamma]], nl]; \n\t
          If[Min[gv] \[GreaterEqual] 
              0, \(LogLikelihoodDisequilibrium[Plus @@ rd]\)[
              10\^\(-20\) + rd, gv], \(-10\^10\)]];\)\)], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(\(\(\n\)\(LogLikelihoodDisequilibriumReduced[s_, cl_, \[Delta]p_, p_, 
          old] := \n\t\tModule[{nt, 
            rd = Transpose[
                Select[ReducedData[s, Length[S], 
                      Detail \[Rule] True] /. {{a_Integer, b_Integer} :> 
                        a + b}, \((#[\([1]\)] > 0)\) &]]}, \n\t\ nt = 
            Plus @@ rd\[LeftDoubleBracket]1\[RightDoubleBracket]; \n
          nt\ Log[nt] + 
            rd\[LeftDoubleBracket]1\[RightDoubleBracket] . 
              Log[\(DiploidGenotypeFrequencyTable[#, cl, \[Delta]p, p] &\) /@ \
rd\[LeftDoubleBracket]2\[RightDoubleBracket]\/rd\[LeftDoubleBracket]1\
\[RightDoubleBracket]]];\)\)\)], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(\(LogLikelihoodDisequilibriumReduced[s_, cl_, \[Delta]p_, 
          p_] := \n\t\tModule[{nt, nl = NumberOfLoci[s], 
            rd = Transpose[
                Select[ReducedData[s, NumberOfLoci[s], 
                      Detail \[Rule] True] /. {{a_Integer, b_Integer} :> 
                        a + b}, \((#[\([1]\)] > 0)\) &]], vv}, \n\t
          vv = Flatten[{p /@ Range[nl], cl}]; \ 
          nt = Plus @@ rd\[LeftDoubleBracket]1\[RightDoubleBracket]; \n
          nt\ Log[nt] + 
            rd\[LeftDoubleBracket]1\[RightDoubleBracket] . 
              Log[\(\((DiploidGenotypeFrequencyTable[#, \[Delta]p] @@ vv)\) &\
\) /@ rd\[LeftDoubleBracket]2\[RightDoubleBracket]\/rd\[LeftDoubleBracket]1\
\[RightDoubleBracket]]];\)\)], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(\(\(\n\)\(LogLikelihoodDisequilibriumReduced[
          s_, {cw_, cb_}, \[Delta]p_, p_, 
          S_List] := \n\t\tModule[{nt, 
            rd = Transpose[
                Select[ReducedData[s, Length[S], 
                      Detail \[Rule] True] /. {{a_Integer, b_Integer} :> 
                        a + b}, \((#[\([1]\)] > 0)\) &]]}, \n\t\ \ \ nt = 
            Plus @@ rd\[LeftDoubleBracket]1\[RightDoubleBracket]; \n\t
          nt\ Log[nt] + 
            rd\[LeftDoubleBracket]1\[RightDoubleBracket] . 
              Log[\(1\/rd\[LeftDoubleBracket]1\[RightDoubleBracket]\) \
\((\(DiploidGenotypeFrequencyTable[#, {cw, cb}, \[Delta]p, p, S] &\) /@ 
                      rd\[LeftDoubleBracket]2\[RightDoubleBracket])\)]];\)\)\)\
], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(\(\(\n\)\(LogLikelihoodDisequilibriumReduced[
          s_, {cw_, cb_}, \[Delta]p_, p_, S_List, 
          gdt_] := \n\t\tModule[{nt, 
            rd = Transpose[
                Select[ReducedData[s, Length[S], 
                      Detail \[Rule] True] /. {{a_Integer, b_Integer} :> 
                        a + b}, \((#[\([1]\)] > 0)\) &]]}, \n\t\ \ \ gdt[
              X_] := \(gdt[X] = 
              DiploidGenotypeFrequencyTable[X, {cw, cb}, \[Delta]p, p, 
                S]\); \n\t\tnt = 
            Plus @@ rd\[LeftDoubleBracket]1\[RightDoubleBracket]; \n\t
          nt\ Log[nt] + 
            rd\[LeftDoubleBracket]1\[RightDoubleBracket] . 
              Log[gdt /@ rd\[LeftDoubleBracket]2\[RightDoubleBracket]\/rd\
\[LeftDoubleBracket]1\[RightDoubleBracket]]];\)\)\)], "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    \(TextForm
    \`LogLikelihoodDisequilibrium[site, p, \[Delta]p, c]\ gives\ the\ log\ 
      likelihood\ of\ the\ matrix\ of\ moments, \ 
    c\_\(j, k\) . \ \ \ \ 
          LogLikelihoodDisequilibrium[site, p, \[Delta]p, c, 
            Compiled \[Rule] True]\ is\ a\ compiled\ 
        version . \ LogLikelihoodDisequilibrium[p, c, Compiled \[Rule] True]\ 
        is\ the\ fastest\ method\ if\ \[Delta]p = 
      \(1. \ LogLikelihoodDisequilibrium[{p, \(p\^*\)}, {\[Delta]p, 
                \(\[Delta]p\^*\)}, c, Compiled \[Rule] True, 
              Symmetric \[Rule] False]\ allows\ for\ different\ frequencies\ 
            in\ the\ male\ &\)\ female\ gamete\ \(pools . \)\)], 
  "Subsubsection"],

Cell[BoxData[
    \(\(Options[LogLikelihoodDisequilibrium] = {Symmetric \[Rule] True, 
          Compiled \[Rule] False};\)\)], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(\(LogLikelihoodDisequilibrium[
          nt_Integer] := \(LogLikelihoodDisequilibrium[
            nt] = \n\t\tCompile[{{o, _Real, 1}, {e, _Real, 1}}, \n
            nt\ Log[nt] + o . Log[e/o]]\);\)\)], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(\(LogLikelihoodDisequilibrium[s_, p_, \[Delta]p_, cl_, 
          opts___Rule] := \n\t
        Module[{gv, rd, nl = NumberOfLoci[s], sm, nt, 
            rdgv}, \n\t\ \ \ sm = \(Symmetric /. {opts}\) /. 
              Options[LogLikelihoodDisequilibrium]; \n\t\trd = 
            ReducedData[s, nl]; nt = Plus @@ rd; 
          If[\(Compiled /. {opts}\) /. 
              Options[LogLikelihoodDisequilibrium], \n\t\t\tgv = 
              If[sm, \n\t\t\t\t\
GenotypeFrequencyConvert[\(DiploidGenotypeFrequencyList[nl, 
                      Symmetric \[Rule] True]\)[p, \[Delta]p, cl], 
                  nl], \n\t\t\t\t\
GenotypeFrequencyConvert[\(DiploidGenotypeFrequencyList[nl]\)[p, \[Delta]p, 
                    cl], nl]]; \n\t\t\trdgv = 
              Transpose[
                DeleteCases[
                  Transpose[{ReducedData[s, nl], gv}], {0, _}]]; \n\t\tIf[
              Min[gv] \[GreaterEqual] 0, \(LogLikelihoodDisequilibrium[nt]\)[
                rdgv\[LeftDoubleBracket]1\[RightDoubleBracket], 
                rdgv\[LeftDoubleBracket]2\[RightDoubleBracket]], \
\(-10\^10\)], \n\t\t\ gv = 
              GenotypeFrequencyConvert[
                DiploidGenotypeFrequencyList[p, \[Delta]p, cl, 
                  Symmetric \[Rule] sm], nl]; \n\t\trdgv = 
              Transpose[
                DeleteCases[
                  Transpose[{ReducedData[s, nl], gv}], {0, _}]]; \n\t
            nt\ Log[nt] + 
              rdgv\[LeftDoubleBracket]1\[RightDoubleBracket] . 
                Log[rdgv\[LeftDoubleBracket]2\[RightDoubleBracket]/
                    rdgv\[LeftDoubleBracket]1\[RightDoubleBracket]]]];\)\)], \
"Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData[{
  "Timings for LogLikelihoodDisequilibrium[] - site 1063\n",
  StyleBox["Using the compiled version of ",
    FontWeight->"Plain"],
  "FullGenotypeFrequencyTable",
  StyleBox[
  ", 2.45s\nUsing the uncompiled version takes 95s to set up.\nThen takes \
0.15s having stored ",
    FontWeight->"Plain"],
  "DiploidGenotypeFrequencyTable",
  StyleBox["[] as a function of {cw,cb} ",
    FontWeight->"Plain"]
}], "Subsubsection"],

Cell[BoxData[
    \(pl = ptable[data[1063]]; S = {1, 2, 3, 4}; \)], "Input"],

Cell[CellGroupData[{

Cell[BoxData[
    \(Timing[
      LogLikelihoodDisequilibrium[
        1063, {{0.01, 0, 0}, {0.01, 0, 0, 0, 0, 0, 0}}, 1&, 
        pl\[LeftDoubleBracket]#\[RightDoubleBracket]&]]\)], "Input"],

Cell[BoxData[
    \({2.45000000000072759`\ Second, \(-38.8249180389305781`\)}\)], "Output"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    \(Timing[
      ll = LogLikelihoodDisequilibrium[1063, {cw, cb}, 1&, 
          pl\[LeftDoubleBracket]#\[RightDoubleBracket]&, S, gdt]; ]\)], 
  "Input"],

Cell[BoxData[
    \({95.2333333333335829`\ Second, Null}\)], "Output"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    \(ll /. {cw[j_] -> If[j == 2, 0.01, 0], cb[j_] -> If[j == 2, 0.01, 0]}
        \)], "Input"],

Cell[BoxData[
    \(\(-38.8249180389305195`\)\)], "Output"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    \(Timing[gdt[{0, 0, 2, 1}]]\)], "Input"],

Cell[BoxData[
    \(176387400225\/14049917815684 + \(3094585641\ cb[2]\)\/164206490176 + 
      \(19210689\ cb[2]\^2\)\/14993288 + \(53067\ cb[2]\^3\)\/2738 + 
      24\ cb[2]\^4 + \(243821907\ cb[3]\)\/1109503312 - 
      \(1748817\ cb[2]\ cb[3]\)\/101306 - 4788\/37\ cb[2]\^2\ cb[3] + 
      \(211797\ cb[3]\^2\)\/5476 + 144\ cb[2]\ cb[3]\^2 + 
      \(4413375\ cb[4]\)\/29986576 + \(229329\ cb[2]\ cb[4]\)\/5476 + 
      72\ cb[2]\^2\ cb[4] - 3990\/37\ cb[3]\ cb[4] + 34\ cb[4]\^2 - 
      \(263655\ cb[5]\)\/101306 - 1596\/37\ cb[2]\ cb[5] + 48\ cb[3]\ cb[5] + 
      \(715\ cb[6]\)\/148 + 16\ cb[2]\ cb[6] - \(133\ cb[7]\)\/37 + cb[8] - 
      \(1840794255\ cw[2]\)\/10262905636 - 
      \(22195971\ cb[2]\ cw[2]\)\/14993288 + 
      \(26298\ cb[2]\^2\ cw[2]\)\/1369 - \(1415043\ cb[3]\ cw[2]\)\/202612 - 
      4788\/37\ cb[2]\ cb[3]\ cw[2] + 72\ cb[3]\^2\ cw[2] + 
      2145\/74\ cb[4]\ cw[2] + 96\ cb[2]\ cb[4]\ cw[2] - 
      1197\/37\ cb[5]\ cw[2] + 12\ cb[6]\ cw[2] - 
      \(948591\ cw[2]\^2\)\/29986576 + \(159201\ cb[2]\ cw[2]\^2\)\/5476 + 
      72\ cb[2]\^2\ cw[2]\^2 - 2394\/37\ cb[3]\ cw[2]\^2 + 
      36\ cb[4]\ cw[2]\^2 + \(13149\ cw[2]\^3\)\/2738 + 9\ cw[2]\^4 + 
      \(55858005\ cw[3]\)\/138687914 + \(55629\ cb[2]\ cw[3]\)\/50653 + 
      \(8766\ cb[3]\ cw[3]\)\/1369 - 532\/37\ cb[4]\ cw[3] + 
      8\ cb[5]\ cw[3] - \(582939\ cw[2]\ cw[3]\)\/202612 - 
      1596\/37\ cb[2]\ cw[2]\ cw[3] + 48\ cb[3]\ cw[2]\ cw[3] - 
      399\/37\ cw[2]\^2\ cw[3] + \(17689\ cw[3]\^2\)\/5476 + 
      16\ cb[2]\ cw[3]\^2 - \(419985\ cw[4]\)\/1874161 + 
      \(4383\ cw[2]\ cw[4]\)\/2738 + 6\ cw[2]\^2\ cw[4] - 
      133\/37\ cw[3]\ cw[4] + cw[4]\^2\)], "Output"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    \(Timing[
      ll = LogLikelihoodDisequilibrium[1063, {cw, cb}, 1&, 
          pl\[LeftDoubleBracket]#\[RightDoubleBracket]&, S, gdt]; ]\)], 
  "Input"],

Cell[BoxData[
    \({0.149999999997817212`\ Second, Null}\)], "Output"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(Timing[
      ll = LogLikelihoodDisequilibrium[1063, {cw, cb}, 1&, p, S, gdt2]; ] (*
      from\ scratch*) \)\)], "Input"],

Cell[BoxData[
    \({231.166666666666653`\ Second, Null}\)], "Output"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(Timing[
      ll = LogLikelihoodDisequilibrium[1063, {cw, cb}, 1&, p, S, gdt2]; ] (*\ 
      after\ setting\ up\ FullGenotypeFrequencyTable\ *) \)\)], "Input"],

Cell[BoxData[
    \({121.166666666667888`\ Second, Null}\)], "Output"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(Timing[
      ll = LogLikelihoodDisequilibrium[1063, {cw, cb}, 1&, p, S, gdt2]; ] (*\ 
      after\ setting\ up\ FullGenotypeFrequencyTable\ *) \)\)], "Input"],

Cell[BoxData[
    \({0.366666666666787932`\ Second, Null}\)], "Output"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    \(ll[\([2]\)]\)], "Input"],

Cell[BoxData[
    \(9\ Log[
        1\/9\ \((
            24\ cb[2]\^4 + 144\ cb[2]\ cb[3]\^2 + 72\ cb[2]\^2\ cb[4] + 
              34\ cb[4]\^2 + 48\ cb[3]\ cb[5] + 16\ cb[2]\ cb[6] + cb[8] + 
              72\ cb[3]\^2\ cw[2] + 96\ cb[2]\ cb[4]\ cw[2] + 
              12\ cb[6]\ cw[2] + 72\ cb[2]\^2\ cw[2]\^2 + 
              36\ cb[4]\ cw[2]\^2 + 9\ cw[2]\^4 + 8\ cb[5]\ cw[3] + 
              48\ cb[3]\ cw[2]\ cw[3] + 16\ cb[2]\ cw[3]\^2 + 
              6\ cw[2]\^2\ cw[4] + cw[4]\^2 - 
              72\ cb[2]\^2\ cb[3]\ \((1 - p[1])\) - 
              60\ cb[3]\ cb[4]\ \((1 - p[1])\) - 
              24\ cb[2]\ cb[5]\ \((1 - p[1])\) - 2\ cb[7]\ \((1 - p[1])\) - 
              72\ cb[2]\ cb[3]\ cw[2]\ \((1 - p[1])\) - 
              18\ cb[5]\ cw[2]\ \((1 - p[1])\) - 
              36\ cb[3]\ cw[2]\^2\ \((1 - p[1])\) - 
              8\ cb[4]\ cw[3]\ \((1 - p[1])\) - 
              24\ cb[2]\ cw[2]\ cw[3]\ \((1 - p[1])\) - 
              6\ cw[2]\^2\ cw[3]\ \((1 - p[1])\) - 
              2\ cw[3]\ cw[4]\ \((1 - p[1])\) + 
              6\ cb[2]\^3\ \((1 - p[1])\)\^2 + 
              9\ cb[3]\^2\ \((1 - p[1])\)\^2 + 
              9\ cb[2]\ cb[4]\ \((1 - p[1])\)\^2 + cb[6]\ \((1 - p[1])\)\^2 + 
              6\ cb[4]\ cw[2]\ \((1 - p[1])\)\^2 + 
              9\ cb[2]\ cw[2]\^2\ \((1 - p[1])\)\^2 + 
              cw[3]\^2\ \((1 - p[1])\)\^2 - 
              72\ cb[2]\^2\ cb[3]\ \((1 - p[2])\) - 
              60\ cb[3]\ cb[4]\ \((1 - p[2])\) - 
              24\ cb[2]\ cb[5]\ \((1 - p[2])\) - 2\ cb[7]\ \((1 - p[2])\) - 
              72\ cb[2]\ cb[3]\ cw[2]\ \((1 - p[2])\) - 
              18\ cb[5]\ cw[2]\ \((1 - p[2])\) - 
              36\ cb[3]\ cw[2]\^2\ \((1 - p[2])\) - 
              8\ cb[4]\ cw[3]\ \((1 - p[2])\) - 
              24\ cb[2]\ cw[2]\ cw[3]\ \((1 - p[2])\) - 
              6\ cw[2]\^2\ cw[3]\ \((1 - p[2])\) - 
              2\ cw[3]\ cw[4]\ \((1 - p[2])\) + 
              12\ cb[2]\^3\ \((1 - p[1])\)\ \((1 - p[2])\) + 
              30\ cb[3]\^2\ \((1 - p[1])\)\ \((1 - p[2])\) + 
              34\ cb[2]\ cb[4]\ \((1 - p[1])\)\ \((1 - p[2])\) + 
              4\ cb[6]\ \((1 - p[1])\)\ \((1 - p[2])\) + 
              24\ cb[2]\^2\ cw[2]\ \((1 - p[1])\)\ \((1 - p[2])\) + 
              24\ cb[4]\ cw[2]\ \((1 - p[1])\)\ \((1 - p[2])\) + 
              18\ cb[2]\ cw[2]\^2\ \((1 - p[1])\)\ \((1 - p[2])\) + 
              6\ cw[2]\^3\ \((1 - p[1])\)\ \((1 - p[2])\) + 
              8\ cb[3]\ cw[3]\ \((1 - p[1])\)\ \((1 - p[2])\) + 
              2\ cw[3]\^2\ \((1 - p[1])\)\ \((1 - p[2])\) + 
              2\ cw[2]\ cw[4]\ \((1 - p[1])\)\ \((1 - p[2])\) - 
              12\ cb[2]\ cb[3]\ \((1 - p[1])\)\^2\ \((1 - p[2])\) - 
              2\ cb[5]\ \((1 - p[1])\)\^2\ \((1 - p[2])\) - 
              6\ cb[3]\ cw[2]\ \((1 - p[1])\)\^2\ \((1 - p[2])\) - 
              2\ cw[2]\ cw[3]\ \((1 - p[1])\)\^2\ \((1 - p[2])\) + 
              6\ cb[2]\^3\ \((1 - p[2])\)\^2 + 
              9\ cb[3]\^2\ \((1 - p[2])\)\^2 + 
              9\ cb[2]\ cb[4]\ \((1 - p[2])\)\^2 + cb[6]\ \((1 - p[2])\)\^2 + 
              6\ cb[4]\ cw[2]\ \((1 - p[2])\)\^2 + 
              9\ cb[2]\ cw[2]\^2\ \((1 - p[2])\)\^2 + 
              cw[3]\^2\ \((1 - p[2])\)\^2 - 
              12\ cb[2]\ cb[3]\ \((1 - p[1])\)\ \((1 - p[2])\)\^2 - 
              2\ cb[5]\ \((1 - p[1])\)\ \((1 - p[2])\)\^2 - 
              6\ cb[3]\ cw[2]\ \((1 - p[1])\)\ \((1 - p[2])\)\^2 - 
              2\ cw[2]\ cw[3]\ \((1 - p[1])\)\ \((1 - p[2])\)\^2 + 
              2\ cb[2]\^2\ \((1 - p[1])\)\^2\ \((1 - p[2])\)\^2 + 
              cb[4]\ \((1 - p[1])\)\^2\ \((1 - p[2])\)\^2 + 
              cw[2]\^2\ \((1 - p[1])\)\^2\ \((1 - p[2])\)\^2 - 
              72\ cb[2]\^2\ cb[3]\ \((1 - p[3])\) - 
              60\ cb[3]\ cb[4]\ \((1 - p[3])\) - 
              24\ cb[2]\ cb[5]\ \((1 - p[3])\) - 2\ cb[7]\ \((1 - p[3])\) - 
              72\ cb[2]\ cb[3]\ cw[2]\ \((1 - p[3])\) - 
              18\ cb[5]\ cw[2]\ \((1 - p[3])\) - 
              36\ cb[3]\ cw[2]\^2\ \((1 - p[3])\) - 
              8\ cb[4]\ cw[3]\ \((1 - p[3])\) - 
              24\ cb[2]\ cw[2]\ cw[3]\ \((1 - p[3])\) - 
              6\ cw[2]\^2\ cw[3]\ \((1 - p[3])\) - 
              2\ cw[3]\ cw[4]\ \((1 - p[3])\) + 
              12\ cb[2]\^3\ \((1 - p[1])\)\ \((1 - p[3])\) + 
              30\ cb[3]\^2\ \((1 - p[1])\)\ \((1 - p[3])\) + 
              34\ cb[2]\ cb[4]\ \((1 - p[1])\)\ \((1 - p[3])\) + 
              4\ cb[6]\ \((1 - p[1])\)\ \((1 - p[3])\) + 
              24\ cb[2]\^2\ cw[2]\ \((1 - p[1])\)\ \((1 - p[3])\) + 
              24\ cb[4]\ cw[2]\ \((1 - p[1])\)\ \((1 - p[3])\) + 
              18\ cb[2]\ cw[2]\^2\ \((1 - p[1])\)\ \((1 - p[3])\) + 
              6\ cw[2]\^3\ \((1 - p[1])\)\ \((1 - p[3])\) + 
              8\ cb[3]\ cw[3]\ \((1 - p[1])\)\ \((1 - p[3])\) + 
              2\ cw[3]\^2\ \((1 - p[1])\)\ \((1 - p[3])\) + 
              2\ cw[2]\ cw[4]\ \((1 - p[1])\)\ \((1 - p[3])\) - 
              12\ cb[2]\ cb[3]\ \((1 - p[1])\)\^2\ \((1 - p[3])\) - 
              2\ cb[5]\ \((1 - p[1])\)\^2\ \((1 - p[3])\) - 
              6\ cb[3]\ cw[2]\ \((1 - p[1])\)\^2\ \((1 - p[3])\) - 
              2\ cw[2]\ cw[3]\ \((1 - p[1])\)\^2\ \((1 - p[3])\) + 
              12\ cb[2]\^3\ \((1 - p[2])\)\ \((1 - p[3])\) + 
              30\ cb[3]\^2\ \((1 - p[2])\)\ \((1 - p[3])\) + 
              34\ cb[2]\ cb[4]\ \((1 - p[2])\)\ \((1 - p[3])\) + 
              4\ cb[6]\ \((1 - p[2])\)\ \((1 - p[3])\) + 
              24\ cb[2]\^2\ cw[2]\ \((1 - p[2])\)\ \((1 - p[3])\) + 
              24\ cb[4]\ cw[2]\ \((1 - p[2])\)\ \((1 - p[3])\) + 
              18\ cb[2]\ cw[2]\^2\ \((1 - p[2])\)\ \((1 - p[3])\) + 
              6\ cw[2]\^3\ \((1 - p[2])\)\ \((1 - p[3])\) + 
              8\ cb[3]\ cw[3]\ \((1 - p[2])\)\ \((1 - p[3])\) + 
              2\ cw[3]\^2\ \((1 - p[2])\)\ \((1 - p[3])\) + 
              2\ cw[2]\ cw[4]\ \((1 - p[2])\)\ \((1 - p[3])\) - 
              36\ cb[2]\ cb[3]\ \((1 - p[1])\)\ \((1 - p[2])\)\ 
                \((1 - p[3])\) - 
              8\ cb[5]\ \((1 - p[1])\)\ \((1 - p[2])\)\ \((1 - p[3])\) - 
              30\ cb[3]\ cw[2]\ \((1 - p[1])\)\ \((1 - p[2])\)\ 
                \((1 - p[3])\) - 
              8\ cb[2]\ cw[3]\ \((1 - p[1])\)\ \((1 - p[2])\)\ 
                \((1 - p[3])\) - 
              6\ cw[2]\ cw[3]\ \((1 - p[1])\)\ \((1 - p[2])\)\ 
                \((1 - p[3])\) + 
              4\ cb[2]\^2\ \((1 - p[1])\)\^2\ \((1 - p[2])\)\ 
                \((1 - p[3])\) + 
              4\ cb[4]\ \((1 - p[1])\)\^2\ \((1 - p[2])\)\ \((1 - p[3])\) + 
              6\ cb[2]\ cw[2]\ \((1 - p[1])\)\^2\ \((1 - p[2])\)\ 
                \((1 - p[3])\) + 
              2\ cw[2]\^2\ \((1 - p[1])\)\^2\ \((1 - p[2])\)\ 
                \((1 - p[3])\) - 
              12\ cb[2]\ cb[3]\ \((1 - p[2])\)\^2\ \((1 - p[3])\) - 
              2\ cb[5]\ \((1 - p[2])\)\^2\ \((1 - p[3])\) - 
              6\ cb[3]\ cw[2]\ \((1 - p[2])\)\^2\ \((1 - p[3])\) - 
              2\ cw[2]\ cw[3]\ \((1 - p[2])\)\^2\ \((1 - p[3])\) + 
              4\ cb[2]\^2\ \((1 - p[1])\)\ \((1 - p[2])\)\^2\ 
                \((1 - p[3])\) + 
              4\ cb[4]\ \((1 - p[1])\)\ \((1 - p[2])\)\^2\ \((1 - p[3])\) + 
              6\ cb[2]\ cw[2]\ \((1 - p[1])\)\ \((1 - p[2])\)\^2\ 
                \((1 - p[3])\) + 
              2\ cw[2]\^2\ \((1 - p[1])\)\ \((1 - p[2])\)\^2\ 
                \((1 - p[3])\) - 
              2\ cb[3]\ \((1 - p[1])\)\^2\ \((1 - p[2])\)\^2\ 
                \((1 - p[3])\) + 6\ cb[2]\^3\ \((1 - p[3])\)\^2 + 
              9\ cb[3]\^2\ \((1 - p[3])\)\^2 + 
              9\ cb[2]\ cb[4]\ \((1 - p[3])\)\^2 + cb[6]\ \((1 - p[3])\)\^2 + 
              6\ cb[4]\ cw[2]\ \((1 - p[3])\)\^2 + 
              9\ cb[2]\ cw[2]\^2\ \((1 - p[3])\)\^2 + 
              cw[3]\^2\ \((1 - p[3])\)\^2 - 
              12\ cb[2]\ cb[3]\ \((1 - p[1])\)\ \((1 - p[3])\)\^2 - 
              2\ cb[5]\ \((1 - p[1])\)\ \((1 - p[3])\)\^2 - 
              6\ cb[3]\ cw[2]\ \((1 - p[1])\)\ \((1 - p[3])\)\^2 - 
              2\ cw[2]\ cw[3]\ \((1 - p[1])\)\ \((1 - p[3])\)\^2 + 
              2\ cb[2]\^2\ \((1 - p[1])\)\^2\ \((1 - p[3])\)\^2 + 
              cb[4]\ \((1 - p[1])\)\^2\ \((1 - p[3])\)\^2 + 
              cw[2]\^2\ \((1 - p[1])\)\^2\ \((1 - p[3])\)\^2 - 
              12\ cb[2]\ cb[3]\ \((1 - p[2])\)\ \((1 - p[3])\)\^2 - 
              2\ cb[5]\ \((1 - p[2])\)\ \((1 - p[3])\)\^2 - 
              6\ cb[3]\ cw[2]\ \((1 - p[2])\)\ \((1 - p[3])\)\^2 - 
              2\ cw[2]\ cw[3]\ \((1 - p[2])\)\ \((1 - p[3])\)\^2 + 
              4\ cb[2]\^2\ \((1 - p[1])\)\ \((1 - p[2])\)\ 
                \((1 - p[3])\)\^2 + 
              4\ cb[4]\ \((1 - p[1])\)\ \((1 - p[2])\)\ \((1 - p[3])\)\^2 + 
              6\ cb[2]\ cw[2]\ \((1 - p[1])\)\ \((1 - p[2])\)\ 
                \((1 - p[3])\)\^2 + 
              2\ cw[2]\^2\ \((1 - p[1])\)\ \((1 - p[2])\)\ 
                \((1 - p[3])\)\^2 - 
              2\ cb[3]\ \((1 - p[1])\)\^2\ \((1 - p[2])\)\ 
                \((1 - p[3])\)\^2 + 
              2\ cb[2]\^2\ \((1 - p[2])\)\^2\ \((1 - p[3])\)\^2 + 
              cb[4]\ \((1 - p[2])\)\^2\ \((1 - p[3])\)\^2 + 
              cw[2]\^2\ \((1 - p[2])\)\^2\ \((1 - p[3])\)\^2 - 
              2\ cb[3]\ \((1 - p[1])\)\ \((1 - p[2])\)\^2\ 
                \((1 - p[3])\)\^2 + 
              cb[2]\ \((1 - p[1])\)\^2\ \((1 - p[2])\)\^2\ 
                \((1 - p[3])\)\^2 - 72\ cb[2]\^2\ cb[3]\ \((1 - p[4])\) - 
              60\ cb[3]\ cb[4]\ \((1 - p[4])\) - 
              24\ cb[2]\ cb[5]\ \((1 - p[4])\) - 2\ cb[7]\ \((1 - p[4])\) - 
              72\ cb[2]\ cb[3]\ cw[2]\ \((1 - p[4])\) - 
              18\ cb[5]\ cw[2]\ \((1 - p[4])\) - 
              36\ cb[3]\ cw[2]\^2\ \((1 - p[4])\) - 
              8\ cb[4]\ cw[3]\ \((1 - p[4])\) - 
              24\ cb[2]\ cw[2]\ cw[3]\ \((1 - p[4])\) - 
              6\ cw[2]\^2\ cw[3]\ \((1 - p[4])\) - 
              2\ cw[3]\ cw[4]\ \((1 - p[4])\) + 
              12\ cb[2]\^3\ \((1 - p[1])\)\ \((1 - p[4])\) + 
              30\ cb[3]\^2\ \((1 - p[1])\)\ \((1 - p[4])\) + 
              34\ cb[2]\ cb[4]\ \((1 - p[1])\)\ \((1 - p[4])\) + 
              4\ cb[6]\ \((1 - p[1])\)\ \((1 - p[4])\) + 
              24\ cb[2]\^2\ cw[2]\ \((1 - p[1])\)\ \((1 - p[4])\) + 
              24\ cb[4]\ cw[2]\ \((1 - p[1])\)\ \((1 - p[4])\) + 
              18\ cb[2]\ cw[2]\^2\ \((1 - p[1])\)\ \((1 - p[4])\) + 
              6\ cw[2]\^3\ \((1 - p[1])\)\ \((1 - p[4])\) + 
              8\ cb[3]\ cw[3]\ \((1 - p[1])\)\ \((1 - p[4])\) + 
              2\ cw[3]\^2\ \((1 - p[1])\)\ \((1 - p[4])\) + 
              2\ cw[2]\ cw[4]\ \((1 - p[1])\)\ \((1 - p[4])\) - 
              12\ cb[2]\ cb[3]\ \((1 - p[1])\)\^2\ \((1 - p[4])\) - 
              2\ cb[5]\ \((1 - p[1])\)\^2\ \((1 - p[4])\) - 
              6\ cb[3]\ cw[2]\ \((1 - p[1])\)\^2\ \((1 - p[4])\) - 
              2\ cw[2]\ cw[3]\ \((1 - p[1])\)\^2\ \((1 - p[4])\) + 
              12\ cb[2]\^3\ \((1 - p[2])\)\ \((1 - p[4])\) + 
              30\ cb[3]\^2\ \((1 - p[2])\)\ \((1 - p[4])\) + 
              34\ cb[2]\ cb[4]\ \((1 - p[2])\)\ \((1 - p[4])\) + 
              4\ cb[6]\ \((1 - p[2])\)\ \((1 - p[4])\) + 
              24\ cb[2]\^2\ cw[2]\ \((1 - p[2])\)\ \((1 - p[4])\) + 
              24\ cb[4]\ cw[2]\ \((1 - p[2])\)\ \((1 - p[4])\) + 
              18\ cb[2]\ cw[2]\^2\ \((1 - p[2])\)\ \((1 - p[4])\) + 
              6\ cw[2]\^3\ \((1 - p[2])\)\ \((1 - p[4])\) + 
              8\ cb[3]\ cw[3]\ \((1 - p[2])\)\ \((1 - p[4])\) + 
              2\ cw[3]\^2\ \((1 - p[2])\)\ \((1 - p[4])\) + 
              2\ cw[2]\ cw[4]\ \((1 - p[2])\)\ \((1 - p[4])\) - 
              36\ cb[2]\ cb[3]\ \((1 - p[1])\)\ \((1 - p[2])\)\ 
                \((1 - p[4])\) - 
              8\ cb[5]\ \((1 - p[1])\)\ \((1 - p[2])\)\ \((1 - p[4])\) - 
              30\ cb[3]\ cw[2]\ \((1 - p[1])\)\ \((1 - p[2])\)\ 
                \((1 - p[4])\) - 
              8\ cb[2]\ cw[3]\ \((1 - p[1])\)\ \((1 - p[2])\)\ 
                \((1 - p[4])\) - 
              6\ cw[2]\ cw[3]\ \((1 - p[1])\)\ \((1 - p[2])\)\ 
                \((1 - p[4])\) + 
              4\ cb[2]\^2\ \((1 - p[1])\)\^2\ \((1 - p[2])\)\ 
                \((1 - p[4])\) + 
              4\ cb[4]\ \((1 - p[1])\)\^2\ \((1 - p[2])\)\ \((1 - p[4])\) + 
              6\ cb[2]\ cw[2]\ \((1 - p[1])\)\^2\ \((1 - p[2])\)\ 
                \((1 - p[4])\) + 
              2\ cw[2]\^2\ \((1 - p[1])\)\^2\ \((1 - p[2])\)\ 
                \((1 - p[4])\) - 
              12\ cb[2]\ cb[3]\ \((1 - p[2])\)\^2\ \((1 - p[4])\) - 
              2\ cb[5]\ \((1 - p[2])\)\^2\ \((1 - p[4])\) - 
              6\ cb[3]\ cw[2]\ \((1 - p[2])\)\^2\ \((1 - p[4])\) - 
              2\ cw[2]\ cw[3]\ \((1 - p[2])\)\^2\ \((1 - p[4])\) + 
              4\ cb[2]\^2\ \((1 - p[1])\)\ \((1 - p[2])\)\^2\ 
                \((1 - p[4])\) + 
              4\ cb[4]\ \((1 - p[1])\)\ \((1 - p[2])\)\^2\ \((1 - p[4])\) + 
              6\ cb[2]\ cw[2]\ \((1 - p[1])\)\ \((1 - p[2])\)\^2\ 
                \((1 - p[4])\) + 
              2\ cw[2]\^2\ \((1 - p[1])\)\ \((1 - p[2])\)\^2\ 
                \((1 - p[4])\) - 
              2\ cb[3]\ \((1 - p[1])\)\^2\ \((1 - p[2])\)\^2\ 
                \((1 - p[4])\) + 
              12\ cb[2]\^3\ \((1 - p[3])\)\ \((1 - p[4])\) + 
              30\ cb[3]\^2\ \((1 - p[3])\)\ \((1 - p[4])\) + 
              34\ cb[2]\ cb[4]\ \((1 - p[3])\)\ \((1 - p[4])\) + 
              4\ cb[6]\ \((1 - p[3])\)\ \((1 - p[4])\) + 
              24\ cb[2]\^2\ cw[2]\ \((1 - p[3])\)\ \((1 - p[4])\) + 
              24\ cb[4]\ cw[2]\ \((1 - p[3])\)\ \((1 - p[4])\) + 
              18\ cb[2]\ cw[2]\^2\ \((1 - p[3])\)\ \((1 - p[4])\) + 
              6\ cw[2]\^3\ \((1 - p[3])\)\ \((1 - p[4])\) + 
              8\ cb[3]\ cw[3]\ \((1 - p[3])\)\ \((1 - p[4])\) + 
              2\ cw[3]\^2\ \((1 - p[3])\)\ \((1 - p[4])\) + 
              2\ cw[2]\ cw[4]\ \((1 - p[3])\)\ \((1 - p[4])\) - 
              36\ cb[2]\ cb[3]\ \((1 - p[1])\)\ \((1 - p[3])\)\ 
                \((1 - p[4])\) - 
              8\ cb[5]\ \((1 - p[1])\)\ \((1 - p[3])\)\ \((1 - p[4])\) - 
              30\ cb[3]\ cw[2]\ \((1 - p[1])\)\ \((1 - p[3])\)\ 
                \((1 - p[4])\) - 
              8\ cb[2]\ cw[3]\ \((1 - p[1])\)\ \((1 - p[3])\)\ 
                \((1 - p[4])\) - 
              6\ cw[2]\ cw[3]\ \((1 - p[1])\)\ \((1 - p[3])\)\ 
                \((1 - p[4])\) + 
              4\ cb[2]\^2\ \((1 - p[1])\)\^2\ \((1 - p[3])\)\ 
                \((1 - p[4])\) + 
              4\ cb[4]\ \((1 - p[1])\)\^2\ \((1 - p[3])\)\ \((1 - p[4])\) + 
              6\ cb[2]\ cw[2]\ \((1 - p[1])\)\^2\ \((1 - p[3])\)\ 
                \((1 - p[4])\) + 
              2\ cw[2]\^2\ \((1 - p[1])\)\^2\ \((1 - p[3])\)\ 
                \((1 - p[4])\) - 
              36\ cb[2]\ cb[3]\ \((1 - p[2])\)\ \((1 - p[3])\)\ 
                \((1 - p[4])\) - 
              8\ cb[5]\ \((1 - p[2])\)\ \((1 - p[3])\)\ \((1 - p[4])\) - 
              30\ cb[3]\ cw[2]\ \((1 - p[2])\)\ \((1 - p[3])\)\ 
                \((1 - p[4])\) - 
              8\ cb[2]\ cw[3]\ \((1 - p[2])\)\ \((1 - p[3])\)\ 
                \((1 - p[4])\) - 
              6\ cw[2]\ cw[3]\ \((1 - p[2])\)\ \((1 - p[3])\)\ 
                \((1 - p[4])\) + 
              12\ cb[2]\^2\ \((1 - p[1])\)\ \((1 - p[2])\)\ \((1 - p[3])\)\ 
                \((1 - p[4])\) + 
              14\ cb[4]\ \((1 - p[1])\)\ \((1 - p[2])\)\ \((1 - p[3])\)\ 
                \((1 - p[4])\) + 
              24\ cb[2]\ cw[2]\ \((1 - p[1])\)\ \((1 - p[2])\)\ 
                \((1 - p[3])\)\ \((1 - p[4])\) + 
              12\ cw[2]\^2\ \((1 - p[1])\)\ \((1 - p[2])\)\ \((1 - p[3])\)\ 
                \((1 - p[4])\) + 
              2\ cw[4]\ \((1 - p[1])\)\ \((1 - p[2])\)\ \((1 - p[3])\)\ 
                \((1 - p[4])\) - 
              6\ cb[3]\ \((1 - p[1])\)\^2\ \((1 - p[2])\)\ \((1 - p[3])\)\ 
                \((1 - p[4])\) - 
              2\ cw[3]\ \((1 - p[1])\)\^2\ \((1 - p[2])\)\ \((1 - p[3])\)\ 
                \((1 - p[4])\) + 
              4\ cb[2]\^2\ \((1 - p[2])\)\^2\ \((1 - p[3])\)\ 
                \((1 - p[4])\) + 
              4\ cb[4]\ \((1 - p[2])\)\^2\ \((1 - p[3])\)\ \((1 - p[4])\) + 
              6\ cb[2]\ cw[2]\ \((1 - p[2])\)\^2\ \((1 - p[3])\)\ 
                \((1 - p[4])\) + 
              2\ cw[2]\^2\ \((1 - p[2])\)\^2\ \((1 - p[3])\)\ 
                \((1 - p[4])\) - 
              6\ cb[3]\ \((1 - p[1])\)\ \((1 - p[2])\)\^2\ \((1 - p[3])\)\ 
                \((1 - p[4])\) - 
              2\ cw[3]\ \((1 - p[1])\)\ \((1 - p[2])\)\^2\ \((1 - p[3])\)\ 
                \((1 - p[4])\) + 
              2\ cb[2]\ \((1 - p[1])\)\^2\ \((1 - p[2])\)\^2\ \((1 - p[3])\)\ 
                \((1 - p[4])\) + 
              2\ cw[2]\ \((1 - p[1])\)\^2\ \((1 - p[2])\)\^2\ \((1 - p[3])\)\ 
                \((1 - p[4])\) - 
              12\ cb[2]\ cb[3]\ \((1 - p[3])\)\^2\ \((1 - p[4])\) - 
              2\ cb[5]\ \((1 - p[3])\)\^2\ \((1 - p[4])\) - 
              6\ cb[3]\ cw[2]\ \((1 - p[3])\)\^2\ \((1 - p[4])\) - 
              2\ cw[2]\ cw[3]\ \((1 - p[3])\)\^2\ \((1 - p[4])\) + 
              4\ cb[2]\^2\ \((1 - p[1])\)\ \((1 - p[3])\)\^2\ 
                \((1 - p[4])\) + 
              4\ cb[4]\ \((1 - p[1])\)\ \((1 - p[3])\)\^2\ \((1 - p[4])\) + 
              6\ cb[2]\ cw[2]\ \((1 - p[1])\)\ \((1 - p[3])\)\^2\ 
                \((1 - p[4])\) + 
              2\ cw[2]\^2\ \((1 - p[1])\)\ \((1 - p[3])\)\^2\ 
                \((1 - p[4])\) - 
              2\ cb[3]\ \((1 - p[1])\)\^2\ \((1 - p[3])\)\^2\ 
                \((1 - p[4])\) + 
              4\ cb[2]\^2\ \((1 - p[2])\)\ \((1 - p[3])\)\^2\ 
                \((1 - p[4])\) + 
              4\ cb[4]\ \((1 - p[2])\)\ \((1 - p[3])\)\^2\ \((1 - p[4])\) + 
              6\ cb[2]\ cw[2]\ \((1 - p[2])\)\ \((1 - p[3])\)\^2\ 
                \((1 - p[4])\) + 
              2\ cw[2]\^2\ \((1 - p[2])\)\ \((1 - p[3])\)\^2\ 
                \((1 - p[4])\) - 
              6\ cb[3]\ \((1 - p[1])\)\ \((1 - p[2])\)\ \((1 - p[3])\)\^2\ 
                \((1 - p[4])\) - 
              2\ cw[3]\ \((1 - p[1])\)\ \((1 - p[2])\)\ \((1 - p[3])\)\^2\ 
                \((1 - p[4])\) + 
              2\ cb[2]\ \((1 - p[1])\)\^2\ \((1 - p[2])\)\ \((1 - p[3])\)\^2\ 
                \((1 - p[4])\) + 
              2\ cw[2]\ \((1 - p[1])\)\^2\ \((1 - p[2])\)\ \((1 - p[3])\)\^2\ 
                \((1 - p[4])\) - 
              2\ cb[3]\ \((1 - p[2])\)\^2\ \((1 - p[3])\)\^2\ 
                \((1 - p[4])\) + 
              2\ cb[2]\ \((1 - p[1])\)\ \((1 - p[2])\)\^2\ \((1 - p[3])\)\^2\ 
                \((1 - p[4])\) + 
              2\ cw[2]\ \((1 - p[1])\)\ \((1 - p[2])\)\^2\ \((1 - p[3])\)\^2\ 
                \((1 - p[4])\) + 6\ cb[2]\^3\ \((1 - p[4])\)\^2 + 
              9\ cb[3]\^2\ \((1 - p[4])\)\^2 + 
              9\ cb[2]\ cb[4]\ \((1 - p[4])\)\^2 + cb[6]\ \((1 - p[4])\)\^2 + 
              6\ cb[4]\ cw[2]\ \((1 - p[4])\)\^2 + 
              9\ cb[2]\ cw[2]\^2\ \((1 - p[4])\)\^2 + 
              cw[3]\^2\ \((1 - p[4])\)\^2 - 
              12\ cb[2]\ cb[3]\ \((1 - p[1])\)\ \((1 - p[4])\)\^2 - 
              2\ cb[5]\ \((1 - p[1])\)\ \((1 - p[4])\)\^2 - 
              6\ cb[3]\ cw[2]\ \((1 - p[1])\)\ \((1 - p[4])\)\^2 - 
              2\ cw[2]\ cw[3]\ \((1 - p[1])\)\ \((1 - p[4])\)\^2 + 
              2\ cb[2]\^2\ \((1 - p[1])\)\^2\ \((1 - p[4])\)\^2 + 
              cb[4]\ \((1 - p[1])\)\^2\ \((1 - p[4])\)\^2 + 
              cw[2]\^2\ \((1 - p[1])\)\^2\ \((1 - p[4])\)\^2 - 
              12\ cb[2]\ cb[3]\ \((1 - p[2])\)\ \((1 - p[4])\)\^2 - 
              2\ cb[5]\ \((1 - p[2])\)\ \((1 - p[4])\)\^2 - 
              6\ cb[3]\ cw[2]\ \((1 - p[2])\)\ \((1 - p[4])\)\^2 - 
              2\ cw[2]\ cw[3]\ \((1 - p[2])\)\ \((1 - p[4])\)\^2 + 
              4\ cb[2]\^2\ \((1 - p[1])\)\ \((1 - p[2])\)\ 
                \((1 - p[4])\)\^2 + 
              4\ cb[4]\ \((1 - p[1])\)\ \((1 - p[2])\)\ \((1 - p[4])\)\^2 + 
              6\ cb[2]\ cw[2]\ \((1 - p[1])\)\ \((1 - p[2])\)\ 
                \((1 - p[4])\)\^2 + 
              2\ cw[2]\^2\ \((1 - p[1])\)\ \((1 - p[2])\)\ 
                \((1 - p[4])\)\^2 - 
              2\ cb[3]\ \((1 - p[1])\)\^2\ \((1 - p[2])\)\ 
                \((1 - p[4])\)\^2 + 
              2\ cb[2]\^2\ \((1 - p[2])\)\^2\ \((1 - p[4])\)\^2 + 
              cb[4]\ \((1 - p[2])\)\^2\ \((1 - p[4])\)\^2 + 
              cw[2]\^2\ \((1 - p[2])\)\^2\ \((1 - p[4])\)\^2 - 
              2\ cb[3]\ \((1 - p[1])\)\ \((1 - p[2])\)\^2\ 
                \((1 - p[4])\)\^2 + 
              cb[2]\ \((1 - p[1])\)\^2\ \((1 - p[2])\)\^2\ 
                \((1 - p[4])\)\^2 - 
              12\ cb[2]\ cb[3]\ \((1 - p[3])\)\ \((1 - p[4])\)\^2 - 
              2\ cb[5]\ \((1 - p[3])\)\ \((1 - p[4])\)\^2 - 
              6\ cb[3]\ cw[2]\ \((1 - p[3])\)\ \((1 - p[4])\)\^2 - 
              2\ cw[2]\ cw[3]\ \((1 - p[3])\)\ \((1 - p[4])\)\^2 + 
              4\ cb[2]\^2\ \((1 - p[1])\)\ \((1 - p[3])\)\ 
                \((1 - p[4])\)\^2 + 
              4\ cb[4]\ \((1 - p[1])\)\ \((1 - p[3])\)\ \((1 - p[4])\)\^2 + 
              6\ cb[2]\ cw[2]\ \((1 - p[1])\)\ \((1 - p[3])\)\ 
                \((1 - p[4])\)\^2 + 
              2\ cw[2]\^2\ \((1 - p[1])\)\ \((1 - p[3])\)\ 
                \((1 - p[4])\)\^2 - 
              2\ cb[3]\ \((1 - p[1])\)\^2\ \((1 - p[3])\)\ 
                \((1 - p[4])\)\^2 + 
              4\ cb[2]\^2\ \((1 - p[2])\)\ \((1 - p[3])\)\ 
                \((1 - p[4])\)\^2 + 
              4\ cb[4]\ \((1 - p[2])\)\ \((1 - p[3])\)\ \((1 - p[4])\)\^2 + 
              6\ cb[2]\ cw[2]\ \((1 - p[2])\)\ \((1 - p[3])\)\ 
                \((1 - p[4])\)\^2 + 
              2\ cw[2]\^2\ \((1 - p[2])\)\ \((1 - p[3])\)\ 
                \((1 - p[4])\)\^2 - 
              6\ cb[3]\ \((1 - p[1])\)\ \((1 - p[2])\)\ \((1 - p[3])\)\ 
                \((1 - p[4])\)\^2 - 
              2\ cw[3]\ \((1 - p[1])\)\ \((1 - p[2])\)\ \((1 - p[3])\)\ 
                \((1 - p[4])\)\^2 + 
              2\ cb[2]\ \((1 - p[1])\)\^2\ \((1 - p[2])\)\ \((1 - p[3])\)\ 
                \((1 - p[4])\)\^2 + 
              2\ cw[2]\ \((1 - p[1])\)\^2\ \((1 - p[2])\)\ \((1 - p[3])\)\ 
                \((1 - p[4])\)\^2 - 
              2\ cb[3]\ \((1 - p[2])\)\^2\ \((1 - p[3])\)\ 
                \((1 - p[4])\)\^2 + 
              2\ cb[2]\ \((1 - p[1])\)\ \((1 - p[2])\)\^2\ \((1 - p[3])\)\ 
                \((1 - p[4])\)\^2 + 
              2\ cw[2]\ \((1 - p[1])\)\ \((1 - p[2])\)\^2\ \((1 - p[3])\)\ 
                \((1 - p[4])\)\^2 + 
              2\ cb[2]\^2\ \((1 - p[3])\)\^2\ \((1 - p[4])\)\^2 + 
              cb[4]\ \((1 - p[3])\)\^2\ \((1 - p[4])\)\^2 + 
              cw[2]\^2\ \((1 - p[3])\)\^2\ \((1 - p[4])\)\^2 - 
              2\ cb[3]\ \((1 - p[1])\)\ \((1 - p[3])\)\^2\ 
                \((1 - p[4])\)\^2 + 
              cb[2]\ \((1 - p[1])\)\^2\ \((1 - p[3])\)\^2\ 
                \((1 - p[4])\)\^2 - 
              2\ cb[3]\ \((1 - p[2])\)\ \((1 - p[3])\)\^2\ 
                \((1 - p[4])\)\^2 + 
              2\ cb[2]\ \((1 - p[1])\)\ \((1 - p[2])\)\ \((1 - p[3])\)\^2\ 
                \((1 - p[4])\)\^2 + 
              2\ cw[2]\ \((1 - p[1])\)\ \((1 - p[2])\)\ \((1 - p[3])\)\^2\ 
                \((1 - p[4])\)\^2 + 
              cb[2]\ \((1 - p[2])\)\^2\ \((1 - p[3])\)\^2\ 
                \((1 - p[4])\)\^2 + 
              \((1 - p[1])\)\^2\ \((1 - p[2])\)\^2\ \((1 - p[3])\)\^2\ 
                \((1 - p[4])\)\^2)\)]\)], "Output"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    \(\( (*\ 
      This\ uses\ the\ stored\ gdt2\ on\ a\ different\ dataset\  - \ 
        valid\ because\ gdt2\ contains\ the\ general\ formula\ in\ terms\ of\ 
          p[], cw[], cb[] . \ Larger\ \(dataset . \)\ *) \n
    Timing[llK = 
        LogLikelihoodDisequilibrium[Kopanka, {cw, cb}, 1&, p, S, gdt2]; ]
      \)\)], "Input"],

Cell[BoxData[
    \({962.233333333333362`\ Second, Null}\)], "Output"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    \(Timing[gdt2[{0, 0, 2, 1}]]\)], "Input"],

Cell[BoxData[
    \({3.08333333333575865`\ Second, 
      \(-48\)\ cb[2]\^4 - 288\ cb[2]\ cb[3]\^2 - 144\ cb[2]\^2\ cb[4] - 
        68\ cb[4]\^2 - 96\ cb[3]\ cb[5] - 32\ cb[2]\ cb[6] - 2\ cb[8] - 
        144\ cb[3]\^2\ cw[2] - 192\ cb[2]\ cb[4]\ cw[2] - 24\ cb[6]\ cw[2] - 
        144\ cb[2]\^2\ cw[2]\^2 - 72\ cb[4]\ cw[2]\^2 - 18\ cw[2]\^4 - 
        16\ cb[5]\ cw[3] - 96\ cb[3]\ cw[2]\ cw[3] - 32\ cb[2]\ cw[3]\^2 - 
        12\ cw[2]\^2\ cw[4] - 2\ cw[4]\^2 + 
        144\ cb[2]\^2\ cb[3]\ \((1 - p[1])\) + 
        120\ cb[3]\ cb[4]\ \((1 - p[1])\) + 
        48\ cb[2]\ cb[5]\ \((1 - p[1])\) + 4\ cb[7]\ \((1 - p[1])\) + 
        144\ cb[2]\ cb[3]\ cw[2]\ \((1 - p[1])\) + 
        36\ cb[5]\ cw[2]\ \((1 - p[1])\) + 
        72\ cb[3]\ cw[2]\^2\ \((1 - p[1])\) + 
        16\ cb[4]\ cw[3]\ \((1 - p[1])\) + 
        48\ cb[2]\ cw[2]\ cw[3]\ \((1 - p[1])\) + 
        12\ cw[2]\^2\ cw[3]\ \((1 - p[1])\) + 
        4\ cw[3]\ cw[4]\ \((1 - p[1])\) - 12\ cb[2]\^3\ \((1 - p[1])\)\^2 - 
        18\ cb[3]\^2\ \((1 - p[1])\)\^2 - 
        18\ cb[2]\ cb[4]\ \((1 - p[1])\)\^2 - 2\ cb[6]\ \((1 - p[1])\)\^2 - 
        12\ cb[4]\ cw[2]\ \((1 - p[1])\)\^2 - 
        18\ cb[2]\ cw[2]\^2\ \((1 - p[1])\)\^2 - 
        2\ cw[3]\^2\ \((1 - p[1])\)\^2 + 
        144\ cb[2]\^2\ cb[3]\ \((1 - p[2])\) + 
        120\ cb[3]\ cb[4]\ \((1 - p[2])\) + 
        48\ cb[2]\ cb[5]\ \((1 - p[2])\) + 4\ cb[7]\ \((1 - p[2])\) + 
        144\ cb[2]\ cb[3]\ cw[2]\ \((1 - p[2])\) + 
        36\ cb[5]\ cw[2]\ \((1 - p[2])\) + 
        72\ cb[3]\ cw[2]\^2\ \((1 - p[2])\) + 
        16\ cb[4]\ cw[3]\ \((1 - p[2])\) + 
        48\ cb[2]\ cw[2]\ cw[3]\ \((1 - p[2])\) + 
        12\ cw[2]\^2\ cw[3]\ \((1 - p[2])\) + 
        4\ cw[3]\ cw[4]\ \((1 - p[2])\) - 
        24\ cb[2]\^3\ \((1 - p[1])\)\ \((1 - p[2])\) - 
        60\ cb[3]\^2\ \((1 - p[1])\)\ \((1 - p[2])\) - 
        68\ cb[2]\ cb[4]\ \((1 - p[1])\)\ \((1 - p[2])\) - 
        8\ cb[6]\ \((1 - p[1])\)\ \((1 - p[2])\) - 
        48\ cb[2]\^2\ cw[2]\ \((1 - p[1])\)\ \((1 - p[2])\) - 
        48\ cb[4]\ cw[2]\ \((1 - p[1])\)\ \((1 - p[2])\) - 
        36\ cb[2]\ cw[2]\^2\ \((1 - p[1])\)\ \((1 - p[2])\) - 
        12\ cw[2]\^3\ \((1 - p[1])\)\ \((1 - p[2])\) - 
        16\ cb[3]\ cw[3]\ \((1 - p[1])\)\ \((1 - p[2])\) - 
        4\ cw[3]\^2\ \((1 - p[1])\)\ \((1 - p[2])\) - 
        4\ cw[2]\ cw[4]\ \((1 - p[1])\)\ \((1 - p[2])\) + 
        24\ cb[2]\ cb[3]\ \((1 - p[1])\)\^2\ \((1 - p[2])\) + 
        4\ cb[5]\ \((1 - p[1])\)\^2\ \((1 - p[2])\) + 
        12\ cb[3]\ cw[2]\ \((1 - p[1])\)\^2\ \((1 - p[2])\) + 
        4\ cw[2]\ cw[3]\ \((1 - p[1])\)\^2\ \((1 - p[2])\) - 
        12\ cb[2]\^3\ \((1 - p[2])\)\^2 - 18\ cb[3]\^2\ \((1 - p[2])\)\^2 - 
        18\ cb[2]\ cb[4]\ \((1 - p[2])\)\^2 - 2\ cb[6]\ \((1 - p[2])\)\^2 - 
        12\ cb[4]\ cw[2]\ \((1 - p[2])\)\^2 - 
        18\ cb[2]\ cw[2]\^2\ \((1 - p[2])\)\^2 - 
        2\ cw[3]\^2\ \((1 - p[2])\)\^2 + 
        24\ cb[2]\ cb[3]\ \((1 - p[1])\)\ \((1 - p[2])\)\^2 + 
        4\ cb[5]\ \((1 - p[1])\)\ \((1 - p[2])\)\^2 + 
        12\ cb[3]\ cw[2]\ \((1 - p[1])\)\ \((1 - p[2])\)\^2 + 
        4\ cw[2]\ cw[3]\ \((1 - p[1])\)\ \((1 - p[2])\)\^2 - 
        4\ cb[2]\^2\ \((1 - p[1])\)\^2\ \((1 - p[2])\)\^2 - 
        2\ cb[4]\ \((1 - p[1])\)\^2\ \((1 - p[2])\)\^2 - 
        2\ cw[2]\^2\ \((1 - p[1])\)\^2\ \((1 - p[2])\)\^2 - 
        144\ cb[2]\^2\ cb[3]\ p[3] - 120\ cb[3]\ cb[4]\ p[3] - 
        48\ cb[2]\ cb[5]\ p[3] - 4\ cb[7]\ p[3] - 
        144\ cb[2]\ cb[3]\ cw[2]\ p[3] - 36\ cb[5]\ cw[2]\ p[3] - 
        72\ cb[3]\ cw[2]\^2\ p[3] - 16\ cb[4]\ cw[3]\ p[3] - 
        48\ cb[2]\ cw[2]\ cw[3]\ p[3] - 12\ cw[2]\^2\ cw[3]\ p[3] - 
        4\ cw[3]\ cw[4]\ p[3] + 24\ cb[2]\^3\ \((1 - p[1])\)\ p[3] + 
        60\ cb[3]\^2\ \((1 - p[1])\)\ p[3] + 
        68\ cb[2]\ cb[4]\ \((1 - p[1])\)\ p[3] + 
        8\ cb[6]\ \((1 - p[1])\)\ p[3] + 
        48\ cb[2]\^2\ cw[2]\ \((1 - p[1])\)\ p[3] + 
        48\ cb[4]\ cw[2]\ \((1 - p[1])\)\ p[3] + 
        36\ cb[2]\ cw[2]\^2\ \((1 - p[1])\)\ p[3] + 
        12\ cw[2]\^3\ \((1 - p[1])\)\ p[3] + 
        16\ cb[3]\ cw[3]\ \((1 - p[1])\)\ p[3] + 
        4\ cw[3]\^2\ \((1 - p[1])\)\ p[3] + 
        4\ cw[2]\ cw[4]\ \((1 - p[1])\)\ p[3] - 
        24\ cb[2]\ cb[3]\ \((1 - p[1])\)\^2\ p[3] - 
        4\ cb[5]\ \((1 - p[1])\)\^2\ p[3] - 
        12\ cb[3]\ cw[2]\ \((1 - p[1])\)\^2\ p[3] - 
        4\ cw[2]\ cw[3]\ \((1 - p[1])\)\^2\ p[3] + 
        24\ cb[2]\^3\ \((1 - p[2])\)\ p[3] + 
        60\ cb[3]\^2\ \((1 - p[2])\)\ p[3] + 
        68\ cb[2]\ cb[4]\ \((1 - p[2])\)\ p[3] + 
        8\ cb[6]\ \((1 - p[2])\)\ p[3] + 
        48\ cb[2]\^2\ cw[2]\ \((1 - p[2])\)\ p[3] + 
        48\ cb[4]\ cw[2]\ \((1 - p[2])\)\ p[3] + 
        36\ cb[2]\ cw[2]\^2\ \((1 - p[2])\)\ p[3] + 
        12\ cw[2]\^3\ \((1 - p[2])\)\ p[3] + 
        16\ cb[3]\ cw[3]\ \((1 - p[2])\)\ p[3] + 
        4\ cw[3]\^2\ \((1 - p[2])\)\ p[3] + 
        4\ cw[2]\ cw[4]\ \((1 - p[2])\)\ p[3] - 
        72\ cb[2]\ cb[3]\ \((1 - p[1])\)\ \((1 - p[2])\)\ p[3] - 
        16\ cb[5]\ \((1 - p[1])\)\ \((1 - p[2])\)\ p[3] - 
        60\ cb[3]\ cw[2]\ \((1 - p[1])\)\ \((1 - p[2])\)\ p[3] - 
        16\ cb[2]\ cw[3]\ \((1 - p[1])\)\ \((1 - p[2])\)\ p[3] - 
        12\ cw[2]\ cw[3]\ \((1 - p[1])\)\ \((1 - p[2])\)\ p[3] + 
        8\ cb[2]\^2\ \((1 - p[1])\)\^2\ \((1 - p[2])\)\ p[3] + 
        8\ cb[4]\ \((1 - p[1])\)\^2\ \((1 - p[2])\)\ p[3] + 
        12\ cb[2]\ cw[2]\ \((1 - p[1])\)\^2\ \((1 - p[2])\)\ p[3] + 
        4\ cw[2]\^2\ \((1 - p[1])\)\^2\ \((1 - p[2])\)\ p[3] - 
        24\ cb[2]\ cb[3]\ \((1 - p[2])\)\^2\ p[3] - 
        4\ cb[5]\ \((1 - p[2])\)\^2\ p[3] - 
        12\ cb[3]\ cw[2]\ \((1 - p[2])\)\^2\ p[3] - 
        4\ cw[2]\ cw[3]\ \((1 - p[2])\)\^2\ p[3] + 
        8\ cb[2]\^2\ \((1 - p[1])\)\ \((1 - p[2])\)\^2\ p[3] + 
        8\ cb[4]\ \((1 - p[1])\)\ \((1 - p[2])\)\^2\ p[3] + 
        12\ cb[2]\ cw[2]\ \((1 - p[1])\)\ \((1 - p[2])\)\^2\ p[3] + 
        4\ cw[2]\^2\ \((1 - p[1])\)\ \((1 - p[2])\)\^2\ p[3] - 
        4\ cb[3]\ \((1 - p[1])\)\^2\ \((1 - p[2])\)\^2\ p[3] - 
        12\ cb[2]\^3\ p[3]\^2 - 18\ cb[3]\^2\ p[3]\^2 - 
        18\ cb[2]\ cb[4]\ p[3]\^2 - 2\ cb[6]\ p[3]\^2 - 
        12\ cb[4]\ cw[2]\ p[3]\^2 - 18\ cb[2]\ cw[2]\^2\ p[3]\^2 - 
        2\ cw[3]\^2\ p[3]\^2 + 24\ cb[2]\ cb[3]\ \((1 - p[1])\)\ p[3]\^2 + 
        4\ cb[5]\ \((1 - p[1])\)\ p[3]\^2 + 
        12\ cb[3]\ cw[2]\ \((1 - p[1])\)\ p[3]\^2 + 
        4\ cw[2]\ cw[3]\ \((1 - p[1])\)\ p[3]\^2 - 
        4\ cb[2]\^2\ \((1 - p[1])\)\^2\ p[3]\^2 - 
        2\ cb[4]\ \((1 - p[1])\)\^2\ p[3]\^2 - 
        2\ cw[2]\^2\ \((1 - p[1])\)\^2\ p[3]\^2 + 
        24\ cb[2]\ cb[3]\ \((1 - p[2])\)\ p[3]\^2 + 
        4\ cb[5]\ \((1 - p[2])\)\ p[3]\^2 + 
        12\ cb[3]\ cw[2]\ \((1 - p[2])\)\ p[3]\^2 + 
        4\ cw[2]\ cw[3]\ \((1 - p[2])\)\ p[3]\^2 - 
        8\ cb[2]\^2\ \((1 - p[1])\)\ \((1 - p[2])\)\ p[3]\^2 - 
        8\ cb[4]\ \((1 - p[1])\)\ \((1 - p[2])\)\ p[3]\^2 - 
        12\ cb[2]\ cw[2]\ \((1 - p[1])\)\ \((1 - p[2])\)\ p[3]\^2 - 
        4\ cw[2]\^2\ \((1 - p[1])\)\ \((1 - p[2])\)\ p[3]\^2 + 
        4\ cb[3]\ \((1 - p[1])\)\^2\ \((1 - p[2])\)\ p[3]\^2 - 
        4\ cb[2]\^2\ \((1 - p[2])\)\^2\ p[3]\^2 - 
        2\ cb[4]\ \((1 - p[2])\)\^2\ p[3]\^2 - 
        2\ cw[2]\^2\ \((1 - p[2])\)\^2\ p[3]\^2 + 
        4\ cb[3]\ \((1 - p[1])\)\ \((1 - p[2])\)\^2\ p[3]\^2 - 
        2\ cb[2]\ \((1 - p[1])\)\^2\ \((1 - p[2])\)\^2\ p[3]\^2 + 
        72\ cb[2]\^2\ cb[3]\ \((1 - p[4])\) + 
        60\ cb[3]\ cb[4]\ \((1 - p[4])\) + 24\ cb[2]\ cb[5]\ \((1 - p[4])\) + 
        2\ cb[7]\ \((1 - p[4])\) + 72\ cb[2]\ cb[3]\ cw[2]\ \((1 - p[4])\) + 
        18\ cb[5]\ cw[2]\ \((1 - p[4])\) + 
        36\ cb[3]\ cw[2]\^2\ \((1 - p[4])\) + 
        8\ cb[4]\ cw[3]\ \((1 - p[4])\) + 
        24\ cb[2]\ cw[2]\ cw[3]\ \((1 - p[4])\) + 
        6\ cw[2]\^2\ cw[3]\ \((1 - p[4])\) + 
        2\ cw[3]\ cw[4]\ \((1 - p[4])\) - 
        12\ cb[2]\^3\ \((1 - p[1])\)\ \((1 - p[4])\) - 
        30\ cb[3]\^2\ \((1 - p[1])\)\ \((1 - p[4])\) - 
        34\ cb[2]\ cb[4]\ \((1 - p[1])\)\ \((1 - p[4])\) - 
        4\ cb[6]\ \((1 - p[1])\)\ \((1 - p[4])\) - 
        24\ cb[2]\^2\ cw[2]\ \((1 - p[1])\)\ \((1 - p[4])\) - 
        24\ cb[4]\ cw[2]\ \((1 - p[1])\)\ \((1 - p[4])\) - 
        18\ cb[2]\ cw[2]\^2\ \((1 - p[1])\)\ \((1 - p[4])\) - 
        6\ cw[2]\^3\ \((1 - p[1])\)\ \((1 - p[4])\) - 
        8\ cb[3]\ cw[3]\ \((1 - p[1])\)\ \((1 - p[4])\) - 
        2\ cw[3]\^2\ \((1 - p[1])\)\ \((1 - p[4])\) - 
        2\ cw[2]\ cw[4]\ \((1 - p[1])\)\ \((1 - p[4])\) + 
        12\ cb[2]\ cb[3]\ \((1 - p[1])\)\^2\ \((1 - p[4])\) + 
        2\ cb[5]\ \((1 - p[1])\)\^2\ \((1 - p[4])\) + 
        6\ cb[3]\ cw[2]\ \((1 - p[1])\)\^2\ \((1 - p[4])\) + 
        2\ cw[2]\ cw[3]\ \((1 - p[1])\)\^2\ \((1 - p[4])\) - 
        12\ cb[2]\^3\ \((1 - p[2])\)\ \((1 - p[4])\) - 
        30\ cb[3]\^2\ \((1 - p[2])\)\ \((1 - p[4])\) - 
        34\ cb[2]\ cb[4]\ \((1 - p[2])\)\ \((1 - p[4])\) - 
        4\ cb[6]\ \((1 - p[2])\)\ \((1 - p[4])\) - 
        24\ cb[2]\^2\ cw[2]\ \((1 - p[2])\)\ \((1 - p[4])\) - 
        24\ cb[4]\ cw[2]\ \((1 - p[2])\)\ \((1 - p[4])\) - 
        18\ cb[2]\ cw[2]\^2\ \((1 - p[2])\)\ \((1 - p[4])\) - 
        6\ cw[2]\^3\ \((1 - p[2])\)\ \((1 - p[4])\) - 
        8\ cb[3]\ cw[3]\ \((1 - p[2])\)\ \((1 - p[4])\) - 
        2\ cw[3]\^2\ \((1 - p[2])\)\ \((1 - p[4])\) - 
        2\ cw[2]\ cw[4]\ \((1 - p[2])\)\ \((1 - p[4])\) + 
        36\ cb[2]\ cb[3]\ \((1 - p[1])\)\ \((1 - p[2])\)\ \((1 - p[4])\) + 
        8\ cb[5]\ \((1 - p[1])\)\ \((1 - p[2])\)\ \((1 - p[4])\) + 
        30\ cb[3]\ cw[2]\ \((1 - p[1])\)\ \((1 - p[2])\)\ \((1 - p[4])\) + 
        8\ cb[2]\ cw[3]\ \((1 - p[1])\)\ \((1 - p[2])\)\ \((1 - p[4])\) + 
        6\ cw[2]\ cw[3]\ \((1 - p[1])\)\ \((1 - p[2])\)\ \((1 - p[4])\) - 
        4\ cb[2]\^2\ \((1 - p[1])\)\^2\ \((1 - p[2])\)\ \((1 - p[4])\) - 
        4\ cb[4]\ \((1 - p[1])\)\^2\ \((1 - p[2])\)\ \((1 - p[4])\) - 
        6\ cb[2]\ cw[2]\ \((1 - p[1])\)\^2\ \((1 - p[2])\)\ \((1 - p[4])\) - 
        2\ cw[2]\^2\ \((1 - p[1])\)\^2\ \((1 - p[2])\)\ \((1 - p[4])\) + 
        12\ cb[2]\ cb[3]\ \((1 - p[2])\)\^2\ \((1 - p[4])\) + 
        2\ cb[5]\ \((1 - p[2])\)\^2\ \((1 - p[4])\) + 
        6\ cb[3]\ cw[2]\ \((1 - p[2])\)\^2\ \((1 - p[4])\) + 
        2\ cw[2]\ cw[3]\ \((1 - p[2])\)\^2\ \((1 - p[4])\) - 
        4\ cb[2]\^2\ \((1 - p[1])\)\ \((1 - p[2])\)\^2\ \((1 - p[4])\) - 
        4\ cb[4]\ \((1 - p[1])\)\ \((1 - p[2])\)\^2\ \((1 - p[4])\) - 
        6\ cb[2]\ cw[2]\ \((1 - p[1])\)\ \((1 - p[2])\)\^2\ \((1 - p[4])\) - 
        2\ cw[2]\^2\ \((1 - p[1])\)\ \((1 - p[2])\)\^2\ \((1 - p[4])\) + 
        2\ cb[3]\ \((1 - p[1])\)\^2\ \((1 - p[2])\)\^2\ \((1 - p[4])\) + 
        12\ cb[2]\^3\ p[3]\ \((1 - p[4])\) + 
        30\ cb[3]\^2\ p[3]\ \((1 - p[4])\) + 
        34\ cb[2]\ cb[4]\ p[3]\ \((1 - p[4])\) + 
        4\ cb[6]\ p[3]\ \((1 - p[4])\) + 
        24\ cb[2]\^2\ cw[2]\ p[3]\ \((1 - p[4])\) + 
        24\ cb[4]\ cw[2]\ p[3]\ \((1 - p[4])\) + 
        18\ cb[2]\ cw[2]\^2\ p[3]\ \((1 - p[4])\) + 
        6\ cw[2]\^3\ p[3]\ \((1 - p[4])\) + 
        8\ cb[3]\ cw[3]\ p[3]\ \((1 - p[4])\) + 
        2\ cw[3]\^2\ p[3]\ \((1 - p[4])\) + 
        2\ cw[2]\ cw[4]\ p[3]\ \((1 - p[4])\) - 
        36\ cb[2]\ cb[3]\ \((1 - p[1])\)\ p[3]\ \((1 - p[4])\) - 
        8\ cb[5]\ \((1 - p[1])\)\ p[3]\ \((1 - p[4])\) - 
        30\ cb[3]\ cw[2]\ \((1 - p[1])\)\ p[3]\ \((1 - p[4])\) - 
        8\ cb[2]\ cw[3]\ \((1 - p[1])\)\ p[3]\ \((1 - p[4])\) - 
        6\ cw[2]\ cw[3]\ \((1 - p[1])\)\ p[3]\ \((1 - p[4])\) + 
        4\ cb[2]\^2\ \((1 - p[1])\)\^2\ p[3]\ \((1 - p[4])\) + 
        4\ cb[4]\ \((1 - p[1])\)\^2\ p[3]\ \((1 - p[4])\) + 
        6\ cb[2]\ cw[2]\ \((1 - p[1])\)\^2\ p[3]\ \((1 - p[4])\) + 
        2\ cw[2]\^2\ \((1 - p[1])\)\^2\ p[3]\ \((1 - p[4])\) - 
        36\ cb[2]\ cb[3]\ \((1 - p[2])\)\ p[3]\ \((1 - p[4])\) - 
        8\ cb[5]\ \((1 - p[2])\)\ p[3]\ \((1 - p[4])\) - 
        30\ cb[3]\ cw[2]\ \((1 - p[2])\)\ p[3]\ \((1 - p[4])\) - 
        8\ cb[2]\ cw[3]\ \((1 - p[2])\)\ p[3]\ \((1 - p[4])\) - 
        6\ cw[2]\ cw[3]\ \((1 - p[2])\)\ p[3]\ \((1 - p[4])\) + 
        12\ cb[2]\^2\ \((1 - p[1])\)\ \((1 - p[2])\)\ p[3]\ \((1 - p[4])\) + 
        14\ cb[4]\ \((1 - p[1])\)\ \((1 - p[2])\)\ p[3]\ \((1 - p[4])\) + 
        24\ cb[2]\ cw[2]\ \((1 - p[1])\)\ \((1 - p[2])\)\ p[3]\ 
          \((1 - p[4])\) + 
        12\ cw[2]\^2\ \((1 - p[1])\)\ \((1 - p[2])\)\ p[3]\ \((1 - p[4])\) + 
        2\ cw[4]\ \((1 - p[1])\)\ \((1 - p[2])\)\ p[3]\ \((1 - p[4])\) - 
        6\ cb[3]\ \((1 - p[1])\)\^2\ \((1 - p[2])\)\ p[3]\ \((1 - p[4])\) - 
        2\ cw[3]\ \((1 - p[1])\)\^2\ \((1 - p[2])\)\ p[3]\ \((1 - p[4])\) + 
        4\ cb[2]\^2\ \((1 - p[2])\)\^2\ p[3]\ \((1 - p[4])\) + 
        4\ cb[4]\ \((1 - p[2])\)\^2\ p[3]\ \((1 - p[4])\) + 
        6\ cb[2]\ cw[2]\ \((1 - p[2])\)\^2\ p[3]\ \((1 - p[4])\) + 
        2\ cw[2]\^2\ \((1 - p[2])\)\^2\ p[3]\ \((1 - p[4])\) - 
        6\ cb[3]\ \((1 - p[1])\)\ \((1 - p[2])\)\^2\ p[3]\ \((1 - p[4])\) - 
        2\ cw[3]\ \((1 - p[1])\)\ \((1 - p[2])\)\^2\ p[3]\ \((1 - p[4])\) + 
        2\ cb[2]\ \((1 - p[1])\)\^2\ \((1 - p[2])\)\^2\ p[3]\ 
          \((1 - p[4])\) + 
        2\ cw[2]\ \((1 - p[1])\)\^2\ \((1 - p[2])\)\^2\ p[3]\ 
          \((1 - p[4])\) + 12\ cb[2]\ cb[3]\ p[3]\^2\ \((1 - p[4])\) + 
        2\ cb[5]\ p[3]\^2\ \((1 - p[4])\) + 
        6\ cb[3]\ cw[2]\ p[3]\^2\ \((1 - p[4])\) + 
        2\ cw[2]\ cw[3]\ p[3]\^2\ \((1 - p[4])\) - 
        4\ cb[2]\^2\ \((1 - p[1])\)\ p[3]\^2\ \((1 - p[4])\) - 
        4\ cb[4]\ \((1 - p[1])\)\ p[3]\^2\ \((1 - p[4])\) - 
        6\ cb[2]\ cw[2]\ \((1 - p[1])\)\ p[3]\^2\ \((1 - p[4])\) - 
        2\ cw[2]\^2\ \((1 - p[1])\)\ p[3]\^2\ \((1 - p[4])\) + 
        2\ cb[3]\ \((1 - p[1])\)\^2\ p[3]\^2\ \((1 - p[4])\) - 
        4\ cb[2]\^2\ \((1 - p[2])\)\ p[3]\^2\ \((1 - p[4])\) - 
        4\ cb[4]\ \((1 - p[2])\)\ p[3]\^2\ \((1 - p[4])\) - 
        6\ cb[2]\ cw[2]\ \((1 - p[2])\)\ p[3]\^2\ \((1 - p[4])\) - 
        2\ cw[2]\^2\ \((1 - p[2])\)\ p[3]\^2\ \((1 - p[4])\) + 
        6\ cb[3]\ \((1 - p[1])\)\ \((1 - p[2])\)\ p[3]\^2\ \((1 - p[4])\) + 
        2\ cw[3]\ \((1 - p[1])\)\ \((1 - p[2])\)\ p[3]\^2\ \((1 - p[4])\) - 
        2\ cb[2]\ \((1 - p[1])\)\^2\ \((1 - p[2])\)\ p[3]\^2\ 
          \((1 - p[4])\) - 
        2\ cw[2]\ \((1 - p[1])\)\^2\ \((1 - p[2])\)\ p[3]\^2\ 
          \((1 - p[4])\) + 
        2\ cb[3]\ \((1 - p[2])\)\^2\ p[3]\^2\ \((1 - p[4])\) - 
        2\ cb[2]\ \((1 - p[1])\)\ \((1 - p[2])\)\^2\ p[3]\^2\ 
          \((1 - p[4])\) - 
        2\ cw[2]\ \((1 - p[1])\)\ \((1 - p[2])\)\^2\ p[3]\^2\ 
          \((1 - p[4])\) - 72\ cb[2]\^2\ cb[3]\ p[4] - 
        60\ cb[3]\ cb[4]\ p[4] - 24\ cb[2]\ cb[5]\ p[4] - 2\ cb[7]\ p[4] - 
        72\ cb[2]\ cb[3]\ cw[2]\ p[4] - 18\ cb[5]\ cw[2]\ p[4] - 
        36\ cb[3]\ cw[2]\^2\ p[4] - 8\ cb[4]\ cw[3]\ p[4] - 
        24\ cb[2]\ cw[2]\ cw[3]\ p[4] - 6\ cw[2]\^2\ cw[3]\ p[4] - 
        2\ cw[3]\ cw[4]\ p[4] + 12\ cb[2]\^3\ \((1 - p[1])\)\ p[4] + 
        30\ cb[3]\^2\ \((1 - p[1])\)\ p[4] + 
        34\ cb[2]\ cb[4]\ \((1 - p[1])\)\ p[4] + 
        4\ cb[6]\ \((1 - p[1])\)\ p[4] + 
        24\ cb[2]\^2\ cw[2]\ \((1 - p[1])\)\ p[4] + 
        24\ cb[4]\ cw[2]\ \((1 - p[1])\)\ p[4] + 
        18\ cb[2]\ cw[2]\^2\ \((1 - p[1])\)\ p[4] + 
        6\ cw[2]\^3\ \((1 - p[1])\)\ p[4] + 
        8\ cb[3]\ cw[3]\ \((1 - p[1])\)\ p[4] + 
        2\ cw[3]\^2\ \((1 - p[1])\)\ p[4] + 
        2\ cw[2]\ cw[4]\ \((1 - p[1])\)\ p[4] - 
        12\ cb[2]\ cb[3]\ \((1 - p[1])\)\^2\ p[4] - 
        2\ cb[5]\ \((1 - p[1])\)\^2\ p[4] - 
        6\ cb[3]\ cw[2]\ \((1 - p[1])\)\^2\ p[4] - 
        2\ cw[2]\ cw[3]\ \((1 - p[1])\)\^2\ p[4] + 
        12\ cb[2]\^3\ \((1 - p[2])\)\ p[4] + 
        30\ cb[3]\^2\ \((1 - p[2])\)\ p[4] + 
        34\ cb[2]\ cb[4]\ \((1 - p[2])\)\ p[4] + 
        4\ cb[6]\ \((1 - p[2])\)\ p[4] + 
        24\ cb[2]\^2\ cw[2]\ \((1 - p[2])\)\ p[4] + 
        24\ cb[4]\ cw[2]\ \((1 - p[2])\)\ p[4] + 
        18\ cb[2]\ cw[2]\^2\ \((1 - p[2])\)\ p[4] + 
        6\ cw[2]\^3\ \((1 - p[2])\)\ p[4] + 
        8\ cb[3]\ cw[3]\ \((1 - p[2])\)\ p[4] + 
        2\ cw[3]\^2\ \((1 - p[2])\)\ p[4] + 
        2\ cw[2]\ cw[4]\ \((1 - p[2])\)\ p[4] - 
        36\ cb[2]\ cb[3]\ \((1 - p[1])\)\ \((1 - p[2])\)\ p[4] - 
        8\ cb[5]\ \((1 - p[1])\)\ \((1 - p[2])\)\ p[4] - 
        30\ cb[3]\ cw[2]\ \((1 - p[1])\)\ \((1 - p[2])\)\ p[4] - 
        8\ cb[2]\ cw[3]\ \((1 - p[1])\)\ \((1 - p[2])\)\ p[4] - 
        6\ cw[2]\ cw[3]\ \((1 - p[1])\)\ \((1 - p[2])\)\ p[4] + 
        4\ cb[2]\^2\ \((1 - p[1])\)\^2\ \((1 - p[2])\)\ p[4] + 
        4\ cb[4]\ \((1 - p[1])\)\^2\ \((1 - p[2])\)\ p[4] + 
        6\ cb[2]\ cw[2]\ \((1 - p[1])\)\^2\ \((1 - p[2])\)\ p[4] + 
        2\ cw[2]\^2\ \((1 - p[1])\)\^2\ \((1 - p[2])\)\ p[4] - 
        12\ cb[2]\ cb[3]\ \((1 - p[2])\)\^2\ p[4] - 
        2\ cb[5]\ \((1 - p[2])\)\^2\ p[4] - 
        6\ cb[3]\ cw[2]\ \((1 - p[2])\)\^2\ p[4] - 
        2\ cw[2]\ cw[3]\ \((1 - p[2])\)\^2\ p[4] + 
        4\ cb[2]\^2\ \((1 - p[1])\)\ \((1 - p[2])\)\^2\ p[4] + 
        4\ cb[4]\ \((1 - p[1])\)\ \((1 - p[2])\)\^2\ p[4] + 
        6\ cb[2]\ cw[2]\ \((1 - p[1])\)\ \((1 - p[2])\)\^2\ p[4] + 
        2\ cw[2]\^2\ \((1 - p[1])\)\ \((1 - p[2])\)\^2\ p[4] - 
        2\ cb[3]\ \((1 - p[1])\)\^2\ \((1 - p[2])\)\^2\ p[4] - 
        12\ cb[2]\^3\ p[3]\ p[4] - 30\ cb[3]\^2\ p[3]\ p[4] - 
        34\ cb[2]\ cb[4]\ p[3]\ p[4] - 4\ cb[6]\ p[3]\ p[4] - 
        24\ cb[2]\^2\ cw[2]\ p[3]\ p[4] - 24\ cb[4]\ cw[2]\ p[3]\ p[4] - 
        18\ cb[2]\ cw[2]\^2\ p[3]\ p[4] - 6\ cw[2]\^3\ p[3]\ p[4] - 
        8\ cb[3]\ cw[3]\ p[3]\ p[4] - 2\ cw[3]\^2\ p[3]\ p[4] - 
        2\ cw[2]\ cw[4]\ p[3]\ p[4] + 
        36\ cb[2]\ cb[3]\ \((1 - p[1])\)\ p[3]\ p[4] + 
        8\ cb[5]\ \((1 - p[1])\)\ p[3]\ p[4] + 
        30\ cb[3]\ cw[2]\ \((1 - p[1])\)\ p[3]\ p[4] + 
        8\ cb[2]\ cw[3]\ \((1 - p[1])\)\ p[3]\ p[4] + 
        6\ cw[2]\ cw[3]\ \((1 - p[1])\)\ p[3]\ p[4] - 
        4\ cb[2]\^2\ \((1 - p[1])\)\^2\ p[3]\ p[4] - 
        4\ cb[4]\ \((1 - p[1])\)\^2\ p[3]\ p[4] - 
        6\ cb[2]\ cw[2]\ \((1 - p[1])\)\^2\ p[3]\ p[4] - 
        2\ cw[2]\^2\ \((1 - p[1])\)\^2\ p[3]\ p[4] + 
        36\ cb[2]\ cb[3]\ \((1 - p[2])\)\ p[3]\ p[4] + 
        8\ cb[5]\ \((1 - p[2])\)\ p[3]\ p[4] + 
        30\ cb[3]\ cw[2]\ \((1 - p[2])\)\ p[3]\ p[4] + 
        8\ cb[2]\ cw[3]\ \((1 - p[2])\)\ p[3]\ p[4] + 
        6\ cw[2]\ cw[3]\ \((1 - p[2])\)\ p[3]\ p[4] - 
        12\ cb[2]\^2\ \((1 - p[1])\)\ \((1 - p[2])\)\ p[3]\ p[4] - 
        14\ cb[4]\ \((1 - p[1])\)\ \((1 - p[2])\)\ p[3]\ p[4] - 
        24\ cb[2]\ cw[2]\ \((1 - p[1])\)\ \((1 - p[2])\)\ p[3]\ p[4] - 
        12\ cw[2]\^2\ \((1 - p[1])\)\ \((1 - p[2])\)\ p[3]\ p[4] - 
        2\ cw[4]\ \((1 - p[1])\)\ \((1 - p[2])\)\ p[3]\ p[4] + 
        6\ cb[3]\ \((1 - p[1])\)\^2\ \((1 - p[2])\)\ p[3]\ p[4] + 
        2\ cw[3]\ \((1 - p[1])\)\^2\ \((1 - p[2])\)\ p[3]\ p[4] - 
        4\ cb[2]\^2\ \((1 - p[2])\)\^2\ p[3]\ p[4] - 
        4\ cb[4]\ \((1 - p[2])\)\^2\ p[3]\ p[4] - 
        6\ cb[2]\ cw[2]\ \((1 - p[2])\)\^2\ p[3]\ p[4] - 
        2\ cw[2]\^2\ \((1 - p[2])\)\^2\ p[3]\ p[4] + 
        6\ cb[3]\ \((1 - p[1])\)\ \((1 - p[2])\)\^2\ p[3]\ p[4] + 
        2\ cw[3]\ \((1 - p[1])\)\ \((1 - p[2])\)\^2\ p[3]\ p[4] - 
        2\ cb[2]\ \((1 - p[1])\)\^2\ \((1 - p[2])\)\^2\ p[3]\ p[4] - 
        2\ cw[2]\ \((1 - p[1])\)\^2\ \((1 - p[2])\)\^2\ p[3]\ p[4] - 
        12\ cb[2]\ cb[3]\ p[3]\^2\ p[4] - 2\ cb[5]\ p[3]\^2\ p[4] - 
        6\ cb[3]\ cw[2]\ p[3]\^2\ p[4] - 2\ cw[2]\ cw[3]\ p[3]\^2\ p[4] + 
        4\ cb[2]\^2\ \((1 - p[1])\)\ p[3]\^2\ p[4] + 
        4\ cb[4]\ \((1 - p[1])\)\ p[3]\^2\ p[4] + 
        6\ cb[2]\ cw[2]\ \((1 - p[1])\)\ p[3]\^2\ p[4] + 
        2\ cw[2]\^2\ \((1 - p[1])\)\ p[3]\^2\ p[4] - 
        2\ cb[3]\ \((1 - p[1])\)\^2\ p[3]\^2\ p[4] + 
        4\ cb[2]\^2\ \((1 - p[2])\)\ p[3]\^2\ p[4] + 
        4\ cb[4]\ \((1 - p[2])\)\ p[3]\^2\ p[4] + 
        6\ cb[2]\ cw[2]\ \((1 - p[2])\)\ p[3]\^2\ p[4] + 
        2\ cw[2]\^2\ \((1 - p[2])\)\ p[3]\^2\ p[4] - 
        6\ cb[3]\ \((1 - p[1])\)\ \((1 - p[2])\)\ p[3]\^2\ p[4] - 
        2\ cw[3]\ \((1 - p[1])\)\ \((1 - p[2])\)\ p[3]\^2\ p[4] + 
        2\ cb[2]\ \((1 - p[1])\)\^2\ \((1 - p[2])\)\ p[3]\^2\ p[4] + 
        2\ cw[2]\ \((1 - p[1])\)\^2\ \((1 - p[2])\)\ p[3]\^2\ p[4] - 
        2\ cb[3]\ \((1 - p[2])\)\^2\ p[3]\^2\ p[4] + 
        2\ cb[2]\ \((1 - p[1])\)\ \((1 - p[2])\)\^2\ p[3]\^2\ p[4] + 
        2\ cw[2]\ \((1 - p[1])\)\ \((1 - p[2])\)\^2\ p[3]\^2\ p[4] + 
        12\ cb[2]\^3\ \((1 - p[4])\)\ p[4] + 
        18\ cb[3]\^2\ \((1 - p[4])\)\ p[4] + 
        18\ cb[2]\ cb[4]\ \((1 - p[4])\)\ p[4] + 
        2\ cb[6]\ \((1 - p[4])\)\ p[4] + 
        12\ cb[4]\ cw[2]\ \((1 - p[4])\)\ p[4] + 
        18\ cb[2]\ cw[2]\^2\ \((1 - p[4])\)\ p[4] + 
        2\ cw[3]\^2\ \((1 - p[4])\)\ p[4] - 
        24\ cb[2]\ cb[3]\ \((1 - p[1])\)\ \((1 - p[4])\)\ p[4] - 
        4\ cb[5]\ \((1 - p[1])\)\ \((1 - p[4])\)\ p[4] - 
        12\ cb[3]\ cw[2]\ \((1 - p[1])\)\ \((1 - p[4])\)\ p[4] - 
        4\ cw[2]\ cw[3]\ \((1 - p[1])\)\ \((1 - p[4])\)\ p[4] + 
        4\ cb[2]\^2\ \((1 - p[1])\)\^2\ \((1 - p[4])\)\ p[4] + 
        2\ cb[4]\ \((1 - p[1])\)\^2\ \((1 - p[4])\)\ p[4] + 
        2\ cw[2]\^2\ \((1 - p[1])\)\^2\ \((1 - p[4])\)\ p[4] - 
        24\ cb[2]\ cb[3]\ \((1 - p[2])\)\ \((1 - p[4])\)\ p[4] - 
        4\ cb[5]\ \((1 - p[2])\)\ \((1 - p[4])\)\ p[4] - 
        12\ cb[3]\ cw[2]\ \((1 - p[2])\)\ \((1 - p[4])\)\ p[4] - 
        4\ cw[2]\ cw[3]\ \((1 - p[2])\)\ \((1 - p[4])\)\ p[4] + 
        8\ cb[2]\^2\ \((1 - p[1])\)\ \((1 - p[2])\)\ \((1 - p[4])\)\ p[4] + 
        8\ cb[4]\ \((1 - p[1])\)\ \((1 - p[2])\)\ \((1 - p[4])\)\ p[4] + 
        12\ cb[2]\ cw[2]\ \((1 - p[1])\)\ \((1 - p[2])\)\ \((1 - p[4])\)\ 
          p[4] + 4\ cw[2]\^2\ \((1 - p[1])\)\ \((1 - p[2])\)\ \((1 - p[4])\)\ 
          p[4] - 4\ cb[3]\ \((1 - p[1])\)\^2\ \((1 - p[2])\)\ \((1 - p[4])\)\ 
          p[4] + 4\ cb[2]\^2\ \((1 - p[2])\)\^2\ \((1 - p[4])\)\ p[4] + 
        2\ cb[4]\ \((1 - p[2])\)\^2\ \((1 - p[4])\)\ p[4] + 
        2\ cw[2]\^2\ \((1 - p[2])\)\^2\ \((1 - p[4])\)\ p[4] - 
        4\ cb[3]\ \((1 - p[1])\)\ \((1 - p[2])\)\^2\ \((1 - p[4])\)\ p[4] + 
        2\ cb[2]\ \((1 - p[1])\)\^2\ \((1 - p[2])\)\^2\ \((1 - p[4])\)\ 
          p[4] + 24\ cb[2]\ cb[3]\ p[3]\ \((1 - p[4])\)\ p[4] + 
        4\ cb[5]\ p[3]\ \((1 - p[4])\)\ p[4] + 
        12\ cb[3]\ cw[2]\ p[3]\ \((1 - p[4])\)\ p[4] + 
        4\ cw[2]\ cw[3]\ p[3]\ \((1 - p[4])\)\ p[4] - 
        8\ cb[2]\^2\ \((1 - p[1])\)\ p[3]\ \((1 - p[4])\)\ p[4] - 
        8\ cb[4]\ \((1 - p[1])\)\ p[3]\ \((1 - p[4])\)\ p[4] - 
        12\ cb[2]\ cw[2]\ \((1 - p[1])\)\ p[3]\ \((1 - p[4])\)\ p[4] - 
        4\ cw[2]\^2\ \((1 - p[1])\)\ p[3]\ \((1 - p[4])\)\ p[4] + 
        4\ cb[3]\ \((1 - p[1])\)\^2\ p[3]\ \((1 - p[4])\)\ p[4] - 
        8\ cb[2]\^2\ \((1 - p[2])\)\ p[3]\ \((1 - p[4])\)\ p[4] - 
        8\ cb[4]\ \((1 - p[2])\)\ p[3]\ \((1 - p[4])\)\ p[4] - 
        12\ cb[2]\ cw[2]\ \((1 - p[2])\)\ p[3]\ \((1 - p[4])\)\ p[4] - 
        4\ cw[2]\^2\ \((1 - p[2])\)\ p[3]\ \((1 - p[4])\)\ p[4] + 
        12\ cb[3]\ \((1 - p[1])\)\ \((1 - p[2])\)\ p[3]\ \((1 - p[4])\)\ 
          p[4] + 4\ cw[3]\ \((1 - p[1])\)\ \((1 - p[2])\)\ p[3]\ 
          \((1 - p[4])\)\ p[4] - 
        4\ cb[2]\ \((1 - p[1])\)\^2\ \((1 - p[2])\)\ p[3]\ \((1 - p[4])\)\ 
          p[4] - 4\ cw[2]\ \((1 - p[1])\)\^2\ \((1 - p[2])\)\ p[3]\ 
          \((1 - p[4])\)\ p[4] + 
        4\ cb[3]\ \((1 - p[2])\)\^2\ p[3]\ \((1 - p[4])\)\ p[4] - 
        4\ cb[2]\ \((1 - p[1])\)\ \((1 - p[2])\)\^2\ p[3]\ \((1 - p[4])\)\ 
          p[4] - 4\ cw[2]\ \((1 - p[1])\)\ \((1 - p[2])\)\^2\ p[3]\ 
          \((1 - p[4])\)\ p[4] + 4\ cb[2]\^2\ p[3]\^2\ \((1 - p[4])\)\ p[4] + 
        2\ cb[4]\ p[3]\^2\ \((1 - p[4])\)\ p[4] + 
        2\ cw[2]\^2\ p[3]\^2\ \((1 - p[4])\)\ p[4] - 
        4\ cb[3]\ \((1 - p[1])\)\ p[3]\^2\ \((1 - p[4])\)\ p[4] + 
        2\ cb[2]\ \((1 - p[1])\)\^2\ p[3]\^2\ \((1 - p[4])\)\ p[4] - 
        4\ cb[3]\ \((1 - p[2])\)\ p[3]\^2\ \((1 - p[4])\)\ p[4] + 
        4\ cb[2]\ \((1 - p[1])\)\ \((1 - p[2])\)\ p[3]\^2\ \((1 - p[4])\)\ 
          p[4] + 4\ cw[2]\ \((1 - p[1])\)\ \((1 - p[2])\)\ p[3]\^2\ 
          \((1 - p[4])\)\ p[4] + 
        2\ cb[2]\ \((1 - p[2])\)\^2\ p[3]\^2\ \((1 - p[4])\)\ p[4] + 
        2\ \((1 - p[1])\)\^2\ \((1 - p[2])\)\^2\ p[3]\^2\ \((1 - p[4])\)\ 
          p[4]}\)], "Output"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    \(Timing[
      \(ll /. {p[j_] :> pl\[LeftDoubleBracket]j\[RightDoubleBracket], 
            cw[2] -> 0.01, cb[2] -> 0.01}\) /. {cw[_] -> 0, cb[_] -> 0}]\)], 
  "Input"],

Cell[BoxData[
    \(\(-38.8249180389305479`\)\)], "Output"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(Share[] (*48  s*) \)\)], "Input"],

Cell[BoxData[
    \(3613504\)], "Output"]
}, Closed]],

Cell[BoxData[
    \(sv = Join[StandardSet[4, pp], StandardSet[4]] // Flatten; \nnl = 4; \t
    vars = Join[Table[p[j], {j, nl}], Table[cw[j], {j, 2, nl}], 
        Table[cb[j], {j, 2, 2  nl}]]; \n\t\t
    rl[xx_List] := 
      \(({vars, Flatten[xx]} // Transpose)\) /. {x_, y_} :> \((x -> y)\); \t\n
    \ttv = Transpose[{sv, Table[_Real, {4  nl - 2}]}]; \n
    llstd = ll /. rl[sv]; \)], "Input"],

Cell[CellGroupData[{

Cell[BoxData[
    \(Timing[cll = Compile[tv // Evaluate, \ llstd // Evaluate]; ]\)], "Input"],

Cell[BoxData[
    \({234.950000000004388`\ Second, Null}\)], "Output"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    \(vv = Flatten[{pl, {{0.01, 0, 0}, {0.01, 0, 0, 0, 0, 0, 0}}}]; \n
    Timing[cll@@vv]\)], "Input"],

Cell[BoxData[
    \(CompiledFunction::"ccr" \( : \ \) 
      "Expression \!\(p[1]\) should be a machine-size real number."\)], 
  "Message"],

Cell[BoxData[
    \(CompiledFunction::"cfex" \( : \ \) 
      "External evaluation error at instruction \!\(102\); proceeding with \
uncompiled evaluation."\)], "Message"],

Cell[BoxData[
    \($Aborted\)], "Output"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    \(Timing[Share[]]\)], "Input"],

Cell[BoxData[
    \({169.583333333328489`\ Second, 7809152}\)], "Output"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData[{
  "MLEDisequilibrium",
  "[site,cw[k],{cw,cb},{{cw[2],..},{cb[2]..}},\[Delta]p,p,S] gives the MLE \
for cw[k], with the remaining c's given numerically by the lists \
{{cw[2],..},{cb[2]..}}."
}], "Subsubsection",
  InitializationCell->True],

Cell[BoxData[
    \(\(MLEDisequilibrium[s_, 
          c_[k_Integer], {cw_, cb_}, {cwl_List, cbl_List}, \[Delta]p_, p_, 
          S_] := Module[{\[Epsilon] = 0.001, lims, x, ff}, \n\t\tlims = 
            If[c === cb, \n\t\t\t\tMomentLimitsDiploid[
                k, {cw, cb}, {cwl, cbl}, \[Delta]p, p, 
                S], \n\t\t\t\tMomentLimits[k, cw, cwl, \[Delta]p, p, 
                S]]; \n\t\tff = \((LogLikelihoodDisequilibrium[
                    s, {cw, cb}, \[Delta]p, p, S] /. c[k] -> x)\) /. {cw[j_] :> 
                  cwl\[LeftDoubleBracket]j - 1\[RightDoubleBracket], 
                cb[j_] :> 
                  cbl\[LeftDoubleBracket]j - 1\[RightDoubleBracket]}; \n\t
          If[\((D[ff, x] /. 
                  x -> lims\[LeftDoubleBracket]1\[RightDoubleBracket] \((1 - \
\[Epsilon])\) + \[Epsilon]\[VeryThinSpace]lims\[LeftDoubleBracket]2\
\[RightDoubleBracket])\) < 0, 
            lims\[LeftDoubleBracket]1\[RightDoubleBracket], \t
            If[\((D[ff, x] /. 
                    x -> lims\[LeftDoubleBracket]2\[RightDoubleBracket] \((1 \
- \[Epsilon])\) + \[Epsilon]\[VeryThinSpace]lims\[LeftDoubleBracket]1\
\[RightDoubleBracket])\) > 0, 
              lims\[LeftDoubleBracket]2\[RightDoubleBracket], \n\t\t\tx /. \
\(FindMinimum[\(-ff\), {x, \(lims\[LeftDoubleBracket]1\[RightDoubleBracket] + \
lims\[LeftDoubleBracket]2\[RightDoubleBracket]\)\/2}]\)[\([2]\)]]]];\)\)], \
"Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData[
"MetropolisDisequilibrium[site,T,{ntries,nprint},{Log[L],{{{p[1],..}},{{{\
\[Delta]p[1],..}},{{c[0,0],...}},{{pstep0},{\[Delta]pstep0},cstep0}] applies \
the Metropolis algorithm, using temperature T and  a matrix of moments.   \
step0 gives the initial step size; to fix some variables, set entries to 0. \
It is essential that the top left corner of cstep0 is zero.  Returns a list \
of the same form as its argument.  The option Cumulant\[Rule]True fits a \
matrix of cumulants rather than moments."], "Subsubsection"],

Cell[BoxData[
    \(\(Options[
          MetropolisDisequilibrium] = {Cumulant \[Rule] True};\)\)], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(\(MetropolisDisequilibrium[s_, 
          T_, {nt_, npr_}, {_, {{p0_List}, {\[Delta]p0_List}, c0_List}, 
            st0_List}, opts___Rule] := \n\t
        Module[{nl = NumberOfLoci[s], j1, j2, j3, na = 0, nr = 0, ncl, 
            cl = c0, p = p0 // N, \[Delta]p = \[Delta]p0 // N, step = st0, 
            ll, nll, np, n\[Delta]p, \[CapitalGamma], n\[CapitalGamma], gv, 
            ngv, \n\t\trd = ReducedData[s, NumberOfLoci[s]], nz, obs, ntot, 
            newCl, newP, new\[Delta]P, accept, reject, threshold, tr}, \n\t
          If[\(Cumulant /. {opts}\) /. 
              Options[MetropolisDisequilibrium], \n\t\t\ttr[
                c_] := \(Moment[nl]\)[c], \n\t\t\ttr[m_] := 
              m\ ]; \n\t\tthreshold[d_] := 
            If[T <= 0, \((d > 0)\), Exp[d/T] > Random[]]; \n\t\tnz = 
            Position[rd, _?\((\((# > 0)\) &)\)]; \n\t\tobs = 
            Extract[rd, nz]; \ 
          ntot = Plus @@ 
              obs; \n\t\tnewP := \((np = 
                ReplacePart[p, 
                  p[\([j3]\)] + \((2  Random[] - 1)\) step[\([1, 1, j3]\)], 
                  j3]; \n\t\t\t\tn\[Delta]p = \[Delta]p; 
              n\[CapitalGamma] = \(Matrix\[CapitalGamma][nl]\)[np, 
                  n\[Delta]p]; 
              ncl = cl)\); \n\t\tnew\[Delta]P := \((np = 
                p; \n\t\t\t\tn\[Delta]p = 
                ReplacePart[\[Delta]p, \[Delta]p[\([j3]\)] + \((2  Random[] - 
                          1)\) step[\([2, 1, j3]\)], 
                  j3]; \n\t\t\t\tn\[Delta]p = 
                n\[Delta]p/\((Times @@ n\[Delta]p)\)\^\(1/nl\); \n\t\t\t\tn\
\[CapitalGamma] = \(Matrix\[CapitalGamma][nl]\)[np, n\[Delta]p]; 
              ncl = cl)\); \n\t\tnewCl := \ \((ncl = 
                ReplacePart[cl, 
                  cl[\([j2, j3]\)] + \((2  Random[] - 1)\) 
                      step[\([j1, j2, j3]\)], {j2, 
                    j3}]; \[IndentingNewLine]ncl = 
                ReplacePart[ncl, 
                  ncl[\([j2, j3]\)], {j3, 
                    j2}]; \[IndentingNewLine]n\[CapitalGamma] = \
\[CapitalGamma]; np = p; n\[Delta]p = \[Delta]p)\); \n\t
          accept := \t\((cl = ncl; ll = nll; gv = ngv; 
              p = np; \[Delta]p = n\[Delta]p; \[CapitalGamma] = 
                n\[CapitalGamma]; \n\t\t\t\tstep\[LeftDoubleBracket]j1, j2, 
                  j3\[RightDoubleBracket] /= $MetropolisAdjustment; \(na++\))\
\); \n\treject := \((step\[LeftDoubleBracket]j1, j2, 
                  j3\[RightDoubleBracket] *= $MetropolisAdjustment; \(nr++\))\
\); \n\t\[CapitalGamma] = \(Matrix\[CapitalGamma][nl]\)[p, \[Delta]p]; 
          gv = \[CapitalGamma] . tr[cl] . Transpose[\[CapitalGamma]]; \n\t
          ll = If[Min[gv] \[GreaterEqual] 
                0, \(LogLikelihoodDisequilibrium[ntot]\)[obs, 
                Extract[GenotypeFrequencyConvert[gv, nl], 
                  nz]], \(-10\^10\)]; \[IndentingNewLine]Do[
            Do[If[step\[LeftDoubleBracket]j1, j2, j3\[RightDoubleBracket] > 
                  0, \[IndentingNewLine]\((Switch[j1, 1, newP, 2, 
                    new\[Delta]P, 3, newCl]; \[IndentingNewLine]ngv = 
                    n\[CapitalGamma] . tr[ncl] . 
                      Transpose[n\[CapitalGamma]]; \[IndentingNewLine]If[
                    Min[ngv] < 0, 
                    reject, \[IndentingNewLine]\((nll = \
\(LogLikelihoodDisequilibrium[ntot]\)[obs, 
                          Extract[GenotypeFrequencyConvert[ngv, nl], 
                            nz]]; \n\t
                      If[threshold[nll - ll], accept, 
                        reject])\)])\)], \n\t\t\t\t{j1, 1, 3}, {j2, 1, 
                If[j1 < 3, 1, nl + 1]}, {j3, 1, 
                If[j1 < 3, nl, j2]}]; \[IndentingNewLine]If[
              Mod[kk, npr] \[Equal] 0, \t\n\t\t\t\tPrint[kk, Tab, "\<T=\>", 
                T, Tab, \n\t\t\t\t\t"\<log(L)=\>", ll, 
                Tab, "\<% accepted=\>", 
                If[na + nr == 0, "\<?? none tried\>", \((na\/\(na + nr\))\) // 
                    N]]\n\t\t\t], {kk, nt}]; \n\t\ {ll, {{p}, {\[Delta]p}, 
              cl}, step}];\)\)], "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData[{
  "MetropolisDisequilibriumReduced",
  "[site,T,{ntries,nprint},{LogLikelihoodDisequilibrium,{{p[1],..},{cw[2],..,\
cb[2]..}},step0}] applies the Metropolis algorithm, using temperature T.  \
Assumes \[Delta]p=1.  step0 gives the initial step size; to fix some \
variables, set entries to 0.  Returns \
{log(L),{{p1,..},{cw[2],..,cb[2]..}},step}. "
}], "Subsubsection"],

Cell[BoxData[
    \(\(MetropolisDisequilibriumReduced[s_, 
          T_, {nt_, npr_}, {_, {pp_List, cll_List}, st0_List}] := \n\t
        Module[{nl = NumberOfLoci[s], j, na = 0, nr = 0, 
            p = Flatten[pp], \n\t\t\tcl = Flatten[cll], ncl, ll, nll, 
            np, \[CapitalGamma], M, nM, n\[CapitalGamma], gv, 
            ngv, \n\t\t\tstep = Flatten[st0], 
            rd = ReducedData[s, NumberOfLoci[s]], nz, obs, 
            ntot}, \n\t\ \ nz = 
            Position[rd, _?\((\((# > 0)\) &)\)]; \n\t\tobs = 
            Extract[rd, nz]; \ 
          ntot = Plus @@ obs; \n\t\ M = \(MomentReduced[nl]\)[
              cl]; \[CapitalGamma] = Matrix\[CapitalGamma][p, nl]; \n\t\tgv = 
            GenotypeFrequencyConvert[\[CapitalGamma] . M . 
                Transpose[\[CapitalGamma]], nl]; \n\t\tll = 
            If[Min[gv] \[GreaterEqual] 
                0, \n\t\t\t\t\(LogLikelihoodDisequilibrium[ntot]\)[obs, 
                Extract[gv, nz]], \n\t\t\t\t\(-10\^10\)]; \n\t
          Do[Do[If[
                step[\([j]\)] > 
                  0, \n\t\t\t\t\t\((If[
                    j > nl, \n\t\t\t\t\t\t\ ncl = 
                      ReplacePart[cl, 
                        cl\[LeftDoubleBracket]j - 
                              nl\[RightDoubleBracket] + \((2  Random[] - 1)\) 
                            step\[LeftDoubleBracket]j\[RightDoubleBracket], 
                        j - nl]; \n\t\t\t\t\t\t\ \ \ \ n\[CapitalGamma] = \
\[CapitalGamma]; np = p; 
                    nM = \(MomentReduced[nl]\)[ncl], \n\t\t\t\t\t\t\t\ np = 
                      ReplacePart[p, 
                        p[\([j]\)] + \((2  Random[] - 1)\) step[\([j]\)], 
                        j]; \n\t\t\t\t\t\t\ \ n\[CapitalGamma] = 
                      Matrix\[CapitalGamma][np, nl]; nM = M; 
                    ncl = cl]; \n\t\t\t\t\t\tngv = 
                    GenotypeFrequencyConvert[
                      n\[CapitalGamma] . nM . Transpose[n\[CapitalGamma]], 
                      nl]; \nIf[
                    Min[ngv] \[GreaterEqual] 
                      0, \n\t\t\t\t\t\t\t\((nll = \
\(LogLikelihoodDisequilibrium[ntot]\)[obs, Extract[ngv, nz]]; \n\t\tIf[
                        T <= 0, \n\t\t\t\t\t\t\t\t\tIf[
                          nll > ll, \n\t\t\t\t\t\t\t\t\t\tcl = ncl; ll = nll; 
                          gv = ngv; M = nM; 
                          p = np; \[CapitalGamma] = 
                            n\[CapitalGamma]; \n\t\t\t\t\t\t\t\t\t\tstep\
\[LeftDoubleBracket]
                              j\[RightDoubleBracket] /= \
$MetropolisAdjustment; \(na++\), \n\t\t\t\t\t\t\t\t\t\tstep\
\[LeftDoubleBracket]
                              j\[RightDoubleBracket] *= \
$MetropolisAdjustment; \(nr++\)], \n\t\t\t\t\t\t\t\t\ \ If[
                          Exp[\((nll - ll)\)/T] > 
                            Random[], \n\t\t\t\t\t\t\t\t\t\tcl = ncl; 
                          ll = nll; gv = ngv; M = nM; 
                          p = np; \[CapitalGamma] = 
                            n\[CapitalGamma]; \n\t\t\t\t\t\t\t\t\t\tstep\
\[LeftDoubleBracket]j\[RightDoubleBracket] /= $MetropolisAdjustment; \
\(na++\), \n\t\t\t\t\t\t\t\t\t\tstep\[LeftDoubleBracket]
                              j\[RightDoubleBracket] *= \
$MetropolisAdjustment; \(nr++\)]])\), \n\t\t\t\tstep\[LeftDoubleBracket]
                        j\[RightDoubleBracket] *= $MetropolisAdjustment; \(nr\
++\)])\)], {j, 1, 4  nl - 2}]; \n\t\t\t\t\t\tIf[
              Mod[kk, npr] == 0, \t\n\t\t\t\tPrint[kk, 
                Tab, \n\t\t\t\t\t"\<  log(L)=\>", ll, 
                Tab, "\<% accepted=\>", \((na\/\(na + nr\))\) // N]], {kk, 
              nt}]; \n\t\ {ll, {p, cl}, step}];\)\)], "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{

Cell["\<\
$MetropolisAdjustment determines how the step size is adjusted in \
the Metropolis alhgorithm; by default, 0.95\
\>", "Subsubsection"],

Cell[BoxData[
    \(\($MetropolisAdjustment = 0.95;\)\)], "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData[{
  "InitialStepReduced",
  "[{cw,cb},cl,\[Delta]p,p,S] sets a sensible initial step size for the \
moments"
}], "Subsubsection"],

Cell[BoxData[
    \(\(InitialStepReduced[{cw_, cb_}, cl_, \[Delta]p_, p_, 
          S_List] := \(InitialStepReduced[{cw, cb}, cl, \[Delta]p, p, 
            S] = \n\t\tModule[{tlims, vars, vv = Flatten[cl], st, 
              nl = Length[S], cs = HaploidConstraints[cw, \[Delta]p, p, S], 
              cds = DiploidConstraints[{cw, cb}, \[Delta]p, p, S]}, \n\t
            tlims = Transpose[
                Join[Map[MomentLimitsReduced[#\ , cl[\([1]\)], cs] &, 
                    Table[cw[j], {j, 2, nl}]], 
                  Map[MomentLimitsDiploid[#, {cw, cb}\ , cl, cds] &, 
                    Table[cb[j], {j, 2, 2  nl}]]]]; \n\ \tst = 
              Map[Min, {tlims\[LeftDoubleBracket]2\[RightDoubleBracket] - vv, 
                    vv - tlims\[LeftDoubleBracket]1\[RightDoubleBracket]} // 
                  Transpose]; \n{Take[st, nl - 1], 
              Take[st, \(-\((2  nl - 1)\)\)]}]\);\)\)], "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{

Cell["\<\
InitialStep[cl,p] sets a sensible initial step size for c's. May \
fail if the cl is incompatible with the allele frequencies.\
\>", 
  "Subsubsection"],

Cell[BoxData[
    \(\(InitialStep[p_List, \[Delta]p_List, 
          cl_List] := \(InitialStep[p, \[Delta]p, 
            cl] = \n\t\tModule[{nl = Length[p], j, k, ff, ll}, \n
            ff[0, 0] = 0; ff[0, 1] = 0; 
            ff[1, 0] = 
              0; \n\t\t\tff[j_, k_] := \(ff[j, k] = 
                If[j <= k, \((ll = 
                      MomentLimits[{j, k}, p, \[Delta]p, 
                        cl])\); \((ll\[LeftDoubleBracket]2\
\[RightDoubleBracket] - ll\[LeftDoubleBracket]1\[RightDoubleBracket])\)/2, 
                  ff[k, j]]\); 
            Table[ff[j, k], {j, 0, nl}, {k, 0, nl}]]\);\)\)], "Input",
  InitializationCell->True]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["Constraints", "Subsection"],

Cell[CellGroupData[{

Cell["\<\
HaploidConstraints[k,\[Delta]p,p,S] gives a list of the constraints \
on gametic frequencies in terms of the reduced set of cumulants.  Stores \
results\
\>", "Subsubsection"],

Cell[BoxData[
    \(\(HaploidConstraints[c_, \[Delta]p_, p_, S_] := 
        Map[\((FullGenotypeFrequencyReduced[#, c, \[Delta]p, p, S] > 0)\) &, 
          HaploidTypes[Length[S]]];\)\)], "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    \(TextForm
    \`\(DiploidConstraints[{k\_w, k\_b}, \[Delta]p, p, S]\ gives\ a\ list\ of
      \ the\ constraints\ on\ diploid\ genotype\ frequencies\ in\ terms\ of\ 
      the\ reduced\ set\ of\ 
      cumulants . \ \ DiploidConstraints[{k\_w, k\_b}, \[Delta]p, p, S, gft]\ 
      stores\ the\ definition\ of\ FullGenotypeFrequencyTable[X,  .. ]\ in\ 
      \(gft[X] . \)\ \ \)\)], "Subsubsection"],

Cell[BoxData[
    \(\(DiploidConstraints[{cw_, cb_}, \[Delta]p_, p_, 
          S_List] := \(\((DiploidGenotypeFrequencyTable[#, {cw, 
                    cb}, \[Delta]p, p, S] > 0)\) &\) /@ \((DiploidTypes[
                Length[S]] /. {{a_Integer, b_Integer} :> 
                  a + b})\);\)\)], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(\(DiploidConstraints[{cw_, cb_}, \[Delta]p_, p_, S_, 
          gdt_] := \((gdt[X_] := \(gdt[X] = 
              DiploidGenotypeFrequencyTable[X, {cw, cb}, \[Delta]p, p, 
                S]\); \n\(\((gdt[#] > 0)\) &\) /@ \((DiploidTypes[
                  Length[S]] /. {{a_Integer, b_Integer} :> 
                    a + b})\))\);\)\)], "Input",
  InitializationCell->True],

Cell[CellGroupData[{

Cell[BoxData[
    \(DiploidConstraints[{cw, cb}, 1&, 0.4&, {1, 2, 3, 4}]\)], "Input"],

Cell[BoxData[
    \({\(0.0167961599999999977`\[InvisibleSpace]\) + 
          0.746496000000000048`\ cb[2] + 9.33119999999999727`\ cb[2]\^2 + 
          34.5599999999999951`\ cb[2]\^3 + 24\ cb[2]\^4 - 
          3.73248000000000201`\ cb[3] - 62.2079999999999788`\ cb[2]\ cb[3] - 
          172.799999999999975`\ cb[2]\^2\ cb[3] + 
          77.7599999999999891`\ cb[3]\^2 + 144\ cb[2]\ cb[3]\^2 + 
          8.81279999999999752`\ cb[4] + 86.3999999999999701`\ cb[2]\ cb[4] + 
          72\ cb[2]\^2\ cb[4] - 143.999999999999994`\ cb[3]\ cb[4] + 
          34\ cb[4]\^2 - 12.0959999999999934`\ cb[5] - 
          57.6000000000000067`\ cb[2]\ cb[5] + 48\ cb[3]\ cb[5] + 
          10.08`\ cb[6] + 16\ cb[2]\ cb[6] - 4.79999999999999982`\ cb[7] + 
          cb[8] + 0.559871999999999925`\ cw[2] + 
          12.4415999999999948`\ cb[2]\ cw[2] + 
          51.8399999999999927`\ cb[2]\^2\ cw[2] - 
          41.4720000000000332`\ cb[3]\ cw[2] - 
          172.799999999999975`\ cb[2]\ cb[3]\ cw[2] + 72\ cb[3]\^2\ cw[2] + 
          60.479999999999956`\ cb[4]\ cw[2] + 96\ cb[2]\ cb[4]\ cw[2] - 
          43.1999999999999939`\ cb[5]\ cw[2] + 12\ cb[6]\ cw[2] + 
          5.44319999999999826`\ cw[2]\^2 + 
          51.8400000000000016`\ cb[2]\ cw[2]\^2 + 72\ cb[2]\^2\ cw[2]\^2 - 
          86.3999999999999879`\ cb[3]\ cw[2]\^2 + 36\ cb[4]\ cw[2]\^2 + 
          12.9599999999999981`\ cw[2]\^3 + 9\ cw[2]\^4 - 
          0.622079999999999966`\ cw[3] - 6.91199999999999992`\ cb[2]\ cw[3] + 
          17.2799999999999975`\ cb[3]\ cw[3] - 
          19.1999999999999992`\ cb[4]\ cw[3] + 8\ cb[5]\ cw[3] - 
          10.3679999999999994`\ cw[2]\ cw[3] - 
          57.6000000000000067`\ cb[2]\ cw[2]\ cw[3] + 
          48\ cb[3]\ cw[2]\ cw[3] - 14.4000000000000021`\ cw[2]\^2\ cw[3] + 
          5.76000000000000067`\ cw[3]\^2 + 16\ cb[2]\ cw[3]\^2 + 
          0.259199999999999963`\ cw[4] + 4.31999999999999939`\ cw[2]\ cw[4] + 
          6\ cw[2]\^2\ cw[4] - 4.79999999999999982`\ cw[3]\ cw[4] + 
          cw[4]\^2 > 0, 
      \(0.0223948800000000014`\[InvisibleSpace]\) + 
          0.373247999999999979`\ cb[2] - 3.11039999999999761`\ cb[2]\^2 - 
          40.3199999999999825`\ cb[2]\^3 - 48\ cb[2]\^4 - 
          0.311039999999996297`\ cb[3] + 46.6559999999999597`\ cb[2]\ cb[3] + 
          273.599999999999976`\ cb[2]\^2\ cb[3] - 
          90.7199999999999739`\ cb[3]\^2 - 288\ cb[2]\ cb[3]\^2 - 
          2.93760000000000367`\ cb[4] - 100.800000000000045`\ cb[2]\ cb[4] - 
          144\ cb[2]\^2\ cb[4] + 228.000000000000024`\ cb[3]\ cb[4] - 
          68\ cb[4]\^2 + 9.0720000000000045`\ cb[5] + 
          91.1999999999999921`\ cb[2]\ cb[5] - 96\ cb[3]\ cb[5] - 
          11.7600000000000015`\ cb[6] - 32\ cb[2]\ cb[6] + 
          7.60000000000000053`\ cb[7] - 2\ cb[8] + 
          0.279935999999999962`\ cw[2] - 4.14719999999999977`\ cb[2]\ cw[2] - 
          60.4799999999999826`\ cb[2]\^2\ cw[2] + 
          31.1039999999999716`\ cb[3]\ cw[2] + 
          273.599999999999976`\ cb[2]\ cb[3]\ cw[2] - 144\ cb[3]\^2\ cw[2] - 
          70.5599999999999916`\ cb[4]\ cw[2] - 192\ cb[2]\ cb[4]\ cw[2] + 
          68.3999999999999896`\ cb[5]\ cw[2] - 24\ cb[6]\ cw[2] - 
          1.81440000000000072`\ cw[2]\^2 - 
          60.4800000000000093`\ cb[2]\ cw[2]\^2 - 144\ cb[2]\^2\ cw[2]\^2 + 
          136.799999999999988`\ cb[3]\ cw[2]\^2 - 72\ cb[4]\ cw[2]\^2 - 
          15.1199999999999956`\ cw[2]\^3 - 18\ cw[2]\^4 - 
          0.0518399999999999927`\ cw[3] + 
          5.18400000000000016`\ cb[2]\ cw[3] - 
          20.1599999999999912`\ cb[3]\ cw[3] + 
          30.4000000000000003`\ cb[4]\ cw[3] - 16\ cb[5]\ cw[3] + 
          7.77600000000000335`\ cw[2]\ cw[3] + 
          91.1999999999999921`\ cb[2]\ cw[2]\ cw[3] - 
          96\ cb[3]\ cw[2]\ cw[3] + 22.799999999999998`\ cw[2]\^2\ cw[3] - 
          6.71999999999999708`\ cw[3]\^2 - 32\ cb[2]\ cw[3]\^2 - 
          0.0863999999999999701`\ cw[4] - 
          5.03999999999999737`\ cw[2]\ cw[4] - 12\ cw[2]\^2\ cw[4] + 
          7.60000000000000053`\ cw[3]\ cw[4] - 2\ cw[4]\^2 > 0, 
      \(0.00746495999999999959`\[InvisibleSpace]\) + 
          0.0466560000000000218`\ cb[2] + 0.259200000000000407`\ cb[2]\^2 + 
          11.7599999999999993`\ cb[2]\^3 + 24\ cb[2]\^4 + 
          0.155519999999999551`\ cb[3] - 6.04799999999997961`\ cb[2]\ cb[3] - 
          100.799999999999978`\ cb[2]\^2\ cb[3] + 
          21.9599999999999928`\ cb[3]\^2 + 144\ cb[2]\ cb[3]\^2 - 
          0.475200000000000422`\ cb[4] + 23.3999999999999896`\ cb[2]\ cb[4] + 
          72\ cb[2]\^2\ cb[4] - 84.0000000000000035`\ cb[3]\ cb[4] + 
          34\ cb[4]\^2 - 0.5760000000000006`\ cb[5] - 
          33.6000000000000076`\ cb[2]\ cb[5] + 48\ cb[3]\ cb[5] + 
          2.67999999999999838`\ cb[6] + 16\ cb[2]\ cb[6] - 
          2.80000000000000035`\ cb[7] + cb[8] - 
          0.0622079999999999522`\ cw[2] - 
          1.81440000000000178`\ cb[2]\ cw[2] + 
          8.64000000000000056`\ cb[2]\^2\ cw[2] - 
          0.431999999999987949`\ cb[3]\ cw[2] - 
          100.799999999999978`\ cb[2]\ cb[3]\ cw[2] + 72\ cb[3]\^2\ cw[2] + 
          16.0800000000000009`\ cb[4]\ cw[2] + 96\ cb[2]\ cb[4]\ cw[2] - 
          25.1999999999999957`\ cb[5]\ cw[2] + 12\ cb[6]\ cw[2] - 
          0.388800000000000203`\ cw[2]\^2 + 
          17.6399999999999979`\ cb[2]\ cw[2]\^2 + 72\ cb[2]\^2\ cw[2]\^2 - 
          50.3999999999999914`\ cb[3]\ cw[2]\^2 + 36\ cb[4]\ cw[2]\^2 + 
          2.16000000000000014`\ cw[2]\^3 + 9\ cw[2]\^4 + 
          0.241920000000000001`\ cw[3] + 1.72799999999999975`\ cb[2]\ cw[3] + 
          2.87999999999999936`\ cb[3]\ cw[3] - 
          11.200000000000001`\ cb[4]\ cw[3] + 8\ cb[5]\ cw[3] - 
          1.00800000000000067`\ cw[2]\ cw[3] - 
          33.6000000000000076`\ cb[2]\ cw[2]\ cw[3] + 
          48\ cb[3]\ cw[2]\ cw[3] - 8.40000000000000213`\ cw[2]\^2\ cw[3] + 
          1.95999999999999996`\ cw[3]\^2 + 16\ cb[2]\ cw[3]\^2 - 
          0.17280000000000002`\ cw[4] + 0.71999999999999984`\ cw[2]\ cw[4] + 
          6\ cw[2]\^2\ cw[4] - 2.80000000000000035`\ cw[3]\ cw[4] + 
          cw[4]\^2 > 0, 
      \(0.0223948800000000014`\[InvisibleSpace]\) + 
          0.37324799999999989`\ cb[2] - 3.11039999999999761`\ cb[2]\^2 - 
          40.3199999999999825`\ cb[2]\^3 - 48\ cb[2]\^4 - 
          0.311039999999996297`\ cb[3] + 46.6559999999999597`\ cb[2]\ cb[3] + 
          273.599999999999976`\ cb[2]\^2\ cb[3] - 
          90.7199999999999739`\ cb[3]\^2 - 288\ cb[2]\ cb[3]\^2 - 
          2.93760000000000367`\ cb[4] - 100.800000000000045`\ cb[2]\ cb[4] - 
          144\ cb[2]\^2\ cb[4] + 228.000000000000024`\ cb[3]\ cb[4] - 
          68\ cb[4]\^2 + 9.0720000000000045`\ cb[5] + 
          91.1999999999999921`\ cb[2]\ cb[5] - 96\ cb[3]\ cb[5] - 
          11.7600000000000015`\ cb[6] - 32\ cb[2]\ cb[6] + 
          7.60000000000000053`\ cb[7] - 2\ cb[8] + 
          0.279935999999999962`\ cw[2] - 4.14719999999999977`\ cb[2]\ cw[2] - 
          60.4799999999999826`\ cb[2]\^2\ cw[2] + 
          31.1039999999999716`\ cb[3]\ cw[2] + 
          273.599999999999976`\ cb[2]\ cb[3]\ cw[2] - 144\ cb[3]\^2\ cw[2] - 
          70.5599999999999916`\ cb[4]\ cw[2] - 192\ cb[2]\ cb[4]\ cw[2] + 
          68.3999999999999896`\ cb[5]\ cw[2] - 24\ cb[6]\ cw[2] - 
          1.8144000000000009`\ cw[2]\^2 - 
          60.4800000000000093`\ cb[2]\ cw[2]\^2 - 144\ cb[2]\^2\ cw[2]\^2 + 
          136.799999999999988`\ cb[3]\ cw[2]\^2 - 72\ cb[4]\ cw[2]\^2 - 
          15.1199999999999956`\ cw[2]\^3 - 18\ cw[2]\^4 - 
          0.0518399999999999927`\ cw[3] + 
          5.18400000000000016`\ cb[2]\ cw[3] - 
          20.1599999999999912`\ cb[3]\ cw[3] + 
          30.4000000000000003`\ cb[4]\ cw[3] - 16\ cb[5]\ cw[3] + 
          7.77600000000000335`\ cw[2]\ cw[3] + 
          91.1999999999999921`\ cb[2]\ cw[2]\ cw[3] - 
          96\ cb[3]\ cw[2]\ cw[3] + 22.799999999999998`\ cw[2]\^2\ cw[3] - 
          6.71999999999999708`\ cw[3]\^2 - 32\ cb[2]\ cw[3]\^2 - 
          0.0864000000000000056`\ cw[4] - 
          5.03999999999999737`\ cw[2]\ cw[4] - 12\ cw[2]\^2\ cw[4] + 
          7.60000000000000053`\ cw[3]\ cw[4] - 2\ cw[4]\^2 > 0, 
      \(0.0298598399999999983`\[InvisibleSpace]\) - 
          0.0725759999999997695`\ cb[2] - 3.28320000000000078`\ cb[2]\^2 + 
          35.04`\ cb[2]\^3 + 96\ cb[2]\^4 + 1.48607999999999851`\ cb[3] - 
          9.79199999999992698`\ cb[2]\ cb[3] - 
          403.199999999999914`\ cb[2]\^2\ cb[3] + 
          81.8399999999999749`\ cb[3]\^2 + 576\ cb[2]\ cb[3]\^2 - 
          2.6208000000000009`\ cb[4] + 91.5999999999999658`\ cb[2]\ cb[4] + 
          288\ cb[2]\^2\ cb[4] - 336.000000000000031`\ cb[3]\ cb[4] + 
          136\ cb[4]\^2 - 2.30400000000000249`\ cb[5] - 
          134.40000000000003`\ cb[2]\ cb[5] + 192\ cb[3]\ cb[5] + 
          10.7199999999999939`\ cb[6] + 64\ cb[2]\ cb[6] - 
          11.200000000000001`\ cb[7] + 4\ cb[8] + 
          0.0103680000000001282`\ cw[2] - 
          2.93760000000000243`\ cb[2]\ cw[2] + 
          58.5599999999999987`\ cb[2]\^2\ cw[2] - 
          8.92799999999995819`\ cb[3]\ cw[2] - 
          403.199999999999914`\ cb[2]\ cb[3]\ cw[2] + 288\ cb[3]\^2\ cw[2] + 
          64.3200000000000038`\ cb[4]\ cw[2] + 384\ cb[2]\ cb[4]\ cw[2] - 
          100.799999999999978`\ cb[5]\ cw[2] + 48\ cb[6]\ cw[2] - 
          1.55520000000000147`\ cw[2]\^2 + 
          52.5600000000000022`\ cb[2]\ cw[2]\^2 + 288\ cb[2]\^2\ cw[2]\^2 - 
          201.599999999999957`\ cb[3]\ cw[2]\^2 + 144\ cb[4]\ cw[2]\^2 + 
          14.6399999999999996`\ cw[2]\^3 + 36\ cw[2]\^4 + 
          0.103680000000000038`\ cw[3] - 2.68800000000000061`\ cb[2]\ cw[3] + 
          19.519999999999996`\ cb[3]\ cw[3] - 
          44.8000000000000042`\ cb[4]\ cw[3] + 32\ cb[5]\ cw[3] - 
          1.63200000000000278`\ cw[2]\ cw[3] - 
          134.40000000000003`\ cb[2]\ cw[2]\ cw[3] + 
          192\ cb[3]\ cw[2]\ cw[3] - 33.6000000000000076`\ cw[2]\^2\ cw[3] + 
          5.83999999999999985`\ cw[3]\^2 + 64\ cb[2]\ cw[3]\^2 + 
          0.0287999999999999367`\ cw[4] + 4.879999999999999`\ cw[2]\ cw[4] + 
          24\ cw[2]\^2\ cw[4] - 11.200000000000001`\ cw[3]\ cw[4] + 
          4\ cw[4]\^2 > 0, 
      \(0.00995328000000000301`\[InvisibleSpace]\) - 
          0.0414719999999999799`\ cb[2] + 0.633599999999999852`\ cb[2]\^2 - 
          6.72000000000000596`\ cb[2]\^3 - 48\ cb[2]\^4 + 
          0.120960000000001532`\ cb[3] - 5.6640000000000219`\ cb[2]\ cb[3] + 
          129.599999999999981`\ cb[2]\^2\ cb[3] - 
          9.11999999999998323`\ cb[3]\^2 - 288\ cb[2]\ cb[3]\^2 + 
          0.758400000000001295`\ cb[4] - 8.79999999999995452`\ cb[2]\ cb[4] - 
          144\ cb[2]\^2\ cb[4] + 108.000000000000007`\ cb[3]\ cb[4] - 
          68\ cb[4]\^2 - 1.56799999999999872`\ cb[5] + 
          43.199999999999985`\ cb[2]\ cb[5] - 96\ cb[3]\ cb[5] - 
          0.959999999999995168`\ cb[6] - 32\ cb[2]\ cb[6] + 
          3.59999999999999964`\ cb[7] - 2\ cb[8] - 
          0.11750400000000003`\ cw[2] + 1.32479999999999775`\ cb[2]\ cw[2] + 
          1.91999999999999459`\ cb[2]\^2\ cw[2] - 
          6.57600000000001383`\ cb[3]\ cw[2] + 
          129.599999999999981`\ cb[2]\ cb[3]\ cw[2] - 144\ cb[3]\^2\ cw[2] - 
          5.75999999999999445`\ cb[4]\ cw[2] - 192\ cb[2]\ cb[4]\ cw[2] + 
          32.3999999999999932`\ cb[5]\ cw[2] - 24\ cb[6]\ cw[2] + 
          0.489599999999999457`\ cw[2]\^2 - 
          10.0799999999999978`\ cb[2]\ cw[2]\^2 - 144\ cb[2]\^2\ cw[2]\^2 + 
          64.7999999999999864`\ cb[3]\ cw[2]\^2 - 72\ cb[4]\ cw[2]\^2 + 
          0.479999999999998649`\ cw[2]\^3 - 18\ cw[2]\^4 + 
          0.0921600000000000108`\ cw[3] - 
          2.49600000000000044`\ cb[2]\ cw[3] + 
          0.639999999999998792`\ cb[3]\ cw[3] + 
          14.3999999999999994`\ cb[4]\ cw[3] - 16\ cb[5]\ cw[3] - 
          0.94399999999999995`\ cw[2]\ cw[3] + 
          43.199999999999985`\ cb[2]\ cw[2]\ cw[3] - 
          96\ cb[3]\ cw[2]\ cw[3] + 10.7999999999999962`\ cw[2]\^2\ cw[3] - 
          1.1200000000000001`\ cw[3]\^2 - 32\ cb[2]\ cw[3]\^2 + 
          0.0576000000000000067`\ cw[4] + 
          0.159999999999999698`\ cw[2]\ cw[4] - 12\ cw[2]\^2\ cw[4] + 
          3.59999999999999964`\ cw[3]\ cw[4] - 2\ cw[4]\^2 > 0, 
      \(0.00746495999999999781`\[InvisibleSpace]\) + 
          0.0466560000000000396`\ cb[2] + 0.259200000000000407`\ cb[2]\^2 + 
          11.7599999999999993`\ cb[2]\^3 + 24\ cb[2]\^4 + 
          0.155519999999999569`\ cb[3] - 6.04799999999997961`\ cb[2]\ cb[3] - 
          100.799999999999978`\ cb[2]\^2\ cb[3] + 
          21.9599999999999928`\ cb[3]\^2 + 144\ cb[2]\ cb[3]\^2 - 
          0.475200000000000422`\ cb[4] + 23.3999999999999896`\ cb[2]\ cb[4] + 
          72\ cb[2]\^2\ cb[4] - 84.0000000000000035`\ cb[3]\ cb[4] + 
          34\ cb[4]\^2 - 0.5760000000000006`\ cb[5] - 
          33.6000000000000076`\ cb[2]\ cb[5] + 48\ cb[3]\ cb[5] + 
          2.67999999999999838`\ cb[6] + 16\ cb[2]\ cb[6] - 
          2.80000000000000035`\ cb[7] + cb[8] - 
          0.0622079999999999522`\ cw[2] - 
          1.81440000000000178`\ cb[2]\ cw[2] + 
          8.64000000000000056`\ cb[2]\^2\ cw[2] - 
          0.43199999999998786`\ cb[3]\ cw[2] - 
          100.799999999999978`\ cb[2]\ cb[3]\ cw[2] + 72\ cb[3]\^2\ cw[2] + 
          16.0800000000000009`\ cb[4]\ cw[2] + 96\ cb[2]\ cb[4]\ cw[2] - 
          25.1999999999999957`\ cb[5]\ cw[2] + 12\ cb[6]\ cw[2] - 
          0.388800000000000203`\ cw[2]\^2 + 
          17.6399999999999979`\ cb[2]\ cw[2]\^2 + 72\ cb[2]\^2\ cw[2]\^2 - 
          50.3999999999999914`\ cb[3]\ cw[2]\^2 + 36\ cb[4]\ cw[2]\^2 + 
          2.16000000000000014`\ cw[2]\^3 + 9\ cw[2]\^4 + 
          0.241919999999999957`\ cw[3] + 1.72799999999999975`\ cb[2]\ cw[3] + 
          2.87999999999999936`\ cb[3]\ cw[3] - 
          11.200000000000001`\ cb[4]\ cw[3] + 8\ cb[5]\ cw[3] - 
          1.00800000000000067`\ cw[2]\ cw[3] - 
          33.6000000000000076`\ cb[2]\ cw[2]\ cw[3] + 
          48\ cb[3]\ cw[2]\ cw[3] - 8.40000000000000213`\ cw[2]\^2\ cw[3] + 
          1.95999999999999996`\ cw[3]\^2 + 16\ cb[2]\ cw[3]\^2 - 
          0.172799999999999975`\ cw[4] + 0.71999999999999984`\ cw[2]\ cw[4] + 
          6\ cw[2]\^2\ cw[4] - 2.80000000000000035`\ cw[3]\ cw[4] + 
          cw[4]\^2 > 0, 
      \(0.00995327999999999768`\[InvisibleSpace]\) - 
          0.0414719999999999799`\ cb[2] + 0.633599999999999852`\ cb[2]\^2 - 
          6.72000000000000596`\ cb[2]\^3 - 48\ cb[2]\^4 + 
          0.120960000000001532`\ cb[3] - 5.6640000000000219`\ cb[2]\ cb[3] + 
          129.599999999999981`\ cb[2]\^2\ cb[3] - 
          9.11999999999998323`\ cb[3]\^2 - 288\ cb[2]\ cb[3]\^2 + 
          0.758400000000001295`\ cb[4] - 8.79999999999995452`\ cb[2]\ cb[4] - 
          144\ cb[2]\^2\ cb[4] + 108.000000000000007`\ cb[3]\ cb[4] - 
          68\ cb[4]\^2 - 1.56799999999999872`\ cb[5] + 
          43.199999999999985`\ cb[2]\ cb[5] - 96\ cb[3]\ cb[5] - 
          0.959999999999995168`\ cb[6] - 32\ cb[2]\ cb[6] + 
          3.59999999999999964`\ cb[7] - 2\ cb[8] - 
          0.117504000000000008`\ cw[2] + 1.32479999999999775`\ cb[2]\ cw[2] + 
          1.91999999999999548`\ cb[2]\^2\ cw[2] - 
          6.57600000000001383`\ cb[3]\ cw[2] + 
          129.599999999999981`\ cb[2]\ cb[3]\ cw[2] - 144\ cb[3]\^2\ cw[2] - 
          5.75999999999999268`\ cb[4]\ cw[2] - 192\ cb[2]\ cb[4]\ cw[2] + 
          32.3999999999999932`\ cb[5]\ cw[2] - 24\ cb[6]\ cw[2] + 
          0.48959999999999928`\ cw[2]\^2 - 
          10.0799999999999978`\ cb[2]\ cw[2]\^2 - 144\ cb[2]\^2\ cw[2]\^2 + 
          64.7999999999999864`\ cb[3]\ cw[2]\^2 - 72\ cb[4]\ cw[2]\^2 + 
          0.479999999999998827`\ cw[2]\^3 - 18\ cw[2]\^4 + 
          0.0921600000000000818`\ cw[3] - 
          2.49600000000000044`\ cb[2]\ cw[3] + 
          0.639999999999998792`\ cb[3]\ cw[3] + 
          14.3999999999999994`\ cb[4]\ cw[3] - 16\ cb[5]\ cw[3] - 
          0.94399999999999995`\ cw[2]\ cw[3] + 
          43.199999999999985`\ cb[2]\ cw[2]\ cw[3] - 
          96\ cb[3]\ cw[2]\ cw[3] + 10.7999999999999962`\ cw[2]\^2\ cw[3] - 
          1.1200000000000001`\ cw[3]\^2 - 32\ cb[2]\ cw[3]\^2 + 
          0.0575999999999999801`\ cw[4] + 
          0.159999999999999698`\ cw[2]\ cw[4] - 12\ cw[2]\^2\ cw[4] + 
          3.59999999999999964`\ cw[3]\ cw[4] - 2\ cw[4]\^2 > 0, 
      \(0.00331776000000000026`\[InvisibleSpace]\) + 
          0.00921599999999998864`\ cb[2] + 0.387199999999999544`\ cb[2]\^2 + 
          0.960000000000001207`\ cb[2]\^3 + 24\ cb[2]\^4 - 
          0.0844800000000006612`\ cb[3] + 
          2.11199999999999921`\ cb[2]\ cb[3] - 
          28.79999999999999`\ cb[2]\^2\ cb[3] - 
          3.84000000000000376`\ cb[3]\^2 + 144\ cb[2]\ cb[3]\^2 + 
          0.116800000000001213`\ cb[4] - 5.60000000000000852`\ cb[2]\ cb[4] + 
          72\ cb[2]\^2\ cb[4] - 23.9999999999999991`\ cb[3]\ cb[4] + 
          34\ cb[4]\^2 + 0.543999999999998529`\ cb[5] - 
          9.59999999999999431`\ cb[2]\ cb[5] + 48\ cb[3]\ cb[5] - 
          0.720000000000001438`\ cb[6] + 16\ cb[2]\ cb[6] - 
          0.800000000000000177`\ cb[7] + cb[8] - 
          0.0506879999999999952`\ cw[2] - 
          0.230400000000000071`\ cb[2]\ cw[2] - 
          10.5599999999999916`\ cb[2]\^2\ cw[2] + 
          2.20800000000000062`\ cb[3]\ cw[2] - 
          28.79999999999999`\ cb[2]\ cb[3]\ cw[2] + 72\ cb[3]\^2\ cw[2] - 
          4.31999999999999673`\ cb[4]\ cw[2] + 96\ cb[2]\ cb[4]\ cw[2] - 
          7.19999999999999751`\ cb[5]\ cw[2] + 12\ cb[6]\ cw[2] + 
          0.539199999999999679`\ cw[2]\^2 + 
          1.43999999999999683`\ cb[2]\ cw[2]\^2 + 72\ cb[2]\^2\ cw[2]\^2 - 
          14.399999999999995`\ cb[3]\ cw[2]\^2 + 36\ cb[4]\ cw[2]\^2 - 
          2.6399999999999979`\ cw[2]\^3 + 9\ cw[2]\^4 - 
          0.0460799999999999787`\ cw[3] + 
          0.767999999999999793`\ cb[2]\ cw[3] - 
          3.51999999999999912`\ cb[3]\ cw[3] - 
          3.20000000000000062`\ cb[4]\ cw[3] + 8\ cb[5]\ cw[3] + 
          0.351999999999998447`\ cw[2]\ cw[3] - 
          9.59999999999999431`\ cb[2]\ cw[2]\ cw[3] + 
          48\ cb[3]\ cw[2]\ cw[3] - 2.39999999999999857`\ cw[2]\^2\ cw[3] + 
          0.160000000000000586`\ cw[3]\^2 + 16\ cb[2]\ cw[3]\^2 + 
          0.115199999999999991`\ cw[4] - 
          0.879999999999999715`\ cw[2]\ cw[4] + 6\ cw[2]\^2\ cw[4] - 
          0.800000000000000177`\ cw[3]\ cw[4] + cw[4]\^2 > 0, 
      \(0.0223948800000000014`\[InvisibleSpace]\) + 
          0.37324799999999989`\ cb[2] - 3.11039999999999761`\ cb[2]\^2 - 
          40.3199999999999825`\ cb[2]\^3 - 48\ cb[2]\^4 - 
          0.311039999999997185`\ cb[3] + 46.6559999999999597`\ cb[2]\ cb[3] + 
          273.599999999999976`\ cb[2]\^2\ cb[3] - 
          90.7199999999999739`\ cb[3]\^2 - 288\ cb[2]\ cb[3]\^2 - 
          2.93760000000000367`\ cb[4] - 100.800000000000045`\ cb[2]\ cb[4] - 
          144\ cb[2]\^2\ cb[4] + 228.000000000000024`\ cb[3]\ cb[4] - 
          68\ cb[4]\^2 + 9.0720000000000045`\ cb[5] + 
          91.1999999999999921`\ cb[2]\ cb[5] - 96\ cb[3]\ cb[5] - 
          11.7600000000000015`\ cb[6] - 32\ cb[2]\ cb[6] + 
          7.60000000000000053`\ cb[7] - 2\ cb[8] + 
          0.279935999999999962`\ cw[2] - 4.14719999999999977`\ cb[2]\ cw[2] - 
          60.4799999999999826`\ cb[2]\^2\ cw[2] + 
          31.1039999999999672`\ cb[3]\ cw[2] + 
          273.599999999999976`\ cb[2]\ cb[3]\ cw[2] - 144\ cb[3]\^2\ cw[2] - 
          70.5599999999999916`\ cb[4]\ cw[2] - 192\ cb[2]\ cb[4]\ cw[2] + 
          68.3999999999999896`\ cb[5]\ cw[2] - 24\ cb[6]\ cw[2] - 
          1.81440000000000072`\ cw[2]\^2 - 
          60.4800000000000093`\ cb[2]\ cw[2]\^2 - 144\ cb[2]\^2\ cw[2]\^2 + 
          136.799999999999988`\ cb[3]\ cw[2]\^2 - 72\ cb[4]\ cw[2]\^2 - 
          15.1199999999999956`\ cw[2]\^3 - 18\ cw[2]\^4 - 
          0.0518399999999999927`\ cw[3] + 
          5.18400000000000016`\ cb[2]\ cw[3] - 
          20.1599999999999912`\ cb[3]\ cw[3] + 
          30.4000000000000003`\ cb[4]\ cw[3] - 16\ cb[5]\ cw[3] + 
          7.77600000000000335`\ cw[2]\ cw[3] + 
          91.1999999999999921`\ cb[2]\ cw[2]\ cw[3] - 
          96\ cb[3]\ cw[2]\ cw[3] + 22.799999999999998`\ cw[2]\^2\ cw[3] - 
          6.71999999999999708`\ cw[3]\^2 - 32\ cb[2]\ cw[3]\^2 - 
          0.0864000000000000056`\ cw[4] - 
          5.03999999999999737`\ cw[2]\ cw[4] - 12\ cw[2]\^2\ cw[4] + 
          7.60000000000000053`\ cw[3]\ cw[4] - 2\ cw[4]\^2 > 0, 
      \(0.0298598399999999983`\[InvisibleSpace]\) - 
          0.0725759999999997695`\ cb[2] - 3.28320000000000078`\ cb[2]\^2 + 
          35.04`\ cb[2]\^3 + 96\ cb[2]\^4 + 1.48607999999999851`\ cb[3] - 
          9.7919999999999252`\ cb[2]\ cb[3] - 
          403.199999999999914`\ cb[2]\^2\ cb[3] + 
          81.8399999999999749`\ cb[3]\^2 + 576\ cb[2]\ cb[3]\^2 - 
          2.6208000000000009`\ cb[4] + 91.5999999999999658`\ cb[2]\ cb[4] + 
          288\ cb[2]\^2\ cb[4] - 336.000000000000031`\ cb[3]\ cb[4] + 
          136\ cb[4]\^2 - 2.30400000000000249`\ cb[5] - 
          134.40000000000003`\ cb[2]\ cb[5] + 192\ cb[3]\ cb[5] + 
          10.7199999999999939`\ cb[6] + 64\ cb[2]\ cb[6] - 
          11.200000000000001`\ cb[7] + 4\ cb[8] + 
          0.0103680000000001548`\ cw[2] - 
          2.93760000000000243`\ cb[2]\ cw[2] + 
          58.5599999999999987`\ cb[2]\^2\ cw[2] - 
          8.92799999999995819`\ cb[3]\ cw[2] - 
          403.199999999999914`\ cb[2]\ cb[3]\ cw[2] + 288\ cb[3]\^2\ cw[2] + 
          64.3200000000000038`\ cb[4]\ cw[2] + 384\ cb[2]\ cb[4]\ cw[2] - 
          100.799999999999978`\ cb[5]\ cw[2] + 48\ cb[6]\ cw[2] - 
          1.5552000000000012`\ cw[2]\^2 + 
          52.5600000000000022`\ cb[2]\ cw[2]\^2 + 288\ cb[2]\^2\ cw[2]\^2 - 
          201.599999999999957`\ cb[3]\ cw[2]\^2 + 144\ cb[4]\ cw[2]\^2 + 
          14.6399999999999996`\ cw[2]\^3 + 36\ cw[2]\^4 + 
          0.103679999999999994`\ cw[3] - 2.68800000000000061`\ cb[2]\ cw[3] + 
          19.519999999999996`\ cb[3]\ cw[3] - 
          44.8000000000000042`\ cb[4]\ cw[3] + 32\ cb[5]\ cw[3] - 
          1.63200000000000278`\ cw[2]\ cw[3] - 
          134.40000000000003`\ cb[2]\ cw[2]\ cw[3] + 
          192\ cb[3]\ cw[2]\ cw[3] - 33.6000000000000076`\ cw[2]\^2\ cw[3] + 
          5.83999999999999985`\ cw[3]\^2 + 64\ cb[2]\ cw[3]\^2 + 
          0.0287999999999999367`\ cw[4] + 4.879999999999999`\ cw[2]\ cw[4] + 
          24\ cw[2]\^2\ cw[4] - 11.200000000000001`\ cw[3]\ cw[4] + 
          4\ cw[4]\^2 > 0, 
      \(0.00995328000000000301`\[InvisibleSpace]\) - 
          0.041472000000000051`\ cb[2] + 0.633599999999999852`\ cb[2]\^2 - 
          6.72000000000000596`\ cb[2]\^3 - 48\ cb[2]\^4 + 
          0.120960000000001532`\ cb[3] - 5.6640000000000219`\ cb[2]\ cb[3] + 
          129.599999999999981`\ cb[2]\^2\ cb[3] - 
          9.11999999999998323`\ cb[3]\^2 - 288\ cb[2]\ cb[3]\^2 + 
          0.758400000000001295`\ cb[4] - 8.79999999999995452`\ cb[2]\ cb[4] - 
          144\ cb[2]\^2\ cb[4] + 108.000000000000007`\ cb[3]\ cb[4] - 
          68\ cb[4]\^2 - 1.56799999999999872`\ cb[5] + 
          43.199999999999985`\ cb[2]\ cb[5] - 96\ cb[3]\ cb[5] - 
          0.959999999999995168`\ cb[6] - 32\ cb[2]\ cb[6] + 
          3.59999999999999964`\ cb[7] - 2\ cb[8] - 
          0.11750400000000003`\ cw[2] + 1.32479999999999731`\ cb[2]\ cw[2] + 
          1.91999999999999548`\ cb[2]\^2\ cw[2] - 
          6.57600000000001383`\ cb[3]\ cw[2] + 
          129.599999999999981`\ cb[2]\ cb[3]\ cw[2] - 144\ cb[3]\^2\ cw[2] - 
          5.75999999999999268`\ cb[4]\ cw[2] - 192\ cb[2]\ cb[4]\ cw[2] + 
          32.3999999999999932`\ cb[5]\ cw[2] - 24\ cb[6]\ cw[2] + 
          0.489599999999999457`\ cw[2]\^2 - 
          10.0799999999999978`\ cb[2]\ cw[2]\^2 - 144\ cb[2]\^2\ cw[2]\^2 + 
          64.7999999999999864`\ cb[3]\ cw[2]\^2 - 72\ cb[4]\ cw[2]\^2 + 
          0.479999999999998827`\ cw[2]\^3 - 18\ cw[2]\^4 + 
          0.0921600000000000108`\ cw[3] - 
          2.49600000000000044`\ cb[2]\ cw[3] + 
          0.639999999999998792`\ cb[3]\ cw[3] + 
          14.3999999999999994`\ cb[4]\ cw[3] - 16\ cb[5]\ cw[3] - 
          0.94399999999999995`\ cw[2]\ cw[3] + 
          43.199999999999985`\ cb[2]\ cw[2]\ cw[3] - 
          96\ cb[3]\ cw[2]\ cw[3] + 10.7999999999999962`\ cw[2]\^2\ cw[3] - 
          1.1200000000000001`\ cw[3]\^2 - 32\ cb[2]\ cw[3]\^2 + 
          0.0576000000000000067`\ cw[4] + 
          0.159999999999999698`\ cw[2]\ cw[4] - 12\ cw[2]\^2\ cw[4] + 
          3.59999999999999964`\ cw[3]\ cw[4] - 2\ cw[4]\^2 > 0, 
      \(0.0298598399999999983`\[InvisibleSpace]\) - 
          0.0725759999999997695`\ cb[2] - 3.28320000000000078`\ cb[2]\^2 + 
          35.04`\ cb[2]\^3 + 96\ cb[2]\^4 + 1.48607999999999869`\ cb[3] - 
          9.7919999999999252`\ cb[2]\ cb[3] - 
          403.199999999999914`\ cb[2]\^2\ cb[3] + 
          81.8399999999999749`\ cb[3]\^2 + 576\ cb[2]\ cb[3]\^2 - 
          2.6208000000000009`\ cb[4] + 91.5999999999999658`\ cb[2]\ cb[4] + 
          288\ cb[2]\^2\ cb[4] - 336.000000000000031`\ cb[3]\ cb[4] + 
          136\ cb[4]\^2 - 2.30400000000000249`\ cb[5] - 
          134.40000000000003`\ cb[2]\ cb[5] + 192\ cb[3]\ cb[5] + 
          10.7199999999999939`\ cb[6] + 64\ cb[2]\ cb[6] - 
          11.200000000000001`\ cb[7] + 4\ cb[8] + 
          0.0103680000000001548`\ cw[2] - 
          2.93760000000000243`\ cb[2]\ cw[2] + 
          58.5599999999999987`\ cb[2]\^2\ cw[2] - 
          8.92799999999995819`\ cb[3]\ cw[2] - 
          403.199999999999914`\ cb[2]\ cb[3]\ cw[2] + 288\ cb[3]\^2\ cw[2] + 
          64.3200000000000038`\ cb[4]\ cw[2] + 384\ cb[2]\ cb[4]\ cw[2] - 
          100.799999999999978`\ cb[5]\ cw[2] + 48\ cb[6]\ cw[2] - 
          1.55520000000000147`\ cw[2]\^2 + 
          52.5600000000000022`\ cb[2]\ cw[2]\^2 + 288\ cb[2]\^2\ cw[2]\^2 - 
          201.599999999999957`\ cb[3]\ cw[2]\^2 + 144\ cb[4]\ cw[2]\^2 + 
          14.6399999999999996`\ cw[2]\^3 + 36\ cw[2]\^4 + 
          0.103679999999999994`\ cw[3] - 2.68800000000000061`\ cb[2]\ cw[3] + 
          19.519999999999996`\ cb[3]\ cw[3] - 
          44.8000000000000042`\ cb[4]\ cw[3] + 32\ cb[5]\ cw[3] - 
          1.63200000000000278`\ cw[2]\ cw[3] - 
          134.40000000000003`\ cb[2]\ cw[2]\ cw[3] + 
          192\ cb[3]\ cw[2]\ cw[3] - 33.6000000000000076`\ cw[2]\^2\ cw[3] + 
          5.83999999999999985`\ cw[3]\^2 + 64\ cb[2]\ cw[3]\^2 + 
          0.02879999999999999`\ cw[4] + 4.879999999999999`\ cw[2]\ cw[4] + 
          24\ cw[2]\^2\ cw[4] - 11.200000000000001`\ cw[3]\ cw[4] + 
          4\ cw[4]\^2 > 0, 
      \(0.0398131200000000085`\[InvisibleSpace]\) - 
          0.511488000000000031`\ cb[2] + 3.97439999999999962`\ cb[2]\^2 - 
          2.88000000000001321`\ cb[2]\^3 - 192\ cb[2]\^4 + 
          0.91584000000000536`\ cb[3] - 39.4560000000000812`\ cb[2]\ cb[3] + 
          518.399999999999749`\ cb[2]\^2\ cb[3] - 
          24.4799999999999418`\ cb[3]\^2 - 1152\ cb[2]\ cb[3]\^2 + 
          3.27360000000000406`\ cb[4] - 31.1999999999998456`\ cb[2]\ cb[4] - 
          576\ cb[2]\^2\ cb[4] + 432.000000000000028`\ cb[3]\ cb[4] - 
          272\ cb[4]\^2 - 6.27199999999999491`\ cb[5] + 
          172.799999999999931`\ cb[2]\ cb[5] - 384\ cb[3]\ cb[5] - 
          3.8399999999999812`\ cb[6] - 128\ cb[2]\ cb[6] + 
          14.4000000000000021`\ cb[7] - 8\ cb[8] - 
          0.124416000000000037`\ cw[2] + 3.85919999999999099`\ cb[2]\ cw[2] - 
          40.3200000000000091`\ cb[2]\^2\ cw[2] - 
          17.9040000000000576`\ cb[3]\ cw[2] + 
          518.399999999999749`\ cb[2]\ cb[3]\ cw[2] - 576\ cb[3]\^2\ cw[2] - 
          23.0399999999999716`\ cb[4]\ cw[2] - 768\ cb[2]\ cb[4]\ cw[2] + 
          129.599999999999937`\ cb[5]\ cw[2] - 96\ cb[6]\ cw[2] + 
          1.95839999999999783`\ cw[2]\^2 - 
          4.31999999999999317`\ cb[2]\ cw[2]\^2 - 576\ cb[2]\^2\ cw[2]\^2 + 
          259.199999999999874`\ cb[3]\ cw[2]\^2 - 288\ cb[4]\ cw[2]\^2 - 
          10.0800000000000022`\ cw[2]\^3 - 72\ cw[2]\^4 - 
          0.0633599999999998608`\ cw[3] + 1.2159999999999993`\ cb[2]\ cw[3] - 
          13.4400000000000008`\ cb[3]\ cw[3] + 
          57.6000000000000067`\ cb[4]\ cw[3] - 64\ cb[5]\ cw[3] - 
          6.57599999999999695`\ cw[2]\ cw[3] + 
          172.799999999999931`\ cb[2]\ cw[2]\ cw[3] - 
          384\ cb[3]\ cw[2]\ cw[3] + 43.199999999999985`\ cw[2]\^2\ cw[3] - 
          0.480000000000000426`\ cw[3]\^2 - 128\ cb[2]\ cw[3]\^2 - 
          0.00959999999999999786`\ cw[4] - 
          3.36000000000000031`\ cw[2]\ cw[4] - 48\ cw[2]\^2\ cw[4] + 
          14.4000000000000021`\ cw[3]\ cw[4] - 8\ cw[4]\^2 > 0, 
      \(0.0132710400000000028`\[InvisibleSpace]\) - 
          0.0783359999999999612`\ cb[2] + 0.42879999999999816`\ cb[2]\^2 - 
          8.15999999999998593`\ cb[2]\^3 + 96\ cb[2]\^4 - 
          0.433920000000002747`\ cb[3] + 10.8479999999999975`\ cb[2]\ cb[3] - 
          115.199999999999969`\ cb[2]\^2\ cb[3] - 
          21.36000000000001`\ cb[3]\^2 + 576\ cb[2]\ cb[3]\^2 + 
          0.947200000000004393`\ cb[4] - 24.4000000000000305`\ cb[2]\ cb[4] + 
          288\ cb[2]\^2\ cb[4] - 95.9999999999999964`\ cb[3]\ cb[4] + 
          136\ cb[4]\^2 + 2.17599999999999393`\ cb[5] - 
          38.3999999999999772`\ cb[2]\ cb[5] + 192\ cb[3]\ cb[5] - 
          2.88000000000000575`\ cb[6] + 64\ cb[2]\ cb[6] - 
          3.20000000000000062`\ cb[7] + 4\ cb[8] - 
          0.0875519999999999676`\ cw[2] + 2.1983999999999999`\ cb[2]\ cw[2] - 
          18.2399999999999806`\ cb[2]\^2\ cw[2] + 
          7.632000000000005`\ cb[3]\ cw[2] - 
          115.199999999999969`\ cb[2]\ cb[3]\ cw[2] + 288\ cb[3]\^2\ cw[2] - 
          17.2799999999999869`\ cb[4]\ cw[2] + 384\ cb[2]\ cb[4]\ cw[2] - 
          28.79999999999999`\ cb[5]\ cw[2] + 48\ cb[6]\ cw[2] + 
          0.156800000000000494`\ cw[2]\^2 - 
          12.2399999999999975`\ cb[2]\ cw[2]\^2 + 288\ cb[2]\^2\ cw[2]\^2 - 
          57.5999999999999801`\ cb[3]\ cw[2]\^2 + 144\ cb[4]\ cw[2]\^2 - 
          4.55999999999999516`\ cw[2]\^3 + 36\ cw[2]\^4 - 
          0.0883199999999999008`\ cw[3] + 
          1.47199999999999908`\ cb[2]\ cw[3] - 
          6.07999999999999563`\ cb[3]\ cw[3] - 
          12.8000000000000024`\ cb[4]\ cw[3] + 32\ cb[5]\ cw[3] + 
          1.80799999999999378`\ cw[2]\ cw[3] - 
          38.3999999999999772`\ cb[2]\ cw[2]\ cw[3] + 
          192\ cb[3]\ cw[2]\ cw[3] - 9.59999999999999431`\ cw[2]\^2\ cw[3] - 
          1.3599999999999992`\ cw[3]\^2 + 64\ cb[2]\ cw[3]\^2 - 
          0.0192000000000000206`\ cw[4] - 
          1.51999999999999886`\ cw[2]\ cw[4] + 24\ cw[2]\^2\ cw[4] - 
          3.20000000000000062`\ cw[3]\ cw[4] + 4\ cw[4]\^2 > 0, 
      \(0.00995327999999999768`\[InvisibleSpace]\) - 
          0.0414720000000000066`\ cb[2] + 0.633599999999999408`\ cb[2]\^2 - 
          6.72000000000000596`\ cb[2]\^3 - 48\ cb[2]\^4 + 
          0.120960000000001532`\ cb[3] - 5.6640000000000219`\ cb[2]\ cb[3] + 
          129.599999999999981`\ cb[2]\^2\ cb[3] - 
          9.11999999999998323`\ cb[3]\^2 - 288\ cb[2]\ cb[3]\^2 + 
          0.758400000000001028`\ cb[4] - 8.79999999999995452`\ cb[2]\ cb[4] - 
          144\ cb[2]\^2\ cb[4] + 108.000000000000007`\ cb[3]\ cb[4] - 
          68\ cb[4]\^2 - 1.56799999999999872`\ cb[5] + 
          43.199999999999985`\ cb[2]\ cb[5] - 96\ cb[3]\ cb[5] - 
          0.959999999999995168`\ cb[6] - 32\ cb[2]\ cb[6] + 
          3.59999999999999964`\ cb[7] - 2\ cb[8] - 
          0.117504000000000008`\ cw[2] + 1.32479999999999753`\ cb[2]\ cw[2] + 
          1.91999999999999637`\ cb[2]\^2\ cw[2] - 
          6.57600000000001738`\ cb[3]\ cw[2] + 
          129.599999999999981`\ cb[2]\ cb[3]\ cw[2] - 144\ cb[3]\^2\ cw[2] - 
          5.7599999999999909`\ cb[4]\ cw[2] - 192\ cb[2]\ cb[4]\ cw[2] + 
          32.3999999999999932`\ cb[5]\ cw[2] - 24\ cb[6]\ cw[2] + 
          0.48959999999999928`\ cw[2]\^2 - 
          10.0799999999999978`\ cb[2]\ cw[2]\^2 - 144\ cb[2]\^2\ cw[2]\^2 + 
          64.7999999999999864`\ cb[3]\ cw[2]\^2 - 72\ cb[4]\ cw[2]\^2 + 
          0.479999999999999094`\ cw[2]\^3 - 18\ cw[2]\^4 + 
          0.0921600000000000818`\ cw[3] - 
          2.49600000000000044`\ cb[2]\ cw[3] + 
          0.639999999999998792`\ cb[3]\ cw[3] + 
          14.3999999999999994`\ cb[4]\ cw[3] - 16\ cb[5]\ cw[3] - 
          0.94399999999999995`\ cw[2]\ cw[3] + 
          43.199999999999985`\ cb[2]\ cw[2]\ cw[3] - 
          96\ cb[3]\ cw[2]\ cw[3] + 10.7999999999999962`\ cw[2]\^2\ cw[3] - 
          1.1200000000000001`\ cw[3]\^2 - 32\ cb[2]\ cw[3]\^2 + 
          0.0575999999999999801`\ cw[4] + 
          0.159999999999999698`\ cw[2]\ cw[4] - 12\ cw[2]\^2\ cw[4] + 
          3.59999999999999964`\ cw[3]\ cw[4] - 2\ cw[4]\^2 > 0, 
      \(0.0132710399999999983`\[InvisibleSpace]\) - 
          0.0783359999999999612`\ cb[2] + 0.42879999999999816`\ cb[2]\^2 - 
          8.15999999999998593`\ cb[2]\^3 + 96\ cb[2]\^4 - 
          0.433920000000002747`\ cb[3] + 10.8479999999999909`\ cb[2]\ cb[3] - 
          115.199999999999969`\ cb[2]\^2\ cb[3] - 
          21.36000000000001`\ cb[3]\^2 + 576\ cb[2]\ cb[3]\^2 + 
          0.947200000000004393`\ cb[4] - 24.4000000000000305`\ cb[2]\ cb[4] + 
          288\ cb[2]\^2\ cb[4] - 95.9999999999999964`\ cb[3]\ cb[4] + 
          136\ cb[4]\^2 + 2.17599999999999393`\ cb[5] - 
          38.3999999999999772`\ cb[2]\ cb[5] + 192\ cb[3]\ cb[5] - 
          2.88000000000000575`\ cb[6] + 64\ cb[2]\ cb[6] - 
          3.20000000000000062`\ cb[7] + 4\ cb[8] - 
          0.0875519999999999853`\ cw[2] + 
          2.19839999999999946`\ cb[2]\ cw[2] - 
          18.2399999999999806`\ cb[2]\^2\ cw[2] + 
          7.632000000000005`\ cb[3]\ cw[2] - 
          115.199999999999969`\ cb[2]\ cb[3]\ cw[2] + 288\ cb[3]\^2\ cw[2] - 
          17.2799999999999869`\ cb[4]\ cw[2] + 384\ cb[2]\ cb[4]\ cw[2] - 
          28.79999999999999`\ cb[5]\ cw[2] + 48\ cb[6]\ cw[2] + 
          0.156800000000000494`\ cw[2]\^2 - 
          12.2399999999999975`\ cb[2]\ cw[2]\^2 + 288\ cb[2]\^2\ cw[2]\^2 - 
          57.5999999999999801`\ cb[3]\ cw[2]\^2 + 144\ cb[4]\ cw[2]\^2 - 
          4.55999999999999516`\ cw[2]\^3 + 36\ cw[2]\^4 - 
          0.088319999999999954`\ cw[3] + 1.47199999999999908`\ cb[2]\ cw[3] - 
          6.07999999999999563`\ cb[3]\ cw[3] - 
          12.8000000000000024`\ cb[4]\ cw[3] + 32\ cb[5]\ cw[3] + 
          1.80799999999999378`\ cw[2]\ cw[3] - 
          38.3999999999999772`\ cb[2]\ cw[2]\ cw[3] + 
          192\ cb[3]\ cw[2]\ cw[3] - 9.59999999999999431`\ cw[2]\^2\ cw[3] - 
          1.3599999999999992`\ cw[3]\^2 + 64\ cb[2]\ cw[3]\^2 - 
          0.0191999999999999957`\ cw[4] - 
          1.51999999999999886`\ cw[2]\ cw[4] + 24\ cw[2]\^2\ cw[4] - 
          3.20000000000000062`\ cw[3]\ cw[4] + 4\ cw[4]\^2 > 0, 
      \(0.00442368000000000094`\[InvisibleSpace]\) + 
          0.0430080000000000151`\ cb[2] - 0.422399999999999486`\ cb[2]\^2 + 
          2.87999999999999278`\ cb[2]\^3 - 48\ cb[2]\^4 - 
          0.151039999999999619`\ cb[3] + 2.01599999999999468`\ cb[2]\ cb[3] - 
          14.4000000000000198`\ cb[2]\^2\ cb[3] + 
          12.4799999999999999`\ cb[3]\^2 - 288\ cb[2]\ cb[3]\^2 - 
          0.505600000000002935`\ cb[4] + 15.2000000000000001`\ cb[2]\ cb[4] - 
          144\ cb[2]\^2\ cb[4] - 11.9999999999999996`\ cb[3]\ cb[4] - 
          68\ cb[4]\^2 + 0.592000000000002213`\ cb[5] - 
          4.80000000000001136`\ cb[2]\ cb[5] - 96\ cb[3]\ cb[5] + 
          1.83999999999999772`\ cb[6] - 32\ cb[2]\ cb[6] - 
          0.399999999999999911`\ cb[7] - 2\ cb[8] - 
          0.00614399999999997259`\ cw[2] - 
          0.883200000000000251`\ cb[2]\ cw[2] + 
          16.3199999999999967`\ cb[2]\^2\ cw[2] + 
          2.5440000000000067`\ cb[3]\ cw[2] - 
          14.4000000000000198`\ cb[2]\ cb[3]\ cw[2] - 144\ cb[3]\^2\ cw[2] + 
          11.0399999999999809`\ cb[4]\ cw[2] - 192\ cb[2]\ cb[4]\ cw[2] - 
          3.60000000000000497`\ cb[5]\ cw[2] - 24\ cb[6]\ cw[2] - 
          0.326400000000000423`\ cw[2]\^2 + 
          4.3200000000000065`\ cb[2]\ cw[2]\^2 - 144\ cb[2]\^2\ cw[2]\^2 - 
          7.20000000000000994`\ cb[3]\ cw[2]\^2 - 72\ cb[4]\ cw[2]\^2 + 
          4.07999999999999918`\ cw[2]\^3 - 18\ cw[2]\^4 - 
          0.0998400000000000353`\ cw[3] + 
          1.02400000000000002`\ cb[2]\ cw[3] + 
          5.4399999999999995`\ cb[3]\ cw[3] - 
          1.59999999999999964`\ cb[4]\ cw[3] - 16\ cb[5]\ cw[3] + 
          0.336000000000002296`\ cw[2]\ cw[3] - 
          4.80000000000001136`\ cb[2]\ cw[2]\ cw[3] - 
          96\ cb[3]\ cw[2]\ cw[3] - 1.20000000000000284`\ cw[2]\^2\ cw[3] + 
          0.479999999999998649`\ cw[3]\^2 - 32\ cb[2]\ cw[3]\^2 - 
          0.0383999999999999896`\ cw[4] + 
          1.35999999999999987`\ cw[2]\ cw[4] - 12\ cw[2]\^2\ cw[4] - 
          0.399999999999999911`\ cw[3]\ cw[4] - 2\ cw[4]\^2 > 0, 
      \(0.00746495999999999781`\[InvisibleSpace]\) + 
          0.0466560000000000396`\ cb[2] + 0.259200000000000407`\ cb[2]\^2 + 
          11.7599999999999993`\ cb[2]\^3 + 24\ cb[2]\^4 + 
          0.155519999999999569`\ cb[3] - 6.04799999999997961`\ cb[2]\ cb[3] - 
          100.799999999999978`\ cb[2]\^2\ cb[3] + 
          21.9599999999999928`\ cb[3]\^2 + 144\ cb[2]\ cb[3]\^2 - 
          0.475200000000000422`\ cb[4] + 23.3999999999999896`\ cb[2]\ cb[4] + 
          72\ cb[2]\^2\ cb[4] - 84.0000000000000035`\ cb[3]\ cb[4] + 
          34\ cb[4]\^2 - 0.5760000000000006`\ cb[5] - 
          33.6000000000000076`\ cb[2]\ cb[5] + 48\ cb[3]\ cb[5] + 
          2.67999999999999838`\ cb[6] + 16\ cb[2]\ cb[6] - 
          2.80000000000000035`\ cb[7] + cb[8] - 
          0.0622079999999999522`\ cw[2] - 
          1.81440000000000178`\ cb[2]\ cw[2] + 
          8.63999999999999701`\ cb[2]\^2\ cw[2] - 
          0.431999999999987505`\ cb[3]\ cw[2] - 
          100.799999999999978`\ cb[2]\ cb[3]\ cw[2] + 72\ cb[3]\^2\ cw[2] + 
          16.0800000000000009`\ cb[4]\ cw[2] + 96\ cb[2]\ cb[4]\ cw[2] - 
          25.1999999999999957`\ cb[5]\ cw[2] + 12\ cb[6]\ cw[2] - 
          0.388800000000000203`\ cw[2]\^2 + 
          17.6399999999999979`\ cb[2]\ cw[2]\^2 + 72\ cb[2]\^2\ cw[2]\^2 - 
          50.3999999999999914`\ cb[3]\ cw[2]\^2 + 36\ cb[4]\ cw[2]\^2 + 
          2.15999999999999925`\ cw[2]\^3 + 9\ cw[2]\^4 + 
          0.241919999999999957`\ cw[3] + 1.72799999999999975`\ cb[2]\ cw[3] + 
          2.87999999999999936`\ cb[3]\ cw[3] - 
          11.200000000000001`\ cb[4]\ cw[3] + 8\ cb[5]\ cw[3] - 
          1.00800000000000067`\ cw[2]\ cw[3] - 
          33.6000000000000076`\ cb[2]\ cw[2]\ cw[3] + 
          48\ cb[3]\ cw[2]\ cw[3] - 8.40000000000000213`\ cw[2]\^2\ cw[3] + 
          1.95999999999999996`\ cw[3]\^2 + 16\ cb[2]\ cw[3]\^2 - 
          0.172799999999999975`\ cw[4] + 0.71999999999999984`\ cw[2]\ cw[4] + 
          6\ cw[2]\^2\ cw[4] - 2.80000000000000035`\ cw[3]\ cw[4] + 
          cw[4]\^2 > 0, 
      \(0.00995327999999999946`\[InvisibleSpace]\) - 
          0.041472000000000051`\ cb[2] + 0.633599999999999852`\ cb[2]\^2 - 
          6.72000000000000596`\ cb[2]\^3 - 48\ cb[2]\^4 + 
          0.120960000000001532`\ cb[3] - 5.6640000000000219`\ cb[2]\ cb[3] + 
          129.599999999999981`\ cb[2]\^2\ cb[3] - 
          9.11999999999998323`\ cb[3]\^2 - 288\ cb[2]\ cb[3]\^2 + 
          0.758400000000001295`\ cb[4] - 8.79999999999995452`\ cb[2]\ cb[4] - 
          144\ cb[2]\^2\ cb[4] + 108.000000000000007`\ cb[3]\ cb[4] - 
          68\ cb[4]\^2 - 1.56799999999999872`\ cb[5] + 
          43.199999999999985`\ cb[2]\ cb[5] - 96\ cb[3]\ cb[5] - 
          0.959999999999995168`\ cb[6] - 32\ cb[2]\ cb[6] + 
          3.59999999999999964`\ cb[7] - 2\ cb[8] - 
          0.117504000000000052`\ cw[2] + 1.32479999999999797`\ cb[2]\ cw[2] + 
          1.91999999999999637`\ cb[2]\^2\ cw[2] - 
          6.57600000000001738`\ cb[3]\ cw[2] + 
          129.599999999999981`\ cb[2]\ cb[3]\ cw[2] - 144\ cb[3]\^2\ cw[2] - 
          5.7599999999999909`\ cb[4]\ cw[2] - 192\ cb[2]\ cb[4]\ cw[2] + 
          32.3999999999999932`\ cb[5]\ cw[2] - 24\ cb[6]\ cw[2] + 
          0.489599999999999457`\ cw[2]\^2 - 
          10.0799999999999978`\ cb[2]\ cw[2]\^2 - 144\ cb[2]\^2\ cw[2]\^2 + 
          64.7999999999999864`\ cb[3]\ cw[2]\^2 - 72\ cb[4]\ cw[2]\^2 + 
          0.479999999999999094`\ cw[2]\^3 - 18\ cw[2]\^4 + 
          0.0921600000000000818`\ cw[3] - 
          2.49600000000000044`\ cb[2]\ cw[3] + 
          0.639999999999998792`\ cb[3]\ cw[3] + 
          14.3999999999999994`\ cb[4]\ cw[3] - 16\ cb[5]\ cw[3] - 
          0.94399999999999995`\ cw[2]\ cw[3] + 
          43.199999999999985`\ cb[2]\ cw[2]\ cw[3] - 
          96\ cb[3]\ cw[2]\ cw[3] + 10.7999999999999962`\ cw[2]\^2\ cw[3] - 
          1.1200000000000001`\ cw[3]\^2 - 32\ cb[2]\ cw[3]\^2 + 
          0.0575999999999999801`\ cw[4] + 
          0.159999999999999698`\ cw[2]\ cw[4] - 12\ cw[2]\^2\ cw[4] + 
          3.59999999999999964`\ cw[3]\ cw[4] - 2\ cw[4]\^2 > 0, 
      \(0.00331776000000000026`\[InvisibleSpace]\) + 
          0.00921599999999999575`\ cb[2] + 0.387199999999999544`\ cb[2]\^2 + 
          0.960000000000001207`\ cb[2]\^3 + 24\ cb[2]\^4 - 
          0.0844800000000006612`\ cb[3] + 
          2.11199999999999921`\ cb[2]\ cb[3] - 
          28.79999999999999`\ cb[2]\^2\ cb[3] - 
          3.84000000000000376`\ cb[3]\^2 + 144\ cb[2]\ cb[3]\^2 + 
          0.116800000000001213`\ cb[4] - 5.60000000000000852`\ cb[2]\ cb[4] + 
          72\ cb[2]\^2\ cb[4] - 23.9999999999999991`\ cb[3]\ cb[4] + 
          34\ cb[4]\^2 + 0.543999999999998529`\ cb[5] - 
          9.59999999999999431`\ cb[2]\ cb[5] + 48\ cb[3]\ cb[5] - 
          0.720000000000001438`\ cb[6] + 16\ cb[2]\ cb[6] - 
          0.800000000000000177`\ cb[7] + cb[8] - 
          0.0506879999999999952`\ cw[2] - 
          0.230399999999999982`\ cb[2]\ cw[2] - 
          10.5599999999999916`\ cb[2]\^2\ cw[2] + 
          2.20800000000000062`\ cb[3]\ cw[2] - 
          28.79999999999999`\ cb[2]\ cb[3]\ cw[2] + 72\ cb[3]\^2\ cw[2] - 
          4.31999999999999673`\ cb[4]\ cw[2] + 96\ cb[2]\ cb[4]\ cw[2] - 
          7.19999999999999751`\ cb[5]\ cw[2] + 12\ cb[6]\ cw[2] + 
          0.539199999999999768`\ cw[2]\^2 + 
          1.43999999999999683`\ cb[2]\ cw[2]\^2 + 72\ cb[2]\^2\ cw[2]\^2 - 
          14.399999999999995`\ cb[3]\ cw[2]\^2 + 36\ cb[4]\ cw[2]\^2 - 
          2.6399999999999979`\ cw[2]\^3 + 9\ cw[2]\^4 - 
          0.0460799999999999787`\ cw[3] + 
          0.767999999999999793`\ cb[2]\ cw[3] - 
          3.51999999999999912`\ cb[3]\ cw[3] - 
          3.20000000000000062`\ cb[4]\ cw[3] + 8\ cb[5]\ cw[3] + 
          0.351999999999998447`\ cw[2]\ cw[3] - 
          9.59999999999999431`\ cb[2]\ cw[2]\ cw[3] + 
          48\ cb[3]\ cw[2]\ cw[3] - 2.39999999999999857`\ cw[2]\^2\ cw[3] + 
          0.160000000000000586`\ cw[3]\^2 + 16\ cb[2]\ cw[3]\^2 + 
          0.115199999999999991`\ cw[4] - 
          0.879999999999999715`\ cw[2]\ cw[4] + 6\ cw[2]\^2\ cw[4] - 
          0.800000000000000177`\ cw[3]\ cw[4] + cw[4]\^2 > 0, 
      \(0.00995327999999999768`\[InvisibleSpace]\) - 
          0.0414720000000000066`\ cb[2] + 0.633599999999999408`\ cb[2]\^2 - 
          6.72000000000000596`\ cb[2]\^3 - 48\ cb[2]\^4 + 
          0.120960000000001532`\ cb[3] - 5.6640000000000219`\ cb[2]\ cb[3] + 
          129.599999999999981`\ cb[2]\^2\ cb[3] - 
          9.11999999999998323`\ cb[3]\^2 - 288\ cb[2]\ cb[3]\^2 + 
          0.758400000000001028`\ cb[4] - 8.79999999999995452`\ cb[2]\ cb[4] - 
          144\ cb[2]\^2\ cb[4] + 108.000000000000007`\ cb[3]\ cb[4] - 
          68\ cb[4]\^2 - 1.56799999999999872`\ cb[5] + 
          43.199999999999985`\ cb[2]\ cb[5] - 96\ cb[3]\ cb[5] - 
          0.959999999999995168`\ cb[6] - 32\ cb[2]\ cb[6] + 
          3.59999999999999964`\ cb[7] - 2\ cb[8] - 
          0.117504000000000008`\ cw[2] + 1.32479999999999797`\ cb[2]\ cw[2] + 
          1.91999999999999992`\ cb[2]\^2\ cw[2] - 
          6.57600000000001738`\ cb[3]\ cw[2] + 
          129.599999999999981`\ cb[2]\ cb[3]\ cw[2] - 144\ cb[3]\^2\ cw[2] - 
          5.7599999999999909`\ cb[4]\ cw[2] - 192\ cb[2]\ cb[4]\ cw[2] + 
          32.3999999999999932`\ cb[5]\ cw[2] - 24\ cb[6]\ cw[2] + 
          0.489599999999999457`\ cw[2]\^2 - 
          10.0799999999999978`\ cb[2]\ cw[2]\^2 - 144\ cb[2]\^2\ cw[2]\^2 + 
          64.7999999999999864`\ cb[3]\ cw[2]\^2 - 72\ cb[4]\ cw[2]\^2 + 
          0.479999999999999982`\ cw[2]\^3 - 18\ cw[2]\^4 + 
          0.0921600000000000818`\ cw[3] - 
          2.49600000000000044`\ cb[2]\ cw[3] + 
          0.639999999999998792`\ cb[3]\ cw[3] + 
          14.3999999999999994`\ cb[4]\ cw[3] - 16\ cb[5]\ cw[3] - 
          0.94399999999999995`\ cw[2]\ cw[3] + 
          43.199999999999985`\ cb[2]\ cw[2]\ cw[3] - 
          96\ cb[3]\ cw[2]\ cw[3] + 10.7999999999999962`\ cw[2]\^2\ cw[3] - 
          1.1200000000000001`\ cw[3]\^2 - 32\ cb[2]\ cw[3]\^2 + 
          0.0575999999999999801`\ cw[4] + 
          0.159999999999999698`\ cw[2]\ cw[4] - 12\ cw[2]\^2\ cw[4] + 
          3.59999999999999964`\ cw[3]\ cw[4] - 2\ cw[4]\^2 > 0, 
      \(0.0132710399999999983`\[InvisibleSpace]\) - 
          0.0783359999999999612`\ cb[2] + 0.42879999999999816`\ cb[2]\^2 - 
          8.15999999999998593`\ cb[2]\^3 + 96\ cb[2]\^4 - 
          0.433920000000002747`\ cb[3] + 10.8479999999999909`\ cb[2]\ cb[3] - 
          115.199999999999969`\ cb[2]\^2\ cb[3] - 
          21.36000000000001`\ cb[3]\^2 + 576\ cb[2]\ cb[3]\^2 + 
          0.947200000000004393`\ cb[4] - 24.4000000000000305`\ cb[2]\ cb[4] + 
          288\ cb[2]\^2\ cb[4] - 95.9999999999999964`\ cb[3]\ cb[4] + 
          136\ cb[4]\^2 + 2.17599999999999393`\ cb[5] - 
          38.3999999999999772`\ cb[2]\ cb[5] + 192\ cb[3]\ cb[5] - 
          2.88000000000000575`\ cb[6] + 64\ cb[2]\ cb[6] - 
          3.20000000000000062`\ cb[7] + 4\ cb[8] - 
          0.0875519999999999853`\ cw[2] + 
          2.19840000000000124`\ cb[2]\ cw[2] - 
          18.2399999999999806`\ cb[2]\^2\ cw[2] + 
          7.63200000000000677`\ cb[3]\ cw[2] - 
          115.199999999999969`\ cb[2]\ cb[3]\ cw[2] + 288\ cb[3]\^2\ cw[2] - 
          17.2799999999999869`\ cb[4]\ cw[2] + 384\ cb[2]\ cb[4]\ cw[2] - 
          28.79999999999999`\ cb[5]\ cw[2] + 48\ cb[6]\ cw[2] + 
          0.156800000000000494`\ cw[2]\^2 - 
          12.2399999999999975`\ cb[2]\ cw[2]\^2 + 288\ cb[2]\^2\ cw[2]\^2 - 
          57.5999999999999801`\ cb[3]\ cw[2]\^2 + 144\ cb[4]\ cw[2]\^2 - 
          4.55999999999999516`\ cw[2]\^3 + 36\ cw[2]\^4 - 
          0.088319999999999954`\ cw[3] + 1.47199999999999908`\ cb[2]\ cw[3] - 
          6.07999999999999563`\ cb[3]\ cw[3] - 
          12.8000000000000024`\ cb[4]\ cw[3] + 32\ cb[5]\ cw[3] + 
          1.80799999999999378`\ cw[2]\ cw[3] - 
          38.3999999999999772`\ cb[2]\ cw[2]\ cw[3] + 
          192\ cb[3]\ cw[2]\ cw[3] - 9.59999999999999431`\ cw[2]\^2\ cw[3] - 
          1.3599999999999992`\ cw[3]\^2 + 64\ cb[2]\ cw[3]\^2 - 
          0.0191999999999999957`\ cw[4] - 
          1.51999999999999886`\ cw[2]\ cw[4] + 24\ cw[2]\^2\ cw[4] - 
          3.20000000000000062`\ cw[3]\ cw[4] + 4\ cw[4]\^2 > 0, 
      \(0.00442368000000000094`\[InvisibleSpace]\) + 
          0.0430080000000000151`\ cb[2] - 0.422399999999999486`\ cb[2]\^2 + 
          2.87999999999999278`\ cb[2]\^3 - 48\ cb[2]\^4 - 
          0.151039999999999619`\ cb[3] + 2.01600000000000001`\ cb[2]\ cb[3] - 
          14.4000000000000198`\ cb[2]\^2\ cb[3] + 
          12.4799999999999999`\ cb[3]\^2 - 288\ cb[2]\ cb[3]\^2 - 
          0.505600000000002935`\ cb[4] + 15.2000000000000001`\ cb[2]\ cb[4] - 
          144\ cb[2]\^2\ cb[4] - 11.9999999999999996`\ cb[3]\ cb[4] - 
          68\ cb[4]\^2 + 0.592000000000002213`\ cb[5] - 
          4.80000000000001136`\ cb[2]\ cb[5] - 96\ cb[3]\ cb[5] + 
          1.83999999999999772`\ cb[6] - 32\ cb[2]\ cb[6] - 
          0.399999999999999911`\ cb[7] - 2\ cb[8] - 
          0.00614399999999997259`\ cw[2] - 
          0.883200000000000251`\ cb[2]\ cw[2] + 
          16.3199999999999967`\ cb[2]\^2\ cw[2] + 
          2.5440000000000067`\ cb[3]\ cw[2] - 
          14.4000000000000198`\ cb[2]\ cb[3]\ cw[2] - 144\ cb[3]\^2\ cw[2] + 
          11.0399999999999831`\ cb[4]\ cw[2] - 192\ cb[2]\ cb[4]\ cw[2] - 
          3.60000000000000497`\ cb[5]\ cw[2] - 24\ cb[6]\ cw[2] - 
          0.326400000000000423`\ cw[2]\^2 + 
          4.3200000000000065`\ cb[2]\ cw[2]\^2 - 144\ cb[2]\^2\ cw[2]\^2 - 
          7.20000000000000994`\ cb[3]\ cw[2]\^2 - 72\ cb[4]\ cw[2]\^2 + 
          4.07999999999999918`\ cw[2]\^3 - 18\ cw[2]\^4 - 
          0.0998400000000000353`\ cw[3] + 
          1.02400000000000002`\ cb[2]\ cw[3] + 
          5.4399999999999995`\ cb[3]\ cw[3] - 
          1.59999999999999964`\ cb[4]\ cw[3] - 16\ cb[5]\ cw[3] + 
          0.336000000000002296`\ cw[2]\ cw[3] - 
          4.80000000000001136`\ cb[2]\ cw[2]\ cw[3] - 
          96\ cb[3]\ cw[2]\ cw[3] - 1.20000000000000284`\ cw[2]\^2\ cw[3] + 
          0.479999999999998649`\ cw[3]\^2 - 32\ cb[2]\ cw[3]\^2 - 
          0.0383999999999999896`\ cw[4] + 
          1.35999999999999987`\ cw[2]\ cw[4] - 12\ cw[2]\^2\ cw[4] - 
          0.399999999999999911`\ cw[3]\ cw[4] - 2\ cw[4]\^2 > 0, 
      \(0.00331776000000000026`\[InvisibleSpace]\) + 
          0.00921599999999999575`\ cb[2] + 0.387199999999999544`\ cb[2]\^2 + 
          0.960000000000001207`\ cb[2]\^3 + 24\ cb[2]\^4 - 
          0.0844800000000006612`\ cb[3] + 
          2.11199999999999921`\ cb[2]\ cb[3] - 
          28.79999999999999`\ cb[2]\^2\ cb[3] - 
          3.84000000000000376`\ cb[3]\^2 + 144\ cb[2]\ cb[3]\^2 + 
          0.116800000000001258`\ cb[4] - 5.60000000000000852`\ cb[2]\ cb[4] + 
          72\ cb[2]\^2\ cb[4] - 23.9999999999999991`\ cb[3]\ cb[4] + 
          34\ cb[4]\^2 + 0.543999999999998529`\ cb[5] - 
          9.59999999999999431`\ cb[2]\ cb[5] + 48\ cb[3]\ cb[5] - 
          0.720000000000001438`\ cb[6] + 16\ cb[2]\ cb[6] - 
          0.800000000000000177`\ cb[7] + cb[8] - 
          0.0506879999999999952`\ cw[2] - 
          0.230400000000000027`\ cb[2]\ cw[2] - 
          10.559999999999996`\ cb[2]\^2\ cw[2] + 
          2.20800000000000107`\ cb[3]\ cw[2] - 
          28.79999999999999`\ cb[2]\ cb[3]\ cw[2] + 72\ cb[3]\^2\ cw[2] - 
          4.31999999999999673`\ cb[4]\ cw[2] + 96\ cb[2]\ cb[4]\ cw[2] - 
          7.19999999999999751`\ cb[5]\ cw[2] + 12\ cb[6]\ cw[2] + 
          0.539199999999999679`\ cw[2]\^2 + 
          1.43999999999999683`\ cb[2]\ cw[2]\^2 + 72\ cb[2]\^2\ cw[2]\^2 - 
          14.399999999999995`\ cb[3]\ cw[2]\^2 + 36\ cb[4]\ cw[2]\^2 - 
          2.63999999999999879`\ cw[2]\^3 + 9\ cw[2]\^4 - 
          0.0460799999999999787`\ cw[3] + 
          0.767999999999999793`\ cb[2]\ cw[3] - 
          3.51999999999999912`\ cb[3]\ cw[3] - 
          3.20000000000000062`\ cb[4]\ cw[3] + 8\ cb[5]\ cw[3] + 
          0.351999999999998447`\ cw[2]\ cw[3] - 
          9.59999999999999431`\ cb[2]\ cw[2]\ cw[3] + 
          48\ cb[3]\ cw[2]\ cw[3] - 2.39999999999999857`\ cw[2]\^2\ cw[3] + 
          0.160000000000000586`\ cw[3]\^2 + 16\ cb[2]\ cw[3]\^2 + 
          0.115199999999999991`\ cw[4] - 
          0.879999999999999715`\ cw[2]\ cw[4] + 6\ cw[2]\^2\ cw[4] - 
          0.800000000000000177`\ cw[3]\ cw[4] + cw[4]\^2 > 0, 
      \(0.00442368000000000094`\[InvisibleSpace]\) + 
          0.0430079999999999884`\ cb[2] - 0.422399999999999486`\ cb[2]\^2 + 
          2.87999999999999278`\ cb[2]\^3 - 48\ cb[2]\^4 - 
          0.151039999999999841`\ cb[3] + 2.01600000000000356`\ cb[2]\ cb[3] - 
          14.4000000000000198`\ cb[2]\^2\ cb[3] + 
          12.4799999999999999`\ cb[3]\^2 - 288\ cb[2]\ cb[3]\^2 - 
          0.505600000000002935`\ cb[4] + 15.2000000000000001`\ cb[2]\ cb[4] - 
          144\ cb[2]\^2\ cb[4] - 11.9999999999999996`\ cb[3]\ cb[4] - 
          68\ cb[4]\^2 + 0.592000000000002213`\ cb[5] - 
          4.80000000000001136`\ cb[2]\ cb[5] - 96\ cb[3]\ cb[5] + 
          1.83999999999999772`\ cb[6] - 32\ cb[2]\ cb[6] - 
          0.399999999999999911`\ cb[7] - 2\ cb[8] - 
          0.00614399999999997259`\ cw[2] - 
          0.883200000000000073`\ cb[2]\ cw[2] + 
          16.3200000000000011`\ cb[2]\^2\ cw[2] + 
          2.54400000000000314`\ cb[3]\ cw[2] - 
          14.4000000000000198`\ cb[2]\ cb[3]\ cw[2] - 144\ cb[3]\^2\ cw[2] + 
          11.0399999999999831`\ cb[4]\ cw[2] - 192\ cb[2]\ cb[4]\ cw[2] - 
          3.60000000000000497`\ cb[5]\ cw[2] - 24\ cb[6]\ cw[2] - 
          0.326400000000000423`\ cw[2]\^2 + 
          4.3200000000000065`\ cb[2]\ cw[2]\^2 - 144\ cb[2]\^2\ cw[2]\^2 - 
          7.20000000000000994`\ cb[3]\ cw[2]\^2 - 72\ cb[4]\ cw[2]\^2 + 
          4.08000000000000007`\ cw[2]\^3 - 18\ cw[2]\^4 - 
          0.0998400000000000353`\ cw[3] + 
          1.02400000000000002`\ cb[2]\ cw[3] + 
          5.4399999999999995`\ cb[3]\ cw[3] - 
          1.59999999999999964`\ cb[4]\ cw[3] - 16\ cb[5]\ cw[3] + 
          0.336000000000002296`\ cw[2]\ cw[3] - 
          4.80000000000001136`\ cb[2]\ cw[2]\ cw[3] - 
          96\ cb[3]\ cw[2]\ cw[3] - 1.20000000000000284`\ cw[2]\^2\ cw[3] + 
          0.479999999999998649`\ cw[3]\^2 - 32\ cb[2]\ cw[3]\^2 - 
          0.0383999999999999896`\ cw[4] + 
          1.35999999999999987`\ cw[2]\ cw[4] - 12\ cw[2]\^2\ cw[4] - 
          0.399999999999999911`\ cw[3]\ cw[4] - 2\ cw[4]\^2 > 0, 
      \(0.00147456000000000013`\[InvisibleSpace]\) + 
          0.0501760000000000072`\ cb[2] + 0.115199999999999191`\ cb[2]\^2 + 
          2.16000000000000103`\ cb[2]\^3 + 24\ cb[2]\^4 + 
          0.107520000000000148`\ cb[3] - 1.72800000000000153`\ cb[2]\ cb[3] + 
          43.2000000000000028`\ cb[2]\^2\ cb[3] + 
          0.359999999999998987`\ cb[3]\^2 + 144\ cb[2]\ cb[3]\^2 - 
          0.211199999999998944`\ cb[4] - 0.5999999999999992`\ cb[2]\ cb[4] + 
          72\ cb[2]\^2\ cb[4] + 36.0000000000000008`\ cb[3]\ cb[4] + 
          34\ cb[4]\^2 - 0.736000000000000476`\ cb[5] + 
          14.4000000000000056`\ cb[2]\ cb[5] + 48\ cb[3]\ cb[5] - 
          0.119999999999999108`\ cb[6] + 16\ cb[2]\ cb[6] + 
          1.20000000000000017`\ cb[7] + cb[8] + 
          0.0184319999999999986`\ cw[2] - 
          0.806400000000000183`\ cb[2]\ cw[2] - 
          5.75999999999999801`\ cb[2]\^2\ cw[2] - 
          3.55200000000000049`\ cb[3]\ cw[2] + 
          43.2000000000000028`\ cb[2]\ cb[3]\ cw[2] + 72\ cb[3]\^2\ cw[2] - 
          0.719999999999990425`\ cb[4]\ cw[2] + 96\ cb[2]\ cb[4]\ cw[2] + 
          10.8000000000000007`\ cb[5]\ cw[2] + 12\ cb[6]\ cw[2] - 
          0.172800000000000402`\ cw[2]\^2 + 
          3.23999999999999932`\ cb[2]\ cw[2]\^2 + 72\ cb[2]\^2\ cw[2]\^2 + 
          21.6000000000000014`\ cb[3]\ cw[2]\^2 + 36\ cb[4]\ cw[2]\^2 - 
          1.4399999999999995`\ cw[2]\^3 + 9\ cw[2]\^4 - 
          0.0460799999999999965`\ cw[3] - 
          1.79199999999999963`\ cb[2]\ cw[3] - 
          1.91999999999999815`\ cb[3]\ cw[3] + 
          4.80000000000000071`\ cb[4]\ cw[3] + 8\ cb[5]\ cw[3] - 
          0.287999999999999722`\ cw[2]\ cw[3] + 
          14.4000000000000056`\ cb[2]\ cw[2]\ cw[3] + 
          48\ cb[3]\ cw[2]\ cw[3] + 3.60000000000000142`\ cw[2]\^2\ cw[3] + 
          0.360000000000000541`\ cw[3]\^2 + 16\ cb[2]\ cw[3]\^2 - 
          0.0767999999999999971`\ cw[4] - 
          0.479999999999999538`\ cw[2]\ cw[4] + 6\ cw[2]\^2\ cw[4] + 
          1.20000000000000017`\ cw[3]\ cw[4] + cw[4]\^2 > 0, 
      \(0.022394879999999997`\[InvisibleSpace]\) + 
          0.373247999999999979`\ cb[2] - 3.11039999999999761`\ cb[2]\^2 - 
          40.3199999999999825`\ cb[2]\^3 - 48\ cb[2]\^4 - 
          0.311039999999996297`\ cb[3] + 46.6559999999999597`\ cb[2]\ cb[3] + 
          273.599999999999976`\ cb[2]\^2\ cb[3] - 
          90.7199999999999739`\ cb[3]\^2 - 288\ cb[2]\ cb[3]\^2 - 
          2.93760000000000367`\ cb[4] - 100.800000000000045`\ cb[2]\ cb[4] - 
          144\ cb[2]\^2\ cb[4] + 228.000000000000024`\ cb[3]\ cb[4] - 
          68\ cb[4]\^2 + 9.0720000000000045`\ cb[5] + 
          91.1999999999999921`\ cb[2]\ cb[5] - 96\ cb[3]\ cb[5] - 
          11.7600000000000015`\ cb[6] - 32\ cb[2]\ cb[6] + 
          7.60000000000000053`\ cb[7] - 2\ cb[8] + 
          0.279935999999999918`\ cw[2] - 4.14719999999999977`\ cb[2]\ cw[2] - 
          60.4799999999999826`\ cb[2]\^2\ cw[2] + 
          31.1039999999999672`\ cb[3]\ cw[2] + 
          273.599999999999976`\ cb[2]\ cb[3]\ cw[2] - 144\ cb[3]\^2\ cw[2] - 
          70.5599999999999916`\ cb[4]\ cw[2] - 192\ cb[2]\ cb[4]\ cw[2] + 
          68.3999999999999896`\ cb[5]\ cw[2] - 24\ cb[6]\ cw[2] - 
          1.81440000000000054`\ cw[2]\^2 - 
          60.4800000000000093`\ cb[2]\ cw[2]\^2 - 144\ cb[2]\^2\ cw[2]\^2 + 
          136.799999999999988`\ cb[3]\ cw[2]\^2 - 72\ cb[4]\ cw[2]\^2 - 
          15.1199999999999956`\ cw[2]\^3 - 18\ cw[2]\^4 - 
          0.0518399999999999927`\ cw[3] + 
          5.18400000000000016`\ cb[2]\ cw[3] - 
          20.1599999999999912`\ cb[3]\ cw[3] + 
          30.4000000000000003`\ cb[4]\ cw[3] - 16\ cb[5]\ cw[3] + 
          7.77600000000000335`\ cw[2]\ cw[3] + 
          91.1999999999999921`\ cb[2]\ cw[2]\ cw[3] - 
          96\ cb[3]\ cw[2]\ cw[3] + 22.799999999999998`\ cw[2]\^2\ cw[3] - 
          6.71999999999999708`\ cw[3]\^2 - 32\ cb[2]\ cw[3]\^2 - 
          0.0864000000000000056`\ cw[4] - 
          5.03999999999999737`\ cw[2]\ cw[4] - 12\ cw[2]\^2\ cw[4] + 
          7.60000000000000053`\ cw[3]\ cw[4] - 2\ cw[4]\^2 > 0, 
      \(0.0298598399999999983`\[InvisibleSpace]\) - 
          0.0725759999999997695`\ cb[2] - 3.28320000000000078`\ cb[2]\^2 + 
          35.04`\ cb[2]\^3 + 96\ cb[2]\^4 + 1.48607999999999851`\ cb[3] - 
          9.7919999999999252`\ cb[2]\ cb[3] - 
          403.199999999999914`\ cb[2]\^2\ cb[3] + 
          81.8399999999999749`\ cb[3]\^2 + 576\ cb[2]\ cb[3]\^2 - 
          2.6208000000000009`\ cb[4] + 91.5999999999999658`\ cb[2]\ cb[4] + 
          288\ cb[2]\^2\ cb[4] - 336.000000000000031`\ cb[3]\ cb[4] + 
          136\ cb[4]\^2 - 2.30400000000000249`\ cb[5] - 
          134.40000000000003`\ cb[2]\ cb[5] + 192\ cb[3]\ cb[5] + 
          10.7199999999999939`\ cb[6] + 64\ cb[2]\ cb[6] - 
          11.200000000000001`\ cb[7] + 4\ cb[8] + 
          0.0103680000000000704`\ cw[2] - 
          2.93760000000000243`\ cb[2]\ cw[2] + 
          58.5599999999999987`\ cb[2]\^2\ cw[2] - 
          8.92799999999995819`\ cb[3]\ cw[2] - 
          403.199999999999914`\ cb[2]\ cb[3]\ cw[2] + 288\ cb[3]\^2\ cw[2] + 
          64.3200000000000038`\ cb[4]\ cw[2] + 384\ cb[2]\ cb[4]\ cw[2] - 
          100.799999999999978`\ cb[5]\ cw[2] + 48\ cb[6]\ cw[2] - 
          1.5552000000000012`\ cw[2]\^2 + 
          52.5600000000000022`\ cb[2]\ cw[2]\^2 + 288\ cb[2]\^2\ cw[2]\^2 - 
          201.599999999999957`\ cb[3]\ cw[2]\^2 + 144\ cb[4]\ cw[2]\^2 + 
          14.6399999999999996`\ cw[2]\^3 + 36\ cw[2]\^4 + 
          0.103679999999999994`\ cw[3] - 2.68800000000000061`\ cb[2]\ cw[3] + 
          19.519999999999996`\ cb[3]\ cw[3] - 
          44.8000000000000042`\ cb[4]\ cw[3] + 32\ cb[5]\ cw[3] - 
          1.63200000000000278`\ cw[2]\ cw[3] - 
          134.40000000000003`\ cb[2]\ cw[2]\ cw[3] + 
          192\ cb[3]\ cw[2]\ cw[3] - 33.6000000000000076`\ cw[2]\^2\ cw[3] + 
          5.83999999999999985`\ cw[3]\^2 + 64\ cb[2]\ cw[3]\^2 + 
          0.0287999999999999367`\ cw[4] + 4.879999999999999`\ cw[2]\ cw[4] + 
          24\ cw[2]\^2\ cw[4] - 11.200000000000001`\ cw[3]\ cw[4] + 
          4\ cw[4]\^2 > 0, 
      \(0.00995328000000000301`\[InvisibleSpace]\) - 
          0.0414720000000000332`\ cb[2] + 0.633599999999999408`\ cb[2]\^2 - 
          6.72000000000000596`\ cb[2]\^3 - 48\ cb[2]\^4 + 
          0.120960000000001532`\ cb[3] - 5.6640000000000219`\ cb[2]\ cb[3] + 
          129.599999999999981`\ cb[2]\^2\ cb[3] - 
          9.11999999999998323`\ cb[3]\^2 - 288\ cb[2]\ cb[3]\^2 + 
          0.758400000000001295`\ cb[4] - 8.79999999999995452`\ cb[2]\ cb[4] - 
          144\ cb[2]\^2\ cb[4] + 108.000000000000007`\ cb[3]\ cb[4] - 
          68\ cb[4]\^2 - 1.56799999999999872`\ cb[5] + 
          43.199999999999985`\ cb[2]\ cb[5] - 96\ cb[3]\ cb[5] - 
          0.959999999999995168`\ cb[6] - 32\ cb[2]\ cb[6] + 
          3.59999999999999964`\ cb[7] - 2\ cb[8] - 
          0.11750400000000003`\ cw[2] + 1.32479999999999775`\ cb[2]\ cw[2] + 
          1.91999999999999637`\ cb[2]\^2\ cw[2] - 
          6.57600000000001383`\ cb[3]\ cw[2] + 
          129.599999999999981`\ cb[2]\ cb[3]\ cw[2] - 144\ cb[3]\^2\ cw[2] - 
          5.7599999999999909`\ cb[4]\ cw[2] - 192\ cb[2]\ cb[4]\ cw[2] + 
          32.3999999999999932`\ cb[5]\ cw[2] - 24\ cb[6]\ cw[2] + 
          0.489599999999999457`\ cw[2]\^2 - 
          10.0799999999999978`\ cb[2]\ cw[2]\^2 - 144\ cb[2]\^2\ cw[2]\^2 + 
          64.7999999999999864`\ cb[3]\ cw[2]\^2 - 72\ cb[4]\ cw[2]\^2 + 
          0.479999999999999094`\ cw[2]\^3 - 18\ cw[2]\^4 + 
          0.0921600000000000108`\ cw[3] - 
          2.49600000000000044`\ cb[2]\ cw[3] + 
          0.639999999999998792`\ cb[3]\ cw[3] + 
          14.3999999999999994`\ cb[4]\ cw[3] - 16\ cb[5]\ cw[3] - 
          0.94399999999999995`\ cw[2]\ cw[3] + 
          43.199999999999985`\ cb[2]\ cw[2]\ cw[3] - 
          96\ cb[3]\ cw[2]\ cw[3] + 10.7999999999999962`\ cw[2]\^2\ cw[3] - 
          1.1200000000000001`\ cw[3]\^2 - 32\ cb[2]\ cw[3]\^2 + 
          0.0576000000000000067`\ cw[4] + 
          0.159999999999999698`\ cw[2]\ cw[4] - 12\ cw[2]\^2\ cw[4] + 
          3.59999999999999964`\ cw[3]\ cw[4] - 2\ cw[4]\^2 > 0, 
      \(0.0298598399999999983`\[InvisibleSpace]\) - 
          0.0725759999999997695`\ cb[2] - 3.28320000000000078`\ cb[2]\^2 + 
          35.04`\ cb[2]\^3 + 96\ cb[2]\^4 + 1.48607999999999869`\ cb[3] - 
          9.7919999999999252`\ cb[2]\ cb[3] - 
          403.199999999999914`\ cb[2]\^2\ cb[3] + 
          81.8399999999999749`\ cb[3]\^2 + 576\ cb[2]\ cb[3]\^2 - 
          2.6208000000000009`\ cb[4] + 91.5999999999999658`\ cb[2]\ cb[4] + 
          288\ cb[2]\^2\ cb[4] - 336.000000000000031`\ cb[3]\ cb[4] + 
          136\ cb[4]\^2 - 2.30400000000000249`\ cb[5] - 
          134.40000000000003`\ cb[2]\ cb[5] + 192\ cb[3]\ cb[5] + 
          10.7199999999999939`\ cb[6] + 64\ cb[2]\ cb[6] - 
          11.200000000000001`\ cb[7] + 4\ cb[8] + 
          0.0103680000000002103`\ cw[2] - 
          2.93760000000000243`\ cb[2]\ cw[2] + 
          58.5599999999999898`\ cb[2]\^2\ cw[2] - 
          8.92799999999995819`\ cb[3]\ cw[2] - 
          403.199999999999914`\ cb[2]\ cb[3]\ cw[2] + 288\ cb[3]\^2\ cw[2] + 
          64.3200000000000038`\ cb[4]\ cw[2] + 384\ cb[2]\ cb[4]\ cw[2] - 
          100.799999999999978`\ cb[5]\ cw[2] + 48\ cb[6]\ cw[2] - 
          1.5552000000000012`\ cw[2]\^2 + 
          52.5600000000000022`\ cb[2]\ cw[2]\^2 + 288\ cb[2]\^2\ cw[2]\^2 - 
          201.599999999999957`\ cb[3]\ cw[2]\^2 + 144\ cb[4]\ cw[2]\^2 + 
          14.639999999999997`\ cw[2]\^3 + 36\ cw[2]\^4 + 
          0.103679999999999994`\ cw[3] - 2.68800000000000061`\ cb[2]\ cw[3] + 
          19.519999999999996`\ cb[3]\ cw[3] - 
          44.8000000000000042`\ cb[4]\ cw[3] + 32\ cb[5]\ cw[3] - 
          1.63200000000000278`\ cw[2]\ cw[3] - 
          134.40000000000003`\ cb[2]\ cw[2]\ cw[3] + 
          192\ cb[3]\ cw[2]\ cw[3] - 33.6000000000000076`\ cw[2]\^2\ cw[3] + 
          5.83999999999999985`\ cw[3]\^2 + 64\ cb[2]\ cw[3]\^2 + 
          0.02879999999999999`\ cw[4] + 4.879999999999999`\ cw[2]\ cw[4] + 
          24\ cw[2]\^2\ cw[4] - 11.200000000000001`\ cw[3]\ cw[4] + 
          4\ cw[4]\^2 > 0, 
      \(0.0398131200000000085`\[InvisibleSpace]\) - 
          0.51148800000000012`\ cb[2] + 3.97439999999999891`\ cb[2]\^2 - 
          2.88000000000001321`\ cb[2]\^3 - 192\ cb[2]\^4 + 
          0.915840000000005716`\ cb[3] - 39.4560000000000865`\ cb[2]\ cb[3] + 
          518.399999999999749`\ cb[2]\^2\ cb[3] - 
          24.4799999999999418`\ cb[3]\^2 - 1152\ cb[2]\ cb[3]\^2 + 
          3.27360000000000361`\ cb[4] - 31.1999999999998456`\ cb[2]\ cb[4] - 
          576\ cb[2]\^2\ cb[4] + 432.000000000000028`\ cb[3]\ cb[4] - 
          272\ cb[4]\^2 - 6.27199999999999491`\ cb[5] + 
          172.799999999999931`\ cb[2]\ cb[5] - 384\ cb[3]\ cb[5] - 
          3.8399999999999812`\ cb[6] - 128\ cb[2]\ cb[6] + 
          14.4000000000000021`\ cb[7] - 8\ cb[8] - 
          0.124416000000000037`\ cw[2] + 3.85919999999999152`\ cb[2]\ cw[2] - 
          40.3200000000000091`\ cb[2]\^2\ cw[2] - 
          17.9040000000000665`\ cb[3]\ cw[2] + 
          518.399999999999749`\ cb[2]\ cb[3]\ cw[2] - 576\ cb[3]\^2\ cw[2] - 
          23.0399999999999716`\ cb[4]\ cw[2] - 768\ cb[2]\ cb[4]\ cw[2] + 
          129.599999999999937`\ cb[5]\ cw[2] - 96\ cb[6]\ cw[2] + 
          1.95839999999999765`\ cw[2]\^2 - 
          4.31999999999999317`\ cb[2]\ cw[2]\^2 - 576\ cb[2]\^2\ cw[2]\^2 + 
          259.199999999999874`\ cb[3]\ cw[2]\^2 - 288\ cb[4]\ cw[2]\^2 - 
          10.0800000000000022`\ cw[2]\^3 - 72\ cw[2]\^4 - 
          0.0633599999999999141`\ cw[3] + 1.2159999999999993`\ cb[2]\ cw[3] - 
          13.4400000000000008`\ cb[3]\ cw[3] + 
          57.6000000000000067`\ cb[4]\ cw[3] - 64\ cb[5]\ cw[3] - 
          6.57599999999999695`\ cw[2]\ cw[3] + 
          172.799999999999931`\ cb[2]\ cw[2]\ cw[3] - 
          384\ cb[3]\ cw[2]\ cw[3] + 43.199999999999985`\ cw[2]\^2\ cw[3] - 
          0.480000000000000426`\ cw[3]\^2 - 128\ cb[2]\ cw[3]\^2 - 
          0.00959999999999999786`\ cw[4] - 
          3.36000000000000031`\ cw[2]\ cw[4] - 48\ cw[2]\^2\ cw[4] + 
          14.4000000000000021`\ cw[3]\ cw[4] - 8\ cw[4]\^2 > 0, 
      \(0.0132710400000000006`\[InvisibleSpace]\) - 
          0.0783359999999999612`\ cb[2] + 0.42879999999999816`\ cb[2]\^2 - 
          8.15999999999998593`\ cb[2]\^3 + 96\ cb[2]\^4 - 
          0.433920000000002747`\ cb[3] + 10.8479999999999975`\ cb[2]\ cb[3] - 
          115.199999999999969`\ cb[2]\^2\ cb[3] - 
          21.36000000000001`\ cb[3]\^2 + 576\ cb[2]\ cb[3]\^2 + 
          0.947200000000004749`\ cb[4] - 24.4000000000000305`\ cb[2]\ cb[4] + 
          288\ cb[2]\^2\ cb[4] - 95.9999999999999964`\ cb[3]\ cb[4] + 
          136\ cb[4]\^2 + 2.17599999999999393`\ cb[5] - 
          38.3999999999999772`\ cb[2]\ cb[5] + 192\ cb[3]\ cb[5] - 
          2.88000000000000575`\ cb[6] + 64\ cb[2]\ cb[6] - 
          3.20000000000000062`\ cb[7] + 4\ cb[8] - 
          0.0875519999999999853`\ cw[2] + 
          2.19840000000000035`\ cb[2]\ cw[2] - 
          18.2399999999999806`\ cb[2]\^2\ cw[2] + 
          7.63200000000000589`\ cb[3]\ cw[2] - 
          115.199999999999969`\ cb[2]\ cb[3]\ cw[2] + 288\ cb[3]\^2\ cw[2] - 
          17.2799999999999869`\ cb[4]\ cw[2] + 384\ cb[2]\ cb[4]\ cw[2] - 
          28.79999999999999`\ cb[5]\ cw[2] + 48\ cb[6]\ cw[2] + 
          0.156800000000000716`\ cw[2]\^2 - 
          12.2399999999999975`\ cb[2]\ cw[2]\^2 + 288\ cb[2]\^2\ cw[2]\^2 - 
          57.5999999999999801`\ cb[3]\ cw[2]\^2 + 144\ cb[4]\ cw[2]\^2 - 
          4.55999999999999516`\ cw[2]\^3 + 36\ cw[2]\^4 - 
          0.088319999999999954`\ cw[3] + 1.47199999999999908`\ cb[2]\ cw[3] - 
          6.07999999999999563`\ cb[3]\ cw[3] - 
          12.8000000000000024`\ cb[4]\ cw[3] + 32\ cb[5]\ cw[3] + 
          1.80799999999999378`\ cw[2]\ cw[3] - 
          38.3999999999999772`\ cb[2]\ cw[2]\ cw[3] + 
          192\ cb[3]\ cw[2]\ cw[3] - 9.59999999999999431`\ cw[2]\^2\ cw[3] - 
          1.3599999999999992`\ cw[3]\^2 + 64\ cb[2]\ cw[3]\^2 - 
          0.0192000000000000206`\ cw[4] - 
          1.51999999999999886`\ cw[2]\ cw[4] + 24\ cw[2]\^2\ cw[4] - 
          3.20000000000000062`\ cw[3]\ cw[4] + 4\ cw[4]\^2 > 0, 
      \(0.00995327999999999946`\[InvisibleSpace]\) - 
          0.041472000000000051`\ cb[2] + 0.633599999999999052`\ cb[2]\^2 - 
          6.72000000000000596`\ cb[2]\^3 - 48\ cb[2]\^4 + 
          0.120960000000001532`\ cb[3] - 5.6640000000000219`\ cb[2]\ cb[3] + 
          129.599999999999981`\ cb[2]\^2\ cb[3] - 
          9.11999999999998323`\ cb[3]\^2 - 288\ cb[2]\ cb[3]\^2 + 
          0.758400000000000851`\ cb[4] - 8.79999999999995452`\ cb[2]\ cb[4] - 
          144\ cb[2]\^2\ cb[4] + 108.000000000000007`\ cb[3]\ cb[4] - 
          68\ cb[4]\^2 - 1.56799999999999872`\ cb[5] + 
          43.199999999999985`\ cb[2]\ cb[5] - 96\ cb[3]\ cb[5] - 
          0.959999999999995168`\ cb[6] - 32\ cb[2]\ cb[6] + 
          3.59999999999999964`\ cb[7] - 2\ cb[8] - 
          0.117504000000000008`\ cw[2] + 1.32479999999999775`\ cb[2]\ cw[2] + 
          1.91999999999999992`\ cb[2]\^2\ cw[2] - 
          6.57600000000001738`\ cb[3]\ cw[2] + 
          129.599999999999981`\ cb[2]\ cb[3]\ cw[2] - 144\ cb[3]\^2\ cw[2] - 
          5.7599999999999909`\ cb[4]\ cw[2] - 192\ cb[2]\ cb[4]\ cw[2] + 
          32.3999999999999932`\ cb[5]\ cw[2] - 24\ cb[6]\ cw[2] + 
          0.489599999999999013`\ cw[2]\^2 - 
          10.0799999999999978`\ cb[2]\ cw[2]\^2 - 144\ cb[2]\^2\ cw[2]\^2 + 
          64.7999999999999864`\ cb[3]\ cw[2]\^2 - 72\ cb[4]\ cw[2]\^2 + 
          0.479999999999999982`\ cw[2]\^3 - 18\ cw[2]\^4 + 
          0.0921600000000000108`\ cw[3] - 
          2.49600000000000044`\ cb[2]\ cw[3] + 
          0.639999999999998792`\ cb[3]\ cw[3] + 
          14.3999999999999994`\ cb[4]\ cw[3] - 16\ cb[5]\ cw[3] - 
          0.94399999999999995`\ cw[2]\ cw[3] + 
          43.199999999999985`\ cb[2]\ cw[2]\ cw[3] - 
          96\ cb[3]\ cw[2]\ cw[3] + 10.7999999999999962`\ cw[2]\^2\ cw[3] - 
          1.1200000000000001`\ cw[3]\^2 - 32\ cb[2]\ cw[3]\^2 + 
          0.0575999999999999801`\ cw[4] + 
          0.159999999999999698`\ cw[2]\ cw[4] - 12\ cw[2]\^2\ cw[4] + 
          3.59999999999999964`\ cw[3]\ cw[4] - 2\ cw[4]\^2 > 0, 
      \(0.0132710400000000006`\[InvisibleSpace]\) - 
          0.0783359999999999612`\ cb[2] + 0.42879999999999816`\ cb[2]\^2 - 
          8.15999999999998593`\ cb[2]\^3 + 96\ cb[2]\^4 - 
          0.433920000000002747`\ cb[3] + 10.8479999999999909`\ cb[2]\ cb[3] - 
          115.199999999999969`\ cb[2]\^2\ cb[3] - 
          21.36000000000001`\ cb[3]\^2 + 576\ cb[2]\ cb[3]\^2 + 
          0.947200000000004749`\ cb[4] - 24.4000000000000305`\ cb[2]\ cb[4] + 
          288\ cb[2]\^2\ cb[4] - 95.9999999999999964`\ cb[3]\ cb[4] + 
          136\ cb[4]\^2 + 2.17599999999999393`\ cb[5] - 
          38.3999999999999772`\ cb[2]\ cb[5] + 192\ cb[3]\ cb[5] - 
          2.88000000000000575`\ cb[6] + 64\ cb[2]\ cb[6] - 
          3.20000000000000062`\ cb[7] + 4\ cb[8] - 
          0.0875519999999999853`\ cw[2] + 
          2.19840000000000124`\ cb[2]\ cw[2] - 
          18.2399999999999806`\ cb[2]\^2\ cw[2] + 
          7.63200000000000677`\ cb[3]\ cw[2] - 
          115.199999999999969`\ cb[2]\ cb[3]\ cw[2] + 288\ cb[3]\^2\ cw[2] - 
          17.2799999999999869`\ cb[4]\ cw[2] + 384\ cb[2]\ cb[4]\ cw[2] - 
          28.79999999999999`\ cb[5]\ cw[2] + 48\ cb[6]\ cw[2] + 
          0.156800000000000494`\ cw[2]\^2 - 
          12.2399999999999975`\ cb[2]\ cw[2]\^2 + 288\ cb[2]\^2\ cw[2]\^2 - 
          57.5999999999999801`\ cb[3]\ cw[2]\^2 + 144\ cb[4]\ cw[2]\^2 - 
          4.55999999999999516`\ cw[2]\^3 + 36\ cw[2]\^4 - 
          0.088319999999999954`\ cw[3] + 1.47199999999999908`\ cb[2]\ cw[3] - 
          6.07999999999999563`\ cb[3]\ cw[3] - 
          12.8000000000000024`\ cb[4]\ cw[3] + 32\ cb[5]\ cw[3] + 
          1.80799999999999378`\ cw[2]\ cw[3] - 
          38.3999999999999772`\ cb[2]\ cw[2]\ cw[3] + 
          192\ cb[3]\ cw[2]\ cw[3] - 9.59999999999999431`\ cw[2]\^2\ cw[3] - 
          1.3599999999999992`\ cw[3]\^2 + 64\ cb[2]\ cw[3]\^2 - 
          0.0191999999999999957`\ cw[4] - 
          1.51999999999999886`\ cw[2]\ cw[4] + 24\ cw[2]\^2\ cw[4] - 
          3.20000000000000062`\ cw[3]\ cw[4] + 4\ cw[4]\^2 > 0, 
      \(0.00442368000000000094`\[InvisibleSpace]\) + 
          0.0430080000000000151`\ cb[2] - 0.422399999999999664`\ cb[2]\^2 + 
          2.87999999999999278`\ cb[2]\^3 - 48\ cb[2]\^4 - 
          0.151039999999999619`\ cb[3] + 2.01599999999999468`\ cb[2]\ cb[3] - 
          14.4000000000000198`\ cb[2]\^2\ cb[3] + 
          12.4799999999999999`\ cb[3]\^2 - 288\ cb[2]\ cb[3]\^2 - 
          0.505600000000003113`\ cb[4] + 15.2000000000000001`\ cb[2]\ cb[4] - 
          144\ cb[2]\^2\ cb[4] - 11.9999999999999996`\ cb[3]\ cb[4] - 
          68\ cb[4]\^2 + 0.592000000000002213`\ cb[5] - 
          4.80000000000001136`\ cb[2]\ cb[5] - 96\ cb[3]\ cb[5] + 
          1.83999999999999772`\ cb[6] - 32\ cb[2]\ cb[6] - 
          0.399999999999999911`\ cb[7] - 2\ cb[8] - 
          0.00614399999999997259`\ cw[2] - 
          0.883200000000000251`\ cb[2]\ cw[2] + 
          16.3199999999999967`\ cb[2]\^2\ cw[2] + 
          2.5440000000000067`\ cb[3]\ cw[2] - 
          14.4000000000000198`\ cb[2]\ cb[3]\ cw[2] - 144\ cb[3]\^2\ cw[2] + 
          11.0399999999999831`\ cb[4]\ cw[2] - 192\ cb[2]\ cb[4]\ cw[2] - 
          3.60000000000000497`\ cb[5]\ cw[2] - 24\ cb[6]\ cw[2] - 
          0.326400000000000556`\ cw[2]\^2 + 
          4.3200000000000065`\ cb[2]\ cw[2]\^2 - 144\ cb[2]\^2\ cw[2]\^2 - 
          7.20000000000000994`\ cb[3]\ cw[2]\^2 - 72\ cb[4]\ cw[2]\^2 + 
          4.07999999999999918`\ cw[2]\^3 - 18\ cw[2]\^4 - 
          0.0998399999999999998`\ cw[3] + 
          1.02400000000000002`\ cb[2]\ cw[3] + 
          5.4399999999999995`\ cb[3]\ cw[3] - 
          1.59999999999999964`\ cb[4]\ cw[3] - 16\ cb[5]\ cw[3] + 
          0.33600000000000243`\ cw[2]\ cw[3] - 
          4.80000000000001136`\ cb[2]\ cw[2]\ cw[3] - 
          96\ cb[3]\ cw[2]\ cw[3] - 1.20000000000000284`\ cw[2]\^2\ cw[3] + 
          0.479999999999998649`\ cw[3]\^2 - 32\ cb[2]\ cw[3]\^2 - 
          0.0383999999999999896`\ cw[4] + 
          1.35999999999999987`\ cw[2]\ cw[4] - 12\ cw[2]\^2\ cw[4] - 
          0.399999999999999911`\ cw[3]\ cw[4] - 2\ cw[4]\^2 > 0, 
      \(0.0298598399999999983`\[InvisibleSpace]\) - 
          0.0725759999999997695`\ cb[2] - 3.28320000000000078`\ cb[2]\^2 + 
          35.04`\ cb[2]\^3 + 96\ cb[2]\^4 + 1.48607999999999869`\ cb[3] - 
          9.7919999999999252`\ cb[2]\ cb[3] - 
          403.199999999999914`\ cb[2]\^2\ cb[3] + 
          81.8399999999999749`\ cb[3]\^2 + 576\ cb[2]\ cb[3]\^2 - 
          2.6208000000000009`\ cb[4] + 91.5999999999999658`\ cb[2]\ cb[4] + 
          288\ cb[2]\^2\ cb[4] - 336.000000000000031`\ cb[3]\ cb[4] + 
          136\ cb[4]\^2 - 2.30400000000000249`\ cb[5] - 
          134.40000000000003`\ cb[2]\ cb[5] + 192\ cb[3]\ cb[5] + 
          10.7199999999999939`\ cb[6] + 64\ cb[2]\ cb[6] - 
          11.200000000000001`\ cb[7] + 4\ cb[8] + 
          0.0103680000000002103`\ cw[2] - 
          2.93760000000000243`\ cb[2]\ cw[2] + 
          58.5599999999999898`\ cb[2]\^2\ cw[2] - 
          8.92799999999995819`\ cb[3]\ cw[2] - 
          403.199999999999914`\ cb[2]\ cb[3]\ cw[2] + 288\ cb[3]\^2\ cw[2] + 
          64.3200000000000038`\ cb[4]\ cw[2] + 384\ cb[2]\ cb[4]\ cw[2] - 
          100.799999999999978`\ cb[5]\ cw[2] + 48\ cb[6]\ cw[2] - 
          1.5552000000000012`\ cw[2]\^2 + 
          52.5600000000000022`\ cb[2]\ cw[2]\^2 + 288\ cb[2]\^2\ cw[2]\^2 - 
          201.599999999999957`\ cb[3]\ cw[2]\^2 + 144\ cb[4]\ cw[2]\^2 + 
          14.639999999999997`\ cw[2]\^3 + 36\ cw[2]\^4 + 
          0.103679999999999994`\ cw[3] - 2.68800000000000061`\ cb[2]\ cw[3] + 
          19.519999999999996`\ cb[3]\ cw[3] - 
          44.8000000000000042`\ cb[4]\ cw[3] + 32\ cb[5]\ cw[3] - 
          1.63200000000000278`\ cw[2]\ cw[3] - 
          134.40000000000003`\ cb[2]\ cw[2]\ cw[3] + 
          192\ cb[3]\ cw[2]\ cw[3] - 33.6000000000000076`\ cw[2]\^2\ cw[3] + 
          5.83999999999999985`\ cw[3]\^2 + 64\ cb[2]\ cw[3]\^2 + 
          0.0288000000000000468`\ cw[4] + 4.879999999999999`\ cw[2]\ cw[4] + 
          24\ cw[2]\^2\ cw[4] - 11.200000000000001`\ cw[3]\ cw[4] + 
          4\ cw[4]\^2 > 0, 
      \(0.0398131200000000085`\[InvisibleSpace]\) - 
          0.511488000000000031`\ cb[2] + 3.97439999999999784`\ cb[2]\^2 - 
          2.88000000000001321`\ cb[2]\^3 - 192\ cb[2]\^4 + 
          0.915840000000005716`\ cb[3] - 39.4560000000000865`\ cb[2]\ cb[3] + 
          518.399999999999749`\ cb[2]\^2\ cb[3] - 
          24.4799999999999418`\ cb[3]\^2 - 1152\ cb[2]\ cb[3]\^2 + 
          3.27360000000000361`\ cb[4] - 31.1999999999998456`\ cb[2]\ cb[4] - 
          576\ cb[2]\^2\ cb[4] + 432.000000000000028`\ cb[3]\ cb[4] - 
          272\ cb[4]\^2 - 6.27199999999999491`\ cb[5] + 
          172.799999999999931`\ cb[2]\ cb[5] - 384\ cb[3]\ cb[5] - 
          3.8399999999999812`\ cb[6] - 128\ cb[2]\ cb[6] + 
          14.4000000000000021`\ cb[7] - 8\ cb[8] - 
          0.124415999999999904`\ cw[2] + 3.85919999999999241`\ cb[2]\ cw[2] - 
          40.3200000000000091`\ cb[2]\^2\ cw[2] - 
          17.9040000000000665`\ cb[3]\ cw[2] + 
          518.399999999999749`\ cb[2]\ cb[3]\ cw[2] - 576\ cb[3]\^2\ cw[2] - 
          23.0399999999999671`\ cb[4]\ cw[2] - 768\ cb[2]\ cb[4]\ cw[2] + 
          129.599999999999937`\ cb[5]\ cw[2] - 96\ cb[6]\ cw[2] + 
          1.95839999999999729`\ cw[2]\^2 - 
          4.31999999999999317`\ cb[2]\ cw[2]\^2 - 576\ cb[2]\^2\ cw[2]\^2 + 
          259.199999999999874`\ cb[3]\ cw[2]\^2 - 288\ cb[4]\ cw[2]\^2 - 
          10.0800000000000022`\ cw[2]\^3 - 72\ cw[2]\^4 - 
          0.0633599999999999141`\ cw[3] + 1.2159999999999993`\ cb[2]\ cw[3] - 
          13.4400000000000008`\ cb[3]\ cw[3] + 
          57.6000000000000067`\ cb[4]\ cw[3] - 64\ cb[5]\ cw[3] - 
          6.57599999999999695`\ cw[2]\ cw[3] + 
          172.799999999999931`\ cb[2]\ cw[2]\ cw[3] - 
          384\ cb[3]\ cw[2]\ cw[3] + 43.199999999999985`\ cw[2]\^2\ cw[3] - 
          0.480000000000000426`\ cw[3]\^2 - 128\ cb[2]\ cw[3]\^2 - 
          0.00959999999999998365`\ cw[4] - 
          3.36000000000000031`\ cw[2]\ cw[4] - 48\ cw[2]\^2\ cw[4] + 
          14.4000000000000021`\ cw[3]\ cw[4] - 8\ cw[4]\^2 > 0, 
      \(0.0132710400000000006`\[InvisibleSpace]\) - 
          0.0783359999999999612`\ cb[2] + 0.428799999999999048`\ cb[2]\^2 - 
          8.15999999999998593`\ cb[2]\^3 + 96\ cb[2]\^4 - 
          0.433920000000002747`\ cb[3] + 10.8479999999999975`\ cb[2]\ cb[3] - 
          115.199999999999969`\ cb[2]\^2\ cb[3] - 
          21.36000000000001`\ cb[3]\^2 + 576\ cb[2]\ cb[3]\^2 + 
          0.947200000000004749`\ cb[4] - 24.4000000000000305`\ cb[2]\ cb[4] + 
          288\ cb[2]\^2\ cb[4] - 95.9999999999999964`\ cb[3]\ cb[4] + 
          136\ cb[4]\^2 + 2.17599999999999393`\ cb[5] - 
          38.3999999999999772`\ cb[2]\ cb[5] + 192\ cb[3]\ cb[5] - 
          2.88000000000000575`\ cb[6] + 64\ cb[2]\ cb[6] - 
          3.20000000000000062`\ cb[7] + 4\ cb[8] - 
          0.0875519999999999853`\ cw[2] + 
          2.19840000000000035`\ cb[2]\ cw[2] - 
          18.2399999999999806`\ cb[2]\^2\ cw[2] + 
          7.63200000000000233`\ cb[3]\ cw[2] - 
          115.199999999999969`\ cb[2]\ cb[3]\ cw[2] + 288\ cb[3]\^2\ cw[2] - 
          17.2799999999999869`\ cb[4]\ cw[2] + 384\ cb[2]\ cb[4]\ cw[2] - 
          28.79999999999999`\ cb[5]\ cw[2] + 48\ cb[6]\ cw[2] + 
          0.156800000000000716`\ cw[2]\^2 - 
          12.2399999999999975`\ cb[2]\ cw[2]\^2 + 288\ cb[2]\^2\ cw[2]\^2 - 
          57.5999999999999801`\ cb[3]\ cw[2]\^2 + 144\ cb[4]\ cw[2]\^2 - 
          4.55999999999999516`\ cw[2]\^3 + 36\ cw[2]\^4 - 
          0.088319999999999954`\ cw[3] + 1.47199999999999908`\ cb[2]\ cw[3] - 
          6.07999999999999563`\ cb[3]\ cw[3] - 
          12.8000000000000024`\ cb[4]\ cw[3] + 32\ cb[5]\ cw[3] + 
          1.80799999999999378`\ cw[2]\ cw[3] - 
          38.3999999999999772`\ cb[2]\ cw[2]\ cw[3] + 
          192\ cb[3]\ cw[2]\ cw[3] - 9.59999999999999431`\ cw[2]\^2\ cw[3] - 
          1.3599999999999992`\ cw[3]\^2 + 64\ cb[2]\ cw[3]\^2 - 
          0.0192000000000000508`\ cw[4] - 
          1.51999999999999886`\ cw[2]\ cw[4] + 24\ cw[2]\^2\ cw[4] - 
          3.20000000000000062`\ cw[3]\ cw[4] + 4\ cw[4]\^2 > 0, 
      \(0.0398131199999999996`\[InvisibleSpace]\) - 
          0.511488000000000031`\ cb[2] + 3.97439999999999749`\ cb[2]\^2 - 
          2.88000000000001321`\ cb[2]\^3 - 192\ cb[2]\^4 + 
          0.915840000000005716`\ cb[3] - 39.4560000000000865`\ cb[2]\ cb[3] + 
          518.399999999999749`\ cb[2]\^2\ cb[3] - 
          24.4799999999999418`\ cb[3]\^2 - 1152\ cb[2]\ cb[3]\^2 + 
          3.27360000000000361`\ cb[4] - 31.1999999999998456`\ cb[2]\ cb[4] - 
          576\ cb[2]\^2\ cb[4] + 432.000000000000028`\ cb[3]\ cb[4] - 
          272\ cb[4]\^2 - 6.27199999999999491`\ cb[5] + 
          172.799999999999931`\ cb[2]\ cb[5] - 384\ cb[3]\ cb[5] - 
          3.8399999999999812`\ cb[6] - 128\ cb[2]\ cb[6] + 
          14.4000000000000021`\ cb[7] - 8\ cb[8] - 
          0.124416000000000059`\ cw[2] + 3.85919999999999241`\ cb[2]\ cw[2] - 
          40.3200000000000091`\ cb[2]\^2\ cw[2] - 
          17.9040000000000665`\ cb[3]\ cw[2] + 
          518.399999999999749`\ cb[2]\ cb[3]\ cw[2] - 576\ cb[3]\^2\ cw[2] - 
          23.0399999999999627`\ cb[4]\ cw[2] - 768\ cb[2]\ cb[4]\ cw[2] + 
          129.599999999999937`\ cb[5]\ cw[2] - 96\ cb[6]\ cw[2] + 
          1.95839999999999658`\ cw[2]\^2 - 
          4.31999999999999317`\ cb[2]\ cw[2]\^2 - 576\ cb[2]\^2\ cw[2]\^2 + 
          259.199999999999874`\ cb[3]\ cw[2]\^2 - 288\ cb[4]\ cw[2]\^2 - 
          10.0800000000000022`\ cw[2]\^3 - 72\ cw[2]\^4 - 
          0.0633599999999999141`\ cw[3] + 1.2159999999999993`\ cb[2]\ cw[3] - 
          13.4400000000000008`\ cb[3]\ cw[3] + 
          57.6000000000000067`\ cb[4]\ cw[3] - 64\ cb[5]\ cw[3] - 
          6.57599999999999695`\ cw[2]\ cw[3] + 
          172.799999999999931`\ cb[2]\ cw[2]\ cw[3] - 
          384\ cb[3]\ cw[2]\ cw[3] + 43.199999999999985`\ cw[2]\^2\ cw[3] - 
          0.480000000000000426`\ cw[3]\^2 - 128\ cb[2]\ cw[3]\^2 - 
          0.00959999999999999786`\ cw[4] - 
          3.36000000000000031`\ cw[2]\ cw[4] - 48\ cw[2]\^2\ cw[4] + 
          14.4000000000000021`\ cw[3]\ cw[4] - 8\ cw[4]\^2 > 0, 
      \(0.0530841600000000291`\[InvisibleSpace]\) - 
          0.774143999999999898`\ cb[2] + 9.23520000000000251`\ cb[2]\^2 - 
          80.6399999999998939`\ cb[2]\^3 + 384\ cb[2]\^4 - 
          2.11968000000001044`\ cb[3] + 52.9919999999999724`\ cb[2]\ cb[3] - 
          460.799999999999965`\ cb[2]\^2\ cb[3] - 
          109.440000000000026`\ cb[3]\^2 + 2304\ cb[2]\ cb[3]\^2 + 
          3.70880000000001919`\ cb[4] - 105.600000000000115`\ cb[2]\ cb[4] + 
          1152\ cb[2]\^2\ cb[4] - 383.999999999999985`\ cb[3]\ cb[4] + 
          544\ cb[4]\^2 + 8.70399999999997753`\ cb[5] - 
          153.599999999999914`\ cb[2]\ cb[5] + 768\ cb[3]\ cb[5] - 
          11.5200000000000191`\ cb[6] + 256\ cb[2]\ cb[6] - 
          12.8000000000000046`\ cb[7] + 16\ cb[8] + 
          0.110591999999999934`\ cw[2] - 2.72639999999998217`\ cb[2]\ cw[2] + 
          23.0400000000000071`\ cb[2]\^2\ cw[2] + 
          25.7280000000000219`\ cb[3]\ cw[2] - 
          460.799999999999965`\ cb[2]\ cb[3]\ cw[2] + 1152\ cb[3]\^2\ cw[2] - 
          69.1199999999999192`\ cb[4]\ cw[2] + 1536\ cb[2]\ cb[4]\ cw[2] - 
          115.199999999999991`\ cb[5]\ cw[2] + 192\ cb[6]\ cw[2] + 
          4.62720000000000464`\ cw[2]\^2 - 120.96`\ cb[2]\ cw[2]\^2 + 
          1152\ cb[2]\^2\ cw[2]\^2 - 230.399999999999982`\ cb[3]\ cw[2]\^2 + 
          576\ cb[4]\ cw[2]\^2 + 5.76000000000000156`\ cw[2]\^3 + 
          144\ cw[2]\^4 + 0.0307200000000001338`\ cw[3] - 
          0.511999999999999566`\ cb[2]\ cw[3] + 
          7.68000000000000682`\ cb[3]\ cw[3] - 
          51.2000000000000188`\ cb[4]\ cw[3] + 128\ cb[5]\ cw[3] + 
          8.83199999999997764`\ cw[2]\ cw[3] - 
          153.599999999999914`\ cb[2]\ cw[2]\ cw[3] + 
          768\ cb[3]\ cw[2]\ cw[3] - 38.3999999999999772`\ cw[2]\^2\ cw[3] - 
          13.4400000000000008`\ cw[3]\^2 + 256\ cb[2]\ cw[3]\^2 + 
          0.00319999999999964757`\ cw[4] + 
          1.9200000000000017`\ cw[2]\ cw[4] + 96\ cw[2]\^2\ cw[4] - 
          12.8000000000000046`\ cw[3]\ cw[4] + 16\ cw[4]\^2 > 0, 
      \(0.0176947199999999993`\[InvisibleSpace]\) + 
          0.0184320000000000305`\ cb[2] - 2.64959999999999951`\ cb[2]\^2 + 
          35.5199999999999738`\ cb[2]\^3 - 192\ cb[2]\^4 - 
          1.05215999999999754`\ cb[3] + 15.264000000000002`\ cb[2]\ cb[3] - 
          57.6000000000000778`\ cb[2]\^2\ cb[3] + 
          61.9199999999999928`\ cb[3]\^2 - 1152\ cb[2]\ cb[3]\^2 - 
          2.18240000000001233`\ cb[4] + 64.7999999999999953`\ cb[2]\ cb[4] - 
          576\ cb[2]\^2\ cb[4] - 47.9999999999999982`\ cb[3]\ cb[4] - 
          272\ cb[4]\^2 + 2.3680000000000092`\ cb[5] - 
          19.2000000000000454`\ cb[2]\ cb[5] - 384\ cb[3]\ cb[5] + 
          7.35999999999999143`\ cb[6] - 128\ cb[2]\ cb[6] - 
          1.59999999999999964`\ cb[7] - 8\ cb[8] + 
          0.129024000000000071`\ cw[2] - 2.57279999999999997`\ cb[2]\ cw[2] + 
          17.2799999999999869`\ cb[2]\^2\ cw[2] + 
          6.57600000000001827`\ cb[3]\ cw[2] - 
          57.6000000000000778`\ cb[2]\ cb[3]\ cw[2] - 576\ cb[3]\^2\ cw[2] + 
          44.1599999999999415`\ cb[4]\ cw[2] - 768\ cb[2]\ cb[4]\ cw[2] - 
          14.4000000000000198`\ cb[5]\ cw[2] - 96\ cb[6]\ cw[2] - 
          1.30560000000000231`\ cw[2]\^2 + 
          53.2800000000000117`\ cb[2]\ cw[2]\^2 - 576\ cb[2]\^2\ cw[2]\^2 - 
          28.8000000000000397`\ cb[3]\ cw[2]\^2 - 288\ cb[4]\ cw[2]\^2 + 
          4.31999999999999673`\ cw[2]\^3 - 72\ cw[2]\^4 + 
          0.0486399999999999632`\ cw[3] - 
          0.704000000000000625`\ cb[2]\ cw[3] + 
          5.7599999999999909`\ cb[3]\ cw[3] - 
          6.39999999999999857`\ cb[4]\ cw[3] - 64\ cb[5]\ cw[3] + 
          2.5440000000000098`\ cw[2]\ cw[3] - 
          19.2000000000000454`\ cb[2]\ cw[2]\ cw[3] - 
          384\ cb[3]\ cw[2]\ cw[3] - 4.80000000000001136`\ cw[2]\^2\ cw[3] + 
          5.91999999999999548`\ cw[3]\^2 - 128\ cb[2]\ cw[3]\^2 + 
          0.00640000000000001634`\ cw[4] + 
          1.43999999999999772`\ cw[2]\ cw[4] - 48\ cw[2]\^2\ cw[4] - 
          1.59999999999999964`\ cw[3]\ cw[4] - 8\ cw[4]\^2 > 0, 
      \(0.0132710400000000006`\[InvisibleSpace]\) - 
          0.0783359999999999612`\ cb[2] + 0.428799999999999048`\ cb[2]\^2 - 
          8.15999999999998593`\ cb[2]\^3 + 96\ cb[2]\^4 - 
          0.433920000000002747`\ cb[3] + 10.8479999999999909`\ cb[2]\ cb[3] - 
          115.199999999999969`\ cb[2]\^2\ cb[3] - 
          21.36000000000001`\ cb[3]\^2 + 576\ cb[2]\ cb[3]\^2 + 
          0.947200000000004749`\ cb[4] - 24.4000000000000305`\ cb[2]\ cb[4] + 
          288\ cb[2]\^2\ cb[4] - 95.9999999999999964`\ cb[3]\ cb[4] + 
          136\ cb[4]\^2 + 2.17599999999999393`\ cb[5] - 
          38.3999999999999772`\ cb[2]\ cb[5] + 192\ cb[3]\ cb[5] - 
          2.88000000000000575`\ cb[6] + 64\ cb[2]\ cb[6] - 
          3.20000000000000062`\ cb[7] + 4\ cb[8] - 
          0.0875519999999999853`\ cw[2] + 
          2.19840000000000035`\ cb[2]\ cw[2] - 
          18.2399999999999948`\ cb[2]\^2\ cw[2] + 
          7.63200000000000322`\ cb[3]\ cw[2] - 
          115.199999999999969`\ cb[2]\ cb[3]\ cw[2] + 288\ cb[3]\^2\ cw[2] - 
          17.2799999999999869`\ cb[4]\ cw[2] + 384\ cb[2]\ cb[4]\ cw[2] - 
          28.79999999999999`\ cb[5]\ cw[2] + 48\ cb[6]\ cw[2] + 
          0.156800000000000494`\ cw[2]\^2 - 
          12.2399999999999975`\ cb[2]\ cw[2]\^2 + 288\ cb[2]\^2\ cw[2]\^2 - 
          57.5999999999999801`\ cb[3]\ cw[2]\^2 + 144\ cb[4]\ cw[2]\^2 - 
          4.55999999999999872`\ cw[2]\^3 + 36\ cw[2]\^4 - 
          0.088319999999999954`\ cw[3] + 1.47199999999999908`\ cb[2]\ cw[3] - 
          6.07999999999999563`\ cb[3]\ cw[3] - 
          12.8000000000000024`\ cb[4]\ cw[3] + 32\ cb[5]\ cw[3] + 
          1.80799999999999378`\ cw[2]\ cw[3] - 
          38.3999999999999772`\ cb[2]\ cw[2]\ cw[3] + 
          192\ cb[3]\ cw[2]\ cw[3] - 9.59999999999999431`\ cw[2]\^2\ cw[3] - 
          1.3599999999999992`\ cw[3]\^2 + 64\ cb[2]\ cw[3]\^2 - 
          0.0191999999999999957`\ cw[4] - 
          1.51999999999999886`\ cw[2]\ cw[4] + 24\ cw[2]\^2\ cw[4] - 
          3.20000000000000062`\ cw[3]\ cw[4] + 4\ cw[4]\^2 > 0, 
      \(0.0176947199999999993`\[InvisibleSpace]\) + 
          0.0184320000000000039`\ cb[2] - 2.64959999999999951`\ cb[2]\^2 + 
          35.5199999999999738`\ cb[2]\^3 - 192\ cb[2]\^4 - 
          1.05215999999999776`\ cb[3] + 15.2640000000000108`\ cb[2]\ cb[3] - 
          57.6000000000000778`\ cb[2]\^2\ cb[3] + 
          61.9199999999999928`\ cb[3]\^2 - 1152\ cb[2]\ cb[3]\^2 - 
          2.18240000000001277`\ cb[4] + 64.7999999999999953`\ cb[2]\ cb[4] - 
          576\ cb[2]\^2\ cb[4] - 47.9999999999999982`\ cb[3]\ cb[4] - 
          272\ cb[4]\^2 + 2.36800000000000965`\ cb[5] - 
          19.2000000000000454`\ cb[2]\ cb[5] - 384\ cb[3]\ cb[5] + 
          7.35999999999999143`\ cb[6] - 128\ cb[2]\ cb[6] - 
          1.59999999999999964`\ cb[7] - 8\ cb[8] + 
          0.129024000000000071`\ cw[2] - 2.57279999999999997`\ cb[2]\ cw[2] + 
          17.2799999999999904`\ cb[2]\^2\ cw[2] + 
          6.57600000000001738`\ cb[3]\ cw[2] - 
          57.6000000000000778`\ cb[2]\ cb[3]\ cw[2] - 576\ cb[3]\^2\ cw[2] + 
          44.1599999999999415`\ cb[4]\ cw[2] - 768\ cb[2]\ cb[4]\ cw[2] - 
          14.4000000000000198`\ cb[5]\ cw[2] - 96\ cb[6]\ cw[2] - 
          1.30560000000000231`\ cw[2]\^2 + 
          53.2800000000000117`\ cb[2]\ cw[2]\^2 - 576\ cb[2]\^2\ cw[2]\^2 - 
          28.8000000000000397`\ cb[3]\ cw[2]\^2 - 288\ cb[4]\ cw[2]\^2 + 
          4.31999999999999761`\ cw[2]\^3 - 72\ cw[2]\^4 + 
          0.0486399999999999632`\ cw[3] - 
          0.704000000000000181`\ cb[2]\ cw[3] + 
          5.7599999999999909`\ cb[3]\ cw[3] - 
          6.39999999999999857`\ cb[4]\ cw[3] - 64\ cb[5]\ cw[3] + 
          2.5440000000000098`\ cw[2]\ cw[3] - 
          19.2000000000000454`\ cb[2]\ cw[2]\ cw[3] - 
          384\ cb[3]\ cw[2]\ cw[3] - 4.80000000000001136`\ cw[2]\^2\ cw[3] + 
          5.91999999999999548`\ cw[3]\^2 - 128\ cb[2]\ cw[3]\^2 + 
          0.0063999999999999888`\ cw[4] + 
          1.43999999999999772`\ cw[2]\ cw[4] - 48\ cw[2]\^2\ cw[4] - 
          1.59999999999999964`\ cw[3]\ cw[4] - 8\ cw[4]\^2 > 0, 
      \(0.00589824000000000037`\[InvisibleSpace]\) + 
          0.149503999999999992`\ cb[2] - 1.45920000000000227`\ cb[2]\^2 - 
          3.35999999999998877`\ cb[2]\^3 + 96\ cb[2]\^4 + 
          0.174080000000000856`\ cb[3] - 16.5119999999999977`\ cb[2]\ cb[3] + 
          172.80000000000002`\ cb[2]\^2\ cb[3] - 
          4.55999999999999872`\ cb[3]\^2 + 576\ cb[2]\ cb[3]\^2 - 
          1.16479999999999539`\ cb[4] - 4.39999999999998703`\ cb[2]\ cb[4] + 
          288\ cb[2]\^2\ cb[4] + 143.999999999999994`\ cb[3]\ cb[4] + 
          136\ cb[4]\^2 - 2.94400000000000261`\ cb[5] + 
          57.6000000000000245`\ cb[2]\ cb[5] + 192\ cb[3]\ cb[5] - 
          0.479999999999996429`\ cb[6] + 64\ cb[2]\ cb[6] + 
          4.80000000000000071`\ cb[7] + 4\ cb[8] + 
          0.124927999999999994`\ cw[2] - 1.30560000000000009`\ cb[2]\ cw[2] + 
          0.960000000000006181`\ cb[2]\^2\ cw[2] - 
          9.40799999999999947`\ cb[3]\ cw[2] + 
          172.80000000000002`\ cb[2]\ cb[3]\ cw[2] + 288\ cb[3]\^2\ cw[2] - 
          2.8799999999999617`\ cb[4]\ cw[2] + 384\ cb[2]\ cb[4]\ cw[2] + 
          43.2000000000000028`\ cb[5]\ cw[2] + 48\ cb[6]\ cw[2] - 
          0.691200000000001146`\ cw[2]\^2 - 
          5.04000000000000181`\ cb[2]\ cw[2]\^2 + 288\ cb[2]\^2\ cw[2]\^2 + 
          86.4000000000000056`\ cb[3]\ cw[2]\^2 + 144\ cb[4]\ cw[2]\^2 + 
          0.240000000000001545`\ cw[2]\^3 + 36\ cw[2]\^4 + 
          0.0716800000000000192`\ cw[3] - 
          0.767999999999999349`\ cb[2]\ cw[3] + 
          0.320000000000005613`\ cb[3]\ cw[3] + 
          19.2000000000000028`\ cb[4]\ cw[3] + 32\ cb[5]\ cw[3] - 
          2.75200000000000155`\ cw[2]\ cw[3] + 
          57.6000000000000245`\ cb[2]\ cw[2]\ cw[3] + 
          192\ cb[3]\ cw[2]\ cw[3] + 14.4000000000000056`\ cw[2]\^2\ cw[3] - 
          0.559999999999997122`\ cw[3]\^2 + 64\ cb[2]\ cw[3]\^2 + 
          0.0128000000000000069`\ cw[4] + 
          0.0800000000000014033`\ cw[2]\ cw[4] + 24\ cw[2]\^2\ cw[4] + 
          4.80000000000000071`\ cw[3]\ cw[4] + 4\ cw[4]\^2 > 0, 
      \(0.00995327999999999946`\[InvisibleSpace]\) - 
          0.0414719999999999799`\ cb[2] + 0.633599999999998786`\ cb[2]\^2 - 
          6.72000000000000596`\ cb[2]\^3 - 48\ cb[2]\^4 + 
          0.120960000000001532`\ cb[3] - 5.6640000000000219`\ cb[2]\ cb[3] + 
          129.599999999999981`\ cb[2]\^2\ cb[3] - 
          9.11999999999998323`\ cb[3]\^2 - 288\ cb[2]\ cb[3]\^2 + 
          0.758400000000000851`\ cb[4] - 8.79999999999995452`\ cb[2]\ cb[4] - 
          144\ cb[2]\^2\ cb[4] + 108.000000000000007`\ cb[3]\ cb[4] - 
          68\ cb[4]\^2 - 1.56799999999999872`\ cb[5] + 
          43.199999999999985`\ cb[2]\ cb[5] - 96\ cb[3]\ cb[5] - 
          0.959999999999995168`\ cb[6] - 32\ cb[2]\ cb[6] + 
          3.59999999999999964`\ cb[7] - 2\ cb[8] - 
          0.117504000000000008`\ cw[2] + 1.32479999999999797`\ cb[2]\ cw[2] + 
          1.92000000000000703`\ cb[2]\^2\ cw[2] - 
          6.57600000000001738`\ cb[3]\ cw[2] + 
          129.599999999999981`\ cb[2]\ cb[3]\ cw[2] - 144\ cb[3]\^2\ cw[2] - 
          5.7599999999999909`\ cb[4]\ cw[2] - 192\ cb[2]\ cb[4]\ cw[2] + 
          32.3999999999999932`\ cb[5]\ cw[2] - 24\ cb[6]\ cw[2] + 
          0.489599999999999013`\ cw[2]\^2 - 
          10.0799999999999978`\ cb[2]\ cw[2]\^2 - 144\ cb[2]\^2\ cw[2]\^2 + 
          64.7999999999999864`\ cb[3]\ cw[2]\^2 - 72\ cb[4]\ cw[2]\^2 + 
          0.480000000000001758`\ cw[2]\^3 - 18\ cw[2]\^4 + 
          0.0921600000000000108`\ cw[3] - 
          2.49600000000000044`\ cb[2]\ cw[3] + 
          0.639999999999998792`\ cb[3]\ cw[3] + 
          14.3999999999999994`\ cb[4]\ cw[3] - 16\ cb[5]\ cw[3] - 
          0.94399999999999995`\ cw[2]\ cw[3] + 
          43.199999999999985`\ cb[2]\ cw[2]\ cw[3] - 
          96\ cb[3]\ cw[2]\ cw[3] + 10.7999999999999962`\ cw[2]\^2\ cw[3] - 
          1.1200000000000001`\ cw[3]\^2 - 32\ cb[2]\ cw[3]\^2 + 
          0.0575999999999999712`\ cw[4] + 
          0.159999999999999698`\ cw[2]\ cw[4] - 12\ cw[2]\^2\ cw[4] + 
          3.59999999999999964`\ cw[3]\ cw[4] - 2\ cw[4]\^2 > 0, 
      \(0.0132710400000000006`\[InvisibleSpace]\) - 
          0.0783359999999999612`\ cb[2] + 0.428799999999999048`\ cb[2]\^2 - 
          8.15999999999998593`\ cb[2]\^3 + 96\ cb[2]\^4 - 
          0.433920000000002747`\ cb[3] + 10.8479999999999909`\ cb[2]\ cb[3] - 
          115.199999999999969`\ cb[2]\^2\ cb[3] - 
          21.36000000000001`\ cb[3]\^2 + 576\ cb[2]\ cb[3]\^2 + 
          0.947200000000004749`\ cb[4] - 24.4000000000000305`\ cb[2]\ cb[4] + 
          288\ cb[2]\^2\ cb[4] - 95.9999999999999964`\ cb[3]\ cb[4] + 
          136\ cb[4]\^2 + 2.17599999999999393`\ cb[5] - 
          38.3999999999999772`\ cb[2]\ cb[5] + 192\ cb[3]\ cb[5] - 
          2.88000000000000575`\ cb[6] + 64\ cb[2]\ cb[6] - 
          3.20000000000000062`\ cb[7] + 4\ cb[8] - 
          0.0875519999999999853`\ cw[2] + 
          2.19840000000000124`\ cb[2]\ cw[2] - 
          18.2399999999999948`\ cb[2]\^2\ cw[2] + 
          7.63200000000000322`\ cb[3]\ cw[2] - 
          115.199999999999969`\ cb[2]\ cb[3]\ cw[2] + 288\ cb[3]\^2\ cw[2] - 
          17.2799999999999869`\ cb[4]\ cw[2] + 384\ cb[2]\ cb[4]\ cw[2] - 
          28.79999999999999`\ cb[5]\ cw[2] + 48\ cb[6]\ cw[2] + 
          0.156800000000000716`\ cw[2]\^2 - 
          12.2399999999999975`\ cb[2]\ cw[2]\^2 + 288\ cb[2]\^2\ cw[2]\^2 - 
          57.5999999999999801`\ cb[3]\ cw[2]\^2 + 144\ cb[4]\ cw[2]\^2 - 
          4.55999999999999872`\ cw[2]\^3 + 36\ cw[2]\^4 - 
          0.088319999999999954`\ cw[3] + 1.47199999999999908`\ cb[2]\ cw[3] - 
          6.07999999999999563`\ cb[3]\ cw[3] - 
          12.8000000000000024`\ cb[4]\ cw[3] + 32\ cb[5]\ cw[3] + 
          1.80799999999999378`\ cw[2]\ cw[3] - 
          38.3999999999999772`\ cb[2]\ cw[2]\ cw[3] + 
          192\ cb[3]\ cw[2]\ cw[3] - 9.59999999999999431`\ cw[2]\^2\ cw[3] - 
          1.3599999999999992`\ cw[3]\^2 + 64\ cb[2]\ cw[3]\^2 - 
          0.0191999999999999957`\ cw[4] - 
          1.51999999999999886`\ cw[2]\ cw[4] + 24\ cw[2]\^2\ cw[4] - 
          3.20000000000000062`\ cw[3]\ cw[4] + 4\ cw[4]\^2 > 0, 
      \(0.00442368000000000005`\[InvisibleSpace]\) + 
          0.0430080000000000151`\ cb[2] - 0.422399999999999753`\ cb[2]\^2 + 
          2.87999999999999278`\ cb[2]\^3 - 48\ cb[2]\^4 - 
          0.151039999999999619`\ cb[3] + 2.01600000000000001`\ cb[2]\ cb[3] - 
          14.4000000000000198`\ cb[2]\^2\ cb[3] + 
          12.4799999999999999`\ cb[3]\^2 - 288\ cb[2]\ cb[3]\^2 - 
          0.505600000000003113`\ cb[4] + 15.2000000000000001`\ cb[2]\ cb[4] - 
          144\ cb[2]\^2\ cb[4] - 11.9999999999999996`\ cb[3]\ cb[4] - 
          68\ cb[4]\^2 + 0.592000000000002479`\ cb[5] - 
          4.80000000000001136`\ cb[2]\ cb[5] - 96\ cb[3]\ cb[5] + 
          1.83999999999999772`\ cb[6] - 32\ cb[2]\ cb[6] - 
          0.399999999999999911`\ cb[7] - 2\ cb[8] - 
          0.00614399999999997259`\ cw[2] - 
          0.883200000000000251`\ cb[2]\ cw[2] + 
          16.3200000000000011`\ cb[2]\^2\ cw[2] + 
          2.54400000000000714`\ cb[3]\ cw[2] - 
          14.4000000000000198`\ cb[2]\ cb[3]\ cw[2] - 144\ cb[3]\^2\ cw[2] + 
          11.0399999999999831`\ cb[4]\ cw[2] - 192\ cb[2]\ cb[4]\ cw[2] - 
          3.60000000000000497`\ cb[5]\ cw[2] - 24\ cb[6]\ cw[2] - 
          0.326400000000000556`\ cw[2]\^2 + 
          4.3200000000000065`\ cb[2]\ cw[2]\^2 - 144\ cb[2]\^2\ cw[2]\^2 - 
          7.20000000000000994`\ cb[3]\ cw[2]\^2 - 72\ cb[4]\ cw[2]\^2 + 
          4.08000000000000007`\ cw[2]\^3 - 18\ cw[2]\^4 - 
          0.0998399999999999998`\ cw[3] + 
          1.02400000000000002`\ cb[2]\ cw[3] + 
          5.4399999999999995`\ cb[3]\ cw[3] - 
          1.59999999999999964`\ cb[4]\ cw[3] - 16\ cb[5]\ cw[3] + 
          0.336000000000002607`\ cw[2]\ cw[3] - 
          4.80000000000001136`\ cb[2]\ cw[2]\ cw[3] - 
          96\ cb[3]\ cw[2]\ cw[3] - 1.20000000000000284`\ cw[2]\^2\ cw[3] + 
          0.479999999999998649`\ cw[3]\^2 - 32\ cb[2]\ cw[3]\^2 - 
          0.0383999999999999808`\ cw[4] + 
          1.35999999999999987`\ cw[2]\ cw[4] - 12\ cw[2]\^2\ cw[4] - 
          0.399999999999999911`\ cw[3]\ cw[4] - 2\ cw[4]\^2 > 0, 
      \(0.0132710400000000006`\[InvisibleSpace]\) - 
          0.0783359999999999612`\ cb[2] + 0.428799999999999048`\ cb[2]\^2 - 
          8.15999999999998593`\ cb[2]\^3 + 96\ cb[2]\^4 - 
          0.433920000000002747`\ cb[3] + 10.8479999999999909`\ cb[2]\ cb[3] - 
          115.199999999999969`\ cb[2]\^2\ cb[3] - 
          21.36000000000001`\ cb[3]\^2 + 576\ cb[2]\ cb[3]\^2 + 
          0.947200000000004749`\ cb[4] - 24.4000000000000305`\ cb[2]\ cb[4] + 
          288\ cb[2]\^2\ cb[4] - 95.9999999999999964`\ cb[3]\ cb[4] + 
          136\ cb[4]\^2 + 2.17599999999999393`\ cb[5] - 
          38.3999999999999772`\ cb[2]\ cb[5] + 192\ cb[3]\ cb[5] - 
          2.88000000000000575`\ cb[6] + 64\ cb[2]\ cb[6] - 
          3.20000000000000062`\ cb[7] + 4\ cb[8] - 
          0.0875519999999999853`\ cw[2] + 
          2.19840000000000124`\ cb[2]\ cw[2] - 
          18.2399999999999948`\ cb[2]\^2\ cw[2] + 
          7.63200000000000322`\ cb[3]\ cw[2] - 
          115.199999999999969`\ cb[2]\ cb[3]\ cw[2] + 288\ cb[3]\^2\ cw[2] - 
          17.2799999999999869`\ cb[4]\ cw[2] + 384\ cb[2]\ cb[4]\ cw[2] - 
          28.79999999999999`\ cb[5]\ cw[2] + 48\ cb[6]\ cw[2] + 
          0.156800000000000494`\ cw[2]\^2 - 
          12.2399999999999975`\ cb[2]\ cw[2]\^2 + 288\ cb[2]\^2\ cw[2]\^2 - 
          57.5999999999999801`\ cb[3]\ cw[2]\^2 + 144\ cb[4]\ cw[2]\^2 - 
          4.55999999999999872`\ cw[2]\^3 + 36\ cw[2]\^4 - 
          0.088319999999999954`\ cw[3] + 1.47199999999999908`\ cb[2]\ cw[3] - 
          6.07999999999999563`\ cb[3]\ cw[3] - 
          12.8000000000000024`\ cb[4]\ cw[3] + 32\ cb[5]\ cw[3] + 
          1.80799999999999378`\ cw[2]\ cw[3] - 
          38.3999999999999772`\ cb[2]\ cw[2]\ cw[3] + 
          192\ cb[3]\ cw[2]\ cw[3] - 9.59999999999999431`\ cw[2]\^2\ cw[3] - 
          1.3599999999999992`\ cw[3]\^2 + 64\ cb[2]\ cw[3]\^2 - 
          0.0191999999999999957`\ cw[4] - 
          1.51999999999999886`\ cw[2]\ cw[4] + 24\ cw[2]\^2\ cw[4] - 
          3.20000000000000062`\ cw[3]\ cw[4] + 4\ cw[4]\^2 > 0, 
      \(0.0176947199999999993`\[InvisibleSpace]\) + 
          0.0184320000000000039`\ cb[2] - 2.64959999999999951`\ cb[2]\^2 + 
          35.5199999999999738`\ cb[2]\^3 - 192\ cb[2]\^4 - 
          1.05215999999999776`\ cb[3] + 15.2640000000000153`\ cb[2]\ cb[3] - 
          57.6000000000000778`\ cb[2]\^2\ cb[3] + 
          61.9199999999999928`\ cb[3]\^2 - 1152\ cb[2]\ cb[3]\^2 - 
          2.18240000000001277`\ cb[4] + 64.7999999999999953`\ cb[2]\ cb[4] - 
          576\ cb[2]\^2\ cb[4] - 47.9999999999999982`\ cb[3]\ cb[4] - 
          272\ cb[4]\^2 + 2.36800000000001009`\ cb[5] - 
          19.2000000000000454`\ cb[2]\ cb[5] - 384\ cb[3]\ cb[5] + 
          7.35999999999999143`\ cb[6] - 128\ cb[2]\ cb[6] - 
          1.59999999999999964`\ cb[7] - 8\ cb[8] + 
          0.129024000000000071`\ cw[2] - 2.57279999999999997`\ cb[2]\ cw[2] + 
          17.2799999999999904`\ cb[2]\^2\ cw[2] + 
          6.57600000000001738`\ cb[3]\ cw[2] - 
          57.6000000000000778`\ cb[2]\ cb[3]\ cw[2] - 576\ cb[3]\^2\ cw[2] + 
          44.1599999999999415`\ cb[4]\ cw[2] - 768\ cb[2]\ cb[4]\ cw[2] - 
          14.4000000000000198`\ cb[5]\ cw[2] - 96\ cb[6]\ cw[2] - 
          1.30560000000000231`\ cw[2]\^2 + 
          53.2800000000000117`\ cb[2]\ cw[2]\^2 - 576\ cb[2]\^2\ cw[2]\^2 - 
          28.8000000000000397`\ cb[3]\ cw[2]\^2 - 288\ cb[4]\ cw[2]\^2 + 
          4.31999999999999761`\ cw[2]\^3 - 72\ cw[2]\^4 + 
          0.0486399999999999632`\ cw[3] - 
          0.704000000000000181`\ cb[2]\ cw[3] + 
          5.7599999999999909`\ cb[3]\ cw[3] - 
          6.39999999999999857`\ cb[4]\ cw[3] - 64\ cb[5]\ cw[3] + 
          2.5440000000000098`\ cw[2]\ cw[3] - 
          19.2000000000000454`\ cb[2]\ cw[2]\ cw[3] - 
          384\ cb[3]\ cw[2]\ cw[3] - 4.80000000000001136`\ cw[2]\^2\ cw[3] + 
          5.91999999999999548`\ cw[3]\^2 - 128\ cb[2]\ cw[3]\^2 + 
          0.0063999999999999888`\ cw[4] + 
          1.43999999999999772`\ cw[2]\ cw[4] - 48\ cw[2]\^2\ cw[4] - 
          1.59999999999999964`\ cw[3]\ cw[4] - 8\ cw[4]\^2 > 0, 
      \(0.00589824000000000037`\[InvisibleSpace]\) + 
          0.149503999999999992`\ cb[2] - 1.45920000000000227`\ cb[2]\^2 - 
          3.35999999999998877`\ cb[2]\^3 + 96\ cb[2]\^4 + 
          0.174080000000000945`\ cb[3] - 16.5119999999999977`\ cb[2]\ cb[3] + 
          172.80000000000002`\ cb[2]\^2\ cb[3] - 
          4.55999999999999872`\ cb[3]\^2 + 576\ cb[2]\ cb[3]\^2 - 
          1.16479999999999539`\ cb[4] - 4.39999999999998703`\ cb[2]\ cb[4] + 
          288\ cb[2]\^2\ cb[4] + 143.999999999999994`\ cb[3]\ cb[4] + 
          136\ cb[4]\^2 - 2.94400000000000261`\ cb[5] + 
          57.6000000000000245`\ cb[2]\ cb[5] + 192\ cb[3]\ cb[5] - 
          0.479999999999996429`\ cb[6] + 64\ cb[2]\ cb[6] + 
          4.80000000000000071`\ cb[7] + 4\ cb[8] + 
          0.124927999999999994`\ cw[2] - 1.30560000000000009`\ cb[2]\ cw[2] + 
          0.960000000000006181`\ cb[2]\^2\ cw[2] - 
          9.40799999999999947`\ cb[3]\ cw[2] + 
          172.80000000000002`\ cb[2]\ cb[3]\ cw[2] + 288\ cb[3]\^2\ cw[2] - 
          2.8799999999999617`\ cb[4]\ cw[2] + 384\ cb[2]\ cb[4]\ cw[2] + 
          43.2000000000000028`\ cb[5]\ cw[2] + 48\ cb[6]\ cw[2] - 
          0.691200000000001146`\ cw[2]\^2 - 
          5.04000000000000181`\ cb[2]\ cw[2]\^2 + 288\ cb[2]\^2\ cw[2]\^2 + 
          86.4000000000000056`\ cb[3]\ cw[2]\^2 + 144\ cb[4]\ cw[2]\^2 + 
          0.240000000000001545`\ cw[2]\^3 + 36\ cw[2]\^4 + 
          0.0716800000000000192`\ cw[3] - 
          0.767999999999999349`\ cb[2]\ cw[3] + 
          0.320000000000005613`\ cb[3]\ cw[3] + 
          19.2000000000000028`\ cb[4]\ cw[3] + 32\ cb[5]\ cw[3] - 
          2.75200000000000155`\ cw[2]\ cw[3] + 
          57.6000000000000245`\ cb[2]\ cw[2]\ cw[3] + 
          192\ cb[3]\ cw[2]\ cw[3] + 14.4000000000000056`\ cw[2]\^2\ cw[3] - 
          0.559999999999997122`\ cw[3]\^2 + 64\ cb[2]\ cw[3]\^2 + 
          0.0128000000000000069`\ cw[4] + 
          0.0800000000000014033`\ cw[2]\ cw[4] + 24\ cw[2]\^2\ cw[4] + 
          4.80000000000000071`\ cw[3]\ cw[4] + 4\ cw[4]\^2 > 0, 
      \(0.00442368000000000005`\[InvisibleSpace]\) + 
          0.0430079999999999884`\ cb[2] - 0.422399999999999842`\ cb[2]\^2 + 
          2.87999999999999278`\ cb[2]\^3 - 48\ cb[2]\^4 - 
          0.151039999999999841`\ cb[3] + 2.01600000000000356`\ cb[2]\ cb[3] - 
          14.4000000000000198`\ cb[2]\^2\ cb[3] + 
          12.4799999999999999`\ cb[3]\^2 - 288\ cb[2]\ cb[3]\^2 - 
          0.505600000000003291`\ cb[4] + 15.2000000000000001`\ cb[2]\ cb[4] - 
          144\ cb[2]\^2\ cb[4] - 11.9999999999999996`\ cb[3]\ cb[4] - 
          68\ cb[4]\^2 + 0.592000000000002657`\ cb[5] - 
          4.80000000000001136`\ cb[2]\ cb[5] - 96\ cb[3]\ cb[5] + 
          1.83999999999999772`\ cb[6] - 32\ cb[2]\ cb[6] - 
          0.399999999999999911`\ cb[7] - 2\ cb[8] - 
          0.00614399999999997259`\ cw[2] - 
          0.883200000000000073`\ cb[2]\ cw[2] + 
          16.3200000000000011`\ cb[2]\^2\ cw[2] + 
          2.54400000000000359`\ cb[3]\ cw[2] - 
          14.4000000000000198`\ cb[2]\ cb[3]\ cw[2] - 144\ cb[3]\^2\ cw[2] + 
          11.0399999999999853`\ cb[4]\ cw[2] - 192\ cb[2]\ cb[4]\ cw[2] - 
          3.60000000000000497`\ cb[5]\ cw[2] - 24\ cb[6]\ cw[2] - 
          0.326400000000000689`\ cw[2]\^2 + 
          4.3200000000000065`\ cb[2]\ cw[2]\^2 - 144\ cb[2]\^2\ cw[2]\^2 - 
          7.20000000000000994`\ cb[3]\ cw[2]\^2 - 72\ cb[4]\ cw[2]\^2 + 
          4.08000000000000007`\ cw[2]\^3 - 18\ cw[2]\^4 - 
          0.0998400000000000353`\ cw[3] + 
          1.02400000000000046`\ cb[2]\ cw[3] + 
          5.4399999999999995`\ cb[3]\ cw[3] - 
          1.59999999999999964`\ cb[4]\ cw[3] - 16\ cb[5]\ cw[3] + 
          0.336000000000002607`\ cw[2]\ cw[3] - 
          4.80000000000001136`\ cb[2]\ cw[2]\ cw[3] - 
          96\ cb[3]\ cw[2]\ cw[3] - 1.20000000000000284`\ cw[2]\^2\ cw[3] + 
          0.479999999999998649`\ cw[3]\^2 - 32\ cb[2]\ cw[3]\^2 - 
          0.0383999999999999808`\ cw[4] + 
          1.35999999999999987`\ cw[2]\ cw[4] - 12\ cw[2]\^2\ cw[4] - 
          0.399999999999999911`\ cw[3]\ cw[4] - 2\ cw[4]\^2 > 0, 
      \(0.00589824000000000125`\[InvisibleSpace]\) + 
          0.149503999999999965`\ cb[2] - 1.45920000000000227`\ cb[2]\^2 - 
          3.35999999999998877`\ cb[2]\^3 + 96\ cb[2]\^4 + 
          0.174080000000000856`\ cb[3] - 16.5119999999999977`\ cb[2]\ cb[3] + 
          172.80000000000002`\ cb[2]\^2\ cb[3] - 
          4.55999999999999872`\ cb[3]\^2 + 576\ cb[2]\ cb[3]\^2 - 
          1.16479999999999539`\ cb[4] - 4.39999999999998703`\ cb[2]\ cb[4] + 
          288\ cb[2]\^2\ cb[4] + 143.999999999999994`\ cb[3]\ cb[4] + 
          136\ cb[4]\^2 - 2.94400000000000261`\ cb[5] + 
          57.6000000000000245`\ cb[2]\ cb[5] + 192\ cb[3]\ cb[5] - 
          0.479999999999996429`\ cb[6] + 64\ cb[2]\ cb[6] + 
          4.80000000000000071`\ cb[7] + 4\ cb[8] + 
          0.124927999999999994`\ cw[2] - 1.30559999999999964`\ cb[2]\ cw[2] + 
          0.960000000000006181`\ cb[2]\^2\ cw[2] - 
          9.40800000000000302`\ cb[3]\ cw[2] + 
          172.80000000000002`\ cb[2]\ cb[3]\ cw[2] + 288\ cb[3]\^2\ cw[2] - 
          2.8799999999999617`\ cb[4]\ cw[2] + 384\ cb[2]\ cb[4]\ cw[2] + 
          43.2000000000000028`\ cb[5]\ cw[2] + 48\ cb[6]\ cw[2] - 
          0.691200000000001146`\ cw[2]\^2 - 
          5.04000000000000181`\ cb[2]\ cw[2]\^2 + 288\ cb[2]\^2\ cw[2]\^2 + 
          86.4000000000000056`\ cb[3]\ cw[2]\^2 + 144\ cb[4]\ cw[2]\^2 + 
          0.240000000000001545`\ cw[2]\^3 + 36\ cw[2]\^4 + 
          0.0716800000000000547`\ cw[3] - 
          0.767999999999999349`\ cb[2]\ cw[3] + 
          0.320000000000005613`\ cb[3]\ cw[3] + 
          19.2000000000000028`\ cb[4]\ cw[3] + 32\ cb[5]\ cw[3] - 
          2.75200000000000155`\ cw[2]\ cw[3] + 
          57.6000000000000245`\ cb[2]\ cw[2]\ cw[3] + 
          192\ cb[3]\ cw[2]\ cw[3] + 14.4000000000000056`\ cw[2]\^2\ cw[3] - 
          0.559999999999997122`\ cw[3]\^2 + 64\ cb[2]\ cw[3]\^2 + 
          0.0128000000000000069`\ cw[4] + 
          0.0800000000000014033`\ cw[2]\ cw[4] + 24\ cw[2]\^2\ cw[4] + 
          4.80000000000000071`\ cw[3]\ cw[4] + 4\ cw[4]\^2 > 0, 
      \(0.00196608000000000071`\[InvisibleSpace]\) + 
          0.114688000000000034`\ cb[2] + 0.921599999999999042`\ cb[2]\^2 - 
          11.5200000000000102`\ cb[2]\^3 - 48\ cb[2]\^4 + 
          0.552960000000000118`\ cb[3] - 2.30400000000001536`\ cb[2]\ cb[3] - 
          158.400000000000034`\ cb[2]\^2\ cb[3] - 
          25.9200000000000008`\ cb[3]\^2 - 288\ cb[2]\ cb[3]\^2 + 
          0.870400000000000417`\ cb[4] - 28.8000000000000113`\ cb[2]\ cb[4] - 
          144\ cb[2]\^2\ cb[4] - 131.999999999999984`\ cb[3]\ cb[4] - 
          68\ cb[4]\^2 - 0.448000000000001463`\ cb[5] - 
          52.8000000000000202`\ cb[2]\ cb[5] - 96\ cb[3]\ cb[5] - 
          3.36000000000000209`\ cb[6] - 32\ cb[2]\ cb[6] - 
          4.39999999999999946`\ cb[7] - 2\ cb[8] + 
          0.0860160000000000124`\ cw[2] + 1.228799999999999`\ cb[2]\ cw[2] - 
          17.2800000000000082`\ cb[2]\^2\ cw[2] - 
          1.53600000000000598`\ cb[3]\ cw[2] - 
          158.400000000000034`\ cb[2]\ cb[3]\ cw[2] - 144\ cb[3]\^2\ cw[2] - 
          20.1600000000000223`\ cb[4]\ cw[2] - 192\ cb[2]\ cb[4]\ cw[2] - 
          39.6000000000000085`\ cb[5]\ cw[2] - 24\ cb[6]\ cw[2] + 
          0.537599999999999411`\ cw[2]\^2 - 
          17.2799999999999931`\ cb[2]\ cw[2]\^2 - 144\ cb[2]\^2\ cw[2]\^2 - 
          79.200000000000017`\ cb[3]\ cw[2]\^2 - 72\ cb[4]\ cw[2]\^2 - 
          4.32000000000000206`\ cw[2]\^3 - 18\ cw[2]\^4 + 
          0.092159999999999993`\ cw[3] - 
          0.256000000000000449`\ cb[2]\ cw[3] - 
          5.76000000000000333`\ cb[3]\ cw[3] - 
          17.5999999999999978`\ cb[4]\ cw[3] - 16\ cb[5]\ cw[3] - 
          0.384000000000001406`\ cw[2]\ cw[3] - 
          52.8000000000000202`\ cb[2]\ cw[2]\ cw[3] - 
          96\ cb[3]\ cw[2]\ cw[3] - 13.200000000000005`\ cw[2]\^2\ cw[3] - 
          1.9200000000000017`\ cw[3]\^2 - 32\ cb[2]\ cw[3]\^2 + 
          0.0255999999999999872`\ cw[4] - 
          1.44000000000000083`\ cw[2]\ cw[4] - 12\ cw[2]\^2\ cw[4] - 
          4.39999999999999946`\ cw[3]\ cw[4] - 2\ cw[4]\^2 > 0, 
      \(0.00746495999999999959`\[InvisibleSpace]\) + 
          0.0466560000000000396`\ cb[2] + 0.259200000000000407`\ cb[2]\^2 + 
          11.7599999999999993`\ cb[2]\^3 + 24\ cb[2]\^4 + 
          0.155519999999999551`\ cb[3] - 6.04799999999997961`\ cb[2]\ cb[3] - 
          100.799999999999978`\ cb[2]\^2\ cb[3] + 
          21.9599999999999928`\ cb[3]\^2 + 144\ cb[2]\ cb[3]\^2 - 
          0.475200000000000422`\ cb[4] + 23.3999999999999896`\ cb[2]\ cb[4] + 
          72\ cb[2]\^2\ cb[4] - 84.0000000000000035`\ cb[3]\ cb[4] + 
          34\ cb[4]\^2 - 0.5760000000000006`\ cb[5] - 
          33.6000000000000076`\ cb[2]\ cb[5] + 48\ cb[3]\ cb[5] + 
          2.67999999999999838`\ cb[6] + 16\ cb[2]\ cb[6] - 
          2.80000000000000035`\ cb[7] + cb[8] - 
          0.0622079999999999344`\ cw[2] - 
          1.81440000000000267`\ cb[2]\ cw[2] + 
          8.63999999999999701`\ cb[2]\^2\ cw[2] - 
          0.431999999999987505`\ cb[3]\ cw[2] - 
          100.799999999999978`\ cb[2]\ cb[3]\ cw[2] + 72\ cb[3]\^2\ cw[2] + 
          16.0800000000000009`\ cb[4]\ cw[2] + 96\ cb[2]\ cb[4]\ cw[2] - 
          25.1999999999999957`\ cb[5]\ cw[2] + 12\ cb[6]\ cw[2] - 
          0.388800000000000203`\ cw[2]\^2 + 
          17.6399999999999979`\ cb[2]\ cw[2]\^2 + 72\ cb[2]\^2\ cw[2]\^2 - 
          50.3999999999999914`\ cb[3]\ cw[2]\^2 + 36\ cb[4]\ cw[2]\^2 + 
          2.15999999999999925`\ cw[2]\^3 + 9\ cw[2]\^4 + 
          0.241919999999999957`\ cw[3] + 1.72799999999999975`\ cb[2]\ cw[3] + 
          2.87999999999999936`\ cb[3]\ cw[3] - 
          11.200000000000001`\ cb[4]\ cw[3] + 8\ cb[5]\ cw[3] - 
          1.00800000000000067`\ cw[2]\ cw[3] - 
          33.6000000000000076`\ cb[2]\ cw[2]\ cw[3] + 
          48\ cb[3]\ cw[2]\ cw[3] - 8.40000000000000213`\ cw[2]\^2\ cw[3] + 
          1.95999999999999996`\ cw[3]\^2 + 16\ cb[2]\ cw[3]\^2 - 
          0.172799999999999975`\ cw[4] + 0.71999999999999984`\ cw[2]\ cw[4] + 
          6\ cw[2]\^2\ cw[4] - 2.80000000000000035`\ cw[3]\ cw[4] + 
          cw[4]\^2 > 0, 
      \(0.00995328000000000301`\[InvisibleSpace]\) - 
          0.0414720000000000332`\ cb[2] + 0.633599999999999408`\ cb[2]\^2 - 
          6.72000000000000596`\ cb[2]\^3 - 48\ cb[2]\^4 + 
          0.120960000000001532`\ cb[3] - 5.6640000000000219`\ cb[2]\ cb[3] + 
          129.599999999999981`\ cb[2]\^2\ cb[3] - 
          9.11999999999998323`\ cb[3]\^2 - 288\ cb[2]\ cb[3]\^2 + 
          0.758400000000001295`\ cb[4] - 8.79999999999995452`\ cb[2]\ cb[4] - 
          144\ cb[2]\^2\ cb[4] + 108.000000000000007`\ cb[3]\ cb[4] - 
          68\ cb[4]\^2 - 1.56799999999999872`\ cb[5] + 
          43.199999999999985`\ cb[2]\ cb[5] - 96\ cb[3]\ cb[5] - 
          0.959999999999995168`\ cb[6] - 32\ cb[2]\ cb[6] + 
          3.59999999999999964`\ cb[7] - 2\ cb[8] - 
          0.117504000000000008`\ cw[2] + 1.32479999999999842`\ cb[2]\ cw[2] + 
          1.92000000000000348`\ cb[2]\^2\ cw[2] - 
          6.57600000000001738`\ cb[3]\ cw[2] + 
          129.599999999999981`\ cb[2]\ cb[3]\ cw[2] - 144\ cb[3]\^2\ cw[2] - 
          5.7599999999999909`\ cb[4]\ cw[2] - 192\ cb[2]\ cb[4]\ cw[2] + 
          32.3999999999999932`\ cb[5]\ cw[2] - 24\ cb[6]\ cw[2] + 
          0.489599999999999546`\ cw[2]\^2 - 
          10.0799999999999978`\ cb[2]\ cw[2]\^2 - 144\ cb[2]\^2\ cw[2]\^2 + 
          64.7999999999999864`\ cb[3]\ cw[2]\^2 - 72\ cb[4]\ cw[2]\^2 + 
          0.48000000000000087`\ cw[2]\^3 - 18\ cw[2]\^4 + 
          0.0921600000000000108`\ cw[3] - 
          2.49600000000000044`\ cb[2]\ cw[3] + 
          0.639999999999998792`\ cb[3]\ cw[3] + 
          14.3999999999999994`\ cb[4]\ cw[3] - 16\ cb[5]\ cw[3] - 
          0.94399999999999995`\ cw[2]\ cw[3] + 
          43.199999999999985`\ cb[2]\ cw[2]\ cw[3] - 
          96\ cb[3]\ cw[2]\ cw[3] + 10.7999999999999962`\ cw[2]\^2\ cw[3] - 
          1.1200000000000001`\ cw[3]\^2 - 32\ cb[2]\ cw[3]\^2 + 
          0.0575999999999999801`\ cw[4] + 
          0.159999999999999698`\ cw[2]\ cw[4] - 12\ cw[2]\^2\ cw[4] + 
          3.59999999999999964`\ cw[3]\ cw[4] - 2\ cw[4]\^2 > 0, 
      \(0.00331776000000000026`\[InvisibleSpace]\) + 
          0.00921599999999999575`\ cb[2] + 0.387199999999999544`\ cb[2]\^2 + 
          0.960000000000001207`\ cb[2]\^3 + 24\ cb[2]\^4 - 
          0.0844800000000006612`\ cb[3] + 
          2.11199999999999921`\ cb[2]\ cb[3] - 
          28.79999999999999`\ cb[2]\^2\ cb[3] - 
          3.84000000000000376`\ cb[3]\^2 + 144\ cb[2]\ cb[3]\^2 + 
          0.116800000000001258`\ cb[4] - 5.60000000000000852`\ cb[2]\ cb[4] + 
          72\ cb[2]\^2\ cb[4] - 23.9999999999999991`\ cb[3]\ cb[4] + 
          34\ cb[4]\^2 + 0.543999999999998529`\ cb[5] - 
          9.59999999999999431`\ cb[2]\ cb[5] + 48\ cb[3]\ cb[5] - 
          0.720000000000001438`\ cb[6] + 16\ cb[2]\ cb[6] - 
          0.800000000000000177`\ cb[7] + cb[8] - 
          0.050688000000000013`\ cw[2] - 
          0.230399999999999982`\ cb[2]\ cw[2] - 
          10.559999999999996`\ cb[2]\^2\ cw[2] + 
          2.20799999999999929`\ cb[3]\ cw[2] - 
          28.79999999999999`\ cb[2]\ cb[3]\ cw[2] + 72\ cb[3]\^2\ cw[2] - 
          4.31999999999999673`\ cb[4]\ cw[2] + 96\ cb[2]\ cb[4]\ cw[2] - 
          7.19999999999999751`\ cb[5]\ cw[2] + 12\ cb[6]\ cw[2] + 
          0.539199999999999945`\ cw[2]\^2 + 
          1.43999999999999683`\ cb[2]\ cw[2]\^2 + 72\ cb[2]\^2\ cw[2]\^2 - 
          14.399999999999995`\ cb[3]\ cw[2]\^2 + 36\ cb[4]\ cw[2]\^2 - 
          2.63999999999999879`\ cw[2]\^3 + 9\ cw[2]\^4 - 
          0.0460799999999999787`\ cw[3] + 
          0.767999999999999793`\ cb[2]\ cw[3] - 
          3.51999999999999912`\ cb[3]\ cw[3] - 
          3.20000000000000062`\ cb[4]\ cw[3] + 8\ cb[5]\ cw[3] + 
          0.351999999999998447`\ cw[2]\ cw[3] - 
          9.59999999999999431`\ cb[2]\ cw[2]\ cw[3] + 
          48\ cb[3]\ cw[2]\ cw[3] - 2.39999999999999857`\ cw[2]\^2\ cw[3] + 
          0.160000000000000586`\ cw[3]\^2 + 16\ cb[2]\ cw[3]\^2 + 
          0.115199999999999991`\ cw[4] - 
          0.879999999999999715`\ cw[2]\ cw[4] + 6\ cw[2]\^2\ cw[4] - 
          0.800000000000000177`\ cw[3]\ cw[4] + cw[4]\^2 > 0, 
      \(0.00995327999999999946`\[InvisibleSpace]\) - 
          0.041472000000000051`\ cb[2] + 0.633599999999999052`\ cb[2]\^2 - 
          6.72000000000000596`\ cb[2]\^3 - 48\ cb[2]\^4 + 
          0.120960000000001532`\ cb[3] - 5.6640000000000219`\ cb[2]\ cb[3] + 
          129.599999999999981`\ cb[2]\^2\ cb[3] - 
          9.11999999999998323`\ cb[3]\^2 - 288\ cb[2]\ cb[3]\^2 + 
          0.758400000000000851`\ cb[4] - 8.79999999999995452`\ cb[2]\ cb[4] - 
          144\ cb[2]\^2\ cb[4] + 108.000000000000007`\ cb[3]\ cb[4] - 
          68\ cb[4]\^2 - 1.56799999999999872`\ cb[5] + 
          43.199999999999985`\ cb[2]\ cb[5] - 96\ cb[3]\ cb[5] - 
          0.959999999999995168`\ cb[6] - 32\ cb[2]\ cb[6] + 
          3.59999999999999964`\ cb[7] - 2\ cb[8] - 
          0.117504000000000008`\ cw[2] + 1.32479999999999842`\ cb[2]\ cw[2] + 
          1.92000000000000703`\ cb[2]\^2\ cw[2] - 
          6.57600000000001738`\ cb[3]\ cw[2] + 
          129.599999999999981`\ cb[2]\ cb[3]\ cw[2] - 144\ cb[3]\^2\ cw[2] - 
          5.7599999999999909`\ cb[4]\ cw[2] - 192\ cb[2]\ cb[4]\ cw[2] + 
          32.3999999999999932`\ cb[5]\ cw[2] - 24\ cb[6]\ cw[2] + 
          0.489599999999999191`\ cw[2]\^2 - 
          10.0799999999999978`\ cb[2]\ cw[2]\^2 - 144\ cb[2]\^2\ cw[2]\^2 + 
          64.7999999999999864`\ cb[3]\ cw[2]\^2 - 72\ cb[4]\ cw[2]\^2 + 
          0.480000000000001758`\ cw[2]\^3 - 18\ cw[2]\^4 + 
          0.0921600000000000108`\ cw[3] - 
          2.49600000000000044`\ cb[2]\ cw[3] + 
          0.639999999999998792`\ cb[3]\ cw[3] + 
          14.3999999999999994`\ cb[4]\ cw[3] - 16\ cb[5]\ cw[3] - 
          0.94399999999999995`\ cw[2]\ cw[3] + 
          43.199999999999985`\ cb[2]\ cw[2]\ cw[3] - 
          96\ cb[3]\ cw[2]\ cw[3] + 10.7999999999999962`\ cw[2]\^2\ cw[3] - 
          1.1200000000000001`\ cw[3]\^2 - 32\ cb[2]\ cw[3]\^2 + 
          0.0575999999999999801`\ cw[4] + 
          0.159999999999999698`\ cw[2]\ cw[4] - 12\ cw[2]\^2\ cw[4] + 
          3.59999999999999964`\ cw[3]\ cw[4] - 2\ cw[4]\^2 > 0, 
      \(0.0132710400000000006`\[InvisibleSpace]\) - 
          0.0783359999999999612`\ cb[2] + 0.42879999999999816`\ cb[2]\^2 - 
          8.15999999999998593`\ cb[2]\^3 + 96\ cb[2]\^4 - 
          0.433920000000002747`\ cb[3] + 10.8479999999999909`\ cb[2]\ cb[3] - 
          115.199999999999969`\ cb[2]\^2\ cb[3] - 
          21.36000000000001`\ cb[3]\^2 + 576\ cb[2]\ cb[3]\^2 + 
          0.947200000000004749`\ cb[4] - 24.4000000000000305`\ cb[2]\ cb[4] + 
          288\ cb[2]\^2\ cb[4] - 95.9999999999999964`\ cb[3]\ cb[4] + 
          136\ cb[4]\^2 + 2.17599999999999393`\ cb[5] - 
          38.3999999999999772`\ cb[2]\ cb[5] + 192\ cb[3]\ cb[5] - 
          2.88000000000000575`\ cb[6] + 64\ cb[2]\ cb[6] - 
          3.20000000000000062`\ cb[7] + 4\ cb[8] - 
          0.0875519999999999853`\ cw[2] + 
          2.19840000000000213`\ cb[2]\ cw[2] - 
          18.2399999999999948`\ cb[2]\^2\ cw[2] + 
          7.63200000000000411`\ cb[3]\ cw[2] - 
          115.199999999999969`\ cb[2]\ cb[3]\ cw[2] + 288\ cb[3]\^2\ cw[2] - 
          17.2799999999999869`\ cb[4]\ cw[2] + 384\ cb[2]\ cb[4]\ cw[2] - 
          28.79999999999999`\ cb[5]\ cw[2] + 48\ cb[6]\ cw[2] + 
          0.156800000000000272`\ cw[2]\^2 - 
          12.2399999999999975`\ cb[2]\ cw[2]\^2 + 288\ cb[2]\^2\ cw[2]\^2 - 
          57.5999999999999801`\ cb[3]\ cw[2]\^2 + 144\ cb[4]\ cw[2]\^2 - 
          4.55999999999999872`\ cw[2]\^3 + 36\ cw[2]\^4 - 
          0.088319999999999954`\ cw[3] + 1.47199999999999908`\ cb[2]\ cw[3] - 
          6.07999999999999563`\ cb[3]\ cw[3] - 
          12.8000000000000024`\ cb[4]\ cw[3] + 32\ cb[5]\ cw[3] + 
          1.80799999999999378`\ cw[2]\ cw[3] - 
          38.3999999999999772`\ cb[2]\ cw[2]\ cw[3] + 
          192\ cb[3]\ cw[2]\ cw[3] - 9.59999999999999431`\ cw[2]\^2\ cw[3] - 
          1.3599999999999992`\ cw[3]\^2 + 64\ cb[2]\ cw[3]\^2 - 
          0.0191999999999999957`\ cw[4] - 
          1.51999999999999886`\ cw[2]\ cw[4] + 24\ cw[2]\^2\ cw[4] - 
          3.20000000000000062`\ cw[3]\ cw[4] + 4\ cw[4]\^2 > 0, 
      \(0.00442368000000000094`\[InvisibleSpace]\) + 
          0.0430080000000000151`\ cb[2] - 0.422399999999999664`\ cb[2]\^2 + 
          2.87999999999999278`\ cb[2]\^3 - 48\ cb[2]\^4 - 
          0.151039999999999619`\ cb[3] + 2.01600000000000356`\ cb[2]\ cb[3] - 
          14.4000000000000198`\ cb[2]\^2\ cb[3] + 
          12.4799999999999999`\ cb[3]\^2 - 288\ cb[2]\ cb[3]\^2 - 
          0.505600000000003113`\ cb[4] + 15.2000000000000001`\ cb[2]\ cb[4] - 
          144\ cb[2]\^2\ cb[4] - 11.9999999999999996`\ cb[3]\ cb[4] - 
          68\ cb[4]\^2 + 0.592000000000002213`\ cb[5] - 
          4.80000000000001136`\ cb[2]\ cb[5] - 96\ cb[3]\ cb[5] + 
          1.83999999999999772`\ cb[6] - 32\ cb[2]\ cb[6] - 
          0.399999999999999911`\ cb[7] - 2\ cb[8] - 
          0.00614399999999997259`\ cw[2] - 
          0.883200000000000073`\ cb[2]\ cw[2] + 
          16.3200000000000011`\ cb[2]\^2\ cw[2] + 
          2.54400000000000359`\ cb[3]\ cw[2] - 
          14.4000000000000198`\ cb[2]\ cb[3]\ cw[2] - 144\ cb[3]\^2\ cw[2] + 
          11.0399999999999831`\ cb[4]\ cw[2] - 192\ cb[2]\ cb[4]\ cw[2] - 
          3.60000000000000497`\ cb[5]\ cw[2] - 24\ cb[6]\ cw[2] - 
          0.326400000000000556`\ cw[2]\^2 + 
          4.3200000000000065`\ cb[2]\ cw[2]\^2 - 144\ cb[2]\^2\ cw[2]\^2 - 
          7.20000000000000994`\ cb[3]\ cw[2]\^2 - 72\ cb[4]\ cw[2]\^2 + 
          4.08000000000000007`\ cw[2]\^3 - 18\ cw[2]\^4 - 
          0.0998399999999999998`\ cw[3] + 
          1.02400000000000002`\ cb[2]\ cw[3] + 
          5.4399999999999995`\ cb[3]\ cw[3] - 
          1.59999999999999964`\ cb[4]\ cw[3] - 16\ cb[5]\ cw[3] + 
          0.33600000000000243`\ cw[2]\ cw[3] - 
          4.80000000000001136`\ cb[2]\ cw[2]\ cw[3] - 
          96\ cb[3]\ cw[2]\ cw[3] - 1.20000000000000284`\ cw[2]\^2\ cw[3] + 
          0.479999999999998649`\ cw[3]\^2 - 32\ cb[2]\ cw[3]\^2 - 
          0.0383999999999999896`\ cw[4] + 
          1.35999999999999987`\ cw[2]\ cw[4] - 12\ cw[2]\^2\ cw[4] - 
          0.399999999999999911`\ cw[3]\ cw[4] - 2\ cw[4]\^2 > 0, 
      \(0.00331776000000000026`\[InvisibleSpace]\) + 
          0.00921599999999999575`\ cb[2] + 0.387199999999999544`\ cb[2]\^2 + 
          0.960000000000001207`\ cb[2]\^3 + 24\ cb[2]\^4 - 
          0.0844800000000006612`\ cb[3] + 
          2.11199999999999921`\ cb[2]\ cb[3] - 
          28.79999999999999`\ cb[2]\^2\ cb[3] - 
          3.84000000000000376`\ cb[3]\^2 + 144\ cb[2]\ cb[3]\^2 + 
          0.116800000000001324`\ cb[4] - 5.60000000000000852`\ cb[2]\ cb[4] + 
          72\ cb[2]\^2\ cb[4] - 23.9999999999999991`\ cb[3]\ cb[4] + 
          34\ cb[4]\^2 + 0.543999999999998529`\ cb[5] - 
          9.59999999999999431`\ cb[2]\ cb[5] + 48\ cb[3]\ cb[5] - 
          0.720000000000001438`\ cb[6] + 16\ cb[2]\ cb[6] - 
          0.800000000000000177`\ cb[7] + cb[8] - 
          0.0506879999999999952`\ cw[2] - 
          0.230399999999999982`\ cb[2]\ cw[2] - 
          10.559999999999996`\ cb[2]\^2\ cw[2] + 
          2.20799999999999929`\ cb[3]\ cw[2] - 
          28.79999999999999`\ cb[2]\ cb[3]\ cw[2] + 72\ cb[3]\^2\ cw[2] - 
          4.31999999999999673`\ cb[4]\ cw[2] + 96\ cb[2]\ cb[4]\ cw[2] - 
          7.19999999999999751`\ cb[5]\ cw[2] + 12\ cb[6]\ cw[2] + 
          0.539199999999999768`\ cw[2]\^2 + 
          1.43999999999999683`\ cb[2]\ cw[2]\^2 + 72\ cb[2]\^2\ cw[2]\^2 - 
          14.399999999999995`\ cb[3]\ cw[2]\^2 + 36\ cb[4]\ cw[2]\^2 - 
          2.63999999999999879`\ cw[2]\^3 + 9\ cw[2]\^4 - 
          0.0460799999999999787`\ cw[3] + 
          0.767999999999999793`\ cb[2]\ cw[3] - 
          3.51999999999999912`\ cb[3]\ cw[3] - 
          3.20000000000000062`\ cb[4]\ cw[3] + 8\ cb[5]\ cw[3] + 
          0.351999999999998447`\ cw[2]\ cw[3] - 
          9.59999999999999431`\ cb[2]\ cw[2]\ cw[3] + 
          48\ cb[3]\ cw[2]\ cw[3] - 2.39999999999999857`\ cw[2]\^2\ cw[3] + 
          0.160000000000000586`\ cw[3]\^2 + 16\ cb[2]\ cw[3]\^2 + 
          0.115199999999999991`\ cw[4] - 
          0.879999999999999715`\ cw[2]\ cw[4] + 6\ cw[2]\^2\ cw[4] - 
          0.800000000000000177`\ cw[3]\ cw[4] + cw[4]\^2 > 0, 
      \(0.00442368000000000094`\[InvisibleSpace]\) + 
          0.0430079999999999884`\ cb[2] - 0.422399999999999664`\ cb[2]\^2 + 
          2.87999999999999278`\ cb[2]\^3 - 48\ cb[2]\^4 - 
          0.151039999999999841`\ cb[3] + 2.01600000000000711`\ cb[2]\ cb[3] - 
          14.4000000000000198`\ cb[2]\^2\ cb[3] + 
          12.4799999999999999`\ cb[3]\^2 - 288\ cb[2]\ cb[3]\^2 - 
          0.505600000000003113`\ cb[4] + 15.2000000000000001`\ cb[2]\ cb[4] - 
          144\ cb[2]\^2\ cb[4] - 11.9999999999999996`\ cb[3]\ cb[4] - 
          68\ cb[4]\^2 + 0.592000000000002302`\ cb[5] - 
          4.80000000000001136`\ cb[2]\ cb[5] - 96\ cb[3]\ cb[5] + 
          1.83999999999999772`\ cb[6] - 32\ cb[2]\ cb[6] - 
          0.399999999999999911`\ cb[7] - 2\ cb[8] - 
          0.00614399999999997259`\ cw[2] - 
          0.883199999999999896`\ cb[2]\ cw[2] + 
          16.3200000000000011`\ cb[2]\^2\ cw[2] + 
          2.54400000000000359`\ cb[3]\ cw[2] - 
          14.4000000000000198`\ cb[2]\ cb[3]\ cw[2] - 144\ cb[3]\^2\ cw[2] + 
          11.0399999999999831`\ cb[4]\ cw[2] - 192\ cb[2]\ cb[4]\ cw[2] - 
          3.60000000000000497`\ cb[5]\ cw[2] - 24\ cb[6]\ cw[2] - 
          0.326400000000000556`\ cw[2]\^2 + 
          4.3200000000000065`\ cb[2]\ cw[2]\^2 - 144\ cb[2]\^2\ cw[2]\^2 - 
          7.20000000000000994`\ cb[3]\ cw[2]\^2 - 72\ cb[4]\ cw[2]\^2 + 
          4.08000000000000007`\ cw[2]\^3 - 18\ cw[2]\^4 - 
          0.0998399999999999998`\ cw[3] + 
          1.02400000000000002`\ cb[2]\ cw[3] + 
          5.4399999999999995`\ cb[3]\ cw[3] - 
          1.59999999999999964`\ cb[4]\ cw[3] - 16\ cb[5]\ cw[3] + 
          0.33600000000000243`\ cw[2]\ cw[3] - 
          4.80000000000001136`\ cb[2]\ cw[2]\ cw[3] - 
          96\ cb[3]\ cw[2]\ cw[3] - 1.20000000000000284`\ cw[2]\^2\ cw[3] + 
          0.479999999999998649`\ cw[3]\^2 - 32\ cb[2]\ cw[3]\^2 - 
          0.0383999999999999896`\ cw[4] + 
          1.35999999999999987`\ cw[2]\ cw[4] - 12\ cw[2]\^2\ cw[4] - 
          0.399999999999999911`\ cw[3]\ cw[4] - 2\ cw[4]\^2 > 0, 
      \(0.00147456000000000013`\[InvisibleSpace]\) + 
          0.0501760000000000072`\ cb[2] + 0.115199999999999191`\ cb[2]\^2 + 
          2.16000000000000103`\ cb[2]\^3 + 24\ cb[2]\^4 + 
          0.107520000000000148`\ cb[3] - 1.72800000000000313`\ cb[2]\ cb[3] + 
          43.2000000000000028`\ cb[2]\^2\ cb[3] + 
          0.359999999999998987`\ cb[3]\^2 + 144\ cb[2]\ cb[3]\^2 - 
          0.211199999999998944`\ cb[4] - 0.5999999999999992`\ cb[2]\ cb[4] + 
          72\ cb[2]\^2\ cb[4] + 36.0000000000000008`\ cb[3]\ cb[4] + 
          34\ cb[4]\^2 - 0.736000000000000831`\ cb[5] + 
          14.4000000000000056`\ cb[2]\ cb[5] + 48\ cb[3]\ cb[5] - 
          0.119999999999999108`\ cb[6] + 16\ cb[2]\ cb[6] + 
          1.20000000000000017`\ cb[7] + cb[8] + 
          0.0184319999999999986`\ cw[2] - 
          0.806400000000000005`\ cb[2]\ cw[2] - 
          5.75999999999999801`\ cb[2]\^2\ cw[2] - 
          3.55200000000000049`\ cb[3]\ cw[2] + 
          43.2000000000000028`\ cb[2]\ cb[3]\ cw[2] + 72\ cb[3]\^2\ cw[2] - 
          0.719999999999990425`\ cb[4]\ cw[2] + 96\ cb[2]\ cb[4]\ cw[2] + 
          10.8000000000000007`\ cb[5]\ cw[2] + 12\ cb[6]\ cw[2] - 
          0.172800000000000402`\ cw[2]\^2 + 
          3.23999999999999932`\ cb[2]\ cw[2]\^2 + 72\ cb[2]\^2\ cw[2]\^2 + 
          21.6000000000000014`\ cb[3]\ cw[2]\^2 + 36\ cb[4]\ cw[2]\^2 - 
          1.4399999999999995`\ cw[2]\^3 + 9\ cw[2]\^4 - 
          0.0460800000000000054`\ cw[3] - 
          1.79199999999999963`\ cb[2]\ cw[3] - 
          1.91999999999999815`\ cb[3]\ cw[3] + 
          4.80000000000000071`\ cb[4]\ cw[3] + 8\ cb[5]\ cw[3] - 
          0.288000000000000166`\ cw[2]\ cw[3] + 
          14.4000000000000056`\ cb[2]\ cw[2]\ cw[3] + 
          48\ cb[3]\ cw[2]\ cw[3] + 3.60000000000000142`\ cw[2]\^2\ cw[3] + 
          0.360000000000000541`\ cw[3]\^2 + 16\ cb[2]\ cw[3]\^2 - 
          0.0767999999999999971`\ cw[4] - 
          0.479999999999999538`\ cw[2]\ cw[4] + 6\ cw[2]\^2\ cw[4] + 
          1.20000000000000017`\ cw[3]\ cw[4] + cw[4]\^2 > 0, 
      \(0.00995327999999999946`\[InvisibleSpace]\) - 
          0.0414719999999999799`\ cb[2] + 0.633599999999998786`\ cb[2]\^2 - 
          6.72000000000000596`\ cb[2]\^3 - 48\ cb[2]\^4 + 
          0.120960000000001532`\ cb[3] - 5.6640000000000219`\ cb[2]\ cb[3] + 
          129.599999999999981`\ cb[2]\^2\ cb[3] - 
          9.11999999999998323`\ cb[3]\^2 - 288\ cb[2]\ cb[3]\^2 + 
          0.758400000000000851`\ cb[4] - 8.79999999999995452`\ cb[2]\ cb[4] - 
          144\ cb[2]\^2\ cb[4] + 108.000000000000007`\ cb[3]\ cb[4] - 
          68\ cb[4]\^2 - 1.56799999999999872`\ cb[5] + 
          43.199999999999985`\ cb[2]\ cb[5] - 96\ cb[3]\ cb[5] - 
          0.959999999999995168`\ cb[6] - 32\ cb[2]\ cb[6] + 
          3.59999999999999964`\ cb[7] - 2\ cb[8] - 
          0.117504000000000008`\ cw[2] + 1.32479999999999842`\ cb[2]\ cw[2] + 
          1.92000000000000703`\ cb[2]\^2\ cw[2] - 
          6.57600000000001738`\ cb[3]\ cw[2] + 
          129.599999999999981`\ cb[2]\ cb[3]\ cw[2] - 144\ cb[3]\^2\ cw[2] - 
          5.7599999999999909`\ cb[4]\ cw[2] - 192\ cb[2]\ cb[4]\ cw[2] + 
          32.3999999999999932`\ cb[5]\ cw[2] - 24\ cb[6]\ cw[2] + 
          0.489599999999999102`\ cw[2]\^2 - 
          10.0799999999999978`\ cb[2]\ cw[2]\^2 - 144\ cb[2]\^2\ cw[2]\^2 + 
          64.7999999999999864`\ cb[3]\ cw[2]\^2 - 72\ cb[4]\ cw[2]\^2 + 
          0.480000000000001758`\ cw[2]\^3 - 18\ cw[2]\^4 + 
          0.0921600000000000108`\ cw[3] - 
          2.49600000000000044`\ cb[2]\ cw[3] + 
          0.639999999999998792`\ cb[3]\ cw[3] + 
          14.3999999999999994`\ cb[4]\ cw[3] - 16\ cb[5]\ cw[3] - 
          0.94399999999999995`\ cw[2]\ cw[3] + 
          43.199999999999985`\ cb[2]\ cw[2]\ cw[3] - 
          96\ cb[3]\ cw[2]\ cw[3] + 10.7999999999999962`\ cw[2]\^2\ cw[3] - 
          1.1200000000000001`\ cw[3]\^2 - 32\ cb[2]\ cw[3]\^2 + 
          0.0575999999999999712`\ cw[4] + 
          0.159999999999999698`\ cw[2]\ cw[4] - 12\ cw[2]\^2\ cw[4] + 
          3.59999999999999964`\ cw[3]\ cw[4] - 2\ cw[4]\^2 > 0, 
      \(0.0132710400000000006`\[InvisibleSpace]\) - 
          0.0783359999999999612`\ cb[2] + 0.428799999999999048`\ cb[2]\^2 - 
          8.15999999999998593`\ cb[2]\^3 + 96\ cb[2]\^4 - 
          0.433920000000002747`\ cb[3] + 10.8479999999999909`\ cb[2]\ cb[3] - 
          115.199999999999969`\ cb[2]\^2\ cb[3] - 
          21.36000000000001`\ cb[3]\^2 + 576\ cb[2]\ cb[3]\^2 + 
          0.947200000000004749`\ cb[4] - 24.4000000000000305`\ cb[2]\ cb[4] + 
          288\ cb[2]\^2\ cb[4] - 95.9999999999999964`\ cb[3]\ cb[4] + 
          136\ cb[4]\^2 + 2.17599999999999393`\ cb[5] - 
          38.3999999999999772`\ cb[2]\ cb[5] + 192\ cb[3]\ cb[5] - 
          2.88000000000000575`\ cb[6] + 64\ cb[2]\ cb[6] - 
          3.20000000000000062`\ cb[7] + 4\ cb[8] - 
          0.0875519999999999853`\ cw[2] + 
          2.19840000000000213`\ cb[2]\ cw[2] - 
          18.2399999999999948`\ cb[2]\^2\ cw[2] + 
          7.63200000000000056`\ cb[3]\ cw[2] - 
          115.199999999999969`\ cb[2]\ cb[3]\ cw[2] + 288\ cb[3]\^2\ cw[2] - 
          17.2799999999999869`\ cb[4]\ cw[2] + 384\ cb[2]\ cb[4]\ cw[2] - 
          28.79999999999999`\ cb[5]\ cw[2] + 48\ cb[6]\ cw[2] + 
          0.156800000000000272`\ cw[2]\^2 - 
          12.2399999999999975`\ cb[2]\ cw[2]\^2 + 288\ cb[2]\^2\ cw[2]\^2 - 
          57.5999999999999801`\ cb[3]\ cw[2]\^2 + 144\ cb[4]\ cw[2]\^2 - 
          4.55999999999999872`\ cw[2]\^3 + 36\ cw[2]\^4 - 
          0.088319999999999954`\ cw[3] + 1.47199999999999908`\ cb[2]\ cw[3] - 
          6.07999999999999563`\ cb[3]\ cw[3] - 
          12.8000000000000024`\ cb[4]\ cw[3] + 32\ cb[5]\ cw[3] + 
          1.80799999999999378`\ cw[2]\ cw[3] - 
          38.3999999999999772`\ cb[2]\ cw[2]\ cw[3] + 
          192\ cb[3]\ cw[2]\ cw[3] - 9.59999999999999431`\ cw[2]\^2\ cw[3] - 
          1.3599999999999992`\ cw[3]\^2 + 64\ cb[2]\ cw[3]\^2 - 
          0.0191999999999999957`\ cw[4] - 
          1.51999999999999886`\ cw[2]\ cw[4] + 24\ cw[2]\^2\ cw[4] - 
          3.20000000000000062`\ cw[3]\ cw[4] + 4\ cw[4]\^2 > 0, 
      \(0.00442368000000000005`\[InvisibleSpace]\) + 
          0.0430080000000000151`\ cb[2] - 0.422399999999999753`\ cb[2]\^2 + 
          2.87999999999999278`\ cb[2]\^3 - 48\ cb[2]\^4 - 
          0.151039999999999619`\ cb[3] + 2.01600000000000356`\ cb[2]\ cb[3] - 
          14.4000000000000198`\ cb[2]\^2\ cb[3] + 
          12.4799999999999999`\ cb[3]\^2 - 288\ cb[2]\ cb[3]\^2 - 
          0.505600000000003113`\ cb[4] + 15.2000000000000001`\ cb[2]\ cb[4] - 
          144\ cb[2]\^2\ cb[4] - 11.9999999999999996`\ cb[3]\ cb[4] - 
          68\ cb[4]\^2 + 0.592000000000002479`\ cb[5] - 
          4.80000000000001136`\ cb[2]\ cb[5] - 96\ cb[3]\ cb[5] + 
          1.83999999999999772`\ cb[6] - 32\ cb[2]\ cb[6] - 
          0.399999999999999911`\ cb[7] - 2\ cb[8] - 
          0.00614399999999997259`\ cw[2] - 
          0.883200000000000073`\ cb[2]\ cw[2] + 
          16.3200000000000011`\ cb[2]\^2\ cw[2] + 
          2.54400000000000359`\ cb[3]\ cw[2] - 
          14.4000000000000198`\ cb[2]\ cb[3]\ cw[2] - 144\ cb[3]\^2\ cw[2] + 
          11.0399999999999831`\ cb[4]\ cw[2] - 192\ cb[2]\ cb[4]\ cw[2] - 
          3.60000000000000497`\ cb[5]\ cw[2] - 24\ cb[6]\ cw[2] - 
          0.326400000000000556`\ cw[2]\^2 + 
          4.3200000000000065`\ cb[2]\ cw[2]\^2 - 144\ cb[2]\^2\ cw[2]\^2 - 
          7.20000000000000994`\ cb[3]\ cw[2]\^2 - 72\ cb[4]\ cw[2]\^2 + 
          4.08000000000000007`\ cw[2]\^3 - 18\ cw[2]\^4 - 
          0.0998399999999999998`\ cw[3] + 
          1.02400000000000002`\ cb[2]\ cw[3] + 
          5.4399999999999995`\ cb[3]\ cw[3] - 
          1.59999999999999964`\ cb[4]\ cw[3] - 16\ cb[5]\ cw[3] + 
          0.336000000000002607`\ cw[2]\ cw[3] - 
          4.80000000000001136`\ cb[2]\ cw[2]\ cw[3] - 
          96\ cb[3]\ cw[2]\ cw[3] - 1.20000000000000284`\ cw[2]\^2\ cw[3] + 
          0.479999999999998649`\ cw[3]\^2 - 32\ cb[2]\ cw[3]\^2 - 
          0.0383999999999999808`\ cw[4] + 
          1.35999999999999987`\ cw[2]\ cw[4] - 12\ cw[2]\^2\ cw[4] - 
          0.399999999999999911`\ cw[3]\ cw[4] - 2\ cw[4]\^2 > 0, 
      \(0.0132710400000000006`\[InvisibleSpace]\) - 
          0.0783359999999999612`\ cb[2] + 0.428799999999999048`\ cb[2]\^2 - 
          8.15999999999998593`\ cb[2]\^3 + 96\ cb[2]\^4 - 
          0.433920000000002747`\ cb[3] + 10.8479999999999909`\ cb[2]\ cb[3] - 
          115.199999999999969`\ cb[2]\^2\ cb[3] - 
          21.36000000000001`\ cb[3]\^2 + 576\ cb[2]\ cb[3]\^2 + 
          0.947200000000004749`\ cb[4] - 24.4000000000000305`\ cb[2]\ cb[4] + 
          288\ cb[2]\^2\ cb[4] - 95.9999999999999964`\ cb[3]\ cb[4] + 
          136\ cb[4]\^2 + 2.17599999999999393`\ cb[5] - 
          38.3999999999999772`\ cb[2]\ cb[5] + 192\ cb[3]\ cb[5] - 
          2.88000000000000575`\ cb[6] + 64\ cb[2]\ cb[6] - 
          3.20000000000000062`\ cb[7] + 4\ cb[8] - 
          0.0875519999999999853`\ cw[2] + 
          2.19840000000000124`\ cb[2]\ cw[2] - 
          18.2399999999999948`\ cb[2]\^2\ cw[2] + 
          7.63200000000000056`\ cb[3]\ cw[2] - 
          115.199999999999969`\ cb[2]\ cb[3]\ cw[2] + 288\ cb[3]\^2\ cw[2] - 
          17.2799999999999869`\ cb[4]\ cw[2] + 384\ cb[2]\ cb[4]\ cw[2] - 
          28.79999999999999`\ cb[5]\ cw[2] + 48\ cb[6]\ cw[2] + 
          0.156800000000000716`\ cw[2]\^2 - 
          12.2399999999999975`\ cb[2]\ cw[2]\^2 + 288\ cb[2]\^2\ cw[2]\^2 - 
          57.5999999999999801`\ cb[3]\ cw[2]\^2 + 144\ cb[4]\ cw[2]\^2 - 
          4.55999999999999872`\ cw[2]\^3 + 36\ cw[2]\^4 - 
          0.088319999999999954`\ cw[3] + 1.47199999999999908`\ cb[2]\ cw[3] - 
          6.07999999999999563`\ cb[3]\ cw[3] - 
          12.8000000000000024`\ cb[4]\ cw[3] + 32\ cb[5]\ cw[3] + 
          1.80799999999999378`\ cw[2]\ cw[3] - 
          38.3999999999999772`\ cb[2]\ cw[2]\ cw[3] + 
          192\ cb[3]\ cw[2]\ cw[3] - 9.59999999999999431`\ cw[2]\^2\ cw[3] - 
          1.3599999999999992`\ cw[3]\^2 + 64\ cb[2]\ cw[3]\^2 - 
          0.0191999999999999957`\ cw[4] - 
          1.51999999999999886`\ cw[2]\ cw[4] + 24\ cw[2]\^2\ cw[4] - 
          3.20000000000000062`\ cw[3]\ cw[4] + 4\ cw[4]\^2 > 0, 
      \(0.0176947199999999993`\[InvisibleSpace]\) + 
          0.0184320000000000039`\ cb[2] - 2.64959999999999951`\ cb[2]\^2 + 
          35.5199999999999738`\ cb[2]\^3 - 192\ cb[2]\^4 - 
          1.05215999999999776`\ cb[3] + 15.2640000000000224`\ cb[2]\ cb[3] - 
          57.6000000000000778`\ cb[2]\^2\ cb[3] + 
          61.9199999999999928`\ cb[3]\^2 - 1152\ cb[2]\ cb[3]\^2 - 
          2.18240000000001277`\ cb[4] + 64.7999999999999953`\ cb[2]\ cb[4] - 
          576\ cb[2]\^2\ cb[4] - 47.9999999999999982`\ cb[3]\ cb[4] - 
          272\ cb[4]\^2 + 2.36800000000001009`\ cb[5] - 
          19.2000000000000454`\ cb[2]\ cb[5] - 384\ cb[3]\ cb[5] + 
          7.35999999999999143`\ cb[6] - 128\ cb[2]\ cb[6] - 
          1.59999999999999964`\ cb[7] - 8\ cb[8] + 
          0.129024000000000071`\ cw[2] - 2.57279999999999997`\ cb[2]\ cw[2] + 
          17.2799999999999904`\ cb[2]\^2\ cw[2] + 
          6.57600000000001472`\ cb[3]\ cw[2] - 
          57.6000000000000778`\ cb[2]\ cb[3]\ cw[2] - 576\ cb[3]\^2\ cw[2] + 
          44.1599999999999415`\ cb[4]\ cw[2] - 768\ cb[2]\ cb[4]\ cw[2] - 
          14.4000000000000198`\ cb[5]\ cw[2] - 96\ cb[6]\ cw[2] - 
          1.30560000000000187`\ cw[2]\^2 + 
          53.2800000000000117`\ cb[2]\ cw[2]\^2 - 576\ cb[2]\^2\ cw[2]\^2 - 
          28.8000000000000397`\ cb[3]\ cw[2]\^2 - 288\ cb[4]\ cw[2]\^2 + 
          4.31999999999999761`\ cw[2]\^3 - 72\ cw[2]\^4 + 
          0.0486399999999999632`\ cw[3] - 
          0.704000000000000181`\ cb[2]\ cw[3] + 
          5.7599999999999909`\ cb[3]\ cw[3] - 
          6.39999999999999857`\ cb[4]\ cw[3] - 64\ cb[5]\ cw[3] + 
          2.5440000000000098`\ cw[2]\ cw[3] - 
          19.2000000000000454`\ cb[2]\ cw[2]\ cw[3] - 
          384\ cb[3]\ cw[2]\ cw[3] - 4.80000000000001136`\ cw[2]\^2\ cw[3] + 
          5.91999999999999548`\ cw[3]\^2 - 128\ cb[2]\ cw[3]\^2 + 
          0.0063999999999999888`\ cw[4] + 
          1.43999999999999772`\ cw[2]\ cw[4] - 48\ cw[2]\^2\ cw[4] - 
          1.59999999999999964`\ cw[3]\ cw[4] - 8\ cw[4]\^2 > 0, 
      \(0.00589824000000000037`\[InvisibleSpace]\) + 
          0.149503999999999992`\ cb[2] - 1.45920000000000227`\ cb[2]\^2 - 
          3.35999999999998877`\ cb[2]\^3 + 96\ cb[2]\^4 + 
          0.174080000000000945`\ cb[3] - 16.5120000000000004`\ cb[2]\ cb[3] + 
          172.80000000000002`\ cb[2]\^2\ cb[3] - 
          4.55999999999999872`\ cb[3]\^2 + 576\ cb[2]\ cb[3]\^2 - 
          1.16479999999999539`\ cb[4] - 4.39999999999998703`\ cb[2]\ cb[4] + 
          288\ cb[2]\^2\ cb[4] + 143.999999999999994`\ cb[3]\ cb[4] + 
          136\ cb[4]\^2 - 2.94400000000000261`\ cb[5] + 
          57.6000000000000245`\ cb[2]\ cb[5] + 192\ cb[3]\ cb[5] - 
          0.479999999999996429`\ cb[6] + 64\ cb[2]\ cb[6] + 
          4.80000000000000071`\ cb[7] + 4\ cb[8] + 
          0.124927999999999994`\ cw[2] - 1.30559999999999964`\ cb[2]\ cw[2] + 
          0.960000000000006181`\ cb[2]\^2\ cw[2] - 
          9.40800000000000302`\ cb[3]\ cw[2] + 
          172.80000000000002`\ cb[2]\ cb[3]\ cw[2] + 288\ cb[3]\^2\ cw[2] - 
          2.8799999999999617`\ cb[4]\ cw[2] + 384\ cb[2]\ cb[4]\ cw[2] + 
          43.2000000000000028`\ cb[5]\ cw[2] + 48\ cb[6]\ cw[2] - 
          0.691200000000001146`\ cw[2]\^2 - 
          5.04000000000000181`\ cb[2]\ cw[2]\^2 + 288\ cb[2]\^2\ cw[2]\^2 + 
          86.4000000000000056`\ cb[3]\ cw[2]\^2 + 144\ cb[4]\ cw[2]\^2 + 
          0.240000000000001545`\ cw[2]\^3 + 36\ cw[2]\^4 + 
          0.0716800000000000192`\ cw[3] - 
          0.767999999999999349`\ cb[2]\ cw[3] + 
          0.320000000000005613`\ cb[3]\ cw[3] + 
          19.2000000000000028`\ cb[4]\ cw[3] + 32\ cb[5]\ cw[3] - 
          2.75200000000000155`\ cw[2]\ cw[3] + 
          57.6000000000000245`\ cb[2]\ cw[2]\ cw[3] + 
          192\ cb[3]\ cw[2]\ cw[3] + 14.4000000000000056`\ cw[2]\^2\ cw[3] - 
          0.559999999999997122`\ cw[3]\^2 + 64\ cb[2]\ cw[3]\^2 + 
          0.0128000000000000069`\ cw[4] + 
          0.0800000000000014033`\ cw[2]\ cw[4] + 24\ cw[2]\^2\ cw[4] + 
          4.80000000000000071`\ cw[3]\ cw[4] + 4\ cw[4]\^2 > 0, 
      \(0.00442368000000000005`\[InvisibleSpace]\) + 
          0.0430079999999999884`\ cb[2] - 0.422399999999999842`\ cb[2]\^2 + 
          2.87999999999999278`\ cb[2]\^3 - 48\ cb[2]\^4 - 
          0.151039999999999841`\ cb[3] + 2.01600000000000711`\ cb[2]\ cb[3] - 
          14.4000000000000198`\ cb[2]\^2\ cb[3] + 
          12.4799999999999999`\ cb[3]\^2 - 288\ cb[2]\ cb[3]\^2 - 
          0.505600000000003291`\ cb[4] + 15.2000000000000001`\ cb[2]\ cb[4] - 
          144\ cb[2]\^2\ cb[4] - 11.9999999999999996`\ cb[3]\ cb[4] - 
          68\ cb[4]\^2 + 0.592000000000002657`\ cb[5] - 
          4.80000000000001136`\ cb[2]\ cb[5] - 96\ cb[3]\ cb[5] + 
          1.83999999999999772`\ cb[6] - 32\ cb[2]\ cb[6] - 
          0.399999999999999911`\ cb[7] - 2\ cb[8] - 
          0.00614399999999997259`\ cw[2] - 
          0.883199999999999896`\ cb[2]\ cw[2] + 
          16.3200000000000038`\ cb[2]\^2\ cw[2] + 
          2.54400000000000359`\ cb[3]\ cw[2] - 
          14.4000000000000198`\ cb[2]\ cb[3]\ cw[2] - 144\ cb[3]\^2\ cw[2] + 
          11.0399999999999876`\ cb[4]\ cw[2] - 192\ cb[2]\ cb[4]\ cw[2] - 
          3.60000000000000497`\ cb[5]\ cw[2] - 24\ cb[6]\ cw[2] - 
          0.326400000000000689`\ cw[2]\^2 + 
          4.3200000000000065`\ cb[2]\ cw[2]\^2 - 144\ cb[2]\^2\ cw[2]\^2 - 
          7.20000000000000994`\ cb[3]\ cw[2]\^2 - 72\ cb[4]\ cw[2]\^2 + 
          4.08000000000000095`\ cw[2]\^3 - 18\ cw[2]\^4 - 
          0.0998400000000000353`\ cw[3] + 
          1.02400000000000046`\ cb[2]\ cw[3] + 
          5.4399999999999995`\ cb[3]\ cw[3] - 
          1.59999999999999964`\ cb[4]\ cw[3] - 16\ cb[5]\ cw[3] + 
          0.336000000000002607`\ cw[2]\ cw[3] - 
          4.80000000000001136`\ cb[2]\ cw[2]\ cw[3] - 
          96\ cb[3]\ cw[2]\ cw[3] - 1.20000000000000284`\ cw[2]\^2\ cw[3] + 
          0.479999999999998649`\ cw[3]\^2 - 32\ cb[2]\ cw[3]\^2 - 
          0.0383999999999999808`\ cw[4] + 
          1.35999999999999987`\ cw[2]\ cw[4] - 12\ cw[2]\^2\ cw[4] - 
          0.399999999999999911`\ cw[3]\ cw[4] - 2\ cw[4]\^2 > 0, 
      \(0.00589824000000000125`\[InvisibleSpace]\) + 
          0.149503999999999965`\ cb[2] - 1.45920000000000227`\ cb[2]\^2 - 
          3.35999999999998877`\ cb[2]\^3 + 96\ cb[2]\^4 + 
          0.174080000000000856`\ cb[3] - 16.5120000000000066`\ cb[2]\ cb[3] + 
          172.80000000000002`\ cb[2]\^2\ cb[3] - 
          4.55999999999999872`\ cb[3]\^2 + 576\ cb[2]\ cb[3]\^2 - 
          1.16479999999999539`\ cb[4] - 4.39999999999998703`\ cb[2]\ cb[4] + 
          288\ cb[2]\^2\ cb[4] + 143.999999999999994`\ cb[3]\ cb[4] + 
          136\ cb[4]\^2 - 2.94400000000000261`\ cb[5] + 
          57.6000000000000245`\ cb[2]\ cb[5] + 192\ cb[3]\ cb[5] - 
          0.479999999999996429`\ cb[6] + 64\ cb[2]\ cb[6] + 
          4.80000000000000071`\ cb[7] + 4\ cb[8] + 
          0.124927999999999994`\ cw[2] - 1.30559999999999876`\ cb[2]\ cw[2] + 
          0.959999999999999076`\ cb[2]\^2\ cw[2] - 
          9.40800000000000657`\ cb[3]\ cw[2] + 
          172.80000000000002`\ cb[2]\ cb[3]\ cw[2] + 288\ cb[3]\^2\ cw[2] - 
          2.8799999999999617`\ cb[4]\ cw[2] + 384\ cb[2]\ cb[4]\ cw[2] + 
          43.2000000000000028`\ cb[5]\ cw[2] + 48\ cb[6]\ cw[2] - 
          0.691200000000001146`\ cw[2]\^2 - 
          5.04000000000000181`\ cb[2]\ cw[2]\^2 + 288\ cb[2]\^2\ cw[2]\^2 + 
          86.4000000000000056`\ cb[3]\ cw[2]\^2 + 144\ cb[4]\ cw[2]\^2 + 
          0.239999999999999769`\ cw[2]\^3 + 36\ cw[2]\^4 + 
          0.0716800000000000547`\ cw[3] - 
          0.767999999999999349`\ cb[2]\ cw[3] + 
          0.320000000000005613`\ cb[3]\ cw[3] + 
          19.2000000000000028`\ cb[4]\ cw[3] + 32\ cb[5]\ cw[3] - 
          2.75200000000000155`\ cw[2]\ cw[3] + 
          57.6000000000000245`\ cb[2]\ cw[2]\ cw[3] + 
          192\ cb[3]\ cw[2]\ cw[3] + 14.4000000000000056`\ cw[2]\^2\ cw[3] - 
          0.559999999999997122`\ cw[3]\^2 + 64\ cb[2]\ cw[3]\^2 + 
          0.0128000000000000069`\ cw[4] + 
          0.0800000000000014033`\ cw[2]\ cw[4] + 24\ cw[2]\^2\ cw[4] + 
          4.80000000000000071`\ cw[3]\ cw[4] + 4\ cw[4]\^2 > 0, 
      \(0.00196608000000000071`\[InvisibleSpace]\) + 
          0.114688000000000034`\ cb[2] + 0.921599999999999042`\ cb[2]\^2 - 
          11.5200000000000102`\ cb[2]\^3 - 48\ cb[2]\^4 + 
          0.552960000000000118`\ cb[3] - 2.30400000000001536`\ cb[2]\ cb[3] - 
          158.400000000000034`\ cb[2]\^2\ cb[3] - 
          25.9200000000000008`\ cb[3]\^2 - 288\ cb[2]\ cb[3]\^2 + 
          0.870400000000000417`\ cb[4] - 28.8000000000000113`\ cb[2]\ cb[4] - 
          144\ cb[2]\^2\ cb[4] - 131.999999999999984`\ cb[3]\ cb[4] - 
          68\ cb[4]\^2 - 0.448000000000001463`\ cb[5] - 
          52.8000000000000202`\ cb[2]\ cb[5] - 96\ cb[3]\ cb[5] - 
          3.36000000000000209`\ cb[6] - 32\ cb[2]\ cb[6] - 
          4.39999999999999946`\ cb[7] - 2\ cb[8] + 
          0.0860160000000000124`\ cw[2] + 
          1.22879999999999967`\ cb[2]\ cw[2] - 
          17.2800000000000046`\ cb[2]\^2\ cw[2] - 
          1.53600000000000225`\ cb[3]\ cw[2] - 
          158.400000000000034`\ cb[2]\ cb[3]\ cw[2] - 144\ cb[3]\^2\ cw[2] - 
          20.1600000000000223`\ cb[4]\ cw[2] - 192\ cb[2]\ cb[4]\ cw[2] - 
          39.6000000000000085`\ cb[5]\ cw[2] - 24\ cb[6]\ cw[2] + 
          0.5375999999999995`\ cw[2]\^2 - 
          17.2799999999999931`\ cb[2]\ cw[2]\^2 - 144\ cb[2]\^2\ cw[2]\^2 - 
          79.200000000000017`\ cb[3]\ cw[2]\^2 - 72\ cb[4]\ cw[2]\^2 - 
          4.32000000000000117`\ cw[2]\^3 - 18\ cw[2]\^4 + 
          0.092159999999999993`\ cw[3] - 
          0.256000000000000449`\ cb[2]\ cw[3] - 
          5.76000000000000333`\ cb[3]\ cw[3] - 
          17.5999999999999978`\ cb[4]\ cw[3] - 16\ cb[5]\ cw[3] - 
          0.384000000000001406`\ cw[2]\ cw[3] - 
          52.8000000000000202`\ cb[2]\ cw[2]\ cw[3] - 
          96\ cb[3]\ cw[2]\ cw[3] - 13.200000000000005`\ cw[2]\^2\ cw[3] - 
          1.9200000000000017`\ cw[3]\^2 - 32\ cb[2]\ cw[3]\^2 + 
          0.0255999999999999872`\ cw[4] - 
          1.44000000000000083`\ cw[2]\ cw[4] - 12\ cw[2]\^2\ cw[4] - 
          4.39999999999999946`\ cw[3]\ cw[4] - 2\ cw[4]\^2 > 0, 
      \(0.00331776000000000026`\[InvisibleSpace]\) + 
          0.00921599999999999575`\ cb[2] + 0.387199999999999544`\ cb[2]\^2 + 
          0.960000000000001207`\ cb[2]\^3 + 24\ cb[2]\^4 - 
          0.0844800000000006612`\ cb[3] + 
          2.11199999999999921`\ cb[2]\ cb[3] - 
          28.79999999999999`\ cb[2]\^2\ cb[3] - 
          3.84000000000000376`\ cb[3]\^2 + 144\ cb[2]\ cb[3]\^2 + 
          0.116800000000001324`\ cb[4] - 5.60000000000000852`\ cb[2]\ cb[4] + 
          72\ cb[2]\^2\ cb[4] - 23.9999999999999991`\ cb[3]\ cb[4] + 
          34\ cb[4]\^2 + 0.543999999999998529`\ cb[5] - 
          9.59999999999999431`\ cb[2]\ cb[5] + 48\ cb[3]\ cb[5] - 
          0.720000000000001438`\ cb[6] + 16\ cb[2]\ cb[6] - 
          0.800000000000000177`\ cb[7] + cb[8] - 
          0.050688000000000013`\ cw[2] - 
          0.230400000000000426`\ cb[2]\ cw[2] - 
          10.559999999999996`\ cb[2]\^2\ cw[2] + 
          2.20799999999999974`\ cb[3]\ cw[2] - 
          28.79999999999999`\ cb[2]\ cb[3]\ cw[2] + 72\ cb[3]\^2\ cw[2] - 
          4.31999999999999673`\ cb[4]\ cw[2] + 96\ cb[2]\ cb[4]\ cw[2] - 
          7.19999999999999751`\ cb[5]\ cw[2] + 12\ cb[6]\ cw[2] + 
          0.539199999999999768`\ cw[2]\^2 + 
          1.43999999999999683`\ cb[2]\ cw[2]\^2 + 72\ cb[2]\^2\ cw[2]\^2 - 
          14.399999999999995`\ cb[3]\ cw[2]\^2 + 36\ cb[4]\ cw[2]\^2 - 
          2.63999999999999879`\ cw[2]\^3 + 9\ cw[2]\^4 - 
          0.0460799999999999787`\ cw[3] + 
          0.767999999999999616`\ cb[2]\ cw[3] - 
          3.51999999999999912`\ cb[3]\ cw[3] - 
          3.20000000000000062`\ cb[4]\ cw[3] + 8\ cb[5]\ cw[3] + 
          0.351999999999998447`\ cw[2]\ cw[3] - 
          9.59999999999999431`\ cb[2]\ cw[2]\ cw[3] + 
          48\ cb[3]\ cw[2]\ cw[3] - 2.39999999999999857`\ cw[2]\^2\ cw[3] + 
          0.160000000000000586`\ cw[3]\^2 + 16\ cb[2]\ cw[3]\^2 + 
          0.115200000000000013`\ cw[4] - 
          0.879999999999999715`\ cw[2]\ cw[4] + 6\ cw[2]\^2\ cw[4] - 
          0.800000000000000177`\ cw[3]\ cw[4] + cw[4]\^2 > 0, 
      \(0.00442368000000000094`\[InvisibleSpace]\) + 
          0.0430079999999999884`\ cb[2] - 0.422399999999999753`\ cb[2]\^2 + 
          2.87999999999999278`\ cb[2]\^3 - 48\ cb[2]\^4 - 
          0.151039999999999841`\ cb[3] + 2.01600000000000711`\ cb[2]\ cb[3] - 
          14.4000000000000198`\ cb[2]\^2\ cb[3] + 
          12.4799999999999999`\ cb[3]\^2 - 288\ cb[2]\ cb[3]\^2 - 
          0.505600000000003113`\ cb[4] + 15.2000000000000001`\ cb[2]\ cb[4] - 
          144\ cb[2]\^2\ cb[4] - 11.9999999999999996`\ cb[3]\ cb[4] - 
          68\ cb[4]\^2 + 0.592000000000002657`\ cb[5] - 
          4.80000000000001136`\ cb[2]\ cb[5] - 96\ cb[3]\ cb[5] + 
          1.83999999999999772`\ cb[6] - 32\ cb[2]\ cb[6] - 
          0.399999999999999911`\ cb[7] - 2\ cb[8] - 
          0.00614399999999999657`\ cw[2] - 
          0.883199999999999718`\ cb[2]\ cw[2] + 
          16.3200000000000038`\ cb[2]\^2\ cw[2] + 
          2.54400000000000359`\ cb[3]\ cw[2] - 
          14.4000000000000198`\ cb[2]\ cb[3]\ cw[2] - 144\ cb[3]\^2\ cw[2] + 
          11.0399999999999876`\ cb[4]\ cw[2] - 192\ cb[2]\ cb[4]\ cw[2] - 
          3.60000000000000497`\ cb[5]\ cw[2] - 24\ cb[6]\ cw[2] - 
          0.326400000000000556`\ cw[2]\^2 + 
          4.3200000000000065`\ cb[2]\ cw[2]\^2 - 144\ cb[2]\^2\ cw[2]\^2 - 
          7.20000000000000994`\ cb[3]\ cw[2]\^2 - 72\ cb[4]\ cw[2]\^2 + 
          4.08000000000000095`\ cw[2]\^3 - 18\ cw[2]\^4 - 
          0.0998399999999999998`\ cw[3] + 
          1.02400000000000046`\ cb[2]\ cw[3] + 
          5.4399999999999995`\ cb[3]\ cw[3] - 
          1.59999999999999964`\ cb[4]\ cw[3] - 16\ cb[5]\ cw[3] + 
          0.336000000000002607`\ cw[2]\ cw[3] - 
          4.80000000000001136`\ cb[2]\ cw[2]\ cw[3] - 
          96\ cb[3]\ cw[2]\ cw[3] - 1.20000000000000284`\ cw[2]\^2\ cw[3] + 
          0.479999999999998649`\ cw[3]\^2 - 32\ cb[2]\ cw[3]\^2 - 
          0.0383999999999999896`\ cw[4] + 
          1.35999999999999987`\ cw[2]\ cw[4] - 12\ cw[2]\^2\ cw[4] - 
          0.399999999999999911`\ cw[3]\ cw[4] - 2\ cw[4]\^2 > 0, 
      \(0.00147456000000000049`\[InvisibleSpace]\) + 
          0.0501760000000000072`\ cb[2] + 0.115199999999999191`\ cb[2]\^2 + 
          2.16000000000000103`\ cb[2]\^3 + 24\ cb[2]\^4 + 
          0.107520000000000148`\ cb[3] - 1.72800000000000313`\ cb[2]\ cb[3] + 
          43.2000000000000028`\ cb[2]\^2\ cb[3] + 
          0.359999999999998987`\ cb[3]\^2 + 144\ cb[2]\ cb[3]\^2 - 
          0.211199999999998899`\ cb[4] - 0.5999999999999992`\ cb[2]\ cb[4] + 
          72\ cb[2]\^2\ cb[4] + 36.0000000000000008`\ cb[3]\ cb[4] + 
          34\ cb[4]\^2 - 0.736000000000000831`\ cb[5] + 
          14.4000000000000056`\ cb[2]\ cb[5] + 48\ cb[3]\ cb[5] - 
          0.119999999999999108`\ cb[6] + 16\ cb[2]\ cb[6] + 
          1.20000000000000017`\ cb[7] + cb[8] + 
          0.0184319999999999986`\ cw[2] - 
          0.806400000000000005`\ cb[2]\ cw[2] - 
          5.76000000000000156`\ cb[2]\^2\ cw[2] - 
          3.55200000000000049`\ cb[3]\ cw[2] + 
          43.2000000000000028`\ cb[2]\ cb[3]\ cw[2] + 72\ cb[3]\^2\ cw[2] - 
          0.719999999999990425`\ cb[4]\ cw[2] + 96\ cb[2]\ cb[4]\ cw[2] + 
          10.8000000000000007`\ cb[5]\ cw[2] + 12\ cb[6]\ cw[2] - 
          0.172800000000000402`\ cw[2]\^2 + 
          3.23999999999999932`\ cb[2]\ cw[2]\^2 + 72\ cb[2]\^2\ cw[2]\^2 + 
          21.6000000000000014`\ cb[3]\ cw[2]\^2 + 36\ cb[4]\ cw[2]\^2 - 
          1.44000000000000039`\ cw[2]\^3 + 9\ cw[2]\^4 - 
          0.0460800000000000409`\ cw[3] - 
          1.79199999999999963`\ cb[2]\ cw[3] - 
          1.91999999999999815`\ cb[3]\ cw[3] + 
          4.80000000000000071`\ cb[4]\ cw[3] + 8\ cb[5]\ cw[3] - 
          0.288000000000000166`\ cw[2]\ cw[3] + 
          14.4000000000000056`\ cb[2]\ cw[2]\ cw[3] + 
          48\ cb[3]\ cw[2]\ cw[3] + 3.60000000000000142`\ cw[2]\^2\ cw[3] + 
          0.360000000000000541`\ cw[3]\^2 + 16\ cb[2]\ cw[3]\^2 - 
          0.0768000000000000238`\ cw[4] - 
          0.479999999999999538`\ cw[2]\ cw[4] + 6\ cw[2]\^2\ cw[4] + 
          1.20000000000000017`\ cw[3]\ cw[4] + cw[4]\^2 > 0, 
      \(0.00442368000000000094`\[InvisibleSpace]\) + 
          0.0430079999999999884`\ cb[2] - 0.422399999999999842`\ cb[2]\^2 + 
          2.87999999999999278`\ cb[2]\^3 - 48\ cb[2]\^4 - 
          0.151039999999999841`\ cb[3] + 2.01600000000000711`\ cb[2]\ cb[3] - 
          14.4000000000000198`\ cb[2]\^2\ cb[3] + 
          12.4799999999999999`\ cb[3]\^2 - 288\ cb[2]\ cb[3]\^2 - 
          0.505600000000003291`\ cb[4] + 15.2000000000000001`\ cb[2]\ cb[4] - 
          144\ cb[2]\^2\ cb[4] - 11.9999999999999996`\ cb[3]\ cb[4] - 
          68\ cb[4]\^2 + 0.592000000000002657`\ cb[5] - 
          4.80000000000001136`\ cb[2]\ cb[5] - 96\ cb[3]\ cb[5] + 
          1.83999999999999772`\ cb[6] - 32\ cb[2]\ cb[6] - 
          0.399999999999999911`\ cb[7] - 2\ cb[8] - 
          0.00614399999999999657`\ cw[2] - 
          0.883199999999999718`\ cb[2]\ cw[2] + 
          16.3200000000000073`\ cb[2]\^2\ cw[2] + 
          2.54400000000000359`\ cb[3]\ cw[2] - 
          14.4000000000000198`\ cb[2]\ cb[3]\ cw[2] - 144\ cb[3]\^2\ cw[2] + 
          11.0399999999999876`\ cb[4]\ cw[2] - 192\ cb[2]\ cb[4]\ cw[2] - 
          3.60000000000000497`\ cb[5]\ cw[2] - 24\ cb[6]\ cw[2] - 
          0.326400000000000689`\ cw[2]\^2 + 
          4.3200000000000065`\ cb[2]\ cw[2]\^2 - 144\ cb[2]\^2\ cw[2]\^2 - 
          7.20000000000000994`\ cb[3]\ cw[2]\^2 - 72\ cb[4]\ cw[2]\^2 + 
          4.08000000000000184`\ cw[2]\^3 - 18\ cw[2]\^4 - 
          0.0998400000000000531`\ cw[3] + 1.0240000000000009`\ cb[2]\ cw[3] + 
          5.4399999999999995`\ cb[3]\ cw[3] - 
          1.59999999999999964`\ cb[4]\ cw[3] - 16\ cb[5]\ cw[3] + 
          0.336000000000002607`\ cw[2]\ cw[3] - 
          4.80000000000001136`\ cb[2]\ cw[2]\ cw[3] - 
          96\ cb[3]\ cw[2]\ cw[3] - 1.20000000000000284`\ cw[2]\^2\ cw[3] + 
          0.479999999999998649`\ cw[3]\^2 - 32\ cb[2]\ cw[3]\^2 - 
          0.0383999999999999896`\ cw[4] + 
          1.35999999999999987`\ cw[2]\ cw[4] - 12\ cw[2]\^2\ cw[4] - 
          0.399999999999999911`\ cw[3]\ cw[4] - 2\ cw[4]\^2 > 0, 
      \(0.00589824000000000214`\[InvisibleSpace]\) + 
          0.149503999999999965`\ cb[2] - 1.45920000000000227`\ cb[2]\^2 - 
          3.35999999999998877`\ cb[2]\^3 + 96\ cb[2]\^4 + 
          0.174080000000000723`\ cb[3] - 16.5120000000000155`\ cb[2]\ cb[3] + 
          172.80000000000002`\ cb[2]\^2\ cb[3] - 
          4.55999999999999872`\ cb[3]\^2 + 576\ cb[2]\ cb[3]\^2 - 
          1.16479999999999539`\ cb[4] - 4.39999999999998703`\ cb[2]\ cb[4] + 
          288\ cb[2]\^2\ cb[4] + 143.999999999999994`\ cb[3]\ cb[4] + 
          136\ cb[4]\^2 - 2.94400000000000261`\ cb[5] + 
          57.6000000000000245`\ cb[2]\ cb[5] + 192\ cb[3]\ cb[5] - 
          0.479999999999996429`\ cb[6] + 64\ cb[2]\ cb[6] + 
          4.80000000000000071`\ cb[7] + 4\ cb[8] + 
          0.124928000000000016`\ cw[2] - 1.30559999999999876`\ cb[2]\ cw[2] + 
          0.959999999999995523`\ cb[2]\^2\ cw[2] - 
          9.40800000000000302`\ cb[3]\ cw[2] + 
          172.80000000000002`\ cb[2]\ cb[3]\ cw[2] + 288\ cb[3]\^2\ cw[2] - 
          2.8799999999999617`\ cb[4]\ cw[2] + 384\ cb[2]\ cb[4]\ cw[2] + 
          43.2000000000000028`\ cb[5]\ cw[2] + 48\ cb[6]\ cw[2] - 
          0.691200000000001146`\ cw[2]\^2 - 
          5.04000000000000181`\ cb[2]\ cw[2]\^2 + 288\ cb[2]\^2\ cw[2]\^2 + 
          86.4000000000000056`\ cb[3]\ cw[2]\^2 + 144\ cb[4]\ cw[2]\^2 + 
          0.23999999999999888`\ cw[2]\^3 + 36\ cw[2]\^4 + 
          0.0716800000000000192`\ cw[3] - 
          0.768000000000000238`\ cb[2]\ cw[3] + 
          0.320000000000005613`\ cb[3]\ cw[3] + 
          19.2000000000000028`\ cb[4]\ cw[3] + 32\ cb[5]\ cw[3] - 
          2.75200000000000155`\ cw[2]\ cw[3] + 
          57.6000000000000245`\ cb[2]\ cw[2]\ cw[3] + 
          192\ cb[3]\ cw[2]\ cw[3] + 14.4000000000000056`\ cw[2]\^2\ cw[3] - 
          0.559999999999997122`\ cw[3]\^2 + 64\ cb[2]\ cw[3]\^2 + 
          0.012799999999999978`\ cw[4] + 
          0.0800000000000014033`\ cw[2]\ cw[4] + 24\ cw[2]\^2\ cw[4] + 
          4.80000000000000071`\ cw[3]\ cw[4] + 4\ cw[4]\^2 > 0, 
      \(0.00196608000000000124`\[InvisibleSpace]\) + 
          0.114688000000000034`\ cb[2] + 0.921599999999999042`\ cb[2]\^2 - 
          11.5200000000000102`\ cb[2]\^3 - 48\ cb[2]\^4 + 
          0.552960000000000118`\ cb[3] - 2.30400000000001003`\ cb[2]\ cb[3] - 
          158.400000000000034`\ cb[2]\^2\ cb[3] - 
          25.9200000000000008`\ cb[3]\^2 - 288\ cb[2]\ cb[3]\^2 + 
          0.870400000000000417`\ cb[4] - 28.8000000000000113`\ cb[2]\ cb[4] - 
          144\ cb[2]\^2\ cb[4] - 131.999999999999984`\ cb[3]\ cb[4] - 
          68\ cb[4]\^2 - 0.448000000000001374`\ cb[5] - 
          52.8000000000000202`\ cb[2]\ cb[5] - 96\ cb[3]\ cb[5] - 
          3.36000000000000209`\ cb[6] - 32\ cb[2]\ cb[6] - 
          4.39999999999999946`\ cb[7] - 2\ cb[8] + 
          0.0860160000000000302`\ cw[2] + 
          1.22879999999999989`\ cb[2]\ cw[2] - 
          17.280000000000002`\ cb[2]\^2\ cw[2] - 
          1.53600000000000047`\ cb[3]\ cw[2] - 
          158.400000000000034`\ cb[2]\ cb[3]\ cw[2] - 144\ cb[3]\^2\ cw[2] - 
          20.1600000000000223`\ cb[4]\ cw[2] - 192\ cb[2]\ cb[4]\ cw[2] - 
          39.6000000000000085`\ cb[5]\ cw[2] - 24\ cb[6]\ cw[2] + 
          0.5375999999999995`\ cw[2]\^2 - 
          17.2799999999999931`\ cb[2]\ cw[2]\^2 - 144\ cb[2]\^2\ cw[2]\^2 - 
          79.200000000000017`\ cb[3]\ cw[2]\^2 - 72\ cb[4]\ cw[2]\^2 - 
          4.32000000000000028`\ cw[2]\^3 - 18\ cw[2]\^4 + 
          0.0921600000000000108`\ cw[3] - 
          0.256000000000000316`\ cb[2]\ cw[3] - 
          5.76000000000000333`\ cb[3]\ cw[3] - 
          17.5999999999999978`\ cb[4]\ cw[3] - 16\ cb[5]\ cw[3] - 
          0.384000000000001406`\ cw[2]\ cw[3] - 
          52.8000000000000202`\ cb[2]\ cw[2]\ cw[3] - 
          96\ cb[3]\ cw[2]\ cw[3] - 13.200000000000005`\ cw[2]\^2\ cw[3] - 
          1.9200000000000017`\ cw[3]\^2 - 32\ cb[2]\ cw[3]\^2 + 
          0.0256000000000000049`\ cw[4] - 
          1.44000000000000083`\ cw[2]\ cw[4] - 12\ cw[2]\^2\ cw[4] - 
          4.39999999999999946`\ cw[3]\ cw[4] - 2\ cw[4]\^2 > 0, 
      \(0.00147456000000000049`\[InvisibleSpace]\) + 
          0.0501760000000000072`\ cb[2] + 0.115199999999999191`\ cb[2]\^2 + 
          2.16000000000000103`\ cb[2]\^3 + 24\ cb[2]\^4 + 
          0.10752000000000017`\ cb[3] - 1.72800000000000313`\ cb[2]\ cb[3] + 
          43.2000000000000028`\ cb[2]\^2\ cb[3] + 
          0.359999999999998987`\ cb[3]\^2 + 144\ cb[2]\ cb[3]\^2 - 
          0.211199999999998899`\ cb[4] - 0.5999999999999992`\ cb[2]\ cb[4] + 
          72\ cb[2]\^2\ cb[4] + 36.0000000000000008`\ cb[3]\ cb[4] + 
          34\ cb[4]\^2 - 0.736000000000000831`\ cb[5] + 
          14.4000000000000056`\ cb[2]\ cb[5] + 48\ cb[3]\ cb[5] - 
          0.119999999999999108`\ cb[6] + 16\ cb[2]\ cb[6] + 
          1.20000000000000017`\ cb[7] + cb[8] + 
          0.0184320000000000021`\ cw[2] - 
          0.806400000000000005`\ cb[2]\ cw[2] - 
          5.76000000000000156`\ cb[2]\^2\ cw[2] - 
          3.55200000000000049`\ cb[3]\ cw[2] + 
          43.2000000000000028`\ cb[2]\ cb[3]\ cw[2] + 72\ cb[3]\^2\ cw[2] - 
          0.719999999999990425`\ cb[4]\ cw[2] + 96\ cb[2]\ cb[4]\ cw[2] + 
          10.8000000000000007`\ cb[5]\ cw[2] + 12\ cb[6]\ cw[2] - 
          0.172800000000000402`\ cw[2]\^2 + 
          3.23999999999999932`\ cb[2]\ cw[2]\^2 + 72\ cb[2]\^2\ cw[2]\^2 + 
          21.6000000000000014`\ cb[3]\ cw[2]\^2 + 36\ cb[4]\ cw[2]\^2 - 
          1.44000000000000039`\ cw[2]\^3 + 9\ cw[2]\^4 - 
          0.0460800000000000054`\ cw[3] - 
          1.79199999999999999`\ cb[2]\ cw[3] - 
          1.91999999999999815`\ cb[3]\ cw[3] + 
          4.80000000000000071`\ cb[4]\ cw[3] + 8\ cb[5]\ cw[3] - 
          0.288000000000000166`\ cw[2]\ cw[3] + 
          14.4000000000000056`\ cb[2]\ cw[2]\ cw[3] + 
          48\ cb[3]\ cw[2]\ cw[3] + 3.60000000000000142`\ cw[2]\^2\ cw[3] + 
          0.360000000000000541`\ cw[3]\^2 + 16\ cb[2]\ cw[3]\^2 - 
          0.0768000000000000238`\ cw[4] - 
          0.479999999999999538`\ cw[2]\ cw[4] + 6\ cw[2]\^2\ cw[4] + 
          1.20000000000000017`\ cw[3]\ cw[4] + cw[4]\^2 > 0, 
      \(0.00196608000000000124`\[InvisibleSpace]\) + 
          0.114688000000000078`\ cb[2] + 0.921599999999999042`\ cb[2]\^2 - 
          11.5200000000000102`\ cb[2]\^3 - 48\ cb[2]\^4 + 
          0.552960000000000206`\ cb[3] - 2.30400000000000293`\ cb[2]\ cb[3] - 
          158.400000000000034`\ cb[2]\^2\ cb[3] - 
          25.9200000000000008`\ cb[3]\^2 - 288\ cb[2]\ cb[3]\^2 + 
          0.870400000000000773`\ cb[4] - 28.8000000000000113`\ cb[2]\ cb[4] - 
          144\ cb[2]\^2\ cb[4] - 131.999999999999984`\ cb[3]\ cb[4] - 
          68\ cb[4]\^2 - 0.448000000000001197`\ cb[5] - 
          52.8000000000000202`\ cb[2]\ cb[5] - 96\ cb[3]\ cb[5] - 
          3.36000000000000209`\ cb[6] - 32\ cb[2]\ cb[6] - 
          4.39999999999999946`\ cb[7] - 2\ cb[8] + 
          0.0860160000000000302`\ cw[2] + 
          1.22879999999999989`\ cb[2]\ cw[2] - 
          17.2799999999999975`\ cb[2]\^2\ cw[2] - 
          1.53600000000000047`\ cb[3]\ cw[2] - 
          158.400000000000034`\ cb[2]\ cb[3]\ cw[2] - 144\ cb[3]\^2\ cw[2] - 
          20.1600000000000223`\ cb[4]\ cw[2] - 192\ cb[2]\ cb[4]\ cw[2] - 
          39.6000000000000085`\ cb[5]\ cw[2] - 24\ cb[6]\ cw[2] + 
          0.5375999999999995`\ cw[2]\^2 - 
          17.2799999999999931`\ cb[2]\ cw[2]\^2 - 144\ cb[2]\^2\ cw[2]\^2 - 
          79.200000000000017`\ cb[3]\ cw[2]\^2 - 72\ cb[4]\ cw[2]\^2 - 
          4.31999999999999939`\ cw[2]\^3 - 18\ cw[2]\^4 + 
          0.0921600000000000108`\ cw[3] - 
          0.255999999999999872`\ cb[2]\ cw[3] - 
          5.76000000000000333`\ cb[3]\ cw[3] - 
          17.5999999999999978`\ cb[4]\ cw[3] - 16\ cb[5]\ cw[3] - 
          0.384000000000001406`\ cw[2]\ cw[3] - 
          52.8000000000000202`\ cb[2]\ cw[2]\ cw[3] - 
          96\ cb[3]\ cw[2]\ cw[3] - 13.200000000000005`\ cw[2]\^2\ cw[3] - 
          1.9200000000000017`\ cw[3]\^2 - 32\ cb[2]\ cw[3]\^2 + 
          0.0256000000000000049`\ cw[4] - 
          1.44000000000000083`\ cw[2]\ cw[4] - 12\ cw[2]\^2\ cw[4] - 
          4.39999999999999946`\ cw[3]\ cw[4] - 2\ cw[4]\^2 > 0, 
      \(0.000655360000000000386`\[InvisibleSpace]\) + 
          0.0655360000000000297`\ cb[2] + 1.84319999999999879`\ cb[2]\^2 + 
          15.3600000000000065`\ cb[2]\^3 + 24\ cb[2]\^4 + 
          0.491520000000000667`\ cb[3] + 18.4320000000000128`\ cb[2]\ cb[3] + 
          115.200000000000013`\ cb[2]\^2\ cb[3] + 
          34.5600000000000084`\ cb[3]\^2 + 144\ cb[2]\ cb[3]\^2 + 
          1.74080000000000119`\ cb[4] + 38.4000000000000127`\ cb[2]\ cb[4] + 
          72\ cb[2]\^2\ cb[4] + 95.9999999999999964`\ cb[3]\ cb[4] + 
          34\ cb[4]\^2 + 3.58400000000000273`\ cb[5] + 
          38.4000000000000074`\ cb[2]\ cb[5] + 48\ cb[3]\ cb[5] + 
          4.48000000000000309`\ cb[6] + 16\ cb[2]\ cb[6] + 
          3.19999999999999973`\ cb[7] + cb[8] + 
          0.0491520000000000223`\ cw[2] + 
          2.45759999999999978`\ cb[2]\ cw[2] + 
          23.0400000000000071`\ cb[2]\^2\ cw[2] + 
          12.28800000000001`\ cb[3]\ cw[2] + 
          115.200000000000013`\ cb[2]\ cb[3]\ cw[2] + 72\ cb[3]\^2\ cw[2] + 
          26.8800000000000149`\ cb[4]\ cw[2] + 96\ cb[2]\ cb[4]\ cw[2] + 
          28.8000000000000042`\ cb[5]\ cw[2] + 12\ cb[6]\ cw[2] + 
          1.07519999999999948`\ cw[2]\^2 + 
          23.0400000000000027`\ cb[2]\ cw[2]\^2 + 72\ cb[2]\^2\ cw[2]\^2 + 
          57.6000000000000067`\ cb[3]\ cw[2]\^2 + 36\ cb[4]\ cw[2]\^2 + 
          5.76000000000000156`\ cw[2]\^3 + 9\ cw[2]\^4 + 
          0.0819200000000000372`\ cw[3] + 
          2.04800000000000048`\ cb[2]\ cw[3] + 
          7.68000000000000326`\ cb[3]\ cw[3] + 
          12.799999999999998`\ cb[4]\ cw[3] + 8\ cb[5]\ cw[3] + 
          3.07200000000000228`\ cw[2]\ cw[3] + 
          38.4000000000000074`\ cb[2]\ cw[2]\ cw[3] + 
          48\ cb[3]\ cw[2]\ cw[3] + 9.60000000000000142`\ cw[2]\^2\ cw[3] + 
          2.56000000000000138`\ cw[3]\^2 + 16\ cb[2]\ cw[3]\^2 + 
          0.0512000000000000099`\ cw[4] + 
          1.92000000000000081`\ cw[2]\ cw[4] + 6\ cw[2]\^2\ cw[4] + 
          3.19999999999999973`\ cw[3]\ cw[4] + cw[4]\^2 > 0}\)], "Output"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData[{
  "MomentLimitsReduced",
  "[c[k],{c[2],c[3],..},\[Delta]p,p,S] gives the bounds on the values of \
c[k], based on constraints on gamete frequencies, and expressed in terms of \
c[].  The c's are given numerically by the list {c[2],c[3],..}."
}], "Subsubsection",
  InitializationCell->True],

Cell["\<\
There are difficulties in dealing with nonlinear constraints.  The \
routine MomentLimitsReduced[..old] works by transforming from cumulants to \
moments, giving linear constraints that can be solved by ConstrainedMax[].  \
The limits are then transformed back.  However, this may not be right in \
general, and in any case does not extend t0o the diploid case.  There, cb[4] \
includes different classes of cumulant, and so can't be transformed.

\tI therefore try writing a scheme that resolves polynomial constraints into \
a set of linear constraints.\
\>", "Text"],

Cell[BoxData[
    \(\(MomentLimitsReduced[c_[k_Integer], cl_List, \[Delta]p_, p_, S_] := 
        MomentLimitsReduced[c[k], cl, 
          HaploidConstraints[c, \[Delta]p, p, S]];\)\)], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(\(MomentLimitsReduced[c_[k_Integer], cl_List, ccs__] := 
        Module[{x, cs, ints, n}, \n\t\tcs = 
            DeleteCases[\((\(ccs /. c[k] -> x\) /. 
                    c[j_] :> cl\[LeftDoubleBracket]
                        j - 1\[RightDoubleBracket])\) // Chop, True]; \n
          ints = IntervalCombine @@ Map[ConstrainedIntervals[#, x] &, cs]; \n
          n = Length[ints]; \n
          If[n > 1, 
            Print["\<WARNING: genotype frequencies valid only in disjunct \
regions. \>", ints]]; \n{ints\[LeftDoubleBracket]1, 1\[RightDoubleBracket], 
            ints\[LeftDoubleBracket]n, 2\[RightDoubleBracket]}];\)\)], "Input",\

  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{

Cell["\<\
MomentLimits[{j,k},p,\[Delta]p,c] gives the bounds on the values of \
c[j,k], based on constraints on gamete frequencies, and expressed in terms of \
c[].  The c's are given numerically. If the constraints cannot be satisfied \
at all, returns {0,0}.\
\>", "Subsubsection"],

Cell[BoxData[
    \(\(MomentLimits[{j_, k_}, p_List, \[Delta]p_List, c_List] := 
        Module[{nl = Length[p], ct, cs, \[CapitalGamma], x, jj, kk, cmin, 
            cmax}, \n\t\tct = 
            ReplacePart[c, x, {j + 1, k + 1}]; \n\t\t\[CapitalGamma] = 
            Matrix\[CapitalGamma][p, \[Delta]p, nl]; 
          gv = \[CapitalGamma] . ct . Transpose[\[CapitalGamma]]; \n\t\tcs = 
            Table[Expand[gv\[LeftDoubleBracket]jj, kk\[RightDoubleBracket]] > 
                0, {jj, 1, 2\^nl}, {kk, 1, jj}]; \ \n\t\tcs = 
            DeleteCases[cs // Flatten, True]; \n\t
          cmin = Check[\(ConstrainedMin[x, 
                  cs, {x}]\)\[LeftDoubleBracket]1\[RightDoubleBracket], \
\(-\(ConstrainedMax[y, 
                    cs /. x -> \(-y\), {y}]\)\[LeftDoubleBracket]1\
\[RightDoubleBracket]\), ConstrainedMax::nsatt]; \n\t\tIf[cmin == 0, 
            cmin = \(-\(ConstrainedMax[y, 
                    cs /. x -> \(-y\), {y}]\)\[LeftDoubleBracket]1\
\[RightDoubleBracket]\)]; \n\t\tcmax = 
            Check[\(ConstrainedMax[x, 
                  cs, {x}]\)\[LeftDoubleBracket]1\[RightDoubleBracket], \
\(-\(ConstrainedMin[y, 
                    cs /. x -> \(-y\), {y}]\)\[LeftDoubleBracket]1\
\[RightDoubleBracket]\), ConstrainedMax::nsatt]; \n\t\t\tIf[cmax == 0, 
            cmax = \(-\(ConstrainedMin[y, 
                    cs /. x -> \(-y\), {y}]\)\[LeftDoubleBracket]1\
\[RightDoubleBracket]\)]; \n
          If[\((Head[cmin] === Symbol)\) || \((Head[cmax] === Symbol)\), {0, 
              0}, {cmin, cmax}]];\)\)], "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{

Cell["\<\
ConstrainedIntervals[expr>0,x] gives a list of the possible \
intervals in which x can lie.\
\>", "Subsubsection"],

Cell[BoxData[{
    \(\(ConstrainedIntervals[c_List, x_] := 
        Min[Map[ConstrainedIntervals[#, x] &, c]];\)\), "\n", 
    \(\(ConstrainedIntervals[Less[a_, b_], x_] := 
        ConstrainedIntervals[b > a, x];\)\), "\n", 
    \(\(ConstrainedIntervals[Greater[a_, b_], x_] := 
        ConstrainedIntervals[a - b > 0, x];\)\), "\n", 
    \(\(ConstrainedIntervals[a_ > 0, x_] := 
        Module[{roots, f}, \n\t\t\tIf[
            PolynomialQ[a, 
              x], \n\t\t\t\ \((roots = 
                Select[x /. 
                    NSolve[a == 0, 
                      x], \ \((Chop[Im[#]] == 0)\) &]; \n\t\t\ \ \ \ \ \ If[
                roots == {}, 
                If[\((a /. x -> 0)\) > 
                    0, {{\(-\[Infinity]\), \[Infinity]}}, {}], \((If[\((a /. 
                          x -> \((First[roots] - 1)\))\) > 0, 
                    roots = 
                      Prepend[
                        roots, \(-\[Infinity]\)]]; \n\t\t\t\tIf[\((a /. 
                          x -> \((Last[roots] + 1)\))\) > 0, 
                    roots = 
                      Append[roots, \[Infinity]]]; \n\t\t\t\t\tPartition[
                    roots, 2])\)])\), \n\t\t\tPrint["\<Error: constraint not \
polynomial in \>", x]]];\)\)}], "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{

Cell["\<\
IntervalCombine[{{x1,y1},{x2,y2},..},{{X1,Y1},{X2,Y2},..},..] \
combines the lists of intervals\
\>", "Subsubsection"],

Cell[BoxData[
    \(\(IntervalCombine[a_List, b_List, c__List] := 
        IntervalCombine[IntervalCombine[a, b], c];\)\)], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(\(IntervalCombine[a_List, b_List] := 
        Module[{ps, aps, ll}, \n\t\tFlatten[
            Map[\((ps = Map[IntervalPosition[a, #] &, #]; \n\t\t\t\taps = 
                    Abs[ps]; \n\t\t\t\ ll = 
                    If[ps\[LeftDoubleBracket]1\[RightDoubleBracket] > 
                        0, \n\t\t\t\t\t\tReplacePart[
                        Table[a\[LeftDoubleBracket]
                            j\[RightDoubleBracket], {j, 
                            aps\[LeftDoubleBracket]1\[RightDoubleBracket], 
                            aps\[LeftDoubleBracket]2\[RightDoubleBracket]}], \
#\[LeftDoubleBracket]1\[RightDoubleBracket], {1, 1}], \n\t\t\t\t\ \ \ \ Table[
                        a\[LeftDoubleBracket]j\[RightDoubleBracket], {j, 
                          aps\[LeftDoubleBracket]1\[RightDoubleBracket] + 1, 
                          aps\[LeftDoubleBracket]2\[RightDoubleBracket]}]]; \n\
\t\t\tIf[ps\[LeftDoubleBracket]2\[RightDoubleBracket] > 0, \t
                    ReplacePart[
                      ll, #\[LeftDoubleBracket]2\[RightDoubleBracket], \
{Length[ll], 2}], ll])\) &, b], 1]];\)\)], "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{

Cell["\<\
IntervalPosition[{{x1,y1},{x2,y2},..},z] returns zero if z is not \
in any interval and the relevant interval otherwise.\
\>", "Subsubsection"],

Cell[BoxData[
    \(\(IntervalPosition[ints_List, z_] := 
        Module[{p}, \n\t\tp = \(Position[
                Sort[Prepend[Flatten[ints], z], \((#1 < #2)\) &], z]\)[\([1, 
                1]\)]; \n\t\tIf[OddQ[p], \(-1\), 1] 
            Quotient[p, 2]];\)\)], "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{

Cell["Checking MomentLimitsReduced[..old]", "Subsubsection"],

Cell[CellGroupData[{

Cell[BoxData[
    \(MomentLimitsReduced[c[4], {0.01, 0.01, 0.002}, 1&, p, {1, 2, 3, 4}]\)], 
  "Input"],

Cell[BoxData[
    \({\(-0.0577999999999999936`\), 0.0522000000000000063`}\)], "Output"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    \(Map[{
            FullGenotypeFrequencyReduced[#, c, 1&, p, {1, 2, 3, 4}] /. 
              c[j_] :> {0.01, 0.01, \(-0.0578\)}\[LeftDoubleBracket]j - 1
                    \[RightDoubleBracket], 
            FullGenotypeFrequencyReduced[#, c, 1&, p, {1, 2, 3, 4}] /. 
              c[j_] :> {0.01, 0.01, 0.002}\[LeftDoubleBracket]j - 1
                    \[RightDoubleBracket], 
            FullGenotypeFrequencyReduced[#, c, 1&, p, {1, 2, 3, 4}] /. 
              c[j_] :> {0.01, 0.01, 0.0522}\[LeftDoubleBracket]j - 1
                    \[RightDoubleBracket]}&, gameteTypes[4]] // TableForm\)], 
  "Input"],

Cell[BoxData[
    TagBox[GridBox[{
          {\(-6.93889390390722837`*^-18\), "0.0597999999999999864`", 
            "0.109999999999999985`"},
          {"0.130000000000000004`", "0.0701999999999999957`", 
            "0.0199999999999999964`"},
          {"0.130000000000000004`", "0.0701999999999999957`", 
            "0.0199999999999999964`"},
          {"6.93889390390722837`*^-18", "0.0598000000000000042`", 
            "0.110000000000000008`"},
          {"0.130000000000000004`", "0.0701999999999999957`", 
            "0.0199999999999999964`"},
          {"6.93889390390722837`*^-18", "0.0598000000000000042`", 
            "0.110000000000000008`"},
          {"6.93889390390722837`*^-18", "0.0598000000000000042`", 
            "0.110000000000000008`"},
          {"0.109999999999999985`", "0.0501999999999999957`", 
            \(-6.93889390390722837`*^-18\)},
          {"0.130000000000000004`", "0.0701999999999999957`", 
            "0.0199999999999999964`"},
          {"6.93889390390722837`*^-18", "0.0598000000000000042`", 
            "0.110000000000000008`"},
          {"6.93889390390722837`*^-18", "0.0598000000000000042`", 
            "0.110000000000000008`"},
          {"0.109999999999999985`", "0.0501999999999999957`", 
            \(-6.93889390390722837`*^-18\)},
          {"6.93889390390722837`*^-18", "0.0598000000000000042`", 
            "0.110000000000000008`"},
          {"0.109999999999999985`", "0.0501999999999999957`", 
            \(-6.93889390390722837`*^-18\)},
          {"0.109999999999999985`", "0.0501999999999999957`", 
            \(-6.93889390390722837`*^-18\)},
          {"0.04`", "0.0998000000000000042`", "0.15`"}
          },
        RowSpacings->1,
        ColumnSpacings->3,
        RowAlignments->Baseline,
        ColumnAlignments->{Left}],
      (TableForm[ #]&)]], "Output"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    \(MomentLimitsReduced[c[3], {0.01, 0.01, 0.002}, 1&, p, {1, 2, 3, 4}]\)], 
  "Input"],

Cell[BoxData[
    \({\(-0.0398999999999999985`\), 0.0398999999999999985`}\)], "Output"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    \(Map[{
            FullGenotypeFrequencyReduced[#, c, 1&, p, {1, 2, 3, 4}] /. 
              c[j_] :> {0.01, \(-0.0399\), 0.002}\[LeftDoubleBracket]j - 1
                    \[RightDoubleBracket], 
            FullGenotypeFrequencyReduced[#, c, 1&, p, {1, 2, 3, 4}] /. 
              c[j_] :> {0.01, 0.01, 0.002}\[LeftDoubleBracket]j - 1
                    \[RightDoubleBracket], 
            FullGenotypeFrequencyReduced[#, c, 1&, p, {1, 2, 3, 4}] /. 
              c[j_] :> {0.01, 0.0399, 0.002}\[LeftDoubleBracket]j - 1
                    \[RightDoubleBracket]}&, gameteTypes[4]] // TableForm\)], 
  "Input"],

Cell[BoxData[
    TagBox[GridBox[{
          {"0.15959999999999999`", "0.0597999999999999864`", 
            \(-1.73472347597680709`*^-18\)},
          {"0.020299999999999998`", "0.0701999999999999957`", 
            "0.100099999999999988`"},
          {"0.020299999999999998`", "0.0701999999999999957`", 
            "0.100099999999999988`"},
          {"0.0598000000000000042`", "0.0598000000000000042`", 
            "0.0598000000000000042`"},
          {"0.020299999999999998`", "0.0701999999999999957`", 
            "0.100099999999999988`"},
          {"0.0598000000000000042`", "0.0598000000000000042`", 
            "0.0598000000000000042`"},
          {"0.0598000000000000042`", "0.0598000000000000042`", 
            "0.0598000000000000042`"},
          {"0.100099999999999988`", "0.0501999999999999957`", 
            "0.020299999999999998`"},
          {"0.020299999999999998`", "0.0701999999999999957`", 
            "0.100099999999999988`"},
          {"0.0598000000000000042`", "0.0598000000000000042`", 
            "0.0598000000000000042`"},
          {"0.0598000000000000042`", "0.0598000000000000042`", 
            "0.0598000000000000042`"},
          {"0.100099999999999988`", "0.0501999999999999957`", 
            "0.020299999999999998`"},
          {"0.0598000000000000042`", "0.0598000000000000042`", 
            "0.0598000000000000042`"},
          {"0.100099999999999988`", "0.0501999999999999957`", 
            "0.020299999999999998`"},
          {"0.100099999999999988`", "0.0501999999999999957`", 
            "0.020299999999999998`"},
          {\(-1.73472347597680709`*^-18\), "0.0998000000000000042`", 
            "0.15959999999999999`"}
          },
        RowSpacings->1,
        ColumnSpacings->3,
        RowAlignments->Baseline,
        ColumnAlignments->{Left}],
      (TableForm[ #]&)]], "Output"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    \(MomentLimitsReduced[c[2], {0.01, 0.01, 0.002}, 1&, p, {1, 2, 3, 4}]\)], 
  "Input"],

Cell[BoxData[
    \({\(-0.02986666666666666`\), 0.129599999999999981`}\)], "Output"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    \(Map[{
            FullGenotypeFrequencyReduced[#, c, 1&, p, {1, 2, 3, 4}] /. 
              c[j_] :> {\(-0.03\), 0.01, 0.002}\[LeftDoubleBracket]j - 1
                    \[RightDoubleBracket], 
            FullGenotypeFrequencyReduced[#, c, 1&, p, {1, 2, 3, 4}] /. 
              c[j_] :> {0.01, 0.01, 0.002}\[LeftDoubleBracket]j - 1
                    \[RightDoubleBracket], 
            FullGenotypeFrequencyReduced[#, c, 1&, p, {1, 2, 3, 4}] /. 
              c[j_] :> {0.13, 0.01, 0.002}\[LeftDoubleBracket]j - 1
                    \[RightDoubleBracket]}&, gameteTypes[4]] // TableForm\)], 
  "Input"],

Cell[BoxData[
    TagBox[GridBox[{
          {"0.00220000000000000239`", "0.0597999999999999864`", 
            "0.290200000000000013`"},
          {"0.0677999999999999936`", "0.0701999999999999957`", 
            "0.01979999999999999`"},
          {"0.0677999999999999936`", "0.0701999999999999957`", 
            "0.01979999999999999`"},
          {"0.0821999999999999886`", "0.0598000000000000042`", 
            "0.0502000000000000135`"},
          {"0.0677999999999999936`", "0.0701999999999999957`", 
            "0.01979999999999999`"},
          {"0.0821999999999999886`", "0.0598000000000000042`", 
            "0.0502000000000000135`"},
          {"0.0821999999999999886`", "0.0598000000000000042`", 
            "0.0502000000000000135`"},
          {"0.0477999999999999936`", "0.0501999999999999957`", 
            \(-0.000200000000000009192`\)},
          {"0.0677999999999999936`", "0.0701999999999999957`", 
            "0.01979999999999999`"},
          {"0.0821999999999999886`", "0.0598000000000000042`", 
            "0.0502000000000000135`"},
          {"0.0821999999999999886`", "0.0598000000000000042`", 
            "0.0502000000000000135`"},
          {"0.0477999999999999936`", "0.0501999999999999957`", 
            \(-0.000200000000000009192`\)},
          {"0.0821999999999999886`", "0.0598000000000000042`", 
            "0.0502000000000000135`"},
          {"0.0477999999999999936`", "0.0501999999999999957`", 
            \(-0.000200000000000009192`\)},
          {"0.0477999999999999936`", "0.0501999999999999957`", 
            \(-0.000200000000000009192`\)},
          {"0.0422000000000000063`", "0.0998000000000000042`", 
            "0.330200000000000049`"}
          },
        RowSpacings->1,
        ColumnSpacings->3,
        RowAlignments->Baseline,
        ColumnAlignments->{Left}],
      (TableForm[ #]&)]], "Output"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData[{
  "MomentLimitsDiploid",
  "[cb[k],{cw,cb},{{cw[2],cw[3],..},{cb[2]..}},\[Delta]p,p,S] gives the \
bounds on the values of cb[k], based on constraints on diploid genotype \
frequencies, and expressed in terms of {cw[],cb[]}.  The cw's are given \
numerically by the lists {{cw[2],cw[3],..},{cb[2]..}}. "
}], "Subsubsection",
  InitializationCell->True],

Cell[BoxData[
    \(\(MomentLimitsDiploid[
          cb_[k_Integer], {cw_, cb_}, {cwl_List, cbl_List}, \[Delta]p_, p_, 
          S_] := \n\t
        MomentLimitsDiploid[cb[k], {cw, cb}, {cwl, cbl}, 
          DiploidConstraints[{cw, cb}, \[Delta]p, p, S]];\)\)], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(\(MomentLimitsDiploid[c_[k_Integer], {cw_, cb_}, {cwl_List, cbl_List}, 
          ccs_] := Module[{x, cs, ints, n}, \n\t\tcs = 
            DeleteCases[\((\(ccs /. 
                      c[k] -> x\) /. {cw[j_] :> 
                        cwl\[LeftDoubleBracket]j - 1\[RightDoubleBracket], 
                      cb[j_] :> 
                        cbl\[LeftDoubleBracket]j - 
                            1\[RightDoubleBracket]})\) // Chop, True]; \n
          ints = IntervalCombine @@ Map[ConstrainedIntervals[#, x] &, cs]; \n
          n = Length[ints]; \n
          If[n > 1, 
            Print["\<WARNING: genotype frequencies valid only in disjunct \
regions. \>", ints]]; \n{ints\[LeftDoubleBracket]1, 1\[RightDoubleBracket], 
            ints\[LeftDoubleBracket]n, 2\[RightDoubleBracket]}];\)\)], "Input",\

  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{

Cell["Checking MomentLimitsDiploid[]", "Subsubsection"],

Cell[CellGroupData[{

Cell[BoxData[
    \(Map[
      MomentLimitsDiploid[#, {cw, cb}, {{0.05}, {0.03, 0.01, 0.002}}, 1&, 
          p, {1, 2}]&, {cw[2], cb[2], cb[3], cb[4]}]\)], "Input"],

Cell[BoxData[
    \({{\(-0.220680764907139126`\), 0.220680764907139126`}, {
        \(-0.0872117940390029744`\), 0.15491933384829668`}, {
        \(-0.0561999999999999921`\), 0.0561999999999999921`}, {
        \(-0.0417999999999999971`\), 0.0481999999999999939`}}\)], "Output"]
}, Closed]],

Cell[BoxData[
    \(\(gt = Flatten[Outer[List, gameteTypes[2], gameteTypes[2]], 2]; \)\)], 
  "Input"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(Map[{
              FullGenotypeFrequencyTable[#, {cw, cb}, 1&, p, {1, 2}] /. {
                  cw[2] -> 0.220680764907139126`, 
                  cb[j_] :> {0.03, 0.01, 0.002}\[LeftDoubleBracket]j - 1
                        \[RightDoubleBracket]}, 
              FullGenotypeFrequencyTable[#, {cw, cb}, 1&, p, {1, 2}] /. {
                  cw[2] -> \(-0.220680764907139126`\), 
                  cb[j_] :> {0.03, 0.01, 0.002}\[LeftDoubleBracket]j - 1
                        \[RightDoubleBracket]}, 
              FullGenotypeFrequencyTable[#, {cw, cb}, 1&, p, {1, 2}] /. {
                  cw[2] -> 0.05, 
                  cb[j_] :> {\(-0.0872117940390029744`\), 0.01, 0.002}
                        \[LeftDoubleBracket]j - 1\[RightDoubleBracket]}, 
              FullGenotypeFrequencyTable[#, {cw, cb}, 1&, p, {1, 2}] /. {
                  cw[2] -> 0.05, 
                  cb[j_] :> {0.15491933384829668`, 0.01, 0.002}
                        \[LeftDoubleBracket]j - 1\[RightDoubleBracket]}}&, 
          gt] // Chop\) // TableForm\)], "Input"],

Cell[BoxData[
    TagBox[GridBox[{
          {"0.23534038245356954`", "0.0146596175464304367`", "0", 
            "0.274919333848296698`"},
          {"0.0199999999999999964`", "0.0199999999999999964`", 
            "0.0527882059609970433`", "0.0199999999999999964`"},
          {"0.0199999999999999964`", "0.0199999999999999964`", 
            "0.0527882059609970433`", "0.0199999999999999964`"},
          {"0.00465961754643044034`", "0.225340382453569532`", 
            "0.0572117940390029566`", "0.09`"},
          {"0.23534038245356954`", "0.0146596175464304367`", "0", 
            "0.274919333848296698`"},
          {"0.0199999999999999964`", "0.0199999999999999964`", 
            "0.0527882059609970433`", "0.0199999999999999964`"},
          {"0.0199999999999999964`", "0.0199999999999999964`", 
            "0.0527882059609970433`", "0.0199999999999999964`"},
          {"0.00465961754643044034`", "0.225340382453569532`", 
            "0.0572117940390029566`", "0.09`"},
          {"0.23534038245356954`", "0.0146596175464304367`", "0", 
            "0.274919333848296698`"},
          {"0.0199999999999999964`", "0.0199999999999999964`", 
            "0.0527882059609970433`", "0.0199999999999999964`"},
          {"0.0199999999999999964`", "0.0199999999999999964`", 
            "0.0527882059609970433`", "0.0199999999999999964`"},
          {"0.00465961754643044034`", "0.225340382453569532`", 
            "0.0572117940390029566`", "0.09`"},
          {"0.00465961754643044034`", "0.225340382453569532`", 
            "0.0572117940390029566`", "0.09`"},
          {"0", "0", "0.0327882059609970433`", "0"},
          {"0", "0", "0.0327882059609970433`", "0"},
          {"0.275340382453569576`", "0.0546596175464304412`", 
            "0.0399999999999999822`", "0.314919333848296734`"},
          {"0.00465961754643044034`", "0.225340382453569532`", 
            "0.0572117940390029566`", "0.09`"},
          {"0", "0", "0.0327882059609970433`", "0"},
          {"0", "0", "0.0327882059609970433`", "0"},
          {"0.275340382453569576`", "0.0546596175464304412`", 
            "0.0399999999999999822`", "0.314919333848296734`"},
          {"0.23534038245356954`", "0.0146596175464304367`", "0", 
            "0.274919333848296698`"},
          {"0.0199999999999999964`", "0.0199999999999999964`", 
            "0.0527882059609970433`", "0.0199999999999999964`"},
          {"0.0199999999999999964`", "0.0199999999999999964`", 
            "0.0527882059609970433`", "0.0199999999999999964`"},
          {"0.00465961754643044034`", "0.225340382453569532`", 
            "0.0572117940390029566`", "0.09`"},
          {"0.00465961754643044034`", "0.225340382453569532`", 
            "0.0572117940390029566`", "0.09`"},
          {"0", "0", "0.0327882059609970433`", "0"},
          {"0", "0", "0.0327882059609970433`", "0"},
          {"0.275340382453569576`", "0.0546596175464304412`", 
            "0.0399999999999999822`", "0.314919333848296734`"},
          {"0.00465961754643044034`", "0.225340382453569532`", 
            "0.0572117940390029566`", "0.09`"},
          {"0", "0", "0.0327882059609970433`", "0"},
          {"0", "0", "0.0327882059609970433`", "0"},
          {"0.275340382453569576`", "0.0546596175464304412`", 
            "0.0399999999999999822`", "0.314919333848296734`"}
          },
        RowSpacings->1,
        ColumnSpacings->3,
        RowAlignments->Baseline,
        ColumnAlignments->{Left}],
      (TableForm[ #]&)]], "Output"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(Map[{
              FullGenotypeFrequencyTable[#, {cw, cb}, 1&, p, {1, 2}] /. {
                  cw[2] -> 0.05, 
                  cb[j_] :> {0.03, \(-0.0562\), 0.002}\[LeftDoubleBracket]j - 
                        1\[RightDoubleBracket]}, 
              FullGenotypeFrequencyTable[#, {cw, cb}, 1&, p, {1, 2}] /. {
                  cw[2] -> 0.05, 
                  cb[j_] :> {0.03, 0.0562, 0.002}\[LeftDoubleBracket]j - 1
                        \[RightDoubleBracket]}, 
              FullGenotypeFrequencyTable[#, {cw, cb}, 1&, p, {1, 2}] /. {
                  cw[2] -> 0.05, 
                  cb[j_] :> {0.03, 0.01, \(-0.0418\)}\[LeftDoubleBracket]j - 1
                        \[RightDoubleBracket]}, 
              FullGenotypeFrequencyTable[#, {cw, cb}, 1&, p, {1, 2}] /. {
                  cw[2] -> 0.05, 
                  cb[j_] :> {0.03, 0.01, 0.0482}\[LeftDoubleBracket]j - 1
                        \[RightDoubleBracket]}}&, gt] // Chop\) // TableForm
      \)], "Input"],

Cell[BoxData[
    TagBox[GridBox[{
          {"0.236200000000000009`", "0.011399999999999999`", "0.06`", 
            "0.15`"},
          {"0", "0.112400000000000011`", "0.109999999999999985`", 
            "0.0199999999999999964`"},
          {"0", "0.112400000000000011`", "0.109999999999999985`", 
            "0.0199999999999999964`"},
          {"0.0437999999999999989`", "0.0437999999999999989`", "0", "0.09`"},
          {"0.236200000000000009`", "0.011399999999999999`", "0.06`", 
            "0.15`"},
          {"0", "0.112400000000000011`", "0.109999999999999985`", 
            "0.0199999999999999964`"},
          {"0", "0.112400000000000011`", "0.109999999999999985`", 
            "0.0199999999999999964`"},
          {"0.0437999999999999989`", "0.0437999999999999989`", "0", "0.09`"},
          {"0.236200000000000009`", "0.011399999999999999`", "0.06`", 
            "0.15`"},
          {"0", "0.112400000000000011`", "0.109999999999999985`", 
            "0.0199999999999999964`"},
          {"0", "0.112400000000000011`", "0.109999999999999985`", 
            "0.0199999999999999964`"},
          {"0.0437999999999999989`", "0.0437999999999999989`", "0", "0.09`"},
          {"0.0437999999999999989`", "0.0437999999999999989`", "0", "0.09`"},
          {"0.112400000000000011`", "0", "0.09`", "0"},
          {"0.112400000000000011`", "0", "0.09`", "0"},
          {"0.011399999999999999`", "0.236200000000000009`", "0.1`", 
            "0.19`"},
          {"0.0437999999999999989`", "0.0437999999999999989`", "0", "0.09`"},
          {"0.112400000000000011`", "0", "0.09`", "0"},
          {"0.112400000000000011`", "0", "0.09`", "0"},
          {"0.011399999999999999`", "0.236200000000000009`", "0.1`", 
            "0.19`"},
          {"0.236200000000000009`", "0.011399999999999999`", "0.06`", 
            "0.15`"},
          {"0", "0.112400000000000011`", "0.109999999999999985`", 
            "0.0199999999999999964`"},
          {"0", "0.112400000000000011`", "0.109999999999999985`", 
            "0.0199999999999999964`"},
          {"0.0437999999999999989`", "0.0437999999999999989`", "0", "0.09`"},
          {"0.0437999999999999989`", "0.0437999999999999989`", "0", "0.09`"},
          {"0.112400000000000011`", "0", "0.09`", "0"},
          {"0.112400000000000011`", "0", "0.09`", "0"},
          {"0.011399999999999999`", "0.236200000000000009`", "0.1`", 
            "0.19`"},
          {"0.0437999999999999989`", "0.0437999999999999989`", "0", "0.09`"},
          {"0.112400000000000011`", "0", "0.09`", "0"},
          {"0.112400000000000011`", "0", "0.09`", "0"},
          {"0.011399999999999999`", "0.236200000000000009`", "0.1`", "0.19`"}
          },
        RowSpacings->1,
        ColumnSpacings->3,
        RowAlignments->Baseline,
        ColumnAlignments->{Left}],
      (TableForm[ #]&)]], "Output"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(Map[{#, 
              FullGenotypeFrequencyTable[#, {cw, cb}, 1&, p, {1, 2}] /. {
                  cw[2] -> 0.05, 
                  cb[j_] :> {0.03, 0.01, 0.002}\[LeftDoubleBracket]j - 1
                        \[RightDoubleBracket]}}&, gt] // Chop\) // TableForm
      \)], "Input"],

Cell[BoxData[
    InterpretationBox[GridBox[{
          {GridBox[{
                {"0", "0"},
                {"0", "0"}
                },
              RowSpacings->0.25,
              ColumnSpacings->1,
              RowAlignments->Baseline,
              ColumnAlignments->{Left}], "0.103800000000000003`"},
          {GridBox[{
                {"0", "0"},
                {"0", "1"}
                },
              RowSpacings->0.25,
              ColumnSpacings->1,
              RowAlignments->Baseline,
              ColumnAlignments->{Left}], "0.0661999999999999921`"},
          {GridBox[{
                {"0", "1"},
                {"0", "0"}
                },
              RowSpacings->0.25,
              ColumnSpacings->1,
              RowAlignments->Baseline,
              ColumnAlignments->{Left}], "0.0661999999999999921`"},
          {GridBox[{
                {"0", "1"},
                {"0", "1"}
                },
              RowSpacings->0.25,
              ColumnSpacings->1,
              RowAlignments->Baseline,
              ColumnAlignments->{Left}], "0.0437999999999999989`"},
          {GridBox[{
                {"0", "0"},
                {"0", "0"}
                },
              RowSpacings->0.25,
              ColumnSpacings->1,
              RowAlignments->Baseline,
              ColumnAlignments->{Left}], "0.103800000000000003`"},
          {GridBox[{
                {"0", "0"},
                {"0", "1"}
                },
              RowSpacings->0.25,
              ColumnSpacings->1,
              RowAlignments->Baseline,
              ColumnAlignments->{Left}], "0.0661999999999999921`"},
          {GridBox[{
                {"0", "1"},
                {"0", "0"}
                },
              RowSpacings->0.25,
              ColumnSpacings->1,
              RowAlignments->Baseline,
              ColumnAlignments->{Left}], "0.0661999999999999921`"},
          {GridBox[{
                {"0", "1"},
                {"0", "1"}
                },
              RowSpacings->0.25,
              ColumnSpacings->1,
              RowAlignments->Baseline,
              ColumnAlignments->{Left}], "0.0437999999999999989`"},
          {GridBox[{
                {"0", "0"},
                {"0", "0"}
                },
              RowSpacings->0.25,
              ColumnSpacings->1,
              RowAlignments->Baseline,
              ColumnAlignments->{Left}], "0.103800000000000003`"},
          {GridBox[{
                {"0", "0"},
                {"0", "1"}
                },
              RowSpacings->0.25,
              ColumnSpacings->1,
              RowAlignments->Baseline,
              ColumnAlignments->{Left}], "0.0661999999999999921`"},
          {GridBox[{
                {"0", "1"},
                {"0", "0"}
                },
              RowSpacings->0.25,
              ColumnSpacings->1,
              RowAlignments->Baseline,
              ColumnAlignments->{Left}], "0.0661999999999999921`"},
          {GridBox[{
                {"0", "1"},
                {"0", "1"}
                },
              RowSpacings->0.25,
              ColumnSpacings->1,
              RowAlignments->Baseline,
              ColumnAlignments->{Left}], "0.0437999999999999989`"},
          {GridBox[{
                {"1", "0"},
                {"1", "0"}
                },
              RowSpacings->0.25,
              ColumnSpacings->1,
              RowAlignments->Baseline,
              ColumnAlignments->{Left}], "0.0437999999999999989`"},
          {GridBox[{
                {"1", "0"},
                {"1", "1"}
                },
              RowSpacings->0.25,
              ColumnSpacings->1,
              RowAlignments->Baseline,
              ColumnAlignments->{Left}], "0.0461999999999999921`"},
          {GridBox[{
                {"1", "1"},
                {"1", "0"}
                },
              RowSpacings->0.25,
              ColumnSpacings->1,
              RowAlignments->Baseline,
              ColumnAlignments->{Left}], "0.0461999999999999921`"},
          {GridBox[{
                {"1", "1"},
                {"1", "1"}
                },
              RowSpacings->0.25,
              ColumnSpacings->1,
              RowAlignments->Baseline,
              ColumnAlignments->{Left}], "0.143800000000000016`"},
          {GridBox[{
                {"1", "0"},
                {"1", "0"}
                },
              RowSpacings->0.25,
              ColumnSpacings->1,
              RowAlignments->Baseline,
              ColumnAlignments->{Left}], "0.0437999999999999989`"},
          {GridBox[{
                {"1", "0"},
                {"1", "1"}
                },
              RowSpacings->0.25,
              ColumnSpacings->1,
              RowAlignments->Baseline,
              ColumnAlignments->{Left}], "0.0461999999999999921`"},
          {GridBox[{
                {"1", "1"},
                {"1", "0"}
                },
              RowSpacings->0.25,
              ColumnSpacings->1,
              RowAlignments->Baseline,
              ColumnAlignments->{Left}], "0.0461999999999999921`"},
          {GridBox[{
                {"1", "1"},
                {"1", "1"}
                },
              RowSpacings->0.25,
              ColumnSpacings->1,
              RowAlignments->Baseline,
              ColumnAlignments->{Left}], "0.143800000000000016`"},
          {GridBox[{
                {"0", "0"},
                {"0", "0"}
                },
              RowSpacings->0.25,
              ColumnSpacings->1,
              RowAlignments->Baseline,
              ColumnAlignments->{Left}], "0.103800000000000003`"},
          {GridBox[{
                {"0", "0"},
                {"0", "1"}
                },
              RowSpacings->0.25,
              ColumnSpacings->1,
              RowAlignments->Baseline,
              ColumnAlignments->{Left}], "0.0661999999999999921`"},
          {GridBox[{
                {"0", "1"},
                {"0", "0"}
                },
              RowSpacings->0.25,
              ColumnSpacings->1,
              RowAlignments->Baseline,
              ColumnAlignments->{Left}], "0.0661999999999999921`"},
          {GridBox[{
                {"0", "1"},
                {"0", "1"}
                },
              RowSpacings->0.25,
              ColumnSpacings->1,
              RowAlignments->Baseline,
              ColumnAlignments->{Left}], "0.0437999999999999989`"},
          {GridBox[{
                {"1", "0"},
                {"1", "0"}
                },
              RowSpacings->0.25,
              ColumnSpacings->1,
              RowAlignments->Baseline,
              ColumnAlignments->{Left}], "0.0437999999999999989`"},
          {GridBox[{
                {"1", "0"},
                {"1", "1"}
                },
              RowSpacings->0.25,
              ColumnSpacings->1,
              RowAlignments->Baseline,
              ColumnAlignments->{Left}], "0.0461999999999999921`"},
          {GridBox[{
                {"1", "1"},
                {"1", "0"}
                },
              RowSpacings->0.25,
              ColumnSpacings->1,
              RowAlignments->Baseline,
              ColumnAlignments->{Left}], "0.0461999999999999921`"},
          {GridBox[{
                {"1", "1"},
                {"1", "1"}
                },
              RowSpacings->0.25,
              ColumnSpacings->1,
              RowAlignments->Baseline,
              ColumnAlignments->{Left}], "0.143800000000000016`"},
          {GridBox[{
                {"1", "0"},
                {"1", "0"}
                },
              RowSpacings->0.25,
              ColumnSpacings->1,
              RowAlignments->Baseline,
              ColumnAlignments->{Left}], "0.0437999999999999989`"},
          {GridBox[{
                {"1", "0"},
                {"1", "1"}
                },
              RowSpacings->0.25,
              ColumnSpacings->1,
              RowAlignments->Baseline,
              ColumnAlignments->{Left}], "0.0461999999999999921`"},
          {GridBox[{
                {"1", "1"},
                {"1", "0"}
                },
              RowSpacings->0.25,
              ColumnSpacings->1,
              RowAlignments->Baseline,
              ColumnAlignments->{Left}], "0.0461999999999999921`"},
          {GridBox[{
                {"1", "1"},
                {"1", "1"}
                },
              RowSpacings->0.25,
              ColumnSpacings->1,
              RowAlignments->Baseline,
              ColumnAlignments->{Left}], "0.143800000000000016`"}
          },
        RowSpacings->1,
        ColumnSpacings->3,
        RowAlignments->Baseline,
        ColumnAlignments->{Left}],
      TableForm[ {{{{0, 0}, {0, 0}}, 0.1038}, {{{0, 0}, {0, 1}}, 
        0.066199999999999995}, {{{0, 1}, {0, 0}}, 0.066199999999999995}, {{{
        0, 1}, {0, 1}}, 0.043799999999999999}, {{{0, 0}, {0, 0}}, 0.1038}, {{{
        0, 0}, {0, 1}}, 0.066199999999999995}, {{{0, 1}, {0, 0}}, 
        0.066199999999999995}, {{{0, 1}, {0, 1}}, 0.043799999999999999}, {{{
        0, 0}, {0, 0}}, 0.1038}, {{{0, 0}, {0, 1}}, 0.066199999999999995}, {{{
        0, 1}, {0, 0}}, 0.066199999999999995}, {{{0, 1}, {0, 1}}, 
        0.043799999999999999}, {{{1, 0}, {1, 0}}, 0.043799999999999999}, {{{
        1, 0}, {1, 1}}, 0.046199999999999991}, {{{1, 1}, {1, 0}}, 
        0.046199999999999991}, {{{1, 1}, {1, 1}}, 0.14380000000000001}, {{{1, 
        0}, {1, 0}}, 0.043799999999999999}, {{{1, 0}, {1, 1}}, 
        0.046199999999999991}, {{{1, 1}, {1, 0}}, 0.046199999999999991}, {{{
        1, 1}, {1, 1}}, 0.14380000000000001}, {{{0, 0}, {0, 0}}, 0.1038}, {{{
        0, 0}, {0, 1}}, 0.066199999999999995}, {{{0, 1}, {0, 0}}, 
        0.066199999999999995}, {{{0, 1}, {0, 1}}, 0.043799999999999999}, {{{
        1, 0}, {1, 0}}, 0.043799999999999999}, {{{1, 0}, {1, 1}}, 
        0.046199999999999991}, {{{1, 1}, {1, 0}}, 0.046199999999999991}, {{{
        1, 1}, {1, 1}}, 0.14380000000000001}, {{{1, 0}, {1, 0}}, 
        0.043799999999999999}, {{{1, 0}, {1, 1}}, 0.046199999999999991}, {{{
        1, 1}, {1, 0}}, 0.046199999999999991}, {{{1, 1}, {1, 1}}, 
        0.14380000000000001}}]]], "Output"]
}, Closed]]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["Admixture models", "Subsection"],

Cell[CellGroupData[{

Cell[BoxData[
    \(TextForm
    \`MomentAfterMigration[U, c[i], {j, m\_j}]\ gives\ the\ moment\ after\ 
      migration\ at\ a\ rate\ m\_j\ from\ deme\ j\ into\ deme\ 
      i . \ \ MomentAfterMigration[U, c[i], {{j, m\_j} \[Ellipsis]}]\ allows\ 
      for\ several\ sources\ of\ immigrants . \ \ Expressed\ as\ a\ linear\ 
      mixture\ of\ \(\(c[j]\)[U] . \)\)], "Subsubsection"],

Cell[BoxData[
    \(\(MomentAfterMigration[U_, c_[i_], x : {{_, _} .. }] := 
        Module[{tx = Transpose[x]}, \n\t\tPlus @@ 
              MapThread[\((#2*\(c[#1]\)[U])\) &, 
                tx] + \((1 - 
                  Plus @@ tx\[LeftDoubleBracket]2\[RightDoubleBracket])\) \(c[
                  i]\)[U]];\)\)], "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{

Cell["\<\
MomentAfterRecombination[U,c,r] gives the moment after random \
mating and recombination, in terms of r[S,T].\
\>", "Subsubsection"],

Cell[BoxData[
    \(\(MomentAfterRecombination[U_, c_, r_] := 
        Module[{rr}, \((\((Recombined[c[U], rr] /. rr -> r)\) /. 
                RandomMating[c])\) /. \n\t\t\tSymmetrise[c]];\)\)], "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData[{
  "MomentSimple[i][U,c,pb,\[Delta]p] simplifies c[i][U] by supposing that \
deme 0 is in HW, and that the source demes are in linkage equilibrium and HW. \
 ",
  "MomentSimple",
  "[i][U,c,pb,\[Delta]pl,\[Delta]ps] allows for two migration rates from \
demes {-2,-1,0,1,2}, with the neighbouring demes {-1,1} now with the same \
c[]'s as deme 0."
}], "Subsubsection"],

Cell[BoxData[{
    \(\(\(MomentSimple[x_]\)[U_, c_, pb_, \[Delta]p_] := \(MomentSimple[x]\)[
          U, c, pb, \[Delta]p, 0 &];\)\), "\n", 
    \(\(MomentSimple[x_]\)[U_, c_, 
        pb_, \[Delta]pl_, \[Delta]ps_] := \n\t\((Switch[
              Abs[x], \n\t\t\t0, \((c[U] /. 
                  RandomUnionObsolete[c])\), \n\t\t\t1, 
              ShiftCentre[c[U], 
                If[x > 0, 1 - pb, \(-pb\)] \[Delta]ps[#] &], \n\t\t\t2, 
              Apply[Times, 
                Map[\((If[x > 0, 1 - pb, \(-pb\)] \[Delta]pl[{#}])\) &, 
                  U]], \n\t\t_, 
              Print["\<Error: MomentSimple[] only defined for demes -2\
\[Ellipsis]2; \>", x\ , "\< invalid\>"]] /. Symmetrise[c])\) /. {c[{}] -> 1, 
          c[{_}] -> 0}\)}], "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData[{
  "MomentNew[U,c,m,pb,r,\[Delta]p] gives the overall moment, measured after \
short-range migration.  ",
  "MomentNew",
  "[i][U,c,ml,ms,pb,r,\[Delta]pl,\[Delta]ps] allows for two migration rates."
}], "Subsubsection"],

Cell[BoxData[{
    \(\(MomentNew[U_, c_, m_, pb_, r_, \[Delta]p_] := 
        MomentNew[U, c, 0, m, pb, r, 0, \[Delta]p];\)\), "\n", 
    \(\(MomentNew[U_, c_, ml_, ms_, pb_, 
          r_, \[Delta]pl_, \[Delta]ps_] := \((\(MomentAfterMigration[U, 
                c[0], {{\(-2\), ml \((1 - pb)\)}, {\(-1\), 
                    ms \((1 - pb)\)}, {1, ms\ pb}, {2, ml\ pb}}] /. \(c[i_]\)[
                  W_] :> \((\(MomentSimple[i]\)[W, c, 
                      pb, \[Delta]pl, \[Delta]ps] /. 
                    c[V_] :> MomentAfterRecombination[V, c, r])\)\) /. 
            Symmetrise[c])\);\)\)}], "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData[{
  "MomentEquilibrium[U,c,m,pb,r,\[Delta]p] gives the equilibrium moment in \
deme 0, measured after short-range migration.  Stores results.  ",
  "MomentEquilibrium",
  "[U,c,ml,ms,pb,r,\[Delta]pl,\[Delta]ps] allows for two migration rates."
}], "Subsubsection"],

Cell[BoxData[
    \(\(MomentEquilibrium[U_, c_, m_, pb_, r_, \[Delta]p_] := 
        MomentEquilibrium[U, c, 0, m, pb, r, 0, \[Delta]p];\)\)], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(\(MomentEquilibrium[U_, c_, ml_, ms_, pb_, 
          r_, \[Delta]pl_, \[Delta]ps_] := \n\t\(MomentEquilibrium[U, c, ml, 
            ms, pb, r, \[Delta]pl, \[Delta]ps] = \n\t\tModule[{cs, 
              swap}, \n\t\t\tswap[W_List] := \((cs = W /. Separate; 
                If[cs\[LeftDoubleBracket]1\[RightDoubleBracket] === {}, 
                  Reverse[cs] /. Combine, 
                  W])\); \((\((c[
                        U] /. \(Solve[
                          c[U] == \((MomentNew[U, c, ml, ms, pb, 
                                  r, \[Delta]pl, \[Delta]ps] /. 
                                c[V_] :> c[swap[V]])\), c[U]]\)[\([1]\)])\) /. 
                  c[V_] :> MomentEquilibrium[V, c, ml, ms, pb, 
                      r, \[Delta]pl, \[Delta]ps])\) // 
              Factor]\);\)\)], "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData[{
  "CumulantEquilibrium[U,c,m,pb,r,\[Delta]p] gives the equilibrium cumulant \
in deme 0, measured after short-range migration.  Stores results. ",
  "CumulantEquilibrium",
  "[U,c,ml,ms,pb,r,\[Delta]pl,\[Delta]ps] allows for two migration rates. "
}], "Subsubsection"],

Cell[BoxData[
    \(\(CumulantEquilibrium[W_List, c_, 
          pars__] := \(CumulantEquilibrium[W, c, 
            pars] = \((Cumulant[c, W] /. 
                c[U_List] :> MomentEquilibrium[U, c, pars] // 
              Factor)\)\);\)\)], "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData[{
  "AdmixtureFrequency",
  "[X,c,ml,ms,pb,p,\[Delta]pl,\[Delta]ps,S] gives the frequency of genotype X \
under an admixture model.  Uses PossibleDiploidGenotypes[] and moments \
MomentEquilibrium[]."
}], "Subsubsection",
  InitializationCell->True],

Cell[BoxData[
    \(\(AdmixtureFrequency[X_List, c_, ml_, ms_, pb_, 
          p_, \[Delta]pl_, \[Delta]ps_, 
          S_List] := \n\t\(AdmixtureFrequency[X, c, ml, ms, pb, 
            p, \[Delta]pl, \[Delta]ps, 
            S] = \((DiploidGenotypeFrequency[X, c, p, S] /. 
                c[U_] :> c[\((\((U /. Separate)\) // Sort)\) /. Combine])\) /. 
            c[U_] :> MomentEquilibrium[U, c, ml, ms, pb, 
                UnlinkedRecombination, \[Delta]pl, \[Delta]ps]\);\)\)], \
"Input",
  InitializationCell->True],

Cell[BoxData[
    \(\(AdmixtureFrequency[X_List, c_, ml_, ms_, pb_, 
          p_, \[Delta]pl_, \[Delta]ps_, f_, Symmetric \[Rule] True] := 
        AdmixtureFrequency[Sort[X], c, ml, ms, pb, p, \[Delta]pl, \[Delta]ps, 
          f];\)\)], "Input",
  InitializationCell->True]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData[{
  "Estimating ",
  Cell[BoxData[
      \(TraditionalForm\`\[Delta]p\_i\)]]
}], "Subsection"],

Cell[CellGroupData[{

Cell[BoxData[
    \(TraditionalForm
    \`\(\[Delta]pEst[netCV[site]\/\[Alpha], \[Sum]\_\(i\[Delta]p\_i\)]\ gives
      \ the\ list\ of\ \ \[Delta]p\_i\ \)\)], "Subsubsection",
  InitializationCell->True],

Cell[BoxData[
    \(\(\[Delta]pEst[cva_, dpS_] := 
        1\/2\ \((dpS - \@\(dpS\^2 - 4  cva\))\);\)\)], "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    \(TraditionalForm
    \`\[Delta]pMax[site]\ gives\ the\ maximum\ \(\[Delta]p\_i\) allowed\ for\ 
      each\ locus\)], "Subsubsection",
  InitializationCell->True],

Cell[BoxData[
    \(\(\[Delta]pMax[s_] := \(\[Delta]pMax[s] = 
          Map[Min[#\/pbar[s], \(1 - #\)\/\(1 - pbar[s]\)] &, 
            ptable[data[s]]]\);\)\)], "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData[
"\[Delta]pSoln[\[Delta]pS,\[Alpha],netCV[site]] gives the solution for \
\[Delta]pS, given \[Alpha]"], "Subsubsection",
  InitializationCell->True],

Cell[BoxData[
    \(\(\[Delta]pSoln[\[Delta]pS_, \[Alpha]_, cv_] := 
        Module[{n = Length[cv], i}, \n\t
          FindRoot[\((n - 2)\) \[Delta]pS - 
                Sum[\@\(\[Delta]pS\^2 - 4\ cv[\([i]\)]/\[Alpha]\), {i, 
                    n}], {\[Delta]pS, 2}] // Chop];\)\)], "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData[
"\[Alpha]\[Delta]pSoln[\[Delta]pS,\[Alpha],site] gives the solution for \
\[Alpha] and \[Delta]pS;"], "Subsubsection",
  InitializationCell->True],

Cell[BoxData[
    \(\(\[Alpha]\[Delta]pSoln[\[Delta]pS_, \[Alpha]_, 
          s_, \[Alpha]0_] := \(\[Alpha]\[Delta]pSoln[\[Delta]pS, \[Alpha], 
            s, \[Alpha]0] = 
          Module[{ff, \[Gamma], rl}, \n
            ff[\[Gamma]_] := 
              Max[Re[\(\(\[Delta]pEst[netCV[s]\/\[Gamma], \[Delta]pS]\)\(\ \)\
\)\/\[Delta]pMax[s]]] /. \[Delta]pSoln[\[Delta]pS, \[Gamma], netCV[s]]; 
            rl = FindRoot[
                ff[\[Gamma]] - 
                  1, {\[Gamma], \[Alpha]0}]; \n\t\t\
Join[\[Delta]pSoln[\[Delta]pS, \[Gamma] /. rl, netCV[s]] // Chop, 
              rl /. \[Gamma] -> \[Alpha]]]\);\)\)], "Input",
  InitializationCell->True]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["Random sampling", "Subsection"],

Cell[CellGroupData[{

Cell["\<\
DrawSamples[s,gF,nloci,{nt,ninds}] sets up nt datasets, stored as \
data[s[1]]..data[s[nt]], sampled from a population with genotype frequencies \
in the list gF, which can be generated by AdmixtureFrequency[]\
\>", 
  "Subsubsection"],

Cell[BoxData[
    \(\(DrawSamples[s_, gt_, 
          nl_, {{k1_Integer, k2_Integer}, n_Integer}] := \n\t
        Module[{i}, 
          Do[Data[s[i]] = 
              RandomList[n, gt, DiploidTypes[nl], Compiled \[Rule] True], {i, 
              k1, k2}]];\)\)], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(\(DrawSamples[s_, gt_, nl_, {k_Integer, n_}] := 
        DrawSamples[s, gt, nl, {{1, k}, n}];\)\)], "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{

Cell["\<\
MakeRandomWalk[s,{Log[L],{{pl},{\[Delta]p},\[Kappa]l},step0},{T,{\
ntries,nprint}}, nvalues] generates a random walk at temperature T; with T=1, \
this follows the likelihood surface.  Each element of the output list has the \
same form as the second argument.  Output is generated every ntries cycles; \
the total number of elements is nvalues.\
\>", "Subsubsection"],

Cell[BoxData[
    \(\(Options[MakeRandomWalk] = {Cumulant \[Rule] True};\)\)], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(\(MakeRandomWalk[s_, mr_List, {T_, nn_List}, nv_, opts___Rule] := \n\t
        Module[{mrx = mr}, \n\t\tTable[
            mrx = MetropolisDisequilibrium[s, T, nn, mrx, 
                opts], {nv}]];\)\)], "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    \(TextForm
    \`\(FindMLE[s, {Log[L], {{pl}, {\[Delta]p}, \[Kappa]l}, step0}, metList]\ 
            returns\ the\ MLE\ for\ Data[s], \ 
          found\ using\ the\ Metropolis\ algorithm, \ 
          in\ the\ form
            \ {log \((L)\), {{
                  p\_1 .. }, {{\[Delta]p\_1, 
                    \[Ellipsis]}}, {{\[Kappa]\_\(0, 0\), \[Ellipsis]} 
                    \[Ellipsis]}}, step0}}\) . \ step0\ has\ the\ form
      \ {{{\[CapitalDelta]p\_1 .. }}, {{\[CapitalDelta]\[Delta]p\_1, 
            \[Ellipsis]}}, {{\[Kappa]\_\(0, 0\), \[Ellipsis]} \[Ellipsis]}}\ 
      and\ determines\ which\ parameters\ are\ varied . \ metList\ is\ a\ list
      \ of\ the\ form\ {{T, {ntries, nprint}},  .. }\ which\ determines\ the\ 
      annealing\ schedule . \ Calls\ 
      MetropolisDisequilibrium[] . \ FindMLE[s, p, \[Delta]p, \[Kappa]]\ 
      returns\ the\ MLE\ for\ some\ actual\ matrix\ of\ cumulants\ listed\ in
      \ c; \ calls\ LogLikelihoodDisequilibrium[] . \ \ \ FindMLE[s, p]\ gives
        \ the\ HWLE\ estimates . \ \ Cumulant \[Rule] 
      False\ fits\ moments\ rather\ than\ \(cumulants . \)\)], "Subsubsection"],

Cell[BoxData[
    \(\(Options[FindMLE] = {Cumulant \[Rule] True};\)\)], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(\(FindMLE[s_, pl : {__?NumberQ}, \[Delta]pl : {__?NumberQ}, 
          ce : {{__?NumberQ} .. }, opts___Rule] := 
        Module[{rd = ReducedData[s, NumberOfLoci[s]], nz, obs, ntot, gv, 
            tr}, \n\ \ \ \ If[\(Cumulant /. {opts}\) /. 
              Options[FindMLE], \n\t\t\ttr[c_] := \(Moment[NumberOfLoci[s]]\)[
                c], \n\t\t\ttr[m_] := m\ ]; \n\t\t\ gv = 
            DiploidGenotypeFrequencyList[pl, \[Delta]pl, tr[ce]]; \n\t\tnz = 
            Position[rd, _?\((\((# > 0)\) &)\)]; \n\t\tobs = 
            Extract[rd, nz]; \ 
          ntot = Plus @@ obs; \n\t\t{If[Min[gv] <= 0, \n\t
              10\^\(-10\), \n\t\t\t\t\(LogLikelihoodDisequilibrium[ntot]\)[
                obs, Extract[GenotypeFrequencyConvert[gv, NumberOfLoci[s]], 
                  nz]]], {{pl}, {\[Delta]pl}, ce}}];\)\)], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(\(FindMLE[s_, pl : {__?NumberQ}] := 
        Module[{nl = Length[pl]}, \n\t\tFindMLE[s, pl, Array[1 &, nl], 
            ReplacePart[Array[0 &, {nl + 1, nl + 1}], 
              1, {1, 1}]]];\)\)], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(\(FindMLE[s_, 
          mr : {_, {{{__?NumberQ}}, {{__?
                      NumberQ}}, {{__?NumberQ} .. }}, {{{__?NumberQ}}, {{__?
                      NumberQ}}, {{__?NumberQ} .. }}}, 
          metK : {{_, {_Integer, _Integer}} .. }, opts___Rule] := \n\t
        Module[{mrx = mr, 
            c = mr\[LeftDoubleBracket]2, 3\[RightDoubleBracket], 
            dc = mr\[LeftDoubleBracket]3, 
                3\[RightDoubleBracket]}, \n\t\tc\[LeftDoubleBracket]1, 
              1\[RightDoubleBracket] = 
            0; \n\t\tIf[\((Union[Flatten[c]] === {0})\) && \((Union[
                    Flatten[dc]] === {0})\), \n\t\t\tFindMLE[s, 
              mr\[LeftDoubleBracket]2, 1, 1\[RightDoubleBracket]],  (*\ 
              HWLE\ *) \n\t\t\tScan[\((mrx = 
                    MetropolisDisequilibrium[
                      s, #\[LeftDoubleBracket]1\[RightDoubleBracket], #\
\[LeftDoubleBracket]2\[RightDoubleBracket], mrx, opts])\) &, metK]; 
            mrx]];\)\)], "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{

Cell["Testing", "Subsubsection"],

Cell[CellGroupData[{

Cell[BoxData[
    \(st0 = 
      Join[{{0.1, 0.1, 0.1, 0.1}}, 
        InitialStepReduced[{cw, cb}, cl, 1&, 0.4&, {1, 2, 3, 4}]]\)], "Input"],

Cell[BoxData[
    RowBox[{"{", 
      RowBox[{
        RowBox[{"{", 
          RowBox[{
            StyleBox["0.1`",
              StyleBoxAutoDelete->True,
              PrintPrecision->1], ",", 
            StyleBox["0.1`",
              StyleBoxAutoDelete->True,
              PrintPrecision->1], ",", 
            StyleBox["0.1`",
              StyleBoxAutoDelete->True,
              PrintPrecision->1], ",", 
            StyleBox["0.1`",
              StyleBoxAutoDelete->True,
              PrintPrecision->1]}], "}"}], ",", 
        StyleBox["0.1`",
          StyleBoxAutoDelete->True,
          PrintPrecision->1], ",", 
        StyleBox["0.1`",
          StyleBoxAutoDelete->True,
          PrintPrecision->1], ",", 
        StyleBox["0.1`",
          StyleBoxAutoDelete->True,
          PrintPrecision->1], ",", 
        StyleBox["0.1`",
          StyleBoxAutoDelete->True,
          PrintPrecision->1], ",", 
        \({0.0293605470515638344`, 0.0160000000000000008`, 
          0.0256000000000000005`}\), ",", 
        \({0.0170302067428260688`, 0.00148928415970065763`, 
          0.00037928022671928292`, 0.000182857142857142811`, 
          0.000146285714285714245`, 0.000204800000000000137`, 
          0.000655360000000000386`}\)}], "}"}]], "Output"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    \(FindMLE[
      1063, {0, {pl, cl}, st0}, {{1, {10, 5}}, {0.5, {10, 5}}, {0, {10, 5}}}]
      \)], "Input"],

Cell[BoxData[
    InterpretationBox[
      \(5\[InvisibleSpace]"\t"\[InvisibleSpace]"  \
log(L)="\[InvisibleSpace]\(-44.9630896336927055`
          \)\[InvisibleSpace]"\t"\[InvisibleSpace]"% accepted="\
\[InvisibleSpace]0.314285714285714279`\),
      SequenceForm[ 
      5, "\t", "  log(L)=", -44.963089633692704, "\t", "% accepted=", 
        0.31428571428571428],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \(10\[InvisibleSpace]"\t"\[InvisibleSpace]"  \
log(L)="\[InvisibleSpace]\(-42.4538065417877685`
          \)\[InvisibleSpace]"\t"\[InvisibleSpace]"% accepted="\
\[InvisibleSpace]0.314285714285714279`\),
      SequenceForm[ 
      10, "\t", "  log(L)=", -42.45380654178777, "\t", "% accepted=", 
        0.31428571428571428],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \(5\[InvisibleSpace]"\t"\[InvisibleSpace]"  \
log(L)="\[InvisibleSpace]\(-39.7444763955929261`
          \)\[InvisibleSpace]"\t"\[InvisibleSpace]"% accepted="\
\[InvisibleSpace]0.242857142857142838`\),
      SequenceForm[ 
      5, "\t", "  log(L)=", -39.744476395592926, "\t", "% accepted=", 
        0.24285714285714285],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \(10\[InvisibleSpace]"\t"\[InvisibleSpace]"  \
log(L)="\[InvisibleSpace]\(-39.7394255176358512`
          \)\[InvisibleSpace]"\t"\[InvisibleSpace]"% accepted="\
\[InvisibleSpace]0.257142857142857117`\),
      SequenceForm[ 
      10, "\t", "  log(L)=", -39.739425517635851, "\t", "% accepted=", 
        0.25714285714285712],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \(5\[InvisibleSpace]"\t"\[InvisibleSpace]"  \
log(L)="\[InvisibleSpace]\(-39.053248974924827`
          \)\[InvisibleSpace]"\t"\[InvisibleSpace]"% accepted="\
\[InvisibleSpace]0.114285714285714279`\),
      SequenceForm[ 
      5, "\t", "  log(L)=", -39.053248974924827, "\t", "% accepted=", 
        0.11428571428571428],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \(10\[InvisibleSpace]"\t"\[InvisibleSpace]"  \
log(L)="\[InvisibleSpace]\(-37.6647412962577732`
          \)\[InvisibleSpace]"\t"\[InvisibleSpace]"% accepted="\
\[InvisibleSpace]0.15`\),
      SequenceForm[ 
      10, "\t", "  log(L)=", -37.664741296257773, "\t", "% accepted=", 
        0.14999999999999999],
      Editable->False]], "Print"],

Cell[BoxData[
    \({\(-37.6647412962577732`
        \), {{0.471248887768270829`, 0.362604749894552158`, 
          0.407234228405861031`, 0.386789605255636459`}, {
          0.0217902543205777643`, \(-0.0163501877016666714`\), 
          0.00589621036014781996`, 0.0337427269170403665`, 
          \(-0.00342006979786569154`\), 0.000735901539470224186`, 
          0.000373777750140356124`, \(-0.000462710122797670386`\), 
          0.000714912427102181169`, \(-0.000134268354613673257`\)}}, {
        0.0531441000000000141`, 0.0228767924549610146`, 
        0.0430467210000000211`, 0.0656100000000000171`, 
        0.0228767924549610146`, 0.00984770902183612051`, 
        0.00984770902183612051`, 0.012157665459056941`, 
        0.00440686060182486016`, 0.00157563344349377913`, 
        0.00165403696364202978`, 0.0011003356035585956`, 
        0.000519281277670064689`, 0.000201565062967922425`, 
        0.000182857142857142811`, 0.000146285714285714245`, 
        0.000204800000000000137`, 0.000655360000000000386`}}\)], "Output"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    \(m0 = {{0, 0, 0, 0}, {1, 1, 1}, {1, 1, 1, 1, 1, 1, 1}}; st0*m0\)], 
  "Input"],

Cell[BoxData[
    \({{0, 0, 0, 0}, {0.0293605470515638344`, 0.0160000000000000008`, 
        0.0256000000000000005`}, {0.0170302067428260688`, 
        0.00148928415970065763`, 0.00037928022671928292`, 
        0.000182857142857142811`, 0.000146285714285714245`, 
        0.000204800000000000137`, 0.000655360000000000386`}}\)], "Output"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    \(FindMLE[
      1063, {0, {pl, cl}, 
        st0*m0}, {{1, {10, 5}}, {0.5, {10, 5}}, {0, {10, 5}}}]\)], "Input"],

Cell[BoxData[
    InterpretationBox[
      \(5\[InvisibleSpace]"\t"\[InvisibleSpace]"  \
log(L)="\[InvisibleSpace]\(-59.4342863946220312`
          \)\[InvisibleSpace]"\t"\[InvisibleSpace]"% accepted="\
\[InvisibleSpace]0.620000000000000017`\),
      SequenceForm[ 
      5, "\t", "  log(L)=", -59.434286394622035, "\t", "% accepted=", 0.62],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \(10\[InvisibleSpace]"\t"\[InvisibleSpace]"  \
log(L)="\[InvisibleSpace]\(-57.249850396167945`
          \)\[InvisibleSpace]"\t"\[InvisibleSpace]"% accepted="\
\[InvisibleSpace]0.6`\),
      SequenceForm[ 
      10, "\t", "  log(L)=", -57.249850396167943, "\t", "% accepted=", 
        0.59999999999999998],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \(5\[InvisibleSpace]"\t"\[InvisibleSpace]"  \
log(L)="\[InvisibleSpace]\(-56.6369074844110098`
          \)\[InvisibleSpace]"\t"\[InvisibleSpace]"% accepted="\
\[InvisibleSpace]0.540000000000000035`\),
      SequenceForm[ 
      5, "\t", "  log(L)=", -56.636907484411012, "\t", "% accepted=", 
        0.54000000000000004],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \(10\[InvisibleSpace]"\t"\[InvisibleSpace]"  \
log(L)="\[InvisibleSpace]\(-53.005223480455097`
          \)\[InvisibleSpace]"\t"\[InvisibleSpace]"% accepted="\
\[InvisibleSpace]0.55`\),
      SequenceForm[ 
      10, "\t", "  log(L)=", -53.005223480455101, "\t", "% accepted=", 
        0.55000000000000004],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \(5\[InvisibleSpace]"\t"\[InvisibleSpace]"  \
log(L)="\[InvisibleSpace]\(-50.7057616467092753`
          \)\[InvisibleSpace]"\t"\[InvisibleSpace]"% accepted="\
\[InvisibleSpace]0.340000000000000035`\),
      SequenceForm[ 
      5, "\t", "  log(L)=", -50.705761646709277, "\t", "% accepted=", 
        0.34000000000000002],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \(10\[InvisibleSpace]"\t"\[InvisibleSpace]"  \
log(L)="\[InvisibleSpace]\(-50.0523547643072408`
          \)\[InvisibleSpace]"\t"\[InvisibleSpace]"% accepted="\
\[InvisibleSpace]0.260000000000000008`\),
      SequenceForm[ 
      10, "\t", "  log(L)=", -50.052354764307239, "\t", "% accepted=", 
        0.26000000000000001],
      Editable->False]], "Print"],

Cell[BoxData[
    RowBox[{"{", 
      RowBox[{\(-50.0523547643072408`\), ",", 
        RowBox[{"{", 
          RowBox[{
            RowBox[{"{", 
              RowBox[{
                StyleBox["0.4`",
                  StyleBoxAutoDelete->True,
                  PrintPrecision->1], ",", 
                StyleBox["0.45`",
                  StyleBoxAutoDelete->True,
                  PrintPrecision->2], ",", 
                StyleBox["0.509999999999999964`",
                  StyleBoxAutoDelete->True,
                  PrintPrecision->2], ",", 
                StyleBox["0.55`",
                  StyleBoxAutoDelete->True,
                  PrintPrecision->2]}], "}"}], ",", 
            \({0.0190702989676050922`, \(-0.00295291105826478794`\), 
              0.00923815748378723`, 0.0436740099972228179`, 
              \(-0.00274596924550712051`\), 0.00158350148984456495`, 
              0.00109714630812220592`, \(-0.000665620590829970382`\), 
              0.000284481042353967517`, \(-0.00046066496664790284`\)}\)}], 
          "}"}], ",", 
        \({0, 0, 0, 0, 0.0126387527733604132`, 0.0104976000000000002`, 
          0.0110199605760000052`, 0.00905055010161422934`, 
          0.00226990422146114578`, 0.000713682660388044354`, 
          0.000344077974520488272`, 0.000180599647266313922`, 
          0.000134369280000000079`, 0.000348285173760000121`}\)}], "}"}]], 
  "Output"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["Testing timings: standard 4 locus dataset", "Subsubsection"],

Cell[TextData[{
  "FindMLE[,LE] uses LogLikelihoodDisequilibrium[] uncompiled, which then \
calls the compiled version of ",
  "FullGenotypeFrequencyTable",
  ".  That takes 0.04s per haploid genotype; 200 genotypes takes 8s.  So, why \
isn't LogLikelihoodDisequilibrium[] faster - takes 25s??  Seems to take twice \
as long using pE[], \[Delta]pE[] as using raw functions"
}], "Text"],

Cell[BoxData[
    RowBox[{
      RowBox[{"FindMLE", "[", 
        RowBox[{
          RowBox[{
            RowBox[{"r", "[", 
              RowBox[{"0", ",", 
                StyleBox["0.5`",
                  StyleBoxAutoDelete->True,
                  PrintPrecision->1]}], "]"}], "[", "1", "]"}], ",", 
          RowBox[{"\[Delta]pE", "[", 
            RowBox[{"0", ",", 
              StyleBox["0.5`",
                StyleBoxAutoDelete->True,
                PrintPrecision->1], ",", "1"}], "]"}], ",", 
          RowBox[{"pE", "[", 
            RowBox[{"0", ",", 
              StyleBox["0.5`",
                StyleBoxAutoDelete->True,
                PrintPrecision->1], ",", "1"}], "]"}], ",", "LE"}], "]"}], 
      \( (*\ 26\ s*) \)}]], "Input"],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"FindMLE", "[", 
        RowBox[{
          RowBox[{
            RowBox[{"r", "[", 
              RowBox[{"0", ",", 
                StyleBox["0.5`",
                  StyleBoxAutoDelete->True,
                  PrintPrecision->1]}], "]"}], "[", "1", "]"}], ",", \(1&\), 
          ",", \(0.2&\), ",", "LE"}], "]"}], \( (*\ 10\ s*) \)}]], "Input"],

Cell[BoxData[
    \({\(-206.112316172674336`\), {{0, 0, 0}, {0, 0, 0, 0, 0, 0, 0}}}\)], 
  "Output"]
}, Closed]],

Cell["\<\
FindMLE[..,metK] first compiles LogLikelihoodDisequilibrium[] and \
DiploidConstraints[], which is slow to do (546s & 307s to evaluate, then 15s \
to compile).  Thereafter, each call takes 0.45s and 0.08s.  A Metropolis run \
takes about 150*10=1500 calls, or 750s. In practice (with constraints) takes \
only about 2.5s, or 400s for the run.  100 reps take 20 hours!!\
\>", "Text"],

Cell[BoxData[
    \(\(metK = {{1, {50, 1}}, {0.1, {50, 1}}, {0, {50, 1}}}; \)\)], "Input"],

Cell[BoxData[
    RowBox[{"FindMLE", "[", 
      RowBox[{
        RowBox[{
          RowBox[{"r", "[", 
            RowBox[{"0", ",", 
              StyleBox["0.5`",
                StyleBoxAutoDelete->True,
                PrintPrecision->1]}], "]"}], "[", "1", "]"}], ",", 
        \({cw, cb}\), ",", 
        RowBox[{"\[Delta]pE", "[", 
          RowBox[{"0", ",", 
            StyleBox["0.5`",
              StyleBoxAutoDelete->True,
              PrintPrecision->1], ",", "1"}], "]"}], ",", 
        RowBox[{"pE", "[", 
          RowBox[{"0", ",", 
            StyleBox["0.5`",
              StyleBoxAutoDelete->True,
              PrintPrecision->1], ",", "1"}], "]"}], ",", \({1, 2, 3, 4}\), 
        ",", \({{0.125`, 0.`, \(-0.0625`\)}, {0.125`, 0.`, \(-0.0625`\), 0.`, 
            0.125`, 0.`, \(-0.53125`\)}}\), ",", "metK"}], "]"}]], "Input"],

Cell[BoxData[
    \(cl = {{0, 0, 0}, {0, 0, 0, 0, 0, 0, 0}}; \nst0 = cl /. {0 -> 0.002}; \n
    S = {1, 2, 3, 4}; nl = Length[S]; na = 0; nr = 0; \n\t\t\t
    vv = Flatten[cl]; \n\t\t\tstep = Flatten[st0]; \)], "Input"],

Cell[BoxData[
    \(\(\tvars = Join[Table[cw[j], {j, 2, nl}], Table[cb[j], {j, 2, 2  nl}]]; 
    \n\t\trl[xx_List] := 
      \(({vars, Flatten[xx]} // Transpose)\) /. {x_, y_} :> 
          \((x -> y)\)\)\)], "Input"],

Cell[BoxData[
    \(\(\ \(llx = 
      LogLikelihoodDisequilibrium[\(r[0, 0.5]\)[1], {cw, cb}, 1&, 0.2&, S, 
          gg] /. rl[StandardSet[nl]]; \)\)\)], "Input"],

Cell[BoxData[
    \(\(csx = 
      DiploidConstraints[{cw, cb}, 1&, 0.2&, S, gg] /. rl[StandardSet[nl]]; 
    \)\)], "Input"],

Cell[BoxData[
    \(\(tv = 
      Transpose[{StandardSet[nl] // Flatten, Table[_Real, {3  nl - 2}]}]; 
    \)\)], "Input"],

Cell[BoxData[
    \(\(\ \(cll = Compile[tv // Evaluate, llx // Evaluate]; \)\n\t\)\)], 
  "Input"],

Cell[BoxData[
    \(\((And@@csx)\) // Evaluate\)], "Input"],

Cell[BoxData[
    \(\(ccs = Compile[tv // Evaluate, \((And@@csx)\) // Evaluate]; \)\)], 
  "Input"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(\ Timing[ll = cll@@vv]\)\)], "Input"],

Cell[BoxData[
    \({0.0166666666664241347`\ Second, \(-212.578662332147105`\)}\)], "Output"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    \(Timing[ccs@@vv]\)], "Input"],

Cell[BoxData[
    \({0.0666666666666060336`\ Second, True}\)], "Output"]
}, Closed]],

Cell[BoxData[
    \(\(Do[
      Do[If[step[\([j]\)] > 0, 
          \((nvv = 
              ReplacePart[vv, 
                vv[\([j]\)] + \((2  Random[] - 1)\) step[\([j]\)], j]; \n\t
            If[ccs@@nvv, \n\t\t\t\t\t\t\t
              \((nll = cll@@nvv; \n\t
                If[Exp[\((nll - ll)\)] > Random[], \n\t\t\t\t\t\t\t\t\t\t
                  vv = nvv; ll = nll; 
                  step\[LeftDoubleBracket]j
                      \[RightDoubleBracket] /= $MetropolisAdjustment; 
                  \(na++\), \n\t\t\t\t\t\t\t\t\t\t
                  step\[LeftDoubleBracket]j
                      \[RightDoubleBracket] *= $MetropolisAdjustment; 
                  \(nr++\)])\), \n\t\t\t\t
              step\[LeftDoubleBracket]j
                  \[RightDoubleBracket] *= $MetropolisAdjustment; \(nr++\)])
            \)], {j, 3  nl - 2}]; Print[nvv], {10}] (*25  s*) \)\)], "Input"],

Cell[BoxData[
    \(FindMLE[\(r[0, 0.5]\)[1], {cw, cb}, 1&, pE[0, 0.5, 1], 
      S, {{0.01, 0.01, 0.002}, {0.01, 0.01, 0.01, 0.002, 0.002, 0.002, 
          0.002}}, {{1, {50, 1}}, {0.1, {50, 10}}, {0, {50, 10}}}]\)], "Input"]
}, Closed]],

Cell[CellGroupData[{

Cell["Testing the sampling routine: 400 samples", "Subsubsection"],

Cell[BoxData[
    \(\(DrawSamples[test, ttLE, 2, {400, 100}]; \)\)], "Input"],

Cell[BoxData[
    \(\(obsList = Table[reducedData[test[k]] /. {x_, y_List} :> x, {k, 400}]; 
    \)\)], "Input"],

Cell[CellGroupData[{

Cell[BoxData[
    \({Mean[obsList] // N, 100  ttLE}\)], "Input"],

Cell[BoxData[
    \({{41.2599999999999944`, 20.3849999999999997`, 2.6549999999999998`, 
        20.4150000000000009`, 9.99000000000000021`, 1.30000000000000004`, 
        2.58499999999999996`, 1.23999999999999999`, 0.170000000000000017`}, {
        40.9600000000000186`, 20.4800000000000093`, 2.56000000000000094`, 
        20.4800000000000093`, 10.2400000000000046`, 1.28000000000000046`, 
        2.56000000000000094`, 1.28000000000000046`, 0.160000000000000053`}}
      \)], "Output"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    \(ttLE\)], "Input"],

Cell[BoxData[
    \({0.409600000000000097`, 0.204800000000000048`, 0.0256000000000000049`, 
      0.204800000000000048`, 0.102400000000000024`, 0.0128000000000000024`, 
      0.0256000000000000049`, 0.0128000000000000024`, 0.00160000000000000035`}
      \)], "Output"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    \(cm = \(CovarianceMatrix[obsList] // N\) // TableForm\)], "Input"],

Cell[BoxData[
    TagBox[GridBox[{
          {"21.3758395989974925`", \(-6.53894736842105306`\), 
            \(-1.01032581453634096`\), \(-8.05553884711779488`\), 
            \(-3.89213032581453646`\), \(-0.634586466165413565`\), 
            \(-1.00461152882205517`\), \(-0.195388471177944857`\), 
            \(-0.0443107769423558917`\)},
          {\(-6.53894736842105306`\), "16.4478947368421053`", 
            \(-1.19265664160401009`\), \(-4.65641604010025034`\), 
            \(-2.79313283208020068`\), \(-0.434085213032581496`\), 
            \(-0.634310776942355936`\), \(-0.300651629072681725`\), 
            "0.102305764411027566`"},
          {\(-1.01032581453634096`\), \(-1.19265664160401009`\), 
            "2.74784461152882197`", \(-0.4128571428571429`\), 
            \(-0.239047619047619042`\), "0.0486215538847117834`", 
            "0.0319047619047619068`", "0.0253634085213032589`", 
            "0.00115288220551378439`"},
          {\(-8.05553884711779488`\), \(-4.65641604010025034`\), 
            \(-0.4128571428571429`\), "16.0930075187969912`", 
            \(-1.41438596491228079`\), "0.000501253132832080172`", 
            \(-0.92007518796992489`\), \(-0.498345864661654136`\), 
            \(-0.135889724310776949`\)},
          {\(-3.89213032581453646`\), \(-2.79313283208020068`\), 
            \(-0.239047619047619042`\), \(-1.41438596491228079`\), 
            "8.90716791979949817`", \(-0.295238095238095255`\), 
            \(-0.0166917293233082713`\), \(-0.175538847117794505`\), 
            \(-0.0810025062656641736`\)},
          {\(-0.634586466165413565`\), \(-0.434085213032581496`\), 
            "0.0486215538847117834`", "0.000501253132832080172`", 
            \(-0.295238095238095255`\), "1.37844611528822058`", 
            \(-0.0907268170426065267`\), "0.0180451127819548879`", 
            "0.00902255639097744399`"},
          {\(-1.00461152882205517`\), \(-0.634310776942355936`\), 
            "0.0319047619047619068`", \(-0.92007518796992489`\), 
            \(-0.0166917293233082713`\), \(-0.0907268170426065267`\), 
            "2.71456140350877195`", \(-0.0505263157894736814`\), 
            \(-0.0295238095238095255`\)},
          {\(-0.195388471177944857`\), \(-0.300651629072681725`\), 
            "0.0253634085213032589`", \(-0.498345864661654136`\), 
            \(-0.175538847117794505`\), "0.0180451127819548879`", 
            \(-0.0505263157894736814`\), "1.16531328320801996`", 
            "0.011729323308270676`"},
          {\(-0.0443107769423558917`\), "0.102305764411027566`", 
            "0.00115288220551378439`", \(-0.135889724310776949`\), 
            \(-0.0810025062656641736`\), "0.00902255639097744399`", 
            \(-0.0295238095238095255`\), "0.011729323308270676`", 
            "0.16651629072681704`"}
          },
        RowSpacings->1,
        ColumnSpacings->3,
        RowAlignments->Baseline,
        ColumnAlignments->{Left}],
      (TableForm[ #]&)]], "Output"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    \(100 \((DiagonalMatrix[ttLE] - Outer[Times, ttLE, ttLE])\) // TableForm
      \)], "Input"],

Cell[BoxData[
    TagBox[GridBox[{
          {"24.1827840000000016`", \(-8.38860800000000494`\), 
            \(-1.04857600000000061`\), \(-8.38860800000000494`\), 
            \(-4.19430400000000247`\), \(-0.524288000000000309`\), 
            \(-1.04857600000000061`\), \(-0.524288000000000309`\), 
            \(-0.0655360000000000386`\)},
          {\(-8.38860800000000494`\), "16.285696000000005`", 
            \(-0.524288000000000309`\), \(-4.19430400000000247`\), 
            \(-2.09715200000000123`\), \(-0.262144000000000154`\), 
            \(-0.524288000000000309`\), \(-0.262144000000000154`\), 
            \(-0.0327680000000000193`\)},
          {\(-1.04857600000000061`\), \(-0.524288000000000309`\), 
            "2.49446400000000068`", \(-0.524288000000000309`\), 
            \(-0.262144000000000154`\), \(-0.0327680000000000193`\), 
            \(-0.0655360000000000386`\), \(-0.0327680000000000193`\), 
            \(-0.00409600000000000274`\)},
          {\(-8.38860800000000494`\), \(-4.19430400000000247`\), 
            \(-0.524288000000000309`\), "16.285696000000005`", 
            \(-2.09715200000000123`\), \(-0.262144000000000154`\), 
            \(-0.524288000000000309`\), \(-0.262144000000000154`\), 
            \(-0.0327680000000000193`\)},
          {\(-4.19430400000000247`\), \(-2.09715200000000123`\), 
            \(-0.262144000000000154`\), \(-2.09715200000000123`\), 
            "9.19142400000000137`", \(-0.131072000000000077`\), 
            \(-0.262144000000000154`\), \(-0.131072000000000077`\), 
            \(-0.0163840000000000092`\)},
          {\(-0.524288000000000309`\), \(-0.262144000000000154`\), 
            \(-0.0327680000000000193`\), \(-0.262144000000000154`\), 
            \(-0.131072000000000077`\), "1.26361600000000029`", 
            \(-0.0327680000000000193`\), \(-0.0163840000000000092`\), 
            \(-0.00204800000000000137`\)},
          {\(-1.04857600000000061`\), \(-0.524288000000000309`\), 
            \(-0.0655360000000000386`\), \(-0.524288000000000309`\), 
            \(-0.262144000000000154`\), \(-0.0327680000000000193`\), 
            "2.49446400000000068`", \(-0.0327680000000000193`\), 
            \(-0.00409600000000000274`\)},
          {\(-0.524288000000000309`\), \(-0.262144000000000154`\), 
            \(-0.0327680000000000193`\), \(-0.262144000000000154`\), 
            \(-0.131072000000000077`\), \(-0.0163840000000000092`\), 
            \(-0.0327680000000000193`\), "1.26361600000000029`", 
            \(-0.00204800000000000137`\)},
          {\(-0.0655360000000000386`\), \(-0.0327680000000000193`\), 
            \(-0.00409600000000000274`\), \(-0.0327680000000000193`\), 
            \(-0.0163840000000000092`\), \(-0.00204800000000000137`\), 
            \(-0.00409600000000000274`\), \(-0.00204800000000000137`\), 
            "0.159744000000000063`"}
          },
        RowSpacings->1,
        ColumnSpacings->3,
        RowAlignments->Baseline,
        ColumnAlignments->{Left}],
      (TableForm[ #]&)]], "Output"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData[{
  "SetData[site,p,\[Delta]p,\[Delta]pV] sets up functions p, \[Delta]p,\
\[Delta]pV which are based on the sampled allele frequency.  ",
  "SetData",
  "[site,p,\[Delta]p] doesn't bother with \[Delta]pV."
}], "Subsubsection"],

Cell[BoxData[
    \(\(SetData[s_, pE_, \[Delta]pE_, \[Delta]pEV_] := 
        Module[{\[Alpha], \[Delta]ps, \[Delta]pee}, \n\t
          pE[i_] := \(ptable[data[s]]\)[\([i]\)] // N; 
          pE[\(i_\^*\)] := 
            pE[i]; \n\t\t\[Delta]pE[\(i_\^*\)] := \[Delta]pE[i]; \[Delta]pE[
              i_] := 1; \n\t\t\[Delta]pEV[\(i_\^*\)] := \[Delta]pEV[
              i]; \n\t\tIf[
            nloci[data[s]] > 
              2, \n\t\t\t\t\[Delta]pee = \[Delta]pEst[
                    netCV[s]/\[Alpha], \[Delta]pS] /. \[Alpha]\[Delta]pSoln[\
\[Delta]pS, \[Alpha], s, {0.1, 0.2}] // Re; \n\t\[Delta]pEV[
                i_] := \[Delta]pee[\([i]\)], \n\t\t\t\[Delta]pEV[i_] := 
              Min[\[Delta]pMax[s]]]];\)\)], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(\(SetData[s_, pE_, \[Delta]pE_] := 
        Module[{}, \n\tpE[i_] := \(ptable[data[s]]\)[\([i]\)] // N; 
          pE[\(i_\^*\)] := 
            pE[i]; \n\t\t\[Delta]pE[\(i_\^*\)] := \[Delta]pE[i]; \[Delta]pE[
              i_] := 1];\)\)], "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{

Cell["\<\
 CumulantEquilibriumList[m,p,nloci] gives a list of the equilibrium \
cumulants under long 
  range migration\
\>", "Subsubsection"],

Cell[BoxData[
    \(\(CumulantEquilibriumList[m_, pp_, 
          nl_] := \(CumulantEquilibriumList[m, p, 
            nl] = \n\t\tModule[{k}, {\(\((CumulantEquilibrium[#, c, m, 0, pp, 
                      UnlinkedRecombination, 1 &, 0 &])\) &\) /@ 
                Table[Range[k], {k, 2, 
                    nl}], \(\((CumulantEquilibrium[#, c, m, 0, pp, 
                      UnlinkedRecombination, 1 &, 0 &])\) &\) /@ 
                MakeSets[nl]}]\);\)\)], "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    \(TextForm
    \`DoReplicates[m, p\&_, nloci, {nreps, ninds}, metK, r, MethodP -> Fit, 
        MethodC -> Fit]\ performs\ various\ tests\ on\ replicate\ samples, \ 
    fitting\ cumulants\ c\_\(j, k\) . \ Replicate\ samples\ are\ stored\ in\ 
      files\ named\ r[m, p], \ where\ m\ p\&_, \ 
    m\ q\&_\ are\ the\ rates\ of\ long - 
      range\ immigration . \ \ Results\ are\ \(\((in\ order)\) : \ HWLE\); 
    \ {optional\ set}; \ 
    true\ model\ \((with\ true\ p)\) . \ MethodP -> 
      Fit\ fits\ allele\ frequencies; \ Sample\ uses\ the\ estimated\ P; \ 
    True\ uses\ the\ actual\ P; \ \ 
    All\ uses\ all\ these\ \((default)\) . \ MethodC -> 
      Fit\ fits\ all\ moments; \ TrueC2\ fixes\ c\_\(1, 1\), \ c\_\(0, 2\); \ 
    True\ uses\ the\ actual\ C' s; \ \ Both\ uses\ True\ and\ Fit; \ 
    All\ uses\ all\ these\ \((default)\) . \ \ Cumulant \[Rule] 
      False\ fits\ moments\ instead\ of\ \(cumulants . \)\)], "Subsubsection"],

Cell[BoxData[
    \(\(Options[DoReplicates] = {MethodP -> {Fit, Sample, True}, 
          MethodC -> {HWLE, Fit, Sample, TrueC2, True}, 
          Cumulant \[Rule] True, Print \[Rule] False};\)\)], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(\(DoReplicates[m_, pp_, nl_, {nr_, ni_}, metK_, r_, opts___Rule] := \n\t
        Module[{cTrue, j, k, c, tt, ccc, dt, cStep, pSample, 
            cSample, \n\t\t\tcl00, cl10, cl01, cl11, clRU, clLE, \n\t\t\ts, 
            mm, cc, h, mset, cset, rs, cum, tr, tr2, ff, mx, x0, 
            y0, \n\t\t\tpStep = 
              Array[2 \@\(\( pp \((1 - pp)\)\)\/ni\) &, nl], 
            pStepFix = Array[0 &, nl], 
            pStepFree = Array[1 &, nl], \n\t\t\t\[Delta]p = 
              Array[1 &, nl], \[CapitalDelta]\[Delta]p = 
              Array[0 &, nl], \n\t\t\tpTrue = Array[pp &, nl], 
            pMid, \n\t\t\tpFree, cFree, def = 0.95, res, 
            pQ = \(Print /. {opts}\) /. 
                Options[DoReplicates]}, \n\ \ \ \ \ Off[
            General::ovfl]; \n\t\tcl00 = 
            Array[0 &, {nl + 1, nl + 1}]; \n\t\tcl11 = 
            Array[1 &, {nl + 1, nl + 1}]; \n\t\tcl11\[LeftDoubleBracket]1, 
              1\[RightDoubleBracket] = 0; 
          cl11\[LeftDoubleBracket]1, 2\[RightDoubleBracket] = 0; 
          cl11\[LeftDoubleBracket]2, 1\[RightDoubleBracket] = 0; \n\t\tcl10 = 
            ReplacePart[cl00, 1, {1, 1}]; \n\t\tclLE = 
            ReplacePart[cl00, 1, {2, 2}]; \n\t\tcl01 = 
            Table[If[j + k > 2, 1, 0], {j, 0, nl}, {k, 0, nl}]; \n\t\tclRU = 
            cl11*Table[
                If[\((j == 0)\) || \((k == 0)\), 1, 0], {j, 0, nl}, {k, 0, 
                  nl}]; \n\ \ \ \ \ mm = {\(MethodP /. {opts}\) /. 
                  Options[DoReplicates]} // 
              Flatten; \n\t\tcc = {\(MethodC /. {opts}\) /. 
                  Options[DoReplicates]} // 
              Flatten; \n\t\tcum = \(Cumulant /. {opts}\) /. 
              Options[DoReplicates]; \n\t\ \ \ If[
            cum, \n\t\t\ttr[mmm_] := \(Cumulant[nl]\)[mmm]; 
            tr2[kkk_] := \ \(Moment[nl]\)[kkk], \n\t\t\ttr[c_] := c; 
            tr2[c_] := c]; \n\t\t\ cTrue = 
            tr[Table[
                MomentEquilibrium[{Range[j], Range[k]} /. Combine, ccc, m, 0, 
                  pp, UnlinkedRecombination, 1 &, 0 &], {j, 0, nl}, {k, 0, 
                  nl}]]; \n\ \ \ \ \ Print["\<True C: \>", 
            cTrue // MatrixForm]; \n\t\t\ mset := 
            mm /. {Fit \[Rule] {pSample, pStepFree}, 
                Sample \[Rule] {pSample, pStepFix}, 
                True \[Rule] {pTrue, pStepFix}}; \n\t\t\ cset := 
            cc /. {HWLE \[Rule] {cl10, 
                    cl00}, \n\t\t\t\t\t\t\tLinkageEquilibrium \[Rule] \
{cSample*clLE + cl10, 
                    clLE}, \n\t\t\t\t\t\t\tRandomUnionMethod \[Rule] {clRU*
                        cS + cl10, 
                    clRU}, \n\t\t\t\t\t\t\tFit \[Rule] {cSample, 
                    cl11}, \n\t\t\t\t\t\t\tSample \[Rule] {cSample, 
                    cl00}, \n\t\t\t\t\t\t\tTrue \[Rule] {cTrue, 
                    cl00}, \n\t\t\t\t\t\t\tTrueC2 \[Rule] {cSample*cl01 + 
                      cTrue*\((1 - cl01)\), cl01}}; \n\ \ \ \ \ \ mx[y_] := 
            Array[If[#1 + #2 == 2, 1, y\^\(#1 + #2 - 2\)] &, {nl + 1, 
                nl + 1}]; \n\t\tff[x_, 
              y_, {ppp_, \[CapitalDelta]ppp_}, {mmm_, \[CapitalDelta]mmm_}] := 
            Min[DiploidGenotypeFrequencyList[\((1 - \[CapitalDelta]ppp)\) 
                    ppp + \[CapitalDelta]ppp \((ppp*y + pMid \((1 - y)\))\), 
                tr2[mmm \((\((1 - \[CapitalDelta]mmm)\) + \[CapitalDelta]mmm*
                          mx[x])\)]]]; 
          tt = GenotypeFrequencyConvert[
              DiploidGenotypeFrequencyList[pTrue, tr2[cTrue]], 
              nl]\ ; \n\t\tDrawSamples[r[m, pp], tt, 
            nl, {nr, ni}]; \n\t\tcStep = 
            InitialStep[pTrue, \[Delta]p, 
              tr2[cTrue]]; \n\t\th[{p0_, \[CapitalDelta]p0_}, {c0_, \
\[CapitalDelta]c0_}] := \n\t\t\t\t\t\((x0 = 1; 
              y0 = 1; \n\t\t\t\t\ \ \ \ \ \ pFree = 
                Not[\((Union[\[CapitalDelta]p0] === {0})\)]; \n\t\t\t\t\ \ \ \
\ \ cFree = Not[\((Union[
                        Flatten[\[CapitalDelta]c0]] === {0})\)]; \n\t\t\t\t\ \
\ \ \ \ pMid = Mean[pSample]*\[Delta]p; \n\t\t\t\t\t\tIf[
                ff[1, 1, {p0, \[CapitalDelta]p0}, {c0, \[CapitalDelta]c0}] < 
                  0, \n\t\t\t\t\t\ \ \ If[
                  cFree && \((ff[0, 
                          1, {p0, \[CapitalDelta]p0}, {c0, \
\[CapitalDelta]c0}] \[GreaterEqual] 
                        0)\), \n\ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \  \
(*\(Print["\<Deflating moments\>"];\)*) \n\t\t\t\t\t\t\ \ \ \ \ \ \ While[
                    ff[x0, y0, {p0, \[CapitalDelta]p0}, {c0, \
\[CapitalDelta]c0}] < 0, x0 *= def], \n\t\t\t\t\t\t\ \ \ \ \ \ \ \ \ \ pMid = 
                    Mean[pSample]*\[Delta]p; \n\t\t\t\t\t\t\ \ \ \ \ \ \ \ \ \
If[ff[1, 0, {p0, \[CapitalDelta]p0}, {c0, \[CapitalDelta]c0}] < 
                      0, \n\t\t\t\t\t\t\t\ \ \ \ \ \ \ \ \ \ \ \ pMid = 
                      pTrue; \n\t\t\t\t\t\t\ \ \ \ \ \ \ \ \ \ \ \ \ \ If[
                      ff[1, 0, {p0, \[CapitalDelta]p0}, {c0, \
\[CapitalDelta]c0}] < 0, 
                      pMid = \((\[Delta]p + \[CapitalDelta]\[Delta]p)\)/
                          2]]; \n\t\t\t\t\t\t\ \ \ \ \ \ \ \ \ If[
                    pFree && \((ff[1, 
                            0, {p0, \[CapitalDelta]p0}, {c0, \
\[CapitalDelta]c0}] \[GreaterEqual] 
                          0)\), \n\ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \
\ \ \ \ \ \  (*\(Print["\<Inflating p\>"];\)*) \n\t\t\t\t\t\t\ \ \ \ \ \ \ \ \
\ \ \ \ \ \ While[ff[x0, 
                          y0, {p0, \[CapitalDelta]p0}, {c0, \
\[CapitalDelta]c0}] < 0, 
                      y0 *= def], \n\t\t\t\t\t\t\ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \
\ \ \ \ \ Print["\<Failed to find a sensible starting point\>"]]]]; \n\t\t\t\ \
\ \ If[pQ, Print["\<p, c adjusted by:\>", x0, Tab, \ 
                  y0, "\<; p, \[CapitalDelta]p=\>", p0, 
                  Tab, \[CapitalDelta]p0, "\<; c, \[CapitalDelta]c=\>", 
                  c0 // MatrixForm, 
                  Tab, \[CapitalDelta]c0 // MatrixForm]]; \n\t\t\t\t\ FindMLE[
                s, {0, {{\((1 - \[CapitalDelta]p0)\) 
                          p0 + \[CapitalDelta]p0 \((p0*y0 + 
                              pMid \((1 - 
                                    y0)\))\)}, {\[Delta]p}, \n\t\t\t\t\t\t\t\t\
c0*\((\((1 - \[CapitalDelta]c0)\) + \[CapitalDelta]c0*
                            mx[x0])\)}, {{\[CapitalDelta]p0*
                        pStep}, {\[CapitalDelta]\[Delta]p}, \[CapitalDelta]c0*
                      cStep}}, metK, opts])\); \n\t\t\ \ res = 
            Table[\((s = \(r[m, pp]\)[k]; 
                rs = ReducedData[s, 
                    nl]; \n\t\t\t\t\ \ \ pSample = \(\(AlleleFrequencyTable[
                          s, nl] // N\) // Transpose\) // 
                    Last; \n\t\t\t\t\tcSample = 
                  tr[EstimateMoments[rs\/Plus @@ rs, 
                      pSample]]; \n\t\t\t\t\ \ \ dt = 
                  Flatten[Outer[h, mset, cset, 1], 
                    1]; \n\t\t\ \ \ \ \ \ \ \ Print @@ \(({k}~Join~
                      Flatten[\({Tab, #\[LeftDoubleBracket]1\
\[RightDoubleBracket]} &\) /@ dt])\); \n\t\t\t\tdt)\), {k, nr}]; \n\t
          On[General::ovfl]; \n\t\tres];\)\)], "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{

Cell["\<\
DoReplicatesReduced[m,p,nloci,{nreps,ninds},metK,r] performs \
various tests on replicate  
samples, fitting cumulants cw[j],cb[j]\
\>", "Subsubsection"],

Cell["A syntax error buried in here:", "Text"],

Cell[BoxData[
    RowBox[{
      RowBox[{
      \(DoReplicatesReduced[m_, pp_, nl_, {nr_, ni_}, metK_, r_]\), ":=", 
        "\n", "\t", 
        RowBox[{"Module", "[", 
          RowBox[{
          \({p, ce, cle, k, tt, dt, st0, dum, pl, pE, m00, m10, 
              S = Range[nl], cl0}\), ",", "\n", "    ", 
            RowBox[{
            \(m00 = {Table[0, {nl}], Table[0, {nl - 1}], 
                  Table[0, {2  nl - 1}]}\), ";", "\n", " \t", 
              \(m10 = {Table[1, {nl}], Table[0, {nl - 1}], 
                  Table[0, {2  nl - 1}]}\), ";", "\n", "\t\t", 
              \(cl0 = Drop[m00, 1]\), ";", \(p[\(i_\^*\)] := p[i]\), ";", 
              \(p[i_] := pp\), ";", "\n", "\t\t", 
              \(ce = CumulantEquilibriumList[m, pp, nl]\), ";", "\n", 
              "\t\t\t", \(Print["\<Expected cumulants \>", ce]\), ";", "\n", 
              "\t\t", \(cle = 
                \(MomentEquilibrium[Sort[#], c, m, 0, pp, 
                      UnlinkedRecombination, 1&, 0&]&\)/@DiploidSubsets[S]\), 
              ";", "\n", "\t\t\t ", 
              \(Print["\<Expected moments found; finding g'type freqs\>"]\), 
              ";", "\n", "\t\t", 
              \(dum[X_] := 
                \(dum[X] = 
                  PossibleDiploidGenotypes[Sort[X], cle, \((\(pp&\)/@S)\)]
                    \)\), ";", "\n", "\t\t\t", 
              \(tt = dum/@diploidTypes[nl]\), ";", "\n", "\t    ", 
              \(Print["\<Expected #:\>", ni*tt]\), ";", "\t", "\n", "\t\t", 
              \(DrawSamples[r[m, pp], tt, nl, {nr, ni}]\), ";", "\n", 
              "\t\t\t\t", \(Print["\<Finding initial step size\>"]\), ";", 
              "\n", "\t\t", 
              \(st0 = Prepend[
                  InitialStepReduced[{cw, cb}, ccl0, 1&, p, Range[nl]], 
                  Table[2 \@\( pp \((1 - pp)\)/ni\), {nl}]]\), ";", "\n", 
              "\t\t", \(Print[st0]\), ";", "\n", "   ", 
              RowBox[{"Table", "[", 
                RowBox[{
                  RowBox[{"(", 
                    RowBox[{
                    \(pE = ptable[data[\(r[m, pp]\)[k]]] // N\), ";", "\n", 
                      "\t\t\t\t\t ", 
                      RowBox[{"dt", "=", 
                        RowBox[{"Join", "[", 
                          RowBox[{
                          \({{k}}\), ",", 
                            \({FindMLE[\(r[m, pp]\)[k], pE, LE]}\), ",", 
                            "\n", "\t\t\t\t\t\t\t", 
                            StyleBox[\( (*\ MLE*) \),
                              FontSlant->"Italic"], 
                            \({FindMLE[\(r[m, pp]\)[k], {0, {pE, cl0}, st0}, 
                                metK]}\), ",", "\n", 
                            StyleBox[
                              RowBox[{"\t\t\t", 
                                StyleBox["\t",
                                  FontSlant->"Italic"], "\t\t"}]], 
                            StyleBox[\( (*\ actual\ c' s\ *) \),
                              FontSlant->"Italic"], 
                            StyleBox["\n",
                              FontSlant->"Italic"], 
                            StyleBox["\t",
                              FontSlant->"Italic"], 
                            RowBox[{
                              StyleBox["{",
                                FontSlant->"Italic"], 
                              \(FindMLE[
                                \(r[m, pp]\)[k], {0, {pE, ce}, st0*m10}, metK]
                                \), "}"}], ",", "\n", "\t\t\t", 
                            \({{\(-
                                  LogLtest[
                                    reducedData[\(r[m, pp]\)[k], simple], 
                                    ni*tt]\), exactModel}}\)}], "]"}]}], ";", 
                      "\n", "\t\t", 
                      \(Print@@
                        Flatten[
                          \({Tab, #\[LeftDoubleBracket]1
                                  \[RightDoubleBracket]}&\)/@dt]\), ";", 
                      "\n", "\t\t\t\t", "dt"}], ")"}], ",", \({k, nr}\)}], 
                "]"}]}]}], "]"}]}], ";"}]], "Input"]
}, Closed]],

Cell[CellGroupData[{

Cell["\<\
MakeSets[nloci] gives an appropriate set of loci for generating the \
expected cumulants.  Works for 2-4 loci.\
\>", "Subsubsection"],

Cell[BoxData[{
    \(\(MakeSets[
          2] = {{1, \(1\^*\)}, {1, 2, \(1\^*\)}, {1, 
            2, \(1\^*\), \(2\^*\)}};\)\), "\n", 
    \(\(MakeSets[
          3] = {{1, \(1\^*\)}, {1, 2, \(1\^*\)}, {1, 
            2, \(1\^*\), \(2\^*\)}, {1, 2, 3, \(1\^*\), \(2\^*\)}, {1, 2, 
            3, \(1\^*\), \(2\^*\), \(3\^*\)}};\)\), "\n", 
    \(\(MakeSets[
          4] = {{1, \(1\^*\)}, {1, 2, \(1\^*\)}, {1, 
            2, \(1\^*\), \(2\^*\)}, {1, 2, 3, \(1\^*\), \(2\^*\)}, {1, 2, 
            3, \(1\^*\), \(2\^*\), \(3\^*\)}, {1, 2, 3, 
            4, \(1\^*\), \(2\^*\), \(3\^*\)}, {1, 2, 3, 
            4, \(1\^*\), \(2\^*\), \(3\^*\), \(4\^*\)}};\)\)}], "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    \(TextForm
    \`PresentResults[results]\ gives\ a\ table\ which\ presents\ the\ mean\ 
      and\ standard\ deviation\ of\ log \((L)\)\ and\ \[Kappa]\_\(0, 2\), \ 
    \[Kappa]\_\(1, 1\), \ \[Kappa]\_\(1, 2\), \ 
    \[Kappa]\_\(2, 2\) . \ \ The\ same\ set\ of\ options\ should\ be\ given\ 
      as\ for\ the\ run\ of\ DoReplicates[]\ which\ generated\ the\ 
      \(results . \)\)], "Subsubsection"],

Cell[BoxData[
    \(\(PresentResults[results_List, {m_, pt_}, opts___Rule] := 
        Module[{nreps = Length[results], ll, logL, pp, cc, pset, cset, np, 
            nc, \[Kappa], \[Kappa]L, nx, fm, fsd, dfp, dfc, 
            nl = Length[
                results\[LeftDoubleBracket]1, 2, 2, 1, 
                  1\[RightDoubleBracket]], sel, ccc, cTrue, \[Kappa]True, j, 
            k}, cTrue = 
            Table[MomentEquilibrium[{Range[j], Range[k]} /. Combine, ccc, m, 
                0, pt, UnlinkedRecombination, 1 &, 0 &], {j, 0, nl}, {k, 0, 
                nl}]; \[Kappa]True = \(Cumulant[nl]\)[cTrue]; 
          pp = \(MethodP /. {opts}\) /. Options[DoReplicates]; 
          cc = \(MethodC /. {opts}\) /. Options[DoReplicates]; 
          dfp = pp /. {Fit \[Rule] nl, Sample \[Rule] nl, True \[Rule] 0}; 
          dfc = cc /. {HWLE \[Rule] 0, LinkageEquilibrium \[Rule] nl - 1, 
                RandomUnionMethod \[Rule] 1, 
                Fit \[Rule] \((nl + 1)\) \((nl + 2)\)/2 - 2, 
                Sample \[Rule] \((nl + 1)\) \((nl + 2)\)/2 - 2, 
                True \[Rule] 0, 
                TrueC2 \[Rule] \((nl + 1)\) \((nl + 2)\)/2 - 4}; 
          pset = pp /. {Fit \[Rule] \*"\"\<fit \!\(p\_i\)\>\"", 
                Sample \[Rule] \*"\"\<sample \!\(p\_i\)\>\"", 
                True \[Rule] \*"\"\<true \!\(p\_i\)\>\""}; 
          cset = cc /. {HWLE \[Rule] "\<HWLE\>", 
                LinkageEquilibrium \[Rule] "\<linkage equilibrium\>", 
                RandomUnionMethod \[Rule] "\<random union\>", 
                Fit \[Rule] \*"\"\<fit all \!\(\[Kappa]\_\(j, \\\\\\\ \
\(\(\\\\\\\\\)\(\\\\\\\ \)\(k\)\)\)\)\>\"", 
                Sample \[Rule] \*"\"\<sample \!\(\[Kappa]\_\(j, \\\\\\\ \
\(\(\\\\\\\\\)\(\\\\\\\ \)\(k\)\)\)\)\>\"", 
                True \[Rule] \*"\"\<true \!\(\[Kappa]\_\(j, \\\\\\\ \
\(\(\\\\\\\\\)\(\\\\\\\ \)\(k\)\)\)\)\>\"", 
                TrueC2 \[Rule] \*"\"\<true \!\(\[Kappa]\_\(1, \\\\\\\ \
\(\(\\\\\\\\\)\(\\\\\\\ \)\(1\)\)\)\), \!\(\[Kappa]\_\(0, \\\\\\\ \
\(\(\\\\\\\\\)\(\\\\\\\ \)\(2\)\)\)\)\>\""}; np = Length[pset]; 
          nc = Length[cset]; 
          dfp = Transpose[Partition[Repeat[dfp, nc], np]] // Flatten; 
          dfc = Repeat[dfc, np]; 
          pset = Transpose[Partition[Repeat[pset, nc], np]] // Flatten; 
          cset = Repeat[cset, np]; 
          ll = Transpose[\(\((# /. {{x_, _List, _List} :> x, {x_, _List} :> 
                          x})\) &\) /@ results]; 
          sel[s_] := Select[s, \((# > \(-10\^8\))\) &]; logL = sel /@ ll; 
          nx = \((Length /@ ll)\) - \((Length /@ logL)\); \n\t\t\[Kappa][i_, 
              j_] := \((#\[LeftDoubleBracket]2, 3, i + 1, 
                  j + 1\[RightDoubleBracket])\) &; \[Kappa]L[i_, 
              j_] := \(\[Kappa]L[i, j] = 
              Transpose[\(\((\[Kappa][i, j] /@ #)\) &\) /@ results]\); 
          fm[x_List] := \(PaddedForm[Chop[Mean[#]], {7, 4}] &\) /@ x; 
          fsd[x_List] := \(PaddedForm[
                  Chop[StandardDeviation[#]], {7, 4}] &\) /@ x; 
          Append[Prepend[{pset, 
                  cset, \(PaddedForm[Mean[#], {8, 2}] &\) /@ 
                    logL, \(PaddedForm[Variance[#], {8, 2}] &\) /@ logL, 
                  3\^nl - 1 - dfc - dfp, nx, fm[\[Kappa]L[0, 2]], 
                  fsd[\[Kappa]L[0, 2]], fm[\[Kappa]L[1, 1]], 
                  fsd[\[Kappa]L[1, 1]], fm[\[Kappa]L[1, 2]], 
                  fsd[\[Kappa]L[1, 2]], fm[\[Kappa]L[2, 2]], 
                  fsd[\[Kappa]L[2, 2]]} // 
                Transpose, {"\<allele\nfrequencies\>", "\<moments\>", \
"\<log(L)\nmean\>", "\<\nvariance\>", "\<d.f.\>", "\<#\ninvalid\>", \*"\"\<\!\
\(\[Kappa]\_\(0, \\\\\\\ \(\(\\\\\\\\\)\(\\\\\\\ \)\(2\)\)\)\)\\nmean\>\"", "\
\<\ns.d.\>", \*"\"\<\!\(\[Kappa]\_\(1, \\\\\\\ \(\(\\\\\\\\\)\(\\\\\\\ \
\)\(1\)\)\)\)\\nmean\>\"", "\<\ns.d.\>", \*"\"\<\!\(\[Kappa]\_\(1, \\\\\\\ \(\
\(\\\\\\\\\)\(\\\\\\\ \)\(2\)\)\)\)\\nmean\>\"", "\<\ns.d.\>", \*"\"\<\!\(\
\[Kappa]\_\(2, \\\\\\\ \(\(\\\\\\\\\)\(\\\\\\\ \)\(2\)\)\)\)\\nmean\>\"", "\<\
\ns.d.\>"}], {"\<\>", "\<true\ncumulants\>", "\<\>", "\<\>", "\<\>", "\<\>", 
              PaddedForm[\[Kappa]True\[LeftDoubleBracket]1, 
                  3\[RightDoubleBracket], {7, 
                  4}], "\<\>", \n\t\t\t\t\t\tPaddedForm[\[Kappa]True\
\[LeftDoubleBracket]2, 2\[RightDoubleBracket], {7, 4}], "\<\>", 
              PaddedForm[\[Kappa]True\[LeftDoubleBracket]2, 
                  3\[RightDoubleBracket], {7, 4}], "\<\>", 
              PaddedForm[\[Kappa]True\[LeftDoubleBracket]3, 
                  3\[RightDoubleBracket], {7, 4}], "\<\>"}]];\)\)], "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    \(TextForm
    \`CompareLogL[results, {i, j}]\ compares\ the\ likelihood\ of\ method\_i\ 
      with\ that\ of\ method\_j, \ 
    using\ a\ set\ of\ results\ generated\ by\ 
      DoReplicates[] . \ \ \ Returns\ a\ list\ of\ the\ differences\ in\ log 
      \(\((likelihood)\) . \)\)], "Subsubsection"],

Cell[BoxData[
    \(\(CompareLogL[results_List, {i_Integer, j_Integer}] := \n\t
        Module[{logL}, \n\t\ \ \ logL = 
            Transpose[\(\((# /. {{x_, _List, _List} :> x, {x_, _List} :> 
                          x})\) &\) /@ results]; \n\t\t\((Sort[
                logL\[LeftDoubleBracket]i\[RightDoubleBracket] - 
                  logL\[LeftDoubleBracket]j\[RightDoubleBracket]])\) // 
            Chop];\)\)], "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    \(TextForm
    \`PresentLogL[
        results, {{j, k}, \[Ellipsis]}, {df\_\(j, k\), \[Ellipsis]}, {
          name\_\(j, k\), \[Ellipsis]}, P]\ presents\ a\ table\ summarising\ a
      \ list\ of\ comparisons\ based\ on\ results\ produced\ by\ 
      DoReplicates[] . \ \ {{j, k}, \[Ellipsis]}\ is\ a\ list\ of\ comparisons
      \ between\ method\ j\ and\ method\ k\ in\ 
      results . \ {df\_\(j, k\), \[Ellipsis]}\ gives\ the\ corresponding\ 
      degrees\ of\ freedom, \ 
    and\ {\(name\_\(j, k\)\) \[Ellipsis]}\ the\ corresponding\ names . \ \ P\ 
      gives\ the\ significance\ level . \ \ The\ table\ lists\ the\ number\ of
      \ valid\ log \((L)\); \ 
    the\ mean\ and\ variance\ of\ the\ valid\ log \((L)\); \ 
    the\ number\ of\ negative\ \[CapitalDelta]log \((L)\); \ 
    and\ the\ number\ of\ cases\ in\ which\ the\ hypothesis\ was\ rejected\ at
      \ significance\ level\ P, \ 
    based\ on\ the\ asymptotic\ 1/2  \[Chi]\^2\ \(distribution . \)\)], 
  "Subsubsection"],

Cell[BoxData[
    \(\(PresentLogL[res_, jl_List, dfl_List, names_List, P_] := 
        Module[{dc, ff, 
            cl}, \n\t\tcl = \(CompareLogL[res, #] &\) /@ jl; \n\t\tff[ll_, 
              df_, name_] := \n\t\t\t\((dc = 
                Select[ll, \((# < 10\^6)\) &]; \n\t\t\t\t{name, Length[dc], 
                Mean[dc], Variance[dc], Length[Select[dc, \((# < 0)\) &]], 
                Length[Select[
                    dc, \((# > \(1\/2\) 
                            Quantile[ChiSquareDistribution[df], 
                              1 - P])\) &]]})\); \n\t\tPrepend[
            MapThread[
              ff, {cl, dfl, 
                names}], \n\t\t{"\<\>", "\<# valid\nresults\>", "\<log(L)\n\
mean\>", "\<\nvariance\>", "\<# negative\nvalues\>", 
              StringJoin["\<# rejected\n at P=\>", 
                ToString[P]]}]];\)\)], "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    \(TextForm
    \`PlotLogL[results, {{j, k}, \[Ellipsis]}, {\(df\_\(j, k\)\) \[Ellipsis]}]
        \ plots\ the\ cumulative\ distributions\ of\ \[CapitalDelta]log 
      \((L)\), \ 
    and\ the\ asymptotic\ 1/2  \[Chi]\^2\ distribution . \ Uses\ results\ 
      produced\ by\ DoReplicates[] . \ \ {{j, k}, \[Ellipsis]}\ is\ a\ list\ 
      of\ comparisons\ between\ method\ j\ and\ method\ k\ in\ results; \ 
    each\ gives\ a\ graph . \ \ {df\_\(j, k\), \[Ellipsis]}\ gives\ the\ 
      corresponding\ degrees\ of\ \(freedom . \)\)], "Subsubsection"],

Cell[BoxData[
    \(\(PlotLogL[res_, jl_List, dfl_List] := \n\t
        Module[{dc, bc, ff, x0, x1, dx = 0.25, jk, ll, x}, \n\t
          ff[jk_, df_] := \n\t\t\t\((ll = 
                CompareLogL[res, jk]; \n\t\t\t\tdc = 
                Select[ll, \((# < 10\^6)\) &]; \n\t\t\t\ x0 = Floor[Min[dc]]; 
              x1 = Ceiling[Max[dc]]; \n\t\t\t\tbc = 
                BinCounts[dc, {x0, x1, dx}]; \n\t\t\tDisplayTogether[
                Plot[CDF[ChiSquareDistribution[df], 2  x], {x, 0, 
                    x1}], \n\t\t\t\t\tListPlot[
                  Transpose[{Range[x0, x1, dx] + dx/2, 
                      FoldList[Plus, \ 0, \ bc]/Length[dc] // N}]]])\); \n\t
          MapThread[ff, {jl, dfl}];];\)\)], "Input",
  InitializationCell->True]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["Ending", "Subsection"],

Cell[BoxData[
    \(\(On[General::spell1, General::spell];\)\)], "Input",
  InitializationCell->True],

Cell["\<\
End[];
\
\>", "Input",
  InitializationCell->True],

Cell["EndPackage[];", "Input",
  InitializationCell->True]
}, Closed]]
}, Open  ]]
},
FrontEndVersion->"4.0 for Macintosh",
ScreenRectangle->{{0, 1152}, {0, 748}},
AutoGeneratedPackage->Automatic,
WindowSize->{695, 690},
WindowMargins->{{Automatic, 34}, {Automatic, 11}},
Visible->True,
InputAliases->{"notation"->RowBox[ {"Notation", "[", 
        RowBox[ {
          TagBox[ 
          "\[Placeholder]", NotationBoxTag, TagStyle -> 
            "NotationTemplateStyle"], " ", "\[DoubleLongLeftRightArrow]", " ",
           
          TagBox[ 
          "\[Placeholder]", NotationBoxTag, TagStyle -> 
            "NotationTemplateStyle"]}], "]"}], 
    "notation>"->RowBox[ {"Notation", "[", 
        RowBox[ {
          TagBox[ 
          "\[Placeholder]", NotationBoxTag, TagStyle -> 
            "NotationTemplateStyle"], " ", "\[DoubleLongRightArrow]", " ", 
          TagBox[ 
          "\[Placeholder]", NotationBoxTag, TagStyle -> 
            "NotationTemplateStyle"]}], "]"}], 
    "notation<"->RowBox[ {"Notation", "[", 
        RowBox[ {
          TagBox[ 
          "\[Placeholder]", NotationBoxTag, TagStyle -> 
            "NotationTemplateStyle"], " ", "\[DoubleLongLeftArrow]", " ", 
          TagBox[ 
          "\[Placeholder]", NotationBoxTag, TagStyle -> 
            "NotationTemplateStyle"]}], "]"}], 
    "symb"->RowBox[ {"Symbolize", "[", 
        TagBox[ 
        "\[Placeholder]", NotationBoxTag, TagStyle -> 
          "NotationTemplateStyle"], "]"}], 
    "infixnotation"->RowBox[ {"InfixNotation", "[", 
        RowBox[ {
          TagBox[ 
          "\[Placeholder]", NotationBoxTag, TagStyle -> 
            "NotationTemplateStyle"], ",", "\[Placeholder]"}], "]"}], 
    "addia"->RowBox[ {"AddInputAlias", "[", 
        RowBox[ {
          TagBox[ 
          "\[Placeholder]", NotationBoxTag, TagStyle -> 
            "NotationTemplateStyle"], ",", "\[Placeholder]"}], "]"}], 
    "pattwraper"->TagBox[ 
      "\[Placeholder]", NotationPatternTag, TagStyle -> 
        "NotationPatternWrapperStyle"], 
    "madeboxeswraper"->TagBox[ 
      "\[Placeholder]", NotationMadeBoxesTag, TagStyle -> 
        "NotationMadeBoxesWrapperStyle"]},
StyleDefinitions -> Notebook[{
  
  Cell[CellGroupData[{
  Cell["Style Definitions", "Subtitle"],
  
  Cell["\<\
Modify the definitions below to change the default appearance of \
all cells in a given style.  Make modifications to any definition using \
commands in the Format menu.\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell["Style Environment Names", "Section"],
  
  Cell[StyleData[All, "Working"],
    PageWidth->WindowWidth,
    CellLabelMargins->{{12, Inherited}, {Inherited, Inherited}},
    ScriptMinSize->9],
  
  Cell[StyleData[All, "Presentation"],
    PageWidth->WindowWidth,
    CellLabelMargins->{{24, Inherited}, {Inherited, Inherited}},
    ScriptMinSize->12],
  
  Cell[StyleData[All, "Condensed"],
    PageWidth->WindowWidth,
    CellLabelMargins->{{8, Inherited}, {Inherited, Inherited}},
    ScriptMinSize->8],
  
  Cell[StyleData[All, "Printout"],
    PageWidth->PaperWidth,
    CellLabelMargins->{{2, Inherited}, {Inherited, Inherited}},
    ScriptMinSize->5,
    PrivateFontOptions->{"FontType"->"Outline"}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Notebook Options", "Section"],
  
  Cell["\<\
The options defined for the style below will be used at the \
Notebook level.\
\>", "Text"],
  
  Cell[StyleData["Notebook"],
    PageHeaders->{{Cell[ 
            TextData[ {
              CounterBox[ "Page"]}], "PageNumber"], None, Cell[ 
            TextData[ {
              ValueBox[ "FileName"]}], "Header"]}, {Cell[ 
            TextData[ {
              ValueBox[ "FileName"]}], "Header"], None, Cell[ 
            TextData[ {
              CounterBox[ "Page"]}], "PageNumber"]}},
    CellFrameLabelMargins->6,
    StyleMenuListing->None]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Styles for Headings", "Section"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Title"],
    CellMargins->{{12, Inherited}, {20, 40}},
    CellGroupingRules->{"TitleGrouping", 0},
    PageBreakBelow->False,
    DefaultNewInlineCellStyle->"None",
    InputAutoReplacements->{"TeX"->StyleBox[ 
            RowBox[ {"T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.074999999999999997, \
-0.085000000000000006}, {0, 0}}, BoxBaselineShift -> 0.5], "X"}]], 
        "LaTeX"->StyleBox[ 
            RowBox[ {"L", 
              StyleBox[ 
                AdjustmentBox[ 
                "A", BoxMargins -> {{-0.35999999999999999, \
-0.10000000000000001}, {0, 0}}, BoxBaselineShift -> -0.20000000000000001], 
                FontSize -> Smaller], "T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.074999999999999997, \
-0.085000000000000006}, {0, 0}}, BoxBaselineShift -> 0.5], "X"}]], 
        "mma"->"Mathematica", "Mma"->"Mathematica", "MMA"->"Mathematica"},
    LanguageCategory->"NaturalLanguage",
    CounterIncrements->"Title",
    CounterAssignments->{{"Section", 0}, {"Equation", 0}, {"Figure", 0}, {
        "Subtitle", 0}, {"Subsubtitle", 0}},
    FontFamily->"Helvetica",
    FontSize->36,
    FontWeight->"Bold"],
  
  Cell[StyleData["Title", "Presentation"],
    CellMargins->{{24, 10}, {20, 40}},
    LineSpacing->{1, 0},
    FontSize->44],
  
  Cell[StyleData["Title", "Condensed"],
    CellMargins->{{8, 10}, {4, 8}},
    FontSize->20],
  
  Cell[StyleData["Title", "Printout"],
    CellMargins->{{2, 10}, {12, 30}},
    FontSize->24]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Subtitle"],
    CellMargins->{{12, Inherited}, {20, 15}},
    CellGroupingRules->{"TitleGrouping", 10},
    PageBreakBelow->False,
    DefaultNewInlineCellStyle->"None",
    InputAutoReplacements->{"TeX"->StyleBox[ 
            RowBox[ {"T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.074999999999999997, \
-0.085000000000000006}, {0, 0}}, BoxBaselineShift -> 0.5], "X"}]], 
        "LaTeX"->StyleBox[ 
            RowBox[ {"L", 
              StyleBox[ 
                AdjustmentBox[ 
                "A", 
                  BoxMargins -> {{-0.35999999999999999, \
-0.10000000000000001}, {0, 0}}, BoxBaselineShift -> -0.20000000000000001], 
                FontSize -> Smaller], "T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.074999999999999997, \
-0.085000000000000006}, {0, 0}}, BoxBaselineShift -> 0.5], "X"}]], 
        "mma"->"Mathematica", "Mma"->"Mathematica", "MMA"->"Mathematica"},
    LanguageCategory->"NaturalLanguage",
    CounterIncrements->"Subtitle",
    CounterAssignments->{{"Section", 0}, {"Equation", 0}, {"Figure", 0}, {
        "Subsubtitle", 0}},
    FontFamily->"Helvetica",
    FontSize->24],
  
  Cell[StyleData["Subtitle", "Presentation"],
    CellMargins->{{24, 10}, {20, 20}},
    LineSpacing->{1, 0},
    FontSize->36],
  
  Cell[StyleData["Subtitle", "Condensed"],
    CellMargins->{{8, 10}, {4, 4}},
    FontSize->14],
  
  Cell[StyleData["Subtitle", "Printout"],
    CellMargins->{{2, 10}, {12, 8}},
    FontSize->18]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Subsubtitle"],
    CellMargins->{{12, Inherited}, {20, 15}},
    CellGroupingRules->{"TitleGrouping", 20},
    PageBreakBelow->False,
    DefaultNewInlineCellStyle->"None",
    InputAutoReplacements->{"TeX"->StyleBox[ 
            RowBox[ {"T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.074999999999999997, \
-0.085000000000000006}, {0, 0}}, BoxBaselineShift -> 0.5], "X"}]], 
        "LaTeX"->StyleBox[ 
            RowBox[ {"L", 
              StyleBox[ 
                AdjustmentBox[ 
                "A", BoxMargins -> {{-0.35999999999999999, \
-0.10000000000000001}, {0, 0}}, BoxBaselineShift -> -0.20000000000000001], 
                FontSize -> Smaller], "T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.074999999999999997, \
-0.085000000000000006}, {0, 0}}, BoxBaselineShift -> 0.5], "X"}]], 
        "mma"->"Mathematica", "Mma"->"Mathematica", "MMA"->"Mathematica"},
    LanguageCategory->"NaturalLanguage",
    CounterIncrements->"Subsubtitle",
    CounterAssignments->{{"Section", 0}, {"Equation", 0}, {"Figure", 0}},
    FontFamily->"Helvetica",
    FontSize->14,
    FontSlant->"Italic"],
  
  Cell[StyleData["Subsubtitle", "Presentation"],
    CellMargins->{{24, 10}, {20, 20}},
    LineSpacing->{1, 0},
    FontSize->24],
  
  Cell[StyleData["Subsubtitle", "Condensed"],
    CellMargins->{{8, 10}, {8, 8}},
    FontSize->12],
  
  Cell[StyleData["Subsubtitle", "Printout"],
    CellMargins->{{2, 10}, {12, 8}},
    FontSize->14]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Section"],
    CellDingbat->"\[FilledSquare]",
    CellMargins->{{25, Inherited}, {8, 24}},
    CellGroupingRules->{"SectionGrouping", 30},
    PageBreakBelow->False,
    DefaultNewInlineCellStyle->"None",
    InputAutoReplacements->{"TeX"->StyleBox[ 
            RowBox[ {"T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.074999999999999997, \
-0.085000000000000006}, {0, 0}}, BoxBaselineShift -> 0.5], "X"}]], 
        "LaTeX"->StyleBox[ 
            RowBox[ {"L", 
              StyleBox[ 
                AdjustmentBox[ 
                "A", BoxMargins -> {{-0.35999999999999999, \
-0.10000000000000001}, {0, 0}}, BoxBaselineShift -> -0.20000000000000001], 
                FontSize -> Smaller], "T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.074999999999999997, \
-0.085000000000000006}, {0, 0}}, BoxBaselineShift -> 0.5], "X"}]], 
        "mma"->"Mathematica", "Mma"->"Mathematica", "MMA"->"Mathematica"},
    LanguageCategory->"NaturalLanguage",
    CounterIncrements->"Section",
    CounterAssignments->{{"Subsection", 0}, {"Subsubsection", 0}},
    FontFamily->"Helvetica",
    FontSize->16,
    FontWeight->"Bold"],
  
  Cell[StyleData["Section", "Presentation"],
    CellMargins->{{40, 10}, {11, 32}},
    LineSpacing->{1, 0},
    FontSize->24],
  
  Cell[StyleData["Section", "Condensed"],
    CellMargins->{{18, Inherited}, {6, 12}},
    FontSize->12],
  
  Cell[StyleData["Section", "Printout"],
    CellMargins->{{13, 0}, {7, 22}},
    FontSize->14]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Subsection"],
    CellDingbat->"\[FilledSmallSquare]",
    CellMargins->{{22, Inherited}, {8, 20}},
    CellGroupingRules->{"SectionGrouping", 40},
    PageBreakBelow->False,
    DefaultNewInlineCellStyle->"None",
    InputAutoReplacements->{"TeX"->StyleBox[ 
            RowBox[ {"T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.074999999999999997, \
-0.085000000000000006}, {0, 0}}, BoxBaselineShift -> 0.5], "X"}]], 
        "LaTeX"->StyleBox[ 
            RowBox[ {"L", 
              StyleBox[ 
                AdjustmentBox[ 
                "A", BoxMargins -> {{-0.35999999999999999, \
-0.10000000000000001}, {0, 0}}, BoxBaselineShift -> -0.20000000000000001], 
                FontSize -> Smaller], "T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.074999999999999997, \
-0.085000000000000006}, {0, 0}}, BoxBaselineShift -> 0.5], "X"}]], 
        "mma"->"Mathematica", "Mma"->"Mathematica", "MMA"->"Mathematica"},
    LanguageCategory->"NaturalLanguage",
    CounterIncrements->"Subsection",
    CounterAssignments->{{"Subsubsection", 0}},
    FontFamily->"Times",
    FontSize->14,
    FontWeight->"Bold"],
  
  Cell[StyleData["Subsection", "Presentation"],
    CellMargins->{{36, 10}, {11, 32}},
    LineSpacing->{1, 0},
    FontSize->22],
  
  Cell[StyleData["Subsection", "Condensed"],
    CellMargins->{{16, Inherited}, {6, 12}},
    FontSize->12],
  
  Cell[StyleData["Subsection", "Printout"],
    CellMargins->{{9, 0}, {7, 22}},
    FontSize->12]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Subsubsection"],
    CellDingbat->"\[FilledSmallSquare]",
    CellMargins->{{22, Inherited}, {8, 18}},
    CellGroupingRules->{"SectionGrouping", 50},
    PageBreakBelow->False,
    DefaultNewInlineCellStyle->"None",
    InputAutoReplacements->{"TeX"->StyleBox[ 
            RowBox[ {"T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.074999999999999997, \
-0.085000000000000006}, {0, 0}}, BoxBaselineShift -> 0.5], "X"}]], 
        "LaTeX"->StyleBox[ 
            RowBox[ {"L", 
              StyleBox[ 
                AdjustmentBox[ 
                "A", BoxMargins -> {{-0.35999999999999999, \
-0.10000000000000001}, {0, 0}}, BoxBaselineShift -> -0.20000000000000001], 
                FontSize -> Smaller], "T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.074999999999999997, \
-0.085000000000000006}, {0, 0}}, BoxBaselineShift -> 0.5], "X"}]], 
        "mma"->"Mathematica", "Mma"->"Mathematica", "MMA"->"Mathematica"},
    LanguageCategory->"NaturalLanguage",
    CounterIncrements->"Subsubsection",
    FontFamily->"Times",
    FontWeight->"Bold"],
  
  Cell[StyleData["Subsubsection", "Presentation"],
    CellMargins->{{34, 10}, {11, 26}},
    LineSpacing->{1, 0},
    FontSize->18],
  
  Cell[StyleData["Subsubsection", "Condensed"],
    CellMargins->{{17, Inherited}, {6, 12}},
    FontSize->10],
  
  Cell[StyleData["Subsubsection", "Printout"],
    CellMargins->{{9, 0}, {7, 14}},
    FontSize->11]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Styles for Body Text", "Section"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Text"],
    CellMargins->{{12, 10}, {7, 7}},
    InputAutoReplacements->{"TeX"->StyleBox[ 
            RowBox[ {"T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.074999999999999997, \
-0.085000000000000006}, {0, 0}}, BoxBaselineShift -> 0.5], "X"}]], 
        "LaTeX"->StyleBox[ 
            RowBox[ {"L", 
              StyleBox[ 
                AdjustmentBox[ 
                "A", BoxMargins -> {{-0.35999999999999999, \
-0.10000000000000001}, {0, 0}}, BoxBaselineShift -> -0.20000000000000001], 
                FontSize -> Smaller], "T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.074999999999999997, \
-0.085000000000000006}, {0, 0}}, BoxBaselineShift -> 0.5], "X"}]], 
        "mma"->"Mathematica", "Mma"->"Mathematica", "MMA"->"Mathematica"},
    Hyphenation->True,
    LineSpacing->{1, 3},
    CounterIncrements->"Text"],
  
  Cell[StyleData["Text", "Presentation"],
    CellMargins->{{24, 10}, {10, 10}},
    LineSpacing->{1, 5},
    FontSize->16],
  
  Cell[StyleData["Text", "Condensed"],
    CellMargins->{{8, 10}, {6, 6}},
    LineSpacing->{1, 1},
    FontSize->11],
  
  Cell[StyleData["Text", "Printout"],
    CellMargins->{{2, 2}, {6, 6}},
    TextJustification->0.5,
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["SmallText"],
    CellMargins->{{12, 10}, {6, 6}},
    DefaultNewInlineCellStyle->"None",
    Hyphenation->True,
    LineSpacing->{1, 3},
    LanguageCategory->"NaturalLanguage",
    CounterIncrements->"SmallText",
    FontFamily->"Helvetica",
    FontSize->9],
  
  Cell[StyleData["SmallText", "Presentation"],
    CellMargins->{{24, 10}, {8, 8}},
    LineSpacing->{1, 5},
    FontSize->12],
  
  Cell[StyleData["SmallText", "Condensed"],
    CellMargins->{{8, 10}, {5, 5}},
    LineSpacing->{1, 2},
    FontSize->9],
  
  Cell[StyleData["SmallText", "Printout"],
    CellMargins->{{2, 2}, {5, 5}},
    TextJustification->0.5,
    FontSize->7]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Styles for Input/Output", "Section"],
  
  Cell["\<\
The cells in this section define styles used for input and output \
to the kernel.  Be careful when modifying, renaming, or removing these \
styles, because the front end associates special meanings with these style \
names. Some attributes for these styles are actually set in FormatType Styles \
(in the last section of this stylesheet). \
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Input"],
    CellMargins->{{45, 10}, {5, 7}},
    Evaluatable->True,
    CellGroupingRules->"InputGrouping",
    CellHorizontalScrolling->True,
    PageBreakWithin->False,
    GroupPageBreakWithin->False,
    DefaultFormatType->DefaultInputFormatType,
    HyphenationOptions->{"HyphenationCharacter"->"\[Continuation]"},
    AutoItalicWords->{},
    LanguageCategory->"Formula",
    FormatType->InputForm,
    ShowStringCharacters->True,
    NumberMarks->True,
    LinebreakAdjustments->{0.85, 2, 10, 0, 1},
    CounterIncrements->"Input",
    FontWeight->"Bold"],
  
  Cell[StyleData["Input", "Presentation"],
    CellMargins->{{72, Inherited}, {8, 10}},
    LineSpacing->{1, 0},
    FontSize->16],
  
  Cell[StyleData["Input", "Condensed"],
    CellMargins->{{40, 10}, {2, 3}},
    FontSize->11],
  
  Cell[StyleData["Input", "Printout"],
    CellMargins->{{39, 0}, {4, 6}},
    LinebreakAdjustments->{0.85, 2, 10, 1, 1},
    FontSize->9]
  }, Closed]],
  
  Cell[StyleData["InputOnly"],
    Evaluatable->True,
    CellGroupingRules->"InputGrouping",
    CellHorizontalScrolling->True,
    DefaultFormatType->DefaultInputFormatType,
    HyphenationOptions->{"HyphenationCharacter"->"\[Continuation]"},
    AutoItalicWords->{},
    LanguageCategory->"Formula",
    FormatType->InputForm,
    ShowStringCharacters->True,
    NumberMarks->True,
    LinebreakAdjustments->{0.85, 2, 10, 0, 1},
    CounterIncrements->"Input",
    StyleMenuListing->None,
    FontWeight->"Bold"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Output"],
    CellMargins->{{47, 10}, {7, 5}},
    CellEditDuplicate->True,
    CellGroupingRules->"OutputGrouping",
    CellHorizontalScrolling->True,
    PageBreakWithin->False,
    GroupPageBreakWithin->False,
    GeneratedCell->True,
    CellAutoOverwrite->True,
    DefaultFormatType->DefaultOutputFormatType,
    HyphenationOptions->{"HyphenationCharacter"->"\[Continuation]"},
    AutoItalicWords->{},
    LanguageCategory->"Formula",
    FormatType->InputForm,
    CounterIncrements->"Output"],
  
  Cell[StyleData["Output", "Presentation"],
    CellMargins->{{72, Inherited}, {10, 8}},
    LineSpacing->{1, 0},
    FontSize->16],
  
  Cell[StyleData["Output", "Condensed"],
    CellMargins->{{41, Inherited}, {3, 2}},
    FontSize->11],
  
  Cell[StyleData["Output", "Printout"],
    CellMargins->{{39, 0}, {6, 4}},
    FontSize->9]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Message"],
    CellMargins->{{45, Inherited}, {Inherited, Inherited}},
    CellGroupingRules->"OutputGrouping",
    PageBreakWithin->False,
    GroupPageBreakWithin->False,
    GeneratedCell->True,
    CellAutoOverwrite->True,
    ShowCellLabel->False,
    DefaultFormatType->DefaultOutputFormatType,
    HyphenationOptions->{"HyphenationCharacter"->"\[Continuation]"},
    AutoItalicWords->{},
    FormatType->InputForm,
    CounterIncrements->"Message",
    StyleMenuListing->None,
    FontSize->11,
    FontColor->RGBColor[0, 0, 1]],
  
  Cell[StyleData["Message", "Presentation"],
    CellMargins->{{72, Inherited}, {Inherited, Inherited}},
    LineSpacing->{1, 0},
    FontSize->16],
  
  Cell[StyleData["Message", "Condensed"],
    CellMargins->{{41, Inherited}, {Inherited, Inherited}},
    FontSize->11],
  
  Cell[StyleData["Message", "Printout"],
    CellMargins->{{39, Inherited}, {Inherited, Inherited}},
    FontSize->7,
    FontColor->GrayLevel[0]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Print"],
    CellMargins->{{45, Inherited}, {Inherited, Inherited}},
    CellGroupingRules->"OutputGrouping",
    CellHorizontalScrolling->True,
    PageBreakWithin->False,
    GroupPageBreakWithin->False,
    GeneratedCell->True,
    CellAutoOverwrite->True,
    ShowCellLabel->False,
    DefaultFormatType->DefaultOutputFormatType,
    HyphenationOptions->{"HyphenationCharacter"->"\[Continuation]"},
    AutoItalicWords->{},
    FormatType->InputForm,
    CounterIncrements->"Print",
    StyleMenuListing->None],
  
  Cell[StyleData["Print", "Presentation"],
    CellMargins->{{72, Inherited}, {Inherited, Inherited}},
    LineSpacing->{1, 0},
    FontSize->16],
  
  Cell[StyleData["Print", "Condensed"],
    CellMargins->{{41, Inherited}, {Inherited, Inherited}},
    FontSize->11],
  
  Cell[StyleData["Print", "Printout"],
    CellMargins->{{39, Inherited}, {Inherited, Inherited}},
    FontSize->8]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Graphics"],
    CellMargins->{{4, Inherited}, {Inherited, Inherited}},
    CellGroupingRules->"GraphicsGrouping",
    CellHorizontalScrolling->True,
    PageBreakWithin->False,
    GeneratedCell->True,
    CellAutoOverwrite->True,
    ShowCellLabel->False,
    DefaultFormatType->DefaultOutputFormatType,
    LanguageCategory->None,
    FormatType->InputForm,
    CounterIncrements->"Graphics",
    ImageMargins->{{43, Inherited}, {Inherited, 0}},
    StyleMenuListing->None,
    FontFamily->"Courier",
    FontSize->10],
  
  Cell[StyleData["Graphics", "Presentation"],
    ImageMargins->{{62, Inherited}, {Inherited, 0}}],
  
  Cell[StyleData["Graphics", "Condensed"],
    ImageMargins->{{38, Inherited}, {Inherited, 0}},
    Magnification->0.6],
  
  Cell[StyleData["Graphics", "Printout"],
    ImageMargins->{{30, Inherited}, {Inherited, 0}},
    Magnification->0.8]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["CellLabel"],
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->9,
    FontColor->RGBColor[0, 0, 1]],
  
  Cell[StyleData["CellLabel", "Presentation"],
    FontSize->12],
  
  Cell[StyleData["CellLabel", "Condensed"],
    FontSize->9],
  
  Cell[StyleData["CellLabel", "Printout"],
    FontFamily->"Courier",
    FontSize->8,
    FontSlant->"Italic",
    FontColor->GrayLevel[0]]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Inline Formatting", "Section"],
  
  Cell["\<\
These styles are for modifying individual words or letters in a \
cell exclusive of the cell tag.\
\>", "Text"],
  
  Cell[StyleData["RM"],
    StyleMenuListing->None,
    FontWeight->"Plain",
    FontSlant->"Plain"],
  
  Cell[StyleData["BF"],
    StyleMenuListing->None,
    FontWeight->"Bold"],
  
  Cell[StyleData["IT"],
    StyleMenuListing->None,
    FontSlant->"Italic"],
  
  Cell[StyleData["TR"],
    StyleMenuListing->None,
    FontFamily->"Times",
    FontWeight->"Plain",
    FontSlant->"Plain"],
  
  Cell[StyleData["TI"],
    StyleMenuListing->None,
    FontFamily->"Times",
    FontWeight->"Plain",
    FontSlant->"Italic"],
  
  Cell[StyleData["TB"],
    StyleMenuListing->None,
    FontFamily->"Times",
    FontWeight->"Bold",
    FontSlant->"Plain"],
  
  Cell[StyleData["TBI"],
    StyleMenuListing->None,
    FontFamily->"Times",
    FontWeight->"Bold",
    FontSlant->"Italic"],
  
  Cell[StyleData["MR"],
    StyleMenuListing->None,
    FontFamily->"Courier",
    FontWeight->"Plain",
    FontSlant->"Plain"],
  
  Cell[StyleData["MO"],
    StyleMenuListing->None,
    FontFamily->"Courier",
    FontWeight->"Plain",
    FontSlant->"Italic"],
  
  Cell[StyleData["MB"],
    StyleMenuListing->None,
    FontFamily->"Courier",
    FontWeight->"Bold",
    FontSlant->"Plain"],
  
  Cell[StyleData["MBO"],
    StyleMenuListing->None,
    FontFamily->"Courier",
    FontWeight->"Bold",
    FontSlant->"Italic"],
  
  Cell[StyleData["SR"],
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontWeight->"Plain",
    FontSlant->"Plain"],
  
  Cell[StyleData["SO"],
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontWeight->"Plain",
    FontSlant->"Italic"],
  
  Cell[StyleData["SB"],
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontWeight->"Bold",
    FontSlant->"Plain"],
  
  Cell[StyleData["SBO"],
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontWeight->"Bold",
    FontSlant->"Italic"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["SO10"],
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->10,
    FontWeight->"Plain",
    FontSlant->"Italic"],
  
  Cell[StyleData["SO10", "Printout"],
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->7,
    FontWeight->"Plain",
    FontSlant->"Italic"],
  
  Cell[StyleData["SO10", "EnhancedPrintout"],
    StyleMenuListing->None,
    FontFamily->"Futura",
    FontSize->7,
    FontWeight->"Plain",
    FontSlant->"Italic"]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Formulas and Programming", "Section"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["InlineFormula"],
    CellMargins->{{10, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    HyphenationOptions->{"HyphenationCharacter"->"\[Continuation]"},
    LanguageCategory->"Formula",
    ScriptLevel->1,
    SingleLetterItalics->True],
  
  Cell[StyleData["InlineFormula", "Presentation"],
    CellMargins->{{24, 10}, {10, 10}},
    LineSpacing->{1, 5},
    FontSize->16],
  
  Cell[StyleData["InlineFormula", "Condensed"],
    CellMargins->{{8, 10}, {6, 6}},
    LineSpacing->{1, 1},
    FontSize->11],
  
  Cell[StyleData["InlineFormula", "Printout"],
    CellMargins->{{2, 0}, {6, 6}},
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["DisplayFormula"],
    CellMargins->{{42, Inherited}, {Inherited, Inherited}},
    CellHorizontalScrolling->True,
    DefaultFormatType->DefaultInputFormatType,
    HyphenationOptions->{"HyphenationCharacter"->"\[Continuation]"},
    LanguageCategory->"Formula",
    ScriptLevel->0,
    SingleLetterItalics->True,
    UnderoverscriptBoxOptions->{LimitsPositioning->True}],
  
  Cell[StyleData["DisplayFormula", "Presentation"],
    LineSpacing->{1, 5},
    FontSize->16],
  
  Cell[StyleData["DisplayFormula", "Condensed"],
    LineSpacing->{1, 1},
    FontSize->11],
  
  Cell[StyleData["DisplayFormula", "Printout"],
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Program"],
    CellFrame->{{0, 0}, {0.5, 0.5}},
    CellMargins->{{10, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    LanguageCategory->"Formula",
    ScriptLevel->1,
    FontFamily->"Courier"],
  
  Cell[StyleData["Program", "Presentation"],
    CellMargins->{{24, 10}, {10, 10}},
    LineSpacing->{1, 5},
    FontSize->16],
  
  Cell[StyleData["Program", "Condensed"],
    CellMargins->{{8, 10}, {6, 6}},
    LineSpacing->{1, 1},
    FontSize->11],
  
  Cell[StyleData["Program", "Printout"],
    CellMargins->{{2, 0}, {6, 6}},
    FontSize->9]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Hyperlink Styles", "Section"],
  
  Cell["\<\
The cells below define styles useful for making hypertext \
ButtonBoxes.  The \"Hyperlink\" style is for links within the same Notebook, \
or between Notebooks.\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Hyperlink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontColor->RGBColor[0, 0, 1],
    FontVariations->{"Underline"->True},
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`NotebookLocate[ #2]}]&),
    Active->True,
    ButtonNote->ButtonData}],
  
  Cell[StyleData["Hyperlink", "Presentation"],
    FontSize->16],
  
  Cell[StyleData["Hyperlink", "Condensed"],
    FontSize->11],
  
  Cell[StyleData["Hyperlink", "Printout"],
    FontSize->10,
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Closed]],
  
  Cell["\<\
The following styles are for linking automatically to the on-line \
help system.\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["MainBookLink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontColor->RGBColor[0, 0, 1],
    FontVariations->{"Underline"->True},
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`HelpBrowserLookup[ "MainBook", #]}]&),
    Active->True,
    ButtonFrame->"None"}],
  
  Cell[StyleData["MainBookLink", "Presentation"],
    FontSize->16],
  
  Cell[StyleData["MainBookLink", "Condensed"],
    FontSize->11],
  
  Cell[StyleData["MainBookLink", "Printout"],
    FontSize->10,
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["AddOnsLink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontFamily->"Courier",
    FontColor->RGBColor[0, 0, 1],
    FontVariations->{"Underline"->True},
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`HelpBrowserLookup[ "AddOns", #]}]&),
    Active->True,
    ButtonFrame->"None"}],
  
  Cell[StyleData["AddOnsLink", "Presentation"],
    FontSize->16],
  
  Cell[StyleData["AddOnsLink", "Condensed"],
    FontSize->11],
  
  Cell[StyleData["AddOnsLink", "Printout"],
    FontSize->10,
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["RefGuideLink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontFamily->"Courier",
    FontColor->RGBColor[0, 0, 1],
    FontVariations->{"Underline"->True},
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`HelpBrowserLookup[ "RefGuide", #]}]&),
    Active->True,
    ButtonFrame->"None"}],
  
  Cell[StyleData["RefGuideLink", "Presentation"],
    FontSize->16],
  
  Cell[StyleData["RefGuideLink", "Condensed"],
    FontSize->11],
  
  Cell[StyleData["RefGuideLink", "Printout"],
    FontSize->10,
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["GettingStartedLink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontColor->RGBColor[0, 0, 1],
    FontVariations->{"Underline"->True},
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`HelpBrowserLookup[ "GettingStarted", #]}]&),
    Active->True,
    ButtonFrame->"None"}],
  
  Cell[StyleData["GettingStartedLink", "Presentation"],
    FontSize->16],
  
  Cell[StyleData["GettingStartedLink", "Condensed"],
    FontSize->11],
  
  Cell[StyleData["GettingStartedLink", "Printout"],
    FontSize->10,
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["OtherInformationLink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontColor->RGBColor[0, 0, 1],
    FontVariations->{"Underline"->True},
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`HelpBrowserLookup[ "OtherInformation", #]}]&),
    Active->True,
    ButtonFrame->"None"}],
  
  Cell[StyleData["OtherInformationLink", "Presentation"],
    FontSize->16],
  
  Cell[StyleData["OtherInformationLink", "Condensed"],
    FontSize->11],
  
  Cell[StyleData["OtherInformationLink", "Printout"],
    FontSize->10,
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Styles for Headers and Footers", "Section"],
  
  Cell[StyleData["Header"],
    CellMargins->{{0, 0}, {4, 1}},
    DefaultNewInlineCellStyle->"None",
    LanguageCategory->"NaturalLanguage",
    StyleMenuListing->None,
    FontSize->10,
    FontSlant->"Italic"],
  
  Cell[StyleData["Footer"],
    CellMargins->{{0, 0}, {0, 4}},
    DefaultNewInlineCellStyle->"None",
    LanguageCategory->"NaturalLanguage",
    StyleMenuListing->None,
    FontSize->9,
    FontSlant->"Italic"],
  
  Cell[StyleData["PageNumber"],
    CellMargins->{{0, 0}, {4, 1}},
    StyleMenuListing->None,
    FontFamily->"Times",
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Palette Styles", "Section"],
  
  Cell["\<\
The cells below define styles that define standard \
ButtonFunctions, for use in palette buttons.\
\>", "Text"],
  
  Cell[StyleData["Paste"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`NotebookApply[ 
          FrontEnd`InputNotebook[ ], #, After]}]&)}],
  
  Cell[StyleData["Evaluate"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`NotebookApply[ 
          FrontEnd`InputNotebook[ ], #, All], 
        SelectionEvaluate[ 
          FrontEnd`InputNotebook[ ], All]}]&)}],
  
  Cell[StyleData["EvaluateCell"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`NotebookApply[ 
          FrontEnd`InputNotebook[ ], #, All], 
        FrontEnd`SelectionMove[ 
          FrontEnd`InputNotebook[ ], All, Cell, 1], 
        FrontEnd`SelectionEvaluateCreateCell[ 
          FrontEnd`InputNotebook[ ], All]}]&)}],
  
  Cell[StyleData["CopyEvaluate"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`SelectionCreateCell[ 
          FrontEnd`InputNotebook[ ], All], 
        FrontEnd`NotebookApply[ 
          FrontEnd`InputNotebook[ ], #, All], 
        FrontEnd`SelectionEvaluate[ 
          FrontEnd`InputNotebook[ ], All]}]&)}],
  
  Cell[StyleData["CopyEvaluateCell"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`SelectionCreateCell[ 
          FrontEnd`InputNotebook[ ], All], 
        FrontEnd`NotebookApply[ 
          FrontEnd`InputNotebook[ ], #, All], 
        FrontEnd`SelectionEvaluateCreateCell[ 
          FrontEnd`InputNotebook[ ], All]}]&)}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Placeholder Styles", "Section"],
  
  Cell["\<\
The cells below define styles useful for making placeholder \
objects in palette templates.\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Placeholder"],
    Placeholder->True,
    StyleMenuListing->None,
    FontSlant->"Italic",
    FontColor->RGBColor[0.890623, 0.864698, 0.384756],
    TagBoxOptions->{Editable->False,
    Selectable->False,
    StripWrapperBoxes->False}],
  
  Cell[StyleData["Placeholder", "Presentation"]],
  
  Cell[StyleData["Placeholder", "Condensed"]],
  
  Cell[StyleData["Placeholder", "Printout"]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["PrimaryPlaceholder"],
    StyleMenuListing->None,
    DrawHighlighted->True,
    FontSlant->"Italic",
    Background->RGBColor[0.912505, 0.891798, 0.507774],
    TagBoxOptions->{Editable->False,
    Selectable->False,
    StripWrapperBoxes->False}],
  
  Cell[StyleData["PrimaryPlaceholder", "Presentation"]],
  
  Cell[StyleData["PrimaryPlaceholder", "Condensed"]],
  
  Cell[StyleData["PrimaryPlaceholder", "Printout"]]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["FormatType Styles", "Section"],
  
  Cell["\<\
The cells below define styles that are mixed in with the styles \
of most cells.  If a cell's FormatType matches the name of one of the styles \
defined below, then that style is applied between the cell's style and its \
own options. This is particularly true of Input and Output.\
\>", "Text"],
  
  Cell[StyleData["CellExpression"],
    PageWidth->Infinity,
    CellMargins->{{6, Inherited}, {Inherited, Inherited}},
    ShowCellLabel->False,
    ShowSpecialCharacters->False,
    AllowInlineCells->False,
    Hyphenation->False,
    AutoItalicWords->{},
    StyleMenuListing->None,
    FontFamily->"Courier",
    FontSize->12,
    Background->GrayLevel[1]],
  
  Cell[StyleData["InputForm"],
    InputAutoReplacements->{},
    AllowInlineCells->False,
    Hyphenation->False,
    StyleMenuListing->None,
    FontFamily->"Courier"],
  
  Cell[StyleData["OutputForm"],
    PageWidth->Infinity,
    TextAlignment->Left,
    LineSpacing->{0.6, 1},
    StyleMenuListing->None,
    FontFamily->"Courier"],
  
  Cell[StyleData["StandardForm"],
    InputAutoReplacements->{
      "->"->"\[Rule]", ":>"->"\[RuleDelayed]", "<="->"\[LessEqual]", 
        ">="->"\[GreaterEqual]", "!="->"\[NotEqual]", "=="->"\[Equal]", 
        Inherited},
    LineSpacing->{1.25, 0},
    StyleMenuListing->None,
    FontFamily->"Courier"],
  
  Cell[StyleData["TraditionalForm"],
    InputAutoReplacements->{
      "->"->"\[Rule]", ":>"->"\[RuleDelayed]", "<="->"\[LessEqual]", 
        ">="->"\[GreaterEqual]", "!="->"\[NotEqual]", "=="->"\[Equal]", 
        Inherited},
    LineSpacing->{1.25, 0},
    SingleLetterItalics->True,
    TraditionalFunctionNotation->True,
    DelimiterMatching->None,
    StyleMenuListing->None],
  
  Cell["\<\
The style defined below is mixed in to any cell that is in an \
inline cell within another.\
\>", "Text"],
  
  Cell[StyleData["InlineCell"],
    TextAlignment->Left,
    ScriptLevel->1,
    StyleMenuListing->None],
  
  Cell[StyleData["InlineCellEditing"],
    StyleMenuListing->None,
    Background->RGBColor[1, 0.749996, 0.8]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Automatic Styles", "Section"],
  
  Cell["\<\
The cells below define styles that are used to affect the display \
of certain types of objects in typeset expressions.  For example, \
\"UnmatchedBracket\" style defines how unmatched bracket, curly bracket, and \
parenthesis characters are displayed (typically by coloring them to make them \
stand out).\
\>", "Text"],
  
  Cell[StyleData["UnmatchedBracket"],
    StyleMenuListing->None,
    FontColor->RGBColor[0.760006, 0.330007, 0.8]]
  }, Closed]]
  }, Open  ]],
  
  Cell[CellGroupData[{
  
  Cell["Notation Package Styles", "Section",
    GeneratedCell->True,
    CellTags->"NotationPackage"],
  
  Cell["\<\
The cells below define certain styles needed by the Notation \
package. These styles serve to make visible otherwise invisible \
tagboxes.\
\>", "Text",
    GeneratedCell->True,
    CellTags->"NotationPackage"],
  
  Cell[StyleData["NotationTemplateStyle"],
    GeneratedCell->True,
    StyleMenuListing->None,
    Background->RGBColor[1, 1, 0.850004],
    TagBoxOptions->{SyntaxForm->"symbol"},
    CellTags->"NotationPackage"],
  
  Cell[StyleData["NotationPatternWrapperStyle"],
    GeneratedCell->True,
    StyleMenuListing->None,
    Background->RGBColor[1, 0.900008, 0.979995],
    TagBoxOptions->{SyntaxForm->"symbol"},
    CellTags->"NotationPackage"],
  
  Cell[StyleData["NotationMadeBoxesWrapperStyle"],
    GeneratedCell->True,
    StyleMenuListing->None,
    Background->RGBColor[0.900008, 0.889998, 1],
    TagBoxOptions->{SyntaxForm->"symbol"},
    CellTags->"NotationPackage"]
  }, Closed]]
  }],
MacintoshSystemPageSetup->"\<\
00`0001804P000000bX2@?oaooL3>@99:P85N0?N0@00004/0B`000003Bl9H001
0000I0000@400@0000000BL?0040000000000000000000000000000000000?o2
omX=K@V600P100000000000000000000\>"
]


(***********************************************************************
Cached data follows.  If you edit this Notebook file directly, not using
Mathematica, you must remove the line containing CacheID at the top of 
the file.  The cache data will then be recreated when you save this file 
from within Mathematica.
***********************************************************************)

(*CellTagsOutline
CellTagsIndex->{}
*)

(*CellTagsIndex
CellTagsIndex->{}
*)

(*NotebookFileOutline
Notebook[{
Cell[1717, 49, 483, 9, 123, "Input",
  InitializationCell->True],

Cell[CellGroupData[{
Cell[2225, 62, 31, 0, 50, "Section"],
Cell[2259, 64, 102, 2, 27, "Input",
  InitializationCell->True],

Cell[CellGroupData[{
Cell[2386, 70, 40, 0, 46, "Subsection"],

Cell[CellGroupData[{
Cell[2451, 74, 371, 7, 63, "Subsubsection"],
Cell[2825, 83, 370, 6, 85, "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{
Cell[3232, 94, 35, 0, 28, "Subsubsection"],
Cell[3270, 96, 408, 6, 107, "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{
Cell[3715, 107, 157, 3, 28, "Subsubsection"],
Cell[3875, 112, 167, 3, 27, "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{
Cell[4079, 120, 36, 0, 28, "Subsubsection"],
Cell[4118, 122, 188, 3, 43, "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{
Cell[4343, 130, 44, 0, 28, "Subsubsection"],
Cell[4390, 132, 377, 6, 79, "Input",
  InitializationCell->True]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[4816, 144, 70, 0, 30, "Subsection"],

Cell[CellGroupData[{
Cell[4911, 148, 32, 0, 42, "Subsubsection"],
Cell[4946, 150, 129, 3, 27, "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{
Cell[5112, 158, 197, 4, 44, "Subsubsection"],
Cell[5312, 164, 367, 6, 91, "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{
Cell[5716, 175, 949, 17, 103, "Subsubsection"],
Cell[6668, 194, 774, 11, 157, "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{
Cell[7479, 210, 389, 6, 58, "Subsubsection"],
Cell[7871, 218, 370, 6, 93, "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{
Cell[8278, 229, 458, 8, 76, "Subsubsection"],
Cell[8739, 239, 533, 9, 123, "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{
Cell[9309, 253, 186, 4, 44, "Subsubsection"],
Cell[9498, 259, 261, 5, 75, "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{
Cell[9796, 269, 465, 8, 73, "Subsubsection"],
Cell[10264, 279, 427, 7, 107, "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{
Cell[10728, 291, 260, 5, 43, "Subsubsection"],
Cell[10991, 298, 307, 5, 75, "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{
Cell[11335, 308, 399, 6, 58, "Subsubsection"],
Cell[11737, 316, 431, 7, 107, "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{
Cell[12205, 328, 250, 6, 60, "Subsubsection"],
Cell[12458, 336, 331, 6, 91, "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{
Cell[12826, 347, 1605, 29, 193, "Subsubsection"],
Cell[14434, 378, 1300, 19, 331, "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{
Cell[15771, 402, 788, 15, 103, "Subsubsection"],
Cell[16562, 419, 736, 11, 203, "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{
Cell[17335, 435, 332, 7, 60, "Subsubsection",
  InitializationCell->True],
Cell[17670, 444, 359, 6, 91, "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{
Cell[18066, 455, 345, 7, 44, "Subsubsection",
  InitializationCell->True],
Cell[18414, 464, 478, 9, 107, "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{
Cell[18929, 478, 108, 3, 28, "Subsubsection"],
Cell[19040, 483, 165, 3, 43, "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{
Cell[19242, 491, 982, 16, 106, "Subsubsection"],
Cell[20227, 509, 874, 13, 161, "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{
Cell[21138, 527, 979, 16, 105, "Subsubsection"],
Cell[22120, 545, 872, 14, 160, "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{
Cell[23029, 564, 216, 5, 44, "Subsubsection"],
Cell[23248, 571, 293, 6, 75, "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{
Cell[23578, 582, 281, 4, 44, "Subsubsection"],
Cell[23862, 588, 364, 6, 75, "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{
Cell[24263, 599, 559, 10, 61, "Subsubsection"],
Cell[24825, 611, 533, 8, 92, "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{
Cell[25395, 624, 172, 4, 28, "Subsubsection",
  InitializationCell->True],
Cell[25570, 630, 208, 4, 59, "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{
Cell[25815, 639, 254, 7, 44, "Subsubsection",
  InitializationCell->True],
Cell[26072, 648, 229, 4, 59, "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{
Cell[26338, 657, 302, 6, 47, "Subsubsection"],
Cell[26643, 665, 431, 7, 93, "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{
Cell[27111, 677, 259, 5, 43, "Subsubsection",
  InitializationCell->True],
Cell[27373, 684, 277, 5, 75, "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{
Cell[27687, 694, 144, 4, 28, "Subsubsection",
  InitializationCell->True],
Cell[27834, 700, 418, 6, 93, "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{
Cell[28289, 711, 1532, 26, 139, "Subsubsection"],
Cell[29824, 739, 1500, 22, 192, "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{
Cell[31361, 766, 401, 7, 45, "Subsubsection"],
Cell[31765, 775, 415, 6, 76, "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{
Cell[32217, 786, 286, 6, 29, "Subsubsection"],
Cell[32506, 794, 481, 7, 109, "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{
Cell[33024, 806, 194, 4, 44, "Subsubsection"],
Cell[33221, 812, 250, 4, 75, "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{
Cell[33508, 821, 279, 5, 59, "Subsubsection"],
Cell[33790, 828, 383, 6, 91, "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{
Cell[34210, 839, 118, 3, 28, "Subsubsection"],
Cell[34331, 844, 173, 3, 43, "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{
Cell[34541, 852, 1379, 23, 101, "Subsubsection"],
Cell[35923, 877, 1252, 17, 147, "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{
Cell[37212, 899, 247, 5, 30, "Subsubsection",
  InitializationCell->True],
Cell[37462, 906, 233, 4, 62, "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{
Cell[37732, 915, 282, 6, 45, "Subsubsection"],
Cell[38017, 923, 490, 7, 93, "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{
Cell[38544, 935, 1479, 30, 105, "Subsubsection"],
Cell[40026, 967, 1336, 21, 145, "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{
Cell[41399, 993, 47, 0, 28, "Subsubsection"],
Cell[41449, 995, 361, 6, 107, "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{
Cell[41847, 1006, 192, 3, 43, "Subsubsection"],
Cell[42042, 1011, 248, 4, 59, "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{
Cell[42327, 1020, 251, 5, 43, "Subsubsection"],
Cell[42581, 1027, 398, 7, 91, "Input",
  InitializationCell->True]
}, Closed]]
}, Open  ]],

Cell[CellGroupData[{
Cell[43028, 1040, 52, 0, 46, "Subsection"],

Cell[CellGroupData[{
Cell[43105, 1044, 451, 8, 82, "Subsubsection"],
Cell[43559, 1054, 448, 7, 117, "Input",
  InitializationCell->True]
}, Open  ]],

Cell[CellGroupData[{
Cell[44044, 1066, 127, 3, 42, "Subsubsection"],
Cell[44174, 1071, 194, 3, 59, "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{
Cell[44405, 1079, 2332, 52, 140, "Subsubsection"],
Cell[46740, 1133, 926, 13, 174, "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{
Cell[47703, 1151, 532, 9, 82, "Subsubsection"],
Cell[48238, 1162, 468, 7, 107, "Input",
  InitializationCell->True]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[48755, 1175, 51, 0, 30, "Subsection"],

Cell[CellGroupData[{
Cell[48831, 1179, 737, 13, 102, "Subsubsection"],
Cell[49571, 1194, 697, 11, 155, "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{
Cell[50305, 1210, 728, 13, 89, "Subsubsection"],
Cell[51036, 1225, 637, 10, 124, "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{
Cell[51710, 1240, 256, 6, 44, "Subsubsection",
  InitializationCell->True],
Cell[51969, 1248, 283, 5, 75, "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{
Cell[52289, 1258, 536, 7, 76, "Subsubsection"],
Cell[52828, 1267, 794, 12, 123, "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{
Cell[53659, 1284, 392, 7, 74, "Subsubsection"],
Cell[54054, 1293, 432, 7, 107, "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{
Cell[54523, 1305, 144, 3, 28, "Subsubsection"],
Cell[54670, 1310, 216, 4, 59, "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{
Cell[54923, 1319, 143, 4, 28, "Subsubsection"],
Cell[55069, 1325, 195, 4, 43, "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{
Cell[55301, 1334, 162, 4, 28, "Subsubsection"],
Cell[55466, 1340, 232, 4, 59, "Input",
  InitializationCell->True]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[55747, 1350, 33, 0, 30, "Subsection"],

Cell[CellGroupData[{
Cell[55805, 1354, 185, 4, 42, "Subsubsection"],
Cell[55993, 1360, 252, 4, 59, "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{
Cell[56282, 1369, 417, 7, 57, "Subsubsection"],
Cell[56702, 1378, 420, 8, 107, "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{
Cell[57159, 1391, 307, 6, 44, "Subsubsection",
  InitializationCell->True],
Cell[57469, 1399, 417, 7, 107, "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{
Cell[57923, 1411, 286, 4, 44, "Subsubsection"],
Cell[58212, 1417, 344, 5, 91, "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{
Cell[58593, 1427, 124, 3, 28, "Subsubsection"],
Cell[58720, 1432, 193, 3, 43, "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{
Cell[58950, 1440, 128, 3, 28, "Subsubsection"],
Cell[59081, 1445, 194, 4, 43, "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{
Cell[59312, 1454, 143, 3, 28, "Subsubsection"],
Cell[59458, 1459, 229, 4, 59, "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{
Cell[59724, 1468, 368, 7, 60, "Subsubsection",
  InitializationCell->True],
Cell[60095, 1477, 499, 8, 123, "Input",
  InitializationCell->True]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[60643, 1491, 38, 0, 30, "Subsection"],

Cell[CellGroupData[{
Cell[60706, 1495, 385, 6, 74, "Subsubsection"],
Cell[61094, 1503, 383, 6, 80, "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{
Cell[61514, 1514, 145, 3, 28, "Subsubsection"],
Cell[61662, 1519, 219, 4, 59, "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{
Cell[61918, 1528, 383, 8, 60, "Subsubsection"],
Cell[62304, 1538, 426, 7, 91, "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{
Cell[62767, 1550, 234, 5, 44, "Subsubsection"],
Cell[63004, 1557, 276, 5, 59, "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{
Cell[63317, 1567, 278, 5, 44, "Subsubsection"],
Cell[63598, 1574, 328, 5, 75, "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{
Cell[63963, 1584, 284, 5, 44, "Subsubsection"],
Cell[64250, 1591, 373, 6, 91, "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{
Cell[64660, 1602, 244, 4, 44, "Subsubsection",
  InitializationCell->True],
Cell[64907, 1608, 510, 8, 123, "Input",
  InitializationCell->True]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[65466, 1622, 108, 4, 31, "Subsection"],

Cell[CellGroupData[{
Cell[65599, 1630, 204, 4, 57, "Subsubsection",
  InitializationCell->True],
Cell[65806, 1636, 176, 4, 27, "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{
Cell[66019, 1645, 181, 4, 30, "Subsubsection",
  InitializationCell->True],
Cell[66203, 1651, 179, 3, 44, "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{
Cell[66419, 1659, 162, 3, 28, "Subsubsection",
  InitializationCell->True],
Cell[66584, 1664, 196, 4, 43, "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{
Cell[66817, 1673, 161, 3, 28, "Subsubsection",
  InitializationCell->True],
Cell[66981, 1678, 223, 4, 27, "Input",
  InitializationCell->True]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[67253, 1688, 37, 0, 30, "Subsection"],

Cell[CellGroupData[{
Cell[67315, 1692, 245, 5, 58, "Subsubsection"],
Cell[67563, 1699, 382, 6, 107, "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{
Cell[67982, 1710, 1163, 19, 105, "Subsubsection"],
Cell[69148, 1731, 959, 14, 158, "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{
Cell[70144, 1750, 381, 5, 60, "Subsubsection"],
Cell[70528, 1757, 443, 7, 107, "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{
Cell[71008, 1769, 241, 5, 44, "Subsubsection"],
Cell[71252, 1776, 281, 5, 59, "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{
Cell[71570, 1786, 142, 4, 44, "Subsubsection"],
Cell[71715, 1792, 287, 5, 75, "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{
Cell[72039, 1802, 971, 16, 105, "Subsubsection"],
Cell[73013, 1820, 848, 13, 157, "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{
Cell[73898, 1838, 132, 3, 28, "Subsubsection"],
Cell[74033, 1843, 188, 3, 43, "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{
Cell[74258, 1851, 148, 3, 28, "Subsubsection"],
Cell[74409, 1856, 228, 4, 59, "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{
Cell[74674, 1865, 320, 4, 44, "Subsubsection"],
Cell[74997, 1871, 364, 6, 76, "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{
Cell[75398, 1882, 331, 6, 58, "Subsubsection"],
Cell[75732, 1890, 344, 5, 60, "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{
Cell[76113, 1900, 352, 7, 44, "Subsubsection"],
Cell[76468, 1909, 330, 5, 76, "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{
Cell[76835, 1919, 134, 3, 28, "Subsubsection"],
Cell[76972, 1924, 190, 3, 43, "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{
Cell[77199, 1932, 261, 4, 44, "Subsubsection"],
Cell[77463, 1938, 288, 5, 60, "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{
Cell[77788, 1948, 163, 4, 44, "Subsubsection"],
Cell[77954, 1954, 344, 6, 91, "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{
Cell[78335, 1965, 143, 3, 28, "Subsubsection"],
Cell[78481, 1970, 216, 4, 59, "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{
Cell[78734, 1979, 420, 7, 45, "Subsubsection"],
Cell[79157, 1988, 455, 7, 76, "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{
Cell[79649, 2000, 320, 6, 44, "Subsubsection"],
Cell[79972, 2008, 312, 5, 60, "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{
Cell[80321, 2018, 1016, 18, 106, "Subsubsection"],
Cell[81340, 2038, 897, 13, 143, "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{
Cell[82274, 2056, 570, 9, 60, "Subsubsection"],
Cell[82847, 2067, 533, 8, 95, "Input",
  InitializationCell->True]
}, Closed]]
}, Closed]]
}, Open  ]],

Cell[CellGroupData[{
Cell[83441, 2082, 32, 0, 50, "Section"],
Cell[83476, 2084, 137, 3, 27, "Input",
  InitializationCell->True],
Cell[83616, 2089, 118, 3, 30, "Text"],
Cell[83737, 2094, 130, 3, 27, "Input",
  InitializationCell->True],

Cell[CellGroupData[{
Cell[83892, 2101, 40, 0, 46, "Subsection"],

Cell[CellGroupData[{
Cell[83957, 2105, 371, 7, 63, "Subsubsection"],
Cell[84331, 2114, 320, 7, 43, "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{
Cell[84688, 2126, 35, 0, 28, "Subsubsection"],
Cell[84726, 2128, 1013, 18, 210, "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{
Cell[85776, 2151, 167, 3, 28, "Subsubsection"],
Cell[85946, 2156, 173, 4, 27, "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{
Cell[86156, 2165, 36, 0, 28, "Subsubsection"],
Cell[86195, 2167, 287, 6, 59, "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{
Cell[86519, 2178, 44, 0, 42, "Subsubsection"],
Cell[86566, 2180, 570, 11, 107, "Input",
  InitializationCell->True]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[87185, 2197, 70, 0, 30, "Subsection"],

Cell[CellGroupData[{
Cell[87280, 2201, 197, 4, 58, "Subsubsection"],
Cell[87480, 2207, 112, 2, 27, "Input",
  InitializationCell->True],
Cell[87595, 2211, 581, 11, 107, "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{
Cell[88213, 2227, 458, 8, 76, "Subsubsection"],
Cell[88674, 2237, 811, 14, 132, "Input",
  InitializationCell->True],
Cell[89488, 2253, 818, 13, 169, "Input",
  InitializationCell->True],
Cell[90309, 2268, 330, 6, 75, "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{
Cell[90676, 2279, 186, 4, 44, "Subsubsection"],
Cell[90865, 2285, 460, 8, 91, "Input",
  InitializationCell->True],
Cell[91328, 2295, 633, 13, 123, "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{
Cell[91998, 2313, 465, 8, 73, "Subsubsection"],
Cell[92466, 2323, 285, 5, 75, "Input",
  InitializationCell->True],
Cell[92754, 2330, 244, 4, 59, "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{
Cell[93035, 2339, 1479, 25, 139, "Subsubsection"],
Cell[94517, 2366, 154, 4, 27, "Input",
  InitializationCell->True],
Cell[94674, 2372, 747, 13, 107, "Input",
  InitializationCell->True],
Cell[95424, 2387, 912, 17, 123, "Input",
  InitializationCell->True],
Cell[96339, 2406, 741, 14, 107, "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{
Cell[97117, 2425, 108, 3, 28, "Subsubsection"],
Cell[97228, 2430, 291, 6, 43, "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{
Cell[97556, 2441, 264, 4, 43, "Subsubsection"],
Cell[97823, 2447, 385, 6, 75, "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{
Cell[98245, 2458, 65, 0, 28, "Subsubsection"],

Cell[CellGroupData[{
Cell[98335, 2462, 151, 3, 43, "Input"],
Cell[98489, 2467, 35, 1, 26, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[98561, 2473, 197, 4, 40, "Input"],
Cell[98761, 2479, 35, 1, 26, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[98833, 2485, 230, 4, 47, "Input"],
Cell[99066, 2491, 1092, 20, 126, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[100195, 2516, 58, 1, 24, "Input"],
Cell[100256, 2519, 237, 5, 70, "Output"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[100542, 2530, 488, 10, 58, "Subsubsection"],
Cell[101033, 2542, 560, 10, 129, "Input",
  InitializationCell->True],
Cell[101596, 2554, 1183, 19, 232, "Input",
  InitializationCell->True],
Cell[102782, 2575, 102, 3, 30, "Text"]
}, Closed]],

Cell[CellGroupData[{
Cell[102921, 2583, 949, 17, 103, "Subsubsection"],
Cell[103873, 2602, 545, 11, 91, "Input",
  InitializationCell->True],
Cell[104421, 2615, 613, 12, 91, "Input",
  InitializationCell->True],
Cell[105037, 2629, 300, 5, 59, "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{
Cell[105374, 2639, 331, 6, 43, "Subsubsection"],
Cell[105708, 2647, 551, 11, 91, "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{
Cell[106296, 2663, 1081, 17, 106, "Subsubsection"],
Cell[107380, 2682, 150, 4, 27, "Input",
  InitializationCell->True],
Cell[107533, 2688, 773, 14, 155, "Input",
  InitializationCell->True],
Cell[108309, 2704, 624, 12, 123, "Input",
  InitializationCell->True],
Cell[108936, 2718, 563, 10, 139, "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{
Cell[109536, 2733, 979, 16, 105, "Subsubsection"],
Cell[110518, 2751, 165, 4, 27, "Input",
  InitializationCell->True],
Cell[110686, 2757, 802, 15, 155, "Input",
  InitializationCell->True],
Cell[111491, 2774, 657, 13, 139, "Input",
  InitializationCell->True],
Cell[112151, 2789, 601, 11, 139, "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{
Cell[112789, 2805, 62, 0, 28, "Subsubsection"],

Cell[CellGroupData[{
Cell[112876, 2809, 179, 3, 75, "Input"],
Cell[113058, 2814, 35, 1, 26, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[113130, 2820, 223, 4, 56, "Input"],
Cell[113356, 2826, 35, 1, 26, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[113428, 2832, 272, 5, 72, "Input"],
Cell[113703, 2839, 56, 1, 28, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[113796, 2845, 272, 5, 72, "Input"],
Cell[114071, 2852, 67, 1, 26, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[114175, 2858, 272, 5, 72, "Input"],
Cell[114450, 2865, 67, 1, 26, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[114554, 2871, 321, 6, 72, "Input"],
Cell[114878, 2879, 70, 1, 28, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[114985, 2885, 370, 7, 72, "Input"],
Cell[115358, 2894, 125, 2, 70, "Output"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[115532, 2902, 1605, 29, 193, "Subsubsection"],
Cell[117140, 2933, 333, 6, 91, "Input",
  InitializationCell->True],
Cell[117476, 2941, 1694, 27, 219, "Input",
  InitializationCell->True],
Cell[119173, 2970, 1447, 24, 283, "Input",
  InitializationCell->True],
Cell[120623, 2996, 1592, 27, 299, "Input",
  InitializationCell->True],
Cell[122218, 3025, 556, 10, 107, "Input",
  InitializationCell->True],
Cell[122777, 3037, 1125, 19, 235, "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{
Cell[123939, 3061, 78, 0, 28, "Subsubsection"],

Cell[CellGroupData[{
Cell[124042, 3065, 596, 10, 59, "Input"],
Cell[124641, 3077, 4331, 69, 120, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[129009, 3151, 596, 10, 56, "Input"],
Cell[129608, 3163, 47999, 769, 1645, "Output"]
}, Closed]],
Cell[177622, 3935, 605, 11, 56, "Input"],
Cell[178230, 3948, 79, 1, 27, "Input"],
Cell[178312, 3951, 856, 15, 123, "Input"],
Cell[179171, 3968, 5563, 84, 349, "Input"],
Cell[184737, 4054, 53565, 792, 1877, "Input"],

Cell[CellGroupData[{
Cell[238327, 4850, 185, 3, 59, "Input"],
Cell[238515, 4855, 56, 1, 27, "Output"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[238620, 4862, 788, 15, 103, "Subsubsection"],
Cell[239411, 4879, 443, 10, 91, "Input",
  InitializationCell->True],
Cell[239857, 4891, 393, 8, 75, "Input",
  InitializationCell->True],
Cell[240253, 4901, 872, 15, 203, "Input",
  InitializationCell->True],
Cell[241128, 4918, 1010, 17, 219, "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{
Cell[242175, 4940, 250, 6, 60, "Subsubsection"],
Cell[242428, 4948, 650, 11, 139, "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{
Cell[243115, 4964, 332, 7, 60, "Subsubsection",
  InitializationCell->True],
Cell[243450, 4973, 1547, 26, 219, "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{
Cell[245034, 5004, 345, 7, 44, "Subsubsection",
  InitializationCell->True],
Cell[245382, 5013, 626, 12, 123, "Input",
  InitializationCell->True],
Cell[246011, 5027, 270, 5, 59, "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{
Cell[246318, 5037, 216, 5, 44, "Subsubsection"],
Cell[246537, 5044, 205, 4, 27, "Input",
  InitializationCell->True],
Cell[246745, 5050, 378, 8, 59, "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{
Cell[247160, 5063, 281, 4, 44, "Subsubsection"],
Cell[247444, 5069, 377, 7, 75, "Input",
  InitializationCell->True],
Cell[247824, 5078, 286, 5, 43, "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{
Cell[248147, 5088, 559, 10, 61, "Subsubsection"],
Cell[248709, 5100, 425, 9, 59, "Input",
  InitializationCell->True],
Cell[249137, 5111, 436, 9, 75, "Input",
  InitializationCell->True],
Cell[249576, 5122, 437, 8, 75, "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{
Cell[250050, 5135, 172, 4, 28, "Subsubsection",
  InitializationCell->True],
Cell[250225, 5141, 216, 5, 43, "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{
Cell[250478, 5151, 319, 10, 44, "Subsubsection",
  InitializationCell->True],
Cell[250800, 5163, 266, 7, 59, "Input",
  InitializationCell->True],
Cell[251069, 5172, 230, 5, 27, "Input",
  InitializationCell->True],
Cell[251302, 5179, 321, 6, 75, "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{
Cell[251660, 5190, 314, 6, 43, "Subsubsection",
  InitializationCell->True],
Cell[251977, 5198, 231, 5, 43, "Input",
  InitializationCell->True],
Cell[252211, 5205, 142, 3, 30, "Text"],
Cell[252356, 5210, 662, 13, 123, "Input"],

Cell[CellGroupData[{
Cell[253043, 5227, 77, 1, 27, "Input"],
Cell[253123, 5230, 55, 1, 26, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[253215, 5236, 55, 1, 27, "Input"],
Cell[253273, 5239, 68, 1, 26, "Output"]
}, Closed]],
Cell[253356, 5243, 463, 9, 43, "Text"],
Cell[253822, 5254, 365, 7, 75, "Input",
  InitializationCell->True],

Cell[CellGroupData[{
Cell[254212, 5265, 81, 1, 27, "Input"],
Cell[254296, 5268, 69, 1, 26, "Output"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[254414, 5275, 302, 6, 47, "Subsubsection"],
Cell[254719, 5283, 306, 6, 59, "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{
Cell[255062, 5294, 144, 4, 28, "Subsubsection",
  InitializationCell->True],
Cell[255209, 5300, 148, 3, 27, "Input",
  InitializationCell->True],
Cell[255360, 5305, 185, 4, 43, "Input",
  InitializationCell->True],
Cell[255548, 5311, 185, 4, 47, "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{
Cell[255770, 5320, 286, 6, 29, "Subsubsection"],
Cell[256059, 5328, 481, 7, 109, "Input",
  InitializationCell->True],
Cell[256543, 5337, 110, 2, 27, "Input",
  InitializationCell->True],
Cell[256656, 5341, 660, 12, 123, "Input",
  InitializationCell->True],
Cell[257319, 5355, 501, 10, 75, "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{
Cell[257857, 5370, 194, 4, 44, "Subsubsection"],
Cell[258054, 5376, 250, 4, 75, "Input",
  InitializationCell->True],
Cell[258307, 5382, 284, 6, 72, "Input",
  InitializationCell->True],
Cell[258594, 5390, 1415, 22, 191, "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{
Cell[260046, 5417, 279, 5, 59, "Subsubsection"],
Cell[260328, 5424, 383, 6, 91, "Input",
  InitializationCell->True],
Cell[260714, 5432, 281, 6, 59, "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{
Cell[261032, 5443, 118, 3, 28, "Subsubsection"],
Cell[261153, 5448, 173, 3, 43, "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{
Cell[261363, 5456, 1379, 23, 101, "Subsubsection"],
Cell[262745, 5481, 803, 16, 139, "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{
Cell[263585, 5502, 247, 5, 30, "Subsubsection",
  InitializationCell->True],
Cell[263835, 5509, 837, 16, 155, "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{
Cell[264709, 5530, 401, 7, 45, "Subsubsection"],
Cell[265113, 5539, 154, 3, 27, "Input",
  InitializationCell->True],
Cell[265270, 5544, 963, 16, 186, "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{
Cell[266270, 5565, 282, 6, 45, "Subsubsection"],
Cell[266555, 5573, 318, 6, 78, "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{
Cell[266910, 5584, 1210, 25, 67, "Subsubsection"],
Cell[268123, 5611, 153, 4, 27, "Input",
  InitializationCell->True],
Cell[268279, 5617, 2252, 36, 450, "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{
Cell[270568, 5658, 192, 3, 43, "Subsubsection"],
Cell[270763, 5663, 199, 4, 43, "Input",
  InitializationCell->True]
}, Open  ]],

Cell[CellGroupData[{
Cell[270999, 5672, 251, 5, 57, "Subsubsection"],
Cell[271253, 5679, 434, 8, 91, "Input",
  InitializationCell->True]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[271736, 5693, 29, 0, 46, "Subsection"],

Cell[CellGroupData[{
Cell[271790, 5697, 360, 10, 74, "Subsubsection"],

Cell[CellGroupData[{
Cell[272175, 5711, 191, 4, 59, "Input"],
Cell[272369, 5717, 71, 1, 27, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[272477, 5723, 236, 4, 56, "Input"],
Cell[272716, 5729, 70, 1, 27, "Output"]
}, Closed]],
Cell[272801, 5733, 72, 0, 27, "Text"],

Cell[CellGroupData[{
Cell[272898, 5737, 225, 4, 75, "Input"],
Cell[273126, 5743, 70, 1, 27, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[273233, 5749, 221, 4, 72, "Input"],
Cell[273457, 5755, 70, 1, 27, "Output"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[273576, 5762, 79, 0, 28, "Subsubsection"],
Cell[273658, 5764, 91, 3, 30, "Text"],

Cell[CellGroupData[{
Cell[273774, 5771, 253, 4, 75, "Input"],
Cell[274030, 5777, 65, 1, 27, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[274132, 5783, 103, 2, 24, "Input"],
Cell[274238, 5787, 40, 1, 27, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[274315, 5793, 152, 3, 40, "Input"],
Cell[274470, 5798, 88, 1, 27, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[274595, 5804, 152, 3, 40, "Input"],
Cell[274750, 5809, 91, 1, 27, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[274878, 5815, 213, 4, 56, "Input"],
Cell[275094, 5821, 747, 10, 147, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[275878, 5836, 189, 4, 40, "Input"],
Cell[276070, 5842, 730, 10, 147, "Output"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[276849, 5858, 66, 0, 42, "Subsubsection"],
Cell[276918, 5860, 102, 2, 27, "Input"],
Cell[277023, 5864, 188, 3, 59, "Input"],
Cell[277214, 5869, 138, 2, 59, "Input"],
Cell[277355, 5873, 196, 4, 59, "Input"],
Cell[277554, 5879, 202, 5, 43, "Input"],
Cell[277759, 5886, 204, 4, 42, "Input"],

Cell[CellGroupData[{
Cell[277988, 5894, 154, 3, 43, "Input"],
Cell[278145, 5899, 70, 1, 27, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[278252, 5905, 138, 3, 40, "Input"],
Cell[278393, 5910, 53, 1, 27, "Output"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[278495, 5917, 174, 4, 44, "Subsubsection"],

Cell[CellGroupData[{
Cell[278694, 5925, 193, 3, 59, "Input"],
Cell[278890, 5930, 88, 1, 27, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[279015, 5936, 92, 1, 24, "Input"],
Cell[279110, 5939, 91, 1, 27, "Output"]
}, Closed]],
Cell[279216, 5943, 133, 3, 43, "Text"],

Cell[CellGroupData[{
Cell[279374, 5950, 188, 3, 59, "Input"],
Cell[279565, 5955, 57, 1, 27, "Output"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[279671, 5962, 62, 0, 28, "Subsubsection"],

Cell[CellGroupData[{
Cell[279758, 5966, 142, 3, 27, "Input"],
Cell[279903, 5971, 91, 1, 27, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[280031, 5977, 142, 3, 40, "Input"],
Cell[280176, 5982, 92, 1, 27, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[280305, 5988, 305, 4, 56, "Input"],
Cell[280613, 5994, 420, 10, 43, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[281070, 6009, 317, 6, 61, "Input"],
Cell[281390, 6017, 92, 1, 27, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[281519, 6023, 60, 1, 24, "Input"],
Cell[281582, 6026, 55, 1, 27, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[281674, 6032, 977, 15, 196, "Input"],
Cell[282654, 6049, 888, 14, 116, "Output"]
}, Closed]],
Cell[283557, 6066, 901, 14, 155, "Input"],
Cell[284461, 6082, 901, 14, 155, "Input"],

Cell[CellGroupData[{
Cell[285387, 6100, 62, 1, 27, "Input"],
Cell[285452, 6103, 70, 1, 27, "Output"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[285571, 6110, 46, 0, 42, "Subsubsection"],
Cell[285620, 6112, 153, 3, 43, "Input"],
Cell[285776, 6117, 199, 4, 43, "Input"],

Cell[CellGroupData[{
Cell[286000, 6125, 180, 3, 59, "Input"],
Cell[286183, 6130, 88, 1, 27, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[286308, 6136, 46, 1, 24, "Input"],
Cell[286357, 6139, 41, 1, 27, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[286435, 6145, 180, 3, 56, "Input"],
Cell[286618, 6150, 88, 1, 27, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[286743, 6156, 180, 3, 56, "Input"],
Cell[286926, 6161, 90, 1, 27, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[287053, 6167, 46, 1, 24, "Input"],
Cell[287102, 6170, 41, 1, 27, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[287180, 6176, 49, 1, 24, "Input"],
Cell[287232, 6179, 42, 1, 27, "Output"]
}, Closed]],
Cell[287289, 6183, 362, 6, 88, "Input"],

Cell[CellGroupData[{
Cell[287676, 6193, 170, 3, 59, "Input"],
Cell[287849, 6198, 56, 1, 27, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[287942, 6204, 169, 3, 40, "Input"],
Cell[288114, 6209, 56, 1, 27, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[288207, 6215, 249, 5, 56, "Input"],
Cell[288459, 6222, 46, 1, 27, "Output"]
}, Closed]],
Cell[288520, 6226, 103, 2, 24, "Input"],
Cell[288626, 6230, 122, 3, 43, "Input"],
Cell[288751, 6235, 268, 5, 75, "Input"],
Cell[289022, 6242, 145, 3, 43, "Input"]
}, Closed]],

Cell[CellGroupData[{
Cell[289204, 6250, 43, 0, 28, "Subsubsection"],
Cell[289250, 6252, 336, 7, 63, "Text"],

Cell[CellGroupData[{
Cell[289611, 6263, 130, 3, 43, "Input"],
Cell[289744, 6268, 930, 15, 182, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[290711, 6288, 90, 1, 24, "Input"],
Cell[290804, 6291, 127, 2, 29, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[290968, 6298, 67, 1, 24, "Input"],
Cell[291038, 6301, 354, 5, 78, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[291429, 6311, 189, 4, 48, "Input"],
Cell[291621, 6317, 173, 3, 46, "Output"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[291843, 6326, 50, 0, 28, "Subsubsection"],
Cell[291896, 6328, 545, 9, 94, "Text"],

Cell[CellGroupData[{
Cell[292466, 6341, 236, 4, 59, "Input"],
Cell[292705, 6347, 70, 1, 27, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[292812, 6353, 213, 4, 56, "Input"],
Cell[293028, 6359, 71, 1, 27, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[293136, 6365, 109, 2, 24, "Input"],
Cell[293248, 6369, 70, 1, 27, "Output"]
}, Closed]],
Cell[293333, 6373, 424, 9, 120, "Input"],
Cell[293760, 6384, 150, 2, 43, "Input"]
}, Closed]],

Cell[CellGroupData[{
Cell[293947, 6391, 108, 3, 28, "Subsubsection"],
Cell[294058, 6396, 2806, 46, 603, "Input"],
Cell[296867, 6444, 605, 10, 155, "Input"],

Cell[CellGroupData[{
Cell[297497, 6458, 244, 4, 59, "Input"],
Cell[297744, 6464, 71, 1, 27, "Output"]
}, Closed]],
Cell[297830, 6468, 585, 10, 152, "Input"],

Cell[CellGroupData[{
Cell[298440, 6482, 49, 1, 27, "Input"],
Cell[298492, 6485, 53, 1, 27, "Output"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[298594, 6492, 59, 0, 28, "Subsubsection"],

Cell[CellGroupData[{
Cell[298678, 6496, 76, 1, 27, "Input"],
Cell[298757, 6499, 71, 1, 27, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[298865, 6505, 93, 1, 24, "Input"],
Cell[298961, 6508, 72, 1, 27, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[299070, 6514, 79, 1, 24, "Input"],
Cell[299152, 6517, 72, 1, 27, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[299261, 6523, 197, 5, 40, "Input"],
Cell[299461, 6530, 71, 1, 27, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[299569, 6536, 49, 1, 24, "Input"],
Cell[299621, 6539, 8886, 132, 575, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[308544, 6676, 83, 1, 24, "Input"],
Cell[308630, 6679, 71, 1, 27, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[308738, 6685, 200, 4, 56, "Input"],
Cell[308941, 6691, 71, 1, 27, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[309049, 6697, 54, 1, 24, "Input"],
Cell[309106, 6700, 56, 1, 27, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[309199, 6706, 85, 1, 24, "Input"],
Cell[309287, 6709, 1793, 28, 226, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[311117, 6742, 141, 2, 40, "Input"],
Cell[311261, 6746, 1585, 24, 177, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[312883, 6775, 87, 1, 24, "Input"],
Cell[312973, 6778, 71, 1, 27, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[313081, 6784, 154, 2, 40, "Input"],
Cell[313238, 6788, 1268, 19, 132, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[314543, 6812, 61, 1, 24, "Input"],
Cell[314607, 6815, 2062, 37, 217, "Print"]
}, Closed]],
Cell[316684, 6855, 107, 2, 27, "Input"],

Cell[CellGroupData[{
Cell[316816, 6861, 138, 3, 43, "Input"],
Cell[316957, 6866, 71, 1, 27, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[317065, 6872, 177, 3, 56, "Input"],
Cell[317245, 6877, 53, 1, 27, "Output"]
}, Closed]],
Cell[317313, 6881, 100, 2, 24, "Input"],

Cell[CellGroupData[{
Cell[317438, 6887, 154, 3, 59, "Input"],
Cell[317595, 6892, 70, 1, 27, "Output"]
}, Closed]],
Cell[317680, 6896, 35, 1, 24, "Input"],

Cell[CellGroupData[{
Cell[317740, 6901, 101, 2, 27, "Input"],
Cell[317844, 6905, 71, 1, 27, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[317952, 6911, 101, 2, 24, "Input"],
Cell[318056, 6915, 55, 1, 27, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[318148, 6921, 101, 2, 24, "Input"],
Cell[318252, 6925, 71, 1, 27, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[318360, 6931, 248, 4, 72, "Input"],
Cell[318611, 6937, 57, 1, 27, "Output"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[318717, 6944, 53, 0, 28, "Subsubsection"],
Cell[318773, 6946, 156, 3, 59, "Input"],

Cell[CellGroupData[{
Cell[318954, 6953, 197, 5, 43, "Input"],
Cell[319154, 6960, 70, 1, 27, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[319261, 6966, 197, 5, 40, "Input"],
Cell[319461, 6973, 71, 1, 27, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[319569, 6979, 85, 1, 24, "Input"],
Cell[319657, 6982, 15035, 421, 153, "Output"]
}, Closed]],
Cell[334707, 7406, 161, 3, 40, "Input"],
Cell[334871, 7411, 102, 2, 27, "Input"],
Cell[334976, 7415, 92, 1, 27, "Input"],

Cell[CellGroupData[{
Cell[335093, 7420, 86, 1, 27, "Input"],
Cell[335182, 7423, 15035, 421, 153, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[350254, 7849, 72, 1, 24, "Input"],
Cell[350329, 7852, 62, 1, 27, "Output"]
}, Closed]]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[350452, 7860, 44, 0, 30, "Subsection"],

Cell[CellGroupData[{
Cell[350521, 7864, 62, 0, 42, "Subsubsection"],

Cell[CellGroupData[{
Cell[350608, 7868, 200, 4, 59, "Input"],
Cell[350811, 7874, 572, 12, 89, "Output"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[351432, 7892, 309, 6, 60, "Subsubsection"],
Cell[351744, 7900, 116, 2, 27, "Input"],

Cell[CellGroupData[{
Cell[351885, 7906, 90, 1, 27, "Input"],
Cell[351978, 7909, 70, 1, 27, "Output"]
}, Closed]],
Cell[352063, 7913, 242, 4, 56, "Input"],

Cell[CellGroupData[{
Cell[352330, 7921, 233, 4, 43, "Input"],
Cell[352566, 7927, 121, 2, 27, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[352724, 7934, 102, 2, 24, "Input"],
Cell[352829, 7938, 69, 1, 27, "Output"]
}, Closed]],
Cell[352913, 7942, 167, 3, 40, "Input"],

Cell[CellGroupData[{
Cell[353105, 7949, 140, 3, 59, "Input"],
Cell[353248, 7954, 71, 1, 27, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[353356, 7960, 69, 1, 24, "Input"],
Cell[353428, 7963, 660, 11, 142, "Print"]
}, Closed]]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[354149, 7981, 52, 0, 30, "Subsection"],

Cell[CellGroupData[{
Cell[354226, 7985, 451, 8, 65, "Subsubsection"],
Cell[354680, 7995, 2444, 50, 191, "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{
Cell[357161, 8050, 127, 3, 28, "Subsubsection"],
Cell[357291, 8055, 282, 7, 68, "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{
Cell[357610, 8067, 1026, 18, 101, "Subsubsection"],
Cell[358639, 8087, 8015, 155, 711, "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{
Cell[366691, 8247, 532, 9, 64, "Subsubsection"],
Cell[367226, 8258, 475, 9, 114, "Input",
  InitializationCell->True],
Cell[367704, 8269, 1737, 29, 219, "Input",
  InitializationCell->True],
Cell[369444, 8300, 751, 13, 75, "Input",
  InitializationCell->True]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[370244, 8319, 51, 0, 30, "Subsection"],

Cell[CellGroupData[{
Cell[370320, 8323, 737, 13, 87, "Subsubsection"],
Cell[371060, 8338, 619, 11, 98, "Input",
  InitializationCell->True],
Cell[371682, 8351, 725, 13, 162, "Input",
  InitializationCell->True],
Cell[372410, 8366, 792, 14, 130, "Input",
  InitializationCell->True],
Cell[373205, 8382, 796, 15, 178, "Input",
  InitializationCell->True],
Cell[374004, 8399, 841, 16, 178, "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{
Cell[374882, 8420, 722, 13, 89, "Subsubsection"],
Cell[375607, 8435, 164, 3, 27, "Input",
  InitializationCell->True],
Cell[375774, 8440, 259, 5, 59, "Input",
  InitializationCell->True],
Cell[376036, 8447, 1694, 33, 283, "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{
Cell[377767, 8485, 440, 12, 74, "Subsubsection"],
Cell[378210, 8499, 76, 1, 27, "Input"],

Cell[CellGroupData[{
Cell[378311, 8504, 192, 4, 43, "Input"],
Cell[378506, 8510, 91, 1, 26, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[378634, 8516, 171, 4, 40, "Input"],
Cell[378808, 8522, 70, 1, 26, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[378915, 8528, 110, 2, 24, "Input"],
Cell[379028, 8532, 59, 1, 26, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[379124, 8538, 58, 1, 24, "Input"],
Cell[379185, 8541, 1679, 26, 536, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[380901, 8572, 171, 4, 40, "Input"],
Cell[381075, 8578, 71, 1, 27, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[381183, 8584, 144, 3, 56, "Input"],
Cell[381330, 8589, 70, 1, 27, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[381437, 8595, 181, 3, 56, "Input"],
Cell[381621, 8600, 70, 1, 27, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[381728, 8606, 181, 3, 56, "Input"],
Cell[381912, 8611, 71, 1, 27, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[382020, 8617, 44, 1, 24, "Input"],
Cell[382067, 8620, 23314, 406, 3715, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[405418, 9031, 350, 7, 104, "Input"],
Cell[405771, 9040, 70, 1, 27, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[405878, 9046, 59, 1, 24, "Input"],
Cell[405940, 9049, 24387, 414, 4216, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[430364, 9468, 187, 4, 40, "Input"],
Cell[430554, 9474, 59, 1, 27, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[430650, 9480, 55, 1, 24, "Input"],
Cell[430708, 9483, 41, 1, 27, "Output"]
}, Closed]],
Cell[430764, 9487, 397, 7, 120, "Input"],

Cell[CellGroupData[{
Cell[431186, 9498, 93, 1, 27, "Input"],
Cell[431282, 9501, 70, 1, 27, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[431389, 9507, 117, 2, 40, "Input"],
Cell[431509, 9511, 140, 3, 21, "Message"],
Cell[431652, 9516, 171, 3, 35, "Message"],
Cell[431826, 9521, 42, 1, 27, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[431905, 9527, 48, 1, 24, "Input"],
Cell[431956, 9530, 73, 1, 27, "Output"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[432078, 9537, 256, 6, 44, "Subsubsection",
  InitializationCell->True],
Cell[432337, 9545, 1446, 25, 198, "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{
Cell[433820, 9575, 536, 7, 76, "Subsubsection"],
Cell[434359, 9584, 136, 3, 27, "Input",
  InitializationCell->True],
Cell[434498, 9589, 4131, 71, 736, "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{
Cell[438666, 9665, 385, 7, 60, "Subsubsection"],
Cell[439054, 9674, 3736, 66, 695, "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{
Cell[442827, 9745, 144, 3, 28, "Subsubsection"],
Cell[442974, 9750, 94, 2, 27, "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{
Cell[443105, 9757, 143, 4, 28, "Subsubsection"],
Cell[443251, 9763, 948, 15, 155, "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{
Cell[444236, 9783, 162, 4, 28, "Subsubsection"],
Cell[444401, 9789, 654, 13, 107, "Input",
  InitializationCell->True]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[445104, 9808, 33, 0, 30, "Subsection"],

Cell[CellGroupData[{
Cell[445162, 9812, 185, 4, 42, "Subsubsection"],
Cell[445350, 9818, 225, 4, 43, "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{
Cell[445612, 9827, 417, 7, 57, "Subsubsection"],
Cell[446032, 9836, 337, 6, 59, "Input",
  InitializationCell->True],
Cell[446372, 9844, 394, 7, 75, "Input",
  InitializationCell->True],

Cell[CellGroupData[{
Cell[446791, 9855, 85, 1, 27, "Input"],
Cell[446879, 9858, 166356, 2698, 17195, "Output"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[613284, 12562, 307, 6, 44, "Subsubsection",
  InitializationCell->True],
Cell[613594, 12570, 579, 10, 94, "Text"],
Cell[614176, 12582, 222, 4, 43, "Input",
  InitializationCell->True],
Cell[614401, 12588, 691, 13, 123, "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{
Cell[615129, 12606, 283, 5, 58, "Subsubsection"],
Cell[615415, 12613, 1586, 28, 231, "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{
Cell[617038, 12646, 124, 3, 42, "Subsubsection"],
Cell[617165, 12651, 1286, 26, 219, "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{
Cell[618488, 12682, 128, 3, 28, "Subsubsection"],
Cell[618619, 12687, 160, 3, 43, "Input",
  InitializationCell->True],
Cell[618782, 12692, 1170, 19, 123, "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{
Cell[619989, 12716, 153, 3, 28, "Subsubsection"],
Cell[620145, 12721, 302, 6, 59, "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{
Cell[620484, 12732, 60, 0, 28, "Subsubsection"],

Cell[CellGroupData[{
Cell[620569, 12736, 103, 2, 27, "Input"],
Cell[620675, 12740, 87, 1, 26, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[620799, 12746, 630, 11, 136, "Input"],
Cell[621432, 12759, 1835, 38, 70, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[623304, 12802, 103, 2, 24, "Input"],
Cell[623410, 12806, 87, 1, 70, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[623534, 12812, 632, 11, 136, "Input"],
Cell[624169, 12825, 1841, 39, 270, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[626047, 12869, 103, 2, 27, "Input"],
Cell[626153, 12873, 84, 1, 70, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[626274, 12879, 628, 11, 136, "Input"],
Cell[626905, 12892, 1860, 39, 70, "Output"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[628814, 12937, 368, 7, 60, "Subsubsection",
  InitializationCell->True],
Cell[629185, 12946, 300, 6, 75, "Input",
  InitializationCell->True],
Cell[629488, 12954, 861, 16, 155, "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{
Cell[630386, 12975, 55, 0, 28, "Subsubsection"],

Cell[CellGroupData[{
Cell[630466, 12979, 165, 3, 59, "Input"],
Cell[630634, 12984, 277, 4, 41, "Output"]
}, Closed]],
Cell[630926, 12991, 102, 2, 24, "Input"],

Cell[CellGroupData[{
Cell[631053, 12997, 1077, 18, 235, "Input"],
Cell[632133, 13017, 3481, 63, 520, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[635651, 13085, 1011, 18, 168, "Input"],
Cell[636665, 13105, 2848, 54, 70, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[639550, 13164, 308, 6, 72, "Input"],
Cell[639861, 13172, 10240, 283, 70, "Output"]
}, Closed]]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[650162, 13462, 38, 0, 30, "Subsection"],

Cell[CellGroupData[{
Cell[650225, 13466, 383, 6, 59, "Subsubsection"],
Cell[650611, 13474, 357, 7, 43, "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{
Cell[651005, 13486, 142, 3, 28, "Subsubsection"],
Cell[651150, 13491, 233, 4, 59, "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{
Cell[651420, 13500, 383, 8, 60, "Subsubsection"],
Cell[651806, 13510, 791, 15, 139, "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{
Cell[652634, 13530, 234, 5, 58, "Subsubsection"],
Cell[652871, 13537, 642, 11, 91, "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{
Cell[653550, 13553, 278, 5, 58, "Subsubsection"],
Cell[653831, 13560, 179, 3, 27, "Input",
  InitializationCell->True],
Cell[654013, 13565, 866, 15, 123, "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{
Cell[654916, 13585, 284, 5, 58, "Subsubsection"],
Cell[655203, 13592, 279, 6, 59, "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{
Cell[655519, 13603, 263, 6, 44, "Subsubsection",
  InitializationCell->True],
Cell[655785, 13611, 524, 10, 123, "Input",
  InitializationCell->True],
Cell[656312, 13623, 276, 5, 59, "Input",
  InitializationCell->True]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[656637, 13634, 108, 4, 31, "Subsection"],

Cell[CellGroupData[{
Cell[656770, 13642, 204, 4, 56, "Subsubsection",
  InitializationCell->True],
Cell[656977, 13648, 142, 3, 42, "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{
Cell[657156, 13656, 181, 4, 44, "Subsubsection",
  InitializationCell->True],
Cell[657340, 13662, 199, 4, 44, "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{
Cell[657576, 13671, 162, 3, 28, "Subsubsection",
  InitializationCell->True],
Cell[657741, 13676, 321, 6, 56, "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{
Cell[658099, 13687, 161, 3, 28, "Subsubsection",
  InitializationCell->True],
Cell[658263, 13692, 663, 13, 147, "Input",
  InitializationCell->True]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[658975, 13711, 37, 0, 30, "Subsection"],

Cell[CellGroupData[{
Cell[659037, 13715, 245, 5, 58, "Subsubsection"],
Cell[659285, 13722, 300, 7, 59, "Input",
  InitializationCell->True],
Cell[659588, 13731, 156, 3, 27, "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{
Cell[659781, 13739, 378, 6, 60, "Subsubsection"],
Cell[660162, 13747, 115, 2, 27, "Input",
  InitializationCell->True],
Cell[660280, 13751, 263, 5, 59, "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{
Cell[660580, 13761, 1163, 19, 105, "Subsubsection"],
Cell[661746, 13782, 108, 2, 27, "Input",
  InitializationCell->True],
Cell[661857, 13786, 880, 14, 215, "Input",
  InitializationCell->True],
Cell[662740, 13802, 254, 5, 43, "Input",
  InitializationCell->True],
Cell[662997, 13809, 1031, 19, 155, "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{
Cell[664065, 13833, 32, 0, 42, "Subsubsection"],

Cell[CellGroupData[{
Cell[664122, 13837, 141, 3, 43, "Input"],
Cell[664266, 13842, 1268, 34, 56, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[665571, 13881, 126, 3, 40, "Input"],
Cell[665700, 13886, 400, 9, 22, "Print"],
Cell[666103, 13897, 401, 9, 22, "Print"],
Cell[666507, 13908, 400, 9, 22, "Print"],
Cell[666910, 13919, 402, 9, 22, "Print"],
Cell[667315, 13930, 399, 9, 22, "Print"],
Cell[667717, 13941, 386, 9, 22, "Print"],
Cell[668106, 13952, 1037, 17, 117, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[669180, 13974, 97, 2, 24, "Input"],
Cell[669280, 13978, 338, 5, 42, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[669655, 13988, 131, 3, 40, "Input"],
Cell[669789, 13993, 376, 8, 22, "Print"],
Cell[670168, 14003, 384, 9, 22, "Print"],
Cell[670555, 14014, 400, 9, 22, "Print"],
Cell[670958, 14025, 385, 9, 22, "Print"],
Cell[671346, 14036, 400, 9, 22, "Print"],
Cell[671749, 14047, 402, 9, 22, "Print"],
Cell[672154, 14058, 1396, 30, 87, "Output"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[673599, 14094, 66, 0, 28, "Subsubsection"],
Cell[673668, 14096, 385, 7, 62, "Text"],
Cell[674056, 14105, 754, 20, 27, "Input"],

Cell[CellGroupData[{
Cell[674835, 14129, 388, 10, 27, "Input"],
Cell[675226, 14141, 100, 2, 27, "Output"]
}, Closed]],
Cell[675341, 14146, 392, 6, 59, "Text"],
Cell[675736, 14154, 90, 1, 27, "Input"],
Cell[675829, 14157, 854, 21, 75, "Input"],
Cell[676686, 14180, 219, 3, 91, "Input"],
Cell[676908, 14185, 217, 4, 43, "Input"],
Cell[677128, 14191, 164, 3, 59, "Input"],
Cell[677295, 14196, 125, 3, 43, "Input"],
Cell[677423, 14201, 122, 3, 27, "Input"],
Cell[677548, 14206, 98, 2, 43, "Input"],
Cell[677649, 14210, 59, 1, 27, "Input"],
Cell[677711, 14213, 99, 2, 27, "Input"],

Cell[CellGroupData[{
Cell[677835, 14219, 59, 1, 27, "Input"],
Cell[677897, 14222, 93, 1, 27, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[678027, 14228, 48, 1, 24, "Input"],
Cell[678078, 14231, 72, 1, 27, "Output"]
}, Closed]],
Cell[678165, 14235, 896, 18, 152, "Input"],
Cell[679064, 14255, 227, 3, 59, "Input"]
}, Closed]],

Cell[CellGroupData[{
Cell[679328, 14263, 66, 0, 28, "Subsubsection"],
Cell[679397, 14265, 77, 1, 27, "Input"],
Cell[679477, 14268, 112, 2, 43, "Input"],

Cell[CellGroupData[{
Cell[679614, 14274, 64, 1, 27, "Input"],
Cell[679681, 14277, 487, 7, 42, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[680205, 14289, 37, 1, 24, "Input"],
Cell[680245, 14292, 268, 4, 41, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[680550, 14301, 85, 1, 27, "Input"],
Cell[680638, 14304, 2965, 52, 153, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[683640, 14361, 110, 2, 40, "Input"],
Cell[683753, 14365, 3028, 52, 152, "Output"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[686830, 14423, 241, 5, 44, "Subsubsection"],
Cell[687074, 14430, 762, 14, 155, "Input",
  InitializationCell->True],
Cell[687839, 14446, 297, 6, 59, "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{
Cell[688173, 14457, 142, 4, 44, "Subsubsection"],
Cell[688318, 14463, 502, 9, 139, "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{
Cell[688857, 14477, 971, 16, 105, "Subsubsection"],
Cell[689831, 14495, 234, 4, 43, "Input",
  InitializationCell->True],
Cell[690068, 14501, 7259, 123, 1322, "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{
Cell[697364, 14629, 163, 4, 58, "Subsubsection"],
Cell[697530, 14635, 46, 0, 30, "Text"],
Cell[697579, 14637, 4104, 79, 460, "Input"]
}, Closed]],

Cell[CellGroupData[{
Cell[701720, 14721, 143, 3, 28, "Subsubsection"],
Cell[701866, 14726, 703, 14, 75, "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{
Cell[702606, 14745, 420, 7, 45, "Subsubsection"],
Cell[703029, 14754, 4645, 75, 587, "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{
Cell[707711, 14834, 320, 6, 58, "Subsubsection"],
Cell[708034, 14842, 459, 8, 75, "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{
Cell[708530, 14855, 1016, 18, 106, "Subsubsection"],
Cell[709549, 14875, 890, 17, 210, "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{
Cell[710476, 14897, 570, 9, 60, "Subsubsection"],
Cell[711049, 14908, 755, 13, 205, "Input",
  InitializationCell->True]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[711853, 14927, 28, 0, 30, "Subsection"],
Cell[711884, 14929, 101, 2, 27, "Input",
  InitializationCell->True],
Cell[711988, 14933, 60, 4, 42, "Input",
  InitializationCell->True],
Cell[712051, 14939, 58, 1, 27, "Input",
  InitializationCell->True]
}, Closed]]
}, Open  ]]
}
]
*)




(***********************************************************************
End of Mathematica Notebook file.
***********************************************************************)

