(***********************************************************************

                    Mathematica-Compatible Notebook

This notebook can be used on any computer system with Mathematica 4.0,
MathReader 4.0, or any compatible application. The data for the notebook 
starts with the line containing stars above.

To get the notebook into a Mathematica-compatible application, do one of 
the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing the 
word CacheID, otherwise Mathematica-compatible applications may try to 
use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
***********************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[    156998,       3829]*)
(*NotebookOutlinePosition[    248194,       6089]*)
(*  CellTagsIndexPosition[    248150,       6085]*)
(*WindowFrame->Normal*)



Notebook[{
Cell[BoxData[
    \(\(BeginPackage["\<Multilocus`Multilocus`\>", \
{"\<Multilocus`DataManipulation`\>", "\<Utilities`Cumulants`\>", \
"\<Utilities`SetManipulation`\>", "\<Utilities`Notation`\>"}];\)\)], "Input",
  PageWidth->PaperWidth,
  InitializationCell->True,
  AspectRatioFixed->False],

Cell[BoxData[
    RowBox[{
      RowBox[{"NotebookClose", "[", 
        InterpretationBox[\(NotebookObject[\[LeftSkeleton]"\<Notation Palette\
\>"\[RightSkeleton]]\),
          NotebookObject[ 
            FrontEndObject[ 
              LinkObject[ "Mathematica 4", 1, 1]], 47]], "]"}], 
      ";"}]], "Input",
  InitializationCell->True,
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[CellGroupData[{

Cell[" Usage statements", "Subsection",
  Evaluatable->False,
  InitializationCell->True,
  GeneratedCell->True,
  CellAutoOverwrite->True,
  AspectRatioFixed->False],

Cell[BoxData[
    \(\(\[Zeta]::usage = \*"\"\<\!\(\[Zeta]\_\[DoubleStruckI]\) or \
AllelicDeviation[\[DoubleStruckI]] represents the deviation of \
gene-in-context \[DoubleStruckI] from its reference point: \!\(\[Zeta]\_\
\[DoubleStruckI]\)\[Congruent]\!\(X\_\[DoubleStruckI]\)-\!\(\[WeierstrassP]\_\
\[DoubleStruckI]\).\>\"";\)\)], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(\(AllelicDeviation::usage = \*"\"\<AllelicDeviation[\[DoubleStruckI]] \
or \!\(\[Zeta]\_\[DoubleStruckI]\) represents the deviation of \
gene-in-context \[DoubleStruckI] from its reference point: \!\(\[Zeta]\_\
\[DoubleStruckI]\)\[Congruent]\!\(X\_\[DoubleStruckI]\)-\!\(\[WeierstrassP]\_\
\[DoubleStruckI]\).\>\"";\)\)], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(\(X::usage = \*"\"\<\!\(X\_\(\(\[DoubleStruckI]\)\(\\\\\\\ \)\)\)or \
AllelicState[\[DoubleStruckI]] indicates the allelic state of gene-in-context \
\[DoubleStruckI]\>\"";\)\)], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(\(AllelicState::usage = \*"\"\<AllelicState[\[DoubleStruckI]] or \
\!\(X\_\[DoubleStruckI]\) indicates the allelic state of gene-in-context \
\[DoubleStruckI]\>\"";\)\)], "Input",
  InitializationCell->True,
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    \(\(ReferencePoint::usage = \*"\"\<ReferencePoint[\[DoubleStruckI]] or \!\
\(\[WeierstrassP]\_\[DoubleStruckI]\) is the reference point for \
gene-in-context \[DoubleStruckI].  \>\"";\)\)], "Input",
  InitializationCell->True,
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    \(\(\[WeierstrassP]::usage = \*"\"\<\!\(\[WeierstrassP]\_\[DoubleStruckI]\
\) or ReferencePoint[\[DoubleStruckI]] is the reference point for \
gene-in-context \[DoubleStruckI].  \>\"";\)\)], "Input",
  InitializationCell->True,
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    \(\(\[GothicM]::usage = \*"\"\<\!\(\[GothicM]\_\[DoubleStruckI]\) or  \
MeanContribution[\[DoubleStruckI]] is the mean contribution of \
gene-in-context \[DoubleStruckI]\>\"";\)\)], "Input",
  InitializationCell->True,
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    \(\(MeanContribution::usage = \*"\"\<MeanContribution[\[DoubleStruckI]] \
or \!\(\[GothicM]\_\[DoubleStruckI]\) is the mean contribution of \
gene-in-context \[DoubleStruckI].  \>\"";\)\)], "Input",
  InitializationCell->True,
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    \(\(AlleleFrequencyP::usage = \*"\"\<AlleleFrequencyP[\[DoubleStruckI]] \
or \!\(\[GothicP]\_\[DoubleStruckI]\) is the allele frequency \
\[LeftAngleBracket]\!\(X\_\[DoubleStruckI]\)\[RightAngleBracket] of \
gene-in-context \[DoubleStruckI].  \>\"";\)\)], "Input",
  InitializationCell->True,
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    \(\(\[GothicP]::usage = \*"\"\<\!\(\[GothicP]\_\[DoubleStruckI]\)  or \
AlleleFrequencyP[\[DoubleStruckI]] is the allele frequency \
\[LeftAngleBracket]\!\(X\_\[DoubleStruckI]\)\[RightAngleBracket] of \
gene-in-context \[DoubleStruckI].  \>\"";\)\)], "Input",
  InitializationCell->True,
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    \(\(AlleleFrequencyQ::usage = \*"\"\<AlleleFrequencyQ[\[DoubleStruckI]] \
or \!\(\[GothicQ]\_\[DoubleStruckI]\) is the allele frequency \
\[LeftAngleBracket]1-\!\(X\_\[DoubleStruckI]\)\[RightAngleBracket] of \
gene-in-context \[DoubleStruckI].  \>\"";\)\)], "Input",
  InitializationCell->True,
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    \(\(\[GothicQ]::usage = \*"\"\<\!\(\[GothicQ]\_\[DoubleStruckI]\)  or \
AlleleFrequencyQ[\[DoubleStruckI]] is the allele frequency \
\[LeftAngleBracket]1-\!\(X\_\[DoubleStruckI]\)\[RightAngleBracket] of \
gene-in-context \[DoubleStruckI].  \>\"";\)\)], "Input",
  InitializationCell->True,
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    \(\(AlleleFrequencyPQ::usage = \*"\"\<AlleleFrequencyP[\[DoubleStruckI]] \
or \!\(\[GothicP]\[GothicQ]\_\[DoubleStruckI]\) is the allele frequency of \
gene-in-context \[DoubleStruckI].  \>\"";\)\)], "Input",
  InitializationCell->True,
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    \(\(\[GothicP]\[GothicQ]::usage = \*"\"\<\!\(\[GothicP]\[GothicQ]\_\
\[DoubleStruckI]\)  or AlleleFrequencyPQ[\[DoubleStruckI]] is the product of \
allele frequencies of gene-in-context \[DoubleStruckI].  \>\"";\)\)], "Input",\

  InitializationCell->True,
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    \(\(\[GothicCapitalD]::usage = \*"\"\<\!\(\[GothicCapitalD]\_\
\[DoubleStruckCapitalU]\) or Disequilibrium[\[DoubleStruckCapitalU]] is the \
linkage disequilibrium between the set of genes-in-context \
\[DoubleStruckCapitalU].\>\"";\)\)], "Input",
  InitializationCell->True,
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    \(\(Disequilibrium::usage = \
\*"\"\<Disequilibrium[\[DoubleStruckCapitalU]] or \!\(\[GothicCapitalD]\_\
\[DoubleStruckCapitalU]\) is the linkage disequilibrium between the set of \
genes-in-context \[DoubleStruckCapitalU].\>\"";\)\)], "Input",
  InitializationCell->True,
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    \(\(PopulationDisequilibrium::usage = \*"\"\<PopulationDisequilibrium[{{\
\[DoubleStruckCapitalU]},{\[DoubleStruckCapitalV]}\[Ellipsis]},{{\
\[DoubleStruckI]},{\[DoubleStruckJ]},\[Ellipsis]}] or \!\(\[GothicCapitalC]\_\
\({{\[DoubleStruckCapitalU]}, \\\\\\\ {\[DoubleStruckCapitalV]}\\\\\\\ \
\[Ellipsis]}, {{\[DoubleStruckI]}, {\[DoubleStruckJ]}, \[Ellipsis]}\)\) is \
the expectation over a distribution of populations of \!\(\[GothicCapitalD]\_\
\[DoubleStruckCapitalU]\)\!\(\[GothicCapitalD]\_\[DoubleStruckCapitalV]\)\!\(\
\[Ellipsis]\[WeierstrassP]\_\[DoubleStruckI]\)\!\(\[WeierstrassP]\_\
\[DoubleStruckJ]\)\[Ellipsis]. PopulationDisequilibrium[{{\
\[DoubleStruckCapitalU]},{\[DoubleStruckCapitalV]}\[Ellipsis]},{{\
\[DoubleStruckI]},{\[DoubleStruckJ]},\[Ellipsis]},{{\[DoubleStruckCapitalA]}\
\[Ellipsis]},{{\[DoubleStruckCapitalB]}\[Ellipsis]}\[Ellipsis]] or \!\(\
\[GothicCapitalC]\_\({{\[DoubleStruckCapitalU]}, \\\\\\\ {\
\[DoubleStruckCapitalV]} \[Ellipsis]}, {{\[DoubleStruckI]}, \\\\\\\ {\
\[DoubleStruckJ]}, \\\\\\\ \[Ellipsis]}, \\\\\\\ \\\\\\\ {{\
\[DoubleStruckCapitalA]} \[Ellipsis]}, {{\[DoubleStruckCapitalB]}\\\\\\\ \
\[Ellipsis]} \[Ellipsis]\)\) indicates the expectation of \!\(\
\[GothicCapitalD]\_\[DoubleStruckCapitalU]\)\!\(\[GothicCapitalD]\_\
\[DoubleStruckCapitalV]\)\!\(\[Ellipsis]\[WeierstrassP]\_\[DoubleStruckI]\)\!\
\(\[WeierstrassP]\_\[DoubleStruckJ]\)\[Ellipsis]f[\[DoubleStruckCapitalA]]\
\[Ellipsis]g[\[DoubleStruckCapitalB]]\[Ellipsis], where the arbitrary \
functions f, g, \[Ellipsis] are also random variables. \
{\!\(c\_1\),\[Ellipsis],\[DoubleStruckCapitalA]} is given instead of {\
\[DoubleStruckCapitalA]} denotes the function f[\!\(c\_1\),\[Ellipsis],\
\[DoubleStruckCapitalA]].\>\"";\)\)], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(\(\[GothicCapitalC]::usage = \*"\"\<\!\(\[GothicCapitalC]\_\({\
\[DoubleStruckCapitalU], \\\\\\\ \[DoubleStruckCapitalV]\[Ellipsis]}, \\\\\\\ \
\\\\\\\ {\[DoubleStruckI], \\\\\\\ \\\\\\\ \[DoubleStruckJ], \\\\\\\ \\\\\\\ \
\[Ellipsis]}\)\) or PopulationDisequilibrium[{{\[DoubleStruckCapitalU]},{\
\[DoubleStruckCapitalV]}\[Ellipsis]},{{\[DoubleStruckI]},{\[DoubleStruckJ]},\
\[Ellipsis]}] is the expectation over a distribution of populations of \!\(\
\[GothicCapitalD]\_\[DoubleStruckCapitalU]\)\!\(\[GothicCapitalD]\_\
\[DoubleStruckCapitalV]\)\!\(\[Ellipsis]\[WeierstrassP]\_\[DoubleStruckI]\)\!\
\(\[WeierstrassP]\_\[DoubleStruckJ]\)\[Ellipsis]. PopulationDisequilibrium[{{\
\[DoubleStruckCapitalU]},{\[DoubleStruckCapitalV]}\[Ellipsis]},{{\
\[DoubleStruckI]},{\[DoubleStruckJ]},\[Ellipsis]},{{\[DoubleStruckCapitalA]}\
\[Ellipsis]},{{\[DoubleStruckCapitalB]}\[Ellipsis]}\[Ellipsis]] or \!\(\
\[GothicCapitalC]\_\({{\[DoubleStruckCapitalU]}, \\\\\\\ {\
\[DoubleStruckCapitalV]}\\\\\\\ \[Ellipsis]}, \\\\\\\ {{\[DoubleStruckI]}, \\\
\\\\\ \\\\\\\ {\[DoubleStruckJ]}, \\\\\\\ \[Ellipsis]}, \\\\\\\ {{\
\[DoubleStruckCapitalA]}\\\\\\\ \[Ellipsis]}, \\\\\\\ {{\
\[DoubleStruckCapitalB]} \[Ellipsis]}\\\\\\\ \[Ellipsis]\)\) indicates the \
expectation of \!\(\[GothicCapitalD]\_\[DoubleStruckCapitalU]\)\!\(\
\[GothicCapitalD]\_\[DoubleStruckCapitalV]\)\!\(\[Ellipsis]\[WeierstrassP]\_\
\[DoubleStruckI]\)\!\(\[WeierstrassP]\_\[DoubleStruckJ]\)\[Ellipsis]f[\
\[DoubleStruckCapitalA]]\[Ellipsis]g[\[DoubleStruckCapitalB]]\[Ellipsis], \
where the arbitrary functions f, g, \[Ellipsis] are also random variables. \
{\!\(c\_1\),\[Ellipsis],\[DoubleStruckCapitalA]} is given instead of {\
\[DoubleStruckCapitalA]} denotes the function f[\!\(c\_1\),\[Ellipsis],\
\[DoubleStruckCapitalA]].\>\"";\)\)], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(\(Stage::usage = "\<Stage or \[Sampi] denotes the stage in the life \
cycle\>";\)\)], "Input",
  InitializationCell->True,
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    \(\(\[Sampi]::usage = "\<\[Sampi] or Stage denotes the stage in the life \
cycle\>";\)\)], "Input",
  InitializationCell->True,
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    \(\(ContextStructure::usage = "\<ContextStructure[stage] lists the \
components of stage.\>";\)\)], "Input",
  InitializationCell->True,
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    \(\(ContextPosition::usage = "\<ContextPosition[stage,component]  gives \
the position of component  in the context whose structure is defined by \
stage.  Returns 0 if the component is not defined, and 1 for the stage \
itself.\>";\)\)], "Input",
  InitializationCell->True,
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    \(\(ContextComponentQ::usage = "\<ContextComponentQ[stage, symbol] finds \
whether symbol is a component of stage.\>";\)\)], "Input",
  InitializationCell->True,
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    \(\(ContextStageQ::usage = "\<ContextStageQ[symbol] finds whether symbol \
is a defined stage.\>";\)\)], "Input",
  InitializationCell->True,
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    \(\(DefineContext::usage = \
\*"\"\<DefineContext[stage,{\!\(component\_1\),\[Ellipsis]}] defines a \
context with components in the given order\>\"";\)\)], "Input",
  InitializationCell->True,
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    \(\(FullContext::usage = \*"\"\<FullContext[{{stage,\!\(c\_1\),#1,\
\[Ellipsis]},\[DoubleStruckI],\[DoubleStruckJ]\[Ellipsis]}] converts the \
short form of a set of genes-in-context to the full form. \>\"";\)\)], "Input",\

  InitializationCell->True,
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    \(\(ShortContext::usage = "\<ShortContext[{\[DoubleStruckI],\
\[DoubleStruckJ],\[Ellipsis]}] converts the full form of a set of \
genes-in-context to the short form. \>";\)\)], "Input",
  InitializationCell->True,
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    \(\(SelectContext::usage = \
\*"\"\<SelectContext[\[DoubleStruckCapitalU],c]  or \[DoubleStruckCapitalU]\
\[CircleDot]c finds those elements of \[DoubleStruckCapitalU] that are in \
context c.  Components of c that are replaced by _ are disregarded.  \
SelectContext[\[DoubleStruckCapitalU],c,x]  or \[DoubleStruckCapitalU]\!\(\
\[CircleDot]\_x\)c   only takes account of the components x; x may be a \
single component name or a list of component names.\>\"";\)\)], "Input",
  InitializationCell->True,
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    \(\(ExtractContexts::usage = \*"\"\<ExtractContexts[\
\[DoubleStruckCapitalU]] or \[Chi][\[DoubleStruckCapitalU]] lists all the \
contexts of the genes in \[DoubleStruckCapitalU]. ExtractContexts[\
\[DoubleStruckCapitalU],x] or \!\(\[Chi]\_x\)[\[DoubleStruckCapitalU]] \
extracts only components listed in x.\>\"";\)\)], "Input",
  InitializationCell->True,
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    \(\(\[Chi]::usage = \*"\"\<\[Chi][\[DoubleStruckCapitalU]] or \
ExtractContexts[\[DoubleStruckCapitalU]] lists all the contexts of the genes \
in \[DoubleStruckCapitalU]. \!\(\[Chi]\_x\)[\[DoubleStruckCapitalU]] or \
ExtractContexts[\[DoubleStruckCapitalU],x] extracts only components listed in \
x.\>\"";\)\)], "Input",
  InitializationCell->True,
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    \(\(ExtractContexts::usage = \*"\"\<ExtractContexts[\
\[DoubleStruckCapitalU]] or \[Chi][\[DoubleStruckCapitalU]] lists all the \
contexts of the genes in \[DoubleStruckCapitalU]. ExtractContexts[\
\[DoubleStruckCapitalU],x] or \!\(\[Chi]\_x\)[\[DoubleStruckCapitalU]] \
extracts only components listed in x.\>\"";\)\)], "Input",
  InitializationCell->True,
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    \(\(\[Chi]::usage = \*"\"\<\[Chi][\[DoubleStruckCapitalU]] or \
ExtractContexts[\[DoubleStruckCapitalU]] lists all the contexts of the genes \
in \[DoubleStruckCapitalU]. \!\(\[Chi]\_x\)[\[DoubleStruckCapitalU]] or \
ExtractContexts[\[DoubleStruckCapitalU],x] extracts only components listed in \
x.\>\"";\)\)], "Input",
  InitializationCell->True,
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    \(\(ExtractGenes::usage = "\<ExtractGenes[\[DoubleStruckCapitalU]] or \
\[Gamma][\[DoubleStruckCapitalU]] lists all the genes in \
\[DoubleStruckCapitalU].\>";\)\)], "Input",
  InitializationCell->True,
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    \(\(\[Gamma]::usage = "\<\[Gamma][\[DoubleStruckCapitalU]] or \
ExtractGenes[\[DoubleStruckCapitalU]] lists all the genes in \
\[DoubleStruckCapitalU].\>";\)\)], "Input",
  InitializationCell->True,
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    \(\(TransmissionRule::usage = "\<TransmissionRule[present,previous] or \
present\[LeftArrow]previous specifies that genes in the present context \
derive from those in the previous context. The present context can include \
pattern elements.  TransmissionRule[present,previous,A] or present  \
\[LeftArrow] previous restricts the rule to the set of genes A.\>";\)\)], \
"Input",
  InitializationCell->True],

Cell[BoxData[
    \(\(ChangeContext::usage = \
\*"\"\<ChangeContext[\[DoubleStruckCapitalU],rule] or \[DoubleStruckCapitalU]\
\[CirclePlus]rule applies rule to the set of genes-in-context \
\[DoubleStruckCapitalU].  rule should be a TransmissionRule, or a list of \
transmission rules.  ChangeContext[\!\(\[GothicCapitalD]\_\
\[DoubleStruckCapitalU]\),rule] expresses the linkage disequilibrium in the \
present context in terms of the previous context, making allowance for the \
change in reference point. ChangeContext[\!\(\[GothicCapitalC]\_{\
\[DoubleStruckCapitalU]1, \[Ellipsis]}\),rule] does the same for associations \
between linkage disequilibria.\>\"";\)\)], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(\(Expectation::usage = \*"\"\<Expectation[expr] or \
\[LeftAngleBracket]expr\[RightAngleBracket] gives the expectation over a \
polynomial expression in \!\(\[Zeta]\_\[DoubleStruckI]\) and \!\(X\_\
\[DoubleStruckI]\), in terms of the linkage disequilibria, \!\(\
\[GothicCapitalD]\_\[DoubleStruckCapitalU]\).  If expr includes \!\(X\_\
\[DoubleStruckI]\), then the reference points \!\(\[WeierstrassP]\_\
\[DoubleStruckI]\) must be defined, since \!\(\[Zeta]\_\[DoubleStruckI]\)\
\[Congruent]\!\(X\_\[DoubleStruckI]\)-\!\(\[WeierstrassP]\_\[DoubleStruckI]\),\
 and \!\(\[GothicCapitalD]\_\[DoubleStruckCapitalU]\)\[Congruent]\
\[LeftAngleBracket]\!\(\[Product]\+\(\[DoubleStruckI]\\\\\\\  \[Element] \\\\\
\\\ \(\(\\\\\\\\\)\(\\\\\\\ \)\(\[DoubleStruckCapitalU]\)\)\)\)\!\(\[Zeta]\_\
\[DoubleStruckI]\)\[RightAngleBracket]. \>\"";\)\)], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(\(PopulationExpectation::usage = \*"\"\<PopulationExpectation[expr] or \
\[LeftDoubleBracketingBar]expr\[RightDoubleBracketingBar] gives the \
expectation over a polynomial expression in \!\(\[GothicCapitalD]\_\
\[DoubleStruckCapitalU]\) and \!\(\[WeierstrassP]\_\[DoubleStruckI]\), in \
terms of the \!\(\[GothicCapitalC]\_\({\[DoubleStruckCapitalU], \\\\\\\ \
\[Ellipsis]}, \\\\\\\ \\\\\\\ {\[DoubleStruckI], \[Ellipsis]}\)\).  Reference \
points are rewritten as \!\(m\_\[DoubleStruckI]\)=\!\(\[WeierstrassP]\_\
\[DoubleStruckI]\)+\!\(\[GothicCapitalD]\_{\[DoubleStruckI]}\).  \
PopulationExpectation[expr,f, g\[Ellipsis]] or \[LeftDoubleBracketingBar]expr\
\!\(\(\[RightDoubleBracketingBar]\_\(f, \\\\\\\ \\\\\\\ g\[Ellipsis]\)\)\) \
gives the expectation over \!\(\[GothicCapitalD]\_\(\(\[DoubleStruckCapitalU]\
\)\(\\\\\\\ \)\)\)and \!\(\[WeierstrassP]\_\[DoubleStruckI]\) and also of the \
random variables f, g, \[Ellipsis].  \>\"";\)\)], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(\(MakeFitnessSet::usage = \*"\"\<MakeFitnessSet[W] gives the set of \
genes-in-context on which fitness, W, depends.  If W involves sums such as \!\
\(\[Sum]\+\({\[Alpha], \\\\\\\ \[Ellipsis]}\\\\\\\ \\\\\\\  \[Element] \\\\\\\
\ \\\\\\\ {S, \\\\\\\ \[Ellipsis]}\)\)(\!\(\[Zeta]\_\(\[Alpha]\_{\
\[GothicCapitalZ], \\\\\\\ \\\\\\\ \[GothicCapitalM], \\\\\\\ \
\(\(\\\\\\\\\)\(\\\\\\\ \)\(\[GothicCapitalM]\)\)}\)\)\[Ellipsis]), then such \
sets of genes-in-context are represented as \!\(\[Zeta]\_\(S\_{\
\[GothicCapitalZ], \\\\\\\ \\\\\\\ \[GothicCapitalM], \\\\\\\ \\\\\\\ \
\[GothicCapitalM]}\)\).\>\"";\)\)], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(\(MakeSelectionCoefficient::usage = \*"\"\<MakeSelectionCoefficient[\
\[DoubleStruckCapitalU],W] derives the \!\(W\&_\) \!\(a\_\
\[DoubleStruckCapitalU]\) from an expression for the relative fitness.  Can \
deal with expressions involving sums over arbitrary sets, \!\(\[Sum]\+\(i\\\\\
\\\ \\\\\\\  \[Element] \\\\\\\ S\)\)\>\"";\)\)], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(\(\[GothicCapitalG]::usage = \*"\"\<\[GothicCapitalG] represents the \
haploid gamete stage in the life cycle. \!\(\(\[GothicCapitalG]\^*\)\) \
represents the new gamete pool\>\"";\)\)], "Input",
  InitializationCell->True,
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    \(\(\[GothicCapitalG]new::usage = \*"\"\<\[GothicCapitalG]new or \!\(\(\
\[GothicCapitalG]\^*\)\) represents the new gamete pool,\>\"";\)\)], "Input",
  InitializationCell->True,
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    \(\(\[GothicCapitalZ]::usage = "\<\[GothicCapitalZ] represents the \
diploid zygote stage in the life cycle.\>";\)\)], "Input",
  InitializationCell->True,
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    \(\(\[GothicCapitalJ]::usage = "\<\[GothicCapitalJ] represents the \
diploid juvenile stage in the life cycle.\>";\)\)], "Input",
  InitializationCell->True,
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    \(\(\[GothicCapitalH]::usage = "\<\[GothicCapitalH] represents a diploid \
hermaphrodite stage in the life cycle.\>";\)\)], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(\(\[GothicCapitalA]::usage = "\<\[GothicCapitalA] represents the \
diploid adult stage in the life cycle.\>";\)\)], "Input",
  InitializationCell->True,
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    \(\(Sex::usage = "\<Sex represents the sex of the individual; \
\[GothicCapitalM] or \[GothicCapitalF]\>";\)\)], "Input",
  InitializationCell->True,
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    \(\(SexOfOrigin::usage = "\<SexOfOrigin represents the sex of the parent \
from which a gene in a diploid was inherited.\>";\)\)], "Input",
  InitializationCell->True,
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    \(\(OtherSex::usage = "\<OtherSex[\[GothicCapitalM]] returns \
\[GothicCapitalF], and vice versa.\>";\)\)], "Input",
  InitializationCell->True,
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    \(\(\[GothicCapitalM]::usage = "\<\[GothicCapitalM] represents males.\>";\
\)\)], "Input",
  InitializationCell->True,
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    \(\(\[GothicCapitalF]::usage = "\<\[GothicCapitalF] represents \
females.\>";\)\)], "Input",
  InitializationCell->True,
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    \(\(UnionOfGametes::usage = "\<UnionOfGametes[] is a rule which derives \
genes at the zygote stage, \[GothicCapitalZ], from the corresponding gene in \
the gamete pool, \[GothicCapitalG]. UnionOfGametes[{\[GothicCapitalG],\
\[GothicCapitalZ]}] specifies the stages explicitly.\>";\)\)], "Input",
  InitializationCell->True,
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    \(\(Meiosis::usage = \*"\"\<Meiosis[A,B] is a rule which derives genes in \
the new gametes, \!\(\(\[GothicCapitalG]\^*\)\), from those in adult \
diploids, \[GothicCapitalA]. The set A of genes in the new gamete pool derive \
from the maternal genome in adults; the set B derives from the paternal \
genome. Meiosis[{\[GothicCapitalA],\!\(\(\[GothicCapitalG]\^*\)\)},A,B] \
defines the stages explicitly.\>\"";\)\)], "Input",
  InitializationCell->True,
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    \(\(Migrate::usage = "\<Migrate[\[Alpha],\[Beta]] is a rule which derives \
genes in juvenile diploids, \[GothicCapitalJ], in deme \[Alpha], from those \
in zygotes, \[GothicCapitalZ], in deme \[Beta].  Migrate[{\[GothicCapitalZ],\
\[GothicCapitalJ]},\[Alpha],\[Beta]] defines the stages explicitly.  The deme \
must be specified as the last component before Sex and/or SexOfOrigin: {\
\[GothicCapitalZ],\[Ellipsis],\[Beta],\[GothicCapitalM],\[GothicCapitalF]}.\>\
";\)\)], "Input",
  InitializationCell->True,
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    \(\(ReferencePointZero::usage = \*"\"\<ReferencePointZero[stage] sets the \
\!\(\[GothicCapitalD]\_{i\_{stage, \\\\\\\ \[Ellipsis]}}\) to zero, and sets \
the reference point \!\(\[WeierstrassP]\_\[DoubleStruckI]\) to the mean, \!\(\
\[GothicM]\_\[DoubleStruckI]\) at that stage. ReferencePointZero[stage,p] \
denotes the mean by p[\[DoubleStruckI]].\>\"";\)\)], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(\(ReferencePointMean::usage = \*"\"\<ReferencePointMean[stage,m] sets \
the reference point to the mean, averaged over sexes, at that stage.  \!\(\
\[GothicCapitalD]\_{\[DoubleStruckI]}\) is also set appropriately, as a \
function of m.\>\"";\)\)], "Input",
  InitializationCell->True,
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    \(\(RandomUnion::usage = \*"\"\<RandomUnion[\[GothicCapitalG]] is a rule \
which sets the associations among genes in male and female gametes equal to \
the product of the associations in each sex separately.RandomUnion[\
\[GothicCapitalZ]] does the same for zygotes. RandomUnion[stage,{\!\(c\_1\),\
\[Ellipsis]}] is the general form, which treats contexts that differ in any \
of the components {\!\(c\_1\),\[Ellipsis]} as being randomly \
combined.\>\"";\)\)], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(\(Selfing::usage = "\<Selfing[] is a rule which implements \
self-fertilisation; sets the associations among genes a stage \
\[GothicCapitalA] are rewritten in terms of a sexless hermaphrodite stage \
\[GothicCapitalH], and a sexed outcrossing stage \[GothicCapitalJ].  \
Selfing[s] allows for a probability of selfing s. The general form is \
Selfing[{{\[GothicCapitalJ],\[GothicCapitalH]},\[GothicCapitalA]},s].\>";\)\)]\
, "Input",
  InitializationCell->True],

Cell[BoxData[
    \(\(ReferencePointSame::usage = "\<ReferencePointSame[\[GothicCapitalG],\
\[GothicCapitalZ]] is a rule which sets the reference point in zygotes to be \
the same as in the corresponding genes in gametes. ReferencePointSame[\
\[GothicCapitalG],\[GothicCapitalG]2] just equates reference points in the \
haploid stages \[GothicCapitalG]2 to that at stage \[GothicCapitalG]. \
ReferencePointSame[\[GothicCapitalG],{\[GothicCapitalG]2,\[GothicCapitalZ],\
\[GothicCapitalA]}] does the same for all listed stages.\>";\)\)], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(\(CytoplasmicLoci::usage = "\<CytoplasmicLoci\[Rule]{i,j\[Ellipsis]} is \
an option for ReferencePointMean and NonMendelian which specifies a set of \
cytoplasmically inherited loci; equivalent to MaternalLoci.\>";\)\)], "Input",\

  InitializationCell->True],

Cell[BoxData[
    \(\(MaternalLoci::usage = "\<MaternalLoci\[Rule]{i,j\[Ellipsis]} is an \
option for ReferencePointMean and NonMendelian which specifies a set of \
maternally inherited loci; equivalent to CytoplasmicLoci.\>";\)\)], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(\(PaternalLoci::usage = "\<PaternalLoci\[Rule]{i,j\[Ellipsis]} is an \
option for ReferencePointMean and NonMendelian which specifies a set of \
paternally inherited loci.\>";\)\)], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(\(XLinkedLoci::usage = "\<XLinkedLoci\[Rule]{i,j\[Ellipsis]} is an \
option for ReferencePointMean and NonMendelian which specifies a set of \
X-linked loci.\>";\)\)], "Input",
  InitializationCell->True,
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    \(\(YLinkedLoci::usage = "\<YLinkedLoci\[Rule]{i,j\[Ellipsis]} is an \
option for ReferencePointMean and NonMendelian which specifies a set of \
Y-linked loci.\>";\)\)], "Input",
  InitializationCell->True,
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    \(\(ZLinkedLoci::usage = "\<ZLinkedLoci\[Rule]{i,j\[Ellipsis]} is an \
option for ReferencePointMean and NonMendelian which specifies a set of \
Z-linked loci.\>";\)\)], "Input",
  InitializationCell->True,
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    \(\(WLinkedLoci::usage = "\<WLinkedLoci\[Rule]{i,j\[Ellipsis]} is an \
option for ReferencePointMean and NonMendelian which specifies a set of \
W-linked loci.\>";\)\)], "Input",
  InitializationCell->True,
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    \(\(NonMendelian::usage = \*"\"\<NonMendelian[CytoplasmicLoci->{i,j}] is \
a rule which simplifies recombination rates \!\(\[GothicR]\_\(A, \\\\\\\ \
B\)\)on the assumption that genes i, j are cytoplasmically inherited; also \
takes options MaternalLoci, PaternalLoci, XlinkedLoci, YLinkedLoci, \
ZLinkedLoci, and WLinkedLoci.\>\"";\)\)], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(\(Deme::usage = "\<Deme represents the deme a gene is in. By \
convention, the last component before Sex and/or SexOfOrigin\>";\)\)], "Input",\

  InitializationCell->True,
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    \(\(Individual::usage = "\<Individual represents the individual organism \
a gene is in.\>";\)\)], "Input",
  InitializationCell->True,
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    \(\(FitnessSet::usage = \*"\"\<FitnessSet[\!\(c\_1\),\[Ellipsis]] or \!\(\
\[DoubleStruckCapitalW]\_\(c\_1, \\\\\\\ \\\\\\\ \[Ellipsis]\)\) is the set \
of genes-in-context that may affect fitness.\>\"";\)\)], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(\(\[DoubleStruckCapitalW]::usage = \*"\"\<\!\(\[DoubleStruckCapitalW]\_\
\(c\_1, \\\\\\\ \\\\\\\ \[Ellipsis]\)\) or FitnessSet[\!\(c\_1\),\[Ellipsis]] \
is the set of genes-in-context that may affect fitness.\>\"";\)\)], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(\(RecombinationSet::usage = \*"\"\<RecombinationSet[\!\(c\_1\),\
\[Ellipsis]] or \!\(\[DoubleStruckCapitalR]\_\(c\_1, \\\\\\\ \\\\\\\ \
\[Ellipsis]\)\) is the set of genes-in-context that may affect recombination \
rates.\>\"";\)\)], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(\(\[DoubleStruckCapitalR]::usage = \*"\"\<\!\(\[DoubleStruckCapitalR]\_\
\(c\_1, \\\\\\\ \\\\\\\ \[Ellipsis]\)\) or RecombinationSet[\!\(c\_1\),\
\[Ellipsis]] is the set of genes-in-context that may affect recombination \
rates.\>\"";\)\)], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(\(MigrationSet::usage = \*"\"\<MigrationSet[\!\(c\_1\),\[Ellipsis]] or \
\!\(\[DoubleStruckCapitalM]\_\(c\_1, \\\\\\\ \\\\\\\ \[Ellipsis]\)\) is the \
set of genes-in-context that may affect migration rates.\>\"";\)\)], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(\(\[DoubleStruckCapitalM]::usage = \*"\"\<\!\(\[DoubleStruckCapitalM]\_\
\(c\_1, \\\\\\\ \\\\\\\ \[Ellipsis]\)\) or \
MigrationSet[\!\(c\_1\),\[Ellipsis]] is the set of genes-in-context that may \
affect migration rates.\>\"";\)\)], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(\(Selection::usage = \*"\"\<Selection[\[DoubleStruckCapitalW]] is a \
rule which gives linkage disequilibria at the adult stage \[GothicCapitalA] \
in terms of those at the zygote stage, \[GothicCapitalZ]. Selection between \
zygote and adult is described by the selection coefficients \!\(\[GothicA]\_\
\[DoubleStruckCapitalU]\), and the set of selected genes \
\[DoubleStruckCapitalW]. Selection[{\[GothicCapitalZ],\[GothicCapitalA]},\
\[GothicA],\[DoubleStruckCapitalW]] defines the stages and coefficients \
explicitly.  Selection[{\[GothicCapitalZ],\[GothicCapitalA]},\[GothicA],\
\[DoubleStruckCapitalW],{\!\(c\_1\),\[Ellipsis]}] calls functions \!\(\
\[GothicA]\_\(c\_1, \\\\\\\ \\\\\\\ \[Ellipsis], \\\\\\\ \\\\\\\ \
\[DoubleStruckCapitalU]\)\) and \!\(\[DoubleStruckCapitalW]\_\(c\_1, \\\\\\\ \
\\\\\\\ \[Ellipsis]\)\) of the components of \[GothicCapitalZ].  Linkage \
disequilibria must only involve genes with the same values of the specified \
components.\>\"";\)\)], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(\(Recombination::usage = \*"\"\<Recombination[] is a rule which \
calculates \[GothicCapitalD] in the new gamete pool, \
\!\(\(\[GothicCapitalG]\^*\)\), as a sum over all possible recombination \
events amongst genes at the adult stage, \[GothicCapitalA].  Each \
recombination has rate \!\(\[GothicR]\_\(A, \\\\\\\ B\)\).  Recombination[{\
\[GothicCapitalA],\!\(\(\[GothicCapitalG]\^*\)\)},RecombinationRate] gives \
the stages and recombination rates explicitly. Recombination[{\!\(c\_1\),\
\[Ellipsis]}] or \
Recombination[{\[GothicCapitalA],\!\(\(\[GothicCapitalG]\^*\)\)},\
RecombinationRate,{\!\(c\_1\),\[Ellipsis]}] allows for variation in \
recombination rates \!\(\[GothicR]\_\(c\_1, \\\\\\\ \\\\\\\ \[Ellipsis], \\\\\
\\\ \(\(\\\\\\\\\)\(\\\\\\\ \)\(A\)\), \\\\\\\ \(\(\\\\\\\\\)\(\\\\\\\ \
\)\(B\)\)\)\) across components {\!\(c\_1\),\[Ellipsis]}. Recombination[\
\[DoubleStruckCapitalR]], Recombination[{\!\(c\_1\),\[Ellipsis]},\
\[DoubleStruckCapitalR]] etc allows for a dependence of recombination rate on \
the set of genes \[DoubleStruckCapitalR].  Recombination rates are then given \
in terms of \!\(\[GothicR]\_\(\[DoubleStruckCapitalV], \\\\\\\ \\\\\\\ A, \
\\\\\\\ \(\(\\\\\\\\\)\(B\)\)\)\) , which is the dependence of recombination \
rates on the set of genes \[DoubleStruckCapitalV].\>\"";\)\)], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(\(UnlinkedRecombination::usage = \*"\"\<UnlinkedRecombination[A,B] \
gives the probability of recombination between sets A and B with no linkage; \
this is just \!\(2\^\(-n\)\), where there are n loci in total.\>\"";\)\)], \
"Input",
  InitializationCell->True],

Cell[BoxData[
    \(\(LinkedRecombination::usage = \*"\"\<LinkedRecombination[A,B,{i,j,k\
\[Ellipsis]},c] gives the recombination rate \!\(r\_\(A, B\)\) assuming the \
loci are in order {i,j,k\[Ellipsis]}, in terms of c[i,j], c[j,k]\[Ellipsis]  \
Assumes no interference or meiotic drive, and that all loci are autosomal. \>\
\"";\)\)], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(\(\[GothicA]::usage = \*"\"\<\!\(\[GothicA]\_\[DoubleStruckCapitalU]\) \
or SelectionCoefficient[\[DoubleStruckCapitalU]] is the selection \
coefficient.  \!\(\[GothicA]\_\(c\_1, \\\\\\\ \\\\\\\ \[Ellipsis], \\\\\\\ \\\
\\\\\ \[DoubleStruckCapitalU]\)\) or SelectionCoefficient[\!\(c\_1\),\
\[Ellipsis],\[DoubleStruckCapitalU]] makes the coefficient depend on \
components \!\(c\_1\),\[Ellipsis].\>\"";\)\)], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(\(SelectionCoefficient::usage = \*"\"\<SelectionCoefficient[\
\[DoubleStruckCapitalU]] or \!\(\[GothicA]\_\[DoubleStruckCapitalU]\) is the \
selection coefficient.  \!\(\[GothicA]\_\(c\_1, \\\\\\\ \[Ellipsis], \\\\\\\ \
\[DoubleStruckCapitalU]\)\) or SelectionCoefficient[\!\(c\_1\),\[Ellipsis],\
\[DoubleStruckCapitalU]] makes the coefficient depend on components \
\!\(c\_1\),\[Ellipsis].\>\"";\)\)], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(\(\[GothicR]::usage = \*"\"\<\!\(\[GothicR]\_\(A, \\\\\\\ B\)\) or \
RecombinationRate[A,B] is the probability that the set A of genes derive from \
the maternal genome, and set B from the paternal genome.  \
\!\(\[GothicA]\_\(\(c\_1\) \[Ellipsis], \\\\\\\ A, \\\\\\\ B\)\) or \
RecombinationRate[\!\(c\_1\),\[Ellipsis],A,B] makes the coefficient depend on \
components \!\(c\_1\),\[Ellipsis].  \!\(\[GothicR]\_\(c\_1, \[Ellipsis], \\\\\
\\\ \[DoubleStruckCapitalU], \\\\\\\ A, B\)\) or \
RecombinationRate[\!\(c\_1\),\[Ellipsis],\[DoubleStruckCapitalU],A,B] is the \
dependence of the rate on the set of loci \
\[DoubleStruckCapitalU].\>\"";\)\)], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(\(RecombinationRate::usage = \*"\"\<RecombinationRate[A,B] or \!\(\
\[GothicR]\_\(A, \\\\\\\ B\)\) is the probability that the set A of genes \
derive from the maternal genome, and set B from the paternal genome.  \!\(\
\[GothicA]\_\(c\_1, \\\\\\\ \\\\\\\ \[Ellipsis], \\\\\\\ \\\\\\\ A, \\\\\\\ B\
\)\) or RecombinationRate[\!\(c\_1\),\[Ellipsis],A,B] makes the coefficient \
depend on components \!\(c\_1\),\[Ellipsis].  \!\(\[GothicA]\_\(c\_1, \\\\\\\ \
\\\\\\\ \[Ellipsis], \\\\\\\ \\\\\\\ \[DoubleStruckCapitalU], \\\\\\\ \\\\\\\ \
A, \\\\\\\ \\\\\\\ B\)\) or RecombinationRate[\!\(c\_1\),\[Ellipsis],\
\[DoubleStruckCapitalU],A,B] is the dependence of the rate on the set of loci \
\[DoubleStruckCapitalU].\>\"";\)\)], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(\(\[CapitalMu]::usage = \*"\"\<\!\(\[CapitalMu]\_\(\[Alpha], \\\\\\\ \\\
\\\\\ \[Beta]\)\) or MigrationRate[\[Alpha],\[Beta]] is the chance that a \
gene in deme \[Alpha] came from deme \[Beta]. \!\(\[CapitalMu]\_\(c\_1, \
\\\\\\\ \[Ellipsis], \\\\\\\ \[Alpha], \\\\\\\ \[Beta]\)\) or \
MigrationRate[\!\(c\_1\),\[Ellipsis],\[Alpha],\[Beta]] makes the migration \
rate depend on components \!\(c\_1\),\[Ellipsis].  \!\(\[CapitalMu]\_\(c\_1, \
\\\\\\\ \[Ellipsis], \\\\\\\ \\\\\\\ \[DoubleStruckCapitalU], \\\\\\\ \\\\\\\ \
\[Alpha], \\\\\\\ \\\\\\\ \[Beta]\)\) or \
MigrationRate[\!\(c\_1\),\[Ellipsis],\[DoubleStruckCapitalU],\[Alpha],\[Beta]]\
 is the dependence of the rate on the set of loci \[DoubleStruckCapitalU]. \!\
\(\[CapitalMu]\_\(Deme, \\\\\\\ \\\\\\\ c\_1, \\\\\\\ \\\\\\\ \[Ellipsis], \\\
\\\\\ \\\\\\\ \[DoubleStruckCapitalU], \\\\\\\ \[Alpha], \\\\\\\ \\\\\\\ \
\[Beta]\)\) states the relevant component explicitly. Entered as \
\[AliasIndicator]M\[AliasIndicator]\>\"";\)\)], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(\(MigrationRate::usage = \*"\"\<MigrationRate[\[Alpha],\[Beta]] or \!\(\
\[CapitalMu]\_\(\[Alpha], \\\\\\\ \(\(\\\\\\\\\)\(\\\\\\\ \
\)\(\\\\\\\\\)\(\\\\\\\ \)\(\[Beta]\)\)\)\) is the chance that a gene in deme \
\[Alpha] came from deme \[Beta]. \!\(\[CapitalMu]\_\(c\_1, \\\\\\\ \
\[Ellipsis], \\\\\\\ \\\\\\\ \[Alpha], \\\\\\\ \[Beta]\)\) or \
MigrationRate[\!\(c\_1\),\[Ellipsis],\[Alpha],\[Beta]] makes the migration \
rate depend on components \!\(c\_1\),\[Ellipsis].  \!\(\[CapitalMu]\_\(c\_1, \
\\\\\\\ \[Ellipsis], \\\\\\\ \\\\\\\ \[DoubleStruckCapitalU], \\\\\\\ \\\\\\\ \
\[Alpha], \\\\\\\ \\\\\\\ \[Beta]\)\) or \
MigrationRate[\!\(c\_1\),\[Ellipsis],\[DoubleStruckCapitalU],\[Alpha],\[Beta]]\
 is the dependence of the rate on the set of loci \[DoubleStruckCapitalU]. \!\
\(\[CapitalMu]\_\(Deme, \\\\\\\ \\\\\\\ c\_1, \\\\\\\ \\\\\\\ \[Ellipsis], \\\
\\\\\ \[DoubleStruckCapitalU], \\\\\\\ \(\(\\\\\\\\\)\(\\\\\\\ \)\(\[Alpha]\)\
\), \\\\\\\ \(\(\\\\\\\\\)\(\\\\\\\ \)\(\[Beta]\)\)\)\) states the relevant \
component explicitly. Entered as \
\[AliasIndicator]M\[AliasIndicator]\>\"";\)\)], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(\(Migration::usage = \*"\"\<Migration[\[CapitalOmega]] is a rule which \
calculates \[GothicCapitalD] in the new juvenile pool, \[GothicCapitalJ], as \
a sum over all possible movements of genes at the zygote stage, \
\[GothicCapitalZ].  \[CapitalOmega][\[Alpha]] is the set of possible sources \
of immigrants to deme \[Alpha]; it will usually include \[Alpha] itself.  \
Each movement from \[Beta] to  \[Alpha] has rate \
\!\(\[CapitalMu]\_\(\[Alpha], \\\\\\\ \\\\\\\ \[Beta]\)\).  Migration[{\
\[GothicCapitalZ],\[GothicCapitalJ]},MigrationRate,\[CapitalOmega]] gives the \
stages and recombination rates explicitly. \
Migration[{\!\(c\_1\),\[Ellipsis]},\[CapitalOmega]] or Migration[{\
\[GothicCapitalZ],\[GothicCapitalJ]},MigrationRate,{\!\(c\_1\),\[Ellipsis]},\
\[CapitalOmega]] allows for variation in migration rates \
\!\(\[CapitalMu]\_\(c\_1, \\\\\\\ _, \\\\\\\ \\\\\\\ \[Alpha], \\\\\\\ \
\[Beta]\)\) across components {\!\(c\_1\),\[Ellipsis]}. Migration[\
\[DoubleStruckCapitalM],\[CapitalOmega]], Migration[{\!\(c\_1\),\[Ellipsis]},\
\[DoubleStruckCapitalM],\[CapitalOmega]] etc allows for a dependence of \
recombination rate on the set of genes \[DoubleStruckCapitalM].  Migration \
rates are then given in terms of \!\(\[CapitalMu]\_\(\[DoubleStruckCapitalV], \
\\\\\\\ \\\\\\\ \[Alpha], \\\\\\\ \\\\\\\ \[Beta]\)\), which is the \
dependence of recombination rates on the set of genes \
\[DoubleStruckCapitalV].\>\"";\)\)], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(\(SymmetricRecombination::usage = \*"\"\<SymmetricRecombination[] is a \
rule which replaces \!\(\[GothicR]\_\(c\_1, \\\\\\\ \[Ellipsis], \\\\\\\ \\\\\
\\\ B, \\\\\\\ \(\(\\\\\\\\\)\(\\\\\\\ \)\(A\)\)\)\) by \
\!\(\[GothicR]\_\(c\_1, \\\\\\\ \[Ellipsis], \\\\\\\ A, \\\\\\\ B\)\), on the \
assumption that reciprocal segregations are equally frequent. \
SymmetricRecombination[rec] applies to rec[\[Ellipsis],A,B].\>\"";\)\)], \
"Input",
  InitializationCell->True],

Cell[BoxData[
    \(\(Biallelic::usage = \*"\"\<Biallelic[] is a rule which simplifies \
linkage disequilibria with repeated indices, {\[Ellipsis], \[DoubleStruckI],\
\[Ellipsis], \[DoubleStruckI], \[Ellipsis]}, assuming that there are two \
alleles at frequency \!\(\[GothicP]\_\[DoubleStruckI]\), \!\(\[GothicQ]\_\
\[DoubleStruckI]\), and labelled as \!\(X\_\[DoubleStruckI]\) = 0 or 1. \
Powers of allelic states, \!\(X\_\[DoubleStruckI]\) and allelic deviations, \
\!\(\[Zeta]\_\[DoubleStruckI]\), are also simplified. Biallelic[\[GothicP]] \
names the allele frequency explicitly as \[GothicP].  Biallelic[{i, j, \
\[Ellipsis]}] states which loci are biallelic. BiallelicPQ\[Rule]True names \
products of allele frequencies as \
\!\(\[GothicP]\[GothicQ]\_\[DoubleStruckI]\)= \
\!\(\[GothicP]\_\[DoubleStruckI]\)\!\(\[GothicQ]\_\[DoubleStruckI]\).\>\"";\)\
\)], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(\(BiallelicPQ::usage = \*"\"\<BiallelicPQ is an option for Biallelic[] \
which names products of allele frequencies as \!\(\[GothicP]\[GothicQ]\_\
\[DoubleStruckI]\)= \!\(\[GothicP]\_\[DoubleStruckI]\)\!\(\[GothicQ]\_\
\[DoubleStruckI]\).\>\"";\)\)], "Input",
  InitializationCell->True,
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    \(\(SymmetricSexes::usage = "\<SymmetricSexes[] is a rule which \
simplifies \[GothicM] and \[GothicCapitalD] on the assumption of symmetry \
across the sexes.  By default, \[GothicCapitalM] at Sex or SexOfOrigin is \
swapped for \[GothicCapitalF] if this will increase the proportion of \
\[GothicCapitalF].  SymmetricSexes[\[GothicCapitalM]] does the opposite.  \
SymmetricSexes[] may block later rules and so should be placed at the end of \
lists of rules.\>";\)\)], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(\(ToCumulants::usage = \*"\"\<ToCumulants[] is a rule which converts \
linkage disequilibria, \!\(\[GothicCapitalD]\_\[DoubleStruckCapitalU]\), to \
cumulants, \!\(\[GothicK]\_\[DoubleStruckCapitalU]\).  ToCumulants[mom,cum] \
does the same, for arbitrary symbols.\>\"";\)\)], "Input",
  InitializationCell->True,
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    \(\(ToMoments::usage = \*"\"\<ToMoments[] is a rule which converts \
cumulants, \!\(\[GothicK]\_\[DoubleStruckCapitalU]\), to linkage \
disequilibria, \!\(\[GothicCapitalD]\_\[DoubleStruckCapitalU]\).  \
ToMoments[cum,mom] does the same, for arbitrary symbols.\>\"";\)\)], "Input",
  InitializationCell->True,
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    \(\(ToBaake::usage = \*"\"\<ToBaake[] is a rule which converts \
disequilibria, \!\(\[GothicCapitalD]\_\[DoubleStruckCapitalU]\), to Baake's \
measures of association, \!\(\[GothicZ]\_\[DoubleStruckCapitalU]\), which \
decay exponentially under weak recombination.  The order of genes along the \
chromosome is assumed to be the same as in \[DoubleStruckCapitalU].  \
ToBaake[diseq,baake] does the same, for arbitrary symbols.\>\"";\)\)], "Input",\

  InitializationCell->True],

Cell[BoxData[
    \(\(FromBaake::usage = \*"\"\<FromBaake[] is a rule which converts \
Baake's measures of association, \!\(\[GothicZ]\_\[DoubleStruckCapitalU]\), \
to disequilibria, \!\(\[GothicCapitalD]\_\[DoubleStruckCapitalU]\).  The \
order of genes along the chromosome is assumed to be the same as in \
\[DoubleStruckCapitalU].  FromBaake[baake,diseq] does the same, for arbitrary \
symbols.\>\"";\)\)], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(\(CumulantDisequilibrium::usage = \*"\"\<CumulantDisequilibrium[\
\[DoubleStruckCapitalU]] or \!\(\[GothicK]\_\[DoubleStruckCapitalU]\) is a \
cumulant measure of the association among the set of genes \
\[DoubleStruckCapitalU].\>\"";\)\)], "Input",
  InitializationCell->True,
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    \(\(\[GothicK]::usage = \*"\"\<\!\(\[GothicK]\_\[DoubleStruckCapitalU]\) \
or CumulantDisequilibrium[\[DoubleStruckCapitalU]] is a cumulant measure of \
the association among the set of genes \[DoubleStruckCapitalU].\>\"";\)\)], \
"Input",
  InitializationCell->True,
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    \(\(BaakeDisequilibrium::usage = \*"\"\<BaakeDisequilibrium[\
\[DoubleStruckCapitalU]] or \!\(\[GothicZ]\_\[DoubleStruckCapitalU]\) is a \
measure of the association among the set of genes \[DoubleStruckCapitalU] \
which changes exponentially under weak recombination and \
mutation.\>\"";\)\)], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(\(\[GothicZ]::usage = \*"\"\<\!\(\[GothicZ]\_\[DoubleStruckCapitalU]\) \
or BaakeDisequilibrium[\[DoubleStruckCapitalU]] is a measure of the \
association among the set of genes \[DoubleStruckCapitalU] which changes \
exponentially under weak recombination and mutation.\>\"";\)\)], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(\(CumulantPopulationDisequilibrium::usage = \
\*"\"\<CumulantPopulationDisequilibrium[{{\[DoubleStruckCapitalU]},{\
\[DoubleStruckCapitalV]}\[Ellipsis]},{{\[DoubleStruckI]},{\[DoubleStruckJ]}},\
\[Ellipsis]] or \!\(\[GothicCapitalK]\_\({{\[DoubleStruckCapitalU]}, \\\\\\\ \
\\\\\\\ {\[DoubleStruckCapitalV]}\\\\\\\ \[Ellipsis]}, {{\[DoubleStruckI]}, \
\\\\\\\ {\[DoubleStruckJ]}}, \\\\\\\ \\\\\\\ \[Ellipsis]\)\) is a cumulant \
measure of the association amongst a set of random variables.\>\"";\)\)], \
"Input",
  InitializationCell->True],

Cell[BoxData[
    \(\(\[GothicCapitalK]::usage = \*"\"\<\!\(\[GothicCapitalK]\_\({{\
\[DoubleStruckCapitalU]}, \\\\\\\ {\[DoubleStruckCapitalV]}\\\\\\\ \
\[Ellipsis]}, \\\\\\\ \(\(\\\\\\\\\)\(\\\\\\\ \)\({{\[DoubleStruckI]}, \\\\\\\
\ {\[DoubleStruckJ]}}\)\), \\\\\\\ \[Ellipsis]\)\) or \
CumulantPopulationDisequilibrium[{{\[DoubleStruckCapitalU]},{\
\[DoubleStruckCapitalV]}\[Ellipsis]},{{\[DoubleStruckI]},{\[DoubleStruckJ]}},\
\[Ellipsis]] is a cumulant measure of the association amongst a set of random \
variables.\>\"";\)\)], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(\(ToPopulationCumulants::usage = \*"\"\<ToPopulationCumulants[] is a \
rule which converts moments across populations, \!\(\[GothicCapitalC]\_\
\[DoubleStruckCapitalU]\), to cumulants, \!\(\[GothicCapitalK]\_\
\[DoubleStruckCapitalU]\).  ToPopulationCumulants[mom,cum] does the same, for \
arbitrary symbols.\>\"";\)\)], "Input",
  InitializationCell->True,
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    \(\(ToPopulationMoments::usage = \*"\"\<ToPopulationMoments[] is a rule \
which converts cumulants across populations, \!\(\[GothicCapitalK]\_\
\[DoubleStruckCapitalU]\), to momenta across populations, \!\(\
\[GothicCapitalC]\_\[DoubleStruckCapitalU]\).  ToPopulationMoments[cum,mom] \
does the same, for arbitrary symbols.\>\"";\)\)], "Input",
  InitializationCell->True,
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    \(\(\[GothicS]::usage = "\<\[GothicS] is the default symbol for a small \
quantity such as a selection coefficient.\>";\)\)], "Input",
  InitializationCell->True,
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    \(\(SlowChange::usage = "\<SlowChange[expr] approximates expr by a \
first-order expansion in \[GothicS]. SlowChange[expr,\[Epsilon],k] \
approximates by a k'th order expansion in \[Epsilon].\>";\)\)], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(\(WrightFisherSampling::usage = \*"\"\<WrightFisherSampling[2N] is a \
rule which expresses associations \[GothicCapitalC]  involving \
genes-in-context at the adult stage to those at the juvenile stage. \
WrightFisherSampling[{\[GothicCapitalJ],\[GothicCapitalA]},2N] gives the \
stages explicitly.  SlowChange\[Rule]True only calculates to first order in \
\!\(1\/\(2\\\\\\\ N\)\).\>\"";\)\)], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(\(FromBennett::usage = \*"\"\<FromBennett[] is a rule which expresses \
Bennett's measure of disequilibrium, \!\(\[GothicB]\_U\), in terms of \!\(\
\[GothicCapitalD]\_U\).  The expression is written in terms of recombination \
rates, \!\(\[GothicR]\_\(A, \\\\\\\ \(\(\\\\\\\\\)\(\\\\\\\ \)\(B\)\)\)\). \
FromBennett[b,d,r] does the same, for arbitrary symbols.\>\"";\)\)], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(\(ToBennett::usage = \*"\"\<ToBennett[] is a rule which expresses \!\(\
\[GothicCapitalD]\_U\) in terms of Bennett's measure of disequilibrium, \!\(\
\[GothicB]\_U\), which decay exponentially under recombination.  The \
expression is written in terms of recombination rates, \!\(\[GothicR]\_\(A, B\
\)\). ToBennett[d,b,r] does the same, for arbitrary symbols.\>\"";\)\)], \
"Input",
  InitializationCell->True],

Cell[BoxData[
    \(\(ToBennettExpression::usage = \*"\"\<ToBennettExpression[U] is an \
expression for \!\(\[GothicCapitalD]\_U\) in terms of \!\(\[GothicB]\_U\), \!\
\(\[GothicR]\_\(A, B\)\).  ToBennettExpression[n] stores \
ToBennettExpression[Range[n]].\>\"";\)\)], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(\(FromBennettExpression::usage = \*"\"\<FromBennettExpression[U] is an \
expression for \!\(\[GothicB]\_U\) in terms of \!\(\[GothicCapitalD]\_U\), \!\
\(\[GothicR]\_\(A, B\)\).  FromBennettExpression[n] stores \
FromBennettExpression[Range[n]].\>\"";\)\)], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(\(BennettB::usage = \*"\"\<BennettB[U] or \!\(\[GothicB]\_U\) denotes \
Bennett's measure of linkage disequilibrium, which decays exponentially under \
recombination. \!\(\[GothicB]\_\(\({U, V, \[Ellipsis]}\)\(\\\\\\\ \)\)\)is \
interpreted as \!\(\[GothicB]\_U\)\!\(\[GothicB]\_V\)\[Ellipsis] \>\"";\)\)], \
"Input",
  InitializationCell->True],

Cell[BoxData[
    \(\(\[GothicB]::usage = \*"\"\<\!\(\[GothicB]\_U\) or BennettB[U] denotes \
Bennett's measure of linkage disequilibrium, which decays exponentially under \
recombination.  \!\(\[GothicB]\_\(\({U, V, \[Ellipsis]}\)\(\\\\\\\ \)\)\)is \
interpreted as \!\(\[GothicB]\_U\)\!\(\[GothicB]\_V\)\[Ellipsis] \>\"";\)\)], \
"Input",
  InitializationCell->True],

Cell[BoxData[
    \(\(BennettExpansion::usage = "\<BennettExpansion[U] stores the expansion \
used to generate Bennett's coefficients; uses a dummy function bb. \>";\)\)], \
"Input",
  InitializationCell->True],

Cell[BoxData[
    \(\(BennettC::usage = \*"\"\<BennettC[P] gives the coefficient \!\(c\_P\) \
in an expression for Bennett's measure of disequilibrium, \
\!\(\[GothicB]\_U\)=\!\(\[GothicCapitalD]\_\[DoubleStruckCapitalU]\)+\!\(\
\[Sum]\+\(P\\\\\\\  \[Element] \\\\\\\ \[DoubleStruckCapitalP][U]\)\)\!\(c\_P\
\)\!\(\[GothicB]\_P\).  The expression is in terms of \!\(\[GothicR]\_\(A, \\\
\\\\\ B\)\), with \!\(\[GothicR]\_\(A, \\\\\\\ B\)\) assumed equal to \!\(\
\[GothicR]\_\(B, \\\\\\\ A\)\). \>\"";\)\)], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(\(BennettCstandard::usage = \*"\"\<BennettCstandard[P] generates and \
stores the coefficient \!\(c\_P\) in an expression for Bennett's measure of \
disequilibrium, \!\(\[GothicB]\_U\)=\!\(\[GothicCapitalD]\_\
\[DoubleStruckCapitalU]\)+\!\(\[Sum]\+\(P\\\\\\\  \[Element] \\\\\\\ \
\[DoubleStruckCapitalP][U]\)\)\!\(c\_P\)\!\(\[GothicB]\_P\). = \>\"";\)\)], \
"Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{

Cell["Private parts", "Subsection",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    \(\(Begin["\<Multilocus`Multilocus`Private`\>"];\)\)], "Input",
  InitializationCell->True,
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell["\<\
There was an obscure problem here: since I changed Subsets to use \
the Combinatorica routine, the option Subsets->True was not recognised within \
packages such as this.  Therefore, AddUp[\[Ellipsis],Subsets->True] is \
interpreted mistakenly as \
AddUp[\[Ellipsis],Multilocus`Multilocus`Private`Subsets->True] leading to \
errors.  There is no difficulty outside packages.  The problem seemed to be \
that within the package, the set manipulation extensions were not available \
(a problem that has come up elsewhere).  Hence, the fix below.\
\>", "Text"],

Cell[BoxData[
    \(\(<< Utilities`SetManipulation`;\)\)], "Input",
  InitializationCell->True],

Cell[CellGroupData[{

Cell["Stage", "Subsubsection"],

Cell[BoxData[
    RowBox[{
      RowBox[{"Notation", "[", 
        RowBox[{
          TagBox["Multilocus`Multilocus`\[Sampi]",
            NotationBoxTag,
            TagStyle->"NotationTemplateStyle"], " ", 
          "\[DoubleLongLeftRightArrow]", " ", 
          TagBox["Multilocus`Multilocus`Stage",
            NotationBoxTag,
            TagStyle->"NotationTemplateStyle"]}], "]"}], ";"}]], "Input",
  InitializationCell->True,
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell["AllelicState", "Subsubsection"],

Cell[BoxData[
    RowBox[{
      RowBox[{"Notation", "[", 
        RowBox[{
          TagBox[\(X\_\[DoubleStruckI]_\),
            NotationBoxTag,
            TagStyle->"NotationTemplateStyle"], " ", 
          "\[DoubleLongLeftRightArrow]", " ", 
          TagBox[\(AllelicState[\[DoubleStruckI]_]\),
            NotationBoxTag,
            TagStyle->"NotationTemplateStyle"]}], "]"}], ";"}]], "Input",
  InitializationCell->True,
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell["AllelicDeviation", "Subsubsection"],

Cell[BoxData[
    RowBox[{
      RowBox[{"Notation", "[", 
        RowBox[{
          TagBox[\(\[Zeta]\_\[DoubleStruckI]_\),
            NotationBoxTag,
            TagStyle->"NotationTemplateStyle"], " ", 
          "\[DoubleLongLeftRightArrow]", " ", 
          TagBox[\(AllelicDeviation[\[DoubleStruckI]_]\),
            NotationBoxTag,
            TagStyle->"NotationTemplateStyle"]}], "]"}], ";"}]], "Input",
  InitializationCell->True,
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell["ReferencePoint", "Subsubsection"],

Cell[BoxData[
    RowBox[{
      RowBox[{"Notation", "[", 
        RowBox[{
          TagBox[\(\[WeierstrassP]\_\[DoubleStruckI]_\),
            NotationBoxTag,
            TagStyle->"NotationTemplateStyle"], " ", 
          "\[DoubleLongLeftRightArrow]", " ", 
          TagBox[\(ReferencePoint[\[DoubleStruckI]_]\),
            NotationBoxTag,
            TagStyle->"NotationTemplateStyle"]}], "]"}], ";"}]], "Input",
  InitializationCell->True,
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell["MeanContribution", "Subsubsection"],

Cell[BoxData[
    RowBox[{
      RowBox[{"Notation", "[", 
        RowBox[{
          TagBox[\(\[GothicM]\_\[DoubleStruckI]_\),
            NotationBoxTag,
            TagStyle->"NotationTemplateStyle"], " ", 
          "\[DoubleLongLeftRightArrow]", " ", 
          TagBox[\(MeanContribution[\[DoubleStruckI]_]\),
            NotationBoxTag,
            TagStyle->"NotationTemplateStyle"]}], "]"}], ";"}]], "Input",
  InitializationCell->True,
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell["Disequilibrium", "Subsubsection"],

Cell[BoxData[
    \(\(Disequilibrium[{}] = 1;\)\)], "Input",
  InitializationCell->True,
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    RowBox[{
      RowBox[{"Notation", "[", 
        RowBox[{
          TagBox[\(\[GothicCapitalD]\_\[DoubleStruckI]_\),
            NotationBoxTag,
            TagStyle->"NotationTemplateStyle"], " ", 
          "\[DoubleLongLeftRightArrow]", " ", 
          TagBox[\(Multilocus`Multilocus`Disequilibrium[\[DoubleStruckI]_]\),
            NotationBoxTag,
            TagStyle->"NotationTemplateStyle"]}], "]"}], ";"}]], "Input",
  InitializationCell->True,
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell["PopulationDisequilibrium", "Subsubsection"],

Cell[BoxData[
    \(\(PopulationDisequilibrium[{} ... ] = 1;\)\)], "Input",
  InitializationCell->True,
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    RowBox[{
      RowBox[{"Notation", "[", 
        RowBox[{
          TagBox[\(\[GothicCapitalC]\_\[DoubleStruckI]__\),
            NotationBoxTag,
            TagStyle->"NotationTemplateStyle"], " ", 
          "\[DoubleLongLeftRightArrow]", " ", 
          
          TagBox[\(Multilocus`Multilocus`PopulationDisequilibrium[\
\[DoubleStruckI]__]\),
            NotationBoxTag,
            TagStyle->"NotationTemplateStyle"]}], "]"}], ";"}]], "Input",
  InitializationCell->True,
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell["ContextPosition", "Subsubsection"],

Cell[BoxData[
    \(\(ContextPosition[s_, c_] := 
        If[c === s, 1, 
          If[ContextComponentQ[s, c], 
            1 + \(Position[ContextStructure[s], c]\)\[LeftDoubleBracket]1, 
                1\[RightDoubleBracket], 
            Message[ContextPosition::nocom, s, c]; 0]];\)\)], "Input",
  InitializationCell->True,
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    \(\(ContextPosition::nocom = "\<Components not defined for \
ContextPosition[`1`,`2`]\>";\)\)], "Input",
  InitializationCell->True,
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell["ContextComponentQ", "Subsubsection"],

Cell[BoxData[
    \(\(ContextComponentQ[_, _] := False;\)\)], "Input",
  InitializationCell->True,
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell["ContextStageQ", "Subsubsection"],

Cell[BoxData[
    \(\(ContextStageQ[_] := False;\)\)], "Input",
  InitializationCell->True,
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell["DefineContext", "Subsubsection"],

Cell[BoxData[
    \(\(DefineContext[s_, cl_List] := 
        Module[{}, ContextStructure[s] = cl; ContextStageQ[s] = True; 
          Scan[\((ContextComponentQ[s, #] = True)\) &, 
            ContextStructure[s]]];\)\)], "Input",
  InitializationCell->True,
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell["FullContext", "Subsubsection"],

Cell[BoxData[
    \(\(FullContext[{cc_List, 
            x : _\__List ... }] := {x} /. {i_\_c_ \[RuleDelayed] 
              i\_\(\(cc &\) @@ c\)};\)\)], "Input",
  InitializationCell->True,
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell["ShortContext", "Subsubsection"],

Cell[BoxData[{
    \(\(ShortContext[{}] := {};\)\), "\[IndentingNewLine]", 
    \(\(ShortContext[cc : {_\_{b_, ___} ... }] := 
        Module[{cl = Transpose[cc /. {_\_c_ \[RuleDelayed] c}], com, subs, 
            k = 0, ss}, \[IndentingNewLine]subs = \
\[IndentingNewLine]Transpose[{cc /. i_\__ \[RuleDelayed] i, 
                  Transpose[DeleteCases[cl, {a_\  ... }]]}] /. {i_, 
                  s_List} \[RuleDelayed] i\_s; \[IndentingNewLine]ss = 
            Replace[cl /. {a_\  ... } \[RuleDelayed] a, _List \[Rule] #, 
              1]; \[IndentingNewLine]com = 
            Table[If[ss\[LeftDoubleBracket]j\[RightDoubleBracket] === #, 
                k += 1; Slot[k], 
                ss\[LeftDoubleBracket]j\[RightDoubleBracket]], {j, 
                Length[ss]}]; \[IndentingNewLine]Prepend[subs, 
            com]];\)\)}], "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{

Cell["SelectContext", "Subsubsection"],

Cell[BoxData[
    \(\(\( (*\ if\ all\ the\ stages\ are\ the\ same, \ 
      and\ the\ desired\ stage\ is\ not\ specified, \ 
      add\ the\ stage\ to\ the\ specification\ \
*) \)\(\[IndentingNewLine]\)\(SelectContext[\[DoubleStruckCapitalU] : \
{_\__List ... }, c_List] := 
        Module[{s}, 
          If[ContextStageQ[c\[LeftDoubleBracket]1\[RightDoubleBracket]], 
            Cases[\[DoubleStruckCapitalU], _\_c], 
            s = Union[\[DoubleStruckCapitalU] /. {_\_{a_, ___} \[RuleDelayed] 
                      a}]; If[Length[s] > 1, 
              Message[SelectContext::mxstg, \[DoubleStruckCapitalU], c], 
              If[ContextStageQ[s\[LeftDoubleBracket]1\[RightDoubleBracket]], 
                SelectContext[\[DoubleStruckCapitalU], 
                  Prepend[c, s\[LeftDoubleBracket]1\[RightDoubleBracket]]], 
                Message[SelectContext::mxstg, \[DoubleStruckCapitalU], 
                  c]]]]];\)\)\)], "Input",
  InitializationCell->True],

Cell[BoxData[{
    \(\(SelectContext::mxstg = "\<Multiple stages specified in \
SelectContext[`1`,`2`]\>";\)\), "\[IndentingNewLine]", 
    \(\(SelectContext::nostg = "\<No stage defined in \
SelectContext[`1`,`2`]\>";\)\)}], "Input",
  InitializationCell->True,
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    RowBox[{
      RowBox[{"(*", " ", 
        StyleBox[\(\(handle\\shorthand\)\\contexts\),
          FontWeight->"Plain"], " ", "*)"}], 
      "\[IndentingNewLine]", \(SelectContext[\[DoubleStruckCapitalU] : \
{_List, _\__List ... }, cx__] := 
          SelectContext[FullContext[\[DoubleStruckCapitalU]], 
            cx];\)}]], "Input",
  InitializationCell->True,
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    RowBox[{
      RowBox[{"(*", " ", 
        StyleBox[\(\(handle\\single\)\\components\),
          FontWeight->"Plain"], " ", "*)"}], 
      "\[IndentingNewLine]", \(SelectContext[\[DoubleStruckCapitalU] : \
{_\__List ... }, c_List, x_?\((\(! ListQ[#]\) &)\)] := 
          SelectContext[\[DoubleStruckCapitalU], c, {x}];\)}]], "Input",
  InitializationCell->True,
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    RowBox[{
      RowBox[{"(*", " ", 
        StyleBox[\(handle\ components\ specified\ by\ name\),
          FontWeight->"Plain"], " ", "*)"}], 
      "\[IndentingNewLine]", \(SelectContext[\[DoubleStruckCapitalU] : \
{_\_{a_, ___} ... }, c_List, x_List] := 
          SelectContext[\[DoubleStruckCapitalU], \(\((ps = 
                    Position[x, #]; \[IndentingNewLine]If[ps \[Equal] {}, _, 
                    c\[LeftDoubleBracket]ps\[LeftDoubleBracket]1, 
                        1\[RightDoubleBracket]\[RightDoubleBracket]])\) &\) /@ 
              ContextStructure[a]];\)}]], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(\(SelectContext[{}, __] := {};\)\)], "Input",
  InitializationCell->True,
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    RowBox[{
      RowBox[{"Notation", "[", 
        RowBox[{
          TagBox[\(U_\[CircleDot]c_\),
            NotationBoxTag,
            TagStyle->"NotationTemplateStyle"], " ", 
          "\[DoubleLongLeftRightArrow]", " ", 
          TagBox[\(Multilocus`Multilocus`SelectContext[U_, c_]\),
            NotationBoxTag,
            TagStyle->"NotationTemplateStyle"]}], "]"}], ";"}]], "Input",
  InitializationCell->True,
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    RowBox[{"Notation", "[", 
      RowBox[{
        TagBox[\(U_\(\[CircleDot]\_x_\)c_\),
          NotationBoxTag,
          TagStyle->"NotationTemplateStyle"], " ", 
        "\[DoubleLongLeftRightArrow]", " ", 
        TagBox[\(Multilocus`Multilocus`SelectContext[U_, c_, x_]\),
          NotationBoxTag,
          TagStyle->"NotationTemplateStyle"]}], "]"}]], "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{

Cell["ExtractGenes", "Subsubsection"],

Cell[BoxData[
    \(\(ExtractGenes[\[DoubleStruckCapitalU] : {_\_{s_?ContextStageQ, ___} \
... }] := \[DoubleStruckCapitalU] /. {i_\__ \[RuleDelayed] i};\)\)], "Input",
  InitializationCell->True],

Cell[BoxData[
    RowBox[{
      RowBox[{"(*", " ", 
        StyleBox[\(handle\ shorthand\ contexts\),
          FontWeight->"Plain"], " ", "*)"}], 
      "\[IndentingNewLine]", \(ExtractGenes[\[DoubleStruckCapitalU] : {_List, \
_\__List ... }] := 
          ExtractGenes[FullContext[\[DoubleStruckCapitalU]]];\)}]], "Input",
  InitializationCell->True],

Cell[BoxData[{
    RowBox[{
      RowBox[{"Notation", "[", 
        RowBox[{
          TagBox[\(\[Gamma][\[DoubleStruckCapitalU]_]\),
            NotationBoxTag,
            TagStyle->"NotationTemplateStyle"], " ", 
          "\[DoubleLongLeftRightArrow]", " ", 
          TagBox[\(ExtractGenes[\[DoubleStruckCapitalU]_]\),
            NotationBoxTag,
            TagStyle->"NotationTemplateStyle"]}], "]"}], 
      ";"}], "\[IndentingNewLine]", 
    RowBox[{
      RowBox[{"Notation", "[", 
        RowBox[{
          TagBox[\(\[Gamma]\_x_[\[DoubleStruckCapitalU]_]\),
            NotationBoxTag,
            TagStyle->"NotationTemplateStyle"], " ", 
          "\[DoubleLongLeftRightArrow]", " ", 
          TagBox[\(ExtractGenes[\[DoubleStruckCapitalU]_, x_]\),
            NotationBoxTag,
            TagStyle->"NotationTemplateStyle"]}], "]"}], ";"}]}], "Input",
  InitializationCell->True,
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell["ExtractContexts", "Subsubsection"],

Cell[BoxData[
    \(\(ExtractContexts[\[DoubleStruckCapitalU] : {_\__List ... }] := \
\[DoubleStruckCapitalU] /. {_\_c_List \[RuleDelayed] c};\)\)], "Input",
  InitializationCell->True,
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    RowBox[{
      RowBox[{"(*", " ", 
        StyleBox[\(handle\ named\ components\),
          FontWeight->"Plain"], " ", "*)"}], 
      "\[IndentingNewLine]", \(ExtractContexts[\[DoubleStruckCapitalU] : \
{_\_{a_, ___} ... }, x_List] := 
          Module[{ps}, 
            Transpose[\(\((ps = 
                      ContextPosition[
                        a, #]; \[DoubleStruckCapitalU] /. {_\_c_ \
\[RuleDelayed] c\[LeftDoubleBracket]ps\[RightDoubleBracket]})\) &\) /@ 
                x]];\)}]], "Input",
  InitializationCell->True],

Cell[BoxData[
    RowBox[{
      RowBox[{"(*", " ", 
        StyleBox[\(\(handle\\shorthand\)\\contexts\),
          FontWeight->"Plain"], " ", "*)"}], 
      "\[IndentingNewLine]", \(ExtractContexts[\[DoubleStruckCapitalU] : \
{_List, _\__List ... }, x___List] := 
          ExtractContexts[FullContext[\[DoubleStruckCapitalU]], 
            x];\)}]], "Input",
  InitializationCell->True,
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    RowBox[{
      RowBox[{"(*", " ", 
        StyleBox[\(\(handle\\single\)\\components\),
          FontWeight->"Plain"], " ", "*)"}], 
      "\[IndentingNewLine]", \(ExtractContexts[\[DoubleStruckCapitalU] : \
{_\__List ... }, x_?\((\(! ListQ[#]\) &)\)] := 
          ExtractContexts[\[DoubleStruckCapitalU], {x}];\)}]], "Input",
  InitializationCell->True,
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[{
    RowBox[{
      RowBox[{"Notation", "[", 
        RowBox[{
          TagBox[\(\[Chi][\[DoubleStruckCapitalU]_]\),
            NotationBoxTag,
            TagStyle->"NotationTemplateStyle"], " ", 
          "\[DoubleLongLeftRightArrow]", " ", 
          TagBox[\(ExtractContexts[\[DoubleStruckCapitalU]_]\),
            NotationBoxTag,
            TagStyle->"NotationTemplateStyle"]}], "]"}], 
      ";"}], "\[IndentingNewLine]", 
    RowBox[{
      RowBox[{"Notation", "[", 
        RowBox[{
          TagBox[\(\[Chi]\_x_[\[DoubleStruckCapitalU]_]\),
            NotationBoxTag,
            TagStyle->"NotationTemplateStyle"], " ", 
          "\[DoubleLongLeftRightArrow]", " ", 
          TagBox[\(ExtractContexts[\[DoubleStruckCapitalU]_, x_]\),
            NotationBoxTag,
            TagStyle->"NotationTemplateStyle"]}], "]"}], ";"}]}], "Input",
  InitializationCell->True,
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell["TransmissionRule", "Subsubsection"],

Cell[BoxData[{
    \(\(TransmissionRule[pres_List, 
          prev_List] := \((i_\_pres \[RuleDelayed] 
            i\_prev)\);\)\), "\[IndentingNewLine]", 
    \(\(TransmissionRule[pres_List, prev_List, 
          A_List] := \((\((i_?\((MemberQ[A, #] &)\))\)\_pres \[RuleDelayed] 
            i\_prev)\);\)\)}], "Input",
  InitializationCell->True],

Cell[BoxData[{
    RowBox[{
      RowBox[{"Notation", "[", 
        RowBox[{
          TagBox[\(pres_ \[LeftArrow] prev_\),
            NotationBoxTag,
            TagStyle->"NotationTemplateStyle"], " ", 
          "\[DoubleLongLeftRightArrow]", " ", 
          TagBox[\(Multilocus`Multilocus`TransmissionRule[pres_, prev_]\),
            NotationBoxTag,
            TagStyle->"NotationTemplateStyle"]}], "]"}], 
      ";"}], "\[IndentingNewLine]", 
    RowBox[{
      RowBox[{"Notation", "[", 
        RowBox[{
          TagBox[\(pres_\( \[LeftArrow] \+A_\)prev_\),
            NotationBoxTag,
            TagStyle->"NotationTemplateStyle"], " ", 
          "\[DoubleLongLeftRightArrow]", " ", 
          
          TagBox[\(Multilocus`Multilocus`TransmissionRule[pres_, prev_, A_]\),
            
            NotationBoxTag,
            TagStyle->"NotationTemplateStyle"]}], "]"}], ";"}]}], "Input",
  InitializationCell->True,
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell["ChangeContext", "Subsubsection"],

Cell[BoxData[
    \(\(ChangeContext[\[GothicM]\_\[DoubleStruckI]_, 
          r_] := \[GothicM]\_\(First[{\[DoubleStruckI]}\[CirclePlus]r]\);\)\)]\
, "Input",
  InitializationCell->True],

Cell[BoxData[
    \(\(ChangeContext[\[DoubleStruckCapitalU]_List, r_] := 
        If[ListQ[r], \[DoubleStruckCapitalU] /. 
            Flatten[r], \[DoubleStruckCapitalU] /. r];\)\)], "Input",
  InitializationCell->True,
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    \(\(ChangeContext[\[GothicCapitalD]\_\[DoubleStruckCapitalA]_List, r_] := 
        Module[{\[DoubleStruckCapitalB], \[DoubleStruckCapitalC], cs, 
            rp}, \[IndentingNewLine]\[DoubleStruckCapitalB] = 
            If[ListQ[r], \[DoubleStruckCapitalA] /. 
                Flatten[r], \[DoubleStruckCapitalA] /. r];  (*\ 
            peculiar\ problems\ in\ forcing\ evaluation\ of\ \
\[DoubleStruckCapitalA]\[CirclePlus]r*) \[IndentingNewLine]cs[
              sb_List] := \
\[DoubleStruckCapitalA]\[LeftDoubleBracket]\(\(Position[\
\[DoubleStruckCapitalB], #]\)\[LeftDoubleBracket]1, 
                    1\[RightDoubleBracket] &\) /@ 
                sb\[RightDoubleBracket]; \[IndentingNewLine]rp[
              x_List] := \(\[WeierstrassP]\_# &\) /@ 
              x; \[IndentingNewLine]Plus @@ \((\(\(\[GothicCapitalD]\_\(\
\[DoubleStruckCapitalB]\[Backslash]#\)\) 
                    Times @@ \((rp[#] - rp[cs[#]])\) &\) /@ 
                Subsets[\[DoubleStruckCapitalB]])\)];\)\)], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(\(ChangeContext[\[GothicCapitalD]\_\[DoubleStruckCapitalA]_List, r_] := 
        Module[{\[DoubleStruckCapitalB], \[DoubleStruckCapitalC], cs, 
            rp}, \[IndentingNewLine]\[DoubleStruckCapitalB] = 
            If[ListQ[r], \[DoubleStruckCapitalA] /. 
                Flatten[r], \[DoubleStruckCapitalA] /. 
                r]; \[IndentingNewLine]Print[\[DoubleStruckCapitalB], Tab, 
            Subsets[\[DoubleStruckCapitalB]]]; \[IndentingNewLine]cs[
              sb_List] := \
\[DoubleStruckCapitalA]\[LeftDoubleBracket]\(\(Position[\
\[DoubleStruckCapitalB], #]\)\[LeftDoubleBracket]1, 
                    1\[RightDoubleBracket] &\) /@ 
                sb\[RightDoubleBracket]; \[IndentingNewLine]rp[
              x_List] := \(\[WeierstrassP]\_# &\) /@ 
              x; \[IndentingNewLine]Print[\(\[GothicCapitalD]\_\(\
\[DoubleStruckCapitalB]\[Backslash]#\) &\) /@ 
              Subsets[\[DoubleStruckCapitalB]]]; \
\[IndentingNewLine]Print[\({rp[#], rp[cs[#]]} &\) /@ 
              Subsets[\[DoubleStruckCapitalB]]]; \[IndentingNewLine]Plus @@ \
\((\(\(\[GothicCapitalD]\_\(\[DoubleStruckCapitalB]\[Backslash]#\)\) 
                    Times @@ \((rp[#] - rp[cs[#]])\) &\) /@ 
                Subsets[\[DoubleStruckCapitalB]])\)];\)\)], "Input"],

Cell[BoxData[
    \(\(ChangeContext[\[GothicCapitalC]\_\({\[DoubleStruckCapitalA]___List}, \
{\[DoubleStruckCapitalE]___List}, \[DoubleStruckCapitalF]___List\), r_] := 
        Module[{\[DoubleStruckCapitalB], \[DoubleStruckCapitalA]t, \
\[DoubleStruckCapitalB]t, rt, ff, 
            gg}, \[IndentingNewLine]\[DoubleStruckCapitalB] = 
            If[ListQ[r], \[DoubleStruckCapitalA] /. 
                Flatten[r], \[DoubleStruckCapitalA] /. r];  (*\ 
            peculiar\ problems\ in\ forcing\ evaluation\ of\ \
\[DoubleStruckCapitalA]\[CirclePlus]r*) \[IndentingNewLine]\
\[DoubleStruckCapitalB]t = 
            AddTag[\[DoubleStruckCapitalB], 3]; \[DoubleStruckCapitalA]t = 
            AddTag[{\[DoubleStruckCapitalA]}, 3]; 
          gg[\[DoubleStruckCapitalC]t_, \[DoubleStruckCapitalD]t_] := \((\((\
\[DoubleStruckCapitalC]t\[Backslash]\[DoubleStruckCapitalD]t)\)\[Vee]\
\[DoubleStruckCapitalA]t\[LeftDoubleBracket]\(\(Position[\
\[DoubleStruckCapitalB]t, #]\)\[LeftDoubleBracket]1, 
                          1\[RightDoubleBracket] &\) /@ \
\[DoubleStruckCapitalD]t\[RightDoubleBracket])\) /. {Tag[
                    x_, _] \[Rule] {x}}; \n
          ff[\[DoubleStruckCapitalC]t_] := 
            Plus @@ \((rt = 
                  RemoveTag[\[DoubleStruckCapitalB]t\[Backslash]\
\[DoubleStruckCapitalC]t, 
                    3]; \((\(\((\(\((\(-1\))\)\^Length[#]\) \[GothicCapitalC]\
\_\(rt, gg[\[DoubleStruckCapitalC]t, #]\[Vee]{\[DoubleStruckCapitalE]}, \
\[DoubleStruckCapitalF]\))\) &\) /@ 
                    Subsets[\[DoubleStruckCapitalC]t])\))\); \n
          Plus @@ \((ff /@ 
                Subsets[\[DoubleStruckCapitalB]t])\)];\)\)], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(\(ChangeContext[\[GothicM]\_\[DoubleStruckI]_, 
          r_] := \[GothicM]\_\(First[{\[DoubleStruckI]}\[CirclePlus]r]\);\)\)]\
, "Input",
  InitializationCell->True],

Cell[BoxData[
    RowBox[{"Notation", "[", 
      RowBox[{
        TagBox[\(U_\[CirclePlus]r_\),
          NotationBoxTag,
          TagStyle->"NotationTemplateStyle"], " ", 
        "\[DoubleLongLeftRightArrow]", " ", 
        TagBox[\(Multilocus`Multilocus`ChangeContext[U_, r_]\),
          NotationBoxTag,
          TagStyle->"NotationTemplateStyle"]}], "]"}]], "Input",
  InitializationCell->True,
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    \(\(ChangeContext[\[GothicM]\_\[DoubleStruckI]_, 
          r_] := \[GothicM]\_\(First[{\[DoubleStruckI]}\[CirclePlus]r]\);\)\)]\
, "Input",
  InitializationCell->True],

Cell["\<\
There is an obscure bug here - sometimes it is as if the line above \
were not evaluated.  That leaves \[CirclePlus] symbols in the result\
\>", \
"Text"]
}, Closed]],

Cell[CellGroupData[{

Cell["Expectation", "Subsubsection"],

Cell[BoxData[
    \(\(Expectation[
          f_?\((PolynomialQ[#, 
                  Cases[#, \[Zeta]\__, {1, \[Infinity]}]\[Vee]Cases[#, 
                      X\__, {1, \[Infinity]}]] &)\)] := 
        Module[{d}, \(Expand[
                f /. {X\_a_ \[RuleDelayed] 
                      d\_{a} + \[WeierstrassP]\_a, \[Zeta]\_a_ \[RuleDelayed] 
                      d\_{a}}] //. {\(d\_a_\) d\_b_ \[RuleDelayed] 
                  d\_\(a\[Vee]b\), 
                d\_a_\^n_Integer \[RuleDelayed] d\_\(Repeat[a, n]\), 
                d\_U_ \[RuleDelayed] d\_\(Sort[U]\)}\) /. 
            d\_U_List \[RuleDelayed] \[GothicCapitalD]\_U];\)\)], "Input",
  InitializationCell->True,
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[{
    \(\(Expectation[a_] := 
        Expectation[SimplifyAddUp[a]] /; 
          Not[SimplifyAddUpQ[a]];\)\), "\[IndentingNewLine]", 
    \(\(Expectation[a_ + b_] := 
        Expectation[a] + Expectation[b];\)\), "\[IndentingNewLine]", 
    \(\(Expectation[AddUp[a_, e_List, S_List, opts___Rule]] := 
        AddUp[Evaluate[Expectation[a]], e, S, opts];\)\)}], "Input",
  InitializationCell->True],

Cell[BoxData[
    RowBox[{
      RowBox[{"Notation", "[", 
        RowBox[{
          TagBox[\(\[LeftAngleBracket]f_\[RightAngleBracket]\),
            NotationBoxTag,
            TagStyle->"NotationTemplateStyle"], " ", 
          "\[DoubleLongLeftRightArrow]", " ", 
          TagBox[\(Multilocus`Multilocus`Expectation[f_]\),
            NotationBoxTag,
            TagStyle->"NotationTemplateStyle"]}], "]"}], ";"}]], "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{

Cell["PopulationExpectation", "Subsubsection"],

Cell[BoxData[{
    \(\(PopulationExpectation[e_, a___, \[GothicA], b___] := 
        PopulationExpectation[e, a, SelectionCoefficient, 
          b];\)\), "\[IndentingNewLine]", 
    \(\(PopulationExpectation[e_, a___, \[CapitalMu], b___] := 
        PopulationExpectation[e, a, MigrationRate, 
          b];\)\), "\[IndentingNewLine]", 
    \(\(PopulationExpectation[e_, a___, \[GothicR], b___] := 
        PopulationExpectation[e, a, RecombinationRate, 
          b];\)\), "\[IndentingNewLine]", 
    \(\(PopulationExpectation[e_, a___, \[GothicCapitalD], b___] := 
        PopulationExpectation[e, a, Disequilibrium, 
          b];\)\), "\[IndentingNewLine]", 
    \(PopulationExpectation[e_, a___, \[GothicM], b___] := 
      PopulationExpectation[e, a, MeanContribution, b]; 
    PopulationExpectation[e_, a___, \[WeierstrassP], b___] := 
      PopulationExpectation[e, a, ReferencePoint, b];\)}], "Input",
  InitializationCell->True,
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    \(\(PopulationExpectation[e_] := 
        PopulationExpectation[e, Disequilibrium, 
          MeanContribution];\)\)], "Input",
  InitializationCell->True,
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    \(\(PopulationExpectation[e_, ff___] := 
        Module[{cc, rl, i, n, ffn}, n = Length[{ff}]; 
            rl = Flatten[
                Table[{\({ff}\[LeftDoubleBracket]i\[RightDoubleBracket]\)[
                        x___] \[RuleDelayed] 
                      Evaluate[
                        cc[ReplacePart[Repeat[{{}}, n], {{x}}, 
                            i]]], \({ff}\[LeftDoubleBracket]i\
\[RightDoubleBracket]\)[x___]\^k_Integer \[Rule] 
                      Evaluate[
                        cc[ReplacePart[Repeat[{{}}, n], Repeat[{x}, k], 
                            i]]]}, {i, n}]]; \(\(Expand[e] /. 
                  rl\) //. {cc[a_] cc[b_] \[RuleDelayed] 
                    cc[\((Join @@ # &)\) /@ Transpose[{a, b}]]}\) /. 
              cc[U__List] \[RuleDelayed] 
                PopulationDisequilibrium @@ \((Sort /@ U)\)] /; 
          PolynomialQ[e, 
            Cases[e, 
              Alternatives @@ \((\((\(#[___] &\) /@ {ff})\))\), {1, \
\[Infinity]}]];\)\)], "Input",
  InitializationCell->True],

Cell[BoxData[{
    \(\(PopulationExpectation[a_, ff___] := 
        PopulationExpectation[SimplifyAddUp[a], ff] /; 
          Not[SimplifyAddUpQ[a]];\)\), "\[IndentingNewLine]", 
    \(\(PopulationExpectation[a_ + b_, ff___] := 
        PopulationExpectation[a, ff] + 
          PopulationExpectation[b, ff];\)\), "\[IndentingNewLine]", 
    \(\(PopulationExpectation[AddUp[a_, e_List, S_List, opts___Rule], ff___] := 
        AddUp[Evaluate[PopulationExpectation[a, ff]], e, S, 
          opts];\)\)}], "Input",
  InitializationCell->True],

Cell[BoxData[
    RowBox[{
      RowBox[{"Notation", "[", 
        RowBox[{
          
          TagBox[\(\[LeftDoubleBracketingBar]\(\\\)\(f_\)\
\[RightDoubleBracketingBar]\),
            NotationBoxTag,
            TagStyle->"NotationTemplateStyle"], " ", 
          "\[DoubleLongLeftRightArrow]", " ", 
          TagBox[\(Multilocus`Multilocus`PopulationExpectation[f_]\),
            NotationBoxTag,
            TagStyle->"NotationTemplateStyle"]}], "]"}], ";"}]], "Input",
  InitializationCell->True,
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    RowBox[{
      RowBox[{"Notation", "[", 
        RowBox[{
          
          TagBox[\(\[LeftDoubleBracketingBar]f_\[RightDoubleBracketingBar]\_g_\
_\),
            NotationBoxTag,
            TagStyle->"NotationTemplateStyle"], " ", 
          "\[DoubleLongLeftRightArrow]", " ", 
          TagBox[\(Multilocus`Multilocus`PopulationExpectation[f_, g__]\),
            NotationBoxTag,
            TagStyle->"NotationTemplateStyle"]}], "]"}], ";"}]], "Input",
  InitializationCell->True,
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell["MakeFitnessSet", "Subsubsection"],

Cell[BoxData[
    \(\(MakeFitnessSet[
          expr_?\((FreeQ[#, AddUp] &)\)] := \[IndentingNewLine]Module[{fs, 
            ex = expr /. 
                X\_i_ \[Rule] \[Zeta]\_i + \[WeierstrassP]\_i}, \
\[IndentingNewLine]fs = 
            Union[Cases[
                ex, \[Zeta]\__, {1, \[Infinity]}]]; \[IndentingNewLine]If[\(! \
PolynomialQ[expr, fs]\), \[IndentingNewLine]Message[
              MakeFitnessSet::notpolynomial, expr, 
              fs]]; \[IndentingNewLine]Flatten[\(Repeat[{#}, 
                    Exponent[ex, #]] &\) /@ fs] /. \[Zeta]\_i_ \[Rule] 
              i];\)\)], "Input",
  InitializationCell->True],

Cell[BoxData[{
    \(\(MakeFitnessSet[a_] := 
        MakeFitnessSet[SimplifyAddUp[a]] /; 
          Not[SimplifyAddUpQ[a]];\)\), "\[IndentingNewLine]", 
    \(\(MakeFitnessSet[a_ + b_] := 
        Module[{sa = MakeFitnessSet[a], 
            sb = MakeFitnessSet[
                b]}, \[IndentingNewLine]Flatten[\(Repeat[{#}, 
                  Max[Count[sa, \ #], Count[sb, \ #]]] &\) /@ \((sa \[Union] 
                  sb)\)]];\)\), "\[IndentingNewLine]", 
    \(\(MakeFitnessSet[
          AddUp[a_, e_List, S_List, 
            Subsets \[Rule] True]] := \[IndentingNewLine]MakeFitnessSet[
          AddUp[a, e, 
            Union[Sort /@ Subsets[S]]]];\)\), "\[IndentingNewLine]", 
    \(\(MakeFitnessSet[AddUp[a_, e_List, S_List]] := 
        Module[{v, k, 
            ex = a /. 
                X\_i_ \[Rule] \[Zeta]\_i + \[WeierstrassP]\_i}, \
\[IndentingNewLine]v = 
            Union[Cases[
                ex, \[Zeta]\__, {1, \[Infinity]}]]; \[IndentingNewLine]v = 
            Union[v /. 
                Table[e\[LeftDoubleBracket]k\[RightDoubleBracket] \[Rule] 
                    S\[LeftDoubleBracket]k\[RightDoubleBracket], {k, 
                    Length[e]}]]; 
          If[\(! PolynomialQ[a, v]\), 
            Message[MakeFitnessSet::notpolynomial, a, 
              v]]; \[IndentingNewLine]Flatten[\(Repeat[{#}, 
                    Exponent[ex, #]] &\) /@ v] /. \[Zeta]\_i_ \[Rule] 
              i];\)\)}], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(\(MakeFitnessSet::notpolynomial = "\<`1` is not polynomial in `2`\>";\)\
\)], "Input",
  InitializationCell->True,
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell["MakeSelectionCoefficient", "Subsubsection"],

Cell[BoxData[
    \(\(MakeSelectionCoefficient[\[DoubleStruckCapitalU]_List, 
          Z_?\((FreeQ[#, 
                  AddUp] &)\)] := \[IndentingNewLine]Module[{fs}, \
\[IndentingNewLine]fs = 
            Union[Cases[
                Z /. X\_i_ \[Rule] \[Zeta]\_i + \[WeierstrassP]\_i, \
\[Zeta]\__, {1, \[Infinity]}]]; 
          If[\(! PolynomialQ[Z, fs]\), \[IndentingNewLine]Message[
              MakeSelectionCoefficient::notpolynomial, expr, fs]; 
            0, \[IndentingNewLine]If[\[DoubleStruckCapitalU] \[Equal] {}, \
\[IndentingNewLine]\[LeftAngleBracket]Z\[RightAngleBracket], \
\[IndentingNewLine]Coefficient[
                  Z /. X\_i_ \[Rule] \[Zeta]\_i + \[WeierstrassP]\_i, 
                  Times @@ \((\(\[Zeta]\_# &\) /@ \[DoubleStruckCapitalU])\)] \
/. \((\(\((\[Zeta]\_# \[Rule] 0)\) &\) /@ 
                    MakeFitnessSet[Z])\)]]];\)\)], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(\(MakeSelectionCoefficient[\[DoubleStruckCapitalU]_List, a_] := 
        MakeSelectionCoefficient[\[DoubleStruckCapitalU], SimplifyAddUp[a]] /; 
          Not[SimplifyAddUpQ[a]];\)\)], "Input",
  InitializationCell->True,
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    \(\(MakeSelectionCoefficient[\[DoubleStruckCapitalU]_List, a_ + b_] := 
        MakeSelectionCoefficient[\[DoubleStruckCapitalU], a] + 
          MakeSelectionCoefficient[\[DoubleStruckCapitalU], b];\)\)], "Input",\

  InitializationCell->True,
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    \(\(MakeSelectionCoefficient::notpolynomial = "\<`1` is not polynomial in \
`2`\>";\)\)], "Input",
  InitializationCell->True,
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell["\[GothicCapitalG]new", "Subsubsection"],

Cell[BoxData[
    RowBox[{
      RowBox[{"Notation", "[", 
        RowBox[{
          TagBox[\(\[GothicCapitalG]\^*\),
            NotationBoxTag,
            TagStyle->"NotationTemplateStyle"], " ", 
          "\[DoubleLongLeftRightArrow]", " ", 
          TagBox["\[GothicCapitalG]new",
            NotationBoxTag,
            TagStyle->"NotationTemplateStyle"]}], "]"}], ";"}]], "Input",
  InitializationCell->True,
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell["UnionOfGametes", "Subsubsection"],

Cell[BoxData[{
    \(\(UnionOfGametes[] := 
        UnionOfGametes[{\[GothicCapitalG], \[GothicCapitalZ]}];\)\), "\
\[IndentingNewLine]", 
    \(\(UnionOfGametes[{s1_?ContextStageQ, s2_?ContextStageQ}] := 
        If[ContextComponentQ[s2, \ 
            Sex], \[IndentingNewLine]{\[GothicCapitalD]\_\(\
\[DoubleStruckCapitalU] : {_\_{s2, __} .. }\) \[RuleDelayed] \
\[GothicCapitalD]\_\[DoubleStruckCapitalU]\[CirclePlus]\(({s2, x___, sex_, 
                      soo_} \[LeftArrow] {s1, x, 
                      soo})\), \[GothicM]\_\(\[DoubleStruckI] : _\_{s2, __}\) \
\[RuleDelayed] \[GothicM]\_\(\(({\[DoubleStruckI]}\[CirclePlus]\(({s2, x___, \
sex_, soo_} \[LeftArrow] {s1, x, soo})\))\)\[LeftDoubleBracket]1\
\[RightDoubleBracket]\)}, \[IndentingNewLine]{\[GothicCapitalD]\_\(\
\[DoubleStruckCapitalU] : {_\_{s2, __} .. }\) \[RuleDelayed] \
\[GothicCapitalD]\_\[DoubleStruckCapitalU]\[CirclePlus]\(({s2, x___, 
                      soo_} \[LeftArrow] {s1, x, 
                      soo})\), \[GothicM]\_\(\[DoubleStruckI] : _\_{s2, __}\) \
\[RuleDelayed] \[GothicM]\_\(\(({\[DoubleStruckI]}\[CirclePlus]\(({s2, x___, \
soo_} \[LeftArrow] {s1, x, soo})\))\)\[LeftDoubleBracket]1\
\[RightDoubleBracket]\)}];\)\)}], "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{

Cell["Meiosis", "Subsubsection"],

Cell[BoxData[{
    \(\(Meiosis[A_List, B_List] := 
        Meiosis[{\[GothicCapitalA], \(\[GothicCapitalG]\^*\)}, A, 
          B];\)\), "\[IndentingNewLine]", 
    \(\(Meiosis[{s1_?ContextStageQ, s2_?ContextStageQ}, A_List, 
          B_List] := {TransmissionRule[{s2, x___, sex_}, {s1, x, 
              sex, \[GothicCapitalF]}, A], 
          TransmissionRule[{s2, x___, sex_}, {s1, x, sex, \[GothicCapitalM]}, 
            B]};\)\)}], "Input",
  InitializationCell->True,
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell["Migrate", "Subsubsection"],

Cell["\<\
If the stage is either diploid, but with just SexOfOrigin \
specified, or haploid, with Sex specified, then Deme must appear in the \
penultimate slot; otherwise, it appears in the antipenultimate slot.\
\>", \
"Text"],

Cell[BoxData[{
    \(\(Migrate[\[Alpha]_, \[Beta]_] := 
        Migrate[{\[GothicCapitalZ], \[GothicCapitalJ]}, \[Alpha], \[Beta]];\)\
\), "\[IndentingNewLine]", 
    \(\(Migrate[{s1_?ContextStageQ, 
            s2_?ContextStageQ}, \[Alpha]_, \[Beta]_] := \[IndentingNewLine]If[
          ContextComponentQ[s2, Sex] && 
            ContextComponentQ[s2, 
              SexOfOrigin], \[IndentingNewLine]{TransmissionRule[{s2, 
                x___, \[Alpha], sex : \[GothicCapitalM] | \[GothicCapitalF], 
                soo : \[GothicCapitalM] | \[GothicCapitalF]}, {s1, 
                x, \[Beta], sex, soo}]}, {TransmissionRule[{s2, 
                x___, \[Alpha], 
                sex : \[GothicCapitalM] | \[GothicCapitalF]}, {s1, 
                x, \[Beta], sex}]}];\)\)}], "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{

Cell["ReferencePointZero", "Subsubsection"],

Cell[BoxData[{
    \(\(ReferencePointZero[s_?ContextStageQ] := 
        ReferencePointZero[s, MeanContribution];\)\), "\[IndentingNewLine]", 
    \(\(ReferencePointZero[s_?ContextStageQ, 
          m_] := {\[WeierstrassP]\_\(i_\_{s, x___}\) \[RuleDelayed] 
            m[i\_{s, x}], \[GothicCapitalD]\_{_\_{s, ___}} \[RuleDelayed] 
            0};\)\)}], "Input",
  InitializationCell->True,
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[{
    \(\(ReferencePointZero[sl : {_?ContextStageQ ... }] := 
        ReferencePointZero[sl, 
          MeanContribution];\)\), "\[IndentingNewLine]", 
    \(\(ReferencePointZero[sl : {_?ContextStageQ ... }, m_] := 
        Flatten[\(ReferencePointZero[#, m] &\) /@ sl];\)\)}], "Input",
  InitializationCell->True,
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell["ReferencePointMean", "Subsubsection"],

Cell[BoxData[
    \(\(Options[ReferencePointMean] = {CytoplasmicLoci \[Rule] {}, 
          PaternalLoci \[Rule] {}, XLinkedLoci \[Rule] {}, 
          YLinkedLoci \[Rule] {}, ZLinkedLoci \[Rule] {}, 
          WLinkedLoci \[Rule] {}};\)\)], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(\(ReferencePointMean::lociOverlap = "\<Overlapping sets of genes \
specified: C: `1`, P: `2`, X: `3`, Y: `4`, Z: `5`, W: `6`\>";\)\)], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(\(ReferencePointMean::ZWXYmix = "\<Cannot specify both XY linkage and \
ZW linkage: `1`, `2`\>";\)\)], "Input",
  InitializationCell->True,
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    \(\(ReferencePointMean::XlinkageClash = "\<An X-linked gene in a male \
cannot derive from the father: `1`\>";\)\)], "Input",
  InitializationCell->True,
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    \(\(ReferencePointMean::YlinkageClash = "\<A Y-linked gene cannot be in a \
female gamete or derive from the mother: `1`\>";\)\)], "Input",
  InitializationCell->True,
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    \(\(ReferencePointMean::ZlinkageClash = "\<A Z-linked gene in a female \
cannot derive from the mother: `1`\>";\)\)], "Input",
  InitializationCell->True,
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    \(\(ReferencePointMean::WlinkageClash = "\<A W-linked gene cannot be in a \
male gamete or derive from the father: `1`\>";\)\)], "Input",
  InitializationCell->True,
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    \(\(ReferencePointMean::PaternalClash = "\<A paternally inherited gene \
cannot be in a female gamete or derive from the mother: `1`\>";\)\)], "Input",\

  InitializationCell->True],

Cell[BoxData[
    \(\(ReferencePointMean::CytoplasmicClash = "\<A cytoplasmically inherited \
gene cannot be in a male gamete or derive from the father: `1`\>";\)\)], \
"Input",
  InitializationCell->True,
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    \(\(ReferencePointMean::not\[GothicCapitalM]\[GothicCapitalF] = \
"\<Component is not \[GothicCapitalM] or \[GothicCapitalF]: `1`\>";\)\)], \
"Input",
  InitializationCell->True,
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[{
    \(\(ReferencePointMean[s_?ContextStageQ, opts___Rule] := 
        ReferencePointMean[s, MeanContribution, 
          opts];\)\), "\[IndentingNewLine]", 
    \(\(ReferencePointMean[s_?ContextStageQ, m_, opts___Rule] := 
        Module[\[IndentingNewLine]{xs = \(XLinkedLoci /. {opts}\) /. 
                Options[
                  ReferencePointMean], \[IndentingNewLine]ys = \(YLinkedLoci /. \
{opts}\) /. Options[
                  ReferencePointMean], \[IndentingNewLine]zs = \(ZLinkedLoci /. \
{opts}\) /. Options[
                  ReferencePointMean], \[IndentingNewLine]ws = \(WLinkedLoci /. \
{opts}\) /. Options[
                  ReferencePointMean], \[IndentingNewLine]ps = \(PaternalLoci \
/. {opts}\) /. Options[
                  ReferencePointMean], \[IndentingNewLine]cs = \
\(CytoplasmicLoci /. {opts}\) /. 
                Options[ReferencePointMean], \[IndentingNewLine]X, Y, Z, W, 
            C, P, A, f}, \[IndentingNewLine]If[
            xs\[Vee]ys\[Vee]cs\[Vee]ps\[Vee]zs\[Vee]ws \[Equal] {}, \
\[IndentingNewLine]{\[WeierstrassP]\_\(i_\_{s, x___, ss_}\) \[RuleDelayed] 
                1\/2\ \((m[i\_{s, x, \[GothicCapitalF]}] + 
                      m[i\_{s, x, \[GothicCapitalM]}])\), \[IndentingNewLine]\
\[GothicCapitalD]\_{i_\_{s, x___, \[GothicCapitalM]}} \[RuleDelayed] 
                1\/2\ \((m[i\_{s, x, \[GothicCapitalM]}] - 
                      m[i\_{s, x, \[GothicCapitalF]}])\), \[IndentingNewLine]\
\[GothicCapitalD]\_{i_\_{s, x___, \[GothicCapitalF]}} \[RuleDelayed] 
                1\/2\ \((m[i\_{s, x, \[GothicCapitalF]}] - 
                      m[i\_{s, x, \[GothicCapitalM]}])\)}, \
\[IndentingNewLine]If[
              Length[xs\[Vee]ys] Length[zs\[Vee]ws] != 
                0, \[IndentingNewLine]Message[ReferencePointMean::ZWXYmix, 
                xs\[Vee]ys, zs\[Vee]ws]; {}, \[IndentingNewLine]If[
                Length[xs\[Vee]ys\[Vee]cs\[Vee]ps\[Vee]zs\[Vee]ws] \[Equal] 
                  Length[Union[
                      xs\[Vee]ys\[Vee]cs\[Vee]ps\[Vee]zs\[Vee]ws]], \
\[IndentingNewLine]f[g_] := 
                  If[MemberQ[xs, g], 
                    X, \[IndentingNewLine]If[MemberQ[ys, g], 
                      Y, \[IndentingNewLine]If[MemberQ[cs, g], 
                        C, \[IndentingNewLine]If[
                          MemberQ[ps, 
                            g], \[IndentingNewLine]P, \[IndentingNewLine]If[
                            MemberQ[zs, g], 
                            Z, \[IndentingNewLine]If[MemberQ[ws, g], W, 
                              
                              A]]]]]]; \
\[IndentingNewLine]{\[WeierstrassP]\_\(i_\_{s, x___, ss_}\) \[RuleDelayed] 
                    Switch[f[i], \[IndentingNewLine]A, 
                      1\/2\ \((m[i\_{s, x, \[GothicCapitalF]}] + 
                            m[i\_{s, x, \[GothicCapitalM]}])\), \
\[IndentingNewLine]X, 
                      If[ContextComponentQ[s, \ 
                          SexOfOrigin], \[IndentingNewLine]Switch[
                          Last[{x}], \[IndentingNewLine]\[GothicCapitalM], 
                          m[i\_{s, x, \[GothicCapitalF]}], \
\[IndentingNewLine]\[GothicCapitalF], 
                          1\/2\ \((m[i\_{s, x, \[GothicCapitalF]}] + 
                                m[i\_{s, x, \[GothicCapitalM]}])\), \
\[IndentingNewLine]_, Message[
                            ReferencePointMean::not\[GothicCapitalM]\
\[GothicCapitalF], \[WeierstrassP]\_\(i\_{s, x, ss}\)]; \
\[WeierstrassP]\_\(i\_{s, x, ss}\)], \[IndentingNewLine]1\/3\ \((2 
                                 m[i\_{s, x, \[GothicCapitalF]}] + 
                              m[i\_{s, x, \[GothicCapitalM]}])\)], \
\[IndentingNewLine]Z, 
                      If[ContextComponentQ[s, \ 
                          SexOfOrigin], \[IndentingNewLine]Switch[
                          Last[{x}], \[IndentingNewLine]\[GothicCapitalF], 
                          m[i\_{s, x, \[GothicCapitalM]}], \
\[IndentingNewLine]\[GothicCapitalM], 
                          1\/2\ \((m[i\_{s, x, \[GothicCapitalF]}] + 
                                m[i\_{s, x, \[GothicCapitalM]}])\), \
\[IndentingNewLine]_, Message[
                            ReferencePointMean::not\[GothicCapitalM]\
\[GothicCapitalF], \[WeierstrassP]\_\(i\_{s, x, ss}\)]; \
\[WeierstrassP]\_\(i\_{s, x, ss}\)], \[IndentingNewLine]1\/3\ \((m[
                                i\_{s, x, \[GothicCapitalF]}] + 
                              2  m[i\_{s, x, \[GothicCapitalM]}])\)], \
\[IndentingNewLine]Y, m[i\_{s, x, \[GothicCapitalM]}], W, 
                      m[i\_{s, x, \[GothicCapitalF]}], \[IndentingNewLine]P, 
                      m[i\_{s, x, \[GothicCapitalM]}], \[IndentingNewLine]C, 
                      m[i\_{s, x, \[GothicCapitalF]}]], \[IndentingNewLine]\
\[GothicCapitalD]\_{i_\_{s, x___, \[GothicCapitalM]}} \[RuleDelayed] 
                    Switch[f[i], \[IndentingNewLine]A, 
                      1\/2\ \((m[i\_{s, x, \[GothicCapitalM]}] - 
                            m[i\_{s, x, \[GothicCapitalF]}])\), \
\[IndentingNewLine]X, 
                      If[ContextComponentQ[s, \ 
                          SexOfOrigin], \[IndentingNewLine]Switch[
                          Last[{x}], \[IndentingNewLine]\[GothicCapitalM], 
                          Message[
                            ReferencePointMean::XlinkageClash, \
\[GothicCapitalD]\_{i\_{s, x, \[GothicCapitalM]}}]; \
\[GothicCapitalD]\_{i\_{s, x, \[GothicCapitalM]}}, \[IndentingNewLine]\
\[GothicCapitalF], 1\/2\ \((m[i\_{s, x, \[GothicCapitalM]}] - 
                                m[i\_{s, x, \[GothicCapitalF]}])\), \
\[IndentingNewLine]_, Message[
                            ReferencePointMean::not\[GothicCapitalM]\
\[GothicCapitalF], \[GothicCapitalD]\_{i\_{s, x, \[GothicCapitalM]}}]; \
\[GothicCapitalD]\_{i\_{s, x, \[GothicCapitalM]}}], \[IndentingNewLine]2\/3\ \
\((m[i\_{s, x, \[GothicCapitalM]}] - 
                              m[i\_{s, x, \[GothicCapitalF]}])\)], \
\[IndentingNewLine]Z, 
                      If[ContextComponentQ[s, \ 
                          SexOfOrigin], \[IndentingNewLine]Switch[
                          Last[{x}], \[IndentingNewLine]\[GothicCapitalF], 
                          0, \[IndentingNewLine]\[GothicCapitalM], 
                          1\/2\ \((m[i\_{s, x, \[GothicCapitalM]}] - 
                                m[i\_{s, x, \[GothicCapitalF]}])\), \
\[IndentingNewLine]_, Message[
                            ReferencePointMean::not\[GothicCapitalM]\
\[GothicCapitalF], \[GothicCapitalD]\_{i\_{s, x, \[GothicCapitalM]}}]; \
\[GothicCapitalD]\_{i\_{s, x, \[GothicCapitalM]}}], \[IndentingNewLine]1\/3\ \
\((m[i\_{s, x, \[GothicCapitalM]}] - 
                              m[i\_{s, x, \[GothicCapitalF]}])\)], \
\[IndentingNewLine]Y, 0, \[IndentingNewLine]W, 
                      Message[
                        ReferencePointMean::WlinkageClash, \
\[GothicCapitalD]\_{i\_{s, x, \[GothicCapitalM]}}]; \
\[GothicCapitalD]\_{i\_{s, x, \[GothicCapitalM]}}, \[IndentingNewLine]C, 
                      Message[
                        ReferencePointMean::CytoplasmicClash, \
\[GothicCapitalD]\_{i\_{s, x, \[GothicCapitalM]}}]; \
\[GothicCapitalD]\_{i\_{s, x, \[GothicCapitalM]}}, \[IndentingNewLine]P, 
                      0], \[IndentingNewLine]\[GothicCapitalD]\_{i_\_{s, \
x___, \[GothicCapitalF]}} \[RuleDelayed] 
                    Switch[f[i], \[IndentingNewLine]A, 
                      1\/2\ \((m[i\_{s, x, \[GothicCapitalF]}] - 
                            m[i\_{s, x, \[GothicCapitalM]}])\), \
\[IndentingNewLine]X, 
                      If[ContextComponentQ[s, \ 
                          SexOfOrigin], \[IndentingNewLine]Switch[
                          Last[{x}], \[IndentingNewLine]\[GothicCapitalM], 
                          0, \[IndentingNewLine]\[GothicCapitalF], 
                          1\/2\ \((m[i\_{s, x, \[GothicCapitalF]}] - 
                                m[i\_{s, x, \[GothicCapitalM]}])\), \
\[IndentingNewLine]_, Message[
                            ReferencePointMean::not\[GothicCapitalM]\
\[GothicCapitalF], \[GothicCapitalD]\_{i\_{s, x, \[GothicCapitalF]}}]; \
\[GothicCapitalD]\_{i\_{s, x, \[GothicCapitalF]}}], \[IndentingNewLine]1\/3\ \
\((m[i\_{s, x, \[GothicCapitalF]}] - 
                              m[i\_{s, x, \[GothicCapitalM]}])\)], \
\[IndentingNewLine]Z, 
                      If[ContextComponentQ[s, \ 
                          SexOfOrigin], \[IndentingNewLine]Switch[
                          Last[{x}], \[IndentingNewLine]\[GothicCapitalF], 
                          Message[
                            ReferencePointMean::ZlinkageClash, \
\[GothicCapitalD]\_{i\_{s, x, \[GothicCapitalF]}}]; \
\[GothicCapitalD]\_{i\_{s, x, \[GothicCapitalF]}}, \[IndentingNewLine]\
\[GothicCapitalM], 1\/2\ \((m[i\_{s, x, \[GothicCapitalF]}] - 
                                m[i\_{s, x, \[GothicCapitalM]}])\), \
\[IndentingNewLine]_, Message[
                            ReferencePointMean::not\[GothicCapitalM]\
\[GothicCapitalF], \[GothicCapitalD]\_{i\_{s, x, \[GothicCapitalF]}}]; \
\[GothicCapitalD]\_{i\_{s, x, \[GothicCapitalF]}}], \[IndentingNewLine]2\/3\ \
\((m[i\_{s, x, \[GothicCapitalF]}] - 
                              m[i\_{s, x, \[GothicCapitalM]}])\)], \
\[IndentingNewLine]Y, 
                      Message[
                        ReferencePointMean::YlinkageClash, \
\[GothicCapitalD]\_{i\_{s, x, \[GothicCapitalF]}}]; \
\[GothicCapitalD]\_{i\_{s, x, \[GothicCapitalF]}}, \[IndentingNewLine]W, 
                      0, \[IndentingNewLine]C, 0, \[IndentingNewLine]P, 
                      Message[
                        ReferencePointMean::PaternalClash, \
\[GothicCapitalD]\_{i\_{s, x, \[GothicCapitalF]}}]; \
\[GothicCapitalD]\_{i\_{s, x, \[GothicCapitalF]}}]}, \
\[IndentingNewLine]Message[ReferencePointMean::lociOverlap, cs, ps, xs, ys, 
                  zs, ws]; {}]]]];\)\)}], "Input",
  InitializationCell->True],

Cell[BoxData[{
    \(\(ReferencePointMean[sl : {_?ContextStageQ ... }, opts___Rule] := 
        ReferencePointMean[sl, MeanContribution, 
          opts];\)\), "\[IndentingNewLine]", 
    \(\(ReferencePointMean[sl : {_?ContextStageQ ... }, m_, opts___Rule] := 
        Flatten[\(ReferencePointMean[#, m, opts] &\) /@ sl];\)\)}], "Input",
  InitializationCell->True,
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell["MaternalLoci", "Subsubsection"],

Cell[BoxData[
    \(\(MaternalLoci = CytoplasmicLoci;\)\)], "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{

Cell["NonMendelian", "Subsubsection"],

Cell[BoxData[
    \(\(Options[NonMendelian] = {CytoplasmicLoci \[Rule] {}, 
          PaternalLoci \[Rule] {}, XLinkedLoci \[Rule] {}, 
          YLinkedLoci \[Rule] {}, ZLinkedLoci \[Rule] {}, 
          WLinkedLoci \[Rule] {}};\)\)], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(\(NonMendelian::lociOverlap = "\<Overlapping sets of genes specified: \
C: `1`,P: `2`, X: `3`, Y: `4`, Z: `5`, W: `6`\>";\)\)], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(\(NonMendelian::ZWXYmix = "\<Cannot specify both XY linkage and ZW \
linkage: `1`, `2`\>";\)\)], "Input",
  InitializationCell->True,
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    \(\(NonMendelian::YlinkageClash = "\<A Y-linked gene cannot be in a \
female gamete or derive from the mother: `1`\>";\)\)], "Input",
  InitializationCell->True,
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    \(\(NonMendelian::WlinkageClash = "\<A W-linked gene cannot be in a male \
gamete or derive from the father: `1`\>";\)\)], "Input",
  InitializationCell->True,
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    \(\(NonMendelian::CytoplasmicClash = "\<A cytoplasmically inherited gene \
cannot be in a male gamete or derive from the father: `1`\>";\)\)], "Input",
  InitializationCell->True,
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    \(\(NonMendelian::PaternalClash = "\<A paternally inherited gene cannot \
be in a female gamete or derive from the mother: `1`\>";\)\)], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(\(NonMendelian::noSex = "\<Sex must be specified with X- or Z-linkage: \
`1`\>";\)\)], "Input",
  InitializationCell->True,
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[{
    \(\(NonMendelian[XLinkedLoci, _List, 0] = 0;\)\), "\[IndentingNewLine]", 
    \(\(NonMendelian[XLinkedLoci, {}, {c___, A_List, B_List}] = {c, A, 
          B};\)\), "\[IndentingNewLine]", 
    \(\(NonMendelian[XLinkedLoci, xs_List, {c___, A_List, B_List}] := 
        If[{c} \[Equal] {}, 
          Message[NonMendelian::noSex, \[GothicR]\_\(c, A, B\)]; {c, A, B}, 
          Switch[Last[{c}], \[GothicCapitalM], 
            If[Intersection[B, xs] \[Equal] {}, {c, Complement[A, xs], B}, 
              0], \[GothicCapitalF], {c, A, B}, _, 
            Message[NonMendelian::noSex, \[GothicR]\_\(c, A, B\)]; {c, A, 
              B}]];\)\)}], "Input",
  InitializationCell->True,
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[{
    \(\(NonMendelian[ZLinkedLoci, _List, 0] = 0;\)\), "\[IndentingNewLine]", 
    \(\(NonMendelian[ZLinkedLoci, {}, {c___, A_List, B_List}] = {c, A, 
          B};\)\), "\[IndentingNewLine]", 
    \(\(NonMendelian[ZLinkedLoci, zs_List, {c___, A_List, B_List}] := 
        If[{c} \[Equal] {}, 
          Message[NonMendelian::noSex, \[GothicR]\_\(c, A, B\)]; {c, A, B}, 
          Switch[Last[{c}], \[GothicCapitalF], 
            If[Intersection[A, zs] \[Equal] {}, {c, A, Complement[B, zs]}, 
              0], \[GothicCapitalM], {c, A, B}, _, 
            Message[NonMendelian::noSex, \[GothicR]\_\(c, A, B\)]; {c, A, 
              B}]];\)\)}], "Input",
  InitializationCell->True,
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[{
    \(\(NonMendelian[CytoplasmicLoci, _List, 0] = 
        0;\)\), "\[IndentingNewLine]", 
    \(\(NonMendelian[CytoplasmicLoci, {}, {c___, A_List, B_List}] = {c, A, 
          B};\)\), "\[IndentingNewLine]", 
    \(\(NonMendelian[CytoplasmicLoci, 
          cs_List, {c___, A_List, B_List}] := \((If[{c} \[NotEqual] {}, 
            If[Last[{c}] === \[GothicCapitalM], 
              If[Intersection[A\[Vee]B, cs] \[NotEqual] {}, 
                Message[NonMendelian::CytoplasmicClash, 0]]]]; 
          If[Intersection[B, cs] \[Equal] {}, 
            If[Intersection[A, cs] \[Equal] {}, {c, A, B}, {c, 
                Complement[A, cs], B}], 0])\);\)\)}], "Input",
  InitializationCell->True,
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[{
    \(\(NonMendelian[PaternalLoci, _List, 0] = 
        0;\)\), "\[IndentingNewLine]", 
    \(\(NonMendelian[PaternalLoci, {}, {c___, A_List, B_List}] = {c, A, 
          B};\)\), "\[IndentingNewLine]", 
    \(\(NonMendelian[PaternalLoci, 
          cs_List, {c___, A_List, B_List}] := \((If[{c} \[NotEqual] {}, 
            If[Last[{c}] === \[GothicCapitalF], 
              If[Intersection[A\[Vee]B, cs] \[NotEqual] {}, 
                Message[NonMendelian::PaternalClash, 0]]]]; 
          If[Intersection[A, cs] \[Equal] {}, 
            If[Intersection[B, cs] \[Equal] {}, {c, A, B}, {c, A, 
                Complement[B, cs]}], 0])\);\)\)}], "Input",
  InitializationCell->True],

Cell[BoxData[{
    \(\(NonMendelian[YLinkedLoci, _List, 0] = 0;\)\), "\[IndentingNewLine]", 
    \(\(NonMendelian[YLinkedLoci, {}, {c___, A_List, B_List}] = {c, A, 
          B};\)\), "\[IndentingNewLine]", 
    \(\(NonMendelian[YLinkedLoci, 
          ys_List, {c___, A_List, B_List}] := \((If[{c} \[NotEqual] {}, 
            If[Last[{c}] === \[GothicCapitalF], 
              If[Intersection[A\[Vee]B, ys] \[NotEqual] {}, 
                Message[
                  NonMendelian::YlinkageClash, \[GothicR]\_\(c, A, B\)]]]]; 
          If[Intersection[A, ys] \[Equal] {}, 
            If[Intersection[B, ys] \[Equal] {}, {c, A, B}, {c, A, 
                Complement[B, ys]}], 0])\);\)\)}], "Input",
  InitializationCell->True,
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[{
    \(\(NonMendelian[WLinkedLoci, _List, 0] = 0;\)\), "\[IndentingNewLine]", 
    \(\(NonMendelian[WLinkedLoci, {}, {c___, A_List, B_List}] = {c, A, 
          B};\)\), "\[IndentingNewLine]", 
    \(\(NonMendelian[WLinkedLoci, 
          ws_List, {c___, A_List, B_List}] := \((If[{c} \[NotEqual] {}, 
            If[Last[{c}] === \[GothicCapitalM], 
              If[Intersection[A\[Vee]B, ws] \[NotEqual] {}, 
                Message[
                  NonMendelian::WlinkageClash, \[GothicR]\_\(c, A, B\)]]]]; 
          If[Intersection[B, ws] \[Equal] {}, 
            If[Intersection[A, ws] \[Equal] {}, {c, A, B}, {c, 
                Complement[A, ws], B}], 0])\);\)\)}], "Input",
  InitializationCell->True,
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[{
    \(\(NonMendelian[opts___Rule] := 
        NonMendelian[RecombinationRate, opts];\)\), "\[IndentingNewLine]", 
    \(\(NonMendelian[r_, opts___Rule] := 
        Module[{xs = \(XLinkedLoci /. {opts}\) /. Options[NonMendelian], 
            ys = \(YLinkedLoci /. {opts}\) /. Options[NonMendelian], 
            zs = \(ZLinkedLoci /. {opts}\) /. Options[NonMendelian], 
            ws = \(WLinkedLoci /. {opts}\) /. Options[NonMendelian], 
            ps = \(PaternalLoci /. {opts}\) /. Options[NonMendelian], 
            cs = \(CytoplasmicLoci /. {opts}\) /. 
                Options[NonMendelian]}, \[IndentingNewLine]tt = 
            xs\[Vee]ys\[Vee]cs\[Vee]ps\[Vee]zs\[Vee]ws; \[IndentingNewLine]If[
            Length[xs\[Vee]ys] Length[zs\[Vee]ws] \[NotEqual] 
              0, \[IndentingNewLine]Message[NonMendelian::ZWXYmix, 
              xs\[Vee]ys, zs\[Vee]ws]; {}, 
            If[Not[Length[tt] \[Equal] Length[Union[tt]]], 
              Message[NonMendelian::lociOverlap, cs, ps, xs, ys, zs, ws]; {}, 
              If[tt \[Equal] {}, {}, {\(r[c___, A_List, 
                        B_List]\)?\((\((Intersection[
                                  tt, #\[LeftDoubleBracket]\(-2\)\
\[RightDoubleBracket]\[Vee]#\[LeftDoubleBracket]\(-1\)\[RightDoubleBracket]] \
\[NotEqual] {} && If[Length[#] \[Equal] 2, True, 
                                Not[Intersection[
                                        Complement[#\[LeftDoubleBracket]\(-2\)\
\[RightDoubleBracket]\[Vee]#\[LeftDoubleBracket]\(-1\)\[RightDoubleBracket], 
                                        xs], 
                                        tt] \[Equal] {} && #\
\[LeftDoubleBracket]\(-3\)\[RightDoubleBracket] === \[GothicCapitalF]]] && 
                              If[Length[#] \[Equal] 2, True, 
                                Not[Intersection[
                                        Complement[#\[LeftDoubleBracket]\(-2\)\
\[RightDoubleBracket]\[Vee]#\[LeftDoubleBracket]\(-1\)\[RightDoubleBracket], 
                                        zs], 
                                        tt] \[Equal] {} && #\
\[LeftDoubleBracket]\(-3\)\[RightDoubleBracket] === \[GothicCapitalM]]])\) &)\
\) \[RuleDelayed] r @@ NonMendelian[XLinkedLoci, 
                        xs, \[IndentingNewLine]NonMendelian[ZLinkedLoci, 
                          zs, \[IndentingNewLine]NonMendelian[YLinkedLoci, 
                            ys, \[IndentingNewLine]NonMendelian[WLinkedLoci, 
                              ws, \[IndentingNewLine]NonMendelian[
                                PaternalLoci, 
                                ps, \[IndentingNewLine]NonMendelian[
                                  CytoplasmicLoci, 
                                  cs, {c, A, B}]]]]]]}]]]];\)\)}], "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{

Cell["ReferencePointSame", "Subsubsection"],

Cell[BoxData[{
    \(\(ReferencePointSame[s1_?ContextStageQ, s2_?ContextStageQ] := 
        If[ContextComponentQ[s2, 
            SexOfOrigin], \[IndentingNewLine]{\[WeierstrassP]\_\(i_\_{s2, \
x___, sex_, soo_}\) \[RuleDelayed] \[WeierstrassP]\_\(i\_{s1, x, soo}\)}, \
\[IndentingNewLine]{\[WeierstrassP]\_\(i_\_{s2, x___, sex_}\) \[RuleDelayed] \
\[WeierstrassP]\_\(i\_{s1, x, sex}\)}];\)\), "\[IndentingNewLine]", 
    \(\(ReferencePointSame[s1_?ContextStageQ, sl : {_?ContextStageQ ... }] := 
        Flatten[\(ReferencePointSame[s1, #] &\) /@ sl];\)\)}], "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{

Cell["RandomUnion", "Subsubsection"],

Cell[BoxData[
    \(RandomUnion[s_?ContextStageQ] := RandomUnion[s, {Sex}]; 
    RandomUnion[s_?ContextStageQ, cl_List] := 
      Module[{cc}, {\[GothicCapitalD]\_\(\[DoubleStruckCapitalU] : {_\_{s, \
__} ... }\)?\((\((Length[
                        Union[\[Chi]\_cl[#\[LeftDoubleBracket]1\
\[RightDoubleBracket]]]] > 
                      1)\) &)\) \[RuleDelayed] \((cc = \[Chi]\_cl[\
\[DoubleStruckCapitalU]]; 
              Times @@ \((\(\[GothicCapitalD]\_# &\) /@ \((\(Extract[\
\[DoubleStruckCapitalU], Position[cc, #]] &\) /@ 
                        Union[cc])\))\))\)}];\)], "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{

Cell["Selfing", "Subsubsection"],

Cell[BoxData[
    \(\(Selfing::badSelfingRate = "\<Selfing rate `1` is invalid.\>";\)\)], \
"Input",
  InitializationCell->True],

Cell[BoxData[{
    \(\(Selfing[] := 
        Selfing[{{\[GothicCapitalJ], \[GothicCapitalH]}, \[GothicCapitalA]}, 
          1];\)\), "\[IndentingNewLine]", 
    \(\(Selfing[{{s1o_?ContextStageQ, s1s_?ContextStageQ}, 
            s2_?ContextStageQ}] := 
        Selfing[{{s1o, s1s}, s2}, 1];\)\), "\[IndentingNewLine]", 
    \(\(Selfing[s_?\((Not[ListQ[#]] &)\)] := 
        Selfing[{{\[GothicCapitalJ], \[GothicCapitalH]}, \[GothicCapitalA]}, 
          s];\)\), "\[IndentingNewLine]", 
    \(\(Selfing[{{s1o_?ContextStageQ, s1s_?ContextStageQ}, 
            s2_?ContextStageQ}, s_] := 
        Module[{cc}, 
          If[\((s \[Equal] 0)\) === 
              True, {}, \[IndentingNewLine]If[\((s < 0 \[Or] s > 1)\) === 
                True, \[IndentingNewLine]Message[Selfing::badSelfingRate, 
                s]; {}, \[IndentingNewLine]{\[GothicCapitalD]\_\(\
\[DoubleStruckCapitalU] : {_\_{s2, __} ... }\) \[RuleDelayed] \((1 - 
                          s)\) \((\[GothicCapitalD]\_\[DoubleStruckCapitalU]\
\[CirclePlus]\(({s2, x___} \[LeftArrow] {s1o, x})\))\) + 
                    s \((\[GothicCapitalD]\_\[DoubleStruckCapitalU]\
\[CirclePlus]\(({s2, x___, sex_, soo_} \[LeftArrow] {s1s, x, 
                                soo})\))\), \[GothicM]\_\(\[DoubleStruckI] : \
_\_{s2, __}\) \[RuleDelayed] \((1 - 
                          s)\) \((\[GothicM]\_\[DoubleStruckI]\[CirclePlus]\((\
{s2, x___} \[LeftArrow] {s1o, x})\))\) + 
                    s \((\[GothicM]\_\[DoubleStruckI]\[CirclePlus]\(({s2, 
                                x___, sex_, soo_} \[LeftArrow] {s1s, x, 
                                soo})\))\)}]]];\)\)}], "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{

Cell["FitnessSet", "Subsubsection"],

Cell[BoxData[
    RowBox[{
      RowBox[{"Notation", "[", 
        RowBox[{
          TagBox[\(\[DoubleStruckCapitalW]\_x___\),
            NotationBoxTag,
            TagStyle->"NotationTemplateStyle"], " ", 
          "\[DoubleLongLeftRightArrow]", " ", 
          TagBox[\(FitnessSet[x___]\),
            NotationBoxTag,
            TagStyle->"NotationTemplateStyle"]}], "]"}], ";"}]], "Input",
  InitializationCell->True,
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell["RecombinationSet", "Subsubsection"],

Cell[BoxData[
    RowBox[{
      RowBox[{"Notation", "[", 
        RowBox[{
          TagBox[\(\[DoubleStruckCapitalR]\_x___\),
            NotationBoxTag,
            TagStyle->"NotationTemplateStyle"], " ", 
          "\[DoubleLongLeftRightArrow]", " ", 
          TagBox[\(RecombinationSet[x___]\),
            NotationBoxTag,
            TagStyle->"NotationTemplateStyle"]}], "]"}], ";"}]], "Input",
  InitializationCell->True,
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell["MigrationSet", "Subsubsection"],

Cell[BoxData[
    RowBox[{
      RowBox[{"Notation", "[", 
        RowBox[{
          TagBox[\(\[DoubleStruckCapitalM]\_x___\),
            NotationBoxTag,
            TagStyle->"NotationTemplateStyle"], " ", 
          "\[DoubleLongLeftRightArrow]", " ", 
          TagBox[\(MigrationSet[x___]\),
            NotationBoxTag,
            TagStyle->"NotationTemplateStyle"]}], "]"}], ";"}]], "Input",
  InitializationCell->True,
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell["Selection", "Subsubsection"],

Cell[BoxData[
    \(\(Selection[] := 
        Selection[{\[GothicCapitalZ], \[GothicCapitalA]}, 
          SelectionCoefficient, \[DoubleStruckCapitalW]];\)\)], "Input",
  InitializationCell->True,
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    \(\(Selection[{s1_?ContextStageQ, s2_?ContextStageQ}, a_, 
          w_] := {\[GothicCapitalD]\_\(\[DoubleStruckCapitalU] : {_\_{s2, \
___} ... }\) \[RuleDelayed] 
            Module[{\[DoubleStruckCapitalZ] = \[DoubleStruckCapitalU]\
\[CirclePlus]{{s2, x__} \[LeftArrow] {s1, 
                          x}}, \[DoubleStruckCapitalV]}, \((\[GothicCapitalD]\
\_\[DoubleStruckCapitalZ] + \[Sum]\+\(\[DoubleStruckCapitalV] \[SubsetEqual] \
w\)a[\[DoubleStruckCapitalV]] \((\[GothicCapitalD]\_\(\[DoubleStruckCapitalZ]\
\[Vee]\[DoubleStruckCapitalV]\) - \
\(\[GothicCapitalD]\_\[DoubleStruckCapitalZ]\) \[GothicCapitalD]\_\
\[DoubleStruckCapitalV])\))\)], \[GothicM]\_\(i_\_{s2, x___}\) \[RuleDelayed] 
            Module[{\[DoubleStruckCapitalV], ss}, 
              ss = Union[
                  Sort /@ Subsets[
                      w]]; \((\[WeierstrassP]\_\(i\_{s1, x}\) + \
\[GothicCapitalD]\_{i\_{s1, x}} + \[Sum]\+\(\[DoubleStruckCapitalV] \
\[Element] ss\)a[\[DoubleStruckCapitalV]] \((\[GothicCapitalD]\_\({i\_{s1, \
x}}\[Vee]\[DoubleStruckCapitalV]\) - \(\[GothicCapitalD]\_{i\_{s1, x}}\) \
\[GothicCapitalD]\_\[DoubleStruckCapitalV])\))\)]};\)\)], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(\(Selection[cl_List] := 
        Selection[{\[GothicCapitalZ], \[GothicCapitalA]}, 
          SelectionCoefficient, FitnessSet, cl];\)\)], "Input",
  InitializationCell->True,
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    \(\(Selection[{s1_?ContextStageQ, s2_?ContextStageQ}, a_, w_, 
          cl_List] := {\[GothicCapitalD]\_\(\[DoubleStruckCapitalU] : \
{_\_{s2, ___} ... }\) \[RuleDelayed] 
            Module[{\[DoubleStruckCapitalZ] = \[DoubleStruckCapitalU]\
\[CirclePlus]{{s2, x__} \[LeftArrow] {s1, x}}, \[DoubleStruckCapitalV], 
                cc = Union[\[Chi]\_cl[\[DoubleStruckCapitalU]]]}, \
\[IndentingNewLine]If[Length[cc] > 1, 
                Message[Selection::mix, \[DoubleStruckCapitalU], 
                  cl, {s1, s2}, a, 
                  w]; \[GothicCapitalD]\_\[DoubleStruckCapitalU], \((\
\[GothicCapitalD]\_\[DoubleStruckCapitalZ] + \
\[Sum]\+\(\[DoubleStruckCapitalV] \[SubsetEqual] \((w @@ cc\
\[LeftDoubleBracket]1\[RightDoubleBracket])\)\)\((a @@ \((cc\
\[LeftDoubleBracket]1\[RightDoubleBracket]\[Vee]{\[DoubleStruckCapitalV]})\))\
\) \((\[GothicCapitalD]\_\(\[DoubleStruckCapitalZ]\[Vee]\
\[DoubleStruckCapitalV]\) - \(\[GothicCapitalD]\_\[DoubleStruckCapitalZ]\) \
\[GothicCapitalD]\_\[DoubleStruckCapitalV])\))\)]], \[GothicM]\_\(i_\_{s2, \
x___}\) \[RuleDelayed] 
            Module[{\[DoubleStruckCapitalV], 
                cc = Union[\[Chi]\_cl[{i\_{s2, x}}]]}, 
              If[Length[cc] > 1, 
                Message[Selection::mix, {i\_{s2, x}}, cl, {s1, s2}, a, 
                  w]; \[GothicM]\_\(i\_{s2, x}\), 
                ss = Union[
                    Sort /@ Subsets[
                        w @@ cc\[LeftDoubleBracket]1\[RightDoubleBracket]]]; \
\[IndentingNewLine]\((\[WeierstrassP]\_\(i\_{s1, x}\) + \[GothicCapitalD]\_{i\
\_{s1, x}} + \[Sum]\+\(\[DoubleStruckCapitalV] \[Element] ss\)\((a @@ \((cc\
\[LeftDoubleBracket]1\[RightDoubleBracket]\[Vee]{\[DoubleStruckCapitalV]})\))\
\) \((\[GothicCapitalD]\_\({i\_{s1, x}}\[Vee]\[DoubleStruckCapitalV]\) - \(\
\[GothicCapitalD]\_{i\_{s1, x}}\) \[GothicCapitalD]\_\[DoubleStruckCapitalV])\
\))\)]]};\)\)], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(\(Selection::mix = \*"\"\<Mixed contexts in \
\!\(\[GothicCapitalD]\_`1`\)/.Selection[`3`,`4`,`5`,`2`]: the relevant \
components `2` must be the same for all genes.\>\"";\)\)], "Input",
  InitializationCell->True,
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Open  ]],

Cell[CellGroupData[{

Cell["Recombination", "Subsubsection"],

Cell[BoxData[{
    \(\(Recombination[] := 
        Recombination[{\[GothicCapitalA], \(\[GothicCapitalG]\^*\)}, 
          RecombinationRate];\)\), "\[IndentingNewLine]", 
    \(\(Recombination[cl_List] := 
        Recombination[{\[GothicCapitalA], \(\[GothicCapitalG]\^*\)}, 
          RecombinationRate, cl];\)\)}], "Input",
  InitializationCell->True,
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    \(\(Recombination[{s1_?ContextStageQ, s2_?ContextStageQ}, 
          r_] := {\[GothicCapitalD]\_\(\[DoubleStruckCapitalU] : {_\_{s2, __} \
... }\) \[RuleDelayed] 
            Module[{A\[GothicCapitalM], 
                A\[GothicCapitalF], \[DoubleStruckCapitalU]\[GothicCapitalM] \
= \[DoubleStruckCapitalU]\(\[CircleDot]\_Sex\){\[GothicCapitalM]}, \
\[DoubleStruckCapitalU]\[GothicCapitalF] = \[DoubleStruckCapitalU]\(\
\[CircleDot]\_Sex\){\[GothicCapitalF]}}, \[Sum]\+\(A\[GothicCapitalM] \
\[SubsetEqual] \[Gamma][\[DoubleStruckCapitalU]\[GothicCapitalM]]\)\(\[Sum]\+\
\(A\[GothicCapitalF] \[SubsetEqual] \[Gamma][\[DoubleStruckCapitalU]\
\[GothicCapitalF]]\)\((\((\[GothicCapitalD]\_\[DoubleStruckCapitalU]\
\[CirclePlus]Meiosis[{s1, s2}, 
                            A\[GothicCapitalM]\[Vee]A\[GothicCapitalF], \((\
\[Gamma][\[DoubleStruckCapitalU]\[GothicCapitalM]]\[Backslash]
                                  A\[GothicCapitalM])\)\[Vee]\((\[Gamma][\
\[DoubleStruckCapitalU]\[GothicCapitalF]]\[Backslash]
                                  A\[GothicCapitalF])\)])\) 
                      r[A\[GothicCapitalM], \[Gamma][\[DoubleStruckCapitalU]\
\[GothicCapitalM]]\[Backslash]A\[GothicCapitalM]] 
                      r[A\[GothicCapitalF], \[Gamma][\[DoubleStruckCapitalU]\
\[GothicCapitalF]]\[Backslash]
                          A\[GothicCapitalF]])\)\)], \[GothicM]\_\(i_\_{s2, \
x__}\) \[RuleDelayed] \((\((\[GothicM]\_\(i\_{s2, \
x}\)\[CirclePlus]Meiosis[{s1, s2}, {i}, {}])\) 
                  r[{i}, {}] + \((\[GothicM]\_\(i\_{s2, \
x}\)\[CirclePlus]Meiosis[{s1, s2}, {}, {i}])\) r[{}, {i}])\)};\)\)], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(\(Recombination[{s1_?ContextStageQ, s2_?ContextStageQ}, r_, 
          cl_List] := {\[GothicCapitalD]\_\(\[DoubleStruckCapitalU] : \
{_\_{s2, __} ... }\) \[RuleDelayed] 
            Module[{A\[GothicCapitalM], 
                A\[GothicCapitalF], \[DoubleStruckCapitalU]\[GothicCapitalM] \
= \[DoubleStruckCapitalU]\(\[CircleDot]\_Sex\){\[GothicCapitalM]}, \
\[DoubleStruckCapitalU]\[GothicCapitalF] = \[DoubleStruckCapitalU]\(\
\[CircleDot]\_Sex\){\[GothicCapitalF]}, cc\[GothicCapitalM], 
                cc\[GothicCapitalF]}, 
              cc\[GothicCapitalM] = 
                Union[\[Chi]\_cl[\[DoubleStruckCapitalU]\[GothicCapitalM]]]; 
              cc\[GothicCapitalF] = 
                Union[\[Chi]\_cl[\[DoubleStruckCapitalU]\[GothicCapitalF]]]; 
              If[\((Length[cc\[GothicCapitalM]] > 
                      1)\) \[Or] \((Length[cc\[GothicCapitalF]] > 1)\), 
                Message[Recombination::mix, {s1, s2}, r, 
                  cl, \[DoubleStruckCapitalU]]; \[GothicCapitalD]\_\
\[DoubleStruckCapitalU], 
                cc\[GothicCapitalM] = 
                  If[cc\[GothicCapitalM] === {}, {}, 
                    First[cc\[GothicCapitalM]]]; 
                cc\[GothicCapitalF] = 
                  If[cc\[GothicCapitalF] === {}, {}, 
                    First[cc\[GothicCapitalF]]]; \[Sum]\+\(A\[GothicCapitalM] \
\[SubsetEqual] \[Gamma][\[DoubleStruckCapitalU]\[GothicCapitalM]]\)\(\[Sum]\+\
\(A\[GothicCapitalF] \[SubsetEqual] \[Gamma][\[DoubleStruckCapitalU]\
\[GothicCapitalF]]\)\((\((\[GothicCapitalD]\_\[DoubleStruckCapitalU]\
\[CirclePlus]Meiosis[{s1, s2}, 
                              A\[GothicCapitalM]\[Vee]A\[GothicCapitalF], \((\
\[Gamma][\[DoubleStruckCapitalU]\[GothicCapitalM]]\[Backslash]
                                    A\[GothicCapitalM])\)\[Vee]\((\[Gamma][\
\[DoubleStruckCapitalU]\[GothicCapitalF]]\[Backslash]
                                    A\[GothicCapitalF])\)])\) \((\(r[##, 
                                A\[GothicCapitalM], \[Gamma][\
\[DoubleStruckCapitalU]\[GothicCapitalM]]\[Backslash]A\[GothicCapitalM]] &\) @@ 
                            cc\[GothicCapitalM])\) \((\(r[##, 
                                A\[GothicCapitalF], \[Gamma][\
\[DoubleStruckCapitalU]\[GothicCapitalF]]\[Backslash]A\[GothicCapitalF]] &\) @@ 
                            cc\[GothicCapitalF])\))\)\)]], \
\[GothicM]\_\(i_\_{s2, x__}\) \[RuleDelayed] 
            Module[{cc = Union[\[Chi]\_cl[{i\_{s2, x}}]]}, 
              If[Length[cc] > 1, 
                Message[Recombination::mix, {s1, s2}, r, 
                  cl, \[DoubleStruckCapitalU]]; \[GothicM]\_\(i\_{s2, x}\), \
\((\((\[GothicM]\_\(i\_{s2, x}\)\[CirclePlus]Meiosis[{s1, 
                              s2}, {i}, {}])\) \((\(r[##, {i}, {}] &\) @@ 
                          cc\[LeftDoubleBracket]1\[RightDoubleBracket])\) + \
\((\((\[GothicM]\_\(i\_{s2, x}\)\[CirclePlus]Meiosis[{s1, 
                                s2}, {}, {i}])\) \((\(r[##, {}, {i}] &\) @@ 
                            cc\[LeftDoubleBracket]1\[RightDoubleBracket])\))\)\
)\)]]};\)\)], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(\(Recombination::mix = \*"\"\<Mixed contexts in \
\!\(\[GothicCapitalD]\_`4`\)/.Recombination[`1`,`2`,`3`]: the relevant \
components `3` must be the same for all genes.\>\"";\)\)], "Input",
  InitializationCell->True,
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    RowBox[{
      RowBox[{"Notation", "[", 
        RowBox[{
          TagBox[\(\[GothicA]\_x__\),
            NotationBoxTag,
            TagStyle->"NotationTemplateStyle"], " ", 
          "\[DoubleLongLeftRightArrow]", " ", 
          TagBox[\(SelectionCoefficient[x__]\),
            NotationBoxTag,
            TagStyle->"NotationTemplateStyle"]}], "]"}], ";"}]], "Input",
  InitializationCell->True,
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell["UnlinkedRecombination", "Subsubsection"],

Cell[BoxData[
    \(\(UnlinkedRecombination[A_List, B_List] := 
        2\^\(\(-Length[A]\) - Length[B]\);\)\)], "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{

Cell["LinkedRecombination", "Subsubsection"],

Cell[BoxData[
    \(\(LinkedRecombination::badLoci = \*"\"\<Order of the loci in \!\(\
\[GothicR]\_\(`1`, \\\\\\\ `2`\)\) is not specified by `3`\>\"";\)\)], "Input",\

  InitializationCell->True],

Cell[BoxData[
    \(\(LinkedRecombination[A_List, B_List, ord_List, 
          c_] := \[IndentingNewLine]Module[{oab}, \[IndentingNewLine]If[
            Complement[A\[Vee]B, ord] === {}, \[IndentingNewLine]oab = 
              ord\[Backslash]Complement[ord, 
                  A\[Vee]B]; \[IndentingNewLine]Times @@ 
                Replace[
                  Drop[Transpose[{oab, RotateLeft[oab]}], \(-1\)], {{i_, 
                        j_} \[RuleDelayed] 
                      If[Xor[MemberQ[A, i], MemberQ[A, j]], c[i, j], 
                        1 - c[i, j]]}, {1}]/2, 
            Message[LinkedRecombination::badLoci, A, B, ord]; 
            Indeterminate]];\)\)], "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{

Cell["RecombinationRate", "Subsubsection"],

Cell[BoxData[
    \(\(RecombinationRate[___, {}, {}] = 1;\)\)], "Input",
  InitializationCell->True,
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    RowBox[{
      RowBox[{"Notation", "[", 
        RowBox[{
          TagBox[\(\[GothicR]\_x__\),
            NotationBoxTag,
            TagStyle->"NotationTemplateStyle"], " ", 
          "\[DoubleLongLeftRightArrow]", " ", 
          TagBox[\(RecombinationRate[x__]\),
            NotationBoxTag,
            TagStyle->"NotationTemplateStyle"]}], "]"}], ";"}]], "Input",
  InitializationCell->True,
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell["MigrationRate", "Subsubsection"],

Cell[BoxData[
    RowBox[{
      RowBox[{"Notation", "[", 
        RowBox[{
          TagBox[\(\[CapitalMu]\_x__\),
            NotationBoxTag,
            TagStyle->"NotationTemplateStyle"], " ", 
          "\[DoubleLongLeftRightArrow]", " ", 
          TagBox[\(MigrationRate[x__]\),
            NotationBoxTag,
            TagStyle->"NotationTemplateStyle"]}], "]"}], ";"}]], "Input",
  InitializationCell->True,
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell["Migration", "Subsubsection"],

Cell[BoxData[
    \(\(Migration::mix = \*"\"\<Mixed contexts in \
\!\(\[GothicCapitalD]\_`4`\)/.Migration[`1`,`2`,`3`]: the relevant components \
`3` must be the same for all genes.\>\"";\)\)], "Input",
  InitializationCell->True],

Cell[BoxData[{
    \(\(Migration[\[CapitalOmega]_] := 
        Migration[{\[GothicCapitalZ], \[GothicCapitalJ]}, 
          MigrationRate, \[CapitalOmega]];\)\), "\[IndentingNewLine]", 
    \(\(Migration[cl_List, \[CapitalOmega]_] := 
        Migration[{\[GothicCapitalZ], \[GothicCapitalJ]}, MigrationRate, 
          cl, \[CapitalOmega]];\)\)}], "Input",
  InitializationCell->True,
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    \(\(Migration[{s1_?ContextStageQ, s2_?ContextStageQ}, 
          m_, \[CapitalOmega]_] := 
        Module[{\[Beta]}, 
          If[ContextComponentQ[s2, SexOfOrigin] && 
              ContextComponentQ[s2, 
                Sex], {\[GothicCapitalD]\_\(\[DoubleStruckCapitalU] : \
{_\_{s2, ___, \[Alpha]_, \[GothicCapitalM] | \[GothicCapitalF], \
\[GothicCapitalM] | \[GothicCapitalF]} ... }\) \[RuleDelayed] \[Sum]\+\(\
\[Beta] \[Element] \[CapitalOmega][\[Alpha]]\)\((\((\[GothicCapitalD]\_\
\[DoubleStruckCapitalU]\[CirclePlus]Migrate[{s1, s2}, \[Alpha], \[Beta]])\) 
                      m[\[Alpha], \[Beta]])\), \[GothicM]\_\(\[DoubleStruckI] \
: _\_{s2, ___, \[Alpha]_, \[GothicCapitalM] | \[GothicCapitalF], \
\[GothicCapitalM] | \[GothicCapitalF]}\) \[RuleDelayed] \[Sum]\+\(\[Beta] \
\[Element] \[CapitalOmega][\[Alpha]]\)\((\((\[GothicM]\_\[DoubleStruckI]\
\[CirclePlus]Migrate[{s1, s2}, \[Alpha], \[Beta]])\) 
                      m[\[Alpha], \[Beta]])\)}, {\[GothicCapitalD]\_\(\
\[DoubleStruckCapitalU] : {_\_{s2, ___, \[Alpha]_, \[GothicCapitalM] | \
\[GothicCapitalF]} ... }\) \[RuleDelayed] \[Sum]\+\(\[Beta] \[Element] \
\[CapitalOmega][\[Alpha]]\)\((\((\[GothicCapitalD]\_\[DoubleStruckCapitalU]\
\[CirclePlus]Migrate[{s1, s2}, \[Alpha], \[Beta]])\) 
                      m[\[Alpha], \[Beta]])\), \[GothicM]\_\(\[DoubleStruckI] \
: _\_{s2, ___, \[Alpha]_, \[GothicCapitalM] | \[GothicCapitalF]}\) \
\[RuleDelayed] \[Sum]\+\(\[Beta] \[Element] \[CapitalOmega][\[Alpha]]\)\((\((\
\[GothicM]\_\[DoubleStruckI]\[CirclePlus]Migrate[{s1, 
                              s2}, \[Alpha], \[Beta]])\) 
                      m[\[Alpha], \[Beta]])\)}]];\)\)], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(\(Migration[{s1_?ContextStageQ, s2_?ContextStageQ}, m_, 
          cl_List, \[CapitalOmega]_] := 
        Module[{\[Beta], cc}, \[IndentingNewLine]If[
            ContextComponentQ[s2, SexOfOrigin] && 
              ContextComponentQ[s2, 
                Sex], {\[GothicCapitalD]\_\(\[DoubleStruckCapitalU] : \
{_\_{s2, ___, \[Alpha]_, \[GothicCapitalM] | \[GothicCapitalF], \
\[GothicCapitalM] | \[GothicCapitalF]} ... }\) \[RuleDelayed] \((cc = 
                    Union[\[Chi]\_cl[\[DoubleStruckCapitalU]]]; \ 
                  If[Length[cc] > 1, \[IndentingNewLine]Message[
                      Migration::mix, {s1, s2}, m, 
                      cl, \[DoubleStruckCapitalU]]; \ \[GothicCapitalD]\_\
\[DoubleStruckCapitalU], \[IndentingNewLine]cc = 
                      If[cc === {}, {}, 
                        First[cc]]; \[IndentingNewLine]\[Sum]\+\(\[Beta] \
\[Element] \[CapitalOmega][\[Alpha]]\)\((\((\[GothicCapitalD]\_\
\[DoubleStruckCapitalU]\[CirclePlus]Migrate[{s1, 
                                  s2}, \[Alpha], \[Beta]])\) \((\((m[##, \ \
\[Alpha], \[Beta]] &)\) @@ 
                              cc)\))\)])\), \[IndentingNewLine]\[GothicM]\_\(\
\[DoubleStruckI] : _\_{s2, ___, \[Alpha]_, \[GothicCapitalM] | \
\[GothicCapitalF], \[GothicCapitalM] | \[GothicCapitalF]}\) \[RuleDelayed] \
\((cc = Union[\[Chi]\_cl[\[DoubleStruckCapitalU]]]; \ 
                  If[Length[cc] > 1, \[IndentingNewLine]Message[
                      Migration::mix, {s1, s2}, m, 
                      cl, \[DoubleStruckCapitalU]]; \ \[GothicCapitalD]\_\
\[DoubleStruckCapitalU], \[IndentingNewLine]cc = 
                      If[cc === {}, {}, 
                        First[cc]]; \[IndentingNewLine]\[Sum]\+\(\[Beta] \
\[Element] \[CapitalOmega][\[Alpha]]\)\((\((\[GothicM]\_\[DoubleStruckI]\
\[CirclePlus]Migrate[{s1, 
                                  s2}, \[Alpha], \[Beta]])\) \((\((m[##, \ \
\[Alpha], \[Beta]] &)\) @@ 
                              cc)\))\)])\)}, {\[GothicCapitalD]\_\(\
\[DoubleStruckCapitalU] : {_\_{s2, ___, \[Alpha]_, \[GothicCapitalM] | \
\[GothicCapitalF]} ... }\) \[RuleDelayed] \((cc = 
                    Union[\[Chi]\_cl[\[DoubleStruckCapitalU]]]; \ 
                  If[Length[cc] > 1, \[IndentingNewLine]Message[
                      Migration::mix, {s1, s2}, m, 
                      cl, \[DoubleStruckCapitalU]]; \ \[GothicCapitalD]\_\
\[DoubleStruckCapitalU], \[IndentingNewLine]cc = 
                      If[cc === {}, {}, 
                        First[cc]]; \[IndentingNewLine]\[Sum]\+\(\[Beta] \
\[Element] \[CapitalOmega][\[Alpha]]\)\((\((\[GothicCapitalD]\_\
\[DoubleStruckCapitalU]\[CirclePlus]Migrate[{s1, 
                                  s2}, \[Alpha], \[Beta]])\) \((\((m[##, \ \
\[Alpha], \[Beta]] &)\) @@ 
                              cc)\))\)])\), \[IndentingNewLine]\[GothicM]\_\(\
\[DoubleStruckI] : _\_{s2, ___, \[Alpha]_, \[GothicCapitalM] | \
\[GothicCapitalF]}\) \[RuleDelayed] \((cc = 
                    Union[\[Chi]\_cl[\[DoubleStruckCapitalU]]]; \ 
                  If[Length[cc] > 1, \[IndentingNewLine]Message[
                      Migration::mix, {s1, s2}, m, 
                      cl, \[DoubleStruckCapitalU]]; \ \[GothicCapitalD]\_\
\[DoubleStruckCapitalU], \[IndentingNewLine]cc = 
                      If[cc === {}, {}, 
                        First[cc]]; \[IndentingNewLine]\[Sum]\+\(\[Beta] \
\[Element] \[CapitalOmega][\[Alpha]]\)\((\((\[GothicM]\_\[DoubleStruckI]\
\[CirclePlus]Migrate[{s1, 
                                  s2}, \[Alpha], \[Beta]])\) \((\((m[##, \ \
\[Alpha], \[Beta]] &)\) @@ cc)\))\)])\)}]];\)\)], "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{

Cell["AlleleFrequencyP", "Subsubsection"],

Cell[BoxData[
    RowBox[{
      RowBox[{"Notation", "[", 
        RowBox[{
          TagBox[\(\[GothicP]\_x__\),
            NotationBoxTag,
            TagStyle->"NotationTemplateStyle"], " ", 
          "\[DoubleLongLeftRightArrow]", " ", 
          TagBox[\(AlleleFrequencyP[x__]\),
            NotationBoxTag,
            TagStyle->"NotationTemplateStyle"]}], "]"}], ";"}]], "Input",
  InitializationCell->True,
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell["AlleleFrequencyQ", "Subsubsection"],

Cell[BoxData[
    RowBox[{
      RowBox[{"Notation", "[", 
        RowBox[{
          TagBox[\(\[GothicQ]\_x__\),
            NotationBoxTag,
            TagStyle->"NotationTemplateStyle"], " ", 
          "\[DoubleLongLeftRightArrow]", " ", 
          TagBox[\(AlleleFrequencyQ[x__]\),
            NotationBoxTag,
            TagStyle->"NotationTemplateStyle"]}], "]"}], ";"}]], "Input",
  InitializationCell->True,
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell["AlleleFrequencyPQ", "Subsubsection"],

Cell[BoxData[
    RowBox[{
      RowBox[{"Notation", "[", 
        RowBox[{
          TagBox[\(\[GothicP]\[GothicQ]\_x__\),
            NotationBoxTag,
            TagStyle->"NotationTemplateStyle"], " ", 
          "\[DoubleLongLeftRightArrow]", " ", 
          TagBox[\(AlleleFrequencyPQ[x__]\),
            NotationBoxTag,
            TagStyle->"NotationTemplateStyle"]}], "]"}], ";"}]], "Input",
  InitializationCell->True,
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell["SymmetricRecombination", "Subsubsection"],

Cell[BoxData[{
    \(\(SymmetricRecombination[] := 
        SymmetricRecombination[
          RecombinationRate];\)\), "\[IndentingNewLine]", 
    \(\(SymmetricRecombination[r_] := {r[x___, {}, {}] :> 1, 
          r[x___, {_}, {}] :> 1\/2, 
          r[x___, {}, {_}] :> 
            1\/2, \(r[x___, A_List, 
                B_List]\)?\((Not[
                    OrderedQ[#\[LeftDoubleBracket]\(-2\)\[RightDoubleBracket]]\
 && OrderedQ[#\[LeftDoubleBracket]\(-1\)\[RightDoubleBracket]] && 
                      OrderedQ[{#\[LeftDoubleBracket]\(-2\)\
\[RightDoubleBracket], #\[LeftDoubleBracket]\(-1\)\[RightDoubleBracket]}]] &)\
\) \[RuleDelayed] r[x, Sequence @@ Sort[Sort /@ {A, B}]]};\)\)}], "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{

Cell["SymmetricSexes", "Subsubsection"],

Cell[BoxData[{
    \(\(SymmetricSexes[] = 
        SymmetricSexes[\[GothicCapitalF]];\)\), "\[IndentingNewLine]", 
    \(\(SymmetricSexes[s_] := 
        Module[{os = 
              OtherSex[
                s]}, \[IndentingNewLine]{\[GothicM]\_\(i_\_{st_?\((\
ContextComponentQ[#, Sex] \[And] ContextComponentQ[#, SexOfOrigin] &)\), \
x___, sex_, os}\) \[RuleDelayed] \[GothicM]\_\(i\_{st, x, OtherSex[sex], \
s}\), \[IndentingNewLine]\[GothicM]\_\(i_\_{st_?\((Xor[ContextComponentQ[#, \
Sex], ContextComponentQ[#, SexOfOrigin]] &)\), x___, os}\) \[RuleDelayed] \
\[GothicM]\_\(i\_{st, x, s}\), \[IndentingNewLine]\[GothicCapitalD]\_\(\
\[DoubleStruckCapitalU] : {_\_{st_?\((ContextComponentQ[#, Sex] \[Or] \
ContextComponentQ[#, SexOfOrigin] &)\), ___} .. }\) \[RuleDelayed] \
\[IndentingNewLine]Module[{nu = \[DoubleStruckCapitalU], ds, sl, 
                  cl}, \[IndentingNewLine]cl = 
                  If[ContextComponentQ[\[DoubleStruckCapitalU]\
\[LeftDoubleBracket]1, 2, 1\[RightDoubleBracket], Sex], {Sex}, {}]\[Vee]If[
                      ContextComponentQ[\[DoubleStruckCapitalU]\
\[LeftDoubleBracket]1, 2, 1\[RightDoubleBracket], 
                        SexOfOrigin], {SexOfOrigin}, {}]; \
\[IndentingNewLine]sl = 
                  Flatten[\[Chi]\_cl[\[DoubleStruckCapitalU]]]; \
\[IndentingNewLine]If[
                  Count[sl, os] > 
                    Count[sl, 
                      s], \[IndentingNewLine]nu = \(\(\[DoubleStruckCapitalU] \
/. os \[Rule] ds\) /. s \[Rule] os\) /. 
                      ds \[Rule] 
                        s]; \[IndentingNewLine]\[GothicCapitalD]\_nu]}];\)\)}]\
, "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{

Cell["OtherSex", "Subsubsection"],

Cell[BoxData[
    \(OtherSex[\[GothicCapitalM]] = \[GothicCapitalF]; 
    OtherSex[\[GothicCapitalF]] = \[GothicCapitalM];\)], "Input",
  InitializationCell->True,
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell["Biallelic", "Subsubsection"],

Cell[BoxData[
    \(\(Options[Biallelic] = {BiallelicPQ \[Rule] False};\)\)], "Input",
  InitializationCell->True,
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[{
    \(\(Biallelic[] := 
        Biallelic[AlleleFrequencyP];\)\), "\[IndentingNewLine]", 
    \(\(Biallelic[BiallelicPQ \[Rule] True] := 
        Biallelic[AlleleFrequencyP, AlleleFrequencyPQ, 
          BiallelicPQ \[Rule] True];\)\)}], "Input",
  InitializationCell->True,
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    \(\(Biallelic[
          p_] := {\[GothicCapitalD]\_{a___, \[DoubleStruckI] : _\__List, \
b___, \[DoubleStruckI] : _\__List, c___} \[RuleDelayed] \
\(\[GothicCapitalD]\_{a, b, c}\) \((1 - p[\[DoubleStruckI]])\) 
                p[\[DoubleStruckI]] + \
\(\[GothicCapitalD]\_\({\[DoubleStruckI]}\[Vee]{a, b, c}\)\) \((1 - 
                    2  p[\[DoubleStruckI]])\), \[IndentingNewLine]\[Zeta]\_\
\[DoubleStruckI]_\%n_Integer \[RuleDelayed] \(\[Zeta]\_\[DoubleStruckI]\%\(n \
- 2\)\) \((1 - p[\[DoubleStruckI]])\) 
                p[\[DoubleStruckI]] + \(\[Zeta]\_\[DoubleStruckI]\%\(n - 
                      1\)\) \((1 - 2  p[\[DoubleStruckI]])\), 
          X\_\[DoubleStruckI]_\%n_Integer \[RuleDelayed] 
            X\_\[DoubleStruckI]};\)\)], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(\(Biallelic[p_, pq_, 
          BiallelicPQ \[Rule] 
            True] := {\[GothicCapitalD]\_{a___, \[DoubleStruckI] : _\__List, \
b___, \[DoubleStruckI] : _\__List, c___} \[RuleDelayed] \
\(\[GothicCapitalD]\_{a, b, c}\) 
                pq[\[DoubleStruckI]] + \(\[GothicCapitalD]\_\({\
\[DoubleStruckI]}\[Vee]{a, b, c}\)\) \((1 - 
                    2  p[\[DoubleStruckI]])\), \[IndentingNewLine]\[Zeta]\_\
\[DoubleStruckI]_\%n_Integer \[RuleDelayed] \(\[Zeta]\_\[DoubleStruckI]\%\(n \
- 2\)\) pq[\[DoubleStruckI]] + \(\[Zeta]\_\[DoubleStruckI]\%\(n - 
                      1\)\) \((1 - 2  p[\[DoubleStruckI]])\), 
          X\_\[DoubleStruckI]_\%n_Integer \[RuleDelayed] 
            X\_\[DoubleStruckI]};\)\)], "Input",
  InitializationCell->True],

Cell[BoxData[{
    \(\(Biallelic[ll_List] := 
        Biallelic[ll, AlleleFrequencyP];\)\), "\[IndentingNewLine]", 
    \(\(Biallelic[ll_List, BiallelicPQ \[Rule] True] := 
        Biallelic[ll, AlleleFrequencyP, AlleleFrequencyPQ, 
          BiallelicPQ \[Rule] True];\)\)}], "Input",
  InitializationCell->True,
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    \(\(Biallelic[ll_List, 
          p_?\((\(! ListQ[#]\) &)\)] := {\[GothicCapitalD]\_{a___, \
\((i_?\((MemberQ[ll, #] &)\))\)\_cc_List, \((i_?\((MemberQ[ll, #] \
&)\))\)\_cc_List} \[RuleDelayed] \(\[GothicCapitalD]\_{a}\) 
                p[i\_cc] \((1 - 
                    p[i\_cc])\) + \(\[GothicCapitalD]\_\({i\_cc}\[Vee]{a}\)\) \
\((1 - 2  
                        p[i\_cc])\), \
\[IndentingNewLine]\[Zeta]\_\((i_?\((MemberQ[ll, #] \
&)\))\)\_cc_List\%n_Integer \[RuleDelayed] \(\[Zeta]\_i\_cc\%\(n - 
                      2\)\) \((1 - p[i\_cc])\) 
                p[i\_cc] + \(\[Zeta]\_i\_cc\%\(n - 1\)\) \((1 - 
                    2  p[i\_cc])\), 
          X\_\((i_?\((MemberQ[ll, #] &)\))\)\_cc_List\%n_Integer \
\[RuleDelayed] X\_\(i\_cc\)};\)\)], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(\(Biallelic[ll_List, p_, pq_, 
          BiallelicPQ \[Rule] 
            True] := {\[GothicCapitalD]\_{a___, i_?\((i_?\((MemberQ[ll, #] &)\
\))\)\_cc_List, \((i_?\((MemberQ[ll, #] &)\))\)\_cc_List} \[RuleDelayed] \(\
\[GothicCapitalD]\_{a}\) 
                pq[i\_cc] + \(\[GothicCapitalD]\_\({i\_cc}\[Vee]{a}\)\) \((1 \
- 2  p[i\_cc])\), \[IndentingNewLine]\[Zeta]\_\((i_?\((MemberQ[ll, #] &)\))\)\
\_cc_List\%n_Integer \[RuleDelayed] \(\[Zeta]\_i\_cc\%\(n - 2\)\) 
                pq[i\_cc] + \(\[Zeta]\_i\_cc\%\(n - 1\)\) \((1 - 
                    2  p[i\_cc])\), 
          X\_\((i_?\((MemberQ[ll, #] &)\))\)\_cc_List\%n_Integer \
\[RuleDelayed] X\_\(i\_cc\)};\)\)], "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{

Cell["ToCumulants", "Subsubsection"],

Cell[BoxData[{
    \(\(ToCumulants[] := 
        ToCumulants[Disequilibrium, 
          CumulantDisequilibrium];\)\), "\[IndentingNewLine]", 
    \(\(ToCumulants[mom_, 
          cum_] := {mom[\[DoubleStruckCapitalU]_] \[RuleDelayed] 
            Moment[cum, \[DoubleStruckCapitalU]]};\)\)}], "Input",
  InitializationCell->True,
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell["ToMoments", "Subsubsection"],

Cell[BoxData[{
    \(\(ToMoments[] := 
        ToMoments[CumulantDisequilibrium, 
          Disequilibrium];\)\), "\[IndentingNewLine]", 
    \(\(ToMoments[cum_, 
          mom_] := {cum[\[DoubleStruckCapitalU]_] \[RuleDelayed] 
            Cumulant[mom, \[DoubleStruckCapitalU]]};\)\)}], "Input",
  InitializationCell->True,
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell["CumulantDisequilibrium", "Subsubsection"],

Cell[BoxData[
    \(\(CumulantDisequilibrium[{}] = 1;\)\)], "Input",
  InitializationCell->True,
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    RowBox[{
      RowBox[{"Notation", "[", 
        RowBox[{
          TagBox[\(\[GothicK]\_\[DoubleStruckCapitalU]_\),
            NotationBoxTag,
            TagStyle->"NotationTemplateStyle"], " ", 
          "\[DoubleLongLeftRightArrow]", " ", 
          TagBox[\(CumulantDisequilibrium[\[DoubleStruckCapitalU]_]\),
            NotationBoxTag,
            TagStyle->"NotationTemplateStyle"]}], "]"}], ";"}]], "Input",
  InitializationCell->True,
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell["BaakeDisequilibrium", "Subsubsection"],

Cell[BoxData[
    \(\(BaakeDisequilibrium[{}] = 1;\)\)], "Input",
  InitializationCell->True],

Cell[BoxData[
    RowBox[{
      RowBox[{"Notation", "[", 
        RowBox[{
          TagBox[\(\[GothicZ]\_\[DoubleStruckCapitalU]_\),
            NotationBoxTag,
            Editable->True], " ", "\[DoubleLongLeftRightArrow]", " ", 
          TagBox[\(BaakeDisequilibrium[\[DoubleStruckCapitalU]_]\),
            NotationBoxTag,
            Editable->True]}], "]"}], ";"}]], "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{

Cell["ToBaake", "Subsubsection"],

Cell[BoxData[{
    \(\(ToBaake[] := 
        ToBaake[Disequilibrium, 
          BaakeDisequilibrium];\)\), "\[IndentingNewLine]", 
    \(\(ToBaake[d_, 
          z_] := {d[\[DoubleStruckCapitalU]_] \[RuleDelayed] 
            Module[{n}, 
              Sum[\((Plus @@ \((\(\((Times @@ #)\) &\) /@ 
                        Map[z, 
                          PartitionSet[\[DoubleStruckCapitalU], n, 
                            Ordered \[Rule] True], {2}])\))\), {n, 
                  Length[\[DoubleStruckCapitalU]]}]]};\)\)}], "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{

Cell["FromBaake", "Subsubsection"],

Cell[BoxData[{
    \(\(FromBaake[] := 
        FromBaake[BaakeDisequilibrium, 
          Disequilibrium];\)\), "\[IndentingNewLine]", 
    \(\(FromBaake[z_, 
          d_] := {z[\[DoubleStruckCapitalU]_] \[RuleDelayed] 
            Module[{n}, 
              Sum[\(\((\(-1\))\)\^\(n - 
                        1\)\) \((Plus @@ \((\(\((Times @@ #)\) &\) /@ 
                          Map[d, 
                            PartitionSet[\[DoubleStruckCapitalU], n, 
                              Ordered \[Rule] True], {2}])\))\), {n, 
                  Length[\[DoubleStruckCapitalU]]}]]};\)\)}], "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{

Cell["CumulantPopulationDisequilibrium", "Subsubsection"],

Cell[BoxData[
    \(\(CumulantPopulationDisequilibrium[{} ... ] := 1;\)\)], "Input",
  InitializationCell->True,
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    RowBox[{
      RowBox[{"Notation", "[", 
        RowBox[{
          TagBox[\(\[GothicCapitalK]\_x___\),
            NotationBoxTag,
            TagStyle->"NotationTemplateStyle"], " ", 
          "\[DoubleLongLeftRightArrow]", " ", 
          TagBox[\(CumulantPopulationDisequilibrium[x___]\),
            NotationBoxTag,
            TagStyle->"NotationTemplateStyle"]}], "]"}], ";"}]], "Input",
  InitializationCell->True,
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell["ToPopulationCumulants", "Subsubsection"],

Cell[BoxData[{
    \(\(ToPopulationCumulants[] := 
        ToPopulationCumulants[PopulationDisequilibrium, 
          CumulantPopulationDisequilibrium];\)\), "\[IndentingNewLine]", 
    \(\(ToPopulationCumulants[mom_, 
          cum_] := {cum[x__] \[RuleDelayed] 
              Cumulant[mom, AddTag[{x}, 3]] /. {mom[z_] \[RuleDelayed] 
                mom[RemoveTag[z, 3]]}};\)\)}], "Input",
  InitializationCell->True,
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell["ToPopulationMoments", "Subsubsection"],

Cell[BoxData[{
    \(\(ToPopulationMoments[] := 
        ToPopulationMoments[CumulantPopulationDisequilibrium, 
          PopulationDisequilibrium];\)\), "\[IndentingNewLine]", 
    \(\(ToPopulationMoments[cum_, 
          mom_] := {mom[x__] \[RuleDelayed] 
              Moment[cum, 
                Flatten[
                  MapIndexed[#1[#2\[LeftDoubleBracket]1\[RightDoubleBracket]] \
&, {x}, {2}]]] /. {cum[z_] \[RuleDelayed] 
                cum[changeback[z, Length[{x}]]]}};\)\)}], "Input",
  InitializationCell->True,
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell["SlowChange", "Subsubsection"],

Cell[BoxData[{
    \(\(SlowChange[expr_] := 
        SlowChange[expr, \[GothicS], 1];\)\), "\[IndentingNewLine]", 
    \(\(SlowChange[expr_, \[Epsilon]_, k_Integer] := 
        Series[expr, {\[Epsilon], 0, k}] // Normal;\)\)}], "Input",
  InitializationCell->True,
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]],

Cell[CellGroupData[{

Cell["BennettC", "Subsubsection",
  InitializationCell->True],

Cell[BoxData[
    \(\(BennettC[P : {__List}] := 
        Module[{sp = StandardPartition[P], U, rl}, \[IndentingNewLine]If[
            sp === P, \[IndentingNewLine]BennettCstandard[
              P], \[IndentingNewLine]U = 
              Flatten[Sort[P]]; \[IndentingNewLine]BennettCstandard[
                sp] /. \[GothicR]\_\(A_, B_\) \[RuleDelayed] 
                RecombinationRate @@ 
                  Sort[Sort /@ \(({A, B} /. 
                          j_Integer \[RuleDelayed] 
                            U\[LeftDoubleBracket]
                              j\[RightDoubleBracket])\)]]];\)\)], "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{

Cell["BennettCstandard", "Subsubsection"],

Cell[BoxData[
    \(BennettCstandard[{{_}, {__}}] := \(-1\); 
    BennettCstandard[{{_} .. }] := \(-1\);\)], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(\(BennettCstandard[P_List] := \(BennettCstandard[P] = 
          Module[{x, U = Flatten[P], A, sU, bE, bp}, \[IndentingNewLine]sU = 
              Subsets[U, 1, Length[U] - 1]; 
            bp = \[Product]\+\(x \[Element] P\)bb[
                  x]; \[IndentingNewLine]\(1\/\(\[GothicR]\_\({}, Sort[U]\) - \
\[Product]\+\(x \[Element] P\)\[GothicR]\_\({}, Sort[x]\)\)\) 
              Coefficient[BennettExpansion[U], bp]]\);\)\)], "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{

Cell["BennettExpansion", "Subsubsection",
  InitializationCell->True],

Cell[BoxData[
    \(\(BennettExpansion[U_List] := \(BennettExpansion[U] = 
          Module[{x, y, A, sU, \[DoubleStruckCapitalP], P1, 
              P2}, \[IndentingNewLine]\[DoubleStruckCapitalP][V_] := 
              DeleteCases[PartitionSet[V], {V}]; \[IndentingNewLine]sU = 
              Subsets[U, 1, 
                Length[U] - 
                  1]; \[IndentingNewLine]\((\[Sum]\+\(A \[Element] \
sU\)\(RecombinationRate @@ Sort[Sort /@ {A, U\[Backslash]A}]\/2\) \((bb[
                          A] - \[Sum]\+\(P1 \[Element] \
\[DoubleStruckCapitalP][A]\)\((BennettC[
                                P1] \((\[Product]\+\(x \[Element] P1\)bb[
                                    x])\))\))\) \((bb[
                          U\[Backslash]
                            A] - \[Sum]\+\(P2 \[Element] \
\[DoubleStruckCapitalP][U\[Backslash]A]\)\((BennettC[
                                P2] \((\[Product]\+\(y \[Element] P2\)bb[
                                    y])\))\))\))\) /. \[GothicR]\_\({}, {_}\) \
\[RuleDelayed] 1]\);\)\)], "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{

Cell["BennettB", "Subsubsection",
  InitializationCell->True],

Cell[BoxData[
    RowBox[{
      RowBox[{"Notation", "[", 
        RowBox[{
          TagBox[\(\[GothicB]\_U_\),
            NotationBoxTag,
            Editable->True], " ", "\[DoubleLongLeftRightArrow]", " ", 
          TagBox[\(BennettB[U_]\),
            NotationBoxTag,
            Editable->True]}], "]"}], ";"}]], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(\(BennettB[P : {___List}] := 
        Module[{x}, \[Product]\+\(x \[Element] P\)BennettB[x]];\)\)], "Input",\

  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{

Cell["FromBennettExpression", "Subsubsection",
  InitializationCell->True],

Cell[BoxData[
    \(\(FromBennettExpression[n_Integer] := \(FromBennettExpression[n] = 
          Module[{x, U = Range[n], \[DoubleStruckCapitalP], 
              P}, \[IndentingNewLine]\[DoubleStruckCapitalP] = 
              DeleteCases[
                PartitionSet[
                  U], {U}]; \[IndentingNewLine]\[GothicCapitalD]\_U + \
\[Sum]\+\(P \[Element] \[DoubleStruckCapitalP]\)\((BennettC[
                      P] \((\[Product]\+\(x \[Element] \
P\)FromBennettExpression[x])\))\)]\);\)\)], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(\(FromBennettExpression[
          U_List] := \[IndentingNewLine]FromBennettExpression[Length[U]] /. 
          a : {__Integer} \[RuleDelayed] \((a /. 
                i_Integer \[RuleDelayed] 
                  U\[LeftDoubleBracket]
                    i\[RightDoubleBracket])\);\)\)], "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData[StyleBox["ToBennettExpression", "Subsubsection"]], \
"Subsubsection",
  InitializationCell->True],

Cell[BoxData[
    \(\(ToBennettExpression[n_Integer] := \(ToBennettExpression[n] = 
          Module[{U = Range[n], \[DoubleStruckCapitalP], 
              P}, \[IndentingNewLine]\[DoubleStruckCapitalP] = 
              DeleteCases[
                PartitionSet[
                  U], {U}]; \[IndentingNewLine]\[GothicB]\_U - \[Sum]\+\(P \
\[Element] \[DoubleStruckCapitalP]\)\((BennettC[
                      P] \[GothicB]\_P)\)]\);\)\)], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(\(ToBennettExpression[
          U_List] := \[IndentingNewLine]ToBennettExpression[Length[U]] /. 
          a : {__Integer} \[RuleDelayed] \((a /. 
                i_Integer \[RuleDelayed] 
                  U\[LeftDoubleBracket]
                    i\[RightDoubleBracket])\);\)\)], "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{

Cell["ToBennett", "Subsubsection",
  InitializationCell->True],

Cell[BoxData[{
    \(\(ToBennett[] := {\[GothicCapitalD]\_U_List \[RuleDelayed] 
            ToBennettExpression[U]};\)\), "\[IndentingNewLine]", 
    \(\(ToBennett[d_, b_, 
          r_] := {d[
              U_List] \[RuleDelayed] \((ToBennettExpression[
                  U] /. {BennettB[V_List] \[RuleDelayed] b[V], 
                  RecombinationRate[A_List, B_List] \[RuleDelayed] 
                    r[A, B]})\)};\)\)}], "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{

Cell["FromBennett", "Subsubsection",
  InitializationCell->True],

Cell[BoxData[{
    \(\(FromBennett[] := {\[GothicB]\_U_List \[RuleDelayed] 
            FromBennettExpression[U]};\)\), "\[IndentingNewLine]", 
    \(\(FromBennett[b_, d_, 
          r_] := {b[
              U_List] \[RuleDelayed] \((FromBennettExpression[
                  U] /. {Disequilibrium[V_List] \[RuleDelayed] d[V], 
                  RecombinationRate[A_List, B_List] \[RuleDelayed] 
                    r[A, B]})\)};\)\)}], "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{

Cell["Ending", "Subsubsection",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[{
    \(\(End[];\)\), "\n", 
    \(\(EndPackage[];\)\)}], "Input",
  InitializationCell->True,
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Closed]]
}, Open  ]]
},
FrontEndVersion->"4.0 for Macintosh",
ScreenRectangle->{{0, 1024}, {0, 748}},
AutoGeneratedPackage->None,
WindowSize->{946, 628},
WindowMargins->{{Automatic, 44}, {10, Automatic}},
InputAliases->{"StyleDefinitions"->Notebook[ {
        Cell[ 
          CellGroupData[ {
            Cell[ "Style Definitions", "Subtitle"], 
            Cell[ 
            "Modify the definitions below to change the default appearance of \
all cells in a given style.  Make modifications to any definition using \
commands in the Format menu.", "Text"], 
            Cell[ 
              CellGroupData[ {
                Cell[ "Style Environment Names", "Section"], 
                Cell[ 
                  StyleData[ All, "Working"], PageWidth -> WindowWidth, 
                  CellLabelMargins -> {{12, Inherited}, {Inherited, 
                  Inherited}}, ScriptMinSize -> 9], 
                Cell[ 
                  StyleData[ All, "Presentation"], PageWidth -> WindowWidth, 
                  CellLabelMargins -> {{24, Inherited}, {Inherited, 
                  Inherited}}, ScriptMinSize -> 12], 
                Cell[ 
                  StyleData[ All, "Condensed"], PageWidth -> WindowWidth, 
                  CellLabelMargins -> {{8, Inherited}, {Inherited, 
                  Inherited}}, ScriptMinSize -> 8], 
                Cell[ 
                  StyleData[ All, "Printout"], PageWidth -> PaperWidth, 
                  CellLabelMargins -> {{2, Inherited}, {Inherited, 
                  Inherited}}, ScriptMinSize -> 5, PrivateFontOptions -> {
                  "FontType" -> "Outline"}]}, Closed]], 
            Cell[ 
              CellGroupData[ {
                Cell[ "Notebook Options", "Section"], 
                Cell[ 
                "The options defined for the style below will be used at the \
Notebook level.", "Text"], 
                Cell[ 
                  StyleData[ "Notebook"], PageHeaders -> {{
                  Cell[ 
                    TextData[ {
                      CounterBox[ "Page"]}], "PageNumber"], None, 
                  Cell[ 
                    TextData[ {
                      ValueBox[ "FileName"]}], "Header"]}, {
                  Cell[ 
                    TextData[ {
                      ValueBox[ "FileName"]}], "Header"], None, 
                  Cell[ 
                    TextData[ {
                      CounterBox[ "Page"]}], "PageNumber"]}}, 
                  CellFrameLabelMargins -> 6, StyleMenuListing -> None]}, 
                Closed]], 
            Cell[ 
              CellGroupData[ {
                Cell[ "Styles for Headings", "Section"], 
                Cell[ 
                  CellGroupData[ {
                    Cell[ 
                      StyleData[ "Title"], CellMargins -> {{12, Inherited}, {
                      20, 40}}, CellGroupingRules -> {"TitleGrouping", 0}, 
                      PageBreakBelow -> False, DefaultNewInlineCellStyle -> 
                      "None", InputAutoReplacements -> {"TeX" -> StyleBox[ 
                        RowBox[ {"T", 
                          AdjustmentBox[ 
                          "E", BoxMargins -> {{-0.074999999999999997, \
-0.085000000000000006}, {0, 0}}, BoxBaselineShift -> 0.5], "X"}]], "LaTeX" -> 
                      StyleBox[ 
                        RowBox[ {"L", 
                          StyleBox[ 
                            AdjustmentBox[ 
                            "A", BoxMargins -> {{-0.35999999999999999, \
-0.10000000000000001}, {0, 0}}, BoxBaselineShift -> -0.20000000000000001], 
                            FontSize -> Smaller], "T", 
                          AdjustmentBox[ 
                          "E", BoxMargins -> {{-0.074999999999999997, \
-0.085000000000000006}, {0, 0}}, BoxBaselineShift -> 0.5], "X"}]], "mma" -> 
                      "Mathematica", "Mma" -> "Mathematica", "MMA" -> 
                      "Mathematica"}, LanguageCategory -> "NaturalLanguage", 
                      CounterIncrements -> "Title", CounterAssignments -> {{
                      "Section", 0}, {"Equation", 0}, {"Figure", 0}, {
                      "Subtitle", 0}, {"Subsubtitle", 0}}, FontFamily -> 
                      "Helvetica", FontSize -> 36, FontWeight -> "Bold"], 
                    Cell[ 
                      StyleData[ "Title", "Presentation"], CellMargins -> {{
                      24, 10}, {20, 40}}, LineSpacing -> {1, 0}, FontSize -> 
                      44], 
                    Cell[ 
                      StyleData[ "Title", "Condensed"], CellMargins -> {{8, 
                      10}, {4, 8}}, FontSize -> 20], 
                    Cell[ 
                      StyleData[ "Title", "Printout"], CellMargins -> {{2, 
                      10}, {12, 30}}, FontSize -> 24]}, Closed]], 
                Cell[ 
                  CellGroupData[ {
                    Cell[ 
                      StyleData[ "Subtitle"], CellMargins -> {{12, 
                      Inherited}, {20, 15}}, CellGroupingRules -> {
                      "TitleGrouping", 10}, PageBreakBelow -> False, 
                      DefaultNewInlineCellStyle -> "None", 
                      InputAutoReplacements -> {"TeX" -> StyleBox[ 
                        RowBox[ {"T", 
                          AdjustmentBox[ 
                          "E", BoxMargins -> {{-0.074999999999999997, \
-0.085000000000000006}, {0, 0}}, BoxBaselineShift -> 0.5], "X"}]], "LaTeX" -> 
                      StyleBox[ 
                        RowBox[ {"L", 
                          StyleBox[ 
                            AdjustmentBox[ 
                            "A", BoxMargins -> {{-0.35999999999999999, \
-0.10000000000000001}, {0, 0}}, BoxBaselineShift -> -0.20000000000000001], 
                            FontSize -> Smaller], "T", 
                          AdjustmentBox[ 
                          "E", BoxMargins -> {{-0.074999999999999997, \
-0.085000000000000006}, {0, 0}}, BoxBaselineShift -> 0.5], "X"}]], "mma" -> 
                      "Mathematica", "Mma" -> "Mathematica", "MMA" -> 
                      "Mathematica"}, LanguageCategory -> "NaturalLanguage", 
                      CounterIncrements -> "Subtitle", 
                      CounterAssignments -> {{"Section", 0}, {"Equation", 
                      0}, {"Figure", 0}, {"Subsubtitle", 0}}, FontFamily -> 
                      "Helvetica", FontSize -> 24], 
                    Cell[ 
                      StyleData[ "Subtitle", "Presentation"], 
                      CellMargins -> {{24, 10}, {20, 20}}, LineSpacing -> {1, 
                      0}, FontSize -> 36], 
                    Cell[ 
                      StyleData[ "Subtitle", "Condensed"], CellMargins -> {{8,
                       10}, {4, 4}}, FontSize -> 14], 
                    Cell[ 
                      StyleData[ "Subtitle", "Printout"], CellMargins -> {{2, 
                      10}, {12, 8}}, FontSize -> 18]}, Closed]], 
                Cell[ 
                  CellGroupData[ {
                    Cell[ 
                      StyleData[ "Subsubtitle"], CellMargins -> {{12, 
                      Inherited}, {20, 15}}, CellGroupingRules -> {
                      "TitleGrouping", 20}, PageBreakBelow -> False, 
                      DefaultNewInlineCellStyle -> "None", 
                      InputAutoReplacements -> {"TeX" -> StyleBox[ 
                        RowBox[ {"T", 
                          AdjustmentBox[ 
                          "E", BoxMargins -> {{-0.074999999999999997, \
-0.085000000000000006}, {0, 0}}, BoxBaselineShift -> 0.5], "X"}]], "LaTeX" -> 
                      StyleBox[ 
                        RowBox[ {"L", 
                          StyleBox[ 
                            AdjustmentBox[ 
                            "A", BoxMargins -> {{-0.35999999999999999, \
-0.10000000000000001}, {0, 0}}, BoxBaselineShift -> -0.20000000000000001], 
                            FontSize -> Smaller], "T", 
                          AdjustmentBox[ 
                          "E", BoxMargins -> {{-0.074999999999999997, \
-0.085000000000000006}, {0, 0}}, BoxBaselineShift -> 0.5], "X"}]], "mma" -> 
                      "Mathematica", "Mma" -> "Mathematica", "MMA" -> 
                      "Mathematica"}, LanguageCategory -> "NaturalLanguage", 
                      CounterIncrements -> "Subsubtitle", 
                      CounterAssignments -> {{"Section", 0}, {"Equation", 
                      0}, {"Figure", 0}}, FontFamily -> "Helvetica", FontSize -> 
                      14, FontSlant -> "Italic"], 
                    Cell[ 
                      StyleData[ "Subsubtitle", "Presentation"], 
                      CellMargins -> {{24, 10}, {20, 20}}, LineSpacing -> {1, 
                      0}, FontSize -> 24], 
                    Cell[ 
                      StyleData[ "Subsubtitle", "Condensed"], 
                      CellMargins -> {{8, 10}, {8, 8}}, FontSize -> 12], 
                    Cell[ 
                      StyleData[ "Subsubtitle", "Printout"], CellMargins -> {{
                      2, 10}, {12, 8}}, FontSize -> 14]}, Closed]], 
                Cell[ 
                  CellGroupData[ {
                    Cell[ 
                      StyleData[ "Section"], CellDingbat -> "\[FilledSquare]",
                       CellMargins -> {{25, Inherited}, {8, 24}}, 
                      CellGroupingRules -> {"SectionGrouping", 30}, 
                      PageBreakBelow -> False, DefaultNewInlineCellStyle -> 
                      "None", InputAutoReplacements -> {"TeX" -> StyleBox[ 
                        RowBox[ {"T", 
                          AdjustmentBox[ 
                          "E", BoxMargins -> {{-0.074999999999999997, \
-0.085000000000000006}, {0, 0}}, BoxBaselineShift -> 0.5], "X"}]], "LaTeX" -> 
                      StyleBox[ 
                        RowBox[ {"L", 
                          StyleBox[ 
                            AdjustmentBox[ 
                            "A", BoxMargins -> {{-0.35999999999999999, \
-0.10000000000000001}, {0, 0}}, BoxBaselineShift -> -0.20000000000000001], 
                            FontSize -> Smaller], "T", 
                          AdjustmentBox[ 
                          "E", BoxMargins -> {{-0.074999999999999997, \
-0.085000000000000006}, {0, 0}}, BoxBaselineShift -> 0.5], "X"}]], "mma" -> 
                      "Mathematica", "Mma" -> "Mathematica", "MMA" -> 
                      "Mathematica"}, LanguageCategory -> "NaturalLanguage", 
                      CounterIncrements -> "Section", CounterAssignments -> {{
                      "Subsection", 0}, {"Subsubsection", 0}}, FontFamily -> 
                      "Helvetica", FontSize -> 16, FontWeight -> "Bold"], 
                    Cell[ 
                      StyleData[ "Section", "Presentation"], CellMargins -> {{
                      40, 10}, {11, 32}}, LineSpacing -> {1, 0}, FontSize -> 
                      24], 
                    Cell[ 
                      StyleData[ "Section", "Condensed"], CellMargins -> {{18,
                       Inherited}, {6, 12}}, FontSize -> 12], 
                    Cell[ 
                      StyleData[ "Section", "Printout"], CellMargins -> {{13, 
                      0}, {7, 22}}, FontSize -> 14]}, Closed]], 
                Cell[ 
                  CellGroupData[ {
                    Cell[ 
                      StyleData[ "Subsection"], CellDingbat -> 
                      "\[FilledSmallSquare]", CellMargins -> {{22, 
                      Inherited}, {8, 20}}, CellGroupingRules -> {
                      "SectionGrouping", 40}, PageBreakBelow -> False, 
                      DefaultNewInlineCellStyle -> "None", 
                      InputAutoReplacements -> {"TeX" -> StyleBox[ 
                        RowBox[ {"T", 
                          AdjustmentBox[ 
                          "E", BoxMargins -> {{-0.074999999999999997, \
-0.085000000000000006}, {0, 0}}, BoxBaselineShift -> 0.5], "X"}]], "LaTeX" -> 
                      StyleBox[ 
                        RowBox[ {"L", 
                          StyleBox[ 
                            AdjustmentBox[ 
                            "A", BoxMargins -> {{-0.35999999999999999, \
-0.10000000000000001}, {0, 0}}, BoxBaselineShift -> -0.20000000000000001], 
                            FontSize -> Smaller], "T", 
                          AdjustmentBox[ 
                          "E", BoxMargins -> {{-0.074999999999999997, \
-0.085000000000000006}, {0, 0}}, BoxBaselineShift -> 0.5], "X"}]], "mma" -> 
                      "Mathematica", "Mma" -> "Mathematica", "MMA" -> 
                      "Mathematica"}, LanguageCategory -> "NaturalLanguage", 
                      CounterIncrements -> "Subsection", 
                      CounterAssignments -> {{"Subsubsection", 0}}, 
                      FontFamily -> "Times", FontSize -> 14, FontWeight -> 
                      "Bold"], 
                    Cell[ 
                      StyleData[ "Subsection", "Presentation"], 
                      CellMargins -> {{36, 10}, {11, 32}}, LineSpacing -> {1, 
                      0}, FontSize -> 22], 
                    Cell[ 
                      StyleData[ "Subsection", "Condensed"], CellMargins -> {{
                      16, Inherited}, {6, 12}}, FontSize -> 12], 
                    Cell[ 
                      StyleData[ "Subsection", "Printout"], CellMargins -> {{
                      9, 0}, {7, 22}}, FontSize -> 12]}, Closed]], 
                Cell[ 
                  CellGroupData[ {
                    Cell[ 
                      StyleData[ "Subsubsection"], CellDingbat -> 
                      "\[FilledSmallSquare]", CellMargins -> {{22, 
                      Inherited}, {8, 18}}, CellGroupingRules -> {
                      "SectionGrouping", 50}, PageBreakBelow -> False, 
                      DefaultNewInlineCellStyle -> "None", 
                      InputAutoReplacements -> {"TeX" -> StyleBox[ 
                        RowBox[ {"T", 
                          AdjustmentBox[ 
                          "E", BoxMargins -> {{-0.074999999999999997, \
-0.085000000000000006}, {0, 0}}, BoxBaselineShift -> 0.5], "X"}]], "LaTeX" -> 
                      StyleBox[ 
                        RowBox[ {"L", 
                          StyleBox[ 
                            AdjustmentBox[ 
                            "A", BoxMargins -> {{-0.35999999999999999, \
-0.10000000000000001}, {0, 0}}, BoxBaselineShift -> -0.20000000000000001], 
                            FontSize -> Smaller], "T", 
                          AdjustmentBox[ 
                          "E", BoxMargins -> {{-0.074999999999999997, \
-0.085000000000000006}, {0, 0}}, BoxBaselineShift -> 0.5], "X"}]], "mma" -> 
                      "Mathematica", "Mma" -> "Mathematica", "MMA" -> 
                      "Mathematica"}, LanguageCategory -> "NaturalLanguage", 
                      CounterIncrements -> "Subsubsection", FontFamily -> 
                      "Times", FontWeight -> "Bold"], 
                    Cell[ 
                      StyleData[ "Subsubsection", "Presentation"], 
                      CellMargins -> {{34, 10}, {11, 26}}, LineSpacing -> {1, 
                      0}, FontSize -> 18], 
                    Cell[ 
                      StyleData[ "Subsubsection", "Condensed"], 
                      CellMargins -> {{17, Inherited}, {6, 12}}, FontSize -> 
                      10], 
                    Cell[ 
                      StyleData[ "Subsubsection", "Printout"], 
                      CellMargins -> {{9, 0}, {7, 14}}, FontSize -> 11]}, 
                    Closed]]}, Closed]], 
            Cell[ 
              CellGroupData[ {
                Cell[ "Styles for Body Text", "Section"], 
                Cell[ 
                  CellGroupData[ {
                    Cell[ 
                      StyleData[ "Text"], CellMargins -> {{12, 10}, {7, 7}}, 
                      InputAutoReplacements -> {"TeX" -> StyleBox[ 
                        RowBox[ {"T", 
                          AdjustmentBox[ 
                          "E", BoxMargins -> {{-0.074999999999999997, \
-0.085000000000000006}, {0, 0}}, BoxBaselineShift -> 0.5], "X"}]], "LaTeX" -> 
                      StyleBox[ 
                        RowBox[ {"L", 
                          StyleBox[ 
                            AdjustmentBox[ 
                            "A", BoxMargins -> {{-0.35999999999999999, \
-0.10000000000000001}, {0, 0}}, BoxBaselineShift -> -0.20000000000000001], 
                            FontSize -> Smaller], "T", 
                          AdjustmentBox[ 
                          "E", BoxMargins -> {{-0.074999999999999997, \
-0.085000000000000006}, {0, 0}}, BoxBaselineShift -> 0.5], "X"}]], "mma" -> 
                      "Mathematica", "Mma" -> "Mathematica", "MMA" -> 
                      "Mathematica"}, Hyphenation -> True, LineSpacing -> {1, 
                      3}, CounterIncrements -> "Text"], 
                    Cell[ 
                      StyleData[ "Text", "Presentation"], CellMargins -> {{24,
                       10}, {10, 10}}, LineSpacing -> {1, 5}, FontSize -> 16],
                     
                    Cell[ 
                      StyleData[ "Text", "Condensed"], CellMargins -> {{8, 
                      10}, {6, 6}}, LineSpacing -> {1, 1}, FontSize -> 11], 
                    Cell[ 
                      StyleData[ "Text", "Printout"], CellMargins -> {{2, 
                      2}, {6, 6}}, TextJustification -> 0.5, FontSize -> 10]},
                     Closed]], 
                Cell[ 
                  CellGroupData[ {
                    Cell[ 
                      StyleData[ "SmallText"], CellMargins -> {{12, 10}, {6, 
                      6}}, DefaultNewInlineCellStyle -> "None", Hyphenation -> 
                      True, LineSpacing -> {1, 3}, LanguageCategory -> 
                      "NaturalLanguage", CounterIncrements -> "SmallText", 
                      FontFamily -> "Helvetica", FontSize -> 9], 
                    Cell[ 
                      StyleData[ "SmallText", "Presentation"], 
                      CellMargins -> {{24, 10}, {8, 8}}, LineSpacing -> {1, 
                      5}, FontSize -> 12], 
                    Cell[ 
                      StyleData[ "SmallText", "Condensed"], CellMargins -> {{
                      8, 10}, {5, 5}}, LineSpacing -> {1, 2}, FontSize -> 9], 
                    
                    Cell[ 
                      StyleData[ "SmallText", "Printout"], CellMargins -> {{2,
                       2}, {5, 5}}, TextJustification -> 0.5, FontSize -> 7]},
                     Closed]]}, Closed]], 
            Cell[ 
              CellGroupData[ {
                Cell[ "Styles for Input/Output", "Section"], 
                Cell[ 
                "The cells in this section define styles used for input and \
output to the kernel.  Be careful when modifying, renaming, or removing these \
styles, because the front end associates special meanings with these style \
names. Some attributes for these styles are actually set in FormatType Styles \
(in the last section of this stylesheet). ", "Text"], 
                Cell[ 
                  CellGroupData[ {
                    Cell[ 
                      StyleData[ "Input"], CellMargins -> {{45, 10}, {5, 7}}, 
                      Evaluatable -> True, CellGroupingRules -> 
                      "InputGrouping", CellHorizontalScrolling -> True, 
                      PageBreakWithin -> False, GroupPageBreakWithin -> False,
                       DefaultFormatType -> DefaultInputFormatType, 
                      HyphenationOptions -> {"HyphenationCharacter" -> 
                      "\[Continuation]"}, AutoItalicWords -> {}, 
                      LanguageCategory -> "Formula", FormatType -> InputForm, 
                      ShowStringCharacters -> True, NumberMarks -> True, 
                      LinebreakAdjustments -> {0.84999999999999998, 2, 10, 0, 
                      1}, CounterIncrements -> "Input", FontWeight -> "Bold"],
                     
                    Cell[ 
                      StyleData[ "Input", "Presentation"], CellMargins -> {{
                      72, Inherited}, {8, 10}}, LineSpacing -> {1, 0}, 
                      FontSize -> 16], 
                    Cell[ 
                      StyleData[ "Input", "Condensed"], CellMargins -> {{40, 
                      10}, {2, 3}}, FontSize -> 11], 
                    Cell[ 
                      StyleData[ "Input", "Printout"], CellMargins -> {{39, 
                      0}, {4, 6}}, LinebreakAdjustments -> {
                      0.84999999999999998, 2, 10, 1, 1}, FontSize -> 9]}, 
                    Closed]], 
                Cell[ 
                  StyleData[ "InputOnly"], Evaluatable -> True, 
                  CellGroupingRules -> "InputGrouping", 
                  CellHorizontalScrolling -> True, DefaultFormatType -> 
                  DefaultInputFormatType, HyphenationOptions -> {
                  "HyphenationCharacter" -> "\[Continuation]"}, 
                  AutoItalicWords -> {}, LanguageCategory -> "Formula", 
                  FormatType -> InputForm, ShowStringCharacters -> True, 
                  NumberMarks -> True, LinebreakAdjustments -> {
                  0.84999999999999998, 2, 10, 0, 1}, CounterIncrements -> 
                  "Input", StyleMenuListing -> None, FontWeight -> "Bold"], 
                Cell[ 
                  CellGroupData[ {
                    Cell[ 
                      StyleData[ "Output"], CellMargins -> {{47, 10}, {7, 5}},
                       CellEditDuplicate -> True, CellGroupingRules -> 
                      "OutputGrouping", CellHorizontalScrolling -> True, 
                      PageBreakWithin -> False, GroupPageBreakWithin -> False,
                       GeneratedCell -> True, CellAutoOverwrite -> True, 
                      DefaultFormatType -> DefaultOutputFormatType, 
                      HyphenationOptions -> {"HyphenationCharacter" -> 
                      "\[Continuation]"}, AutoItalicWords -> {}, 
                      LanguageCategory -> "Formula", FormatType -> InputForm, 
                      CounterIncrements -> "Output"], 
                    Cell[ 
                      StyleData[ "Output", "Presentation"], CellMargins -> {{
                      72, Inherited}, {10, 8}}, LineSpacing -> {1, 0}, 
                      FontSize -> 16], 
                    Cell[ 
                      StyleData[ "Output", "Condensed"], CellMargins -> {{41, 
                      Inherited}, {3, 2}}, FontSize -> 11], 
                    Cell[ 
                      StyleData[ "Output", "Printout"], CellMargins -> {{39, 
                      0}, {6, 4}}, FontSize -> 9]}, Closed]], 
                Cell[ 
                  CellGroupData[ {
                    Cell[ 
                      StyleData[ "Message"], CellMargins -> {{45, 
                      Inherited}, {Inherited, Inherited}}, CellGroupingRules -> 
                      "OutputGrouping", PageBreakWithin -> False, 
                      GroupPageBreakWithin -> False, GeneratedCell -> True, 
                      CellAutoOverwrite -> True, ShowCellLabel -> False, 
                      DefaultFormatType -> DefaultOutputFormatType, 
                      HyphenationOptions -> {"HyphenationCharacter" -> 
                      "\[Continuation]"}, AutoItalicWords -> {}, FormatType -> 
                      InputForm, CounterIncrements -> "Message", 
                      StyleMenuListing -> None, FontSize -> 11, FontColor -> 
                      RGBColor[ 0, 0, 1]], 
                    Cell[ 
                      StyleData[ "Message", "Presentation"], CellMargins -> {{
                      72, Inherited}, {Inherited, Inherited}}, 
                      LineSpacing -> {1, 0}, FontSize -> 16], 
                    Cell[ 
                      StyleData[ "Message", "Condensed"], CellMargins -> {{41,
                       Inherited}, {Inherited, Inherited}}, FontSize -> 11], 
                    Cell[ 
                      StyleData[ "Message", "Printout"], CellMargins -> {{39, 
                      Inherited}, {Inherited, Inherited}}, FontSize -> 7, 
                      FontColor -> GrayLevel[ 0]]}, Closed]], 
                Cell[ 
                  CellGroupData[ {
                    Cell[ 
                      StyleData[ "Print"], CellMargins -> {{45, Inherited}, {
                      Inherited, Inherited}}, CellGroupingRules -> 
                      "OutputGrouping", CellHorizontalScrolling -> True, 
                      PageBreakWithin -> False, GroupPageBreakWithin -> False,
                       GeneratedCell -> True, CellAutoOverwrite -> True, 
                      ShowCellLabel -> False, DefaultFormatType -> 
                      DefaultOutputFormatType, HyphenationOptions -> {
                      "HyphenationCharacter" -> "\[Continuation]"}, 
                      AutoItalicWords -> {}, FormatType -> InputForm, 
                      CounterIncrements -> "Print", StyleMenuListing -> None],
                     
                    Cell[ 
                      StyleData[ "Print", "Presentation"], CellMargins -> {{
                      72, Inherited}, {Inherited, Inherited}}, 
                      LineSpacing -> {1, 0}, FontSize -> 16], 
                    Cell[ 
                      StyleData[ "Print", "Condensed"], CellMargins -> {{41, 
                      Inherited}, {Inherited, Inherited}}, FontSize -> 11], 
                    Cell[ 
                      StyleData[ "Print", "Printout"], CellMargins -> {{39, 
                      Inherited}, {Inherited, Inherited}}, FontSize -> 8]}, 
                    Closed]], 
                Cell[ 
                  CellGroupData[ {
                    Cell[ 
                      StyleData[ "Graphics"], CellMargins -> {{4, 
                      Inherited}, {Inherited, Inherited}}, CellGroupingRules -> 
                      "GraphicsGrouping", CellHorizontalScrolling -> True, 
                      PageBreakWithin -> False, GeneratedCell -> True, 
                      CellAutoOverwrite -> True, ShowCellLabel -> False, 
                      DefaultFormatType -> DefaultOutputFormatType, 
                      LanguageCategory -> None, FormatType -> InputForm, 
                      CounterIncrements -> "Graphics", ImageMargins -> {{43, 
                      Inherited}, {Inherited, 0}}, StyleMenuListing -> None, 
                      FontFamily -> "Courier", FontSize -> 10], 
                    Cell[ 
                      StyleData[ "Graphics", "Presentation"], 
                      ImageMargins -> {{62, Inherited}, {Inherited, 0}}], 
                    Cell[ 
                      StyleData[ "Graphics", "Condensed"], ImageMargins -> {{
                      38, Inherited}, {Inherited, 0}}, Magnification -> 
                      0.59999999999999998], 
                    Cell[ 
                      StyleData[ "Graphics", "Printout"], ImageMargins -> {{
                      30, Inherited}, {Inherited, 0}}, Magnification -> 
                      0.80000000000000004]}, Closed]], 
                Cell[ 
                  CellGroupData[ {
                    Cell[ 
                      StyleData[ "CellLabel"], StyleMenuListing -> None, 
                      FontFamily -> "Helvetica", FontSize -> 9, FontColor -> 
                      RGBColor[ 0, 0, 1]], 
                    Cell[ 
                      StyleData[ "CellLabel", "Presentation"], FontSize -> 
                      12], 
                    Cell[ 
                      StyleData[ "CellLabel", "Condensed"], FontSize -> 9], 
                    Cell[ 
                      StyleData[ "CellLabel", "Printout"], FontFamily -> 
                      "Courier", FontSize -> 8, FontSlant -> "Italic", 
                      FontColor -> GrayLevel[ 0]]}, Closed]]}, Closed]], 
            Cell[ 
              CellGroupData[ {
                Cell[ "Inline Formatting", "Section"], 
                Cell[ 
                "These styles are for modifying individual words or letters \
in a cell exclusive of the cell tag.", "Text"], 
                Cell[ 
                  StyleData[ "RM"], StyleMenuListing -> None, FontWeight -> 
                  "Plain", FontSlant -> "Plain"], 
                Cell[ 
                  StyleData[ "BF"], StyleMenuListing -> None, FontWeight -> 
                  "Bold"], 
                Cell[ 
                  StyleData[ "IT"], StyleMenuListing -> None, FontSlant -> 
                  "Italic"], 
                Cell[ 
                  StyleData[ "TR"], StyleMenuListing -> None, FontFamily -> 
                  "Times", FontWeight -> "Plain", FontSlant -> "Plain"], 
                Cell[ 
                  StyleData[ "TI"], StyleMenuListing -> None, FontFamily -> 
                  "Times", FontWeight -> "Plain", FontSlant -> "Italic"], 
                Cell[ 
                  StyleData[ "TB"], StyleMenuListing -> None, FontFamily -> 
                  "Times", FontWeight -> "Bold", FontSlant -> "Plain"], 
                Cell[ 
                  StyleData[ "TBI"], StyleMenuListing -> None, FontFamily -> 
                  "Times", FontWeight -> "Bold", FontSlant -> "Italic"], 
                Cell[ 
                  StyleData[ "MR"], StyleMenuListing -> None, FontFamily -> 
                  "Courier", FontWeight -> "Plain", FontSlant -> "Plain"], 
                Cell[ 
                  StyleData[ "MO"], StyleMenuListing -> None, FontFamily -> 
                  "Courier", FontWeight -> "Plain", FontSlant -> "Italic"], 
                Cell[ 
                  StyleData[ "MB"], StyleMenuListing -> None, FontFamily -> 
                  "Courier", FontWeight -> "Bold", FontSlant -> "Plain"], 
                Cell[ 
                  StyleData[ "MBO"], StyleMenuListing -> None, FontFamily -> 
                  "Courier", FontWeight -> "Bold", FontSlant -> "Italic"], 
                Cell[ 
                  StyleData[ "SR"], StyleMenuListing -> None, FontFamily -> 
                  "Helvetica", FontWeight -> "Plain", FontSlant -> "Plain"], 
                Cell[ 
                  StyleData[ "SO"], StyleMenuListing -> None, FontFamily -> 
                  "Helvetica", FontWeight -> "Plain", FontSlant -> "Italic"], 
                
                Cell[ 
                  StyleData[ "SB"], StyleMenuListing -> None, FontFamily -> 
                  "Helvetica", FontWeight -> "Bold", FontSlant -> "Plain"], 
                Cell[ 
                  StyleData[ "SBO"], StyleMenuListing -> None, FontFamily -> 
                  "Helvetica", FontWeight -> "Bold", FontSlant -> "Italic"], 
                Cell[ 
                  CellGroupData[ {
                    Cell[ 
                      StyleData[ "SO10"], StyleMenuListing -> None, 
                      FontFamily -> "Helvetica", FontSize -> 10, FontWeight -> 
                      "Plain", FontSlant -> "Italic"], 
                    Cell[ 
                      StyleData[ "SO10", "Printout"], StyleMenuListing -> 
                      None, FontFamily -> "Helvetica", FontSize -> 7, 
                      FontWeight -> "Plain", FontSlant -> "Italic"], 
                    Cell[ 
                      StyleData[ "SO10", "EnhancedPrintout"], 
                      StyleMenuListing -> None, FontFamily -> "Futura", 
                      FontSize -> 7, FontWeight -> "Plain", FontSlant -> 
                      "Italic"]}, Closed]]}, Closed]], 
            Cell[ 
              CellGroupData[ {
                Cell[ "Formulas and Programming", "Section"], 
                Cell[ 
                  CellGroupData[ {
                    Cell[ 
                      StyleData[ "InlineFormula"], CellMargins -> {{10, 4}, {
                      0, 8}}, CellHorizontalScrolling -> True, 
                      HyphenationOptions -> {"HyphenationCharacter" -> 
                      "\[Continuation]"}, LanguageCategory -> "Formula", 
                      ScriptLevel -> 1, SingleLetterItalics -> True], 
                    Cell[ 
                      StyleData[ "InlineFormula", "Presentation"], 
                      CellMargins -> {{24, 10}, {10, 10}}, LineSpacing -> {1, 
                      5}, FontSize -> 16], 
                    Cell[ 
                      StyleData[ "InlineFormula", "Condensed"], 
                      CellMargins -> {{8, 10}, {6, 6}}, LineSpacing -> {1, 1},
                       FontSize -> 11], 
                    Cell[ 
                      StyleData[ "InlineFormula", "Printout"], 
                      CellMargins -> {{2, 0}, {6, 6}}, FontSize -> 10]}, 
                    Closed]], 
                Cell[ 
                  CellGroupData[ {
                    Cell[ 
                      StyleData[ "DisplayFormula"], CellMargins -> {{42, 
                      Inherited}, {Inherited, Inherited}}, 
                      CellHorizontalScrolling -> True, DefaultFormatType -> 
                      DefaultInputFormatType, HyphenationOptions -> {
                      "HyphenationCharacter" -> "\[Continuation]"}, 
                      LanguageCategory -> "Formula", ScriptLevel -> 0, 
                      SingleLetterItalics -> True, 
                      UnderoverscriptBoxOptions -> {LimitsPositioning -> 
                      True}], 
                    Cell[ 
                      StyleData[ "DisplayFormula", "Presentation"], 
                      LineSpacing -> {1, 5}, FontSize -> 16], 
                    Cell[ 
                      StyleData[ "DisplayFormula", "Condensed"], 
                      LineSpacing -> {1, 1}, FontSize -> 11], 
                    Cell[ 
                      StyleData[ "DisplayFormula", "Printout"], FontSize -> 
                      10]}, Closed]], 
                Cell[ 
                  CellGroupData[ {
                    Cell[ 
                      StyleData[ "Program"], CellFrame -> {{0, 0}, {0.5, 
                      0.5}}, CellMargins -> {{10, 4}, {0, 8}}, 
                      CellHorizontalScrolling -> True, LanguageCategory -> 
                      "Formula", ScriptLevel -> 1, FontFamily -> "Courier"], 
                    Cell[ 
                      StyleData[ "Program", "Presentation"], CellMargins -> {{
                      24, 10}, {10, 10}}, LineSpacing -> {1, 5}, FontSize -> 
                      16], 
                    Cell[ 
                      StyleData[ "Program", "Condensed"], CellMargins -> {{8, 
                      10}, {6, 6}}, LineSpacing -> {1, 1}, FontSize -> 11], 
                    Cell[ 
                      StyleData[ "Program", "Printout"], CellMargins -> {{2, 
                      0}, {6, 6}}, FontSize -> 9]}, Closed]]}, Closed]], 
            Cell[ 
              CellGroupData[ {
                Cell[ "Hyperlink Styles", "Section"], 
                Cell[ 
                "The cells below define styles useful for making hypertext \
ButtonBoxes.  The \"Hyperlink\" style is for links within the same Notebook, \
or between Notebooks.", "Text"], 
                Cell[ 
                  CellGroupData[ {
                    Cell[ 
                      StyleData[ "Hyperlink"], StyleMenuListing -> None, 
                      ButtonStyleMenuListing -> Automatic, FontColor -> 
                      RGBColor[ 0, 0, 1], FontVariations -> {"Underline" -> 
                      True}, ButtonBoxOptions -> {ButtonFunction :> (
                      FrontEndExecute[ {
                        FrontEnd`NotebookLocate[ #2]}]&), Active -> True, 
                      ButtonNote -> ButtonData}], 
                    Cell[ 
                      StyleData[ "Hyperlink", "Presentation"], FontSize -> 
                      16], 
                    Cell[ 
                      StyleData[ "Hyperlink", "Condensed"], FontSize -> 11], 
                    Cell[ 
                      StyleData[ "Hyperlink", "Printout"], FontSize -> 10, 
                      FontColor -> GrayLevel[ 0], FontVariations -> {
                      "Underline" -> False}]}, Closed]], 
                Cell[ 
                "The following styles are for linking automatically to the \
on-line help system.", "Text"], 
                Cell[ 
                  CellGroupData[ {
                    Cell[ 
                      StyleData[ "MainBookLink"], StyleMenuListing -> None, 
                      ButtonStyleMenuListing -> Automatic, FontColor -> 
                      RGBColor[ 0, 0, 1], FontVariations -> {"Underline" -> 
                      True}, ButtonBoxOptions -> {ButtonFunction :> (
                      FrontEndExecute[ {
                        FrontEnd`HelpBrowserLookup[ "MainBook", #]}]&), 
                      Active -> True, ButtonFrame -> "None"}], 
                    Cell[ 
                      StyleData[ "MainBookLink", "Presentation"], FontSize -> 
                      16], 
                    Cell[ 
                      StyleData[ "MainBookLink", "Condensed"], FontSize -> 
                      11], 
                    Cell[ 
                      StyleData[ "MainBookLink", "Printout"], FontSize -> 10, 
                      FontColor -> GrayLevel[ 0], FontVariations -> {
                      "Underline" -> False}]}, Closed]], 
                Cell[ 
                  CellGroupData[ {
                    Cell[ 
                      StyleData[ "AddOnsLink"], StyleMenuListing -> None, 
                      ButtonStyleMenuListing -> Automatic, FontFamily -> 
                      "Courier", FontColor -> RGBColor[ 0, 0, 1], 
                      FontVariations -> {"Underline" -> True}, 
                      ButtonBoxOptions -> {ButtonFunction :> (
                      FrontEndExecute[ {
                        FrontEnd`HelpBrowserLookup[ "AddOns", #]}]&), Active -> 
                      True, ButtonFrame -> "None"}], 
                    Cell[ 
                      StyleData[ "AddOnsLink", "Presentation"], FontSize -> 
                      16], 
                    Cell[ 
                      StyleData[ "AddOnsLink", "Condensed"], FontSize -> 11], 
                    
                    Cell[ 
                      StyleData[ "AddOnsLink", "Printout"], FontSize -> 10, 
                      FontColor -> GrayLevel[ 0], FontVariations -> {
                      "Underline" -> False}]}, Closed]], 
                Cell[ 
                  CellGroupData[ {
                    Cell[ 
                      StyleData[ "RefGuideLink"], StyleMenuListing -> None, 
                      ButtonStyleMenuListing -> Automatic, FontFamily -> 
                      "Courier", FontColor -> RGBColor[ 0, 0, 1], 
                      FontVariations -> {"Underline" -> True}, 
                      ButtonBoxOptions -> {ButtonFunction :> (
                      FrontEndExecute[ {
                        FrontEnd`HelpBrowserLookup[ "RefGuide", #]}]&), 
                      Active -> True, ButtonFrame -> "None"}], 
                    Cell[ 
                      StyleData[ "RefGuideLink", "Presentation"], FontSize -> 
                      16], 
                    Cell[ 
                      StyleData[ "RefGuideLink", "Condensed"], FontSize -> 
                      11], 
                    Cell[ 
                      StyleData[ "RefGuideLink", "Printout"], FontSize -> 10, 
                      FontColor -> GrayLevel[ 0], FontVariations -> {
                      "Underline" -> False}]}, Closed]], 
                Cell[ 
                  CellGroupData[ {
                    Cell[ 
                      StyleData[ "GettingStartedLink"], StyleMenuListing -> 
                      None, ButtonStyleMenuListing -> Automatic, FontColor -> 
                      RGBColor[ 0, 0, 1], FontVariations -> {"Underline" -> 
                      True}, ButtonBoxOptions -> {ButtonFunction :> (
                      FrontEndExecute[ {
                        FrontEnd`HelpBrowserLookup[ "GettingStarted", #]}]&), 
                      Active -> True, ButtonFrame -> "None"}], 
                    Cell[ 
                      StyleData[ "GettingStartedLink", "Presentation"], 
                      FontSize -> 16], 
                    Cell[ 
                      StyleData[ "GettingStartedLink", "Condensed"], FontSize -> 
                      11], 
                    Cell[ 
                      StyleData[ "GettingStartedLink", "Printout"], FontSize -> 
                      10, FontColor -> GrayLevel[ 0], FontVariations -> {
                      "Underline" -> False}]}, Closed]], 
                Cell[ 
                  CellGroupData[ {
                    Cell[ 
                      StyleData[ "OtherInformationLink"], StyleMenuListing -> 
                      None, ButtonStyleMenuListing -> Automatic, FontColor -> 
                      RGBColor[ 0, 0, 1], FontVariations -> {"Underline" -> 
                      True}, ButtonBoxOptions -> {ButtonFunction :> (
                      FrontEndExecute[ {
                        FrontEnd`HelpBrowserLookup[ 
                        "OtherInformation", #]}]&), Active -> True, 
                      ButtonFrame -> "None"}], 
                    Cell[ 
                      StyleData[ "OtherInformationLink", "Presentation"], 
                      FontSize -> 16], 
                    Cell[ 
                      StyleData[ "OtherInformationLink", "Condensed"], 
                      FontSize -> 11], 
                    Cell[ 
                      StyleData[ "OtherInformationLink", "Printout"], 
                      FontSize -> 10, FontColor -> GrayLevel[ 0], 
                      FontVariations -> {"Underline" -> False}]}, Closed]]}, 
                Closed]], 
            Cell[ 
              CellGroupData[ {
                Cell[ "Styles for Headers and Footers", "Section"], 
                Cell[ 
                  StyleData[ "Header"], CellMargins -> {{0, 0}, {4, 1}}, 
                  DefaultNewInlineCellStyle -> "None", LanguageCategory -> 
                  "NaturalLanguage", StyleMenuListing -> None, FontSize -> 10,
                   FontSlant -> "Italic"], 
                Cell[ 
                  StyleData[ "Footer"], CellMargins -> {{0, 0}, {0, 4}}, 
                  DefaultNewInlineCellStyle -> "None", LanguageCategory -> 
                  "NaturalLanguage", StyleMenuListing -> None, FontSize -> 9, 
                  FontSlant -> "Italic"], 
                Cell[ 
                  StyleData[ "PageNumber"], CellMargins -> {{0, 0}, {4, 1}}, 
                  StyleMenuListing -> None, FontFamily -> "Times", FontSize -> 
                  10]}, Closed]], 
            Cell[ 
              CellGroupData[ {
                Cell[ "Palette Styles", "Section"], 
                Cell[ 
                "The cells below define styles that define standard \
ButtonFunctions, for use in palette buttons.", "Text"], 
                Cell[ 
                  StyleData[ "Paste"], StyleMenuListing -> None, 
                  ButtonStyleMenuListing -> Automatic, ButtonBoxOptions -> {
                  ButtonFunction :> (FrontEndExecute[ {
                    FrontEnd`NotebookApply[ 
                      FrontEnd`InputNotebook[ ], #, After]}]&)}], 
                Cell[ 
                  StyleData[ "Evaluate"], StyleMenuListing -> None, 
                  ButtonStyleMenuListing -> Automatic, ButtonBoxOptions -> {
                  ButtonFunction :> (FrontEndExecute[ {
                    FrontEnd`NotebookApply[ 
                      FrontEnd`InputNotebook[ ], #, All], 
                    SelectionEvaluate[ 
                      FrontEnd`InputNotebook[ ], All]}]&)}], 
                Cell[ 
                  StyleData[ "EvaluateCell"], StyleMenuListing -> None, 
                  ButtonStyleMenuListing -> Automatic, ButtonBoxOptions -> {
                  ButtonFunction :> (FrontEndExecute[ {
                    FrontEnd`NotebookApply[ 
                      FrontEnd`InputNotebook[ ], #, All], 
                    FrontEnd`SelectionMove[ 
                      FrontEnd`InputNotebook[ ], All, Cell, 1], 
                    FrontEnd`SelectionEvaluateCreateCell[ 
                      FrontEnd`InputNotebook[ ], All]}]&)}], 
                Cell[ 
                  StyleData[ "CopyEvaluate"], StyleMenuListing -> None, 
                  ButtonStyleMenuListing -> Automatic, ButtonBoxOptions -> {
                  ButtonFunction :> (FrontEndExecute[ {
                    FrontEnd`SelectionCreateCell[ 
                      FrontEnd`InputNotebook[ ], All], 
                    FrontEnd`NotebookApply[ 
                      FrontEnd`InputNotebook[ ], #, All], 
                    FrontEnd`SelectionEvaluate[ 
                      FrontEnd`InputNotebook[ ], All]}]&)}], 
                Cell[ 
                  StyleData[ "CopyEvaluateCell"], StyleMenuListing -> None, 
                  ButtonStyleMenuListing -> Automatic, ButtonBoxOptions -> {
                  ButtonFunction :> (FrontEndExecute[ {
                    FrontEnd`SelectionCreateCell[ 
                      FrontEnd`InputNotebook[ ], All], 
                    FrontEnd`NotebookApply[ 
                      FrontEnd`InputNotebook[ ], #, All], 
                    FrontEnd`SelectionEvaluateCreateCell[ 
                      FrontEnd`InputNotebook[ ], All]}]&)}]}, Closed]], 
            Cell[ 
              CellGroupData[ {
                Cell[ "Placeholder Styles", "Section"], 
                Cell[ 
                "The cells below define styles useful for making placeholder \
objects in palette templates.", "Text"], 
                Cell[ 
                  CellGroupData[ {
                    Cell[ 
                      StyleData[ "Placeholder"], Placeholder -> True, 
                      StyleMenuListing -> None, FontSlant -> "Italic", 
                      FontColor -> RGBColor[ 
                      0.89062300000000005, 0.86469799999999997, 
                        0.38475599999999999], TagBoxOptions -> {Editable -> 
                      False, Selectable -> False, StripWrapperBoxes -> 
                      False}], 
                    Cell[ 
                      StyleData[ "Placeholder", "Presentation"]], 
                    Cell[ 
                      StyleData[ "Placeholder", "Condensed"]], 
                    Cell[ 
                      StyleData[ "Placeholder", "Printout"]]}, Closed]], 
                Cell[ 
                  CellGroupData[ {
                    Cell[ 
                      StyleData[ "PrimaryPlaceholder"], StyleMenuListing -> 
                      None, DrawHighlighted -> True, FontSlant -> "Italic", 
                      Background -> RGBColor[ 
                      0.91250500000000001, 0.89179799999999998, 
                        0.50777399999999995], TagBoxOptions -> {Editable -> 
                      False, Selectable -> False, StripWrapperBoxes -> 
                      False}], 
                    Cell[ 
                      StyleData[ "PrimaryPlaceholder", "Presentation"]], 
                    Cell[ 
                      StyleData[ "PrimaryPlaceholder", "Condensed"]], 
                    Cell[ 
                      StyleData[ "PrimaryPlaceholder", "Printout"]]}, 
                    Closed]]}, Closed]], 
            Cell[ 
              CellGroupData[ {
                Cell[ "FormatType Styles", "Section"], 
                Cell[ 
                "The cells below define styles that are mixed in with the \
styles of most cells.  If a cell's FormatType matches the name of one of the \
styles defined below, then that style is applied between the cell's style and \
its own options. This is particularly true of Input and Output.", "Text"], 
                Cell[ 
                  StyleData[ "CellExpression"], PageWidth -> DirectedInfinity[
                   1], CellMargins -> {{6, Inherited}, {Inherited, 
                  Inherited}}, ShowCellLabel -> False, ShowSpecialCharacters -> 
                  False, AllowInlineCells -> False, Hyphenation -> False, 
                  AutoItalicWords -> {}, StyleMenuListing -> None, FontFamily -> 
                  "Courier", FontSize -> 12, Background -> GrayLevel[ 1]], 
                Cell[ 
                  StyleData[ "InputForm"], InputAutoReplacements -> {}, 
                  AllowInlineCells -> False, Hyphenation -> False, 
                  StyleMenuListing -> None, FontFamily -> "Courier"], 
                Cell[ 
                  StyleData[ "OutputForm"], PageWidth -> DirectedInfinity[ 1],
                   TextAlignment -> Left, LineSpacing -> {0.59999999999999998,
                   1}, StyleMenuListing -> None, FontFamily -> "Courier"], 
                Cell[ 
                  StyleData[ "StandardForm"], InputAutoReplacements -> {"->" -> 
                  "\[Rule]", ":>" -> "\[RuleDelayed]", "<=" -> "\[LessEqual]",
                   ">=" -> "\[GreaterEqual]", "!=" -> "\[NotEqual]", "==" -> 
                  "\[Equal]", Inherited}, LineSpacing -> {1.25, 0}, 
                  StyleMenuListing -> None, FontFamily -> "Courier"], 
                Cell[ 
                  StyleData[ "TraditionalForm"], InputAutoReplacements -> {
                  "->" -> "\[Rule]", ":>" -> "\[RuleDelayed]", "<=" -> 
                  "\[LessEqual]", ">=" -> "\[GreaterEqual]", "!=" -> 
                  "\[NotEqual]", "==" -> "\[Equal]", Inherited}, 
                  LineSpacing -> {1.25, 0}, SingleLetterItalics -> True, 
                  TraditionalFunctionNotation -> True, DelimiterMatching -> 
                  None, StyleMenuListing -> None], 
                Cell[ 
                "The style defined below is mixed in to any cell that is in \
an inline cell within another.", "Text"], 
                Cell[ 
                  StyleData[ "InlineCell"], TextAlignment -> Left, 
                  ScriptLevel -> 1, StyleMenuListing -> None], 
                Cell[ 
                  StyleData[ "InlineCellEditing"], StyleMenuListing -> None, 
                  Background -> RGBColor[ 1, 0.749996, 0.80000000000000004]]},
                 Closed]], 
            Cell[ 
              CellGroupData[ {
                Cell[ "Automatic Styles", "Section"], 
                Cell[ 
                "The cells below define styles that are used to affect the \
display of certain types of objects in typeset expressions.  For example, \
\"UnmatchedBracket\" style defines how unmatched bracket, curly bracket, and \
parenthesis characters are displayed (typically by coloring them to make them \
stand out).", "Text"], 
                Cell[ 
                  StyleData[ "UnmatchedBracket"], StyleMenuListing -> None, 
                  FontColor -> RGBColor[ 
                  0.76000599999999996, 0.33000699999999999, 
                    0.80000000000000004]]}, Closed]]}, Open]], 
        Cell[ 
          CellGroupData[ {
            Cell[ 
            "Notation Package Styles", "Section", GeneratedCell -> True, 
              CellTags -> "NotationPackage"], 
            Cell[ 
            "The cells below define certain styles needed by the Notation \
package. These styles serve to make visible otherwise invisible tagboxes.", 
              "Text", GeneratedCell -> True, CellTags -> "NotationPackage"], 
            Cell[ 
              StyleData[ "NotationTemplateStyle"], GeneratedCell -> True, 
              StyleMenuListing -> None, Background -> RGBColor[ 
              1, 1, 0.85000399999999998], TagBoxOptions -> {SyntaxForm -> 
              "symbol"}, CellTags -> "NotationPackage"], 
            Cell[ 
              StyleData[ "NotationPatternWrapperStyle"], GeneratedCell -> 
              True, StyleMenuListing -> None, Background -> RGBColor[ 
              1, 0.90000800000000003, 0.97999499999999995], TagBoxOptions -> {
              SyntaxForm -> "symbol"}, CellTags -> "NotationPackage"], 
            Cell[ 
              StyleData[ "NotationMadeBoxesWrapperStyle"], GeneratedCell -> 
              True, StyleMenuListing -> None, Background -> RGBColor[ 
              0.90000800000000003, 0.88999799999999996, 1], TagBoxOptions -> {
              SyntaxForm -> "symbol"}, CellTags -> "NotationPackage"]}, 
            Closed]]}], "notation"->RowBox[ {"Notation", "[", 
        RowBox[ {
          TagBox[ 
          "\[Placeholder]", NotationBoxTag, TagStyle -> 
            "NotationTemplateStyle"], " ", "\[DoubleLongLeftRightArrow]", " ",
           
          TagBox[ 
          "\[Placeholder]", NotationBoxTag, TagStyle -> 
            "NotationTemplateStyle"]}], "]"}], 
    "notation>"->RowBox[ {"Notation", "[", 
        RowBox[ {
          TagBox[ 
          "\[Placeholder]", NotationBoxTag, TagStyle -> 
            "NotationTemplateStyle"], " ", "\[DoubleLongRightArrow]", " ", 
          TagBox[ 
          "\[Placeholder]", NotationBoxTag, TagStyle -> 
            "NotationTemplateStyle"]}], "]"}], 
    "notation<"->RowBox[ {"Notation", "[", 
        RowBox[ {
          TagBox[ 
          "\[Placeholder]", NotationBoxTag, TagStyle -> 
            "NotationTemplateStyle"], " ", "\[DoubleLongLeftArrow]", " ", 
          TagBox[ 
          "\[Placeholder]", NotationBoxTag, TagStyle -> 
            "NotationTemplateStyle"]}], "]"}], 
    "symb"->RowBox[ {"Symbolize", "[", 
        TagBox[ 
        "\[Placeholder]", NotationBoxTag, TagStyle -> 
          "NotationTemplateStyle"], "]"}], 
    "infixnotation"->RowBox[ {"InfixNotation", "[", 
        RowBox[ {
          TagBox[ 
          "\[Placeholder]", NotationBoxTag, TagStyle -> 
            "NotationTemplateStyle"], ",", "\[Placeholder]"}], "]"}], 
    "addia"->RowBox[ {"AddInputAlias", "[", 
        RowBox[ {
          TagBox[ 
          "\[Placeholder]", NotationBoxTag, TagStyle -> 
            "NotationTemplateStyle"], ",", "\[Placeholder]"}], "]"}], 
    "pattwraper"->TagBox[ 
      "\[Placeholder]", NotationPatternTag, TagStyle -> 
        "NotationPatternWrapperStyle"], 
    "madeboxeswraper"->TagBox[ 
      "\[Placeholder]", NotationMadeBoxesTag, TagStyle -> 
        "NotationMadeBoxesWrapperStyle"]},
Magnification->1,
StyleDefinitions -> Notebook[{
  
  Cell[CellGroupData[{
  Cell["Style Definitions", "Subtitle"],
  
  Cell["\<\
Modify the definitions below to change the default appearance of \
all cells in a given style.  Make modifications to any definition using \
commands in the Format menu.\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell["Style Environment Names", "Section"],
  
  Cell[StyleData[All, "Working"],
    PageWidth->WindowWidth,
    CellLabelMargins->{{12, Inherited}, {Inherited, Inherited}},
    ScriptMinSize->9],
  
  Cell[StyleData[All, "Presentation"],
    PageWidth->WindowWidth,
    CellLabelMargins->{{24, Inherited}, {Inherited, Inherited}},
    ScriptMinSize->12],
  
  Cell[StyleData[All, "Condensed"],
    PageWidth->WindowWidth,
    CellLabelMargins->{{8, Inherited}, {Inherited, Inherited}},
    ScriptMinSize->8],
  
  Cell[StyleData[All, "Printout"],
    PageWidth->PaperWidth,
    CellLabelMargins->{{2, Inherited}, {Inherited, Inherited}},
    ScriptMinSize->5,
    PrivateFontOptions->{"FontType"->"Outline"}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Notebook Options", "Section"],
  
  Cell["\<\
The options defined for the style below will be used at the \
Notebook level.\
\>", "Text"],
  
  Cell[StyleData["Notebook"],
    PageHeaders->{{Cell[ 
            TextData[ {
              CounterBox[ "Page"]}], "PageNumber"], None, Cell[ 
            TextData[ {
              ValueBox[ "FileName"]}], "Header"]}, {Cell[ 
            TextData[ {
              ValueBox[ "FileName"]}], "Header"], None, Cell[ 
            TextData[ {
              CounterBox[ "Page"]}], "PageNumber"]}},
    CellFrameLabelMargins->6,
    StyleMenuListing->None]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Styles for Headings", "Section"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Title"],
    CellMargins->{{12, Inherited}, {20, 40}},
    CellGroupingRules->{"TitleGrouping", 0},
    PageBreakBelow->False,
    DefaultNewInlineCellStyle->"None",
    InputAutoReplacements->{"TeX"->StyleBox[ 
            RowBox[ {"T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.074999999999999997, \
-0.085000000000000006}, {0, 0}}, BoxBaselineShift -> 0.5], "X"}]], 
        "LaTeX"->StyleBox[ 
            RowBox[ {"L", 
              StyleBox[ 
                AdjustmentBox[ 
                "A", BoxMargins -> {{-0.35999999999999999, \
-0.10000000000000001}, {0, 0}}, BoxBaselineShift -> -0.20000000000000001], 
                FontSize -> Smaller], "T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.074999999999999997, \
-0.085000000000000006}, {0, 0}}, BoxBaselineShift -> 0.5], "X"}]], 
        "mma"->"Mathematica", "Mma"->"Mathematica", "MMA"->"Mathematica"},
    LanguageCategory->"NaturalLanguage",
    CounterIncrements->"Title",
    CounterAssignments->{{"Section", 0}, {"Equation", 0}, {"Figure", 0}, {
        "Subtitle", 0}, {"Subsubtitle", 0}},
    FontFamily->"Helvetica",
    FontSize->36,
    FontWeight->"Bold"],
  
  Cell[StyleData["Title", "Presentation"],
    CellMargins->{{24, 10}, {20, 40}},
    LineSpacing->{1, 0},
    FontSize->44],
  
  Cell[StyleData["Title", "Condensed"],
    CellMargins->{{8, 10}, {4, 8}},
    FontSize->20],
  
  Cell[StyleData["Title", "Printout"],
    CellMargins->{{2, 10}, {12, 30}},
    FontSize->24]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Subtitle"],
    CellMargins->{{12, Inherited}, {20, 15}},
    CellGroupingRules->{"TitleGrouping", 10},
    PageBreakBelow->False,
    DefaultNewInlineCellStyle->"None",
    InputAutoReplacements->{"TeX"->StyleBox[ 
            RowBox[ {"T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.074999999999999997, \
-0.085000000000000006}, {0, 0}}, BoxBaselineShift -> 0.5], "X"}]], 
        "LaTeX"->StyleBox[ 
            RowBox[ {"L", 
              StyleBox[ 
                AdjustmentBox[ 
                "A", BoxMargins -> {{-0.35999999999999999, \
-0.10000000000000001}, {0, 0}}, BoxBaselineShift -> -0.20000000000000001], 
                FontSize -> Smaller], "T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.074999999999999997, \
-0.085000000000000006}, {0, 0}}, BoxBaselineShift -> 0.5], "X"}]], 
        "mma"->"Mathematica", "Mma"->"Mathematica", "MMA"->"Mathematica"},
    LanguageCategory->"NaturalLanguage",
    CounterIncrements->"Subtitle",
    CounterAssignments->{{"Section", 0}, {"Equation", 0}, {"Figure", 0}, {
        "Subsubtitle", 0}},
    FontFamily->"Helvetica",
    FontSize->24],
  
  Cell[StyleData["Subtitle", "Presentation"],
    CellMargins->{{24, 10}, {20, 20}},
    LineSpacing->{1, 0},
    FontSize->36],
  
  Cell[StyleData["Subtitle", "Condensed"],
    CellMargins->{{8, 10}, {4, 4}},
    FontSize->14],
  
  Cell[StyleData["Subtitle", "Printout"],
    CellMargins->{{2, 10}, {12, 8}},
    FontSize->18]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Subsubtitle"],
    CellMargins->{{12, Inherited}, {20, 15}},
    CellGroupingRules->{"TitleGrouping", 20},
    PageBreakBelow->False,
    DefaultNewInlineCellStyle->"None",
    InputAutoReplacements->{"TeX"->StyleBox[ 
            RowBox[ {"T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.074999999999999997, \
-0.085000000000000006}, {0, 0}}, BoxBaselineShift -> 0.5], "X"}]], 
        "LaTeX"->StyleBox[ 
            RowBox[ {"L", 
              StyleBox[ 
                AdjustmentBox[ 
                "A", BoxMargins -> {{-0.35999999999999999, \
-0.10000000000000001}, {0, 0}}, BoxBaselineShift -> -0.20000000000000001], 
                FontSize -> Smaller], "T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.074999999999999997, \
-0.085000000000000006}, {0, 0}}, BoxBaselineShift -> 0.5], "X"}]], 
        "mma"->"Mathematica", "Mma"->"Mathematica", "MMA"->"Mathematica"},
    LanguageCategory->"NaturalLanguage",
    CounterIncrements->"Subsubtitle",
    CounterAssignments->{{"Section", 0}, {"Equation", 0}, {"Figure", 0}},
    FontFamily->"Helvetica",
    FontSize->14,
    FontSlant->"Italic"],
  
  Cell[StyleData["Subsubtitle", "Presentation"],
    CellMargins->{{24, 10}, {20, 20}},
    LineSpacing->{1, 0},
    FontSize->24],
  
  Cell[StyleData["Subsubtitle", "Condensed"],
    CellMargins->{{8, 10}, {8, 8}},
    FontSize->12],
  
  Cell[StyleData["Subsubtitle", "Printout"],
    CellMargins->{{2, 10}, {12, 8}},
    FontSize->14]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Section"],
    CellDingbat->"\[FilledSquare]",
    CellMargins->{{25, Inherited}, {8, 24}},
    CellGroupingRules->{"SectionGrouping", 30},
    PageBreakBelow->False,
    DefaultNewInlineCellStyle->"None",
    InputAutoReplacements->{"TeX"->StyleBox[ 
            RowBox[ {"T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.074999999999999997, \
-0.085000000000000006}, {0, 0}}, BoxBaselineShift -> 0.5], "X"}]], 
        "LaTeX"->StyleBox[ 
            RowBox[ {"L", 
              StyleBox[ 
                AdjustmentBox[ 
                "A", BoxMargins -> {{-0.35999999999999999, \
-0.10000000000000001}, {0, 0}}, BoxBaselineShift -> -0.20000000000000001], 
                FontSize -> Smaller], "T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.074999999999999997, \
-0.085000000000000006}, {0, 0}}, BoxBaselineShift -> 0.5], "X"}]], 
        "mma"->"Mathematica", "Mma"->"Mathematica", "MMA"->"Mathematica"},
    LanguageCategory->"NaturalLanguage",
    CounterIncrements->"Section",
    CounterAssignments->{{"Subsection", 0}, {"Subsubsection", 0}},
    FontFamily->"Helvetica",
    FontSize->16,
    FontWeight->"Bold"],
  
  Cell[StyleData["Section", "Presentation"],
    CellMargins->{{40, 10}, {11, 32}},
    LineSpacing->{1, 0},
    FontSize->24],
  
  Cell[StyleData["Section", "Condensed"],
    CellMargins->{{18, Inherited}, {6, 12}},
    FontSize->12],
  
  Cell[StyleData["Section", "Printout"],
    CellMargins->{{13, 0}, {7, 22}},
    FontSize->14]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Subsection"],
    CellDingbat->"\[FilledSmallSquare]",
    CellMargins->{{22, Inherited}, {8, 20}},
    CellGroupingRules->{"SectionGrouping", 40},
    PageBreakBelow->False,
    DefaultNewInlineCellStyle->"None",
    InputAutoReplacements->{"TeX"->StyleBox[ 
            RowBox[ {"T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.074999999999999997, \
-0.085000000000000006}, {0, 0}}, BoxBaselineShift -> 0.5], "X"}]], 
        "LaTeX"->StyleBox[ 
            RowBox[ {"L", 
              StyleBox[ 
                AdjustmentBox[ 
                "A", BoxMargins -> {{-0.35999999999999999, \
-0.10000000000000001}, {0, 0}}, BoxBaselineShift -> -0.20000000000000001], 
                FontSize -> Smaller], "T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.074999999999999997, \
-0.085000000000000006}, {0, 0}}, BoxBaselineShift -> 0.5], "X"}]], 
        "mma"->"Mathematica", "Mma"->"Mathematica", "MMA"->"Mathematica"},
    LanguageCategory->"NaturalLanguage",
    CounterIncrements->"Subsection",
    CounterAssignments->{{"Subsubsection", 0}},
    FontFamily->"Times",
    FontSize->14,
    FontWeight->"Bold"],
  
  Cell[StyleData["Subsection", "Presentation"],
    CellMargins->{{36, 10}, {11, 32}},
    LineSpacing->{1, 0},
    FontSize->22],
  
  Cell[StyleData["Subsection", "Condensed"],
    CellMargins->{{16, Inherited}, {6, 12}},
    FontSize->12],
  
  Cell[StyleData["Subsection", "Printout"],
    CellMargins->{{9, 0}, {7, 22}},
    FontSize->12]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Subsubsection"],
    CellDingbat->"\[FilledSmallSquare]",
    CellMargins->{{22, Inherited}, {8, 18}},
    CellGroupingRules->{"SectionGrouping", 50},
    PageBreakBelow->False,
    DefaultNewInlineCellStyle->"None",
    InputAutoReplacements->{"TeX"->StyleBox[ 
            RowBox[ {"T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.074999999999999997, \
-0.085000000000000006}, {0, 0}}, BoxBaselineShift -> 0.5], "X"}]], 
        "LaTeX"->StyleBox[ 
            RowBox[ {"L", 
              StyleBox[ 
                AdjustmentBox[ 
                "A", 
                  BoxMargins -> {{-0.35999999999999999, \
-0.10000000000000001}, {0, 0}}, BoxBaselineShift -> -0.20000000000000001], 
                FontSize -> Smaller], "T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.074999999999999997, \
-0.085000000000000006}, {0, 0}}, BoxBaselineShift -> 0.5], "X"}]], 
        "mma"->"Mathematica", "Mma"->"Mathematica", "MMA"->"Mathematica"},
    LanguageCategory->"NaturalLanguage",
    CounterIncrements->"Subsubsection",
    FontFamily->"Times",
    FontWeight->"Bold"],
  
  Cell[StyleData["Subsubsection", "Presentation"],
    CellMargins->{{34, 10}, {11, 26}},
    LineSpacing->{1, 0},
    FontSize->18],
  
  Cell[StyleData["Subsubsection", "Condensed"],
    CellMargins->{{17, Inherited}, {6, 12}},
    FontSize->10],
  
  Cell[StyleData["Subsubsection", "Printout"],
    CellMargins->{{9, 0}, {7, 14}},
    FontSize->11]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Styles for Body Text", "Section"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Text"],
    CellMargins->{{12, 10}, {7, 7}},
    InputAutoReplacements->{"TeX"->StyleBox[ 
            RowBox[ {"T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.074999999999999997, \
-0.085000000000000006}, {0, 0}}, BoxBaselineShift -> 0.5], "X"}]], 
        "LaTeX"->StyleBox[ 
            RowBox[ {"L", 
              StyleBox[ 
                AdjustmentBox[ 
                "A", BoxMargins -> {{-0.35999999999999999, \
-0.10000000000000001}, {0, 0}}, BoxBaselineShift -> -0.20000000000000001], 
                FontSize -> Smaller], "T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.074999999999999997, \
-0.085000000000000006}, {0, 0}}, BoxBaselineShift -> 0.5], "X"}]], 
        "mma"->"Mathematica", "Mma"->"Mathematica", "MMA"->"Mathematica"},
    Hyphenation->True,
    LineSpacing->{1, 3},
    CounterIncrements->"Text"],
  
  Cell[StyleData["Text", "Presentation"],
    CellMargins->{{24, 10}, {10, 10}},
    LineSpacing->{1, 5},
    FontSize->16],
  
  Cell[StyleData["Text", "Condensed"],
    CellMargins->{{8, 10}, {6, 6}},
    LineSpacing->{1, 1},
    FontSize->11],
  
  Cell[StyleData["Text", "Printout"],
    CellMargins->{{2, 2}, {6, 6}},
    TextJustification->0.5,
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["SmallText"],
    CellMargins->{{12, 10}, {6, 6}},
    DefaultNewInlineCellStyle->"None",
    Hyphenation->True,
    LineSpacing->{1, 3},
    LanguageCategory->"NaturalLanguage",
    CounterIncrements->"SmallText",
    FontFamily->"Helvetica",
    FontSize->9],
  
  Cell[StyleData["SmallText", "Presentation"],
    CellMargins->{{24, 10}, {8, 8}},
    LineSpacing->{1, 5},
    FontSize->12],
  
  Cell[StyleData["SmallText", "Condensed"],
    CellMargins->{{8, 10}, {5, 5}},
    LineSpacing->{1, 2},
    FontSize->9],
  
  Cell[StyleData["SmallText", "Printout"],
    CellMargins->{{2, 2}, {5, 5}},
    TextJustification->0.5,
    FontSize->7]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Styles for Input/Output", "Section"],
  
  Cell["\<\
The cells in this section define styles used for input and output \
to the kernel.  Be careful when modifying, renaming, or removing these \
styles, because the front end associates special meanings with these style \
names. Some attributes for these styles are actually set in FormatType Styles \
(in the last section of this stylesheet). \
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Input"],
    CellMargins->{{45, 10}, {5, 7}},
    Evaluatable->True,
    CellGroupingRules->"InputGrouping",
    CellHorizontalScrolling->True,
    PageBreakWithin->False,
    GroupPageBreakWithin->False,
    DefaultFormatType->DefaultInputFormatType,
    HyphenationOptions->{"HyphenationCharacter"->"\[Continuation]"},
    AutoItalicWords->{},
    LanguageCategory->"Formula",
    FormatType->InputForm,
    ShowStringCharacters->True,
    NumberMarks->True,
    LinebreakAdjustments->{0.85, 2, 10, 0, 1},
    CounterIncrements->"Input",
    FontWeight->"Bold"],
  
  Cell[StyleData["Input", "Presentation"],
    CellMargins->{{72, Inherited}, {8, 10}},
    LineSpacing->{1, 0},
    FontSize->16],
  
  Cell[StyleData["Input", "Condensed"],
    CellMargins->{{40, 10}, {2, 3}},
    FontSize->11],
  
  Cell[StyleData["Input", "Printout"],
    CellMargins->{{39, 0}, {4, 6}},
    LinebreakAdjustments->{0.85, 2, 10, 1, 1},
    FontSize->9]
  }, Closed]],
  
  Cell[StyleData["InputOnly"],
    Evaluatable->True,
    CellGroupingRules->"InputGrouping",
    CellHorizontalScrolling->True,
    DefaultFormatType->DefaultInputFormatType,
    HyphenationOptions->{"HyphenationCharacter"->"\[Continuation]"},
    AutoItalicWords->{},
    LanguageCategory->"Formula",
    FormatType->InputForm,
    ShowStringCharacters->True,
    NumberMarks->True,
    LinebreakAdjustments->{0.85, 2, 10, 0, 1},
    CounterIncrements->"Input",
    StyleMenuListing->None,
    FontWeight->"Bold"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Output"],
    CellMargins->{{47, 10}, {7, 5}},
    CellEditDuplicate->True,
    CellGroupingRules->"OutputGrouping",
    CellHorizontalScrolling->True,
    PageBreakWithin->False,
    GroupPageBreakWithin->False,
    GeneratedCell->True,
    CellAutoOverwrite->True,
    DefaultFormatType->DefaultOutputFormatType,
    HyphenationOptions->{"HyphenationCharacter"->"\[Continuation]"},
    AutoItalicWords->{},
    LanguageCategory->"Formula",
    FormatType->InputForm,
    CounterIncrements->"Output"],
  
  Cell[StyleData["Output", "Presentation"],
    CellMargins->{{72, Inherited}, {10, 8}},
    LineSpacing->{1, 0},
    FontSize->16],
  
  Cell[StyleData["Output", "Condensed"],
    CellMargins->{{41, Inherited}, {3, 2}},
    FontSize->11],
  
  Cell[StyleData["Output", "Printout"],
    CellMargins->{{39, 0}, {6, 4}},
    FontSize->9]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Message"],
    CellMargins->{{45, Inherited}, {Inherited, Inherited}},
    CellGroupingRules->"OutputGrouping",
    PageBreakWithin->False,
    GroupPageBreakWithin->False,
    GeneratedCell->True,
    CellAutoOverwrite->True,
    ShowCellLabel->False,
    DefaultFormatType->DefaultOutputFormatType,
    HyphenationOptions->{"HyphenationCharacter"->"\[Continuation]"},
    AutoItalicWords->{},
    FormatType->InputForm,
    CounterIncrements->"Message",
    StyleMenuListing->None,
    FontSize->11,
    FontColor->RGBColor[0, 0, 1]],
  
  Cell[StyleData["Message", "Presentation"],
    CellMargins->{{72, Inherited}, {Inherited, Inherited}},
    LineSpacing->{1, 0},
    FontSize->16],
  
  Cell[StyleData["Message", "Condensed"],
    CellMargins->{{41, Inherited}, {Inherited, Inherited}},
    FontSize->11],
  
  Cell[StyleData["Message", "Printout"],
    CellMargins->{{39, Inherited}, {Inherited, Inherited}},
    FontSize->7,
    FontColor->GrayLevel[0]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Print"],
    CellMargins->{{45, Inherited}, {Inherited, Inherited}},
    CellGroupingRules->"OutputGrouping",
    CellHorizontalScrolling->True,
    PageBreakWithin->False,
    GroupPageBreakWithin->False,
    GeneratedCell->True,
    CellAutoOverwrite->True,
    ShowCellLabel->False,
    DefaultFormatType->DefaultOutputFormatType,
    HyphenationOptions->{"HyphenationCharacter"->"\[Continuation]"},
    AutoItalicWords->{},
    FormatType->InputForm,
    CounterIncrements->"Print",
    StyleMenuListing->None],
  
  Cell[StyleData["Print", "Presentation"],
    CellMargins->{{72, Inherited}, {Inherited, Inherited}},
    LineSpacing->{1, 0},
    FontSize->16],
  
  Cell[StyleData["Print", "Condensed"],
    CellMargins->{{41, Inherited}, {Inherited, Inherited}},
    FontSize->11],
  
  Cell[StyleData["Print", "Printout"],
    CellMargins->{{39, Inherited}, {Inherited, Inherited}},
    FontSize->8]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Graphics"],
    CellMargins->{{4, Inherited}, {Inherited, Inherited}},
    CellGroupingRules->"GraphicsGrouping",
    CellHorizontalScrolling->True,
    PageBreakWithin->False,
    GeneratedCell->True,
    CellAutoOverwrite->True,
    ShowCellLabel->False,
    DefaultFormatType->DefaultOutputFormatType,
    LanguageCategory->None,
    FormatType->InputForm,
    CounterIncrements->"Graphics",
    ImageMargins->{{43, Inherited}, {Inherited, 0}},
    StyleMenuListing->None,
    FontFamily->"Courier",
    FontSize->10],
  
  Cell[StyleData["Graphics", "Presentation"],
    ImageMargins->{{62, Inherited}, {Inherited, 0}}],
  
  Cell[StyleData["Graphics", "Condensed"],
    ImageMargins->{{38, Inherited}, {Inherited, 0}},
    Magnification->0.6],
  
  Cell[StyleData["Graphics", "Printout"],
    ImageMargins->{{30, Inherited}, {Inherited, 0}},
    Magnification->0.8]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["CellLabel"],
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->9,
    FontColor->RGBColor[0, 0, 1]],
  
  Cell[StyleData["CellLabel", "Presentation"],
    FontSize->12],
  
  Cell[StyleData["CellLabel", "Condensed"],
    FontSize->9],
  
  Cell[StyleData["CellLabel", "Printout"],
    FontFamily->"Courier",
    FontSize->8,
    FontSlant->"Italic",
    FontColor->GrayLevel[0]]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Inline Formatting", "Section"],
  
  Cell["\<\
These styles are for modifying individual words or letters in a \
cell exclusive of the cell tag.\
\>", "Text"],
  
  Cell[StyleData["RM"],
    StyleMenuListing->None,
    FontWeight->"Plain",
    FontSlant->"Plain"],
  
  Cell[StyleData["BF"],
    StyleMenuListing->None,
    FontWeight->"Bold"],
  
  Cell[StyleData["IT"],
    StyleMenuListing->None,
    FontSlant->"Italic"],
  
  Cell[StyleData["TR"],
    StyleMenuListing->None,
    FontFamily->"Times",
    FontWeight->"Plain",
    FontSlant->"Plain"],
  
  Cell[StyleData["TI"],
    StyleMenuListing->None,
    FontFamily->"Times",
    FontWeight->"Plain",
    FontSlant->"Italic"],
  
  Cell[StyleData["TB"],
    StyleMenuListing->None,
    FontFamily->"Times",
    FontWeight->"Bold",
    FontSlant->"Plain"],
  
  Cell[StyleData["TBI"],
    StyleMenuListing->None,
    FontFamily->"Times",
    FontWeight->"Bold",
    FontSlant->"Italic"],
  
  Cell[StyleData["MR"],
    StyleMenuListing->None,
    FontFamily->"Courier",
    FontWeight->"Plain",
    FontSlant->"Plain"],
  
  Cell[StyleData["MO"],
    StyleMenuListing->None,
    FontFamily->"Courier",
    FontWeight->"Plain",
    FontSlant->"Italic"],
  
  Cell[StyleData["MB"],
    StyleMenuListing->None,
    FontFamily->"Courier",
    FontWeight->"Bold",
    FontSlant->"Plain"],
  
  Cell[StyleData["MBO"],
    StyleMenuListing->None,
    FontFamily->"Courier",
    FontWeight->"Bold",
    FontSlant->"Italic"],
  
  Cell[StyleData["SR"],
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontWeight->"Plain",
    FontSlant->"Plain"],
  
  Cell[StyleData["SO"],
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontWeight->"Plain",
    FontSlant->"Italic"],
  
  Cell[StyleData["SB"],
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontWeight->"Bold",
    FontSlant->"Plain"],
  
  Cell[StyleData["SBO"],
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontWeight->"Bold",
    FontSlant->"Italic"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["SO10"],
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->10,
    FontWeight->"Plain",
    FontSlant->"Italic"],
  
  Cell[StyleData["SO10", "Printout"],
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->7,
    FontWeight->"Plain",
    FontSlant->"Italic"],
  
  Cell[StyleData["SO10", "EnhancedPrintout"],
    StyleMenuListing->None,
    FontFamily->"Futura",
    FontSize->7,
    FontWeight->"Plain",
    FontSlant->"Italic"]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Formulas and Programming", "Section"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["InlineFormula"],
    CellMargins->{{10, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    HyphenationOptions->{"HyphenationCharacter"->"\[Continuation]"},
    LanguageCategory->"Formula",
    ScriptLevel->1,
    SingleLetterItalics->True],
  
  Cell[StyleData["InlineFormula", "Presentation"],
    CellMargins->{{24, 10}, {10, 10}},
    LineSpacing->{1, 5},
    FontSize->16],
  
  Cell[StyleData["InlineFormula", "Condensed"],
    CellMargins->{{8, 10}, {6, 6}},
    LineSpacing->{1, 1},
    FontSize->11],
  
  Cell[StyleData["InlineFormula", "Printout"],
    CellMargins->{{2, 0}, {6, 6}},
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["DisplayFormula"],
    CellMargins->{{42, Inherited}, {Inherited, Inherited}},
    CellHorizontalScrolling->True,
    DefaultFormatType->DefaultInputFormatType,
    HyphenationOptions->{"HyphenationCharacter"->"\[Continuation]"},
    LanguageCategory->"Formula",
    ScriptLevel->0,
    SingleLetterItalics->True,
    UnderoverscriptBoxOptions->{LimitsPositioning->True}],
  
  Cell[StyleData["DisplayFormula", "Presentation"],
    LineSpacing->{1, 5},
    FontSize->16],
  
  Cell[StyleData["DisplayFormula", "Condensed"],
    LineSpacing->{1, 1},
    FontSize->11],
  
  Cell[StyleData["DisplayFormula", "Printout"],
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Program"],
    CellFrame->{{0, 0}, {0.5, 0.5}},
    CellMargins->{{10, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    LanguageCategory->"Formula",
    ScriptLevel->1,
    FontFamily->"Courier"],
  
  Cell[StyleData["Program", "Presentation"],
    CellMargins->{{24, 10}, {10, 10}},
    LineSpacing->{1, 5},
    FontSize->16],
  
  Cell[StyleData["Program", "Condensed"],
    CellMargins->{{8, 10}, {6, 6}},
    LineSpacing->{1, 1},
    FontSize->11],
  
  Cell[StyleData["Program", "Printout"],
    CellMargins->{{2, 0}, {6, 6}},
    FontSize->9]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Hyperlink Styles", "Section"],
  
  Cell["\<\
The cells below define styles useful for making hypertext \
ButtonBoxes.  The \"Hyperlink\" style is for links within the same Notebook, \
or between Notebooks.\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Hyperlink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontColor->RGBColor[0, 0, 1],
    FontVariations->{"Underline"->True},
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`NotebookLocate[ #2]}]&),
    Active->True,
    ButtonNote->ButtonData}],
  
  Cell[StyleData["Hyperlink", "Presentation"],
    FontSize->16],
  
  Cell[StyleData["Hyperlink", "Condensed"],
    FontSize->11],
  
  Cell[StyleData["Hyperlink", "Printout"],
    FontSize->10,
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Closed]],
  
  Cell["\<\
The following styles are for linking automatically to the on-line \
help system.\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["MainBookLink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontColor->RGBColor[0, 0, 1],
    FontVariations->{"Underline"->True},
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`HelpBrowserLookup[ "MainBook", #]}]&),
    Active->True,
    ButtonFrame->"None"}],
  
  Cell[StyleData["MainBookLink", "Presentation"],
    FontSize->16],
  
  Cell[StyleData["MainBookLink", "Condensed"],
    FontSize->11],
  
  Cell[StyleData["MainBookLink", "Printout"],
    FontSize->10,
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["AddOnsLink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontFamily->"Courier",
    FontColor->RGBColor[0, 0, 1],
    FontVariations->{"Underline"->True},
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`HelpBrowserLookup[ "AddOns", #]}]&),
    Active->True,
    ButtonFrame->"None"}],
  
  Cell[StyleData["AddOnsLink", "Presentation"],
    FontSize->16],
  
  Cell[StyleData["AddOnsLink", "Condensed"],
    FontSize->11],
  
  Cell[StyleData["AddOnsLink", "Printout"],
    FontSize->10,
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["RefGuideLink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontFamily->"Courier",
    FontColor->RGBColor[0, 0, 1],
    FontVariations->{"Underline"->True},
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`HelpBrowserLookup[ "RefGuide", #]}]&),
    Active->True,
    ButtonFrame->"None"}],
  
  Cell[StyleData["RefGuideLink", "Presentation"],
    FontSize->16],
  
  Cell[StyleData["RefGuideLink", "Condensed"],
    FontSize->11],
  
  Cell[StyleData["RefGuideLink", "Printout"],
    FontSize->10,
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["GettingStartedLink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontColor->RGBColor[0, 0, 1],
    FontVariations->{"Underline"->True},
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`HelpBrowserLookup[ "GettingStarted", #]}]&),
    Active->True,
    ButtonFrame->"None"}],
  
  Cell[StyleData["GettingStartedLink", "Presentation"],
    FontSize->16],
  
  Cell[StyleData["GettingStartedLink", "Condensed"],
    FontSize->11],
  
  Cell[StyleData["GettingStartedLink", "Printout"],
    FontSize->10,
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["OtherInformationLink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontColor->RGBColor[0, 0, 1],
    FontVariations->{"Underline"->True},
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`HelpBrowserLookup[ "OtherInformation", #]}]&),
    Active->True,
    ButtonFrame->"None"}],
  
  Cell[StyleData["OtherInformationLink", "Presentation"],
    FontSize->16],
  
  Cell[StyleData["OtherInformationLink", "Condensed"],
    FontSize->11],
  
  Cell[StyleData["OtherInformationLink", "Printout"],
    FontSize->10,
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Styles for Headers and Footers", "Section"],
  
  Cell[StyleData["Header"],
    CellMargins->{{0, 0}, {4, 1}},
    DefaultNewInlineCellStyle->"None",
    LanguageCategory->"NaturalLanguage",
    StyleMenuListing->None,
    FontSize->10,
    FontSlant->"Italic"],
  
  Cell[StyleData["Footer"],
    CellMargins->{{0, 0}, {0, 4}},
    DefaultNewInlineCellStyle->"None",
    LanguageCategory->"NaturalLanguage",
    StyleMenuListing->None,
    FontSize->9,
    FontSlant->"Italic"],
  
  Cell[StyleData["PageNumber"],
    CellMargins->{{0, 0}, {4, 1}},
    StyleMenuListing->None,
    FontFamily->"Times",
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Palette Styles", "Section"],
  
  Cell["\<\
The cells below define styles that define standard \
ButtonFunctions, for use in palette buttons.\
\>", "Text"],
  
  Cell[StyleData["Paste"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`NotebookApply[ 
          FrontEnd`InputNotebook[ ], #, After]}]&)}],
  
  Cell[StyleData["Evaluate"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`NotebookApply[ 
          FrontEnd`InputNotebook[ ], #, All], 
        SelectionEvaluate[ 
          FrontEnd`InputNotebook[ ], All]}]&)}],
  
  Cell[StyleData["EvaluateCell"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`NotebookApply[ 
          FrontEnd`InputNotebook[ ], #, All], 
        FrontEnd`SelectionMove[ 
          FrontEnd`InputNotebook[ ], All, Cell, 1], 
        FrontEnd`SelectionEvaluateCreateCell[ 
          FrontEnd`InputNotebook[ ], All]}]&)}],
  
  Cell[StyleData["CopyEvaluate"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`SelectionCreateCell[ 
          FrontEnd`InputNotebook[ ], All], 
        FrontEnd`NotebookApply[ 
          FrontEnd`InputNotebook[ ], #, All], 
        FrontEnd`SelectionEvaluate[ 
          FrontEnd`InputNotebook[ ], All]}]&)}],
  
  Cell[StyleData["CopyEvaluateCell"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`SelectionCreateCell[ 
          FrontEnd`InputNotebook[ ], All], 
        FrontEnd`NotebookApply[ 
          FrontEnd`InputNotebook[ ], #, All], 
        FrontEnd`SelectionEvaluateCreateCell[ 
          FrontEnd`InputNotebook[ ], All]}]&)}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Placeholder Styles", "Section"],
  
  Cell["\<\
The cells below define styles useful for making placeholder \
objects in palette templates.\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Placeholder"],
    Placeholder->True,
    StyleMenuListing->None,
    FontSlant->"Italic",
    FontColor->RGBColor[0.890623, 0.864698, 0.384756],
    TagBoxOptions->{Editable->False,
    Selectable->False,
    StripWrapperBoxes->False}],
  
  Cell[StyleData["Placeholder", "Presentation"]],
  
  Cell[StyleData["Placeholder", "Condensed"]],
  
  Cell[StyleData["Placeholder", "Printout"]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["PrimaryPlaceholder"],
    StyleMenuListing->None,
    DrawHighlighted->True,
    FontSlant->"Italic",
    Background->RGBColor[0.912505, 0.891798, 0.507774],
    TagBoxOptions->{Editable->False,
    Selectable->False,
    StripWrapperBoxes->False}],
  
  Cell[StyleData["PrimaryPlaceholder", "Presentation"]],
  
  Cell[StyleData["PrimaryPlaceholder", "Condensed"]],
  
  Cell[StyleData["PrimaryPlaceholder", "Printout"]]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["FormatType Styles", "Section"],
  
  Cell["\<\
The cells below define styles that are mixed in with the styles \
of most cells.  If a cell's FormatType matches the name of one of the styles \
defined below, then that style is applied between the cell's style and its \
own options. This is particularly true of Input and Output.\
\>", "Text"],
  
  Cell[StyleData["CellExpression"],
    PageWidth->Infinity,
    CellMargins->{{6, Inherited}, {Inherited, Inherited}},
    ShowCellLabel->False,
    ShowSpecialCharacters->False,
    AllowInlineCells->False,
    Hyphenation->False,
    AutoItalicWords->{},
    StyleMenuListing->None,
    FontFamily->"Courier",
    FontSize->12,
    Background->GrayLevel[1]],
  
  Cell[StyleData["InputForm"],
    InputAutoReplacements->{},
    AllowInlineCells->False,
    Hyphenation->False,
    StyleMenuListing->None,
    FontFamily->"Courier"],
  
  Cell[StyleData["OutputForm"],
    PageWidth->Infinity,
    TextAlignment->Left,
    LineSpacing->{0.6, 1},
    StyleMenuListing->None,
    FontFamily->"Courier"],
  
  Cell[StyleData["StandardForm"],
    InputAutoReplacements->{
      "->"->"\[Rule]", ":>"->"\[RuleDelayed]", "<="->"\[LessEqual]", 
        ">="->"\[GreaterEqual]", "!="->"\[NotEqual]", "=="->"\[Equal]", 
        Inherited},
    LineSpacing->{1.25, 0},
    StyleMenuListing->None,
    FontFamily->"Courier"],
  
  Cell[StyleData["TraditionalForm"],
    InputAutoReplacements->{
      "->"->"\[Rule]", ":>"->"\[RuleDelayed]", "<="->"\[LessEqual]", 
        ">="->"\[GreaterEqual]", "!="->"\[NotEqual]", "=="->"\[Equal]", 
        Inherited},
    LineSpacing->{1.25, 0},
    SingleLetterItalics->True,
    TraditionalFunctionNotation->True,
    DelimiterMatching->None,
    StyleMenuListing->None],
  
  Cell["\<\
The style defined below is mixed in to any cell that is in an \
inline cell within another.\
\>", "Text"],
  
  Cell[StyleData["InlineCell"],
    TextAlignment->Left,
    ScriptLevel->1,
    StyleMenuListing->None],
  
  Cell[StyleData["InlineCellEditing"],
    StyleMenuListing->None,
    Background->RGBColor[1, 0.749996, 0.8]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Automatic Styles", "Section"],
  
  Cell["\<\
The cells below define styles that are used to affect the display \
of certain types of objects in typeset expressions.  For example, \
\"UnmatchedBracket\" style defines how unmatched bracket, curly bracket, and \
parenthesis characters are displayed (typically by coloring them to make them \
stand out).\
\>", "Text"],
  
  Cell[StyleData["UnmatchedBracket"],
    StyleMenuListing->None,
    FontColor->RGBColor[0.760006, 0.330007, 0.8]]
  }, Closed]]
  }, Open  ]],
  
  Cell[CellGroupData[{
  
  Cell["Notation Package Styles", "Section",
    GeneratedCell->True,
    CellTags->"NotationPackage"],
  
  Cell["\<\
The cells below define certain styles needed by the Notation \
package. These styles serve to make visible otherwise invisible \
tagboxes.\
\>", "Text",
    GeneratedCell->True,
    CellTags->"NotationPackage"],
  
  Cell[StyleData["NotationTemplateStyle"],
    GeneratedCell->True,
    StyleMenuListing->None,
    Background->RGBColor[1, 1, 0.850004],
    TagBoxOptions->{SyntaxForm->"symbol"},
    CellTags->"NotationPackage"],
  
  Cell[StyleData["NotationPatternWrapperStyle"],
    GeneratedCell->True,
    StyleMenuListing->None,
    Background->RGBColor[1, 0.900008, 0.979995],
    TagBoxOptions->{SyntaxForm->"symbol"},
    CellTags->"NotationPackage"],
  
  Cell[StyleData["NotationMadeBoxesWrapperStyle"],
    GeneratedCell->True,
    StyleMenuListing->None,
    Background->RGBColor[0.900008, 0.889998, 1],
    TagBoxOptions->{SyntaxForm->"symbol"},
    CellTags->"NotationPackage"]
  }, Closed]]
  }],
MacintoshSystemPageSetup->"\<\
0@00D01804P000000]X2:?oQon82n@96D005:0?l0040D01804P000000]X2:000
0000I0000000000000000BL?00400@00000000000000000B0002I0000aP00000
8W800@0100<00P0000000000oW`10000\>"
]


(***********************************************************************
Cached data follows.  If you edit this Notebook file directly, not using
Mathematica, you must remove the line containing CacheID at the top of 
the file.  The cache data will then be recreated when you save this file 
from within Mathematica.
***********************************************************************)

(*CellTagsOutline
CellTagsIndex->{}
*)

(*CellTagsIndex
CellTagsIndex->{}
*)

(*NotebookFileOutline
Notebook[{
Cell[1717, 49, 291, 6, 75, "Input",
  InitializationCell->True],
Cell[2011, 57, 388, 11, 27, "Input",
  InitializationCell->True],

Cell[CellGroupData[{
Cell[2424, 72, 166, 5, 46, "Subsection",
  Evaluatable->False,
  InitializationCell->True],
Cell[2593, 79, 369, 6, 43, "Input",
  InitializationCell->True],
Cell[2965, 87, 378, 6, 59, "Input",
  InitializationCell->True],
Cell[3346, 95, 235, 4, 27, "Input",
  InitializationCell->True],
Cell[3584, 101, 277, 6, 27, "Input",
  InitializationCell->True],
Cell[3864, 109, 294, 6, 27, "Input",
  InitializationCell->True],
Cell[4161, 117, 295, 6, 27, "Input",
  InitializationCell->True],
Cell[4459, 125, 286, 6, 27, "Input",
  InitializationCell->True],
Cell[4748, 133, 294, 6, 27, "Input",
  InitializationCell->True],
Cell[5045, 141, 360, 7, 27, "Input",
  InitializationCell->True],
Cell[5408, 150, 355, 7, 27, "Input",
  InitializationCell->True],
Cell[5766, 159, 362, 7, 43, "Input",
  InitializationCell->True],
Cell[6131, 168, 357, 7, 27, "Input",
  InitializationCell->True],
Cell[6491, 177, 304, 6, 29, "Input",
  InitializationCell->True],
Cell[6798, 185, 324, 7, 29, "Input",
  InitializationCell->True],
Cell[7125, 194, 343, 7, 27, "Input",
  InitializationCell->True],
Cell[7471, 203, 340, 7, 43, "Input",
  InitializationCell->True],
Cell[7814, 212, 1796, 26, 109, "Input",
  InitializationCell->True],
Cell[9613, 240, 1851, 26, 93, "Input",
  InitializationCell->True],
Cell[11467, 268, 192, 5, 27, "Input",
  InitializationCell->True],
Cell[11662, 275, 195, 5, 27, "Input",
  InitializationCell->True],
Cell[11860, 282, 204, 5, 27, "Input",
  InitializationCell->True],
Cell[12067, 289, 343, 7, 75, "Input",
  InitializationCell->True],
Cell[12413, 298, 229, 5, 27, "Input",
  InitializationCell->True],
Cell[12645, 305, 209, 5, 27, "Input",
  InitializationCell->True],
Cell[12857, 312, 261, 6, 44, "Input",
  InitializationCell->True],
Cell[13121, 320, 320, 7, 59, "Input",
  InitializationCell->True],
Cell[13444, 329, 281, 6, 43, "Input",
  InitializationCell->True],
Cell[13728, 337, 571, 10, 79, "Input",
  InitializationCell->True],
Cell[14302, 349, 425, 8, 59, "Input",
  InitializationCell->True],
Cell[14730, 359, 416, 8, 43, "Input",
  InitializationCell->True],
Cell[15149, 369, 425, 8, 59, "Input",
  InitializationCell->True],
Cell[15577, 379, 416, 8, 43, "Input",
  InitializationCell->True],
Cell[15996, 389, 270, 6, 27, "Input",
  InitializationCell->True],
Cell[16269, 397, 266, 6, 27, "Input",
  InitializationCell->True],
Cell[16538, 405, 424, 7, 91, "Input",
  InitializationCell->True],
Cell[16965, 414, 707, 11, 108, "Input",
  InitializationCell->True],
Cell[17675, 427, 893, 13, 92, "Input",
  InitializationCell->True],
Cell[18571, 442, 1003, 14, 94, "Input",
  InitializationCell->True],
Cell[19577, 458, 668, 10, 101, "Input",
  InitializationCell->True],
Cell[20248, 470, 392, 6, 77, "Input",
  InitializationCell->True],
Cell[20643, 478, 293, 6, 27, "Input",
  InitializationCell->True],
Cell[20939, 486, 246, 5, 27, "Input",
  InitializationCell->True],
Cell[21188, 493, 223, 5, 27, "Input",
  InitializationCell->True],
Cell[21414, 500, 225, 5, 27, "Input",
  InitializationCell->True],
Cell[21642, 507, 178, 3, 27, "Input",
  InitializationCell->True],
Cell[21823, 512, 222, 5, 27, "Input",
  InitializationCell->True],
Cell[22048, 519, 217, 5, 27, "Input",
  InitializationCell->True],
Cell[22268, 526, 235, 5, 43, "Input",
  InitializationCell->True],
Cell[22506, 533, 212, 5, 27, "Input",
  InitializationCell->True],
Cell[22721, 540, 186, 5, 27, "Input",
  InitializationCell->True],
Cell[22910, 547, 188, 5, 27, "Input",
  InitializationCell->True],
Cell[23101, 554, 392, 7, 59, "Input",
  InitializationCell->True],
Cell[23496, 563, 522, 9, 91, "Input",
  InitializationCell->True],
Cell[24021, 574, 578, 10, 75, "Input",
  InitializationCell->True],
Cell[24602, 586, 417, 6, 65, "Input",
  InitializationCell->True],
Cell[25022, 594, 355, 7, 60, "Input",
  InitializationCell->True],
Cell[25380, 603, 517, 8, 91, "Input",
  InitializationCell->True],
Cell[25900, 613, 482, 8, 91, "Input",
  InitializationCell->True],
Cell[26385, 623, 572, 8, 91, "Input",
  InitializationCell->True],
Cell[26960, 633, 279, 5, 59, "Input",
  InitializationCell->True],
Cell[27242, 640, 269, 4, 59, "Input",
  InitializationCell->True],
Cell[27514, 646, 238, 4, 59, "Input",
  InitializationCell->True],
Cell[27755, 652, 274, 6, 59, "Input",
  InitializationCell->True],
Cell[28032, 660, 274, 6, 59, "Input",
  InitializationCell->True],
Cell[28309, 668, 274, 6, 59, "Input",
  InitializationCell->True],
Cell[28586, 676, 274, 6, 59, "Input",
  InitializationCell->True],
Cell[28863, 684, 393, 6, 76, "Input",
  InitializationCell->True],
Cell[29259, 692, 242, 6, 43, "Input",
  InitializationCell->True],
Cell[29504, 700, 203, 5, 27, "Input",
  InitializationCell->True],
Cell[29710, 707, 264, 4, 29, "Input",
  InitializationCell->True],
Cell[29977, 713, 277, 4, 29, "Input",
  InitializationCell->True],
Cell[30257, 719, 290, 5, 45, "Input",
  InitializationCell->True],
Cell[30550, 726, 297, 5, 45, "Input",
  InitializationCell->True],
Cell[30850, 733, 276, 4, 45, "Input",
  InitializationCell->True],
Cell[31129, 739, 289, 5, 29, "Input",
  InitializationCell->True],
Cell[31421, 746, 1037, 15, 125, "Input",
  InitializationCell->True],
Cell[32461, 763, 1376, 20, 159, "Input",
  InitializationCell->True],
Cell[33840, 785, 281, 5, 59, "Input",
  InitializationCell->True],
Cell[34124, 792, 373, 6, 76, "Input",
  InitializationCell->True],
Cell[34500, 800, 465, 7, 45, "Input",
  InitializationCell->True],
Cell[34968, 809, 459, 7, 61, "Input",
  InitializationCell->True],
Cell[35430, 818, 705, 11, 82, "Input",
  InitializationCell->True],
Cell[36138, 831, 781, 11, 98, "Input",
  InitializationCell->True],
Cell[36922, 844, 1050, 15, 85, "Input",
  InitializationCell->True],
Cell[37975, 861, 1159, 17, 101, "Input",
  InitializationCell->True],
Cell[39137, 880, 1497, 22, 175, "Input",
  InitializationCell->True],
Cell[40637, 904, 485, 8, 77, "Input",
  InitializationCell->True],
Cell[41125, 914, 902, 14, 109, "Input",
  InitializationCell->True],
Cell[42030, 930, 357, 7, 45, "Input",
  InitializationCell->True],
Cell[42390, 939, 525, 8, 91, "Input",
  InitializationCell->True],
Cell[42918, 949, 383, 7, 59, "Input",
  InitializationCell->True],
Cell[43304, 958, 377, 7, 59, "Input",
  InitializationCell->True],
Cell[43684, 967, 495, 8, 91, "Input",
  InitializationCell->True],
Cell[44182, 977, 447, 7, 75, "Input",
  InitializationCell->True],
Cell[44632, 986, 347, 7, 43, "Input",
  InitializationCell->True],
Cell[44982, 995, 335, 7, 43, "Input",
  InitializationCell->True],
Cell[45320, 1004, 350, 6, 59, "Input",
  InitializationCell->True],
Cell[45673, 1012, 339, 5, 43, "Input",
  InitializationCell->True],
Cell[46015, 1019, 561, 9, 60, "Input",
  InitializationCell->True],
Cell[46579, 1030, 570, 9, 44, "Input",
  InitializationCell->True],
Cell[47152, 1041, 427, 8, 59, "Input",
  InitializationCell->True],
Cell[47582, 1051, 440, 8, 59, "Input",
  InitializationCell->True],
Cell[48025, 1061, 230, 5, 27, "Input",
  InitializationCell->True],
Cell[48258, 1068, 256, 4, 59, "Input",
  InitializationCell->True],
Cell[48517, 1074, 452, 7, 92, "Input",
  InitializationCell->True],
Cell[48972, 1083, 429, 6, 76, "Input",
  InitializationCell->True],
Cell[49404, 1091, 431, 7, 76, "Input",
  InitializationCell->True],
Cell[49838, 1100, 306, 5, 60, "Input",
  InitializationCell->True],
Cell[50147, 1107, 314, 5, 60, "Input",
  InitializationCell->True],
Cell[50464, 1114, 365, 6, 60, "Input",
  InitializationCell->True],
Cell[50832, 1122, 368, 6, 44, "Input",
  InitializationCell->True],
Cell[51203, 1130, 210, 4, 59, "Input",
  InitializationCell->True],
Cell[51416, 1136, 544, 8, 78, "Input",
  InitializationCell->True],
Cell[51963, 1146, 415, 7, 78, "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{
Cell[52415, 1158, 85, 2, 30, "Subsection"],
Cell[52503, 1162, 159, 4, 27, "Input",
  InitializationCell->True],
Cell[52665, 1168, 567, 9, 62, "Text"],
Cell[53235, 1179, 95, 2, 27, "Input",
  InitializationCell->True],

Cell[CellGroupData[{
Cell[53355, 1185, 30, 0, 42, "Subsubsection"],
Cell[53388, 1187, 483, 13, 27, "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{
Cell[53908, 1205, 37, 0, 28, "Subsubsection"],
Cell[53948, 1207, 481, 13, 28, "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{
Cell[54466, 1225, 41, 0, 28, "Subsubsection"],
Cell[54510, 1227, 491, 13, 28, "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{
Cell[55038, 1245, 39, 0, 28, "Subsubsection"],
Cell[55080, 1247, 497, 13, 28, "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{
Cell[55614, 1265, 41, 0, 28, "Subsubsection"],
Cell[55658, 1267, 494, 13, 28, "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{
Cell[56189, 1285, 39, 0, 28, "Subsubsection"],
Cell[56231, 1287, 138, 4, 27, "Input",
  InitializationCell->True],
Cell[56372, 1293, 521, 13, 28, "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{
Cell[56930, 1311, 49, 0, 28, "Subsubsection"],
Cell[56982, 1313, 153, 4, 27, "Input",
  InitializationCell->True],
Cell[57138, 1319, 546, 15, 28, "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{
Cell[57721, 1339, 40, 0, 28, "Subsubsection"],
Cell[57764, 1341, 378, 9, 59, "Input",
  InitializationCell->True],
Cell[58145, 1352, 200, 5, 27, "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{
Cell[58382, 1362, 42, 0, 28, "Subsubsection"],
Cell[58427, 1364, 148, 4, 27, "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{
Cell[58612, 1373, 38, 0, 28, "Subsubsection"],
Cell[58653, 1375, 141, 4, 27, "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{
Cell[58831, 1384, 38, 0, 28, "Subsubsection"],
Cell[58872, 1386, 307, 7, 43, "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{
Cell[59216, 1398, 36, 0, 28, "Subsubsection"],
Cell[59255, 1400, 240, 6, 30, "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{
Cell[59532, 1411, 37, 0, 28, "Subsubsection"],
Cell[59572, 1413, 877, 15, 146, "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{
Cell[60486, 1433, 38, 0, 28, "Subsubsection"],
Cell[60527, 1435, 973, 17, 110, "Input",
  InitializationCell->True],
Cell[61503, 1454, 312, 7, 43, "Input",
  InitializationCell->True],
Cell[61818, 1463, 432, 11, 44, "Input",
  InitializationCell->True],
Cell[62253, 1476, 431, 10, 44, "Input",
  InitializationCell->True],
Cell[62687, 1488, 638, 12, 60, "Input",
  InitializationCell->True],
Cell[63328, 1502, 143, 4, 27, "Input",
  InitializationCell->True],
Cell[63474, 1508, 489, 13, 27, "Input",
  InitializationCell->True],
Cell[63966, 1523, 413, 10, 28, "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{
Cell[64416, 1538, 37, 0, 28, "Subsubsection"],
Cell[64456, 1540, 196, 3, 30, "Input",
  InitializationCell->True],
Cell[64655, 1545, 353, 8, 44, "Input",
  InitializationCell->True],
Cell[65011, 1555, 944, 24, 44, "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{
Cell[65992, 1584, 40, 0, 28, "Subsubsection"],
Cell[66035, 1586, 235, 5, 28, "Input",
  InitializationCell->True],
Cell[66273, 1593, 553, 13, 62, "Input",
  InitializationCell->True],
Cell[66829, 1608, 439, 11, 44, "Input",
  InitializationCell->True],
Cell[67271, 1621, 424, 10, 44, "Input",
  InitializationCell->True],
Cell[67698, 1633, 946, 24, 44, "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{
Cell[68681, 1662, 41, 0, 28, "Subsubsection"],
Cell[68725, 1664, 349, 7, 49, "Input",
  InitializationCell->True],
Cell[69077, 1673, 980, 26, 53, "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{
Cell[70094, 1704, 38, 0, 28, "Subsubsection"],
Cell[70135, 1706, 186, 4, 28, "Input",
  InitializationCell->True],
Cell[70324, 1712, 270, 6, 27, "Input",
  InitializationCell->True],
Cell[70597, 1720, 1052, 18, 92, "Input",
  InitializationCell->True],
Cell[71652, 1740, 1286, 21, 140, "Input"],
Cell[72941, 1763, 1700, 30, 117, "Input",
  InitializationCell->True],
Cell[74644, 1795, 186, 4, 28, "Input",
  InitializationCell->True],
Cell[74833, 1801, 452, 12, 27, "Input",
  InitializationCell->True],
Cell[75288, 1815, 186, 4, 28, "Input",
  InitializationCell->True],
Cell[75477, 1821, 164, 4, 30, "Text"]
}, Closed]],

Cell[CellGroupData[{
Cell[75678, 1830, 36, 0, 28, "Subsubsection"],
Cell[75717, 1832, 734, 15, 67, "Input",
  InitializationCell->True],
Cell[76454, 1849, 411, 8, 59, "Input",
  InitializationCell->True],
Cell[76868, 1859, 458, 11, 27, "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{
Cell[77363, 1875, 46, 0, 28, "Subsubsection"],
Cell[77412, 1877, 989, 19, 107, "Input",
  InitializationCell->True],
Cell[78404, 1898, 223, 6, 27, "Input",
  InitializationCell->True],
Cell[78630, 1906, 1049, 21, 138, "Input",
  InitializationCell->True],
Cell[79682, 1929, 540, 10, 75, "Input",
  InitializationCell->True],
Cell[80225, 1941, 555, 15, 27, "Input",
  InitializationCell->True],
Cell[80783, 1958, 555, 15, 30, "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{
Cell[81375, 1978, 39, 0, 28, "Subsubsection"],
Cell[81417, 1980, 635, 13, 111, "Input",
  InitializationCell->True],
Cell[82055, 1995, 1470, 31, 175, "Input",
  InitializationCell->True],
Cell[83528, 2028, 184, 5, 27, "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{
Cell[83749, 2038, 49, 0, 28, "Subsubsection"],
Cell[83801, 2040, 911, 17, 125, "Input",
  InitializationCell->True],
Cell[84715, 2059, 291, 6, 43, "Input",
  InitializationCell->True],
Cell[85009, 2067, 312, 7, 27, "Input",
  InitializationCell->True],
Cell[85324, 2076, 194, 5, 27, "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{
Cell[85555, 2086, 45, 0, 28, "Subsubsection"],
Cell[85603, 2088, 468, 13, 27, "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{
Cell[86108, 2106, 39, 0, 28, "Subsubsection"],
Cell[86150, 2108, 1258, 21, 125, "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{
Cell[87445, 2134, 32, 0, 28, "Subsubsection"],
Cell[87480, 2136, 525, 11, 75, "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{
Cell[88042, 2152, 32, 0, 28, "Subsubsection"],
Cell[88077, 2154, 228, 5, 46, "Text"],
Cell[88308, 2161, 818, 15, 91, "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{
Cell[89163, 2181, 43, 0, 28, "Subsubsection"],
Cell[89209, 2183, 441, 9, 49, "Input",
  InitializationCell->True],
Cell[89653, 2194, 377, 8, 43, "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{
Cell[90067, 2207, 43, 0, 28, "Subsubsection"],
Cell[90113, 2209, 278, 5, 43, "Input",
  InitializationCell->True],
Cell[90394, 2216, 191, 3, 43, "Input",
  InitializationCell->True],
Cell[90588, 2221, 209, 5, 27, "Input",
  InitializationCell->True],
Cell[90800, 2228, 221, 5, 43, "Input",
  InitializationCell->True],
Cell[91024, 2235, 235, 5, 43, "Input",
  InitializationCell->True],
Cell[91262, 2242, 222, 5, 43, "Input",
  InitializationCell->True],
Cell[91487, 2249, 233, 5, 43, "Input",
  InitializationCell->True],
Cell[91723, 2256, 199, 4, 43, "Input",
  InitializationCell->True],
Cell[91925, 2262, 255, 6, 59, "Input",
  InitializationCell->True],
Cell[92183, 2270, 246, 6, 27, "Input",
  InitializationCell->True],
Cell[92432, 2278, 9960, 171, 1730, "Input",
  InitializationCell->True],
Cell[102395, 2451, 415, 8, 75, "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{
Cell[102847, 2464, 37, 0, 28, "Subsubsection"],
Cell[102887, 2466, 96, 2, 27, "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{
Cell[103020, 2473, 37, 0, 28, "Subsubsection"],
Cell[103060, 2475, 272, 5, 43, "Input",
  InitializationCell->True],
Cell[103335, 2482, 184, 3, 43, "Input",
  InitializationCell->True],
Cell[103522, 2487, 203, 5, 27, "Input",
  InitializationCell->True],
Cell[103728, 2494, 229, 5, 43, "Input",
  InitializationCell->True],
Cell[103960, 2501, 227, 5, 43, "Input",
  InitializationCell->True],
Cell[104190, 2508, 247, 5, 59, "Input",
  InitializationCell->True],
Cell[104440, 2515, 191, 3, 43, "Input",
  InitializationCell->True],
Cell[104634, 2520, 193, 5, 27, "Input",
  InitializationCell->True],
Cell[104830, 2527, 749, 14, 109, "Input",
  InitializationCell->True],
Cell[105582, 2543, 749, 14, 109, "Input",
  InitializationCell->True],
Cell[106334, 2559, 762, 15, 123, "Input",
  InitializationCell->True],
Cell[107099, 2576, 700, 13, 123, "Input",
  InitializationCell->True],
Cell[107802, 2591, 779, 15, 124, "Input",
  InitializationCell->True],
Cell[108584, 2608, 779, 15, 124, "Input",
  InitializationCell->True],
Cell[109366, 2625, 2807, 44, 411, "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{
Cell[112210, 2674, 43, 0, 28, "Subsubsection"],
Cell[112256, 2676, 596, 9, 121, "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{
Cell[112889, 2690, 36, 0, 28, "Subsubsection"],
Cell[112928, 2692, 622, 12, 102, "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{
Cell[113587, 2709, 32, 0, 28, "Subsubsection"],
Cell[113622, 2711, 128, 3, 27, "Input",
  InitializationCell->True],
Cell[113753, 2716, 1678, 29, 224, "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{
Cell[115468, 2750, 35, 0, 28, "Subsubsection"],
Cell[115506, 2752, 475, 13, 28, "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{
Cell[116018, 2770, 41, 0, 28, "Subsubsection"],
Cell[116062, 2772, 481, 13, 28, "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{
Cell[116580, 2790, 37, 0, 28, "Subsubsection"],
Cell[116620, 2792, 477, 13, 28, "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{
Cell[117134, 2810, 34, 0, 28, "Subsubsection"],
Cell[117171, 2812, 247, 6, 27, "Input",
  InitializationCell->True],
Cell[117421, 2820, 1210, 20, 136, "Input",
  InitializationCell->True],
Cell[118634, 2842, 245, 6, 27, "Input",
  InitializationCell->True],
Cell[118882, 2850, 1946, 33, 216, "Input",
  InitializationCell->True],
Cell[120831, 2885, 284, 6, 59, "Input",
  InitializationCell->True]
}, Open  ]],

Cell[CellGroupData[{
Cell[121152, 2896, 38, 0, 42, "Subsubsection"],
Cell[121193, 2898, 404, 9, 43, "Input",
  InitializationCell->True],
Cell[121600, 2909, 1672, 27, 107, "Input",
  InitializationCell->True],
Cell[123275, 2938, 3137, 52, 239, "Input",
  InitializationCell->True],
Cell[126415, 2992, 288, 6, 59, "Input",
  InitializationCell->True],
Cell[126706, 3000, 470, 13, 28, "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{
Cell[127213, 3018, 46, 0, 28, "Subsubsection"],
Cell[127262, 3020, 149, 3, 29, "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{
Cell[127448, 3028, 44, 0, 28, "Subsubsection"],
Cell[127495, 3030, 196, 4, 28, "Input",
  InitializationCell->True],
Cell[127694, 3036, 713, 13, 123, "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{
Cell[128444, 3054, 42, 0, 28, "Subsubsection"],
Cell[128489, 3056, 150, 4, 27, "Input",
  InitializationCell->True],
Cell[128642, 3062, 467, 13, 28, "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{
Cell[129146, 3080, 38, 0, 28, "Subsubsection"],
Cell[129187, 3082, 465, 13, 28, "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{
Cell[129689, 3100, 34, 0, 28, "Subsubsection"],
Cell[129726, 3102, 230, 4, 59, "Input",
  InitializationCell->True],
Cell[129959, 3108, 434, 9, 43, "Input",
  InitializationCell->True],
Cell[130396, 3119, 1720, 27, 192, "Input",
  InitializationCell->True],
Cell[132119, 3148, 3669, 62, 607, "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{
Cell[135825, 3215, 41, 0, 28, "Subsubsection"],
Cell[135869, 3217, 466, 13, 28, "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{
Cell[136372, 3235, 41, 0, 28, "Subsubsection"],
Cell[136416, 3237, 466, 13, 28, "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{
Cell[136919, 3255, 42, 0, 28, "Subsubsection"],
Cell[136964, 3257, 477, 13, 31, "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{
Cell[137478, 3275, 47, 0, 28, "Subsubsection"],
Cell[137528, 3277, 733, 14, 97, "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{
Cell[138298, 3296, 39, 0, 28, "Subsubsection"],
Cell[138340, 3298, 1662, 31, 225, "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{
Cell[140039, 3334, 33, 0, 28, "Subsubsection"],
Cell[140075, 3336, 213, 5, 27, "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{
Cell[140325, 3346, 34, 0, 28, "Subsubsection"],
Cell[140362, 3348, 164, 4, 27, "Input",
  InitializationCell->True],
Cell[140529, 3354, 339, 8, 43, "Input",
  InitializationCell->True],
Cell[140871, 3364, 805, 14, 53, "Input",
  InitializationCell->True],
Cell[141679, 3380, 774, 14, 70, "Input",
  InitializationCell->True],
Cell[142456, 3396, 363, 8, 59, "Input",
  InitializationCell->True],
Cell[142822, 3406, 814, 16, 74, "Input",
  InitializationCell->True],
Cell[143639, 3424, 731, 13, 74, "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{
Cell[144407, 3442, 36, 0, 28, "Subsubsection"],
Cell[144446, 3444, 379, 9, 43, "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{
Cell[144862, 3458, 34, 0, 28, "Subsubsection"],
Cell[144899, 3460, 375, 9, 43, "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{
Cell[145311, 3474, 47, 0, 28, "Subsubsection"],
Cell[145361, 3476, 146, 4, 27, "Input",
  InitializationCell->True],
Cell[145510, 3482, 514, 13, 28, "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{
Cell[146061, 3500, 44, 0, 28, "Subsubsection"],
Cell[146108, 3502, 93, 2, 27, "Input",
  InitializationCell->True],
Cell[146204, 3506, 412, 10, 28, "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{
Cell[146653, 3521, 32, 0, 28, "Subsubsection"],
Cell[146688, 3523, 564, 12, 91, "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{
Cell[147289, 3540, 34, 0, 28, "Subsubsection"],
Cell[147326, 3542, 629, 13, 120, "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{
Cell[147992, 3560, 57, 0, 28, "Subsubsection"],
Cell[148052, 3562, 162, 4, 27, "Input",
  InitializationCell->True],
Cell[148217, 3568, 491, 13, 28, "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{
Cell[148745, 3586, 46, 0, 28, "Subsubsection"],
Cell[148794, 3588, 469, 10, 75, "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{
Cell[149300, 3603, 44, 0, 28, "Subsubsection"],
Cell[149347, 3605, 577, 13, 75, "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{
Cell[149961, 3623, 35, 0, 28, "Subsubsection"],
Cell[149999, 3625, 314, 7, 43, "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{
Cell[150350, 3637, 61, 1, 28, "Subsubsection",
  InitializationCell->True],
Cell[150414, 3640, 642, 12, 92, "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{
Cell[151093, 3657, 41, 0, 28, "Subsubsection"],
Cell[151137, 3659, 145, 3, 27, "Input",
  InitializationCell->True],
Cell[151285, 3664, 489, 8, 101, "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{
Cell[151811, 3677, 69, 1, 28, "Subsubsection",
  InitializationCell->True],
Cell[151883, 3680, 1077, 19, 180, "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{
Cell[152997, 3704, 61, 1, 28, "Subsubsection",
  InitializationCell->True],
Cell[153061, 3707, 357, 10, 28, "Input",
  InitializationCell->True],
Cell[153421, 3719, 158, 4, 42, "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{
Cell[153616, 3728, 74, 1, 28, "Subsubsection",
  InitializationCell->True],
Cell[153693, 3731, 540, 10, 126, "Input",
  InitializationCell->True],
Cell[154236, 3743, 343, 7, 43, "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{
Cell[154616, 3755, 111, 2, 28, "Subsubsection",
  InitializationCell->True],
Cell[154730, 3759, 477, 9, 79, "Input",
  InitializationCell->True],
Cell[155210, 3770, 339, 7, 43, "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{
Cell[155586, 3782, 62, 1, 28, "Subsubsection",
  InitializationCell->True],
Cell[155651, 3785, 465, 9, 76, "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{
Cell[156153, 3799, 64, 1, 28, "Subsubsection",
  InitializationCell->True],
Cell[156220, 3802, 472, 9, 76, "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{
Cell[156729, 3816, 81, 2, 28, "Subsubsection"],
Cell[156813, 3820, 157, 5, 43, "Input",
  InitializationCell->True]
}, Closed]]
}, Open  ]]
}
]
*)




(***********************************************************************
End of Mathematica Notebook file.
***********************************************************************)

