(***********************************************************************

                    Mathematica-Compatible Notebook

This notebook can be used on any computer system with Mathematica 4.0,
MathReader 4.0, or any compatible application. The data for the notebook 
starts with the line containing stars above.

To get the notebook into a Mathematica-compatible application, do one of 
the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing the 
word CacheID, otherwise Mathematica-compatible applications may try to 
use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
***********************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[    104096,       2180]*)
(*NotebookOutlinePosition[    105256,       2219]*)
(*  CellTagsIndexPosition[    105156,       2212]*)
(*WindowFrame->Normal*)



Notebook[{

Cell[CellGroupData[{
Cell["Checking the recursions", "SubsectionIcon"],

Cell["This loads the package. ", "MathCaption",
  CellTags->{"S5.24.1", "1.4"}],

Cell[BoxData[
    \(\(<< Multilocus`ExactModel`;\)\)], "Input",
  CellLabel->"In[1]:="],

Cell[CellGroupData[{

Cell[TextData[
"Checking stability of the  solutions for MigrationOrder\[Rule]MUS"], 
  "SubsubsectionIcon"],

Cell[BoxData[
    \(\(StoreExact[\[Psi], hetWfull[0.01, 4], 0.5, {500, 100}, {20, 3}, 
      SymmetricModel \[Rule] False, Compiled \[Rule] True, 
      SortByClass \[Rule] True, MigrationOrder \[Rule] MUS]; \)\)], "Input",
  CellLabel->"In[2]:="],

Cell[BoxData[
    \(\(sm = 
      StabilityDirect[\[Psi][500], hetWfull[0.01, 4], 0.5, 
        SymmetricModel \[Rule] False, SortByClass \[Rule] True, 
        MigrationOrder \[Rule] MUS]; \)\)], "Input",
  CellLabel->"In[33]:="],

Cell[TextData[
"These are the eigenvalues.  BlockMatrix[] has been used to collapse the 8\
\[Times]8 array of 20\[Times]20 arrays into a 160\[Times]160 array.  There \
are two unstable eigenvalues, \[Lambda]=1.0324, and one neutral eigenvalue, \
\[Lambda]=1.  "], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(ev = Eigenvalues[BlockMatrix[sm]] // Chop\)], "Input",
  CellLabel->"In[34]:="],

Cell[BoxData[
    \({1.03237394830660611`, 1.03237394830660567`, 1.00009288219904468`, 
      0.983268914381524794`, 0.983268914381518044`, 0.975779858521001841`, 
      0.975779858521001486`, 0.957187332282767044`, 0.954593052319150991`, 
      0.945381789707977304`, 0.945381789707974995`, 0.908267563112794107`, 
      0.907542809187862964`, 0.907542809187862076`, 0.879885720460643128`, 
      0.856717556867696572`, 0.856717556867696217`, 0.829404943729521271`, 
      0.79755575344094689`, 0.797555753440943959`, 0.774177962484865034`, 
      0.730834511531340424`, 0.730834511531336161`, 0.710579749809923999`, 
      0.658361925680062221`, 0.658361925680061332`, 0.641769583219751549`, 
      0.58222215203372718`, 0.582222152033725848`, 0.56926565009042136`, 
      0.524033787067701872`, 0.524033787067696721`, 0.503988396623326906`, 
      0.503988396623324508`, 0.501772597609640413`, 0.494930239139803607`, 
      0.46331368619802884`, 0.463313686198028573`, 0.441471487223560288`, 
      0.441471487223560288`, 0.432656619619163507`, 0.432656619619162441`, 
      0.430363080670740583`, 0.426101765787303499`, 0.42610176578730341`, 
      0.421647997521391104`, 0.419964557663901683`, 0.418505554400544355`, 
      0.418505554400543111`, 0.414878525273784148`, 0.397196979135276162`, 
      0.397196979135274563`, 0.39630534072025366`, 0.376518322409173666`, 
      0.370038736593879047`, 0.37003873659387878`, 0.35011697872404035`, 
      0.350116978724039418`, 0.34985873351073069`, 0.348124875450306969`, 
      0.338356505699834331`, 0.338356505699833931`, 0.319781924789864202`, 
      0.306002733875579213`, 0.30600273387557908`, 0.290931413181475218`, 
      0.276649170874685257`, 0.276646217653467552`, 0.276646217653467418`, 
      0.270022381996277793`, 0.270022381996277083`, 
      \(0.256829782523610194`\[InvisibleSpace]\) + 
        0.00310068889819729776`\ I, 
      \(0.256829782523610194`\[InvisibleSpace]\) - 
        0.00310068889819729776`\ I, 0.232950973347460355`, 
      0.232950973347460221`, 0.219558179496083161`, 0.214626218533724699`, 
      0.211618414977762725`, 0.210901960902604113`, 0.21090196090260278`, 
      0.194861742268639837`, 0.194861742268639499`, 0.185899252575372067`, 
      0.176676005092559496`, 0.162855039628666409`, 0.162855039628666204`, 
      \(0.160134926804906596`\[InvisibleSpace]\) + 
        0.00192325666979919809`\ I, 
      \(0.160134926804906596`\[InvisibleSpace]\) - 
        0.00192325666979919809`\ I, 0.147836908579587422`, 
      0.147836908579587227`, 0.146003049056010798`, 0.142115347773511775`, 
      0.133967930975717575`, 0.129243867690670644`, 0.127607495214629862`, 
      0.127607495214629418`, 0.124668079562384015`, 0.119957540463457812`, 
      0.110152908443630881`, 0.100359761321532592`, 0.0992643434339566077`, 
      0.0974685733575999613`, 0.0974685733575996415`, 0.0954734844280588923`, 
      0.0954734844280587147`, 0.0902915195643724111`, 0.0836201163322702356`, 
      0.0694814337847412488`, 0.0672798292423104538`, 0.067268007837368593`, 
      0.0672680078373685397`, 0.064477673277749119`, 0.0581424729874685741`, 
      0.0581424729874683698`, 0.0530060694163715595`, 0.0498424396656985013`, 
      0.0422205095306754785`, 0.0422205095306754163`, 0.0361769464508495541`, 
      \(0.0351375927236582263`\[InvisibleSpace]\) + 
        0.00276571189767681469`\ I, 
      \(0.0351375927236582263`\[InvisibleSpace]\) - 
        0.00276571189767681469`\ I, 0.0291990526048855247`, 
      0.0291990526048854839`, 0.0218953842628026285`, 0.0213065097364381372`, 
      0.0213065097364381106`, 0.0203665065159203528`, 0.0169083681645303673`, 
      0.0123705867665762769`, 0.0123705867665762148`, 0.0115627344773384566`, 
      0.0111634211130678817`, 0.00652853136895603647`, 
      0.00577755585735561982`, 0.00577755585735550969`, 
      0.00341039794320347233`, 0.00312125824075035218`, 
      0.00312125824075022073`, 0.00244621972944274856`, 
      0.00143205941544585391`, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
      0, 0, 0, 0, 0}\)], "Output",
  CellLabel->"Out[34]="]
}, Open  ]],

Cell["These results can be checked against the symmetric model.", "Text"],

Cell[BoxData[
    \(StoreExact[\[Psi]E, hetW[0.01, 4], 0.5, {500, 100}, {20, 3}, 
      Compiled \[Rule] True, MigrationOrder \[Rule] MUS]; \n
    \[Sigma][p_] := 
      SigmaMatrix[
        StabilityK[#1, #2, #3, \[Psi]E[500], hetW[0.01, 4], 0.5, 
            MigrationOrder \[Rule] MUS]&, p, 3]; \)], "Input",
  CellLabel->"In[2]:="],

Cell[TextData[
"This shows eigenvalues corresponding to concordant fluctuations, in which \
all genotypes within a class retain the same frequency.  This includes the \
neutral eigevalue, \[Lambda]=1.  The zero eigenvalues reflect perturbations \
which dissappear immediately, owing to the symmetry of the model."], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(ev0 = Eigenvalues[BlockMatrix[\[Sigma][0]]] // Chop\)], "Input",
  CellLabel->"In[3]:="],

Cell[BoxData[
    \({1.0000928821989361`, 0.957187332282552638`, 0.954593052318939605`, 
      0.908267563112616294`, 0.879885720460466913`, 0.829404943729365307`, 
      0.774177962484725412`, 0.710579749809793881`, 0.641769583219634576`, 
      0.569265650090322417`, 0.501772597609635973`, 0.494930239139720562`, 
      0.430363080670735786`, 0.421647997521350603`, 0.419964557663875659`, 
      0.414878525273780152`, 0.396305340720250995`, 0.376518322409167804`, 
      0.349858733510723984`, 0.348124875450261983`, 0.319781924789859628`, 
      0.290931413181457365`, 0.27664917087466101`, 
      \(0.256829782523604777`\[InvisibleSpace]\) + 
        0.00310068889819367976`\ I, 
      \(0.256829782523604777`\[InvisibleSpace]\) - 
        0.00310068889819367976`\ I, 0.219558179496081296`, 
      0.214626218533696278`, 0.211618414977758417`, 0.185899252575378568`, 
      0.176676005092556254`, 
      \(0.160134926804887989`\[InvisibleSpace]\) + 
        0.00192325666983778109`\ I, 
      \(0.160134926804887989`\[InvisibleSpace]\) - 
        0.00192325666983778109`\ I, 0.146003049056032114`, 
      0.142115347773511135`, 0.133967930975716864`, 0.12924386769067353`, 
      0.124668079562348377`, 0.119957540463457657`, 0.110152908443633679`, 
      0.100359761321555152`, 0.09926434343394952`, 0.0902915195643492296`, 
      0.0836201163322676066`, 0.069481433784743114`, 0.0672798292422934895`, 
      0.0644776732777738281`, 0.0530060694163624557`, 0.049842439665687408`, 
      0.0361769464508392202`, 
      \(0.0351375927236624852`\[InvisibleSpace]\) + 
        0.00276571189766330505`\ I, 
      \(0.0351375927236624852`\[InvisibleSpace]\) - 
        0.00276571189766330505`\ I, 0.021895384262808708`, 
      0.0203665065159218539`, 0.0169083681645181282`, 0.0115627344773522167`, 
      0.011163421113065457`, 0.00652853136894985919`, 
      0.00341039794320165512`, 0.00244621972944500676`, 
      0.00143205941544529817`, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
      0, 0, 0, 0, 0}\)], "Output",
  CellLabel->"Out[3]="]
}, Open  ]],

Cell[TextData[
"This shows eigenvalues corresponding to discordant fluctuations.  This \
includes the leading eigenvalue, \[Lambda]=1.0324."], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(ev1 = Eigenvalues[BlockMatrix[\[Sigma][1]]]\)], "Input",
  CellLabel->"In[4]:="],

Cell[BoxData[
    \({1.03237394830660544`, 0.983268914381520708`, 0.975779858521005039`, 
      0.945381789707976949`, 0.907542809187863319`, 0.856717556867695506`, 
      0.797555753440942183`, 0.730834511531336694`, 0.658361925680063642`, 
      0.582222152033724871`, 0.524033787067697254`, 0.503988396623325396`, 
      0.463313686198027774`, 0.441471487223558867`, 0.432656619619162263`, 
      0.426101765787304032`, 0.418505554400543466`, 0.39719697913527451`, 
      0.370038736593879225`, 0.350116978724040128`, 0.338356505699834508`, 
      0.306002733875579036`, 0.276646217653467418`, 0.270022381996278237`, 
      0.232950973347459955`, 0.210901960902603669`, 0.194861742268639037`, 
      0.162855039628666764`, 0.147836908579586552`, 0.127607495214629285`, 
      0.0974685733575997126`, 0.0954734844280586436`, 0.0672680078373682466`, 
      0.0581424729874683521`, 0.0422205095306754341`, 0.0291990526048853027`, 
      0.0213065097364382172`, 0.0123705867665761215`, 
      0.00577755585735561183`, 0.0031212582407502678`}\)], "Output",
  CellLabel->"Out[4]="]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData[
"Checking stability of the  solutions for MigrationOrder\[Rule]USM"], 
  "SubsubsectionIcon"],

Cell[BoxData[
    \(\(StoreExact[\[Psi], hetWfull[0.01, 4], 0.5, {500, 100}, {20, 3}, 
      SymmetricModel \[Rule] False, Compiled \[Rule] True, 
      SortByClass \[Rule] True, MigrationOrder \[Rule] USM]; \)\)], "Input",
  CellLabel->"In[2]:="],

Cell[BoxData[
    \(\(sm = 
      StabilityDirect[\[Psi][500], hetWfull[0.01, 4], 0.5, 
        SymmetricModel \[Rule] False, SortByClass \[Rule] True, 
        MigrationOrder \[Rule] USM]; \)\)], "Input",
  CellLabel->"In[3]:="],

Cell[TextData[
"These are the eigenvalues.  BlockMatrix[] has been used to collapse the 8\
\[Times]8 array of 20\[Times]20 arrays into a 160\[Times]160 array.  There \
are two unstable eigenvalues, \[Lambda]=1.0324, and one neutral eigenvalue, \
\[Lambda]=1.  Note that these eigenvalues are the same as for MigrationOrder\
\[Rule]MUS.  This is because migration of diploids, followed by meiosis, is \
equivalent to meiosis, followed by migration of haploids."], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(ev = Eigenvalues[BlockMatrix[sm]] // Chop\)], "Input",
  CellLabel->"In[4]:="],

Cell[BoxData[
    \({1.03237394830652773`, 1.03237394830652551`, 1.00009288219895275`, 
      0.983268914381541137`, 0.983268914381540248`, 0.975779858521071652`, 
      0.975779858521066145`, 0.957187332283591096`, 0.954593052320032242`, 
      0.945381789707955988`, 0.945381789707951725`, 0.908267563113069975`, 
      0.90754280918785426`, 0.90754280918785426`, 0.879885720461080289`, 
      0.856717556867688045`, 0.856717556867685381`, 0.829404943729871213`, 
      0.797555753440936499`, 0.797555753440935255`, 0.774177962485221549`, 
      0.730834511531327724`, 0.730834511531327368`, 0.710579749810249605`, 
      0.658361925680058313`, 0.658361925680056536`, 0.641769583220048822`, 
      0.582222152033724782`, 0.58222215203372416`, 0.569265650090701136`, 
      0.524033787067617051`, 0.524033787067615897`, 0.503988396623326551`, 
      0.503988396623325751`, 0.501772597609507009`, 0.494930239140044392`, 
      0.463313686197795071`, 0.463313686197794627`, 0.441471487223086711`, 
      0.441471487223084846`, 0.432656619618581039`, 0.432656619618579352`, 
      0.430363080670610997`, 0.426101765787270192`, 0.426101765787267794`, 
      0.421647997521507811`, 0.41996455766400107`, 0.418505554400098045`, 
      0.418505554400097601`, 0.414878525273780596`, 0.397196979134869909`, 
      0.397196979134868843`, 0.396305340720201115`, 0.37651832240913281`, 
      0.370038736593512673`, 0.370038736593512584`, 0.350116978724015437`, 
      0.350116978724014193`, 0.349858733510686281`, 0.348124875450485049`, 
      0.338356505699529908`, 0.338356505699528931`, 0.319781924789828542`, 
      0.306002733875292021`, 0.306002733875290555`, 0.290931413181475093`, 
      0.276649170874801164`, 0.276646217653461157`, 0.276646217653460935`, 
      0.270022381996022708`, 0.270022381996022176`, 
      \(0.256829782523561034`\[InvisibleSpace]\) + 
        0.00310068889822458704`\ I, 
      \(0.256829782523561034`\[InvisibleSpace]\) - 
        0.00310068889822458704`\ I, 0.232950973347242085`, 
      0.232950973347241641`, 0.219558179496088712`, 0.214626218533826174`, 
      0.211618414977525315`, 0.210901960902579554`, 0.210901960902579199`, 
      0.194861742268480284`, 0.194861742268478685`, 0.185899252575339986`, 
      0.176676005092236216`, 0.162855039628528448`, 0.162855039628528297`, 
      \(0.160134926804720318`\[InvisibleSpace]\) + 
        0.00192325666957881562`\ I, 
      \(0.160134926804720318`\[InvisibleSpace]\) - 
        0.00192325666957881562`\ I, 0.147836908579578647`, 
      0.147836908579578629`, 0.146003049055876976`, 0.142115347772712263`, 
      0.133967930974649451`, 0.129243867689678904`, 0.127607495214507826`, 
      0.127607495214507604`, 0.124668079562283162`, 0.119957540462651458`, 
      0.110152908443057251`, 0.100359761321452478`, 0.0992643434335640861`, 
      0.0974685733576069068`, 0.0974685733576066759`, 0.0954734844279626138`, 
      0.0954734844279624894`, 0.0902915195641096168`, 0.083620116331841352`, 
      0.0694814337843770779`, 0.0672798292421495336`, 0.0672680078372986844`, 
      0.0672680078372985335`, 0.0644776732778146755`, 0.0581424729874790546`, 
      0.0581424729874788681`, 0.0530060694161163947`, 0.0498424396655105361`, 
      0.0422205095306269573`, 0.0422205095306268596`, 0.0361769464507220517`, 
      \(0.0351375927235992246`\[InvisibleSpace]\) + 
        0.00276571189764953162`\ I, 
      \(0.0351375927235992246`\[InvisibleSpace]\) - 
        0.00276571189764953162`\ I, 0.0291990526048863241`, 
      0.0291990526048861163`, 0.0218953842626755612`, 0.0213065097364169542`, 
      0.0213065097364169409`, 0.0203665065158611779`, 0.0169083681645620949`, 
      0.0123705867665731905`, 0.0123705867665731905`, 0.0115627344773112716`, 
      0.0111634211130071103`, 0.00652853136895391195`, 
      0.00577755585735201293`, 0.00577755585735201293`, 
      0.00341039794319067901`, 0.0031212582407491034`, 
      0.00312125824074898616`, 0.00244621972943571996`, 
      0.00143205941544275638`, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
      0, 0, 0, 0, 0}\)], "Output",
  CellLabel->"Out[4]="]
}, Open  ]],

Cell["These results can be checked against the symmetric model.", "Text"],

Cell[BoxData[
    \(StoreExact[\[Psi]E, hetW[0.01, 4], 0.5, {500, 100}, {20, 3}, 
      Compiled \[Rule] True, MigrationOrder \[Rule] USM]; \n
    \[Sigma][p_] := 
      SigmaMatrix[
        StabilityK[#1, #2, #3, \[Psi]E[500], hetW[0.01, 4], 0.5, 
            MigrationOrder \[Rule] USM]&, p, 3]; \)], "Input",
  CellLabel->"In[5]:="],

Cell[TextData[
"This shows eigenvalues corresponding to concordant fluctuations, in which \
all genotypes within a class retain the same frequency.  This includes the \
neutral eigenvalue, \[Lambda]=1.  The zero eigenvalues reflect perturbations \
which dissappear immediately, owing to the symmetry of the model."], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(ev0 = Eigenvalues[BlockMatrix[\[Sigma][0]]] // Chop\)], "Input",
  CellLabel->"In[6]:="],

Cell[BoxData[
    \({1.00009288219895209`, 0.957187332283595893`, 0.954593052320031709`, 
      0.908267563113066067`, 0.879885720461076559`, 0.829404943729871746`, 
      0.774177962485225545`, 0.710579749810252181`, 0.641769583220046069`, 
      0.569265650090698294`, 0.501772597609506298`, 0.494930239140044836`, 
      0.430363080670611086`, 0.421647997521507278`, 0.419964557663999915`, 
      0.414878525273778997`, 0.396305340720199605`, 0.376518322409132899`, 
      0.349858733510685127`, 0.348124875450483894`, 0.319781924789828631`, 
      0.29093141318147575`, 0.276649170874801075`, 
      \(0.256829782523561611`\[InvisibleSpace]\) + 
        0.00310068889822455062`\ I, 
      \(0.256829782523561611`\[InvisibleSpace]\) - 
        0.00310068889822455062`\ I, 0.219558179496088756`, 
      0.214626218533827506`, 0.211618414977527136`, 0.185899252575340927`, 
      0.176676005092233996`, 
      \(0.16013492680471919`\[InvisibleSpace]\) + 0.00192325666957528262`\ I, 
      \(0.16013492680471919`\[InvisibleSpace]\) - 0.00192325666957528262`\ I, 
      0.146003049055876976`, 0.142115347772712929`, 0.133967930974650517`, 
      0.129243867689680968`, 0.124668079562280298`, 0.119957540462650968`, 
      0.110152908443059449`, 0.100359761321451324`, 0.0992643434335643881`, 
      0.0902915195641085688`, 0.0836201163318410678`, 0.0694814337843780549`, 
      0.0672798292421505905`, 0.0644776732778143113`, 0.0530060694161160483`, 
      0.0498424396655105095`, 0.0361769464507224913`, 
      \(0.035137592723598976`\[InvisibleSpace]\) + 
        0.00276571189764972391`\ I, 
      \(0.035137592723598976`\[InvisibleSpace]\) - 
        0.00276571189764972391`\ I, 0.0218953842626752859`, 
      0.0203665065158617553`, 0.0169083681645642442`, 0.0115627344773085338`, 
      0.0111634211130072302`, 0.00652853136895338259`, 
      0.00341039794319085931`, 0.00244621972943568311`, 
      0.00143205941544297328`, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
      0, 0, 0, 0, 0}\)], "Output",
  CellLabel->"Out[6]="]
}, Open  ]],

Cell[TextData[
"This shows eigenvalues corresponding to discordant fluctuations.  This \
includes the leading eigevalue, \[Lambda]=1.025."], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(ev1 = Eigenvalues[BlockMatrix[\[Sigma][1]]]\)], "Input",
  CellLabel->"In[7]:="],

Cell[BoxData[
    \({1.03237394830652862`, 0.98326891438153865`, 0.975779858521068987`, 
      0.945381789707954922`, 0.90754280918785497`, 0.856717556867685736`, 
      0.797555753440936143`, 0.730834511531329855`, 0.658361925680055115`, 
      0.582222152033723983`, 0.524033787067615541`, 0.503988396623324508`, 
      0.463313686197792762`, 0.441471487223086445`, 0.432656619618580862`, 
      0.426101765787269304`, 0.418505554400098578`, 0.397196979134869732`, 
      0.370038736593512851`, 0.350116978724014593`, 0.338356505699529286`, 
      0.306002733875291177`, 0.276646217653460801`, 0.27002238199602262`, 
      0.232950973347242085`, 0.210901960902579421`, 0.194861742268479858`, 
      0.162855039628527986`, 0.147836908579578434`, 0.127607495214507427`, 
      0.0974685733576065693`, 0.0954734844279624539`, 0.0672680078372989065`, 
      0.0581424729874792589`, 0.0422205095306266642`, 0.0291990526048864751`, 
      0.0213065097364168165`, 0.0123705867665732971`, 
      0.00577755585735196675`, 0.00312125824074904745`}\)], "Output",
  CellLabel->"Out[7]="]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData[
"Checking stability of the  solutions for default MigrationOrder\[Rule]UMS, \
with fixed endpoints"], "SubsubsectionIcon"],

Cell["\<\
Set up a cline across 10 demes, with 20% selection against \
heterozygotes at 3 loci; use full genotype frequencies\
\>", "Text"],

Cell[BoxData[
    \(\[Psi]0 = 
      HaploidSource[3, 0, SymmetricModel \[Rule] False, 
        SortByClass \[Rule] True]; 
    \[Psi]1 = 
      HaploidSource[3, 1, SymmetricModel \[Rule] False, 
        SortByClass \[Rule] True]; \n
    StoreExact[\[Psi], hetWfull[0.2, 1], 0.5, {100, 10}, {10, 3}, 
      SymmetricModel \[Rule] False, Compiled \[Rule] True, 
      SortByClass \[Rule] True, MigrationOrder \[Rule] UMS, 
      FixedEnds \[Rule] {\[Psi]0, \[Psi]1}]; \)], "Input",
  CellLabel->"In[2]:="],

Cell["Set up the same, using the symmetric model", "Text"],

Cell[BoxData[
    \(\[Psi]E0 = HaploidSource[3, 0]; \[Psi]E1 = HaploidSource[3, 1]; \n
    StoreExact[\[Psi]E, hetW[0.2, 1], 0.5, {100, 10}, {10, 3}, 
      Compiled \[Rule] True, MigrationOrder \[Rule] UMS, 
      FixedEnds \[Rule] {\[Psi]E0, \[Psi]E1}]; \)], "Input",
  CellLabel->"In[7]:="],

Cell["This has reached equilibrium after 100 generations", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(Table[
          First/@MeanP[\[Psi][t], SymmetricModel \[Rule] False, 
              SortByClass \[Rule] True], {t, 0, 100, 10}] // Chop\) // 
      TableForm\)], "Input",
  CellLabel->"In[8]:="],

Cell[BoxData[
    TagBox[GridBox[{
          {"0", "0", "0", "0", "0", "1", "1", "1", "1", "1"},
          {"0.0027426332014731698`", "0.010845193318877342`", 
            "0.037519576352700259`", "0.122200319283432645`", 
            "0.340558661846283516`", "0.659441338153716305`", 
            "0.87779968071656711`", "0.962480423647299687`", 
            "0.9891548066811227`", "0.997257366798526767`"},
          {"0.00550326366866558558`", "0.0173369710240779895`", 
            "0.0493221600342600741`", "0.138796195797668641`", 
            "0.350376313295539576`", "0.649623686704460023`", 
            "0.861203804202331291`", "0.950677839965739934`", 
            "0.982663028975922081`", "0.994496736331334574`"},
          {"0.00606250771212103067`", "0.0185926900559828958`", 
            "0.0514935892954436269`", "0.141724539868696419`", 
            "0.352063969187751713`", "0.64793603081224802`", 
            "0.858275460131303624`", "0.948506410704556479`", 
            "0.981407309944017214`", "0.993937492287878932`"},
          {"0.00616655884881769456`", "0.0188258843604686845`", 
            "0.0518955430514523641`", "0.142264324468779008`", 
            "0.352373966245464353`", "0.647626033754535512`", 
            "0.85773567553122092`", "0.948104456948547635`", 
            "0.98117411563953123`", "0.993833441151182306`"},
          {"0.00618586648227809554`", "0.018869158937783709`", 
            "0.0519701222704394183`", "0.14236442586986624`", 
            "0.352431422984779363`", "0.647568577015220903`", 
            "0.857635574130133804`", "0.94802987772956051`", 
            "0.981130841062216241`", "0.99381413351772192`"},
          {"0.0061894505325166973`", "0.0188771923076325052`", 
            "0.051983966959462311`", "0.14238300704978668`", 
            "0.352442087320607599`", "0.647557912679392266`", 
            "0.857616992950213408`", "0.948016033040537919`", 
            "0.981122807692367437`", "0.993810549467483284`"},
          {"0.00619011592487810524`", "0.0188786837491431196`", 
            "0.0519865373127507801`", "0.142386456720181353`", 
            "0.35244406716435197`", "0.647555932835648029`", 
            "0.857613543279818735`", "0.948013462687249131`", 
            "0.981121316250856878`", "0.993809884075121807`"},
          {"0.00619023946117884449`", "0.0188789606497887607`", 
            "0.0519870145242025127`", "0.142387097184155964`", 
            "0.352444434739975331`", "0.647555565260025023`", 
            "0.85761290281584408`", "0.94801298547579762`", 
            "0.981121039350211354`", "0.993809760538821151`"},
          {"0.00619026239698255853`", "0.0188790120593057828`", 
            "0.0519871031235397573`", "0.142387216092998976`", 
            "0.352444502984200269`", "0.647555497015799907`", 
            "0.85761278390700113`", "0.948012896876460331`", 
            "0.981120987940694178`", "0.993809737603017318`"},
          {"0.0061902666552587684`", "0.01887902160403085`", 
            "0.0519871195729520252`", "0.142387238169692782`", 
            "0.352444515654466661`", "0.647555484345533916`", 
            "0.85761276183030759`", "0.94801288042704801`", 
            "0.981120978395969167`", "0.993809733344741275`"}
          },
        RowSpacings->1,
        ColumnSpacings->3,
        RowAlignments->Baseline,
        ColumnAlignments->{Left}],
      (TableForm[ #]&)]], "Output",
  CellLabel->"Out[8]//TableForm="]
}, Closed]],

Cell["\<\
The solution is the same whether or not the symmetric solution is \
used.\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\({First/@
            MeanP[\[Psi][100], SymmetricModel \[Rule] False, 
              SortByClass \[Rule] True], MeanP[\[Psi]E[100]]} // Chop\) // 
      TableForm\)], "Input",
  CellLabel->"In[9]:="],

Cell[BoxData[
    TagBox[GridBox[{
          {"0.0061902666552587684`", "0.01887902160403085`", 
            "0.0519871195729520252`", "0.142387238169692782`", 
            "0.352444515654466661`", "0.647555484345533916`", 
            "0.85761276183030759`", "0.94801288042704801`", 
            "0.981120978395969167`", "0.993809733344741275`"},
          {"0.00619026665525876751`", "0.0188790216040308322`", 
            "0.0519871195729519719`", "0.142387238169692675`", 
            "0.35244451565446635`", "0.64755548434553356`", 
            "0.857612761830307235`", "0.948012880427048187`", 
            "0.981120978395969167`", "0.993809733344741275`"}
          },
        RowSpacings->1,
        ColumnSpacings->3,
        RowAlignments->Baseline,
        ColumnAlignments->{Left}],
      (TableForm[ #]&)]], "Output",
  CellLabel->"Out[9]//TableForm="]
}, Closed]],

Cell[BoxData[
    \(\(sm = 
      StabilityDirect[\[Psi][100], hetWfull[0.2, 1], 0.5, 
        SymmetricModel \[Rule] False, SortByClass \[Rule] True, 
        MigrationOrder \[Rule] UMS, FixedEnds \[Rule] {\[Psi]0, \[Psi]1}]; 
    \)\)], "Input",
  CellLabel->"In[10]:="],

Cell[TextData[
"These are the eigenvalues.  BlockMatrix[] has been used to collapse the 8\
\[Times]8 array of 10\[Times]10 arrays into an 80\[Times]80 array.  There is \
one almost neutral eigenvalue, \[Lambda]=0.999749; this is just stablilised \
by the fixing of the endpoints.  "], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(ev = Eigenvalues[BlockMatrix[sm]] // Chop\)], "Input",
  CellLabel->"In[11]:="],

Cell[BoxData[
    \({0.99974915209312396`, 0.919069655293701792`, 0.919069655293700193`, 
      0.845029745057107462`, 0.805919549597537354`, 0.805919549597535933`, 
      0.745476185890772846`, 0.716886148464051586`, 0.716886148464050076`, 
      0.653284948425470091`, 0.622621979604140474`, 0.622621979604139319`, 
      0.539328567594376906`, 0.504083288576097654`, 0.504083288576094545`, 
      0.464973516180764523`, 0.464973516180762302`, 0.464776663103926157`, 
      0.41266165252733451`, 0.379816657086209774`, 0.379816657086209197`, 
      0.362899454443922975`, 0.35711300019181964`, 0.357113000191819285`, 
      0.305042674769480592`, 0.303748173019261491`, 0.303748173019261269`, 
      0.300645037669148784`, 0.277029934355765306`, 0.277029934355764329`, 
      0.259196093659287729`, 0.248070048983393487`, 0.248070048983393176`, 
      0.22921196201259546`, 0.228293835440546333`, 0.216434883351382278`, 
      0.216434883351381435`, 0.17942356268442281`, 0.161566045111677158`, 
      0.161253279730273675`, 0.160260464935435003`, 0.160260464935434443`, 
      0.158836940206995347`, 0.15883694020699524`, 0.125312177025925874`, 
      0.117299840775110375`, 0.10745061859641134`, 0.104555837632158987`, 
      0.10455583763215881`, 0.0902227912802057652`, 0.0901740781393024093`, 
      0.0812228586325857548`, 0.0812228586325854884`, 0.0651181724371379022`, 
      0.0550766855398711818`, 0.0550766855398711729`, 0.0534425951640828422`, 
      0.0514247759192478604`, 0.0350629508919983035`, 0.0350629508919982013`, 
      0.0333489536359190452`, 0.027352046122401763`, 0.0215667389176825308`, 
      0.0157255678219991601`, 0.0157255678219990713`, 
      0.00912922307540003963`, 0.00912922307539999522`, 
      0.00804861830014330337`, 0.00485704647924306431`, 
      \(-0.00295500268142192759`\), 0, 0, 0, 0, 0, 0, 0, 0, 0, 0}\)], "Output",\

  CellLabel->"Out[11]="]
}, Open  ]],

Cell["These results can be checked against the symmetric model.", "Text"],

Cell[BoxData[
    \(\(\[Sigma][p_] := 
      SigmaMatrix[
        StabilityK[#1, #2, #3, \[Psi]E[100], hetW[0.2, 1], 0.5, 
            MigrationOrder \[Rule] UMS, 
            FixedEnds \[Rule] {\[Psi]E0, \[Psi]E1}]&, p, 3]; \)\)], "Input",
  CellLabel->"In[12]:="],

Cell[TextData[
"This shows eigenvalues corresponding to concordant fluctuations, in which \
all genotypes within a class retain the same frequency.  This includes the \
neutral eigenvalue, \[Lambda]=1.  The zero eigenvalues reflect perturbations \
which dissappear immediately, owing to the symmetry of the model."], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(ev0 = Eigenvalues[BlockMatrix[\[Sigma][0]]] // Chop\)], "Input",
  CellLabel->"In[13]:="],

Cell[BoxData[
    \({0.999749151784960687`, 0.845029744530442172`, 0.745476185561831794`, 
      0.653284948157697975`, 0.539328567414240467`, 0.464776663010886625`, 
      0.412661652451313276`, 0.362899454384903563`, 0.305042674747396347`, 
      0.300645037623038469`, 0.259196093593138732`, 0.229211961995882074`, 
      0.22829383545325701`, 0.179423562611837343`, 0.161566045108559386`, 
      0.161253279727793881`, 0.125312177029095028`, 0.117299840773248997`, 
      0.107450618564533106`, 0.0902227912805001253`, 0.0901740781257227119`, 
      0.0651181724403586947`, 0.0534425951461383164`, 0.0514247759085818767`, 
      0.03334895363311412`, 0.0273520461113642365`, 0.0215667389204731163`, 
      0.00804861829945138396`, 0.00485704647872743322`, 
      \(-0.00295500271932413394`\), 0, 0, 0, 0, 0, 0, 0, 0, 0, 0}\)], "Output",\

  CellLabel->"Out[13]="]
}, Open  ]],

Cell[TextData[
"This shows eigenvalues corresponding to discordant fluctuations.  This \
includes the leading eigevalue, \[Lambda]=1.025."], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(ev1 = Eigenvalues[BlockMatrix[\[Sigma][1]]]\)], "Input",
  CellLabel->"In[14]:="],

Cell[BoxData[
    \({0.919069655293700904`, 0.80591954959753469`, 0.716886148464048922`, 
      0.622621979604140385`, 0.504083288576095611`, 0.464973516180763102`, 
      0.379816657086209374`, 0.357113000191819685`, 0.303748173019261491`, 
      0.277029934355764728`, 0.248070048983394109`, 0.216434883351382234`, 
      0.160260464935434754`, 0.158836940206995684`, 0.104555837632159054`, 
      0.081222858632585666`, 0.0550766855398711285`, 0.0350629508919981258`, 
      0.0157255678219991619`, 0.00912922307540006805`}\)], "Output",
  CellLabel->"Out[14]="]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData[
"Checking stability of the  solutions for MigrationOrder\[Rule]MUS, with \
fixed endpoints"], "SubsubsectionIcon"],

Cell[BoxData[
    \(\[Psi]0 = 
      HaploidSource[3, 0, SymmetricModel \[Rule] False, 
        SortByClass \[Rule] True]; 
    \[Psi]1 = 
      HaploidSource[3, 1, SymmetricModel \[Rule] False, 
        SortByClass \[Rule] True]; \)], "Input",
  CellLabel->"In[2]:="],

Cell[BoxData[
    \(\(StoreExact[\[Psi], hetWfull[0.2, 1], 0.5, {100, 10}, {10, 3}, 
      SymmetricModel \[Rule] False, Compiled \[Rule] True, 
      SortByClass \[Rule] True, MigrationOrder \[Rule] MUS, 
      FixedEnds \[Rule] {\[Psi]0, \[Psi]1}]; \)\)], "Input",
  CellLabel->"In[16]:="],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(Table[
          First/@MeanP[\[Psi][t], SymmetricModel \[Rule] False, 
              SortByClass \[Rule] True], {t, 0, 100, 10}] // Chop\) // 
      TableForm\)], "Input",
  CellLabel->"In[17]:="],

Cell[BoxData[
    TagBox[GridBox[{
          {"0", "0", "0", "0", "0", "1", "1", "1", "1", "1"},
          {"0.0030422829675797578`", "0.0121114218830726172`", 
            "0.041264172276391724`", "0.127890535157986739`", 
            "0.341997154785149737`", "0.65800284521485004`", 
            "0.872109464842013437`", "0.958735827723608302`", 
            "0.987888578116927362`", "0.996957717032420376`"},
          {"0.00655088285919764778`", "0.0204866850821349366`", 
            "0.0566574487026664996`", "0.149902875618123427`", 
            "0.355877818741360574`", "0.644122181258639514`", 
            "0.850097124381876412`", "0.943342551297333464`", 
            "0.979513314917864974`", "0.993449117140802506`"},
          {"0.00733839569866019392`", "0.0222621976851979619`", 
            "0.0597140836751855097`", "0.15400837513258625`", 
            "0.358329901898488012`", "0.641670098101512031`", 
            "0.845991624867413527`", "0.940285916324814508`", 
            "0.977737802314802095`", "0.992661604301339828`"},
          {"0.00749633908253285685`", "0.0226167590670700624`", 
            "0.0603204420332431467`", "0.15481597820128556`", 
            "0.358808171931133612`", "0.64119182806886652`", 
            "0.845184021798714546`", "0.939679557966756817`", 
            "0.977383240932929986`", "0.9925036609174672`"},
          {"0.00752776286520852266`", "0.0226872739512276844`", 
            "0.0604409326367195998`", "0.154976242411890119`", 
            "0.35890293710342993`", "0.641097062896570069`", 
            "0.845023757588110058`", "0.93955906736328032`", 
            "0.977312726048772262`", "0.992472237134791512`"},
          {"0.00753401108224237336`", "0.0227012943724092686`", 
            "0.0604648865824761827`", "0.155008095766009734`", 
            "0.358921766693938115`", "0.641078233306061839`", 
            "0.844991904233990354`", "0.939535113417523781`", 
            "0.977298705627590891`", "0.99246598891775779`"},
          {"0.00753525340907330765`", "0.0227040820247335473`", 
            "0.060469649188651644`", "0.155014428667195147`", 
            "0.358925510071797049`", "0.641074489928202773`", 
            "0.844985571332804852`", "0.939530350811348213`", 
            "0.977295917975266448`", "0.992464746590926694`"},
          {"0.0075355004191607886`", "0.0227046362892663555`", 
            "0.0604705961260628921`", "0.155015687811172009`", 
            "0.358926254343414807`", "0.641073745656585369`", 
            "0.844984312188828035`", "0.939529403873937241`", 
            "0.977295363710733511`", "0.992464499580839287`"},
          {"0.00753554953182924958`", "0.0227047464928888542`", 
            "0.0604707844041123632`", "0.15501593816430641`", 
            "0.358926402325154381`", "0.641073597674845618`", 
            "0.844984061835693722`", "0.939529215595887556`", 
            "0.977295253507111105`", "0.992464450468170689`"},
          {"0.00753555929683251513`", "0.0227047684045205944`", 
            "0.060470821839166744`", "0.155015987941643196`", 
            "0.358926431748127949`", "0.641073568251872227`", 
            "0.844984012058356981`", "0.939529178160833211`", 
            "0.977295231595479307`", "0.99246444070316766`"}
          },
        RowSpacings->1,
        ColumnSpacings->3,
        RowAlignments->Baseline,
        ColumnAlignments->{Left}],
      (TableForm[ #]&)]], "Output",
  CellLabel->"Out[17]//TableForm="]
}, Closed]],

Cell[BoxData[
    \(\(sm = 
      StabilityDirect[\[Psi][100], hetWfull[0.2, 1], 0.5, 
        SymmetricModel \[Rule] False, SortByClass \[Rule] True, 
        MigrationOrder \[Rule] MUS, FixedEnds \[Rule] {\[Psi]0, \[Psi]1}]; 
    \)\)], "Input",
  CellLabel->"In[18]:="],

Cell[TextData[
"These are the eigenvalues.  BlockMatrix[] has been used to collapse the 8\
\[Times]8 array of 10\[Times]10 arrays into an 80\[Times]80 array.  There is \
one neutral eigenvalue, \[Lambda]=1.   "], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(ev = Eigenvalues[BlockMatrix[sm]] // Chop\)], "Input",
  CellLabel->"In[19]:="],

Cell[BoxData[
    \({0.999689431758275581`, 0.959273801856505947`, 0.95927380185650577`, 
      0.8508399698654177`, 0.82125144809570898`, 0.821251448095705782`, 
      0.748007830089438563`, 0.728848817916043323`, 0.728848817916041546`, 
      0.658383505634603682`, 0.632078807916855556`, 0.63207880791684996`, 
      0.542134670096420823`, 0.512938836871852466`, 0.512938836871850156`, 
      0.494320720463323848`, 0.494320720463322782`, 0.491320413877497053`, 
      0.416350482916899444`, 0.388206611093779017`, 0.388206611093778786`, 
      0.379475404398075344`, 0.37485887156179527`, 0.374858871561794071`, 
      0.313496073013384224`, 0.313496073013384002`, 0.311061822913612395`, 
      0.308111089095420886`, 0.282444920551765665`, 0.282444920551765363`, 
      0.269955694686449687`, 0.254808977745605025`, 0.254808977745604403`, 
      0.243265504833043788`, 0.234716945429168788`, 0.222178501510880765`, 
      0.222178501510880588`, 0.185876082460587639`, 0.173070825404123223`, 
      0.169718159721065298`, 0.164937243953173968`, 0.164937243953173728`, 
      0.16244172338061027`, 0.162441723380609932`, 0.133368548588200686`, 
      0.12230755356761398`, 0.107918543659507015`, 0.107918543659507015`, 
      0.106517481322719964`, 0.0987511051342948853`, 0.0935053988884001618`, 
      0.0832594372025430295`, 0.0832594372025429763`, 0.0690435483429611096`, 
      0.056565536548206392`, 0.0563841769972485629`, 0.0563841769972484563`, 
      0.052777129244247467`, 0.0380106919960370106`, 0.0356709648902932263`, 
      0.0356709648902930887`, 0.0298777539981662307`, 0.0209744381147819725`, 
      0.0164450815798618954`, 0.0164450815798616822`, 0.012194860897871973`, 
      0.00952415498893149425`, 0.00952415498893145873`, 
      0.00739323240294638583`, 0.00492825616002999211`, 0, 0, 0, 0, 0, 0, 0, 
      0, 0, 0}\)], "Output",
  CellLabel->"Out[19]="]
}, Open  ]],

Cell["These results can be checked against the symmetric model.", "Text"],

Cell[BoxData[
    \(\[Psi]E0 = HaploidSource[3, 0]; \[Psi]E1 = HaploidSource[3, 1]; \n
    StoreExact[\[Psi]F, hetW[0.2, 1], 0.5, {100, 10}, {10, 3}, 
      Compiled \[Rule] True, MigrationOrder \[Rule] USM, 
      FixedEnds \[Rule] {\[Psi]E0, \[Psi]E1}]; \n
    \[Sigma][p_] := 
      SigmaMatrix[
        StabilityK[#1, #2, #3, \[Psi]F[100], hetW[0.2, 1], 0.5, 
            MigrationOrder \[Rule] USM, 
            FixedEnds \[Rule] {\[Psi]E0, \[Psi]E1}]&, p, 3]; \)], "Input",
  CellLabel->"In[3]:="],

Cell[TextData[
"This shows eigenvalues corresponding to concordant fluctuations, in which \
all genotypes within a class retain the same frequency.  This includes the \
neutral eigenvalue, \[Lambda]=1.  The zero eigenvalues reflect perturbations \
which dissappear immediately, owing to the symmetry of the model."], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(ev0 = Eigenvalues[BlockMatrix[\[Sigma][0]]] // Chop\)], "Input",
  CellLabel->"In[4]:="],

Cell[BoxData[
    \({0.999689431147512586`, 0.850839968758241127`, 0.748007829161475967`, 
      0.658383505110345179`, 0.542134669644493616`, 0.491320413163650737`, 
      0.416350482452929337`, 0.379475403549433298`, 0.311061822136354138`, 
      0.308111088734882576`, 0.269955694242795107`, 0.243265504175238733`, 
      0.234716945181745195`, 0.185876082194368521`, 0.173070824772266496`, 
      0.16971815942901836`, 0.133368548084431681`, 0.122307553252245759`, 
      0.10651748115747488`, 0.0987511048685643189`, 0.0935053986442870765`, 
      0.0690435481740304002`, 0.0565655363990242676`, 0.0527771291773706785`, 
      0.0380106918786017811`, 0.0298777539436583303`, 0.0209744380888857095`, 
      0.0121948608514747314`, 0.0073932323764511505`, 
      0.00492825614656928667`, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0}\)], "Output",
  CellLabel->"Out[4]="]
}, Open  ]],

Cell[TextData[
"This shows eigenvalues corresponding to discordant fluctuations.  This \
includes the leading eigevalue, \[Lambda]=1.025."], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(ev1 = Eigenvalues[BlockMatrix[\[Sigma][1]]]\)], "Input",
  CellLabel->"In[5]:="],

Cell[BoxData[
    \({0.959273800681542532`, 0.821251446859534794`, 0.728848817006833193`, 
      0.63207880726883161`, 0.512938836307936796`, 0.494320719585231405`, 
      0.388206610626075132`, 0.37485887049403237`, 0.313496072203613529`, 
      0.282444920123885712`, 0.254808977272871928`, 0.222178501091037938`, 
      0.164937243636898234`, 0.162441723187299791`, 0.107918543429674973`, 
      0.0832594370742553735`, 0.0563841768886700567`, 0.0356709648333884699`, 
      0.0164450815392591653`, 0.00952415496803633487`}\)], "Output",
  CellLabel->"Out[5]="]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData[
"Checking stability of the  solutions for MigrationOrder\[Rule]USM, with \
fixed endpoints"], "SubsubsectionIcon"],

Cell[BoxData[
    \(\[Psi]0 = 
      HaploidSource[3, 0, SymmetricModel \[Rule] False, 
        SortByClass \[Rule] True]; 
    \[Psi]1 = 
      HaploidSource[3, 1, SymmetricModel \[Rule] False, 
        SortByClass \[Rule] True]; \)], "Input"],

Cell[BoxData[
    \(\(StoreExact[\[Psi], hetWfull[0.2, 1], 0.5, {100, 10}, {10, 3}, 
      SymmetricModel \[Rule] False, Compiled \[Rule] True, 
      SortByClass \[Rule] True, MigrationOrder \[Rule] USM, 
      FixedEnds \[Rule] {\[Psi]0, \[Psi]1}]; \)\)], "Input",
  CellLabel->"In[19]:="],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(Table[
          First/@MeanP[\[Psi][t], SymmetricModel \[Rule] False, 
              SortByClass \[Rule] True], {t, 0, 100, 10}] // Chop\) // 
      TableForm\)], "Input",
  CellLabel->"In[20]:="],

Cell[BoxData[
    TagBox[GridBox[{
          {"0", "0", "0", "0", "0", "1", "1", "1", "1", "1"},
          {"0.00382981755349094434`", "0.0153226447105192047`", 
            "0.0522622070062914634`", "0.155477823374686412`", 
            "0.365314687582628527`", "0.634685312417371338`", 
            "0.844522176625313747`", "0.947737792993708616`", 
            "0.984677355289480793`", "0.996170182446508967`"},
          {"0.00821565212245881149`", "0.025642517486678944`", 
            "0.070267455636271805`", "0.177326380136197503`", 
            "0.376081005514679089`", "0.623918994485320954`", 
            "0.822673619863802585`", "0.92973254436372823`", 
            "0.974357482513321038`", "0.991784347877541172`"},
          {"0.00919809717737356002`", "0.0278136243329406074`", 
            "0.0737946517224862397`", "0.181367199034578234`", 
            "0.378014041894333985`", "0.621985958105666014`", 
            "0.818632800965421836`", "0.926205348277513706`", 
            "0.972186375667059543`", "0.990801902822626523`"},
          {"0.00939506416401265198`", "0.0282465490314880174`", 
            "0.0744925932375674548`", "0.182160822027215161`", 
            "0.378392079543259773`", "0.621607920456740359`", 
            "0.81783917797278498`", "0.925507406762432616`", 
            "0.971753450968512133`", "0.990604935835987454`"},
          {"0.00943424934360869116`", "0.0283326246896801379`", 
            "0.0746312149778866729`", "0.182318262770885741`", 
            "0.378467022054304491`", "0.621532977945695463`", 
            "0.817681737229114169`", "0.925368785022113371`", 
            "0.971667375310319947`", "0.990565750656391408`"},
          {"0.00944204071784945853`", "0.0283497381153740768`", 
            "0.0746587708198505062`", "0.182349553003823139`", 
            "0.378481914391807539`", "0.621518085608192372`", 
            "0.817650446996177038`", "0.925341229180149582`", 
            "0.971650261884625976`", "0.99055795928215069`"},
          {"0.00944358986533984179`", "0.0283531407070388716`", 
            "0.0746642494637446851`", "0.182355773871700943`", 
            "0.378484875089481587`", "0.621515124910518146`", 
            "0.817644226128298967`", "0.925335750536255297`", 
            "0.971646859292961018`", "0.990556410134660048`"},
          {"0.00944389787999759633`", "0.0283538172375538586`", 
            "0.0746653387651025113`", "0.182357010737532991`", 
            "0.378485463748117245`", "0.621514536251882798`", 
            "0.81764298926246699`", "0.925334661234897559`", 
            "0.971646182762446031`", "0.990556102120002357`"},
          {"0.00944395912211319377`", "0.0283539517510894167`", 
            "0.0746655553489858725`", "0.182357256661027449`", 
            "0.378485580789790354`", "0.621514419210209823`", 
            "0.817642743338972621`", "0.925334444651014287`", 
            "0.971646048248910609`", "0.9905560408778868`"},
          {"0.00944397129879725838`", "0.0283539784962248333`", 
            "0.07466559841204214`", "0.182357305557620854`", 
            "0.378485604061003222`", "0.621514395938996955`", 
            "0.81764269444237918`", "0.9253344015879577`", 
            "0.971646021503775081`", "0.990556028701202784`"}
          },
        RowSpacings->1,
        ColumnSpacings->3,
        RowAlignments->Baseline,
        ColumnAlignments->{Left}],
      (TableForm[ #]&)]], "Output",
  CellLabel->"Out[20]//TableForm="]
}, Closed]],

Cell[BoxData[
    \(\(sm = 
      StabilityDirect[\[Psi][100], hetWfull[0.2, 1], 0.5, 
        SymmetricModel \[Rule] False, SortByClass \[Rule] True, 
        MigrationOrder \[Rule] USM, FixedEnds \[Rule] {\[Psi]0, \[Psi]1}]; 
    \)\)], "Input",
  CellLabel->"In[21]:="],

Cell[TextData[
"These are the eigenvalues.  BlockMatrix[] has been used to collapse the 8\
\[Times]8 array of 10\[Times]10 arrays into an 80\[Times]80 array.  There is \
one neutral eigenvalue, \[Lambda]=1.  Note that these eigenvalues are the \
same as for MigrationOrder\[Rule]MUS.  This is because migration of diploids, \
followed by meiosis, is equivalent to meiosis, followed by migration of \
haploids."], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(ev = Eigenvalues[BlockMatrix[sm]] // Chop\)], "Input",
  CellLabel->"In[22]:="],

Cell[BoxData[
    \({0.999689431147514895`, 0.959273800681544486`, 0.959273800681543598`, 
      0.850839968758242903`, 0.821251446859536393`, 0.821251446859533018`, 
      0.748007829161476323`, 0.728848817006836124`, 0.728848817006831417`, 
      0.658383505110345357`, 0.632078807268831432`, 0.632078807268830544`, 
      0.542134669644496369`, 0.512938836307936441`, 0.512938836307934309`, 
      0.494320719585232204`, 0.494320719585230428`, 0.491320413163649227`, 
      0.416350482452928005`, 0.388206610626073711`, 0.388206610626073711`, 
      0.379475403549433254`, 0.374858870494033435`, 0.374858870494031837`, 
      0.313496072203613085`, 0.313496072203612641`, 0.311061822136355115`, 
      0.308111088734883287`, 0.282444920123885356`, 0.282444920123885356`, 
      0.269955694242795241`, 0.254808977272871839`, 0.254808977272871439`, 
      0.243265504175238023`, 0.234716945181744929`, 0.222178501091038249`, 
      0.222178501091038027`, 0.185876082194369036`, 0.173070824772266185`, 
      0.169718159429017827`, 0.164937243636898189`, 0.164937243636898074`, 
      0.162441723187300013`, 0.162441723187299702`, 0.133368548084431948`, 
      0.122307553252246292`, 0.107918543429675084`, 0.107918543429675084`, 
      0.10651748115747508`, 0.0987511048685635195`, 0.0935053986442868456`, 
      0.0832594370742553557`, 0.0832594370742553202`, 0.0690435481740306933`, 
      0.0565655363990234327`, 0.0563841768886702343`, 0.0563841768886702077`, 
      0.0527771291773709183`, 0.0380106918786026213`, 0.0356709648333883855`, 
      0.0356709648333882611`, 0.0298777539436580816`, 0.0209744380888863268`, 
      0.0164450815392590721`, 0.0164450815392590277`, 0.0121948608514745782`, 
      0.00952415496803611638`, 0.00952415496803611638`, 
      0.00739323237645065489`, 0.00492825614656942612`, 0, 0, 0, 0, 0, 0, 0, 
      0, 0, 0}\)], "Output",
  CellLabel->"Out[22]="]
}, Open  ]],

Cell["These results can be checked against the symmetric model.", "Text"],

Cell[BoxData[
    \(\[Psi]E0 = HaploidSource[3, 0]; \[Psi]E1 = HaploidSource[3, 1]; \n
    StoreExact[\[Psi]E, hetW[0.2, 1], 0.5, {100, 10}, {10, 3}, 
      Compiled \[Rule] True, MigrationOrder \[Rule] USM, 
      FixedEnds \[Rule] {\[Psi]E0, \[Psi]E1}]; \n
    \[Sigma][p_] := 
      SigmaMatrix[
        StabilityK[#1, #2, #3, \[Psi]E[100], hetW[0.2, 1], 0.5, 
            MigrationOrder \[Rule] USM, 
            FixedEnds \[Rule] {\[Psi]E0, \[Psi]E1}]&, p, 3]; \)], "Input",
  CellLabel->"In[4]:="],

Cell[TextData[
"This shows eigenvalues corresponding to concordant fluctuations, in which \
all genotypes within a class retain the same frequency.  This includes the \
neutral eigenvalue, \[Lambda]=1.  The zero eigenvalues reflect perturbations \
which dissappear immediately, owing to the symmetry of the model."], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(ev0 = Eigenvalues[BlockMatrix[\[Sigma][0]]] // Chop\)], "Input",
  CellLabel->"In[5]:="],

Cell[BoxData[
    \({0.999689431147512586`, 0.850839968758241127`, 0.748007829161475967`, 
      0.658383505110345179`, 0.542134669644493616`, 0.491320413163650737`, 
      0.416350482452929337`, 0.379475403549433298`, 0.311061822136354138`, 
      0.308111088734882576`, 0.269955694242795107`, 0.243265504175238733`, 
      0.234716945181745195`, 0.185876082194368521`, 0.173070824772266496`, 
      0.16971815942901836`, 0.133368548084431681`, 0.122307553252245759`, 
      0.10651748115747488`, 0.0987511048685643189`, 0.0935053986442870765`, 
      0.0690435481740304002`, 0.0565655363990242676`, 0.0527771291773706785`, 
      0.0380106918786017811`, 0.0298777539436583303`, 0.0209744380888857095`, 
      0.0121948608514747314`, 0.0073932323764511505`, 
      0.00492825614656928667`, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0}\)], "Output",
  CellLabel->"Out[5]="]
}, Open  ]],

Cell[TextData[
"This shows eigenvalues corresponding to discordant fluctuations.  This \
includes the leading eigevalue, \[Lambda]=1.025."], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(ev1 = Eigenvalues[BlockMatrix[\[Sigma][1]]]\)], "Input",
  CellLabel->"In[6]:="],

Cell[BoxData[
    \({0.959273800681542532`, 0.821251446859534794`, 0.728848817006833193`, 
      0.63207880726883161`, 0.512938836307936796`, 0.494320719585231405`, 
      0.388206610626075132`, 0.37485887049403237`, 0.313496072203613529`, 
      0.282444920123885712`, 0.254808977272871928`, 0.222178501091037938`, 
      0.164937243636898234`, 0.162441723187299791`, 0.107918543429674973`, 
      0.0832594370742553735`, 0.0563841768886700567`, 0.0356709648333884699`, 
      0.0164450815392591653`, 0.00952415496803633487`}\)], "Output",
  CellLabel->"Out[6]="]
}, Open  ]]
}, Closed]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Checking for spatially varying selection......", "SubsectionIcon"],

Cell[CellGroupData[{

Cell["Defining fitness", "SubsubsectionIcon"],

Cell[BoxData[
    \(\(\(grWfull[s_, x0_]\)[x_]\)[X_, Y_] := 
      \((1 + s)\)\^\(\((Plus@@\((X + Y)\) - 3)\) \((x - x0)\)\); \n
    \(\(grW[s_, x0_]\)[x_]\)[i_, j_, _] := 
      \((1 + s)\)\^\(\((i + j - 3)\) \((x - x0)\)\); \)], "Input",
  CellLabel->"In[2]:="],

Cell[BoxData[
    \(\(<< Graphics`Colors`; \)\)], "Input",
  CellLabel->"In[6]:="],

Cell[BoxData[
    \(dfi = DisplayFunction \[Rule] Identity; 
    dfs = DisplayFunction \[Rule] $DisplayFunction; \)], "Input",
  CellLabel->"In[4]:="]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData[
"Checking stability of the  solutions for MigrationOrder\[Rule]MUS"], 
  "SubsubsectionIcon"],

Cell[CellGroupData[{

Cell[BoxData[
    \(StoreExact[\[Psi], grWfull[0.01, 10.5], 0.5, {500, 100}, {20, 3}, 
      SymmetricModel \[Rule] False, Compiled \[Rule] True, 
      SortByClass \[Rule] True, MigrationOrder \[Rule] MUS]; \n
    StoreExact[\[Psi]E, grW[0.01, 10.5], 0.5, {500, 100}, {20, 3}, 
      Compiled \[Rule] True, MigrationOrder \[Rule] MUS]; \n
    MeanP[\[Psi]E[500]] - 
        First/@MeanP[\[Psi][500], SymmetricModel \[Rule] False, 
            SortByClass \[Rule] True] // Chop\)], "Input",
  CellLabel->"In[3]:="],

Cell[BoxData[
    \({0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0}\)], 
  "Output",
  CellLabel->"Out[9]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(Show[
      ListPlot[First/@
          MeanP[\[Psi][500], SymmetricModel \[Rule] False, 
            SortByClass \[Rule] True], PlotJoined -> True, dfi], 
      ListPlot[MeanP[\[Psi]E[500]], PlotJoined -> True, 
        PlotStyle \[Rule] Red, dfi], dfs]; \)\)], "Input",
  CellLabel->"In[7]:="],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.047619 0.0147151 0.594416 [
[.2619 .00222 -3 -9 ]
[.2619 .00222 3 0 ]
[.5 .00222 -6 -9 ]
[.5 .00222 6 0 ]
[.7381 .00222 -6 -9 ]
[.7381 .00222 6 0 ]
[.97619 .00222 -6 -9 ]
[.97619 .00222 6 0 ]
[.01131 .1336 -18 -4.5 ]
[.01131 .1336 0 4.5 ]
[.01131 .25248 -18 -4.5 ]
[.01131 .25248 0 4.5 ]
[.01131 .37136 -18 -4.5 ]
[.01131 .37136 0 4.5 ]
[.01131 .49025 -18 -4.5 ]
[.01131 .49025 0 4.5 ]
[.01131 .60913 -6 -4.5 ]
[.01131 .60913 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2619 .01472 m
.2619 .02097 L
s
[(5)] .2619 .00222 0 1 Mshowa
.5 .01472 m
.5 .02097 L
s
[(10)] .5 .00222 0 1 Mshowa
.7381 .01472 m
.7381 .02097 L
s
[(15)] .7381 .00222 0 1 Mshowa
.97619 .01472 m
.97619 .02097 L
s
[(20)] .97619 .00222 0 1 Mshowa
.125 Mabswid
.07143 .01472 m
.07143 .01847 L
s
.11905 .01472 m
.11905 .01847 L
s
.16667 .01472 m
.16667 .01847 L
s
.21429 .01472 m
.21429 .01847 L
s
.30952 .01472 m
.30952 .01847 L
s
.35714 .01472 m
.35714 .01847 L
s
.40476 .01472 m
.40476 .01847 L
s
.45238 .01472 m
.45238 .01847 L
s
.54762 .01472 m
.54762 .01847 L
s
.59524 .01472 m
.59524 .01847 L
s
.64286 .01472 m
.64286 .01847 L
s
.69048 .01472 m
.69048 .01847 L
s
.78571 .01472 m
.78571 .01847 L
s
.83333 .01472 m
.83333 .01847 L
s
.88095 .01472 m
.88095 .01847 L
s
.92857 .01472 m
.92857 .01847 L
s
.25 Mabswid
0 .01472 m
1 .01472 L
s
.02381 .1336 m
.03006 .1336 L
s
[(0.2)] .01131 .1336 1 0 Mshowa
.02381 .25248 m
.03006 .25248 L
s
[(0.4)] .01131 .25248 1 0 Mshowa
.02381 .37136 m
.03006 .37136 L
s
[(0.6)] .01131 .37136 1 0 Mshowa
.02381 .49025 m
.03006 .49025 L
s
[(0.8)] .01131 .49025 1 0 Mshowa
.02381 .60913 m
.03006 .60913 L
s
[(1)] .01131 .60913 1 0 Mshowa
.125 Mabswid
.02381 .04444 m
.02756 .04444 L
s
.02381 .07416 m
.02756 .07416 L
s
.02381 .10388 m
.02756 .10388 L
s
.02381 .16332 m
.02756 .16332 L
s
.02381 .19304 m
.02756 .19304 L
s
.02381 .22276 m
.02756 .22276 L
s
.02381 .2822 m
.02756 .2822 L
s
.02381 .31192 m
.02756 .31192 L
s
.02381 .34164 m
.02756 .34164 L
s
.02381 .40109 m
.02756 .40109 L
s
.02381 .43081 m
.02756 .43081 L
s
.02381 .46053 m
.02756 .46053 L
s
.02381 .51997 m
.02756 .51997 L
s
.02381 .54969 m
.02756 .54969 L
s
.02381 .57941 m
.02756 .57941 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.07143 .02053 m
.11905 .02281 L
.16667 .02793 L
.21429 .03711 L
.2619 .05217 L
.30952 .07538 L
.35714 .10902 L
.40476 .15457 L
.45238 .2117 L
.5 .27745 L
.54762 .3464 L
.59524 .41215 L
.64286 .46928 L
.69048 .51483 L
.7381 .54847 L
.78571 .57168 L
.83333 .58674 L
.88095 .59591 L
.92857 .60103 L
.97619 .60332 L
s
1 0 0 r
.07143 .02053 m
.11905 .02281 L
.16667 .02793 L
.21429 .03711 L
.2619 .05217 L
.30952 .07538 L
.35714 .10902 L
.40476 .15457 L
.45238 .2117 L
.5 .27745 L
.54762 .3464 L
.59524 .41215 L
.64286 .46928 L
.69048 .51483 L
.7381 .54847 L
.78571 .57168 L
.83333 .58674 L
.88095 .59591 L
.92857 .60103 L
.97619 .60332 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[7]:=",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/A000`40O003h00Oogoo8Goo003oOolQ
Ool005Aoo`<003Yoo`<000Aoo`8003Qoo`<000=oo`<003Moo`@000=oo`8000Eoo`00Egoo00<007oo
Ool0>7oo00<007ooOol00Woo00@007ooOol003Qoo`03001oogoo00Eoo`03001oogoo03Eoo`03001o
ogoo009oo`04001oogoo0004Ool005Moo`03001oogoo03Qoo`03001oogoo009oo`04001oogoo000h
Ool00`00Oomoo`05Ool00`00Oomoo`0fOol01@00Oomoogoo00000Woo00<007ooOol00Woo001DOol3
000kOol00`00Oomoo`02Ool01000Oomoo`00>7oo00<007ooOol00Woo0`00>Woo00@007ooOol0009o
o`03001oogoo009oo`00E7oo00<007ooOol0>goo00<007ooOol00Woo00@007ooOol003Qoo`03001o
ogoo009oo`03001oogoo03Moo`04001oogoo0002Ool01000Oomoo`0017oo001DOol4000iOol20005
Ool2000hOol20004Ool4000gOol20004Ool20005Ool001Ioo`03001oogoo0?moo`Qoo`005Woo00<0
07ooOol0ogoo27oo000FOol00`00Oomoo`3oOol8Ool001Ioo`03001oogoo0?moo`Qoo`0047ooo`00
3`000Woo000FOol00`00Oomoo`0:Ool8O005Ool00`00Oomoo`0:Ool00`00Oomoo`0:Ool00`00Oomo
o`09Ool00`00Oomoo`0:Ool00`00Oomoo`0:Ool00`00Oomoo`0:Ool00`00Oomoo`0:Ool00`00Oomo
o`09Ool00`00Oomoo`0:Ool00`00Oomoo`0:Ool00`00Oomoo`0:Ool00`00Oomoo`0:Ool00`00Oomo
o`0:Ool00`00Oomoo`09Ool00`00Oomoo`0:Ool00`00Oomoo`0:Ool00`00Oomoo`0:Ool00`00Oomo
o`0:Ool00`00Oomoo`06Ool001Ioo`03001oogoo019oo`el01ioo`03001oogoo03eoo`03001oogoo
03ioo`03001oogoo03eoo`03001oogoo00Ioo`005Woo00<007ooOol07goo27`0h7oo000FOol00`00
Oomoo`0WOol5O03KOol001Ioo`03001oogoo02aoo`Al0=Moo`005Woo00<007ooOol0<7oo17`0dgoo
000FOol00`00Oomoo`0dOol3O03@Ool001Ioo`8003Qoo`=l0<eoo`005Woo00<007ooOol0>Woo0g`0
bWoo000FOol00`00Oomoo`0mOol2O038Ool001Ioo`03001oogoo03moo`9l0<Ioo`005Woo00<007oo
Ool0@Goo0W`0a7oo000FOol00`00Oomoo`13Ool3O031Ool001Ioo`03001oogoo04Ioo`9l0;moo`00
5Woo00<007ooOol0B7oo0W`0_Goo000FOol2001;Ool2O02kOol001Ioo`03001oogoo04aoo`03O01o
ogoo0;Qoo`005Woo00<007ooOol0CGoo0W`0^7oo000FOol00`00Oomoo`1?Ool00g`0Oomoo`2eOol0
01Ioo`03001oogoo051oo`9l0;Eoo`005Woo00<007ooOol0DWoo00=l07ooOol0/Woo000FOol00`00
Oomoo`1COol00g`0Oomoo`2aOol001Ioo`03001oogoo05Aoo`9l0;5oo`005Woo0P00Egoo00=l07oo
Ool0[Woo000FOol00`00Oomoo`1GOol00g`0Oomoo`2]Ool001Ioo`03001oogoo05Qoo`03O01oogoo
0:aoo`005Woo00<007ooOol0FGoo00=l07ooOol0Zgoo000FOol00`00Oomoo`1JOol00g`0Oomoo`2Z
Ool001Ioo`03001oogoo05]oo`03O01oogoo0:Uoo`000goo0P0017oo0P000goo100017oo00<007oo
Ool0G7oo00=l07ooOol0Z7oo0002Ool01000Oomoo`000goo0P0017oo00<007ooOol017oo00<007oo
Ool0GGoo00=l07ooOol0Ygoo0002Ool01000Oomoo`002Woo00<007ooOol00goo0`00GWoo00=l07oo
Ool0YWoo0002Ool01000Oomoo`002goo00<007ooOol00Woo00<007ooOol0Ggoo00=l07ooOol0YGoo
0002Ool01000Oomoo`0027oo00@007ooOol000Aoo`03001oogoo061oo`03O01oogoo0:Aoo`000goo
0P002Woo0P001Goo00<007ooOol0HGoo00=l07ooOol0Xgoo000FOol00`00Oomoo`1ROol00g`0Oomo
o`2ROol001Ioo`03001oogoo06=oo`03O01oogoo0:5oo`005Woo00<007ooOol0I7oo00=l07ooOol0
X7oo000FOol00`00Oomoo`1TOol00g`0Oomoo`2POol001Ioo`8006Ioo`03O01oogoo09moo`005Woo
00<007ooOol0IWoo00=l07ooOol0WWoo000FOol00`00Oomoo`1WOol00g`0Oomoo`2MOol001Ioo`03
001oogoo06Qoo`03O01oogoo09aoo`005Woo00<007ooOol0JGoo00=l07ooOol0Vgoo000FOol00`00
Oomoo`1ZOol00g`0Oomoo`2JOol001Ioo`03001oogoo06]oo`03O01oogoo09Uoo`005Woo00<007oo
Ool0Jgoo00=l07ooOol0VGoo000FOol2001]Ool00g`0Oomoo`2HOol001Ioo`03001oogoo06eoo`03
O01oogoo09Moo`005Woo00<007ooOol0KWoo00=l07ooOol0UWoo000FOol00`00Oomoo`1_Ool00g`0
Oomoo`2EOol001Ioo`03001oogoo071oo`03O01oogoo09Aoo`005Woo00<007ooOol0LGoo00=l07oo
Ool0Tgoo000FOol00`00Oomoo`1aOol00g`0Oomoo`2COol001Ioo`03001oogoo079oo`03O01oogoo
099oo`005Woo0P00M7oo00=l07ooOol0TGoo000FOol00`00Oomoo`1cOol00g`0Oomoo`2AOol001Io
o`03001oogoo07Aoo`03O01oogoo091oo`005Woo00<007ooOol0MGoo00=l07ooOol0Sgoo000FOol0
0`00Oomoo`1eOol00g`0Oomoo`2?Ool001Ioo`03001oogoo07Ioo`03O01oogoo08ioo`000goo0P00
17oo0P0017oo0`0017oo00<007ooOol0Mgoo00=l07ooOol0SGoo0002Ool01000Oomoo`000goo0P00
1Goo00<007ooOol00goo00<007ooOol0Mgoo00=l07ooOol0SGoo0002Ool01000Oomoo`0027oo1000
17oo0`00N7oo00=l07ooOol0S7oo0002Ool01000Oomoo`0027oo00<007oo00001Goo00<007ooOol0
NGoo00=l07ooOol0Rgoo0002Ool01000Oomoo`0027oo00<007oo00001Goo00<007ooOol0NGoo00=l
07ooOol0Rgoo0003Ool2000:Ool20005Ool00`00Oomoo`1jOol00g`0Oomoo`2:Ool001Ioo`03001o
ogoo07]oo`03O01oogoo08Uoo`005Woo00<007ooOol0Ngoo00=l07ooOol0RGoo000FOol00`00Oomo
o`1lOol00g`0Oomoo`28Ool001Ioo`03001oogoo07eoo`03O01oogoo08Moo`005Woo0P00OWoo00=l
07ooOol0Qgoo000FOol00`00Oomoo`1nOol00g`0Oomoo`26Ool001Ioo`03001oogoo07moo`03O01o
ogoo08Eoo`005Woo00<007ooOol0P7oo00=l07ooOol0Q7oo000FOol00`00Oomoo`20Ool00g`0Oomo
o`24Ool001Ioo`03001oogoo085oo`03O01oogoo08=oo`005Woo00<007ooOol0PWoo00=l07ooOol0
PWoo000FOol00`00Oomoo`22Ool00g`0Oomoo`22Ool001Ioo`8008Aoo`03O01oogoo085oo`005Woo
00<007ooOol0Q7oo00=l07ooOol0P7oo000FOol00`00Oomoo`25Ool00g`0Oomoo`1oOol001Ioo`03
001oogoo08Eoo`03O01oogoo07moo`005Woo00<007ooOol0QWoo00=l07ooOol0OWoo000FOol00`00
Oomoo`27Ool00g`0Oomoo`1mOol001Ioo`03001oogoo08Moo`03O01oogoo07eoo`005Woo00<007oo
Ool0R7oo00=l07ooOol0O7oo000FOol2002:Ool00g`0Oomoo`1kOol001Ioo`03001oogoo08Yoo`03
O01oogoo07Yoo`005Woo00<007ooOol0RWoo00=l07ooOol0NWoo000FOol00`00Oomoo`2;Ool00g`0
Oomoo`1iOol001Ioo`03001oogoo08aoo`03O01oogoo07Qoo`005Woo00<007ooOol0SGoo00=l07oo
Ool0Mgoo0003Ool20004Ool20004Ool20005Ool00`00Oomoo`2=Ool00g`0Oomoo`1gOol0009oo`04
001oogoo0003Ool20003Ool01000Oomoo`0017oo00<007ooOol0SWoo00=l07ooOol0MWoo0002Ool0
1000Oomoo`0027oo00@007ooOol000Aoo`<008moo`03O01oogoo07Eoo`000Woo00@007ooOol000Qo
o`<000Eoo`03001oogoo08moo`03O01oogoo07Eoo`000Woo00@007ooOol000Qoo`03001oogoo00Eo
o`03001oogoo091oo`03O01oogoo07Aoo`000goo0P002Woo0`0017oo00<007ooOol0TGoo00=l07oo
Ool0Lgoo000FOol00`00Oomoo`2BOol00g`0Oomoo`1bOol001Ioo`03001oogoo099oo`03O01oogoo
079oo`005Woo00<007ooOol0Tgoo00=l07ooOol0LGoo000FOol00`00Oomoo`2DOol00g`0Oomoo`1`
Ool001Ioo`8009Eoo`03O01oogoo071oo`005Woo00<007ooOol0UGoo00=l07ooOol0Kgoo000FOol0
0`00Oomoo`2FOol00g`0Oomoo`1^Ool001Ioo`03001oogoo09Moo`03O01oogoo06eoo`005Woo00<0
07ooOol0Ugoo00=l07ooOol0KGoo000FOol00`00Oomoo`2HOol00g`0Oomoo`1/Ool001Ioo`03001o
ogoo09Uoo`03O01oogoo06]oo`005Woo00<007ooOol0VWoo00=l07ooOol0JWoo000FOol2002LOol0
0g`0Oomoo`1YOol001Ioo`03001oogoo09aoo`03O01oogoo06Qoo`005Woo00<007ooOol0WGoo00=l
07ooOol0Igoo000FOol00`00Oomoo`2NOol00g`0Oomoo`1VOol001Ioo`03001oogoo09ioo`03O01o
ogoo06Ioo`005Woo00<007ooOol0Wgoo00=l07ooOol0IGoo000FOol00`00Oomoo`2POol00g`0Oomo
o`1TOol001Ioo`03001oogoo0:5oo`03O01oogoo06=oo`005Woo0P00Xgoo00=l07ooOol0HWoo000F
Ool00`00Oomoo`2SOol00g`0Oomoo`1QOol001Ioo`03001oogoo0:Aoo`03O01oogoo061oo`005Woo
00<007ooOol0YGoo00=l07ooOol0Ggoo000FOol00`00Oomoo`2VOol00g`0Oomoo`1NOol001Ioo`03
001oogoo0:Moo`03O01oogoo05eoo`000goo0P0017oo0P0017oo0P001Goo00<007ooOol0Z7oo00=l
07ooOol0G7oo0002Ool01000Oomoo`000goo0P000goo00@007ooOol000Aoo`03001oogoo0:Uoo`03
O01oogoo05]oo`000Woo00@007ooOol000Qoo`04001oogoo0004Ool3002ZOol00g`0Oomoo`1JOol0
009oo`04001oogoo0009Ool20005Ool00`00Oomoo`2[Ool00g`0Oomoo`1IOol0009oo`04001oogoo
0008Ool01000Oomoo`0017oo00<007ooOol0[7oo00=l07ooOol0F7oo0003Ool2000:Ool20005Ool0
0`00Oomoo`2]Ool00g`0Oomoo`1GOol001Ioo`03001oogoo0:ioo`03O01oogoo05Ioo`005Woo00<0
07ooOol0[goo00=l07ooOol0EGoo000FOol00`00Oomoo`2`Ool00g`0Oomoo`1DOol001Ioo`03001o
ogoo0;5oo`9l05Aoo`005Woo0P00]7oo00=l07ooOol0DGoo000FOol00`00Oomoo`2dOol2O01AOol0
01Ioo`03001oogoo0;Ioo`03O01oogoo04ioo`005Woo00<007ooOol0]goo0W`0CWoo000FOol00`00
Oomoo`2iOol00g`0Oomoo`1;Ool001Ioo`03001oogoo0;Yoo`03O01oogoo04Yoo`005Woo00<007oo
Ool0^goo0W`0BWoo000FOol00`00Oomoo`2mOol00g`0Oomoo`17Ool001Ioo`800;moo`9l04Moo`00
5Woo00<007ooOol0`7oo0W`0AGoo000FOol00`00Oomoo`32Ool2O013Ool001Ioo`03001oogoo0<Ao
o`9l045oo`005Woo00<007ooOol0aWoo0W`0?goo000FOol00`00Oomoo`38Ool2O00mOol001Ioo`03
001oogoo0<Yoo`=l03Yoo`005Woo00<007ooOol0cGoo0g`0=goo000FOol2003AOol3O00dOol001Io
o`03001oogoo0==oo`=l035oo`005Woo00<007ooOol0eWoo1G`0;7oo000FOol00`00Oomoo`3KOol7
O00UOol001Ioo`03001oogoo0>9oo`Il01moo`005Woo00<007ooOol0j7oo1g`067oo000>Ool30005
Ool00`00Oomoo`3_Ool@O008Ool000moo`03001oogoo00Aoo`03001oogoo0?moo`Qoo`003goo00<0
07ooOol017oo0`00ogoo27oo000?Ool00`00Oomoo`04Ool00`00Oomoo`3oOol8Ool000moo`03001o
ogoo00Aoo`03001oogoo0?moo`Qoo`003Woo0P00ogoo4Goo003oOolQOol00001\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-1.77355, -0.0772508, 
  0.0779824, 0.00624721}}]
}, Open  ]],

Cell[TextData[
"These are the eigenvalues.  BlockMatrix[] has been used to collapse the 8\
\[Times]8 array of 20\[Times]20 arrays into a 160\[Times]160 array.  There \
are two unstable eigenvalues, \[Lambda]=1.0324, and one neutral eigenvalue, \
\[Lambda]=1.  "], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(sm = 
      StabilityDirect[\[Psi][500], grWfull[0.01, 10.5], 0.5, 
        SymmetricModel \[Rule] False, SortByClass \[Rule] True, 
        MigrationOrder \[Rule] MUS]; \n
    ev = Eigenvalues[BlockMatrix[sm]] // Chop\)], "Input",
  CellLabel->"In[10]:="],

Cell[BoxData[
    \({0.978609193890774875`, 0.97860919389077452`, 0.97776999322284066`, 
      0.944100242377491305`, 0.943877866262561049`, 0.943877866262559628`, 
      0.920724508162521892`, 0.920388585836259309`, 0.920388585836257178`, 
      0.897661472966257178`, 0.897346298156660715`, 0.897346298156659649`, 
      0.863112728294515996`, 0.862723361867528915`, 0.86272336186752625`, 
      0.816289944875480166`, 0.815760433254594197`, 0.815760433254594197`, 
      0.760169204668934916`, 0.759459920857436987`, 0.759459920857436543`, 
      0.696791961191303688`, 0.69587209477638563`, 0.695872094776385008`, 
      0.627925867720868335`, 0.626772791617013158`, 0.626772791617010849`, 
      0.555349129197716617`, 0.55394753766377347`, 0.55394753766377347`, 
      0.484269268780416872`, 0.484269268780416695`, 0.482827993549947986`, 
      0.48088858342945322`, 0.479230187192288248`, 0.479230187192287626`, 
      0.457230945076463868`, 0.457230945076463779`, 0.456324447369427588`, 
      0.436602838782599445`, 0.436602838782598734`, 0.436045782306073625`, 
      0.421609296534077415`, 0.421609296534075728`, 0.421234820934544273`, 
      0.407103066873437491`, 0.407103066873436247`, 
      \(0.406592452741084997`\[InvisibleSpace]\) + 
        0.000904310504389401081`\ I, 
      \(0.406592452741084997`\[InvisibleSpace]\) - 
        0.000904310504389401081`\ I, 0.404562607255081729`, 
      0.404562607255081463`, 0.38735048512841006`, 0.387350485128408639`, 
      0.386801640881813391`, 0.361596654943425255`, 0.361596654943425122`, 
      0.360966872137072947`, 0.334714685279346912`, 0.332604929928982429`, 
      0.332604929928982073`, 0.330636832749488185`, 0.330636832749487963`, 
      0.330049852482112271`, 0.298908562452315962`, 0.29890856245231534`, 
      0.298415787065250803`, 0.264307004897573438`, 0.264165898587534897`, 
      0.264165898587534364`, 0.263671025049357465`, 0.262173777188132994`, 
      0.262173777188131751`, 0.239962511223343266`, 0.228482006566919348`, 
      0.228482006566918993`, 0.22811587524578063`, 0.223055827193028477`, 
      0.209501607935653666`, 0.199050590521526373`, 0.198740991904794856`, 
      0.197672346502863245`, 0.197672346502863245`, 0.194214208257739873`, 
      0.193267271812589847`, 0.193267271812589704`, 0.191103252785646908`, 
      0.182629965969388372`, 0.171397334671503864`, 0.157970764833762533`, 
      0.157406262386309396`, 0.157406262386309307`, 0.154836615652763605`, 
      0.146153753989535406`, 0.142221888581634186`, 0.14159680387106488`, 
      0.141596803871064613`, 0.125715846380274243`, 0.124259409016766486`, 
      0.124259409016766353`, 0.122695873323350745`, 0.108748855357088714`, 
      0.0970045782024106806`, 0.093542894876824647`, 0.0935428948768245582`, 
      0.0929155310560139824`, 0.0929155310560138048`, 
      \(0.0918374329536742983`\[InvisibleSpace]\) + 
        0.00147599642450571577`\ I, 
      \(0.0918374329536742983`\[InvisibleSpace]\) - 
        0.00147599642450571577`\ I, 0.0744698461340319539`, 
      0.0660303813686006435`, 0.0660303813686005369`, 0.0648630535227021454`, 
      \(0.0586045581525512915`\[InvisibleSpace]\) + 
        0.000195565183055382281`\ I, 
      \(0.0586045581525512915`\[InvisibleSpace]\) - 
        0.000195565183055382281`\ I, 0.0541592028341164155`, 
      0.0541592028341163711`, 0.0438006735411237624`, 0.0421846685608492855`, 
      0.0421846685608492855`, 0.0408578018259039055`, 0.0313495999755242493`, 
      0.0303615846908500142`, 0.0272366370065378005`, 0.0272366370065377427`, 
      0.0219010359588680003`, 0.0215027524745198217`, 0.0215027524745195286`, 
      0.0176428051351080057`, 0.0149184304527252269`, 0.0117083051719424835`, 
      0.0117083051719424102`, 0.0104961492841179682`, 
      0.00606248387384015607`, 0.00582495277586859128`, 
      0.00582495277586854243`, 0.00529955428362313618`, 
      0.00297421801086585979`, 0.00297421801086579495`, 
      0.00277472045852577275`, 0.00148113236270268844`, 0, 0, 0, 0, 0, 0, 0, 
      0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0}\)], "Output",
  CellLabel->"Out[10]="]
}, Open  ]],

Cell["These results can be checked against the symmetric model.", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(ev = 
      ExactEigenvalues[
        StabilityK[#1, #2, #3, \[Psi]E[500], grW[0.01, 10.5], 0.5, 
            MigrationOrder \[Rule] MUS]&, 3]; \n
    \(ev // Chop\) // TableForm\)], "Input",
  CellLabel->"In[11]:="],

Cell[BoxData[
    InterpretationBox[GridBox[{
          {"0.97776999322284368`", "0.944100242377487397`", 
            "0.920724508162522958`", "0.897661472966258067`", 
            "0.863112728294509601`", "0.816289944875481765`", 
            "0.760169204668933318`", "0.696791961191307152`", 
            "0.627925867720864161`", "0.555349129197721147`", 
            "0.482827993549943634`", "0.480888583429451799`", 
            "0.456324447369428209`", "0.436045782306072737`", 
            "0.421234820934544895`", 
            \(\(0.406592452741082599`\[InvisibleSpace]\) + 
              0.000904310504389285441`\ I\), 
            \(\(0.406592452741082599`\[InvisibleSpace]\) - 
              0.000904310504389285441`\ I\), "0.386801640881814279`", 
            "0.360966872137072858`", "0.334714685279348156`", 
            "0.330049852482111738`", "0.298415787065248636`", 
            "0.264307004897572461`", "0.263671025049354845`", 
            "0.239962511223343133`", "0.228115875245779475`", 
            "0.223055827193028566`", "0.209501607935653177`", 
            "0.199050590521525201`", "0.198740991904794856`", 
            "0.194214208257740494`", "0.191103252785646233`", 
            "0.182629965969387964`", "0.171397334671503749`", 
            "0.157970764833759851`", "0.15483661565276499`", 
            "0.146153753989535184`", "0.142221888581633981`", 
            "0.125715846380274087`", "0.122695873323351878`", 
            "0.108748855357088537`", "0.0970045782024105029`", 
            \(\(0.091837432953674547`\[InvisibleSpace]\) + 
              0.00147599642450660724`\ I\), 
            \(\(0.091837432953674547`\[InvisibleSpace]\) - 
              0.00147599642450660724`\ I\), "0.074469846134032025`", 
            "0.0648630535227024296`", 
            \(\(0.0586045581525511494`\[InvisibleSpace]\) + 
              0.000195565183056047544`\ I\), 
            \(\(0.0586045581525511494`\[InvisibleSpace]\) - 
              0.000195565183056047544`\ I\), "0.0438006735411234071`", 
            "0.0408578018259036301`", "0.031349599975523672`", 
            "0.0303615846908502406`", "0.0219010359588690395`", 
            "0.0176428051351079062`", "0.0149184304527248272`", 
            "0.0104961492841191006`", "0.00606248387384073605`", 
            "0.00529955428362239189`", "0.00277472045852450177`", 
            "0.00148113236270251258`", "0", "0", "0", "0", "0", "0", "0", 
            "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0"},
          {"0.978609193890776474`", "0.943877866262560516`", 
            "0.920388585836258421`", "0.89734629815666338`", 
            "0.862723361867525717`", "0.815760433254593131`", 
            "0.759459920857437609`", "0.695872094776387939`", 
            "0.626772791617011737`", "0.553947537663775158`", 
            "0.484269268780416872`", "0.479230187192287715`", 
            "0.457230945076461914`", "0.436602838782599711`", 
            "0.421609296534077948`", "0.407103066873436603`", 
            "0.404562607255081818`", "0.387350485128408816`", 
            "0.361596654943424677`", "0.332604929928981718`", 
            "0.330636832749488362`", "0.298908562452315749`", 
            "0.264165898587534986`", "0.262173777188132994`", 
            "0.228482006566918993`", "0.19767234650286344`", 
            "0.193267271812588941`", "0.157406262386309325`", 
            "0.141596803871065368`", "0.124259409016766331`", 
            "0.0935428948768244872`", "0.0929155310560139469`", 
            "0.0660303813686004659`", "0.0541592028341167441`", 
            "0.0421846685608491167`", "0.027236637006537494`", 
            "0.0215027524745197995`", "0.0117083051719424258`", 
            "0.00582495277586867743`", "0.00297421801086593617`", "\<\"\"\>", 
            "\<\"\"\>", "\<\"\"\>", "\<\"\"\>", "\<\"\"\>", "\<\"\"\>", 
            "\<\"\"\>", "\<\"\"\>", "\<\"\"\>", "\<\"\"\>", "\<\"\"\>", 
            "\<\"\"\>", "\<\"\"\>", "\<\"\"\>", "\<\"\"\>", "\<\"\"\>", 
            "\<\"\"\>", "\<\"\"\>", "\<\"\"\>", "\<\"\"\>", "\<\"\"\>", 
            "\<\"\"\>", "\<\"\"\>", "\<\"\"\>", "\<\"\"\>", "\<\"\"\>", 
            "\<\"\"\>", "\<\"\"\>", "\<\"\"\>", "\<\"\"\>", "\<\"\"\>", 
            "\<\"\"\>", "\<\"\"\>", "\<\"\"\>", "\<\"\"\>", "\<\"\"\>", 
            "\<\"\"\>", "\<\"\"\>", "\<\"\"\>", "\<\"\"\>"}
          },
        RowSpacings->1,
        ColumnSpacings->3,
        RowAlignments->Baseline,
        ColumnAlignments->{Left}],
      TableForm[ {{0.97776999322284364, 0.94410024237748735, 
        0.92072450816252294, 0.89766147296625809, 0.86311272829450958, 
        0.81628994487548179, 0.76016920466893334, 0.69679196119130715, 
        0.62792586772086412, 0.55534912919772117, 0.48282799354994366, 
        0.48088858342945179, 0.45632444736942823, 0.43604578230607272, 
        0.4212348209345449, 
        Complex[ 0.40659245274108258, 0.0009043105043892853], 
        Complex[ 0.40659245274108258, -0.0009043105043892853], 
        0.38680164088181429, 0.36096687213707285, 0.33471468527934817, 
        0.33004985248211172, 0.29841578706524863, 0.26430700489757247, 
        0.26367102504935486, 0.23996251122334314, 0.22811587524577948, 
        0.22305582719302855, 0.20950160793565317, 0.19905059052152521, 
        0.19874099190479486, 0.19421420825774049, 0.19110325278564624, 
        0.18262996596938796, 0.17139733467150375, 0.15797076483375985, 
        0.15483661565276499, 0.14615375398953517, 0.14222188858163398, 
        0.12571584638027408, 0.12269587332335187, 0.10874885535708853, 
        0.097004578202410499, 
        Complex[ 0.091837432953674553, 0.0014759964245066074], 
        Complex[ 0.091837432953674553, -0.0014759964245066074], 
        0.074469846134032028, 0.064863053522702427, 
        Complex[ 0.058604558152551139, 0.00019556518305604754], 
        Complex[ 0.058604558152551139, -0.00019556518305604754], 
        0.043800673541123408, 0.040857801825903629, 0.031349599975523675, 
        0.030361584690850242, 0.021901035958869042, 0.017642805135107905, 
        0.014918430452724826, 0.0104961492841191, 0.0060624838738407363, 
        0.0052995542836223918, 0.0027747204585245018, 0.0014811323627025124, 
        0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0}, {
        0.9786091938907765, 0.94387786626256043, 0.92038858583625849, 
        0.89734629815666334, 0.86272336186752574, 0.81576043325459313, 
        0.75945992085743763, 0.6958720947763879, 0.62677279161701172, 
        0.55394753766377514, 0.48426926878041687, 0.47923018719228772, 
        0.45723094507646189, 0.43660283878259976, 0.42160929653407797, 
        0.40710306687343661, 0.40456260725508181, 0.38735048512840881, 
        0.36159665494342469, 0.33260492992898172, 0.33063683274948835, 
        0.29890856245231573, 0.26416589858753498, 0.26217377718813301, 
        0.228482006566919, 0.19767234650286344, 0.19326727181258893, 
        0.15740626238630934, 0.14159680387106538, 0.12425940901676633, 
        0.093542894876824489, 0.092915531056013953, 0.066030381368600469, 
        0.054159202834116744, 0.042184668560849112, 0.027236637006537497, 
        0.021502752474519798, 0.011708305171942426, 0.0058249527758686779, 
        0.002974218010865936}}]]], "Output",
  CellLabel->"Out[11]//TableForm="]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData[
"Checking stability of the  solutions for MigrationOrder\[Rule]USM"], 
  "SubsubsectionIcon"],

Cell[CellGroupData[{

Cell[BoxData[
    \(StoreExact[\[Psi], grWfull[0.01, 10.5], 0.5, {500, 100}, {20, 3}, 
      SymmetricModel \[Rule] False, Compiled \[Rule] True, 
      SortByClass \[Rule] True, MigrationOrder \[Rule] USM]; \n
    StoreExact[\[Psi]E, grW[0.01, 10.5], 0.5, {500, 100}, {20, 3}, 
      Compiled \[Rule] True, MigrationOrder \[Rule] USM]; \n
    MeanP[\[Psi]E[500]] - 
        First/@MeanP[\[Psi][500], SymmetricModel \[Rule] False, 
            SortByClass \[Rule] True] // Chop\)], "Input",
  CellLabel->"In[12]:="],

Cell[BoxData[
    \({0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0}\)], 
  "Output",
  CellLabel->"Out[14]="]
}, Open  ]],

Cell[TextData[
"These are the eigenvalues.  BlockMatrix[] has been used to collapse the 8\
\[Times]8 array of 20\[Times]20 arrays into a 160\[Times]160 array.  There \
are two unstable eigenvalues, \[Lambda]=1.0324, and one neutral eigenvalue, \
\[Lambda]=1.  "], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(sm = 
      StabilityDirect[\[Psi][500], grWfull[0.01, 10.5], 0.5, 
        SymmetricModel \[Rule] False, SortByClass \[Rule] True, 
        MigrationOrder \[Rule] USM]; \n
    ev = Eigenvalues[BlockMatrix[sm]] // Chop\)], "Input",
  CellLabel->"In[15]:="],

Cell[BoxData[
    \({0.978609193890779316`, 0.978609193890773809`, 0.977769993222840128`, 
      0.944100242377487752`, 0.943877866262566023`, 0.943877866262565667`, 
      0.920724508162522958`, 0.920388585836258954`, 0.920388585836257355`, 
      0.897661472966257178`, 0.89734629815666338`, 0.89734629815666338`, 
      0.863112728294514397`, 0.862723361867532112`, 0.862723361867523763`, 
      0.816289944875485495`, 0.815760433254590822`, 0.815760433254590289`, 
      0.760169204668935627`, 0.759459920857436898`, 0.759459920857435122`, 
      0.696791961191307951`, 0.695872094776385896`, 0.695872094776384919`, 
      0.627925867720871622`, 0.626772791617013513`, 0.626772791617011737`, 
      0.555349129197716084`, 0.553947537663772848`, 0.553947537663772049`, 
      0.484269268780416961`, 0.484269268780416606`, 0.482827993549945855`, 
      0.480888583429452154`, 0.479230187192289314`, 0.479230187192287537`, 
      0.457230945076464401`, 0.457230945076463424`, 0.456324447369428298`, 
      0.436602838782600066`, 0.436602838782599445`, 0.436045782306071405`, 
      0.421609296534077504`, 0.421609296534076882`, 0.421234820934543918`, 
      0.407103066873437846`, 0.407103066873436603`, 
      \(0.406592452741083487`\[InvisibleSpace]\) + 
        0.000904310504389419023`\ I, 
      \(0.406592452741083487`\[InvisibleSpace]\) - 
        0.000904310504389419023`\ I, 0.404562607255082617`, 
      0.404562607255081552`, 0.387350485128408692`, 0.387350485128408692`, 
      0.386801640881813071`, 0.361596654943424766`, 0.3615966549434245`, 
      0.360966872137073391`, 0.334714685279348556`, 0.332604929928982073`, 
      0.332604929928981807`, 0.330636832749488585`, 0.330636832749488185`, 
      0.330049852482111916`, 0.298908562452315784`, 0.298908562452315109`, 
      0.298415787065249382`, 0.264307004897574504`, 0.264165898587536185`, 
      0.264165898587535297`, 0.263671025049356133`, 0.262173777188133261`, 
      0.262173777188133128`, 0.239962511223343533`, 0.228482006566918993`, 
      0.228482006566918993`, 0.228115875245780319`, 0.223055827193028566`, 
      0.209501607935653044`, 0.199050590521525183`, 0.198740991904797787`, 
      0.197672346502864222`, 0.197672346502863618`, 0.194214208257738381`, 
      0.193267271812590823`, 0.193267271812589402`, 0.191103252785645594`, 
      0.182629965969388159`, 0.171397334671504335`, 0.157970764833758758`, 
      0.157406262386309414`, 0.157406262386308721`, 0.154836615652765097`, 
      0.146153753989535761`, 0.142221888581633759`, 0.141596803871065102`, 
      0.141596803871065057`, 0.125715846380273399`, 0.124259409016766619`, 
      0.124259409016766531`, 0.122695873323351078`, 0.108748855357088359`, 
      0.0970045782024103253`, 0.0935428948768246648`, 0.0935428948768244516`, 
      0.0929155310560138048`, 0.0929155310560136271`, 
      \(0.0918374329536739608`\[InvisibleSpace]\) + 
        0.00147599642450403178`\ I, 
      \(0.0918374329536739608`\[InvisibleSpace]\) - 
        0.00147599642450403178`\ I, 0.074469846134032096`, 
      0.0660303813686006346`, 0.0660303813686005192`, 0.0648630535227020388`, 
      \(0.0586045581525514336`\[InvisibleSpace]\) + 
        0.000195565183061688667`\ I, 
      \(0.0586045581525514336`\[InvisibleSpace]\) - 
        0.000195565183061688667`\ I, 0.0541592028341163889`, 
      0.0541592028341163267`, 0.0438006735411237535`, 0.0421846685608492943`, 
      0.0421846685608492943`, 0.0408578018259029907`, 0.0313495999755260346`, 
      0.0303615846908505693`, 0.0272366370065377116`, 0.0272366370065375829`, 
      0.0219010359588631819`, 0.0215027524745199638`, 0.0215027524745197506`, 
      0.0176428051351114678`, 0.0149184304527257864`, 0.0117083051719425057`, 
      0.0117083051719423769`, 0.0104961492841176706`, 
      0.00606248387384066056`, 0.00582495277586862592`, 
      0.0058249527758685593`, 0.00529955428362364333`, 
      0.00297421801086593884`, 0.00297421801086585801`, 
      0.00277472045852463766`, 0.00148113236270260006`, 0, 0, 0, 0, 0, 0, 0, 
      0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0}\)], "Output",
  CellLabel->"Out[15]="]
}, Open  ]],

Cell["These results can be checked against the symmetric model.", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(ev = 
      ExactEigenvalues[
        StabilityK[#1, #2, #3, \[Psi]E[500], grW[0.01, 10.5], 0.5, 
            MigrationOrder \[Rule] USM]&, 3]; \n
    \(ev // Chop\) // TableForm\)], "Input",
  CellLabel->"In[16]:="],

Cell[BoxData[
    InterpretationBox[GridBox[{
          {"0.977769993222840305`", "0.944100242377485621`", 
            "0.920724508162520294`", "0.897661472966256646`", 
            "0.863112728294509423`", "0.816289944875481765`", 
            "0.760169204668933762`", "0.696791961191303421`", 
            "0.627925867720866826`", "0.555349129197719637`", 
            "0.482827993549946743`", "0.480888583429452332`", 
            "0.456324447369429275`", "0.436045782306073181`", 
            "0.421234820934546938`", 
            \(\(0.406592452741084642`\[InvisibleSpace]\) + 
              0.000904310504389329317`\ I\), 
            \(\(0.406592452741084642`\[InvisibleSpace]\) - 
              0.000904310504389329317`\ I\), "0.386801640881814545`", 
            "0.36096687213707268`", "0.334714685279346735`", 
            "0.330049852482112049`", "0.298415787065248938`", 
            "0.26430700489757406`", "0.263671025049355867`", 
            "0.239962511223343399`", "0.228115875245779209`", 
            "0.223055827193028388`", "0.209501607935653222`", 
            "0.199050590521525059`", "0.198740991904794483`", 
            "0.194214208257739588`", "0.191103252785647299`", 
            "0.182629965969387502`", "0.171397334671504175`", 
            "0.157970764833758607`", "0.154836615652766536`", 
            "0.146153753989534473`", "0.142221888581634186`", 
            "0.125715846380273799`", "0.122695873323351012`", 
            "0.108748855357088935`", "0.0970045782024105918`", 
            \(\(0.0918374329536743161`\[InvisibleSpace]\) + 
              0.00147599642450686063`\ I\), 
            \(\(0.0918374329536743161`\[InvisibleSpace]\) - 
              0.00147599642450686063`\ I\), "0.0744698461340314565`", 
            "0.0648630535227022519`", 
            \(\(0.058604558152551176`\[InvisibleSpace]\) + 
              0.000195565183056473212`\ I\), 
            \(\(0.058604558152551176`\[InvisibleSpace]\) - 
              0.000195565183056473212`\ I\), "0.0438006735411236469`", 
            "0.0408578018259038433`", "0.031349599975524125`", 
            "0.0303615846908502851`", "0.021901035958868027`", 
            "0.0176428051351087367`", "0.0149184304527256905`", 
            "0.0104961492841168158`", "0.00606248387384070053`", 
            "0.00529955428362387426`", "0.0027747204585245444`", 
            "0.00148113236270264803`", "0", "0", "0", "0", "0", "0", "0", 
            "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0"},
          {"0.978609193890776651`", "0.943877866262561227`", 
            "0.920388585836258954`", "0.897346298156662314`", 
            "0.862723361867527138`", "0.815760433254592598`", 
            "0.759459920857437165`", "0.69587209477638634`", 
            "0.626772791617010494`", "0.553947537663772848`", 
            "0.484269268780416695`", "0.479230187192288958`", 
            "0.457230945076462802`", "0.436602838782599445`", 
            "0.421609296534077326`", "0.407103066873436958`", 
            "0.40456260725508244`", "0.38735048512840887`", 
            "0.361596654943424589`", "0.332604929928981674`", 
            "0.330636832749487563`", "0.298908562452314985`", 
            "0.264165898587535075`", "0.262173777188133128`", 
            "0.228482006566918949`", "0.197672346502864808`", 
            "0.19326727181258887`", "0.157406262386309485`", 
            "0.14159680387106512`", "0.124259409016766686`", 
            "0.0935428948768245938`", "0.0929155310560136982`", 
            "0.0660303813686007234`", "0.0541592028341165843`", 
            "0.0421846685608491167`", "0.0272366370065378271`", 
            "0.0215027524745196618`", "0.0117083051719422148`", 
            "0.00582495277586861703`", "0.00297421801086581929`", "\<\"\"\>", 
            "\<\"\"\>", "\<\"\"\>", "\<\"\"\>", "\<\"\"\>", "\<\"\"\>", 
            "\<\"\"\>", "\<\"\"\>", "\<\"\"\>", "\<\"\"\>", "\<\"\"\>", 
            "\<\"\"\>", "\<\"\"\>", "\<\"\"\>", "\<\"\"\>", "\<\"\"\>", 
            "\<\"\"\>", "\<\"\"\>", "\<\"\"\>", "\<\"\"\>", "\<\"\"\>", 
            "\<\"\"\>", "\<\"\"\>", "\<\"\"\>", "\<\"\"\>", "\<\"\"\>", 
            "\<\"\"\>", "\<\"\"\>", "\<\"\"\>", "\<\"\"\>", "\<\"\"\>", 
            "\<\"\"\>", "\<\"\"\>", "\<\"\"\>", "\<\"\"\>", "\<\"\"\>", 
            "\<\"\"\>", "\<\"\"\>", "\<\"\"\>", "\<\"\"\>"}
          },
        RowSpacings->1,
        ColumnSpacings->3,
        RowAlignments->Baseline,
        ColumnAlignments->{Left}],
      TableForm[ {{0.97776999322284031, 0.94410024237748558, 
        0.92072450816252027, 0.89766147296625665, 0.86311272829450936, 
        0.81628994487548179, 0.76016920466893378, 0.69679196119130338, 
        0.62792586772086678, 0.55534912919771962, 0.48282799354994671, 
        0.48088858342945229, 0.45632444736942929, 0.43604578230607322, 
        0.42123482093454695, 
        Complex[ 0.40659245274108469, 0.00090431050438932921], 
        Complex[ 0.40659245274108469, -0.00090431050438932921], 
        0.38680164088181457, 0.36096687213707268, 0.33471468527934672, 
        0.33004985248211205, 0.29841578706524896, 0.26430700489757408, 
        0.26367102504935586, 0.23996251122334342, 0.22811587524577923, 
        0.22305582719302841, 0.20950160793565323, 0.19905059052152504, 
        0.1987409919047945, 0.19421420825773958, 0.1911032527856473, 
        0.18262996596938749, 0.17139733467150417, 0.1579707648337586, 
        0.15483661565276655, 0.14615375398953448, 0.14222188858163418, 
        0.1257158463802738, 0.12269587332335101, 0.10874885535708893, 
        0.097004578202410582, 
        Complex[ 0.091837432953674331, 0.0014759964245068607], 
        Complex[ 0.091837432953674331, -0.0014759964245068607], 
        0.074469846134031459, 0.064863053522702246, 
        Complex[ 0.058604558152551181, 0.00019556518305647322], 
        Complex[ 0.058604558152551181, -0.00019556518305647322], 
        0.043800673541123644, 0.040857801825903844, 0.031349599975524126, 
        0.030361584690850284, 0.021901035958868029, 0.017642805135108734, 
        0.014918430452725688, 0.010496149284116815, 0.0060624838738406999, 
        0.0052995542836238741, 0.0027747204585245443, 0.0014811323627026479, 
        0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0}, {
        0.97860919389077672, 0.94387786626256132, 0.92038858583625893, 
        0.89734629815666223, 0.86272336186752718, 0.81576043325459258, 
        0.75945992085743719, 0.69587209477638634, 0.62677279161701049, 
        0.5539475376637728, 0.48426926878041665, 0.47923018719228899, 
        0.45723094507646284, 0.43660283878259942, 0.42160929653407736, 
        0.407103066873437, 0.40456260725508247, 0.38735048512840886, 
        0.36159665494342458, 0.33260492992898166, 0.33063683274948757, 
        0.29890856245231501, 0.26416589858753509, 0.26217377718813312, 
        0.22848200656691894, 0.1976723465028648, 0.19326727181258888, 
        0.15740626238630948, 0.14159680387106513, 0.12425940901676669, 
        0.0935428948768246, 0.092915531056013689, 0.066030381368600718, 
        0.054159202834116585, 0.042184668560849112, 0.027236637006537827, 
        0.02150275247451966, 0.011708305171942214, 0.0058249527758686172, 
        0.0029742180108658194}}]]], "Output",
  CellLabel->"Out[16]//TableForm="]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData[
"Checking stability of the  solutions for MigrationOrder\[Rule]UMS"], 
  "SubsubsectionIcon"],

Cell[CellGroupData[{

Cell[BoxData[
    \(StoreExact[\[Psi], grWfull[0.01, 10.5], 0.5, {500, 100}, {20, 3}, 
      SymmetricModel \[Rule] False, Compiled \[Rule] True, 
      SortByClass \[Rule] True, MigrationOrder \[Rule] UMS]; \n
    StoreExact[\[Psi]E, grW[0.01, 10.5], 0.5, {500, 100}, {20, 3}, 
      Compiled \[Rule] True, MigrationOrder \[Rule] UMS]; \n
    MeanP[\[Psi]E[500]] - 
        First/@MeanP[\[Psi][500], SymmetricModel \[Rule] False, 
            SortByClass \[Rule] True] // Chop\)], "Input",
  CellLabel->"In[17]:="],

Cell[BoxData[
    \({0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0}\)], 
  "Output",
  CellLabel->"Out[19]="]
}, Open  ]],

Cell[TextData[
"These are the eigenvalues.  BlockMatrix[] has been used to collapse the 8\
\[Times]8 array of 20\[Times]20 arrays into a 160\[Times]160 array.  There \
are two unstable eigenvalues, \[Lambda]=1.0324, and one neutral eigenvalue, \
\[Lambda]=1.  "], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(sm = 
      StabilityDirect[\[Psi][500], grWfull[0.01, 10.5], 0.5, 
        SymmetricModel \[Rule] False, SortByClass \[Rule] True, 
        MigrationOrder \[Rule] UMS]; \n
    ev = Eigenvalues[BlockMatrix[sm]] // Chop\)], "Input",
  CellLabel->"In[20]:="],

Cell[BoxData[
    \({0.977858890866876606`, 0.977858890866868435`, 0.9761186090620793`, 
      0.944092503730192866`, 0.943716385786942169`, 0.943716385786941103`, 
      0.920956591012970804`, 0.92036800754705208`, 0.920368007547048527`, 
      0.897886781644842457`, 0.897322217206548344`, 0.897322217206544436`, 
      0.863410390994249077`, 0.862696284753942066`, 0.862696284753935316`, 
      0.816788382283009717`, 0.815785513609814572`, 0.815785513609811019`, 
      0.760936680509288532`, 0.759564306311687342`, 0.759564306311687165`, 
      0.697876009124090401`, 0.696073569101665423`, 0.696073569101661426`, 
      0.629358655453624127`, 0.627083310945454552`, 0.627083310945452421`, 
      0.557148947426997587`, 0.554375216907734191`, 0.554375216907733747`, 
      0.483439035132579686`, 0.483439035132579597`, 0.483059089802889207`, 
      0.480532117606702158`, 0.479779884391306232`, 0.479779884391303035`, 
      0.456592166490820083`, 0.456592166490818662`, 0.454821592822157683`, 
      0.43617917688793959`, 0.436179176887938346`, 0.435104754294154183`, 
      0.421320674671128436`, 0.421320674671127459`, 0.42059178427466044`, 
      \(0.407510912830567129`\[InvisibleSpace]\) + 
        0.000188016002690987189`\ I, 
      \(0.407510912830567129`\[InvisibleSpace]\) - 
        0.000188016002690987189`\ I, 0.406528425878908006`, 
      0.406528425878907473`, 0.405511253826016826`, 0.405511253826016559`, 
      0.386959537015411925`, 0.386959537015410859`, 0.38585794360949297`, 
      0.361153786562989598`, 0.361153786562988265`, 0.359910465959498937`, 
      0.337587742207948959`, 0.333343909042596431`, 0.333343909042594344`, 
      0.330233713219507318`, 0.330233713219506874`, 0.328982358595258705`, 
      0.298499559718603091`, 0.298499559718602913`, 0.29761987718779963`, 
      0.26703651823914547`, 0.263744336487941`, 0.2637443364879406`, 
      0.262982661956156871`, 0.262982661956156604`, 0.26286454014688303`, 
      0.239068586206489097`, 0.228092592890396961`, 0.22809259289039625`, 
      0.227509945524559764`, 0.222275353379571694`, 0.20889173174022293`, 
      0.200741646795392991`, 0.198614703371677059`, 0.198164613712251806`, 
      0.198164613712251345`, 0.194678450519274122`, 0.193318769692899969`, 
      0.193318769692899721`, 0.190811267290187167`, 0.182197104424561509`, 
      0.170849333528323192`, 0.157360436222534367`, 0.156505776738720392`, 
      0.156505776738720081`, 
      \(0.151898549209323796`\[InvisibleSpace]\) + 
        0.00549792400309815754`\ I, 
      \(0.151898549209323796`\[InvisibleSpace]\) - 
        0.00549792400309815754`\ I, 0.143160776638060465`, 
      0.143160776638059861`, 0.141672070169251718`, 0.125128724512060451`, 
      0.123506605309140637`, 0.123506605309140171`, 0.119649287859173281`, 
      0.108358267023860932`, 0.10267456162140427`, 0.0944645425237789204`, 
      0.0944645425237787605`, 0.0927651223977936822`, 0.0927651223977933625`, 
      \(0.0903685940259469688`\[InvisibleSpace]\) + 
        0.00232953933867026652`\ I, 
      \(0.0903685940259469688`\[InvisibleSpace]\) - 
        0.00232953933867026652`\ I, 0.0732676958990146598`, 
      0.0651578578164310862`, 0.0651578578164308108`, 0.0636710179060900394`, 
      0.0633848891341529796`, 0.0573932161900598014`, 0.0559093202780798126`, 
      0.0559093202780794662`, 0.0424911759845403924`, 0.0411358393014120249`, 
      0.0411358393014119894`, 0.0398782808599759341`, 0.0351408718467378644`, 
      0.0287219992773287824`, 0.0286904286991872403`, 0.0286904286991871515`, 
      0.0220824552396836359`, 0.0206923977230637445`, 0.0206923977230635758`, 
      0.0171600094635026785`, 0.0157352209676790639`, 0.0123638358684838634`, 
      0.0123638358684838323`, 0.0107326309577934031`, 
      0.00690957850556186592`, 0.00599159129310278792`, 
      0.00599159129310269289`, 0.00505851765584363821`, 
      0.0033642728798948811`, 0.00336427287989477541`, 
      0.00296808286835541057`, 0.00179385716822230723`, 0, 0, 0, 0, 0, 0, 0, 
      0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0}\)], "Output",
  CellLabel->"Out[20]="]
}, Open  ]],

Cell["These results can be checked against the symmetric model.", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(ev = 
      ExactEigenvalues[
        StabilityK[#1, #2, #3, \[Psi]E[500], grW[0.01, 10.5], 0.5, 
            MigrationOrder \[Rule] UMS]&, 3]; \n
    \(ev // Chop\) // TableForm\)], "Input",
  CellLabel->"In[21]:="],

Cell[BoxData[
    InterpretationBox[GridBox[{
          {"0.976118609062080011`", "0.944092503730190912`", 
            "0.920956591012971159`", "0.897886781644840326`", 
            "0.863410390994247478`", "0.81678838228300794`", 
            "0.760936680509288798`", "0.697876009124091467`", 
            "0.629358655453623239`", "0.557148947426997587`", 
            "0.48305908980288823`", "0.480532117606705089`", 
            "0.454821592822159548`", "0.435104754294152318`", 
            "0.420591784274660795`", 
            \(\(0.407510912830567484`\[InvisibleSpace]\) + 
              0.000188016002678579869`\ I\), 
            \(\(0.407510912830567484`\[InvisibleSpace]\) - 
              0.000188016002678579869`\ I\), "0.385857943609494302`", 
            "0.35991046595949756`", "0.33758774220794967`", 
            "0.32898235859525684`", "0.297619877187798955`", 
            "0.267036518239144005`", "0.262864540146883252`", 
            "0.239068586206489586`", "0.227509945524559054`", 
            "0.222275353379571782`", "0.208891731740223018`", 
            "0.200741646795397032`", "0.198614703371676259`", 
            "0.194678450519267816`", "0.190811267290189938`", 
            "0.18219710442456181`", "0.170849333528323832`", 
            "0.157360436222532023`", 
            \(\(0.15189854920932488`\[InvisibleSpace]\) + 
              0.005497924003095223`\ I\), 
            \(\(0.15189854920932488`\[InvisibleSpace]\) - 
              0.005497924003095223`\ I\), "0.141672070169252117`", 
            "0.125128724512060873`", "0.119649287859173302`", 
            "0.108358267023858289`", "0.102674561621406357`", 
            \(\(0.0903685940259471287`\[InvisibleSpace]\) + 
              0.00232953933866979223`\ I\), 
            \(\(0.0903685940259471287`\[InvisibleSpace]\) - 
              0.00232953933866979223`\ I\), "0.0732676958990159832`", 
            "0.0636710179060905989`", "0.0633848891341504305`", 
            "0.0573932161900594461`", "0.0424911759845406411`", 
            "0.0398782808599741667`", "0.0351408718467369274`", 
            "0.02872199927733066`", "0.0220824552396887874`", 
            "0.0171600094635019484`", "0.0157352209676753851`", 
            "0.0107326309577972023`", "0.00690957850556025299`", 
            "0.00505851765583623791`", "0.00296808286835748624`", 
            "0.00179385716822173773`", "0", "0", "0", "0", "0", "0", "0", 
            "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0"},
          {"0.977858890866871632`", "0.943716385786943412`", 
            "0.920368007547052791`", "0.897322217206549055`", 
            "0.862696284753938513`", "0.815785513609811729`", 
            "0.759564306311689385`", "0.696073569101664446`", 
            "0.627083310945451977`", "0.554375216907733037`", 
            "0.483439035132579331`", "0.479779884391304456`", 
            "0.456592166490818396`", "0.436179176887938968`", 
            "0.421320674671126393`", "0.406528425878907029`", 
            "0.405511253826017181`", "0.386959537015411303`", 
            "0.361153786562988265`", "0.333343909042594921`", 
            "0.33023371321950683`", "0.29849955971860238`", 
            "0.263744336487941133`", "0.26298266195615727`", 
            "0.228092592890396383`", "0.19816461371225218`", 
            "0.193318769692899721`", "0.156505776738720818`", 
            "0.143160776638059861`", "0.12350660530914066`", 
            "0.0944645425237786184`", "0.0927651223977932382`", 
            "0.0651578578164308996`", "0.0559093202780794662`", 
            "0.0411358393014119627`", "0.0286904286991874446`", 
            "0.020692397723063296`", "0.0123638358684836768`", 
            "0.00599159129310264404`", "0.00336427287989471412`", "\<\"\"\>", 
            "\<\"\"\>", "\<\"\"\>", "\<\"\"\>", "\<\"\"\>", "\<\"\"\>", 
            "\<\"\"\>", "\<\"\"\>", "\<\"\"\>", "\<\"\"\>", "\<\"\"\>", 
            "\<\"\"\>", "\<\"\"\>", "\<\"\"\>", "\<\"\"\>", "\<\"\"\>", 
            "\<\"\"\>", "\<\"\"\>", "\<\"\"\>", "\<\"\"\>", "\<\"\"\>", 
            "\<\"\"\>", "\<\"\"\>", "\<\"\"\>", "\<\"\"\>", "\<\"\"\>", 
            "\<\"\"\>", "\<\"\"\>", "\<\"\"\>", "\<\"\"\>", "\<\"\"\>", 
            "\<\"\"\>", "\<\"\"\>", "\<\"\"\>", "\<\"\"\>", "\<\"\"\>", 
            "\<\"\"\>", "\<\"\"\>", "\<\"\"\>", "\<\"\"\>"}
          },
        RowSpacings->1,
        ColumnSpacings->3,
        RowAlignments->Baseline,
        ColumnAlignments->{Left}],
      TableForm[ {{0.97611860906208003, 0.94409250373019082, 
        0.92095659101297123, 0.89788678164484037, 0.86341039099424755, 
        0.81678838228300799, 0.76093668050928875, 0.69787600912409142, 
        0.62935865545362324, 0.55714894742699761, 0.4830590898028882, 
        0.48053211760670511, 0.45482159282215956, 0.4351047542941523, 
        0.42059178427466076, 
        Complex[ 0.40751091283056751, 0.00018801600267857988], 
        Complex[ 0.40751091283056751, -0.00018801600267857988], 
        0.38585794360949432, 0.35991046595949755, 0.33758774220794968, 
        0.32898235859525682, 0.29761987718779898, 0.26703651823914398, 
        0.26286454014688326, 0.23906858620648958, 0.22750994552455905, 
        0.22227535337957177, 0.20889173174022302, 0.20074164679539702, 
        0.19861470337167625, 0.19467845051926783, 0.19081126729018993, 
        0.1821971044245618, 0.17084933352832382, 0.15736043622253201, 
        Complex[ 0.15189854920932488, 0.0054979240030952224], 
        Complex[ 0.15189854920932488, -0.0054979240030952224], 
        0.14167207016925212, 0.12512872451206086, 0.1196492878591733, 
        0.1083582670238583, 0.10267456162140635, 
        Complex[ 0.09036859402594713, 0.0023295393386697926], 
        Complex[ 0.09036859402594713, -0.0023295393386697926], 
        0.07326769589901598, 0.063671017906090602, 0.063384889134150441, 
        0.057393216190059451, 0.042491175984540643, 0.03987828085997417, 
        0.035140871846736928, 0.02872199927733066, 0.022082455239688787, 
        0.017160009463501949, 0.015735220967675385, 0.010732630957797203, 
        0.0069095785055602529, 0.0050585176558362371, 0.0029680828683574861, 
        0.0017938571682217376, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
        0, 0, 0, 0, 0}, {0.97785889086687161, 0.94371638578694339, 
        0.92036800754705284, 0.89732221720654903, 0.86269628475393845, 
        0.81578551360981166, 0.75956430631168936, 0.6960735691016644, 
        0.627083310945452, 0.55437521690773306, 0.48343903513257935, 
        0.47977988439130448, 0.45659216649081841, 0.43617917688793895, 
        0.42132067467112638, 0.40652842587890703, 0.40551125382601722, 
        0.3869595370154113, 0.36115378656298824, 0.33334390904259492, 
        0.33023371321950684, 0.29849955971860237, 0.26374433648794116, 
        0.26298266195615727, 0.22809259289039638, 0.19816461371225219, 
        0.19331876969289971, 0.15650577673872082, 0.14316077663805987, 
        0.12350660530914065, 0.094464542523778616, 0.092765122397793234, 
        0.065157857816430895, 0.055909320278079461, 0.041135839301411965, 
        0.028690428699187441, 0.020692397723063295, 0.012363835868483677, 
        0.0059915912931026438, 0.0033642728798947141}}]]], "Output",
  CellLabel->"Out[21]//TableForm="]
}, Open  ]]
}, Closed]]
}, Open  ]]
},
FrontEndVersion->"4.0 for Macintosh",
ScreenRectangle->{{0, 1024}, {0, 748}},
AutoGeneratedPackage->None,
WindowSize->{564, 689},
WindowMargins->{{Automatic, -1}, {Automatic, 3}},
StyleDefinitions -> "HelpBrowser.nb",
MacintoshSystemPageSetup->"\<\
00<0001804P000000`d26_oRon@3:`8f0dL5N`?N0080001804P000000`d26P01
0000I00000400@410?l00BL?00400@00000000000000000201T1T0000000@000
00000000004000000000000000010000\>"
]


(***********************************************************************
Cached data follows.  If you edit this Notebook file directly, not using
Mathematica, you must remove the line containing CacheID at the top of 
the file.  The cache data will then be recreated when you save this file 
from within Mathematica.
***********************************************************************)

(*CellTagsOutline
CellTagsIndex->{
  "S5.24.1"->{
    Cell[1791, 53, 79, 1, 28, "MathCaption",
      CellTags->{"S5.24.1", "1.4"}]},
  "1.4"->{
    Cell[1791, 53, 79, 1, 28, "MathCaption",
      CellTags->{"S5.24.1", "1.4"}]}
  }
*)

(*CellTagsIndex
CellTagsIndex->{
  {"S5.24.1", 104954, 2202},
  {"1.4", 105048, 2205}
  }
*)

(*NotebookFileOutline
Notebook[{

Cell[CellGroupData[{
Cell[1739, 51, 49, 0, 36, "SubsectionIcon"],
Cell[1791, 53, 79, 1, 28, "MathCaption",
  CellTags->{"S5.24.1", "1.4"}],
Cell[1873, 56, 87, 2, 27, "Input"],

Cell[CellGroupData[{
Cell[1985, 62, 108, 2, 24, "SubsubsectionIcon"],
Cell[2096, 66, 247, 4, 42, "Input"],
Cell[2346, 72, 230, 5, 42, "Input"],
Cell[2579, 79, 271, 4, 36, "Text"],

Cell[CellGroupData[{
Cell[2875, 87, 99, 2, 26, "Input"],
Cell[2977, 91, 4089, 60, 230, "Output"]
}, Open  ]],
Cell[7081, 154, 73, 0, 22, "Text"],
Cell[7157, 156, 335, 7, 58, "Input"],
Cell[7495, 165, 323, 4, 36, "Text"],

Cell[CellGroupData[{
Cell[7843, 173, 108, 2, 26, "Input"],
Cell[7954, 177, 2048, 34, 110, "Output"]
}, Open  ]],
Cell[10017, 214, 150, 2, 22, "Text"],

Cell[CellGroupData[{
Cell[10192, 220, 100, 2, 26, "Input"],
Cell[10295, 224, 1078, 15, 65, "Output"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{
Cell[11422, 245, 108, 2, 20, "SubsubsectionIcon"],
Cell[11533, 249, 247, 4, 42, "Input"],
Cell[11783, 255, 229, 5, 42, "Input"],
Cell[12015, 262, 470, 6, 50, "Text"],

Cell[CellGroupData[{
Cell[12510, 272, 98, 2, 26, "Input"],
Cell[12611, 276, 4094, 60, 230, "Output"]
}, Open  ]],
Cell[16720, 339, 73, 0, 22, "Text"],
Cell[16796, 341, 335, 7, 58, "Input"],
Cell[17134, 350, 324, 4, 36, "Text"],

Cell[CellGroupData[{
Cell[17483, 358, 108, 2, 26, "Input"],
Cell[17594, 362, 2034, 32, 110, "Output"]
}, Open  ]],
Cell[19643, 397, 148, 2, 22, "Text"],

Cell[CellGroupData[{
Cell[19816, 403, 100, 2, 26, "Input"],
Cell[19919, 407, 1077, 15, 65, "Output"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{
Cell[21045, 428, 137, 2, 20, "SubsubsectionIcon"],
Cell[21185, 432, 139, 3, 22, "Text"],
Cell[21327, 437, 504, 11, 74, "Input"],
Cell[21834, 450, 58, 0, 22, "Text"],
Cell[21895, 452, 293, 5, 58, "Input"],
Cell[22191, 459, 66, 0, 22, "Text"],

Cell[CellGroupData[{
Cell[22282, 463, 218, 5, 42, "Input"],
Cell[22503, 470, 3453, 59, 190, "Output"]
}, Closed]],
Cell[25971, 532, 97, 3, 18, "Text"],

Cell[CellGroupData[{
Cell[26093, 539, 221, 5, 42, "Input"],
Cell[26317, 546, 865, 18, 46, "Output"]
}, Closed]],
Cell[27197, 567, 272, 6, 38, "Input"],
Cell[27472, 575, 292, 4, 36, "Text"],

Cell[CellGroupData[{
Cell[27789, 583, 99, 2, 26, "Input"],
Cell[27891, 587, 1891, 27, 110, "Output"]
}, Open  ]],
Cell[29797, 617, 73, 0, 22, "Text"],
Cell[29873, 619, 265, 6, 58, "Input"],
Cell[30141, 627, 324, 4, 36, "Text"],

Cell[CellGroupData[{
Cell[30490, 635, 109, 2, 26, "Input"],
Cell[30602, 639, 867, 13, 65, "Output"]
}, Open  ]],
Cell[31484, 655, 148, 2, 22, "Text"],

Cell[CellGroupData[{
Cell[31657, 661, 101, 2, 26, "Input"],
Cell[31761, 665, 565, 8, 35, "Output"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{
Cell[32375, 679, 129, 2, 20, "SubsubsectionIcon"],
Cell[32507, 683, 268, 7, 42, "Input"],
Cell[32778, 692, 291, 5, 42, "Input"],

Cell[CellGroupData[{
Cell[33094, 701, 219, 5, 42, "Input"],
Cell[33316, 708, 3463, 59, 190, "Output"]
}, Closed]],
Cell[36794, 770, 272, 6, 38, "Input"],
Cell[37069, 778, 220, 3, 22, "Text"],

Cell[CellGroupData[{
Cell[37314, 785, 99, 2, 26, "Input"],
Cell[37416, 789, 1881, 26, 110, "Output"]
}, Open  ]],
Cell[39312, 818, 73, 0, 22, "Text"],
Cell[39388, 820, 503, 10, 106, "Input"],
Cell[39894, 832, 324, 4, 36, "Text"],

Cell[CellGroupData[{
Cell[40243, 840, 108, 2, 26, "Input"],
Cell[40354, 844, 858, 12, 65, "Output"]
}, Open  ]],
Cell[41227, 859, 148, 2, 22, "Text"],

Cell[CellGroupData[{
Cell[41400, 865, 100, 2, 26, "Input"],
Cell[41503, 869, 564, 8, 35, "Output"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{
Cell[42116, 883, 129, 2, 20, "SubsubsectionIcon"],
Cell[42248, 887, 244, 6, 42, "Input"],
Cell[42495, 895, 291, 5, 42, "Input"],

Cell[CellGroupData[{
Cell[42811, 904, 219, 5, 42, "Input"],
Cell[43033, 911, 3466, 59, 190, "Output"]
}, Closed]],
Cell[46514, 973, 272, 6, 38, "Input"],
Cell[46789, 981, 420, 6, 36, "Text"],

Cell[CellGroupData[{
Cell[47234, 991, 99, 2, 26, "Input"],
Cell[47336, 995, 1891, 26, 110, "Output"]
}, Open  ]],
Cell[49242, 1024, 73, 0, 22, "Text"],
Cell[49318, 1026, 503, 10, 106, "Input"],
Cell[49824, 1038, 324, 4, 36, "Text"],

Cell[CellGroupData[{
Cell[50173, 1046, 108, 2, 26, "Input"],
Cell[50284, 1050, 858, 12, 65, "Output"]
}, Open  ]],
Cell[51157, 1065, 148, 2, 22, "Text"],

Cell[CellGroupData[{
Cell[51330, 1071, 100, 2, 26, "Input"],
Cell[51433, 1075, 564, 8, 35, "Output"]
}, Open  ]]
}, Closed]]
}, Open  ]],

Cell[CellGroupData[{
Cell[52058, 1090, 72, 0, 36, "SubsectionIcon"],

Cell[CellGroupData[{
Cell[52155, 1094, 45, 0, 24, "SubsubsectionIcon"],
Cell[52203, 1096, 263, 5, 46, "Input"],
Cell[52469, 1103, 82, 2, 26, "Input"],
Cell[52554, 1107, 150, 3, 26, "Input"]
}, Closed]],

Cell[CellGroupData[{
Cell[52741, 1115, 108, 2, 20, "SubsubsectionIcon"],

Cell[CellGroupData[{
Cell[52874, 1121, 514, 9, 74, "Input"],
Cell[53391, 1132, 121, 3, 20, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[53549, 1140, 316, 7, 58, "Input"],
Cell[53868, 1149, 11525, 345, 184, 3411, 240, "GraphicsData", "PostScript", \
"Graphics"]
}, Open  ]],
Cell[65408, 1497, 271, 4, 36, "Text"],

Cell[CellGroupData[{
Cell[65704, 1505, 276, 6, 58, "Input"],
Cell[65983, 1513, 4096, 60, 230, "Output"]
}, Open  ]],
Cell[70094, 1576, 73, 0, 22, "Text"],

Cell[CellGroupData[{
Cell[70192, 1580, 236, 6, 58, "Input"],
Cell[70431, 1588, 7314, 116, 46, "Output"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{
Cell[77794, 1710, 108, 2, 20, "SubsubsectionIcon"],

Cell[CellGroupData[{
Cell[77927, 1716, 515, 9, 74, "Input"],
Cell[78445, 1727, 122, 3, 20, "Output"]
}, Open  ]],
Cell[78582, 1733, 271, 4, 36, "Text"],

Cell[CellGroupData[{
Cell[78878, 1741, 276, 6, 58, "Input"],
Cell[79157, 1749, 4102, 60, 230, "Output"]
}, Open  ]],
Cell[83274, 1812, 73, 0, 22, "Text"],

Cell[CellGroupData[{
Cell[83372, 1816, 236, 6, 58, "Input"],
Cell[83611, 1824, 7310, 116, 46, "Output"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{
Cell[90970, 1946, 108, 2, 20, "SubsubsectionIcon"],

Cell[CellGroupData[{
Cell[91103, 1952, 515, 9, 74, "Input"],
Cell[91621, 1963, 122, 3, 20, "Output"]
}, Open  ]],
Cell[91758, 1969, 271, 4, 36, "Text"],

Cell[CellGroupData[{
Cell[92054, 1977, 276, 6, 58, "Input"],
Cell[92333, 1985, 4087, 60, 230, "Output"]
}, Open  ]],
Cell[96435, 2048, 73, 0, 22, "Text"],

Cell[CellGroupData[{
Cell[96533, 2052, 236, 6, 58, "Input"],
Cell[96772, 2060, 7284, 115, 46, "Output"]
}, Open  ]]
}, Closed]]
}, Open  ]]
}
]
*)




(***********************************************************************
End of Mathematica Notebook file.
***********************************************************************)

