(************** Content-type: application/mathematica **************
                     CreatedBy='Mathematica 4.2'

                    Mathematica-Compatible Notebook

This notebook can be used with any Mathematica-compatible
application, such as Mathematica, MathReader or Publicon. The data
for the notebook starts with the line containing stars above.

To get the notebook into a Mathematica-compatible application, do
one of the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the
  application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing
the word CacheID, otherwise Mathematica-compatible applications may
try to use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
*******************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[    272961,       7072]*)
(*NotebookOutlinePosition[    273636,       7095]*)
(*  CellTagsIndexPosition[    273592,       7091]*)
(*WindowFrame->Normal*)



Notebook[{

Cell[CellGroupData[{
Cell[TextData[StyleBox["Simulating a cline",
  FontColor->RGBColor[0, 0, 1]]], "SubsectionIcon"],

Cell[CellGroupData[{

Cell[TextData[{
  StyleBox["Q1: ",
    FontColor->RGBColor[0, 0, 1]],
  " Simulate clines with different selection coefficients.  How does cline \
width depend on selection strength?"
}], "SubsubsectionIcon"],

Cell["\<\
This sets up simulatiuon results for s={0.01,0.02,\[Ellipsis]}.  \
Actually, the runs for stronger selection don't need to be run for as long as \
500 generations.\
\>", "Text"],

Cell[BoxData[
    \(\(\(fitness[s_, mid_, ecotone]\)[i_]\)[X_, Y_] := 
      If[i > mid, 
        Times @@ \(\((1 + s)\)\^\(Plus @@ \((X + Y)\) - Length[X]\)\), 
        Times @@ \(\((1 + 
                  s)\)\^\(-\((Plus @@ \((X + Y)\) - 
                    Length[X])\)\)\)]; \(\((\(StoreExact[res[3, #, ecotone], 
              MakeCline[30, 3, 100], fitness[#, 15, ecotone], 
              0.5, {500, 20}, \[IndentingNewLine]Compiled \[Rule] True, 
              FixedEnds \[Rule] {MakePopulation[3, 0], 
                  MakePopulation[3, 1]}];\))\) &\) /@ {0.01, 0.02, 0.04, 
        0.08, 0.12};\)], "Input",
  CellLabel->"In[23]:="],

Cell["These are the clines for increasing selection pressure:", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(\(ListPlot[AlleleFrequencyMean[\(res[3, #, ecotone]\)[500]], 
            PlotJoined \[Rule] True, 
            PlotRange \[Rule] {{0, 30}, {0, 1}}] &\) /@ {0.01, 0.02, 0.04, 
          0.08, 0.12};\)\)], "Input",
  CellLabel->"In[26]:="],

Cell[CellGroupData[{

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 0.0333333 0 0.618034 [
[.16667 -0.0125 -3 -9 ]
[.16667 -0.0125 3 0 ]
[.33333 -0.0125 -6 -9 ]
[.33333 -0.0125 6 0 ]
[.5 -0.0125 -6 -9 ]
[.5 -0.0125 6 0 ]
[.66667 -0.0125 -6 -9 ]
[.66667 -0.0125 6 0 ]
[.83333 -0.0125 -6 -9 ]
[.83333 -0.0125 6 0 ]
[1 -0.0125 -6 -9 ]
[1 -0.0125 6 0 ]
[-0.0125 .12361 -18 -4.5 ]
[-0.0125 .12361 0 4.5 ]
[-0.0125 .24721 -18 -4.5 ]
[-0.0125 .24721 0 4.5 ]
[-0.0125 .37082 -18 -4.5 ]
[-0.0125 .37082 0 4.5 ]
[-0.0125 .49443 -18 -4.5 ]
[-0.0125 .49443 0 4.5 ]
[-0.0125 .61803 -6 -4.5 ]
[-0.0125 .61803 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.16667 0 m
.16667 .00625 L
s
[(5)] .16667 -0.0125 0 1 Mshowa
.33333 0 m
.33333 .00625 L
s
[(10)] .33333 -0.0125 0 1 Mshowa
.5 0 m
.5 .00625 L
s
[(15)] .5 -0.0125 0 1 Mshowa
.66667 0 m
.66667 .00625 L
s
[(20)] .66667 -0.0125 0 1 Mshowa
.83333 0 m
.83333 .00625 L
s
[(25)] .83333 -0.0125 0 1 Mshowa
1 0 m
1 .00625 L
s
[(30)] 1 -0.0125 0 1 Mshowa
.125 Mabswid
.03333 0 m
.03333 .00375 L
s
.06667 0 m
.06667 .00375 L
s
.1 0 m
.1 .00375 L
s
.13333 0 m
.13333 .00375 L
s
.2 0 m
.2 .00375 L
s
.23333 0 m
.23333 .00375 L
s
.26667 0 m
.26667 .00375 L
s
.3 0 m
.3 .00375 L
s
.36667 0 m
.36667 .00375 L
s
.4 0 m
.4 .00375 L
s
.43333 0 m
.43333 .00375 L
s
.46667 0 m
.46667 .00375 L
s
.53333 0 m
.53333 .00375 L
s
.56667 0 m
.56667 .00375 L
s
.6 0 m
.6 .00375 L
s
.63333 0 m
.63333 .00375 L
s
.7 0 m
.7 .00375 L
s
.73333 0 m
.73333 .00375 L
s
.76667 0 m
.76667 .00375 L
s
.8 0 m
.8 .00375 L
s
.86667 0 m
.86667 .00375 L
s
.9 0 m
.9 .00375 L
s
.93333 0 m
.93333 .00375 L
s
.96667 0 m
.96667 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .12361 m
.00625 .12361 L
s
[(0.2)] -0.0125 .12361 1 0 Mshowa
0 .24721 m
.00625 .24721 L
s
[(0.4)] -0.0125 .24721 1 0 Mshowa
0 .37082 m
.00625 .37082 L
s
[(0.6)] -0.0125 .37082 1 0 Mshowa
0 .49443 m
.00625 .49443 L
s
[(0.8)] -0.0125 .49443 1 0 Mshowa
0 .61803 m
.00625 .61803 L
s
[(1)] -0.0125 .61803 1 0 Mshowa
.125 Mabswid
0 .0309 m
.00375 .0309 L
s
0 .0618 m
.00375 .0618 L
s
0 .09271 m
.00375 .09271 L
s
0 .15451 m
.00375 .15451 L
s
0 .18541 m
.00375 .18541 L
s
0 .21631 m
.00375 .21631 L
s
0 .27812 m
.00375 .27812 L
s
0 .30902 m
.00375 .30902 L
s
0 .33992 m
.00375 .33992 L
s
0 .40172 m
.00375 .40172 L
s
0 .43262 m
.00375 .43262 L
s
0 .46353 m
.00375 .46353 L
s
0 .52533 m
.00375 .52533 L
s
0 .55623 m
.00375 .55623 L
s
0 .58713 m
.00375 .58713 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.03333 .07556 m
.06667 .08648 L
.1 .09285 L
.13333 .09872 L
.16667 .10518 L
.2 .11271 L
.23333 .12165 L
.26667 .13229 L
.3 .14497 L
.33333 .16003 L
.36667 .1779 L
.4 .19906 L
.43333 .22409 L
.46667 .25365 L
.5 .28851 L
.53333 .32953 L
.56667 .36439 L
.6 .39394 L
.63333 .41897 L
.66667 .44013 L
.7 .458 L
.73333 .47306 L
.76667 .48574 L
.8 .49639 L
.83333 .50532 L
.86667 .51285 L
.9 .51931 L
.93333 .52519 L
.96667 .53155 L
1 .54248 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[26]:=",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/B000`400?l00000o`00003ooooooolQ
ooooo`00?_ooool3o`0002Gooooo0ol00004ooooo`;o00008oooool3o`0000?ooooo0ol0000Qoooo
o`Go00000oooool2o`00027ooooo1Ol00002ooooo`?o00008_ooool3o`0000Cooooo0_l00004oooo
o`00?Oooool01Ol0003ooooooooooooooooo000002Gooooo00?o0000ooooooooool00_ooool01?l0
003oooooooooool0000Sooooo`05o`000?ooooooooooooooool000000oooool00ol0003ooooooooo
o`0Oooooo`04o`000?ooooooooooo`0000;ooooo00Co0000oooooooooooo00008Oooool01_l0003o
ooooooooool0003oooooo`0000?ooooo00?o0000ooooooooool07_ooool01Ol0003ooooooooooooo
oooo000000;ooooo00Co0000oooooooooooo00000oooool0047ooooo00?o0000ooooooooool08ooo
ool00ol0003oooooooooo`02ooooo`04o`000?ooooooooooo`0002?ooooo00?o0000ooooooooool0
1Oooool00ol0003oooooooooo`0Pooooo`03o`000?oooooooooo00;ooooo00Co0000oooooooooooo
00008_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo02;ooooo00Co0000oooooooo
oooo00000_ooool00ol0003oooooooooo`01ooooo`00@Oooool00ol0003oooooooooo`0Sooooo`03
o`000?oooooooooo00;ooooo00Co0000oooooooooooo00008oooool00ol0003oooooooooo`05oooo
o`03o`000?oooooooooo027ooooo00Go0000ooooooooooooooooo`000002ooooo`03o`000?oooooo
oooo027ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`0Pooooo`;o00000oooool0
1?l0003oooooooooool00003ooooo`00?Oooool4o`0002Kooooo00?o0000ooooooooool00_ooool0
1?l0003oooooooooool0000Sooooo`04o`000?ooooooooooooooo`Co00008Oooool01Ol0003ooooo
oooooooooooo000000;ooooo00Co0000oooooooooooo00008?ooool01_l0003ooooooooooooooooo
0000ooooo`Co00009Oooool01?l0003oooooooooool00002ooooo`03o`000?oooooooooo007ooooo
000mooooo`03o`000?oooooooooo02Kooooo0_l00004ooooo`04o`000?ooooooooooo`0002;ooooo
0_l00003ooooo`03o`000?oooooooooo02;ooooo00Go0000ooooooooooooooooo`000002ooooo`04
o`000?ooooooooooo`00023ooooo00Oo0000ooooooooooooooooo`000?oooooo000002Cooooo00Go
0000ooooooooooooooooo`000002ooooo`04o`000?ooooooooooo`0000?ooooo000mooooo`Go0000
9Oooool00ol0003oooooooooo`03ooooo`;o00009?ooool01?l0003oooooooooooooool5o`00027o
oooo0ol00004ooooo`;o00008_ooool3o`0000;ooooo1Ol0000Qooooo`?o00001?ooool2o`0000Co
oooo003oooooob7ooooo003oooooob7ooooo003oooooob7ooooo003oooooob7ooooo000Eoooooooo
00001Ol00007ooooo`005Oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Gooooo
00?o0000ooooooooool01_ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Gooooo
00?o0000ooooooooool01_ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Gooooo
00?o0000ooooooooool01_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Kooooo
00?o0000ooooooooool01_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Kooooo
00?o0000ooooooooool01_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Kooooo
00?o0000ooooooooool01_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Kooooo
00?o0000ooooooooool01Oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Kooooo
00?o0000ooooooooool01Oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Kooooo
00?o0000ooooooooool01Oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Kooooo
00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`005Oooool00ol0003ooooooooo
o`3oooooo`Wooooo000Eooooo`03o`000?oooooooooo0?oooooo2Oooool001Gooooo00?o0000oooo
ooooool0ooooool9ooooo`005Oooool00ol0003oooooooooo`3oooooo`Wooooo000Eooooo`03o`00
0?oooooooooo0?oooooo2Oooool001Gooooo00?o0000ooooooooool0ooooool9ooooo`005Oooool2
o`000?oooooo2_ooool001Gooooo00?o0000ooooooooool0ooooool9ooooo`005Oooool00ol0003o
ooooooooo`3oooooo`Wooooo000Eooooo`03o`000?oooooooooo0?oooooo2Oooool001Gooooo00?o
0000ooooooooool0ooooool9ooooo`005Oooool00ol0003oooooooooo`3oooooo`Wooooo000Eoooo
o`03o`000?oooooooooo0?oooooo2Oooool001Gooooo00?o0000ooooooooool0ooooool9ooooo`00
5Oooool2o`000?oooooo2_ooool001Gooooo00?o0000ooooooooool0ooooool9ooooo`005Oooool0
0ol0003oooooooooo`3oooooo`Wooooo000Eooooo`03o`000?oooooooooo00Kooooo0_l0003ooooo
o`7ooooo000Eooooo`03o`000?oooooooooo00Sooooo0ol0003mooooo`005Oooool00ol0003ooooo
ooooo`0;ooooo`?o0000n_ooool001Gooooo00?o0000ooooooooool03_ooool3o`000?Oooooo000E
ooooo`03o`000?oooooooooo017ooooo1Ol0003booooo`005Oooool2o`0001Oooooo1ol0003[oooo
o`005Oooool00ol0003oooooooooo`0Mooooo`Ko0000iOooool001Gooooo00?o0000ooooooooool0
8oooool4o`000>7ooooo000Eooooo`03o`000?oooooooooo02Oooooo1?l0003Mooooo`005Oooool0
0ol0003oooooooooo`0[ooooo`Go0000f?ooool000;ooooo0_l00004ooooo`04o`000?oooooooooo
ooooo`Go00001?ooool00ol0003oooooooooo`0`ooooo`Co0000e?ooool00005ooooool0003ooooo
ooooool000002?ooool01?l0003oooooooooool00004ooooo`03o`000?oooooooooo03Cooooo1Ol0
003?ooooo`0000Goooooo`000?ooooooooooo`000009ooooo`03o`000?oooooooooo00Cooooo00?o
0000ooooooooool0>Oooool3o`000<cooooo00001Ooooooo0000oooooooooooo000000[ooooo00?o
0000ooooooooool00oooool3o`0003cooooo0ol00039ooooo`0000Goooooo`000?ooooooooooo`00
0007ooooo`05o`000?ooooooooooooooool000001?ooool00ol0003oooooooooo`0oooooo`?o0000
a_ooool00005ooooool0003oooooooooool000001oooool01Ol0003ooooooooooooooooo000000Co
oooo00?o0000ooooooooool0@_ooool3o`000<?ooooo0002ooooo`;o00002Oooool3o`0000Gooooo
00?o0000ooooooooool0AOooool3o`000<3ooooo000Eooooo`03o`000?oooooooooo04Sooooo0ol0
002mooooo`005Oooool00ol0003oooooooooo`1;ooooo`;o0000^oooool001Gooooo00?o0000oooo
ooooool0COooool2o`000;Wooooo000Eooooo`03o`000?oooooooooo04oooooo0_l0002gooooo`00
5Oooool2o`0005;ooooo0_l0002eooooo`005Oooool00ol0003oooooooooo`1Cooooo`;o0000/ooo
ool001Gooooo00?o0000ooooooooool0EOooool2o`000;7ooooo000Eooooo`03o`000?oooooooooo
05Oooooo0_l0002_ooooo`005Oooool00ol0003oooooooooo`1Iooooo`03o`000?oooooooooo0:co
oooo000Eooooo`03o`000?oooooooooo05[ooooo0_l0002/ooooo`005Oooool00ol0003ooooooooo
o`1Looooo`;o0000Z_ooool001Gooooo00?o0000ooooooooool0G_ooool2o`000:Sooooo000Eoooo
o`;o0000HOooool2o`000:Kooooo000Eooooo`03o`000?oooooooooo06;ooooo00?o0000oooooooo
ool0Xoooool001Gooooo00?o0000ooooooooool0Hoooool2o`000:?ooooo000Eooooo`03o`000?oo
oooooooo06Gooooo0_l0002Qooooo`005Oooool00ol0003oooooooooo`1Wooooo`03o`000?oooooo
oooo09kooooo000Eooooo`03o`000?oooooooooo06Sooooo00?o0000ooooooooool0WOooool001Go
oooo00?o0000ooooooooool0JOooool00ol0003oooooooooo`2Looooo`005Oooool00ol0003ooooo
ooooo`1Zooooo`03o`000?oooooooooo09_ooooo000Eooooo`;o0000K?ooool00ol0003ooooooooo
o`2Jooooo`005Oooool00ol0003oooooooooo`1/ooooo`03o`000?oooooooooo09Wooooo000Eoooo
o`03o`000?oooooooooo06gooooo0_l0002Iooooo`005Oooool00ol0003oooooooooo`1_ooooo`03
o`000?oooooooooo09Kooooo000Eooooo`03o`000?oooooooooo073ooooo00?o0000ooooooooool0
UOooool000;ooooo0_l00004ooooo`03o`000?oooooooooo00?ooooo0ol00004ooooo`03o`000?oo
oooooooo077ooooo00?o0000ooooooooool0U?ooool00005ooooool0003oooooooooool000002_oo
ool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo07;ooooo00?o0000ooooooooool0Tooo
ool00005ooooool0003oooooooooool000001oooool5o`0000Cooooo00?o0000ooooooooool0Looo
ool00ol0003oooooooooo`2Booooo`0000Goooooo`000?ooooooooooo`000007ooooo`04o`000?oo
ooooooooo`0000Gooooo0ol0001dooooo`03o`000?oooooooooo097ooooo00001Ooooooo0000oooo
oooooooo000000Sooooo00?o0000ooooool000001Oooool00ol0003oooooooooo`1eooooo`03o`00
0?oooooooooo093ooooo00001Ooooooo0000oooooooooooo000000Wooooo0_l00005ooooo`03o`00
0?oooooooooo07Kooooo00?o0000ooooooooool0Soooool000;ooooo0_l0000;ooooo`03o`000?oo
oooooooo00?ooooo00?o0000ooooooooool0Moooool00ol0003oooooooooo`2>ooooo`005Oooool0
0ol0003oooooooooo`1hooooo`03o`000?oooooooooo08gooooo000Eooooo`03o`000?oooooooooo
07Wooooo00?o0000ooooooooool0S?ooool001Gooooo00?o0000ooooooooool0N_ooool00ol0003o
ooooooooo`2;ooooo`005Oooool00ol0003oooooooooo`1kooooo`03o`000?oooooooooo08[ooooo
000Eooooo`;o0000OOooool00ol0003oooooooooo`29ooooo`005Oooool00ol0003oooooooooo`1m
ooooo`03o`000?oooooooooo08Sooooo000Eooooo`03o`000?oooooooooo07kooooo00?o0000oooo
ooooool0Qoooool001Gooooo00?o0000ooooooooool0Ooooool00ol0003oooooooooo`26ooooo`00
5Oooool00ol0003oooooooooo`1oooooo`03o`000?oooooooooo08Kooooo000Eooooo`03o`000?oo
oooooooo083ooooo00?o0000ooooooooool0QOooool001Gooooo00?o0000ooooooooool0POooool0
0ol0003oooooooooo`24ooooo`005Oooool00ol0003oooooooooo`22ooooo`03o`000?oooooooooo
08?ooooo000Eooooo`;o0000Q?ooool00ol0003oooooooooo`22ooooo`005Oooool00ol0003ooooo
ooooo`23ooooo`03o`000?oooooooooo08;ooooo000Eooooo`03o`000?oooooooooo08Cooooo00?o
0000ooooooooool0POooool001Gooooo00?o0000ooooooooool0QOooool00ol0003oooooooooo`20
ooooo`005Oooool00ol0003oooooooooo`26ooooo`03o`000?oooooooooo07oooooo000Eooooo`03
o`000?oooooooooo08Oooooo00?o0000ooooooooool0O_ooool001Gooooo00?o0000ooooooooool0
R?ooool00ol0003oooooooooo`1mooooo`005Oooool00ol0003oooooooooo`29ooooo`03o`000?oo
oooooooo07cooooo000Eooooo`;o0000Roooool00ol0003oooooooooo`1kooooo`005Oooool00ol0
003oooooooooo`2;ooooo`03o`000?oooooooooo07[ooooo000Eooooo`03o`000?oooooooooo08co
oooo00?o0000ooooooooool0NOooool001Gooooo00?o0000ooooooooool0SOooool00ol0003ooooo
ooooo`1hooooo`005Oooool00ol0003oooooooooo`2>ooooo`03o`000?oooooooooo07Oooooo0002
ooooo`;o00001?ooool00ol0003oooooooooo`02ooooo`?o00001Oooool00ol0003oooooooooo`2?
ooooo`03o`000?oooooooooo07Kooooo00001Ooooooo0000oooooooooooo000000Oooooo00Go0000
ooooooooooooooooo`000004ooooo`03o`000?oooooooooo093ooooo0_l0001fooooo`0000Gooooo
o`000?ooooooooooo`000007ooooo`05o`000?ooooooooooooooool000001?ooool00ol0003ooooo
ooooo`2Booooo`03o`000?oooooooooo07?ooooo00001Ooooooo0000oooooooooooo000000Oooooo
1?l00005ooooo`?o0000Toooool00ol0003oooooooooo`1booooo`0000Goooooo`000?oooooooooo
o`000007ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0U?ooool00ol0003ooooo
ooooo`1aooooo`0000Goooooo`000?ooooooooooo`000008ooooo`03o`000?oooooooooo00Gooooo
00?o0000ooooooooool0UOooool00ol0003oooooooooo`1`ooooo`000_ooool2o`0000[ooooo0_l0
0005ooooo`03o`000?oooooooooo09Kooooo00?o0000ooooooooool0Koooool001Gooooo00?o0000
ooooooooool0Uoooool00ol0003oooooooooo`1^ooooo`005Oooool00ol0003oooooooooo`2Hoooo
o`03o`000?oooooooooo06gooooo000Eooooo`03o`000?oooooooooo09Wooooo0_l0001]ooooo`00
5Oooool00ol0003oooooooooo`2Kooooo`03o`000?oooooooooo06[ooooo000Eooooo`;o0000WOoo
ool00ol0003oooooooooo`1Yooooo`005Oooool00ol0003oooooooooo`2Mooooo`;o0000JOooool0
01Gooooo00?o0000ooooooooool0Woooool00ol0003oooooooooo`1Vooooo`005Oooool00ol0003o
ooooooooo`2Pooooo`03o`000?oooooooooo06Gooooo000Eooooo`03o`000?oooooooooo0:7ooooo
0_l0001Uooooo`005Oooool00ol0003oooooooooo`2Sooooo`03o`000?oooooooooo06;ooooo000E
ooooo`03o`000?oooooooooo0:Cooooo0_l0001Rooooo`005Oooool00ol0003oooooooooo`2Voooo
o`03o`000?oooooooooo05oooooo000Eooooo`;o0000Z?ooool2o`0005oooooo000Eooooo`03o`00
0?oooooooooo0:Wooooo00?o0000ooooooooool0G?ooool001Gooooo00?o0000ooooooooool0Z_oo
ool2o`0005cooooo000Eooooo`03o`000?oooooooooo0:cooooo00?o0000ooooooooool0FOooool0
01Gooooo00?o0000ooooooooool0[Oooool2o`0005Wooooo000Eooooo`03o`000?oooooooooo0:oo
oooo0_l0001Gooooo`005Oooool00ol0003oooooooooo`2aooooo`03o`000?oooooooooo05Cooooo
000Eooooo`03o`000?oooooooooo0;;ooooo0ol0001Cooooo`005Oooool2o`000;Kooooo0ol0001@
ooooo`005Oooool00ol0003oooooooooo`2hooooo`?o0000COooool001Gooooo00?o0000oooooooo
ool0^oooool2o`0004_ooooo000Eooooo`03o`000?oooooooooo0;gooooo0_l00019ooooo`005Ooo
ool00ol0003oooooooooo`2oooooo`?o0000A_ooool000;ooooo0_l00004ooooo`03o`000?oooooo
oooo00;ooooo0ol00005ooooo`03o`000?oooooooooo0<;ooooo0_l00014ooooo`0000Goooooo`00
0?ooooooooooo`000007ooooo`05o`000?ooooooooooooooool000001?ooool00ol0003ooooooooo
o`34ooooo`?o0000@Oooool00005ooooool0003oooooooooool000001oooool01Ol0003ooooooooo
oooooooo000000Cooooo00?o0000ooooooooool0aoooool4o`0003gooooo00001Ooooooo0000oooo
oooooooo000000Sooooo0ol00005ooooo`?o0000boooool4o`0003Wooooo00001Ooooooo0000oooo
oooooooo000000Oooooo00Go0000ooooooooooooooooo`000004ooooo`03o`000?oooooooooo0<oo
oooo0ol0000fooooo`0000Goooooo`000?ooooooooooo`000007ooooo`05o`000?oooooooooooooo
ool000001?ooool00ol0003oooooooooo`3Booooo`?o0000<oooool000;ooooo0_l00009ooooo`?o
00001Oooool00ol0003oooooooooo`3Eooooo`?o0000<?ooool001Gooooo00?o0000ooooooooool0
f?ooool5o`0002_ooooo000Eooooo`03o`000?oooooooooo0=gooooo1_l0000Uooooo`005Oooool0
0ol0003oooooooooo`3Sooooo`Ko00007oooool001Gooooo00?o0000ooooooooool0jOooool5o`00
01[ooooo000Eooooo`;o0000koooool4o`0001Kooooo000Eooooo`03o`000?oooooooooo0?;ooooo
1Ol0000Aooooo`005Oooool00ol0003oooooooooo`3gooooo`Co00003Oooool001Gooooo00?o0000
ooooooooool0noooool4o`0000Wooooo000Eooooo`03o`000?oooooooooo0?oooooo0_l00007oooo
o`005Oooool00ol0003oooooooooo`3oooooo`Wooooo000Eooooo`03o`000?oooooooooo0?oooooo
2Oooool001Gooooo00?o0000ooooooooool0ooooool9ooooo`005Oooool2o`000?oooooo2_ooool0
01Gooooo00?o0000ooooooooool0ooooool9ooooo`005Oooool00ol0003oooooooooo`3oooooo`Wo
oooo000Eooooo`03o`000?oooooooooo0?oooooo2Oooool001Gooooo00?o0000ooooooooool0oooo
ool9ooooo`005Oooool00ol0003oooooooooo`3oooooo`Wooooo000Eooooo`03o`000?oooooooooo
0?oooooo2Oooool001Gooooo00?o0000ooooooooool0ooooool9ooooo`005Oooool2o`000?oooooo
2_ooool001Gooooo00?o0000ooooooooool0ooooool9ooooo`005Oooool00ol0003oooooooooo`3o
ooooo`Wooooo000Eooooo`03o`000?oooooooooo0?oooooo2Oooool001Gooooo00?o0000oooooooo
ool0ooooool9ooooo`003Oooool3o`0000Gooooo00?o0000ooooooooool0ooooool9ooooo`003_oo
ool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo0?oooooo2Oooool000kooooo00?o0000
ooooooooool01?ooool00ol0003oooooooooo`3oooooo`Wooooo000>ooooo`03o`000?oooooooooo
00Cooooo0ol0003oooooo`Wooooo000>ooooo`03o`000?oooooooooo0?oooooo4?ooool000gooooo
0_l0003ooooooa;ooooo000>ooooo`03o`000?oooooooooo0?oooooo4?ooool00?oooooo8Oooool0
0001\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-2.49048, -0.0764114, \
0.115739, 0.00624232}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 0.0333333 0 0.618034 [
[.16667 -0.0125 -3 -9 ]
[.16667 -0.0125 3 0 ]
[.33333 -0.0125 -6 -9 ]
[.33333 -0.0125 6 0 ]
[.5 -0.0125 -6 -9 ]
[.5 -0.0125 6 0 ]
[.66667 -0.0125 -6 -9 ]
[.66667 -0.0125 6 0 ]
[.83333 -0.0125 -6 -9 ]
[.83333 -0.0125 6 0 ]
[1 -0.0125 -6 -9 ]
[1 -0.0125 6 0 ]
[-0.0125 .12361 -18 -4.5 ]
[-0.0125 .12361 0 4.5 ]
[-0.0125 .24721 -18 -4.5 ]
[-0.0125 .24721 0 4.5 ]
[-0.0125 .37082 -18 -4.5 ]
[-0.0125 .37082 0 4.5 ]
[-0.0125 .49443 -18 -4.5 ]
[-0.0125 .49443 0 4.5 ]
[-0.0125 .61803 -6 -4.5 ]
[-0.0125 .61803 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.16667 0 m
.16667 .00625 L
s
[(5)] .16667 -0.0125 0 1 Mshowa
.33333 0 m
.33333 .00625 L
s
[(10)] .33333 -0.0125 0 1 Mshowa
.5 0 m
.5 .00625 L
s
[(15)] .5 -0.0125 0 1 Mshowa
.66667 0 m
.66667 .00625 L
s
[(20)] .66667 -0.0125 0 1 Mshowa
.83333 0 m
.83333 .00625 L
s
[(25)] .83333 -0.0125 0 1 Mshowa
1 0 m
1 .00625 L
s
[(30)] 1 -0.0125 0 1 Mshowa
.125 Mabswid
.03333 0 m
.03333 .00375 L
s
.06667 0 m
.06667 .00375 L
s
.1 0 m
.1 .00375 L
s
.13333 0 m
.13333 .00375 L
s
.2 0 m
.2 .00375 L
s
.23333 0 m
.23333 .00375 L
s
.26667 0 m
.26667 .00375 L
s
.3 0 m
.3 .00375 L
s
.36667 0 m
.36667 .00375 L
s
.4 0 m
.4 .00375 L
s
.43333 0 m
.43333 .00375 L
s
.46667 0 m
.46667 .00375 L
s
.53333 0 m
.53333 .00375 L
s
.56667 0 m
.56667 .00375 L
s
.6 0 m
.6 .00375 L
s
.63333 0 m
.63333 .00375 L
s
.7 0 m
.7 .00375 L
s
.73333 0 m
.73333 .00375 L
s
.76667 0 m
.76667 .00375 L
s
.8 0 m
.8 .00375 L
s
.86667 0 m
.86667 .00375 L
s
.9 0 m
.9 .00375 L
s
.93333 0 m
.93333 .00375 L
s
.96667 0 m
.96667 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .12361 m
.00625 .12361 L
s
[(0.2)] -0.0125 .12361 1 0 Mshowa
0 .24721 m
.00625 .24721 L
s
[(0.4)] -0.0125 .24721 1 0 Mshowa
0 .37082 m
.00625 .37082 L
s
[(0.6)] -0.0125 .37082 1 0 Mshowa
0 .49443 m
.00625 .49443 L
s
[(0.8)] -0.0125 .49443 1 0 Mshowa
0 .61803 m
.00625 .61803 L
s
[(1)] -0.0125 .61803 1 0 Mshowa
.125 Mabswid
0 .0309 m
.00375 .0309 L
s
0 .0618 m
.00375 .0618 L
s
0 .09271 m
.00375 .09271 L
s
0 .15451 m
.00375 .15451 L
s
0 .18541 m
.00375 .18541 L
s
0 .21631 m
.00375 .21631 L
s
0 .27812 m
.00375 .27812 L
s
0 .30902 m
.00375 .30902 L
s
0 .33992 m
.00375 .33992 L
s
0 .40172 m
.00375 .40172 L
s
0 .43262 m
.00375 .43262 L
s
0 .46353 m
.00375 .46353 L
s
0 .52533 m
.00375 .52533 L
s
0 .55623 m
.00375 .55623 L
s
0 .58713 m
.00375 .58713 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.03333 .02699 m
.06667 .03151 L
.1 .03495 L
.13333 .03885 L
.16667 .04372 L
.2 .04993 L
.23333 .05787 L
.26667 .06799 L
.3 .08088 L
.33333 .0973 L
.36667 .11818 L
.4 .14474 L
.43333 .17849 L
.46667 .22127 L
.5 .27526 L
.53333 .34277 L
.56667 .39677 L
.6 .43955 L
.63333 .47329 L
.66667 .49985 L
.7 .52074 L
.73333 .53715 L
.76667 .55005 L
.8 .56017 L
.83333 .5681 L
.86667 .57432 L
.9 .57919 L
.93333 .58309 L
.96667 .58653 L
1 .59105 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[26]:=",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/B000`400?l00000o`00003ooooooolQ
ooooo`00?_ooool3o`0002Gooooo0ol00004ooooo`;o00008oooool3o`0000?ooooo0ol0000Qoooo
o`Go00000oooool2o`00027ooooo1Ol00002ooooo`?o00008_ooool3o`0000Cooooo0_l00004oooo
o`00?Oooool01Ol0003ooooooooooooooooo000002Gooooo00?o0000ooooooooool00_ooool01?l0
003oooooooooool0000Sooooo`05o`000?ooooooooooooooool000000oooool00ol0003ooooooooo
o`0Oooooo`04o`000?ooooooooooo`0000;ooooo00Co0000oooooooooooo00008Oooool01_l0003o
ooooooooool0003oooooo`0000?ooooo00?o0000ooooooooool07_ooool01Ol0003ooooooooooooo
oooo000000;ooooo00Co0000oooooooooooo00000oooool0047ooooo00?o0000ooooooooool08ooo
ool00ol0003oooooooooo`02ooooo`04o`000?ooooooooooo`0002?ooooo00?o0000ooooooooool0
1Oooool00ol0003oooooooooo`0Pooooo`03o`000?oooooooooo00;ooooo00Co0000oooooooooooo
00008_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo02;ooooo00Co0000oooooooo
oooo00000_ooool00ol0003oooooooooo`01ooooo`00@Oooool00ol0003oooooooooo`0Sooooo`03
o`000?oooooooooo00;ooooo00Co0000oooooooooooo00008oooool00ol0003oooooooooo`05oooo
o`03o`000?oooooooooo027ooooo00Go0000ooooooooooooooooo`000002ooooo`03o`000?oooooo
oooo027ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`0Pooooo`;o00000oooool0
1?l0003oooooooooool00003ooooo`00?Oooool4o`0002Kooooo00?o0000ooooooooool00_ooool0
1?l0003oooooooooool0000Sooooo`04o`000?ooooooooooooooo`Co00008Oooool01Ol0003ooooo
oooooooooooo000000;ooooo00Co0000oooooooooooo00008?ooool01_l0003ooooooooooooooooo
0000ooooo`Co00009Oooool01?l0003oooooooooool00002ooooo`03o`000?oooooooooo007ooooo
000mooooo`03o`000?oooooooooo02Kooooo0_l00004ooooo`04o`000?ooooooooooo`0002;ooooo
0_l00003ooooo`03o`000?oooooooooo02;ooooo00Go0000ooooooooooooooooo`000002ooooo`04
o`000?ooooooooooo`00023ooooo00Oo0000ooooooooooooooooo`000?oooooo000002Cooooo00Go
0000ooooooooooooooooo`000002ooooo`04o`000?ooooooooooo`0000?ooooo000mooooo`Go0000
9Oooool00ol0003oooooooooo`03ooooo`;o00009?ooool01?l0003oooooooooooooool5o`00027o
oooo0ol00004ooooo`;o00008_ooool3o`0000;ooooo1Ol0000Qooooo`?o00001?ooool2o`0000Co
oooo003oooooob7ooooo003oooooob7ooooo003oooooob7ooooo003oooooob7ooooo000Eoooooooo
00001Ol00007ooooo`005Oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Gooooo
00?o0000ooooooooool01_ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Gooooo
00?o0000ooooooooool01_ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Gooooo
00?o0000ooooooooool01_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Kooooo
00?o0000ooooooooool01_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Kooooo
00?o0000ooooooooool01_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Kooooo
00?o0000ooooooooool01_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Kooooo
00?o0000ooooooooool01Oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Kooooo
00?o0000ooooooooool01Oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Kooooo
00?o0000ooooooooool01Oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Kooooo
00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`005Oooool00ol0003ooooooooo
o`3oooooo`Wooooo000Eooooo`03o`000?oooooooooo0?oooooo2Oooool001Gooooo00?o0000oooo
ooooool0ooooool9ooooo`005Oooool00ol0003oooooooooo`3oooooo`Wooooo000Eooooo`03o`00
0?oooooooooo0?oooooo2Oooool001Gooooo00?o0000ooooooooool01_ooool5o`000?gooooo000E
ooooo`;o00003?ooool9o`000?Cooooo000Eooooo`03o`000?oooooooooo01Cooooo2Ol0003[oooo
o`005Oooool00ol0003oooooooooo`0Mooooo`So0000hoooool001Gooooo00?o0000ooooooooool0
9Oooool6o`000=gooooo000Eooooo`03o`000?oooooooooo02_ooooo1Ol0003Hooooo`005Oooool0
0ol0003oooooooooo`0`ooooo`Co0000e?ooool001Gooooo00?o0000ooooooooool0=?ooool5o`00
0<oooooo000Eooooo`03o`000?oooooooooo03Wooooo1?l0003;ooooo`005Oooool2o`0003kooooo
1?l00037ooooo`005Oooool00ol0003oooooooooo`11ooooo`?o0000a?ooool001Gooooo00?o0000
ooooooooool0A?ooool2o`000<;ooooo000Eooooo`03o`000?oooooooooo04Kooooo0ol0002ooooo
o`005Oooool00ol0003oooooooooo`19ooooo`;o0000_Oooool001Gooooo00?o0000ooooooooool0
Boooool2o`000;_ooooo000Eooooo`03o`000?oooooooooo04gooooo0_l0002iooooo`005Oooool0
0ol0003oooooooooo`1?ooooo`;o0000]oooool001Gooooo0_l0001Booooo`;o0000]Oooool001Go
oooo00?o0000ooooooooool0Doooool2o`000;?ooooo000Eooooo`03o`000?oooooooooo05Gooooo
0_l0002aooooo`005Oooool00ol0003oooooooooo`1Gooooo`;o0000[oooool001Gooooo00?o0000
ooooooooool0FOooool00ol0003oooooooooo`2/ooooo`000_ooool2o`0000Cooooo00Co0000oooo
oooooooooooo1Ol00004ooooo`03o`000?oooooooooo05[ooooo0_l0002/ooooo`0000Goooooo`00
0?ooooooooooo`000008ooooo`04o`000?ooooooooooo`0000Cooooo00?o0000ooooooooool0G?oo
ool2o`000:[ooooo00001Ooooooo0000oooooooooooo000000Wooooo00?o0000ooooooooool01?oo
ool00ol0003oooooooooo`1Nooooo`03o`000?oooooooooo0:Oooooo00001Ooooooo0000oooooooo
oooo000000[ooooo00?o0000ooooooooool00oooool3o`0005oooooo00?o0000ooooooooool0Y_oo
ool00005ooooool0003oooooooooool000001oooool01Ol0003ooooooooooooooooo000000Cooooo
00?o0000ooooooooool0H?ooool2o`000:Kooooo00001Ooooooo0000oooooooooooo000000Oooooo
00Go0000ooooooooooooooooo`000004ooooo`03o`000?oooooooooo06;ooooo00?o0000oooooooo
ool0Xoooool000;ooooo0_l00009ooooo`?o00001Oooool00ol0003oooooooooo`1Sooooo`03o`00
0?oooooooooo0:;ooooo000Eooooo`03o`000?oooooooooo06Cooooo00?o0000ooooooooool0XOoo
ool001Gooooo00?o0000ooooooooool0IOooool00ol0003oooooooooo`2Pooooo`005Oooool00ol0
003oooooooooo`1Uooooo`03o`000?oooooooooo0:3ooooo000Eooooo`03o`000?oooooooooo06Ko
oooo00?o0000ooooooooool0Woooool001Gooooo0_l0001Xooooo`03o`000?oooooooooo09kooooo
000Eooooo`03o`000?oooooooooo06Sooooo00?o0000ooooooooool0WOooool001Gooooo00?o0000
ooooooooool0JOooool00ol0003oooooooooo`2Looooo`005Oooool00ol0003oooooooooo`1Zoooo
o`03o`000?oooooooooo09_ooooo000Eooooo`03o`000?oooooooooo06_ooooo00?o0000oooooooo
ool0V_ooool001Gooooo00?o0000ooooooooool0K?ooool00ol0003oooooooooo`2Iooooo`005Ooo
ool00ol0003oooooooooo`1]ooooo`03o`000?oooooooooo09Sooooo000Eooooo`03o`000?oooooo
oooo06gooooo00?o0000ooooooooool0V?ooool001Gooooo0_l0001_ooooo`03o`000?oooooooooo
09Oooooo000Eooooo`03o`000?oooooooooo06oooooo00?o0000ooooooooool0U_ooool001Gooooo
00?o0000ooooooooool0L?ooool00ol0003oooooooooo`2Eooooo`005Oooool00ol0003ooooooooo
o`1aooooo`03o`000?oooooooooo09Cooooo000Eooooo`03o`000?oooooooooo07;ooooo00?o0000
ooooooooool0Toooool001Gooooo00?o0000ooooooooool0L_ooool00ol0003oooooooooo`2Coooo
o`005Oooool00ol0003oooooooooo`1cooooo`03o`000?oooooooooo09;ooooo000Eooooo`03o`00
0?oooooooooo07Cooooo00?o0000ooooooooool0TOooool001Gooooo0_l0001fooooo`03o`000?oo
oooooooo093ooooo000Eooooo`03o`000?oooooooooo07Kooooo00?o0000ooooooooool0Soooool0
01Gooooo00?o0000ooooooooool0M_ooool00ol0003oooooooooo`2?ooooo`005Oooool00ol0003o
ooooooooo`1gooooo`03o`000?oooooooooo08kooooo000Eooooo`03o`000?oooooooooo07Sooooo
00?o0000ooooooooool0SOooool000;ooooo0_l00004ooooo`03o`000?oooooooooo00?ooooo0ol0
0004ooooo`03o`000?oooooooooo07Sooooo00?o0000ooooooooool0SOooool00005ooooool0003o
ooooooooool000002_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo07Wooooo00?o
0000ooooooooool0S?ooool00005ooooool0003oooooooooool000001oooool5o`0000Cooooo00?o
0000ooooooooool0N_ooool00ol0003oooooooooo`2;ooooo`0000Goooooo`000?ooooooooooo`00
0007ooooo`04o`000?ooooooooooo`0000Gooooo0ol0001jooooo`03o`000?oooooooooo08_ooooo
00001Ooooooo0000oooooooooooo000000Sooooo00?o0000ooooool000001Oooool00ol0003ooooo
ooooo`1kooooo`03o`000?oooooooooo08[ooooo00001Ooooooo0000oooooooooooo000000Wooooo
0_l00005ooooo`03o`000?oooooooooo07_ooooo00?o0000ooooooooool0R_ooool000;ooooo0_l0
000;ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0O?ooool00ol0003ooooooooo
o`29ooooo`005Oooool00ol0003oooooooooo`1mooooo`03o`000?oooooooooo08Sooooo000Eoooo
o`03o`000?oooooooooo07gooooo00?o0000ooooooooool0R?ooool001Gooooo00?o0000oooooooo
ool0O_ooool00ol0003oooooooooo`27ooooo`005Oooool00ol0003oooooooooo`1oooooo`03o`00
0?oooooooooo08Kooooo000Eooooo`;o0000P?ooool00ol0003oooooooooo`26ooooo`005Oooool0
0ol0003oooooooooo`20ooooo`03o`000?oooooooooo08Gooooo000Eooooo`03o`000?oooooooooo
083ooooo00?o0000ooooooooool0QOooool001Gooooo00?o0000ooooooooool0POooool00ol0003o
ooooooooo`24ooooo`005Oooool00ol0003oooooooooo`21ooooo`03o`000?oooooooooo08Cooooo
000Eooooo`03o`000?oooooooooo087ooooo00?o0000ooooooooool0Q?ooool001Gooooo00?o0000
ooooooooool0P_ooool00ol0003oooooooooo`23ooooo`005Oooool00ol0003oooooooooo`22oooo
o`03o`000?oooooooooo08?ooooo000Eooooo`;o0000Q?ooool00ol0003oooooooooo`22ooooo`00
5Oooool00ol0003oooooooooo`23ooooo`03o`000?oooooooooo08;ooooo000Eooooo`03o`000?oo
oooooooo08Cooooo00?o0000ooooooooool0POooool001Gooooo00?o0000ooooooooool0Q?ooool0
0ol0003oooooooooo`21ooooo`005Oooool00ol0003oooooooooo`25ooooo`03o`000?oooooooooo
083ooooo000Eooooo`03o`000?oooooooooo08Gooooo00?o0000ooooooooool0P?ooool001Gooooo
00?o0000ooooooooool0QOooool00ol0003oooooooooo`20ooooo`005Oooool00ol0003ooooooooo
o`26ooooo`03o`000?oooooooooo07oooooo000Eooooo`;o0000Qoooool00ol0003oooooooooo`1o
ooooo`005Oooool00ol0003oooooooooo`27ooooo`03o`000?oooooooooo07kooooo000Eooooo`03
o`000?oooooooooo08Oooooo00?o0000ooooooooool0O_ooool001Gooooo00?o0000ooooooooool0
R?ooool00ol0003oooooooooo`1mooooo`005Oooool00ol0003oooooooooo`29ooooo`03o`000?oo
oooooooo07cooooo0002ooooo`;o00001?ooool00ol0003oooooooooo`02ooooo`?o00001Oooool0
0ol0003oooooooooo`29ooooo`03o`000?oooooooooo07cooooo00001Ooooooo0000oooooooooooo
000000Oooooo00Go0000ooooooooooooooooo`000004ooooo`03o`000?oooooooooo08[ooooo00?o
0000ooooooooool0Noooool00005ooooool0003oooooooooool000001oooool01Ol0003ooooooooo
oooooooo000000Cooooo00?o0000ooooooooool0Roooool00ol0003oooooooooo`1jooooo`0000Go
ooooo`000?ooooooooooo`000007ooooo`Co00001Oooool3o`0008_ooooo00?o0000ooooooooool0
N_ooool00005ooooool0003oooooooooool000001oooool00ol0003oooooooooo`06ooooo`03o`00
0?oooooooooo08cooooo00?o0000ooooooooool0NOooool00005ooooool0003oooooooooool00000
2?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo08cooooo00?o0000ooooooooool0
NOooool000;ooooo0_l0000:ooooo`;o00001Oooool00ol0003oooooooooo`2=ooooo`03o`000?oo
oooooooo07Sooooo000Eooooo`03o`000?oooooooooo08kooooo00?o0000ooooooooool0Moooool0
01Gooooo00?o0000ooooooooool0S_ooool00ol0003oooooooooo`1gooooo`005Oooool00ol0003o
ooooooooo`2?ooooo`03o`000?oooooooooo07Kooooo000Eooooo`03o`000?oooooooooo093ooooo
00?o0000ooooooooool0MOooool001Gooooo0_l0002Aooooo`03o`000?oooooooooo07Gooooo000E
ooooo`03o`000?oooooooooo097ooooo00?o0000ooooooooool0M?ooool001Gooooo00?o0000oooo
ooooool0T_ooool00ol0003oooooooooo`1cooooo`005Oooool00ol0003oooooooooo`2Cooooo`03
o`000?oooooooooo07;ooooo000Eooooo`03o`000?oooooooooo09Cooooo00?o0000ooooooooool0
LOooool001Gooooo00?o0000ooooooooool0UOooool00ol0003oooooooooo`1`ooooo`005Oooool0
0ol0003oooooooooo`2Eooooo`03o`000?oooooooooo073ooooo000Eooooo`03o`000?oooooooooo
09Kooooo00?o0000ooooooooool0Koooool001Gooooo0_l0002Hooooo`03o`000?oooooooooo06ko
oooo000Eooooo`03o`000?oooooooooo09Sooooo00?o0000ooooooooool0KOooool001Gooooo00?o
0000ooooooooool0VOooool00ol0003oooooooooo`1/ooooo`005Oooool00ol0003oooooooooo`2J
ooooo`03o`000?oooooooooo06_ooooo000Eooooo`03o`000?oooooooooo09_ooooo00?o0000oooo
ooooool0J_ooool001Gooooo00?o0000ooooooooool0W?ooool00ol0003oooooooooo`1Yooooo`00
5Oooool00ol0003oooooooooo`2Mooooo`03o`000?oooooooooo06Sooooo000Eooooo`03o`000?oo
oooooooo09kooooo00?o0000ooooooooool0Ioooool001Gooooo0_l0002Pooooo`03o`000?oooooo
oooo06Kooooo000Eooooo`03o`000?oooooooooo0:3ooooo00?o0000ooooooooool0IOooool001Go
oooo00?o0000ooooooooool0XOooool2o`0006Gooooo000Eooooo`03o`000?oooooooooo0:?ooooo
00?o0000ooooooooool0H_ooool001Gooooo00?o0000ooooooooool0Y?ooool00ol0003ooooooooo
o`1Qooooo`000_ooool2o`0000Cooooo00?o0000ooooooooool00_ooool3o`0000Gooooo00?o0000
ooooooooool0YOooool2o`00067ooooo00001Ooooooo0000oooooooooooo000000Oooooo00Go0000
ooooooooooooooooo`000004ooooo`03o`000?oooooooooo0:Oooooo00?o0000ooooooooool0G_oo
ool00005ooooool0003oooooooooool000001oooool01Ol0003ooooooooooooooooo000000Cooooo
00?o0000ooooooooool0Z?ooool00ol0003oooooooooo`1Mooooo`0000Goooooo`000?oooooooooo
o`000008ooooo`?o00001Oooool3o`000:Wooooo00?o0000ooooooooool0G?ooool00005ooooool0
003oooooooooool000001oooool01Ol0003ooooooooooooooooo000000Cooooo00?o0000oooooooo
ool0Z_ooool2o`0005cooooo00001Ooooooo0000oooooooooooo000000Oooooo00Go0000oooooooo
ooooooooo`000004ooooo`03o`000?oooooooooo0:cooooo00?o0000ooooooooool0FOooool000;o
oooo0_l00009ooooo`?o00001Oooool00ol0003oooooooooo`2]ooooo`03o`000?oooooooooo05So
oooo000Eooooo`03o`000?oooooooooo0:kooooo0_l0001Hooooo`005Oooool00ol0003ooooooooo
o`2`ooooo`03o`000?oooooooooo05Gooooo000Eooooo`03o`000?oooooooooo0;7ooooo00?o0000
ooooooooool0E?ooool001Gooooo00?o0000ooooooooool0/_ooool2o`0005Cooooo000Eooooo`;o
0000]Oooool2o`0005;ooooo000Eooooo`03o`000?oooooooooo0;Kooooo0ol0001?ooooo`005Ooo
ool00ol0003oooooooooo`2iooooo`;o0000COooool001Gooooo00?o0000ooooooooool0^oooool3
o`0004[ooooo000Eooooo`03o`000?oooooooooo0;kooooo0ol00017ooooo`005Oooool00ol0003o
ooooooooo`31ooooo`?o0000A?ooool001Gooooo00?o0000ooooooooool0a?ooool2o`0004;ooooo
000Eooooo`03o`000?oooooooooo0<Kooooo0ol0000oooooo`005Oooool2o`000<[ooooo0ol0000l
ooooo`005Oooool00ol0003oooooooooo`3<ooooo`?o0000>Oooool001Gooooo00?o0000oooooooo
ool0coooool5o`0003Cooooo000Eooooo`03o`000?oooooooooo0=Cooooo1?l0000`ooooo`005Ooo
ool00ol0003oooooooooo`3Hooooo`Go0000:oooool001Gooooo00?o0000ooooooooool0gOooool6
o`0002Gooooo000Eooooo`03o`000?oooooooooo0>?ooooo2Ol0000Looooo`005Oooool00ol0003o
ooooooooo`3/ooooo`Wo00004oooool001Gooooo0_l0003fooooo`So00002oooool001Gooooo00?o
0000ooooooooool0oOooool4o`0000Oooooo000Eooooo`03o`000?oooooooooo0?oooooo2Oooool0
01Gooooo00?o0000ooooooooool0ooooool9ooooo`005Oooool00ol0003oooooooooo`3oooooo`Wo
oooo000=ooooo`?o00001Oooool00ol0003oooooooooo`3oooooo`Wooooo000>ooooo`03o`000?oo
oooooooo00Cooooo00?o0000ooooooooool0ooooool9ooooo`003_ooool00ol0003oooooooooo`04
ooooo`03o`000?oooooooooo0?oooooo2Oooool000kooooo00?o0000ooooooooool01?ooool3o`00
0?oooooo2Oooool000kooooo00?o0000ooooooooool0ooooool@ooooo`003Oooool2o`000?oooooo
4_ooool000kooooo00?o0000ooooooooool0ooooool@ooooo`00oooooolQooooo`00\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-2.49048, -0.0764114, \
0.115739, 0.00624232}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 0.0333333 0 0.618034 [
[.16667 -0.0125 -3 -9 ]
[.16667 -0.0125 3 0 ]
[.33333 -0.0125 -6 -9 ]
[.33333 -0.0125 6 0 ]
[.5 -0.0125 -6 -9 ]
[.5 -0.0125 6 0 ]
[.66667 -0.0125 -6 -9 ]
[.66667 -0.0125 6 0 ]
[.83333 -0.0125 -6 -9 ]
[.83333 -0.0125 6 0 ]
[1 -0.0125 -6 -9 ]
[1 -0.0125 6 0 ]
[-0.0125 .12361 -18 -4.5 ]
[-0.0125 .12361 0 4.5 ]
[-0.0125 .24721 -18 -4.5 ]
[-0.0125 .24721 0 4.5 ]
[-0.0125 .37082 -18 -4.5 ]
[-0.0125 .37082 0 4.5 ]
[-0.0125 .49443 -18 -4.5 ]
[-0.0125 .49443 0 4.5 ]
[-0.0125 .61803 -6 -4.5 ]
[-0.0125 .61803 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.16667 0 m
.16667 .00625 L
s
[(5)] .16667 -0.0125 0 1 Mshowa
.33333 0 m
.33333 .00625 L
s
[(10)] .33333 -0.0125 0 1 Mshowa
.5 0 m
.5 .00625 L
s
[(15)] .5 -0.0125 0 1 Mshowa
.66667 0 m
.66667 .00625 L
s
[(20)] .66667 -0.0125 0 1 Mshowa
.83333 0 m
.83333 .00625 L
s
[(25)] .83333 -0.0125 0 1 Mshowa
1 0 m
1 .00625 L
s
[(30)] 1 -0.0125 0 1 Mshowa
.125 Mabswid
.03333 0 m
.03333 .00375 L
s
.06667 0 m
.06667 .00375 L
s
.1 0 m
.1 .00375 L
s
.13333 0 m
.13333 .00375 L
s
.2 0 m
.2 .00375 L
s
.23333 0 m
.23333 .00375 L
s
.26667 0 m
.26667 .00375 L
s
.3 0 m
.3 .00375 L
s
.36667 0 m
.36667 .00375 L
s
.4 0 m
.4 .00375 L
s
.43333 0 m
.43333 .00375 L
s
.46667 0 m
.46667 .00375 L
s
.53333 0 m
.53333 .00375 L
s
.56667 0 m
.56667 .00375 L
s
.6 0 m
.6 .00375 L
s
.63333 0 m
.63333 .00375 L
s
.7 0 m
.7 .00375 L
s
.73333 0 m
.73333 .00375 L
s
.76667 0 m
.76667 .00375 L
s
.8 0 m
.8 .00375 L
s
.86667 0 m
.86667 .00375 L
s
.9 0 m
.9 .00375 L
s
.93333 0 m
.93333 .00375 L
s
.96667 0 m
.96667 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .12361 m
.00625 .12361 L
s
[(0.2)] -0.0125 .12361 1 0 Mshowa
0 .24721 m
.00625 .24721 L
s
[(0.4)] -0.0125 .24721 1 0 Mshowa
0 .37082 m
.00625 .37082 L
s
[(0.6)] -0.0125 .37082 1 0 Mshowa
0 .49443 m
.00625 .49443 L
s
[(0.8)] -0.0125 .49443 1 0 Mshowa
0 .61803 m
.00625 .61803 L
s
[(1)] -0.0125 .61803 1 0 Mshowa
.125 Mabswid
0 .0309 m
.00375 .0309 L
s
0 .0618 m
.00375 .0618 L
s
0 .09271 m
.00375 .09271 L
s
0 .15451 m
.00375 .15451 L
s
0 .18541 m
.00375 .18541 L
s
0 .21631 m
.00375 .21631 L
s
0 .27812 m
.00375 .27812 L
s
0 .30902 m
.00375 .30902 L
s
0 .33992 m
.00375 .33992 L
s
0 .40172 m
.00375 .40172 L
s
0 .43262 m
.00375 .43262 L
s
0 .46353 m
.00375 .46353 L
s
0 .52533 m
.00375 .52533 L
s
0 .55623 m
.00375 .55623 L
s
0 .58713 m
.00375 .58713 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.03333 .00544 m
.06667 .0066 L
.1 .00779 L
.13333 .00939 L
.16667 .01162 L
.2 .01475 L
.23333 .01916 L
.26667 .02537 L
.3 .03415 L
.33333 .04661 L
.36667 .06439 L
.4 .08988 L
.43333 .12653 L
.46667 .17936 L
.5 .25532 L
.53333 .36272 L
.56667 .43868 L
.6 .4915 L
.63333 .52816 L
.66667 .55364 L
.7 .57142 L
.73333 .58389 L
.76667 .59266 L
.8 .59887 L
.83333 .60328 L
.86667 .60642 L
.9 .60865 L
.93333 .61024 L
.96667 .61143 L
1 .61259 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[26]:=",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/B000`400?l00000o`00003ooooooolQ
ooooo`00?_ooool3o`0002Gooooo0ol00004ooooo`;o00008oooool3o`0000?ooooo0ol0000Qoooo
o`Go00000oooool2o`00027ooooo1Ol00002ooooo`?o00008_ooool3o`0000Cooooo0_l00004oooo
o`00?Oooool01Ol0003ooooooooooooooooo000002Gooooo00?o0000ooooooooool00_ooool01?l0
003oooooooooool0000Sooooo`05o`000?ooooooooooooooool000000oooool00ol0003ooooooooo
o`0Oooooo`04o`000?ooooooooooo`0000;ooooo00Co0000oooooooooooo00008Oooool01_l0003o
ooooooooool0003oooooo`0000?ooooo00?o0000ooooooooool07_ooool01Ol0003ooooooooooooo
oooo000000;ooooo00Co0000oooooooooooo00000oooool0047ooooo00?o0000ooooooooool08ooo
ool00ol0003oooooooooo`02ooooo`04o`000?ooooooooooo`0002?ooooo00?o0000ooooooooool0
1Oooool00ol0003oooooooooo`0Pooooo`03o`000?oooooooooo00;ooooo00Co0000oooooooooooo
00008_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo02;ooooo00Co0000oooooooo
oooo00000_ooool00ol0003oooooooooo`01ooooo`00@Oooool00ol0003oooooooooo`0Sooooo`03
o`000?oooooooooo00;ooooo00Co0000oooooooooooo00008oooool00ol0003oooooooooo`05oooo
o`03o`000?oooooooooo027ooooo00Go0000ooooooooooooooooo`000002ooooo`03o`000?oooooo
oooo027ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`0Pooooo`;o00000oooool0
1?l0003oooooooooool00003ooooo`00?Oooool4o`0002Kooooo00?o0000ooooooooool00_ooool0
1?l0003oooooooooool0000Sooooo`04o`000?ooooooooooooooo`Co00008Oooool01Ol0003ooooo
oooooooooooo000000;ooooo00Co0000oooooooooooo00008?ooool01_l0003ooooooooooooooooo
0000ooooo`Co00009Oooool01?l0003oooooooooool00002ooooo`03o`000?oooooooooo007ooooo
000mooooo`03o`000?oooooooooo02Kooooo0_l00004ooooo`04o`000?ooooooooooo`0002;ooooo
0_l00003ooooo`03o`000?oooooooooo02;ooooo00Go0000ooooooooooooooooo`000002ooooo`04
o`000?ooooooooooo`00023ooooo00Oo0000ooooooooooooooooo`000?oooooo000002Cooooo00Go
0000ooooooooooooooooo`000002ooooo`04o`000?ooooooooooo`0000?ooooo000mooooo`Go0000
9Oooool00ol0003oooooooooo`03ooooo`;o00009?ooool01?l0003oooooooooooooool5o`00027o
oooo0ol00004ooooo`;o00008_ooool3o`0000;ooooo1Ol0000Qooooo`?o00001?ooool2o`0000Co
oooo003oooooob7ooooo003oooooob7ooooo003oooooob7ooooo003oooooob7ooooo000Eoooooooo
00001Ol00007ooooo`005Oooool00ol0003oooooooooo`06ooooo`Go00000oooool00ol0003ooooo
ooooo`06ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01Oooool00ol0003ooooo
ooooo`06ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01Oooool00ol0003ooooo
ooooo`06ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01_ooool00ol0003ooooo
ooooo`06ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01_ooool00ol0003ooooo
ooooo`06ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01_ooool00ol0003ooooo
ooooo`06ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01_ooool00ol0003ooooo
ooooo`05ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01_ooool00ol0003ooooo
ooooo`05ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01_ooool00ol0003ooooo
ooooo`05ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01_ooool00ol0003ooooo
ooooo`05ooooo`03o`000?oooooooooo00Gooooo000Eooooo`03o`000?oooooooooo00_ooooo6_l0
003Sooooo`005Oooool00ol0003oooooooooo`0Uooooo`Wo0000f_ooool001Gooooo00?o0000oooo
ooooool0;_ooool9o`000=7ooooo000Eooooo`03o`000?oooooooooo03Oooooo2?l00039ooooo`00
5Oooool00ol0003oooooooooo`0oooooo`Ko0000`oooool001Gooooo00?o0000ooooooooool0AOoo
ool3o`000<3ooooo000Eooooo`;o0000BOooool3o`000;gooooo000Eooooo`03o`000?oooooooooo
04_ooooo0_l0002kooooo`005Oooool00ol0003oooooooooo`1=ooooo`?o0000^?ooool001Gooooo
00?o0000ooooooooool0D?ooool3o`000;Gooooo000Eooooo`03o`000?oooooooooo05?ooooo0_l0
002cooooo`005Oooool00ol0003oooooooooo`1Eooooo`;o0000/Oooool001Gooooo00?o0000oooo
ooooool0Eoooool3o`000:kooooo000Eooooo`03o`000?oooooooooo05[ooooo0_l0002/ooooo`00
5Oooool2o`0005gooooo0_l0002Zooooo`005Oooool00ol0003oooooooooo`1Nooooo`03o`000?oo
oooooooo0:Oooooo000Eooooo`03o`000?oooooooooo05oooooo00?o0000ooooooooool0Y_ooool0
01Gooooo00?o0000ooooooooool0H?ooool2o`000:Kooooo000Eooooo`03o`000?oooooooooo06;o
oooo00?o0000ooooooooool0Xoooool001Gooooo00?o0000ooooooooool0Hoooool00ol0003ooooo
ooooo`2Rooooo`005Oooool00ol0003oooooooooo`1Tooooo`03o`000?oooooooooo0:7ooooo000E
ooooo`03o`000?oooooooooo06Gooooo00?o0000ooooooooool0X?ooool001Gooooo0_l0001Voooo
o`03o`000?oooooooooo0:3ooooo000Eooooo`03o`000?oooooooooo06Kooooo00?o0000oooooooo
ool0Woooool001Gooooo00?o0000ooooooooool0Ioooool00ol0003oooooooooo`2Nooooo`005Ooo
ool00ol0003oooooooooo`1Xooooo`03o`000?oooooooooo09gooooo000Eooooo`03o`000?oooooo
oooo06Wooooo00?o0000ooooooooool0W?ooool000;ooooo0_l00004ooooo`04o`000?oooooooooo
ooooo`Go00001?ooool00ol0003oooooooooo`1Yooooo`03o`000?oooooooooo09cooooo00001Ooo
oooo0000oooooooooooo000000Sooooo00Co0000oooooooooooo00001?ooool00ol0003ooooooooo
o`1Zooooo`03o`000?oooooooooo09_ooooo00001Ooooooo0000oooooooooooo000000Wooooo00?o
0000ooooooooool01?ooool00ol0003oooooooooo`1[ooooo`03o`000?oooooooooo09[ooooo0000
1Ooooooo0000oooooooooooo000000[ooooo00?o0000ooooooooool00oooool3o`0006cooooo00?o
0000ooooooooool0VOooool00005ooooool0003oooooooooool000001oooool01Ol0003ooooooooo
oooooooo000000Cooooo00?o0000ooooooooool0KOooool00ol0003oooooooooo`2Hooooo`0000Go
ooooo`000?ooooooooooo`000007ooooo`05o`000?ooooooooooooooool000001?ooool00ol0003o
ooooooooo`1]ooooo`03o`000?oooooooooo09Sooooo0002ooooo`;o00002Oooool3o`0000Gooooo
00?o0000ooooooooool0K_ooool00ol0003oooooooooo`2Gooooo`005Oooool00ol0003ooooooooo
o`1_ooooo`03o`000?oooooooooo09Kooooo000Eooooo`03o`000?oooooooooo06oooooo00?o0000
ooooooooool0U_ooool001Gooooo00?o0000ooooooooool0L?ooool00ol0003oooooooooo`2Eoooo
o`005Oooool00ol0003oooooooooo`1aooooo`03o`000?oooooooooo09Cooooo000Eooooo`;o0000
Loooool00ol0003oooooooooo`2Cooooo`005Oooool00ol0003oooooooooo`1booooo`03o`000?oo
oooooooo09?ooooo000Eooooo`03o`000?oooooooooo07?ooooo00?o0000ooooooooool0T_ooool0
01Gooooo00?o0000ooooooooool0M?ooool00ol0003oooooooooo`2Aooooo`005Oooool00ol0003o
ooooooooo`1dooooo`03o`000?oooooooooo097ooooo000Eooooo`03o`000?oooooooooo07Gooooo
00?o0000ooooooooool0T?ooool001Gooooo00?o0000ooooooooool0M_ooool00ol0003ooooooooo
o`2?ooooo`005Oooool00ol0003oooooooooo`1fooooo`03o`000?oooooooooo08oooooo000Eoooo
o`;o0000N?ooool00ol0003oooooooooo`2>ooooo`005Oooool00ol0003oooooooooo`1gooooo`03
o`000?oooooooooo08kooooo000Eooooo`03o`000?oooooooooo07Sooooo00?o0000ooooooooool0
SOooool001Gooooo00?o0000ooooooooool0N?ooool00ol0003oooooooooo`2=ooooo`005Oooool0
0ol0003oooooooooo`1hooooo`03o`000?oooooooooo08gooooo000Eooooo`03o`000?oooooooooo
07Wooooo00?o0000ooooooooool0S?ooool001Gooooo00?o0000ooooooooool0NOooool00ol0003o
ooooooooo`2<ooooo`005Oooool00ol0003oooooooooo`1jooooo`03o`000?oooooooooo08_ooooo
000Eooooo`;o0000Noooool00ol0003oooooooooo`2;ooooo`005Oooool00ol0003oooooooooo`1k
ooooo`03o`000?oooooooooo08[ooooo000Eooooo`03o`000?oooooooooo07_ooooo00?o0000oooo
ooooool0R_ooool001Gooooo00?o0000ooooooooool0O?ooool00ol0003oooooooooo`29ooooo`00
5Oooool00ol0003oooooooooo`1looooo`03o`000?oooooooooo08Wooooo0002ooooo`;o00001?oo
ool00ol0003oooooooooo`03ooooo`?o00001?ooool00ol0003oooooooooo`1mooooo`03o`000?oo
oooooooo08Sooooo00001Ooooooo0000oooooooooooo000000[ooooo00?o0000ooooooooool00ooo
ool00ol0003oooooooooo`1mooooo`03o`000?oooooooooo08Sooooo00001Ooooooo0000oooooooo
oooo000000Oooooo1Ol00004ooooo`03o`000?oooooooooo07gooooo00?o0000ooooooooool0R?oo
ool00005ooooool0003oooooooooool000001oooool01?l0003oooooooooool00005ooooo`?o0000
O_ooool00ol0003oooooooooo`27ooooo`0000Goooooo`000?ooooooooooo`000008ooooo`03o`00
0?oooooo000000Gooooo00?o0000ooooooooool0O_ooool00ol0003oooooooooo`27ooooo`0000Go
ooooo`000?ooooooooooo`000009ooooo`;o00001Oooool00ol0003oooooooooo`1oooooo`03o`00
0?oooooooooo08Kooooo0002ooooo`;o00002oooool00ol0003oooooooooo`03ooooo`03o`000?oo
oooooooo07oooooo00?o0000ooooooooool0Q_ooool001Gooooo00?o0000ooooooooool0Ooooool0
0ol0003oooooooooo`26ooooo`005Oooool00ol0003oooooooooo`20ooooo`03o`000?oooooooooo
08Gooooo000Eooooo`03o`000?oooooooooo083ooooo00?o0000ooooooooool0QOooool001Gooooo
00?o0000ooooooooool0P?ooool00ol0003oooooooooo`25ooooo`005Oooool2o`0008;ooooo00?o
0000ooooooooool0Q?ooool001Gooooo00?o0000ooooooooool0POooool00ol0003oooooooooo`24
ooooo`005Oooool00ol0003oooooooooo`21ooooo`03o`000?oooooooooo08Cooooo000Eooooo`03
o`000?oooooooooo087ooooo00?o0000ooooooooool0Q?ooool001Gooooo00?o0000ooooooooool0
P_ooool00ol0003oooooooooo`23ooooo`005Oooool00ol0003oooooooooo`22ooooo`03o`000?oo
oooooooo08?ooooo000Eooooo`03o`000?oooooooooo08;ooooo00?o0000ooooooooool0Poooool0
01Gooooo00?o0000ooooooooool0Poooool00ol0003oooooooooo`22ooooo`005Oooool2o`0008Co
oooo00?o0000ooooooooool0P_ooool001Gooooo00?o0000ooooooooool0Poooool00ol0003ooooo
ooooo`22ooooo`005Oooool00ol0003oooooooooo`23ooooo`03o`000?oooooooooo08;ooooo000E
ooooo`03o`000?oooooooooo08Cooooo00?o0000ooooooooool0POooool001Gooooo00?o0000oooo
ooooool0Q?ooool00ol0003oooooooooo`21ooooo`005Oooool00ol0003oooooooooo`24ooooo`03
o`000?oooooooooo087ooooo000Eooooo`03o`000?oooooooooo08Gooooo00?o0000ooooooooool0
P?ooool001Gooooo00?o0000ooooooooool0QOooool00ol0003oooooooooo`20ooooo`005Oooool2
o`0008Kooooo00?o0000ooooooooool0P?ooool001Gooooo00?o0000ooooooooool0QOooool00ol0
003oooooooooo`20ooooo`005Oooool00ol0003oooooooooo`26ooooo`03o`000?oooooooooo07oo
oooo000Eooooo`03o`000?oooooooooo08Kooooo00?o0000ooooooooool0Ooooool001Gooooo00?o
0000ooooooooool0Q_ooool00ol0003oooooooooo`1oooooo`000_ooool2o`0000Cooooo00?o0000
ooooooooool00_ooool3o`0000Gooooo00?o0000ooooooooool0Qoooool00ol0003oooooooooo`1n
ooooo`0000Goooooo`000?ooooooooooo`000007ooooo`05o`000?ooooooooooooooool000001?oo
ool00ol0003oooooooooo`27ooooo`03o`000?oooooooooo07kooooo00001Ooooooo0000oooooooo
oooo000000Oooooo00Go0000ooooooooooooooooo`000004ooooo`03o`000?oooooooooo08Oooooo
00?o0000ooooooooool0O_ooool00005ooooool0003oooooooooool000001oooool4o`0000Gooooo
0ol00028ooooo`03o`000?oooooooooo07gooooo00001Ooooooo0000oooooooooooo000000Oooooo
00?o0000ooooooooool01_ooool00ol0003oooooooooo`28ooooo`03o`000?oooooooooo07gooooo
00001Ooooooo0000oooooooooooo000000Sooooo00?o0000ooooooooool01Oooool00ol0003ooooo
ooooo`29ooooo`03o`000?oooooooooo07cooooo0002ooooo`;o00002_ooool2o`0000Gooooo00?o
0000ooooooooool0ROooool00ol0003oooooooooo`1looooo`005Oooool00ol0003oooooooooo`29
ooooo`03o`000?oooooooooo07cooooo000Eooooo`03o`000?oooooooooo08[ooooo00?o0000oooo
ooooool0Noooool001Gooooo00?o0000ooooooooool0R_ooool00ol0003oooooooooo`1kooooo`00
5Oooool00ol0003oooooooooo`2;ooooo`03o`000?oooooooooo07[ooooo000Eooooo`;o0000S?oo
ool00ol0003oooooooooo`1jooooo`005Oooool00ol0003oooooooooo`2<ooooo`03o`000?oooooo
oooo07Wooooo000Eooooo`03o`000?oooooooooo08cooooo00?o0000ooooooooool0NOooool001Go
oooo00?o0000ooooooooool0SOooool00ol0003oooooooooo`1hooooo`005Oooool00ol0003ooooo
ooooo`2=ooooo`03o`000?oooooooooo07Sooooo000Eooooo`03o`000?oooooooooo08kooooo00?o
0000ooooooooool0Moooool001Gooooo00?o0000ooooooooool0S_ooool00ol0003oooooooooo`1g
ooooo`005Oooool00ol0003oooooooooo`2>ooooo`03o`000?oooooooooo07Oooooo000Eooooo`;o
0000T?ooool00ol0003oooooooooo`1fooooo`005Oooool00ol0003oooooooooo`2?ooooo`03o`00
0?oooooooooo07Kooooo000Eooooo`03o`000?oooooooooo093ooooo00?o0000ooooooooool0MOoo
ool001Gooooo00?o0000ooooooooool0T?ooool00ol0003oooooooooo`1eooooo`005Oooool00ol0
003oooooooooo`2Aooooo`03o`000?oooooooooo07Cooooo000Eooooo`03o`000?oooooooooo09;o
oooo00?o0000ooooooooool0Loooool001Gooooo00?o0000ooooooooool0T_ooool00ol0003ooooo
ooooo`1cooooo`005Oooool00ol0003oooooooooo`2Cooooo`03o`000?oooooooooo07;ooooo000E
ooooo`;o0000UOooool00ol0003oooooooooo`1aooooo`005Oooool00ol0003oooooooooo`2Eoooo
o`03o`000?oooooooooo073ooooo000Eooooo`03o`000?oooooooooo09Gooooo00?o0000oooooooo
ool0L?ooool001Gooooo00?o0000ooooooooool0U_ooool00ol0003oooooooooo`1_ooooo`005Ooo
ool00ol0003oooooooooo`2Gooooo`03o`000?oooooooooo06kooooo0002ooooo`;o00001?ooool0
0ol0003oooooooooo`02ooooo`?o00001Oooool00ol0003oooooooooo`2Gooooo`03o`000?oooooo
oooo06kooooo00001Ooooooo0000oooooooooooo000000Oooooo00Go0000ooooooooooooooooo`00
0004ooooo`03o`000?oooooooooo09Sooooo00?o0000ooooooooool0KOooool00005ooooool0003o
ooooooooool000001oooool01Ol0003ooooooooooooooooo000000Cooooo00?o0000ooooooooool0
VOooool00ol0003oooooooooo`1/ooooo`0000Goooooo`000?ooooooooooo`000008ooooo`?o0000
1Oooool3o`0009Wooooo00?o0000ooooooooool0K?ooool00005ooooool0003oooooooooool00000
1oooool01Ol0003ooooooooooooooooo000000Cooooo00?o0000ooooooooool0V_ooool00ol0003o
ooooooooo`1[ooooo`0000Goooooo`000?ooooooooooo`000007ooooo`05o`000?oooooooooooooo
ool000001?ooool00ol0003oooooooooo`2Kooooo`03o`000?oooooooooo06[ooooo0002ooooo`;o
00002Oooool3o`0000Gooooo00?o0000ooooooooool0W?ooool00ol0003oooooooooo`1Yooooo`00
5Oooool00ol0003oooooooooo`2Mooooo`03o`000?oooooooooo06Sooooo000Eooooo`03o`000?oo
oooooooo09gooooo00?o0000ooooooooool0J?ooool001Gooooo00?o0000ooooooooool0W_ooool0
0ol0003oooooooooo`1Wooooo`005Oooool00ol0003oooooooooo`2Oooooo`03o`000?oooooooooo
06Kooooo000Eooooo`;o0000XOooool00ol0003oooooooooo`1Uooooo`005Oooool00ol0003ooooo
ooooo`2Qooooo`;o0000IOooool001Gooooo00?o0000ooooooooool0Xoooool00ol0003ooooooooo
o`1Rooooo`005Oooool00ol0003oooooooooo`2Tooooo`;o0000H_ooool001Gooooo00?o0000oooo
ooooool0Y_ooool00ol0003oooooooooo`1Oooooo`005Oooool00ol0003oooooooooo`2Wooooo`;o
0000Goooool001Gooooo00?o0000ooooooooool0ZOooool00ol0003oooooooooo`1Looooo`005Ooo
ool00ol0003oooooooooo`2Zooooo`;o0000G?ooool001Gooooo0_l0002]ooooo`03o`000?oooooo
oooo05Wooooo000Eooooo`03o`000?oooooooooo0:gooooo0_l0001Iooooo`005Oooool00ol0003o
ooooooooo`2_ooooo`;o0000Eoooool001Gooooo00?o0000ooooooooool0/Oooool00ol0003ooooo
ooooo`1Dooooo`005Oooool00ol0003oooooooooo`2booooo`?o0000Doooool001Gooooo00?o0000
ooooooooool0]Oooool3o`00053ooooo000Eooooo`03o`000?oooooooooo0;Sooooo0ol0001=oooo
o`005Oooool00ol0003oooooooooo`2kooooo`?o0000B_ooool001Gooooo0_l0002oooooo`Go0000
AOooool001Gooooo00?o0000ooooooooool0`oooool4o`00047ooooo000Eooooo`03o`000?oooooo
oooo0<Oooooo1?l0000mooooo`005Oooool00ol0003oooooooooo`3;ooooo`Oo0000=_ooool001Go
oooo00?o0000ooooooooool0d_ooool9o`0002gooooo000=ooooo`?o00001Oooool00ol0003ooooo
ooooo`3Kooooo`So00009Oooool000kooooo00?o0000ooooooooool01?ooool00ol0003ooooooooo
o`3Soooooa[o00002oooool000kooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`3m
ooooo`Co00001oooool000kooooo00?o0000ooooooooool01?ooool3o`000?oooooo2Oooool000ko
oooo00?o0000ooooooooool0ooooool@ooooo`003Oooool2o`000?oooooo4_ooool000kooooo00?o
0000ooooooooool0ooooool@ooooo`00oooooolQooooo`00\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-2.49048, -0.0764114, \
0.115739, 0.00624232}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 0.0333333 0 0.618034 [
[.16667 -0.0125 -3 -9 ]
[.16667 -0.0125 3 0 ]
[.33333 -0.0125 -6 -9 ]
[.33333 -0.0125 6 0 ]
[.5 -0.0125 -6 -9 ]
[.5 -0.0125 6 0 ]
[.66667 -0.0125 -6 -9 ]
[.66667 -0.0125 6 0 ]
[.83333 -0.0125 -6 -9 ]
[.83333 -0.0125 6 0 ]
[1 -0.0125 -6 -9 ]
[1 -0.0125 6 0 ]
[-0.0125 .12361 -18 -4.5 ]
[-0.0125 .12361 0 4.5 ]
[-0.0125 .24721 -18 -4.5 ]
[-0.0125 .24721 0 4.5 ]
[-0.0125 .37082 -18 -4.5 ]
[-0.0125 .37082 0 4.5 ]
[-0.0125 .49443 -18 -4.5 ]
[-0.0125 .49443 0 4.5 ]
[-0.0125 .61803 -6 -4.5 ]
[-0.0125 .61803 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.16667 0 m
.16667 .00625 L
s
[(5)] .16667 -0.0125 0 1 Mshowa
.33333 0 m
.33333 .00625 L
s
[(10)] .33333 -0.0125 0 1 Mshowa
.5 0 m
.5 .00625 L
s
[(15)] .5 -0.0125 0 1 Mshowa
.66667 0 m
.66667 .00625 L
s
[(20)] .66667 -0.0125 0 1 Mshowa
.83333 0 m
.83333 .00625 L
s
[(25)] .83333 -0.0125 0 1 Mshowa
1 0 m
1 .00625 L
s
[(30)] 1 -0.0125 0 1 Mshowa
.125 Mabswid
.03333 0 m
.03333 .00375 L
s
.06667 0 m
.06667 .00375 L
s
.1 0 m
.1 .00375 L
s
.13333 0 m
.13333 .00375 L
s
.2 0 m
.2 .00375 L
s
.23333 0 m
.23333 .00375 L
s
.26667 0 m
.26667 .00375 L
s
.3 0 m
.3 .00375 L
s
.36667 0 m
.36667 .00375 L
s
.4 0 m
.4 .00375 L
s
.43333 0 m
.43333 .00375 L
s
.46667 0 m
.46667 .00375 L
s
.53333 0 m
.53333 .00375 L
s
.56667 0 m
.56667 .00375 L
s
.6 0 m
.6 .00375 L
s
.63333 0 m
.63333 .00375 L
s
.7 0 m
.7 .00375 L
s
.73333 0 m
.73333 .00375 L
s
.76667 0 m
.76667 .00375 L
s
.8 0 m
.8 .00375 L
s
.86667 0 m
.86667 .00375 L
s
.9 0 m
.9 .00375 L
s
.93333 0 m
.93333 .00375 L
s
.96667 0 m
.96667 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .12361 m
.00625 .12361 L
s
[(0.2)] -0.0125 .12361 1 0 Mshowa
0 .24721 m
.00625 .24721 L
s
[(0.4)] -0.0125 .24721 1 0 Mshowa
0 .37082 m
.00625 .37082 L
s
[(0.6)] -0.0125 .37082 1 0 Mshowa
0 .49443 m
.00625 .49443 L
s
[(0.8)] -0.0125 .49443 1 0 Mshowa
0 .61803 m
.00625 .61803 L
s
[(1)] -0.0125 .61803 1 0 Mshowa
.125 Mabswid
0 .0309 m
.00375 .0309 L
s
0 .0618 m
.00375 .0618 L
s
0 .09271 m
.00375 .09271 L
s
0 .15451 m
.00375 .15451 L
s
0 .18541 m
.00375 .18541 L
s
0 .21631 m
.00375 .21631 L
s
0 .27812 m
.00375 .27812 L
s
0 .30902 m
.00375 .30902 L
s
0 .33992 m
.00375 .33992 L
s
0 .40172 m
.00375 .40172 L
s
0 .43262 m
.00375 .43262 L
s
0 .46353 m
.00375 .46353 L
s
0 .52533 m
.00375 .52533 L
s
0 .55623 m
.00375 .55623 L
s
0 .58713 m
.00375 .58713 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.03333 .00051 m
.06667 .00066 L
.1 .00087 L
.13333 .0012 L
.16667 .00173 L
.2 .00257 L
.23333 .00393 L
.26667 .00614 L
.3 .00978 L
.33333 .01583 L
.36667 .02599 L
.4 .04329 L
.43333 .07322 L
.46667 .12609 L
.5 .222 L
.53333 .39604 L
.56667 .49194 L
.6 .54482 L
.63333 .57474 L
.66667 .59204 L
.7 .60221 L
.73333 .60825 L
.76667 .61189 L
.8 .61411 L
.83333 .61546 L
.86667 .61631 L
.9 .61683 L
.93333 .61716 L
.96667 .61737 L
1 .61752 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[26]:=",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/B000`400?l00000o`00003ooooooolQ
ooooo`00?_ooool3o`0002Gooooo0ol00004ooooo`;o00008oooool3o`0000?ooooo0ol0000Qoooo
o`Go00000oooool2o`00027ooooo1Ol00002ooooo`?o00008_ooool3o`0000Cooooo0_l00004oooo
o`00?Oooool01Ol0003ooooooooooooooooo000002Gooooo00?o0000ooooooooool00_ooool01?l0
003oooooooooool0000Sooooo`05o`000?ooooooooooooooool000000oooool00ol0003ooooooooo
o`0Oooooo`04o`000?ooooooooooo`0000;ooooo00Co0000oooooooooooo00008Oooool01_l0003o
ooooooooool0003oooooo`0000?ooooo00?o0000ooooooooool07_ooool01Ol0003ooooooooooooo
oooo000000;ooooo00Co0000oooooooooooo00000oooool0047ooooo00?o0000ooooooooool08ooo
ool00ol0003oooooooooo`02ooooo`04o`000?ooooooooooo`0002?ooooo00?o0000ooooooooool0
1Oooool00ol0003oooooooooo`0Pooooo`03o`000?oooooooooo00;ooooo00Co0000oooooooooooo
00008_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo02;ooooo00Co0000oooooooo
oooo00000_ooool00ol0003oooooooooo`01ooooo`00@Oooool00ol0003oooooooooo`0Sooooo`03
o`000?oooooooooo00;ooooo00Co0000oooooooooooo00008oooool00ol0003oooooooooo`05oooo
o`03o`000?oooooooooo027ooooo00Go0000ooooooooooooooooo`000002ooooo`03o`000?oooooo
oooo027ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`0Pooooo`;o00000oooool0
1?l0003oooooooooool00003ooooo`00?Oooool4o`0002Kooooo00?o0000ooooooooool00_ooool0
1?l0003oooooooooool0000Sooooo`04o`000?ooooooooooooooo`Co00008Oooool01Ol0003ooooo
oooooooooooo000000;ooooo00Co0000oooooooooooo00008?ooool01_l0003ooooooooooooooooo
0000ooooo`Co00009Oooool01?l0003oooooooooool00002ooooo`03o`000?oooooooooo007ooooo
000mooooo`03o`000?oooooooooo02Kooooo0_l00004ooooo`04o`000?ooooooooooo`0002;ooooo
0_l00003ooooo`03o`000?oooooooooo02;ooooo00Go0000ooooooooooooooooo`000002ooooo`04
o`000?ooooooooooo`00023ooooo00Oo0000ooooooooooooooooo`000?oooooo000002Cooooo00Go
0000ooooooooooooooooo`000002ooooo`04o`000?ooooooooooo`0000?ooooo000mooooo`Go0000
9Oooool00ol0003oooooooooo`03ooooo`;o00009?ooool01?l0003oooooooooooooool5o`00027o
oooo0ol00004ooooo`;o00008_ooool3o`0000;ooooo1Ol0000Qooooo`?o00001?ooool2o`0000Co
oooo003oooooob7ooooo003oooooob7ooooo003oooooob7ooooo003oooooob7ooooo000Eoooooooo
00001Ol00007ooooo`005Oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Gooooo
00?o0000ooooooooool01_ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Gooooo
00?o0000ooooooooool01_ooool00ol0003oooooooooo`03oooooa7o00000oooool00ol0003ooooo
ooooo`05ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01_ooool00ol0003ooooo
ooooo`05ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01_ooool00ol0003ooooo
ooooo`05ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01_ooool00ol0003ooooo
ooooo`05ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01Oooool00ol0003ooooo
ooooo`06ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01Oooool00ol0003ooooo
ooooo`06ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01Oooool00ol0003ooooo
ooooo`06ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01Oooool00ol0003ooooo
ooooo`05ooooo`005Oooool00ol0003oooooooooo`18ooooo`Ko0000^_ooool001Gooooo00?o0000
ooooooooool0C_ooool4o`000;Kooooo000Eooooo`03o`000?oooooooooo05;ooooo1?l0002boooo
o`005Oooool00ol0003oooooooooo`1Fooooo`?o0000[oooool001Gooooo00?o0000ooooooooool0
FOooool3o`000:cooooo000Eooooo`03o`000?oooooooooo05cooooo0_l0002Zooooo`005Oooool2
o`0005oooooo0_l0002Xooooo`005Oooool00ol0003oooooooooo`1Pooooo`?o0000YOooool001Go
oooo00?o0000ooooooooool0Hoooool2o`000:?ooooo000Eooooo`03o`000?oooooooooo06Gooooo
00?o0000ooooooooool0X?ooool001Gooooo00?o0000ooooooooool0I_ooool00ol0003ooooooooo
o`2Oooooo`005Oooool00ol0003oooooooooo`1Wooooo`03o`000?oooooooooo09kooooo000Eoooo
o`03o`000?oooooooooo06Sooooo00?o0000ooooooooool0WOooool001Gooooo00?o0000oooooooo
ool0JOooool00ol0003oooooooooo`2Looooo`005Oooool2o`0006_ooooo00?o0000ooooooooool0
Voooool001Gooooo00?o0000ooooooooool0Joooool00ol0003oooooooooo`2Jooooo`005Oooool0
0ol0003oooooooooo`1/ooooo`03o`000?oooooooooo09Wooooo000Eooooo`03o`000?oooooooooo
06gooooo00?o0000ooooooooool0V?ooool001Gooooo00?o0000ooooooooool0KOooool00ol0003o
ooooooooo`2Hooooo`005Oooool00ol0003oooooooooo`1^ooooo`03o`000?oooooooooo09Oooooo
000Eooooo`03o`000?oooooooooo06oooooo00?o0000ooooooooool0U_ooool001Gooooo00?o0000
ooooooooool0Koooool00ol0003oooooooooo`2Fooooo`005Oooool2o`00077ooooo00?o0000oooo
ooooool0UOooool001Gooooo00?o0000ooooooooool0LOooool00ol0003oooooooooo`2Dooooo`00
5Oooool00ol0003oooooooooo`1booooo`03o`000?oooooooooo09?ooooo000Eooooo`03o`000?oo
oooooooo07;ooooo00?o0000ooooooooool0Toooool001Gooooo00?o0000ooooooooool0Loooool0
0ol0003oooooooooo`2Booooo`000_ooool2o`0000Cooooo00Co0000oooooooooooooooo1Ol00004
ooooo`03o`000?oooooooooo07Cooooo00?o0000ooooooooool0TOooool00005ooooool0003ooooo
ooooool000002?ooool01?l0003oooooooooool00004ooooo`03o`000?oooooooooo07Cooooo00?o
0000ooooooooool0TOooool00005ooooool0003oooooooooool000002Oooool00ol0003ooooooooo
o`04ooooo`03o`000?oooooooooo07Gooooo00?o0000ooooooooool0T?ooool00005ooooool0003o
ooooooooool000002_ooool00ol0003oooooooooo`03ooooo`?o0000M_ooool00ol0003ooooooooo
o`2?ooooo`0000Goooooo`000?ooooooooooo`000007ooooo`05o`000?ooooooooooooooool00000
1?ooool00ol0003oooooooooo`1fooooo`03o`000?oooooooooo08oooooo00001Ooooooo0000oooo
oooooooo000000Oooooo00Go0000ooooooooooooooooo`000004ooooo`03o`000?oooooooooo07Oo
oooo00?o0000ooooooooool0S_ooool000;ooooo0_l00009ooooo`?o00001Oooool00ol0003ooooo
ooooo`1gooooo`03o`000?oooooooooo08kooooo000Eooooo`03o`000?oooooooooo07Oooooo00?o
0000ooooooooool0S_ooool001Gooooo00?o0000ooooooooool0N?ooool00ol0003oooooooooo`2=
ooooo`005Oooool00ol0003oooooooooo`1hooooo`03o`000?oooooooooo08gooooo000Eooooo`03
o`000?oooooooooo07Sooooo00?o0000ooooooooool0SOooool001Gooooo0_l0001jooooo`03o`00
0?oooooooooo08cooooo000Eooooo`03o`000?oooooooooo07Wooooo00?o0000ooooooooool0S?oo
ool001Gooooo00?o0000ooooooooool0NOooool00ol0003oooooooooo`2<ooooo`005Oooool00ol0
003oooooooooo`1jooooo`03o`000?oooooooooo08_ooooo000Eooooo`03o`000?oooooooooo07[o
oooo00?o0000ooooooooool0Roooool001Gooooo00?o0000ooooooooool0Noooool00ol0003ooooo
ooooo`2:ooooo`005Oooool00ol0003oooooooooo`1kooooo`03o`000?oooooooooo08[ooooo000E
ooooo`03o`000?oooooooooo07_ooooo00?o0000ooooooooool0R_ooool001Gooooo0_l0001moooo
o`03o`000?oooooooooo08Wooooo000Eooooo`03o`000?oooooooooo07cooooo00?o0000oooooooo
ool0ROooool001Gooooo00?o0000ooooooooool0O?ooool00ol0003oooooooooo`29ooooo`005Ooo
ool00ol0003oooooooooo`1mooooo`03o`000?oooooooooo08Sooooo000Eooooo`03o`000?oooooo
oooo07gooooo00?o0000ooooooooool0R?ooool001Gooooo00?o0000ooooooooool0OOooool00ol0
003oooooooooo`28ooooo`005Oooool00ol0003oooooooooo`1nooooo`03o`000?oooooooooo08Oo
oooo000Eooooo`03o`000?oooooooooo07kooooo00?o0000ooooooooool0Qoooool001Gooooo0_l0
001oooooo`03o`000?oooooooooo08Oooooo000Eooooo`03o`000?oooooooooo07oooooo00?o0000
ooooooooool0Q_ooool001Gooooo00?o0000ooooooooool0Ooooool00ol0003oooooooooo`26oooo
o`005Oooool00ol0003oooooooooo`1oooooo`03o`000?oooooooooo08Kooooo000Eooooo`03o`00
0?oooooooooo07oooooo00?o0000ooooooooool0Q_ooool000;ooooo0_l00004ooooo`03o`000?oo
oooooooo00?ooooo0ol00004ooooo`03o`000?oooooooooo083ooooo00?o0000ooooooooool0QOoo
ool00005ooooool0003oooooooooool000002_ooool00ol0003oooooooooo`03ooooo`03o`000?oo
oooooooo083ooooo00?o0000ooooooooool0QOooool00005ooooool0003oooooooooool000001ooo
ool5o`0000Cooooo00?o0000ooooooooool0P?ooool00ol0003oooooooooo`25ooooo`0000Gooooo
o`000?ooooooooooo`000007ooooo`04o`000?ooooooooooo`0000Gooooo0ol00020ooooo`03o`00
0?oooooooooo08Gooooo00001Ooooooo0000oooooooooooo000000Sooooo00?o0000ooooool00000
1Oooool00ol0003oooooooooo`20ooooo`03o`000?oooooooooo08Gooooo00001Ooooooo0000oooo
oooooooo000000Wooooo0_l00005ooooo`03o`000?oooooooooo087ooooo00?o0000ooooooooool0
Q?ooool000;ooooo0_l0000;ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0POoo
ool00ol0003oooooooooo`24ooooo`005Oooool00ol0003oooooooooo`21ooooo`03o`000?oooooo
oooo08Cooooo000Eooooo`03o`000?oooooooooo087ooooo00?o0000ooooooooool0Q?ooool001Go
oooo00?o0000ooooooooool0POooool00ol0003oooooooooo`24ooooo`005Oooool00ol0003ooooo
ooooo`21ooooo`03o`000?oooooooooo08Cooooo000Eooooo`;o0000Poooool00ol0003ooooooooo
o`23ooooo`005Oooool00ol0003oooooooooo`22ooooo`03o`000?oooooooooo08?ooooo000Eoooo
o`03o`000?oooooooooo08;ooooo00?o0000ooooooooool0Poooool001Gooooo00?o0000oooooooo
ool0P_ooool00ol0003oooooooooo`23ooooo`005Oooool00ol0003oooooooooo`22ooooo`03o`00
0?oooooooooo08?ooooo000Eooooo`03o`000?oooooooooo08;ooooo00?o0000ooooooooool0Pooo
ool001Gooooo00?o0000ooooooooool0Poooool00ol0003oooooooooo`22ooooo`005Oooool00ol0
003oooooooooo`23ooooo`03o`000?oooooooooo08;ooooo000Eooooo`;o0000Q?ooool00ol0003o
ooooooooo`22ooooo`005Oooool00ol0003oooooooooo`23ooooo`03o`000?oooooooooo08;ooooo
000Eooooo`03o`000?oooooooooo08?ooooo00?o0000ooooooooool0P_ooool001Gooooo00?o0000
ooooooooool0Q?ooool00ol0003oooooooooo`21ooooo`005Oooool00ol0003oooooooooo`24oooo
o`03o`000?oooooooooo087ooooo000Eooooo`03o`000?oooooooooo08Cooooo00?o0000oooooooo
ool0POooool001Gooooo00?o0000ooooooooool0Q?ooool00ol0003oooooooooo`21ooooo`005Ooo
ool00ol0003oooooooooo`24ooooo`03o`000?oooooooooo087ooooo000Eooooo`;o0000QOooool0
0ol0003oooooooooo`21ooooo`005Oooool00ol0003oooooooooo`25ooooo`03o`000?oooooooooo
083ooooo000Eooooo`03o`000?oooooooooo08Gooooo00?o0000ooooooooool0P?ooool001Gooooo
00?o0000ooooooooool0QOooool00ol0003oooooooooo`20ooooo`005Oooool00ol0003ooooooooo
o`25ooooo`03o`000?oooooooooo083ooooo0002ooooo`;o00001?ooool00ol0003oooooooooo`02
ooooo`?o00001Oooool00ol0003oooooooooo`25ooooo`03o`000?oooooooooo083ooooo00001Ooo
oooo0000oooooooooooo000000Oooooo00Go0000ooooooooooooooooo`000004ooooo`03o`000?oo
oooooooo08Gooooo00?o0000ooooooooool0P?ooool00005ooooool0003oooooooooool000001ooo
ool01Ol0003ooooooooooooooooo000000Cooooo00?o0000ooooooooool0Q_ooool00ol0003ooooo
ooooo`1oooooo`0000Goooooo`000?ooooooooooo`000007ooooo`Co00001Oooool3o`0008Kooooo
00?o0000ooooooooool0Ooooool00005ooooool0003oooooooooool000001oooool00ol0003ooooo
ooooo`06ooooo`03o`000?oooooooooo08Kooooo00?o0000ooooooooool0Ooooool00005ooooool0
003oooooooooool000002?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo08Kooooo
00?o0000ooooooooool0Ooooool000;ooooo0_l0000:ooooo`;o00001Oooool00ol0003ooooooooo
o`26ooooo`03o`000?oooooooooo07oooooo000Eooooo`03o`000?oooooooooo08Oooooo00?o0000
ooooooooool0O_ooool001Gooooo00?o0000ooooooooool0Qoooool00ol0003oooooooooo`1noooo
o`005Oooool00ol0003oooooooooo`27ooooo`03o`000?oooooooooo07kooooo000Eooooo`03o`00
0?oooooooooo08Oooooo00?o0000ooooooooool0O_ooool001Gooooo0_l00029ooooo`03o`000?oo
oooooooo07gooooo000Eooooo`03o`000?oooooooooo08Sooooo00?o0000ooooooooool0OOooool0
01Gooooo00?o0000ooooooooool0R?ooool00ol0003oooooooooo`1mooooo`005Oooool00ol0003o
ooooooooo`29ooooo`03o`000?oooooooooo07cooooo000Eooooo`03o`000?oooooooooo08Wooooo
00?o0000ooooooooool0O?ooool001Gooooo00?o0000ooooooooool0ROooool00ol0003ooooooooo
o`1looooo`005Oooool00ol0003oooooooooo`2:ooooo`03o`000?oooooooooo07_ooooo000Eoooo
o`03o`000?oooooooooo08[ooooo00?o0000ooooooooool0Noooool001Gooooo0_l0002;ooooo`03
o`000?oooooooooo07_ooooo000Eooooo`03o`000?oooooooooo08_ooooo00?o0000ooooooooool0
N_ooool001Gooooo00?o0000ooooooooool0Roooool00ol0003oooooooooo`1jooooo`005Oooool0
0ol0003oooooooooo`2<ooooo`03o`000?oooooooooo07Wooooo000Eooooo`03o`000?oooooooooo
08cooooo00?o0000ooooooooool0NOooool001Gooooo00?o0000ooooooooool0S?ooool00ol0003o
ooooooooo`1iooooo`005Oooool00ol0003oooooooooo`2=ooooo`03o`000?oooooooooo07Sooooo
000Eooooo`03o`000?oooooooooo08gooooo00?o0000ooooooooool0N?ooool001Gooooo0_l0002>
ooooo`03o`000?oooooooooo07Sooooo000Eooooo`03o`000?oooooooooo08kooooo00?o0000oooo
ooooool0Moooool001Gooooo00?o0000ooooooooool0S_ooool00ol0003oooooooooo`1gooooo`00
5Oooool00ol0003oooooooooo`2>ooooo`03o`000?oooooooooo07Oooooo000Eooooo`03o`000?oo
oooooooo08oooooo00?o0000ooooooooool0M_ooool000;ooooo0_l00004ooooo`03o`000?oooooo
oooo00;ooooo0ol00005ooooo`03o`000?oooooooooo08oooooo00?o0000ooooooooool0M_ooool0
0005ooooool0003oooooooooool000001oooool01Ol0003ooooooooooooooooo000000Cooooo00?o
0000ooooooooool0Soooool00ol0003oooooooooo`1fooooo`0000Goooooo`000?ooooooooooo`00
0007ooooo`05o`000?ooooooooooooooool000001?ooool00ol0003oooooooooo`2@ooooo`03o`00
0?oooooooooo07Gooooo00001Ooooooo0000oooooooooooo000000Sooooo0ol00005ooooo`?o0000
T?ooool00ol0003oooooooooo`1eooooo`0000Goooooo`000?ooooooooooo`000007ooooo`05o`00
0?ooooooooooooooool000001?ooool00ol0003oooooooooo`2Aooooo`03o`000?oooooooooo07Co
oooo00001Ooooooo0000oooooooooooo000000Oooooo00Go0000ooooooooooooooooo`000004oooo
o`03o`000?oooooooooo09;ooooo00?o0000ooooooooool0Loooool000;ooooo0_l00009ooooo`?o
00001Oooool00ol0003oooooooooo`2Booooo`03o`000?oooooooooo07?ooooo000Eooooo`03o`00
0?oooooooooo09?ooooo00?o0000ooooooooool0L_ooool001Gooooo00?o0000ooooooooool0U?oo
ool00ol0003oooooooooo`1aooooo`005Oooool00ol0003oooooooooo`2Dooooo`03o`000?oooooo
oooo077ooooo000Eooooo`03o`000?oooooooooo09Gooooo00?o0000ooooooooool0L?ooool001Go
oooo0_l0002Fooooo`03o`000?oooooooooo073ooooo000Eooooo`03o`000?oooooooooo09Kooooo
00?o0000ooooooooool0Koooool001Gooooo00?o0000ooooooooool0Uoooool00ol0003ooooooooo
o`1^ooooo`005Oooool00ol0003oooooooooo`2Gooooo`03o`000?oooooooooo06kooooo000Eoooo
o`03o`000?oooooooooo09Sooooo00?o0000ooooooooool0KOooool001Gooooo00?o0000oooooooo
ool0VOooool00ol0003oooooooooo`1/ooooo`005Oooool00ol0003oooooooooo`2Jooooo`03o`00
0?oooooooooo06_ooooo000Eooooo`03o`000?oooooooooo09_ooooo00?o0000ooooooooool0J_oo
ool001Gooooo0_l0002Mooooo`03o`000?oooooooooo06Wooooo000Eooooo`03o`000?oooooooooo
09gooooo00?o0000ooooooooool0J?ooool001Gooooo00?o0000ooooooooool0W_ooool00ol0003o
ooooooooo`1Wooooo`005Oooool00ol0003oooooooooo`2Oooooo`03o`000?oooooooooo06Kooooo
000Eooooo`03o`000?oooooooooo0:3ooooo00?o0000ooooooooool0IOooool001Gooooo00?o0000
ooooooooool0XOooool2o`0006Gooooo000Eooooo`03o`000?oooooooooo0:?ooooo0_l0001Soooo
o`005Oooool00ol0003oooooooooo`2Uooooo`?o0000H?ooool001Gooooo0_l0002Yooooo`;o0000
G_ooool001Gooooo00?o0000ooooooooool0Z_ooool2o`0005cooooo000Eooooo`03o`000?oooooo
oooo0:cooooo0ol0001Iooooo`005Oooool00ol0003oooooooooo`2_ooooo`?o0000E_ooool001Go
oooo00?o0000ooooooooool0/_ooool6o`00053ooooo000=ooooo`?o00001Oooool00ol0003ooooo
ooooo`2hooooo`Wo0000Aoooool000kooooo00?o0000ooooooooool01?ooool00ol0003ooooooooo
o`31ooooo`So0000?oooool000kooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`39
oooooa;o0000;Oooool000kooooo00?o0000ooooooooool01?ooool3o`000=_ooooo9_l00007oooo
o`003_ooool00ol0003oooooooooo`3ooooooa3ooooo000=ooooo`;o0000oooooolBooooo`003_oo
ool00ol0003oooooooooo`3ooooooa3ooooo003oooooob7ooooo0000\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-2.49048, -0.0764114, \
0.115739, 0.00624232}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 0.0333333 0 0.618034 [
[.16667 -0.0125 -3 -9 ]
[.16667 -0.0125 3 0 ]
[.33333 -0.0125 -6 -9 ]
[.33333 -0.0125 6 0 ]
[.5 -0.0125 -6 -9 ]
[.5 -0.0125 6 0 ]
[.66667 -0.0125 -6 -9 ]
[.66667 -0.0125 6 0 ]
[.83333 -0.0125 -6 -9 ]
[.83333 -0.0125 6 0 ]
[1 -0.0125 -6 -9 ]
[1 -0.0125 6 0 ]
[-0.0125 .12361 -18 -4.5 ]
[-0.0125 .12361 0 4.5 ]
[-0.0125 .24721 -18 -4.5 ]
[-0.0125 .24721 0 4.5 ]
[-0.0125 .37082 -18 -4.5 ]
[-0.0125 .37082 0 4.5 ]
[-0.0125 .49443 -18 -4.5 ]
[-0.0125 .49443 0 4.5 ]
[-0.0125 .61803 -6 -4.5 ]
[-0.0125 .61803 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.16667 0 m
.16667 .00625 L
s
[(5)] .16667 -0.0125 0 1 Mshowa
.33333 0 m
.33333 .00625 L
s
[(10)] .33333 -0.0125 0 1 Mshowa
.5 0 m
.5 .00625 L
s
[(15)] .5 -0.0125 0 1 Mshowa
.66667 0 m
.66667 .00625 L
s
[(20)] .66667 -0.0125 0 1 Mshowa
.83333 0 m
.83333 .00625 L
s
[(25)] .83333 -0.0125 0 1 Mshowa
1 0 m
1 .00625 L
s
[(30)] 1 -0.0125 0 1 Mshowa
.125 Mabswid
.03333 0 m
.03333 .00375 L
s
.06667 0 m
.06667 .00375 L
s
.1 0 m
.1 .00375 L
s
.13333 0 m
.13333 .00375 L
s
.2 0 m
.2 .00375 L
s
.23333 0 m
.23333 .00375 L
s
.26667 0 m
.26667 .00375 L
s
.3 0 m
.3 .00375 L
s
.36667 0 m
.36667 .00375 L
s
.4 0 m
.4 .00375 L
s
.43333 0 m
.43333 .00375 L
s
.46667 0 m
.46667 .00375 L
s
.53333 0 m
.53333 .00375 L
s
.56667 0 m
.56667 .00375 L
s
.6 0 m
.6 .00375 L
s
.63333 0 m
.63333 .00375 L
s
.7 0 m
.7 .00375 L
s
.73333 0 m
.73333 .00375 L
s
.76667 0 m
.76667 .00375 L
s
.8 0 m
.8 .00375 L
s
.86667 0 m
.86667 .00375 L
s
.9 0 m
.9 .00375 L
s
.93333 0 m
.93333 .00375 L
s
.96667 0 m
.96667 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .12361 m
.00625 .12361 L
s
[(0.2)] -0.0125 .12361 1 0 Mshowa
0 .24721 m
.00625 .24721 L
s
[(0.4)] -0.0125 .24721 1 0 Mshowa
0 .37082 m
.00625 .37082 L
s
[(0.6)] -0.0125 .37082 1 0 Mshowa
0 .49443 m
.00625 .49443 L
s
[(0.8)] -0.0125 .49443 1 0 Mshowa
0 .61803 m
.00625 .61803 L
s
[(1)] -0.0125 .61803 1 0 Mshowa
.125 Mabswid
0 .0309 m
.00375 .0309 L
s
0 .0618 m
.00375 .0618 L
s
0 .09271 m
.00375 .09271 L
s
0 .15451 m
.00375 .15451 L
s
0 .18541 m
.00375 .18541 L
s
0 .21631 m
.00375 .21631 L
s
0 .27812 m
.00375 .27812 L
s
0 .30902 m
.00375 .30902 L
s
0 .33992 m
.00375 .33992 L
s
0 .40172 m
.00375 .40172 L
s
0 .43262 m
.00375 .43262 L
s
0 .46353 m
.00375 .46353 L
s
0 .52533 m
.00375 .52533 L
s
0 .55623 m
.00375 .55623 L
s
0 .58713 m
.00375 .58713 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.03333 8e-05 m
.06667 .00011 L
.1 .00016 L
.13333 .00024 L
.16667 .00039 L
.2 .00066 L
.23333 .00114 L
.26667 .00201 L
.3 .00363 L
.33333 .00665 L
.36667 .01237 L
.4 .02342 L
.43333 .04528 L
.46667 .09045 L
.5 .19084 L
.53333 .4272 L
.56667 .52758 L
.6 .57276 L
.63333 .59461 L
.66667 .60566 L
.7 .61139 L
.73333 .61441 L
.76667 .61602 L
.8 .6169 L
.83333 .61737 L
.86667 .61764 L
.9 .61779 L
.93333 .61788 L
.96667 .61792 L
1 .61796 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[26]:=",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/B000`400?l00000o`00003ooooooolQ
ooooo`00?_ooool3o`0002Gooooo0ol00004ooooo`;o00008oooool3o`0000?ooooo0ol0000Qoooo
o`Go00000oooool2o`00027ooooo1Ol00002ooooo`?o00008_ooool3o`0000Cooooo0_l00004oooo
o`00?Oooool01Ol0003ooooooooooooooooo000002Gooooo00?o0000ooooooooool00_ooool01?l0
003oooooooooool0000Sooooo`05o`000?ooooooooooooooool000000oooool00ol0003ooooooooo
o`0Oooooo`04o`000?ooooooooooo`0000;ooooo00Co0000oooooooooooo00008Oooool01_l0003o
ooooooooool0003oooooo`0000?ooooo00?o0000ooooooooool07_ooool01Ol0003ooooooooooooo
oooo000000;ooooo00Co0000oooooooooooo00000oooool0047ooooo00?o0000ooooooooool08ooo
ool00ol0003oooooooooo`02ooooo`04o`000?ooooooooooo`0002?ooooo00?o0000ooooooooool0
1Oooool00ol0003oooooooooo`0Pooooo`03o`000?oooooooooo00;ooooo00Co0000oooooooooooo
00008_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo02;ooooo00Co0000oooooooo
oooo00000_ooool00ol0003oooooooooo`01ooooo`00@Oooool00ol0003oooooooooo`0Sooooo`03
o`000?oooooooooo00;ooooo00Co0000oooooooooooo00008oooool00ol0003oooooooooo`05oooo
o`03o`000?oooooooooo027ooooo00Go0000ooooooooooooooooo`000002ooooo`03o`000?oooooo
oooo027ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`0Pooooo`;o00000oooool0
1?l0003oooooooooool00003ooooo`00?Oooool4o`0002Kooooo00?o0000ooooooooool00_ooool0
1?l0003oooooooooool0000Sooooo`04o`000?ooooooooooooooo`Co00008Oooool01Ol0003ooooo
oooooooooooo000000;ooooo00Co0000oooooooooooo00008?ooool01_l0003ooooooooooooooooo
0000ooooo`Co00009Oooool01?l0003oooooooooool00002ooooo`03o`000?oooooooooo007ooooo
000mooooo`03o`000?oooooooooo02Kooooo0_l00004ooooo`04o`000?ooooooooooo`0002;ooooo
0_l00003ooooo`03o`000?oooooooooo02;ooooo00Go0000ooooooooooooooooo`000002ooooo`04
o`000?ooooooooooo`00023ooooo00Oo0000ooooooooooooooooo`000?oooooo000002Cooooo00Go
0000ooooooooooooooooo`000002ooooo`04o`000?ooooooooooo`0000?ooooo000mooooo`Go0000
9Oooool00ol0003oooooooooo`03ooooo`;o00009?ooool01?l0003oooooooooooooool5o`00027o
oooo0ol00004ooooo`;o00008_ooool3o`0000;ooooo1Ol0000Qooooo`?o00001?ooool2o`0000Co
oooo003oooooob7ooooo003oooooob7ooooo003oooooob7ooooo003oooooob7ooooo000Eoooooooo
00001Ol00007ooooo`005Oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Gooooo
00?o0000ooooooooool01_ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Gooooo
00?o0000ooooooooool01_ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Gooooo
00?o0000ooooooooool00oooool8o`0000?ooooo00?o0000ooooooooool01_ooool00ol0003ooooo
ooooo`06ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01_ooool00ol0003ooooo
ooooo`06ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01_ooool00ol0003ooooo
ooooo`06ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01_ooool00ol0003ooooo
ooooo`05ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01_ooool00ol0003ooooo
ooooo`05ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01_ooool00ol0003ooooo
ooooo`05ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01_ooool00ol0003ooooo
ooooo`05ooooo`03o`000?oooooooooo00Gooooo000Eooooo`03o`000?oooooooooo053ooooo2Ol0
002_ooooo`005Oooool00ol0003oooooooooo`1Iooooo`Ko0000ZOooool001Gooooo00?o0000oooo
ooooool0Goooool3o`000:Kooooo000Eooooo`03o`000?oooooooooo06;ooooo0ol0002Sooooo`00
5Oooool00ol0003oooooooooo`1Uooooo`;o0000XOooool001Gooooo00?o0000ooooooooool0Iooo
ool00ol0003oooooooooo`2Nooooo`005Oooool2o`0006Wooooo00?o0000ooooooooool0WOooool0
01Gooooo00?o0000ooooooooool0JOooool2o`0009gooooo000Eooooo`03o`000?oooooooooo06_o
oooo00?o0000ooooooooool0V_ooool001Gooooo00?o0000ooooooooool0K?ooool00ol0003ooooo
ooooo`2Iooooo`005Oooool00ol0003oooooooooo`1]ooooo`03o`000?oooooooooo09Sooooo000E
ooooo`03o`000?oooooooooo06gooooo00?o0000ooooooooool0V?ooool001Gooooo00?o0000oooo
ooooool0K_ooool00ol0003oooooooooo`2Gooooo`005Oooool00ol0003oooooooooo`1_ooooo`03
o`000?oooooooooo09Kooooo000Eooooo`;o0000LOooool00ol0003oooooooooo`2Eooooo`005Ooo
ool00ol0003oooooooooo`1aooooo`03o`000?oooooooooo09Cooooo000Eooooo`03o`000?oooooo
oooo07;ooooo00?o0000ooooooooool0Toooool001Gooooo00?o0000ooooooooool0L_ooool00ol0
003oooooooooo`2Cooooo`005Oooool00ol0003oooooooooo`1cooooo`03o`000?oooooooooo09;o
oooo000Eooooo`03o`000?oooooooooo07Cooooo00?o0000ooooooooool0TOooool001Gooooo00?o
0000ooooooooool0MOooool00ol0003oooooooooo`2@ooooo`005Oooool00ol0003oooooooooo`1f
ooooo`03o`000?oooooooooo08oooooo000Eooooo`;o0000Moooool00ol0003oooooooooo`2?oooo
o`005Oooool00ol0003oooooooooo`1gooooo`03o`000?oooooooooo08kooooo000Eooooo`03o`00
0?oooooooooo07Oooooo00?o0000ooooooooool0S_ooool001Gooooo00?o0000ooooooooool0Mooo
ool00ol0003oooooooooo`2>ooooo`005Oooool00ol0003oooooooooo`1hooooo`03o`000?oooooo
oooo08gooooo0002ooooo`;o00001?ooool01?l0003oooooooooooooool5o`0000Cooooo00?o0000
ooooooooool0N?ooool00ol0003oooooooooo`2=ooooo`0000Goooooo`000?ooooooooooo`000008
ooooo`04o`000?ooooooooooo`0000Cooooo00?o0000ooooooooool0N?ooool00ol0003ooooooooo
o`2=ooooo`0000Goooooo`000?ooooooooooo`000009ooooo`03o`000?oooooooooo00Cooooo00?o
0000ooooooooool0NOooool00ol0003oooooooooo`2<ooooo`0000Goooooo`000?ooooooooooo`00
000:ooooo`03o`000?oooooooooo00?ooooo0ol0001iooooo`03o`000?oooooooooo08cooooo0000
1Ooooooo0000oooooooooooo000000Oooooo00Go0000ooooooooooooooooo`000004ooooo`03o`00
0?oooooooooo07Wooooo00?o0000ooooooooool0S?ooool00005ooooool0003oooooooooool00000
1oooool01Ol0003ooooooooooooooooo000000Cooooo00?o0000ooooooooool0N_ooool00ol0003o
ooooooooo`2;ooooo`000_ooool2o`0000Wooooo0ol00005ooooo`03o`000?oooooooooo07[ooooo
00?o0000ooooooooool0Roooool001Gooooo00?o0000ooooooooool0N_ooool00ol0003ooooooooo
o`2;ooooo`005Oooool00ol0003oooooooooo`1kooooo`03o`000?oooooooooo08[ooooo000Eoooo
o`03o`000?oooooooooo07_ooooo00?o0000ooooooooool0R_ooool001Gooooo00?o0000oooooooo
ool0Noooool00ol0003oooooooooo`2:ooooo`005Oooool2o`0007gooooo00?o0000ooooooooool0
ROooool001Gooooo00?o0000ooooooooool0O?ooool00ol0003oooooooooo`29ooooo`005Oooool0
0ol0003oooooooooo`1looooo`03o`000?oooooooooo08Wooooo000Eooooo`03o`000?oooooooooo
07gooooo00?o0000ooooooooool0R?ooool001Gooooo00?o0000ooooooooool0OOooool00ol0003o
ooooooooo`28ooooo`005Oooool00ol0003oooooooooo`1mooooo`03o`000?oooooooooo08Sooooo
000Eooooo`03o`000?oooooooooo07kooooo00?o0000ooooooooool0Qoooool001Gooooo00?o0000
ooooooooool0O_ooool00ol0003oooooooooo`27ooooo`005Oooool2o`0007oooooo00?o0000oooo
ooooool0Qoooool001Gooooo00?o0000ooooooooool0Ooooool00ol0003oooooooooo`26ooooo`00
5Oooool00ol0003oooooooooo`1oooooo`03o`000?oooooooooo08Kooooo000Eooooo`03o`000?oo
oooooooo07oooooo00?o0000ooooooooool0Q_ooool001Gooooo00?o0000ooooooooool0Ooooool0
0ol0003oooooooooo`26ooooo`005Oooool00ol0003oooooooooo`1oooooo`03o`000?oooooooooo
08Kooooo000Eooooo`03o`000?oooooooooo083ooooo00?o0000ooooooooool0QOooool001Gooooo
00?o0000ooooooooool0P?ooool00ol0003oooooooooo`25ooooo`005Oooool2o`00087ooooo00?o
0000ooooooooool0QOooool001Gooooo00?o0000ooooooooool0P?ooool00ol0003oooooooooo`25
ooooo`005Oooool00ol0003oooooooooo`20ooooo`03o`000?oooooooooo08Gooooo000Eooooo`03
o`000?oooooooooo083ooooo00?o0000ooooooooool0QOooool001Gooooo00?o0000ooooooooool0
P?ooool00ol0003oooooooooo`25ooooo`000_ooool2o`0000Cooooo00?o0000ooooooooool00ooo
ool3o`0000Cooooo00?o0000ooooooooool0P?ooool00ol0003oooooooooo`25ooooo`0000Gooooo
o`000?ooooooooooo`00000:ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0POoo
ool00ol0003oooooooooo`24ooooo`0000Goooooo`000?ooooooooooo`000007ooooo`Go00001?oo
ool00ol0003oooooooooo`21ooooo`03o`000?oooooooooo08Cooooo00001Ooooooo0000oooooooo
oooo000000Oooooo00Co0000oooooooooooo00001Oooool3o`00087ooooo00?o0000ooooooooool0
Q?ooool00005ooooool0003oooooooooool000002?ooool00ol0003oooooo`000005ooooo`03o`00
0?oooooooooo087ooooo00?o0000ooooooooool0Q?ooool00005ooooool0003oooooooooool00000
2Oooool2o`0000Gooooo00?o0000ooooooooool0POooool00ol0003oooooooooo`24ooooo`000_oo
ool2o`0000_ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`21ooooo`03o`000?oo
oooooooo08Cooooo000Eooooo`03o`000?oooooooooo087ooooo00?o0000ooooooooool0Q?ooool0
01Gooooo00?o0000ooooooooool0P_ooool00ol0003oooooooooo`23ooooo`005Oooool00ol0003o
ooooooooo`22ooooo`03o`000?oooooooooo08?ooooo000Eooooo`03o`000?oooooooooo08;ooooo
00?o0000ooooooooool0Poooool001Gooooo0_l00023ooooo`03o`000?oooooooooo08?ooooo000E
ooooo`03o`000?oooooooooo08;ooooo00?o0000ooooooooool0Poooool001Gooooo00?o0000oooo
ooooool0P_ooool00ol0003oooooooooo`23ooooo`005Oooool00ol0003oooooooooo`22ooooo`03
o`000?oooooooooo08?ooooo000Eooooo`03o`000?oooooooooo08;ooooo00?o0000ooooooooool0
Poooool001Gooooo00?o0000ooooooooool0Poooool00ol0003oooooooooo`22ooooo`005Oooool0
0ol0003oooooooooo`23ooooo`03o`000?oooooooooo08;ooooo000Eooooo`03o`000?oooooooooo
08?ooooo00?o0000ooooooooool0P_ooool001Gooooo0_l00024ooooo`03o`000?oooooooooo08;o
oooo000Eooooo`03o`000?oooooooooo08?ooooo00?o0000ooooooooool0P_ooool001Gooooo00?o
0000ooooooooool0Poooool00ol0003oooooooooo`22ooooo`005Oooool00ol0003oooooooooo`23
ooooo`03o`000?oooooooooo08;ooooo000Eooooo`03o`000?oooooooooo08?ooooo00?o0000oooo
ooooool0P_ooool001Gooooo00?o0000ooooooooool0Q?ooool00ol0003oooooooooo`21ooooo`00
5Oooool00ol0003oooooooooo`24ooooo`03o`000?oooooooooo087ooooo000Eooooo`03o`000?oo
oooooooo08Cooooo00?o0000ooooooooool0POooool001Gooooo0_l00025ooooo`03o`000?oooooo
oooo087ooooo000Eooooo`03o`000?oooooooooo08Cooooo00?o0000ooooooooool0POooool001Go
oooo00?o0000ooooooooool0Q?ooool00ol0003oooooooooo`21ooooo`005Oooool00ol0003ooooo
ooooo`24ooooo`03o`000?oooooooooo087ooooo000Eooooo`03o`000?oooooooooo08Cooooo00?o
0000ooooooooool0POooool000;ooooo0_l00004ooooo`03o`000?oooooooooo00;ooooo0ol00005
ooooo`03o`000?oooooooooo08Gooooo00?o0000ooooooooool0P?ooool00005ooooool0003ooooo
ooooool000001oooool01Ol0003ooooooooooooooooo000000Cooooo00?o0000ooooooooool0QOoo
ool00ol0003oooooooooo`20ooooo`0000Goooooo`000?ooooooooooo`000007ooooo`05o`000?oo
ooooooooooooool000001?ooool00ol0003oooooooooo`25ooooo`03o`000?oooooooooo083ooooo
00001Ooooooo0000oooooooooooo000000Oooooo1?l00005ooooo`?o0000QOooool00ol0003ooooo
ooooo`20ooooo`0000Goooooo`000?ooooooooooo`000007ooooo`03o`000?oooooooooo00Kooooo
00?o0000ooooooooool0QOooool00ol0003oooooooooo`20ooooo`0000Goooooo`000?oooooooooo
o`000008ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0QOooool00ol0003ooooo
ooooo`20ooooo`000_ooool2o`0000[ooooo0_l00005ooooo`03o`000?oooooooooo08Gooooo00?o
0000ooooooooool0P?ooool001Gooooo00?o0000ooooooooool0Q_ooool00ol0003oooooooooo`1o
ooooo`005Oooool00ol0003oooooooooo`26ooooo`03o`000?oooooooooo07oooooo000Eooooo`03
o`000?oooooooooo08Kooooo00?o0000ooooooooool0Ooooool001Gooooo00?o0000ooooooooool0
Q_ooool00ol0003oooooooooo`1oooooo`005Oooool2o`0008Oooooo00?o0000ooooooooool0Oooo
ool001Gooooo00?o0000ooooooooool0Q_ooool00ol0003oooooooooo`1oooooo`005Oooool00ol0
003oooooooooo`26ooooo`03o`000?oooooooooo07oooooo000Eooooo`03o`000?oooooooooo08Ko
oooo00?o0000ooooooooool0Ooooool001Gooooo00?o0000ooooooooool0Qoooool00ol0003ooooo
ooooo`1nooooo`005Oooool00ol0003oooooooooo`27ooooo`03o`000?oooooooooo07kooooo000E
ooooo`03o`000?oooooooooo08Oooooo00?o0000ooooooooool0O_ooool001Gooooo00?o0000oooo
ooooool0Qoooool00ol0003oooooooooo`1nooooo`005Oooool2o`0008Sooooo00?o0000oooooooo
ool0O_ooool001Gooooo00?o0000ooooooooool0R?ooool00ol0003oooooooooo`1mooooo`005Ooo
ool00ol0003oooooooooo`28ooooo`03o`000?oooooooooo07gooooo000Eooooo`03o`000?oooooo
oooo08Sooooo00?o0000ooooooooool0OOooool001Gooooo00?o0000ooooooooool0ROooool00ol0
003oooooooooo`1looooo`005Oooool00ol0003oooooooooo`29ooooo`03o`000?oooooooooo07co
oooo000Eooooo`03o`000?oooooooooo08Wooooo00?o0000ooooooooool0O?ooool001Gooooo00?o
0000ooooooooool0R_ooool00ol0003oooooooooo`1kooooo`005Oooool2o`0008_ooooo00?o0000
ooooooooool0Noooool001Gooooo00?o0000ooooooooool0R_ooool00ol0003oooooooooo`1koooo
o`005Oooool00ol0003oooooooooo`2;ooooo`03o`000?oooooooooo07[ooooo000Eooooo`03o`00
0?oooooooooo08_ooooo00?o0000ooooooooool0N_ooool001Gooooo00?o0000ooooooooool0Rooo
ool00ol0003oooooooooo`1jooooo`000_ooool2o`0000Cooooo00?o0000ooooooooool00_ooool3
o`0000Gooooo00?o0000ooooooooool0S?ooool00ol0003oooooooooo`1iooooo`0000Goooooo`00
0?ooooooooooo`000007ooooo`05o`000?ooooooooooooooool000001?ooool00ol0003ooooooooo
o`2<ooooo`03o`000?oooooooooo07Wooooo00001Ooooooo0000oooooooooooo000000Oooooo00Go
0000ooooooooooooooooo`000004ooooo`03o`000?oooooooooo08cooooo00?o0000ooooooooool0
NOooool00005ooooool0003oooooooooool000002?ooool3o`0000Gooooo0ol0002=ooooo`03o`00
0?oooooooooo07Sooooo00001Ooooooo0000oooooooooooo000000Oooooo00Go0000oooooooooooo
ooooo`000004ooooo`03o`000?oooooooooo08gooooo00?o0000ooooooooool0N?ooool00005oooo
ool0003oooooooooool000001oooool01Ol0003ooooooooooooooooo000000Cooooo00?o0000oooo
ooooool0SOooool00ol0003oooooooooo`1hooooo`000_ooool2o`0000Wooooo0ol00005ooooo`03
o`000?oooooooooo08kooooo00?o0000ooooooooool0Moooool001Gooooo00?o0000ooooooooool0
S_ooool00ol0003oooooooooo`1gooooo`005Oooool00ol0003oooooooooo`2>ooooo`03o`000?oo
oooooooo07Oooooo000Eooooo`03o`000?oooooooooo08oooooo00?o0000ooooooooool0M_ooool0
01Gooooo00?o0000ooooooooool0Soooool00ol0003oooooooooo`1fooooo`005Oooool2o`00093o
oooo00?o0000ooooooooool0M_ooool001Gooooo00?o0000ooooooooool0T?ooool00ol0003ooooo
ooooo`1eooooo`005Oooool00ol0003oooooooooo`2@ooooo`03o`000?oooooooooo07Gooooo000E
ooooo`03o`000?oooooooooo097ooooo00?o0000ooooooooool0M?ooool001Gooooo00?o0000oooo
ooooool0T_ooool00ol0003oooooooooo`1cooooo`005Oooool00ol0003oooooooooo`2Cooooo`03
o`000?oooooooooo07;ooooo000Eooooo`03o`000?oooooooooo09Cooooo00?o0000ooooooooool0
LOooool001Gooooo00?o0000ooooooooool0UOooool00ol0003oooooooooo`1`ooooo`005Oooool2
o`0009Kooooo00?o0000ooooooooool0L?ooool001Gooooo00?o0000ooooooooool0U_ooool00ol0
003oooooooooo`1_ooooo`005Oooool00ol0003oooooooooo`2Gooooo`03o`000?oooooooooo06ko
oooo000Eooooo`03o`000?oooooooooo09Sooooo00?o0000ooooooooool0KOooool001Gooooo00?o
0000ooooooooool0VOooool2o`0006gooooo000Eooooo`03o`000?oooooooooo09_ooooo00?o0000
ooooooooool0J_ooool001Gooooo00?o0000ooooooooool0W?ooool00ol0003oooooooooo`1Yoooo
o`005Oooool00ol0003oooooooooo`2Mooooo`;o0000JOooool001Gooooo0_l0002Pooooo`03o`00
0?oooooooooo06Kooooo000Eooooo`03o`000?oooooooooo0:3ooooo00?o0000ooooooooool0IOoo
ool001Gooooo00?o0000ooooooooool0XOooool3o`0006Cooooo000Eooooo`03o`000?oooooooooo
0:Cooooo0ol0001Qooooo`005Oooool00ol0003oooooooooo`2Wooooo`?o0000G_ooool000gooooo
0ol00005ooooo`03o`000?oooooooooo0:[ooooo1Ol0001Iooooo`003_ooool00ol0003ooooooooo
o`04ooooo`03o`000?oooooooooo0:oooooo2Ol0001@ooooo`003_ooool00ol0003oooooooooo`04
ooooo`03o`000?oooooooooo0;Sooooo4Ol0000oooooo`003_ooool00ol0003oooooooooo`04oooo
o`?o0000bOoooolho`0000Oooooo000>ooooo`03o`000?oooooooooo0?oooooo4?ooool000gooooo
0_l0003ooooooa;ooooo000>ooooo`03o`000?oooooooooo0?oooooo4?ooool00?oooooo8Oooool0
0001\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-2.49048, -0.0764114, \
0.115739, 0.00624232}}]
}, Closed]]
}, Open  ]],

Cell["\<\
The cline widths decrease as selection gets stronger, but are wider \
than predicted.   This may be because the diffusion approximation is accurate \
when selection becomes very weak - here, selection gets fairly strong\
\>", \
"Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(Flatten[{#, 
              ClineWidth[\(res[3, #, ecotone]\)[
                  500]], \@\(\(6\ 0.5\)\/\(2\ #\)\)}] &\) /@ {0.01, 0.02, 
          0.04, 0.08, 0.12} // TableForm\)], "Input",
  CellLabel->"In[30]:="],

Cell[BoxData[
    TagBox[GridBox[{
          {"0.01`", "15.067818288559337`", "15.06781828855935`", 
            "15.06781828855935`", "12.24744871391589`"},
          {"0.02`", "9.154158872524821`", "9.15415887252483`", 
            "9.154158872524816`", "8.660254037844387`"},
          {"0.04`", "5.754306540047342`", "5.754306540047343`", 
            "5.754306540047343`", "6.123724356957945`"},
          {"0.08`", "3.5510488713516937`", "3.5510488713516937`", 
            "3.5510488713516937`", "4.330127018922194`"},
          {"0.12`", "2.614776940646242`", "2.614776940646242`", 
            "2.6147769406462418`", "3.5355339059327378`"}
          },
        RowSpacings->1,
        ColumnSpacings->3,
        RowAlignments->Baseline,
        ColumnAlignments->{Left}],
      Function[ BoxForm`e$, 
        TableForm[ BoxForm`e$]]]], "Output",
  CellLabel->"Out[30]//TableForm="]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Cline shape", "SubsectionIcon"],

Cell[CellGroupData[{

Cell[TextData[{
  StyleBox["Q2: ",
    FontColor->RGBColor[0, 0, 1]],
  "A cline maintained by selection against heterozygotes ",
  Cell[BoxData[
      \(TraditionalForm\`\((\[PartialD]\_t p\  = \ 
          s\[VeryThinSpace]p\[VeryThinSpace]\(q(p - q)\)\)\)]],
  ") gives a straight line on a logit scale",
  ". W",
  "hat might explain deviations from a straight line on a logit scale??"
}], "SubsubsectionIcon"],

Cell[TextData[{
  "This shows an example for ",
  Cell[BoxData[
      \(TraditionalForm\`s = 0.08\)]],
  ".  There is a steepening near the centre, relative to the straight line \
expected for selection against heterozygotes.  This is because in the model \
of an ecotone, selection coefficients are \[PlusMinus]s near the centre, \
whereas with selection against heterozygotes, selection coefficient ",
  Cell[BoxData[
      \(TraditionalForm\`s(p - q)\)]],
  " approaches zero near the centre."
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(LinearLogListPlot[
        1/\((1\/AlleleFrequencyMean[\(res[3, 0.08, ecotone]\)[500]] - 1)\), 
        PlotJoined \[Rule] True];\)\)], "Input",
  CellLabel->"In[33]:="],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.031746 0.309017 0.0954353 [
[.02381 -0.0125 -3 -9 ]
[.02381 -0.0125 3 0 ]
[.18254 -0.0125 -3 -9 ]
[.18254 -0.0125 3 0 ]
[.34127 -0.0125 -6 -9 ]
[.34127 -0.0125 6 0 ]
[.5 -0.0125 -6 -9 ]
[.5 -0.0125 6 0 ]
[.65873 -0.0125 -6 -9 ]
[.65873 -0.0125 6 0 ]
[.81746 -0.0125 -6 -9 ]
[.81746 -0.0125 6 0 ]
[.97619 -0.0125 -6 -9 ]
[.97619 -0.0125 6 0 ]
[-0.0125 .02271 -34 -6 ]
[-0.0125 .02271 0 6 ]
[-0.0125 .11815 -28 -6 ]
[-0.0125 .11815 0 6 ]
[-0.0125 .21358 -22 -6 ]
[-0.0125 .21358 0 6 ]
[-0.0125 .30902 -10 -6 ]
[-0.0125 .30902 0 6 ]
[-0.0125 .40445 -16 -6 ]
[-0.0125 .40445 0 6 ]
[-0.0125 .49989 -22 -6 ]
[-0.0125 .49989 0 6 ]
[-0.0125 .59532 -28 -6 ]
[-0.0125 .59532 0 6 ]
[ -0.0005 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 0 m
.02381 .00625 L
s
[(0)] .02381 -0.0125 0 1 Mshowa
.18254 0 m
.18254 .00625 L
s
[(5)] .18254 -0.0125 0 1 Mshowa
.34127 0 m
.34127 .00625 L
s
[(10)] .34127 -0.0125 0 1 Mshowa
.5 0 m
.5 .00625 L
s
[(15)] .5 -0.0125 0 1 Mshowa
.65873 0 m
.65873 .00625 L
s
[(20)] .65873 -0.0125 0 1 Mshowa
.81746 0 m
.81746 .00625 L
s
[(25)] .81746 -0.0125 0 1 Mshowa
.97619 0 m
.97619 .00625 L
s
[(30)] .97619 -0.0125 0 1 Mshowa
.125 Mabswid
.05556 0 m
.05556 .00375 L
s
.0873 0 m
.0873 .00375 L
s
.11905 0 m
.11905 .00375 L
s
.15079 0 m
.15079 .00375 L
s
.21429 0 m
.21429 .00375 L
s
.24603 0 m
.24603 .00375 L
s
.27778 0 m
.27778 .00375 L
s
.30952 0 m
.30952 .00375 L
s
.37302 0 m
.37302 .00375 L
s
.40476 0 m
.40476 .00375 L
s
.43651 0 m
.43651 .00375 L
s
.46825 0 m
.46825 .00375 L
s
.53175 0 m
.53175 .00375 L
s
.56349 0 m
.56349 .00375 L
s
.59524 0 m
.59524 .00375 L
s
.62698 0 m
.62698 .00375 L
s
.69048 0 m
.69048 .00375 L
s
.72222 0 m
.72222 .00375 L
s
.75397 0 m
.75397 .00375 L
s
.78571 0 m
.78571 .00375 L
s
.84921 0 m
.84921 .00375 L
s
.88095 0 m
.88095 .00375 L
s
.9127 0 m
.9127 .00375 L
s
.94444 0 m
.94444 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .02271 m
.00625 .02271 L
s
gsave
-0.0125 .02271 -95 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.001) show
93.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 .11815 m
.00625 .11815 L
s
gsave
-0.0125 .11815 -89 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.01) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 .21358 m
.00625 .21358 L
s
gsave
-0.0125 .21358 -83 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.1) show
81.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 .30902 m
.00625 .30902 L
s
gsave
-0.0125 .30902 -71 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 .40445 m
.00625 .40445 L
s
gsave
-0.0125 .40445 -77 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(10) show
75.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 .49989 m
.00625 .49989 L
s
gsave
-0.0125 .49989 -83 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(100) show
81.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 .59532 m
.00625 .59532 L
s
gsave
-0.0125 .59532 -89 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1000) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.001 w
0 .05144 m
.00375 .05144 L
s
0 .06825 m
.00375 .06825 L
s
0 .08017 m
.00375 .08017 L
s
0 .08942 m
.00375 .08942 L
s
0 .09697 m
.00375 .09697 L
s
0 .10336 m
.00375 .10336 L
s
0 .1089 m
.00375 .1089 L
s
0 .11378 m
.00375 .11378 L
s
0 .14688 m
.00375 .14688 L
s
0 .16368 m
.00375 .16368 L
s
0 .1756 m
.00375 .1756 L
s
0 .18485 m
.00375 .18485 L
s
0 .19241 m
.00375 .19241 L
s
0 .1988 m
.00375 .1988 L
s
0 .20433 m
.00375 .20433 L
s
0 .20921 m
.00375 .20921 L
s
0 .24231 m
.00375 .24231 L
s
0 .25912 m
.00375 .25912 L
s
0 .27104 m
.00375 .27104 L
s
0 .28029 m
.00375 .28029 L
s
0 .28784 m
.00375 .28784 L
s
0 .29423 m
.00375 .29423 L
s
0 .29977 m
.00375 .29977 L
s
0 .30465 m
.00375 .30465 L
s
0 .33775 m
.00375 .33775 L
s
0 .35455 m
.00375 .35455 L
s
0 .36647 m
.00375 .36647 L
s
0 .37572 m
.00375 .37572 L
s
0 .38328 m
.00375 .38328 L
s
0 .38967 m
.00375 .38967 L
s
0 .3952 m
.00375 .3952 L
s
0 .40009 m
.00375 .40009 L
s
0 .43318 m
.00375 .43318 L
s
0 .44999 m
.00375 .44999 L
s
0 .46191 m
.00375 .46191 L
s
0 .47116 m
.00375 .47116 L
s
0 .47872 m
.00375 .47872 L
s
0 .4851 m
.00375 .4851 L
s
0 .49064 m
.00375 .49064 L
s
0 .49552 m
.00375 .49552 L
s
0 .52862 m
.00375 .52862 L
s
0 .54542 m
.00375 .54542 L
s
0 .55735 m
.00375 .55735 L
s
0 .56659 m
.00375 .56659 L
s
0 .57415 m
.00375 .57415 L
s
0 .58054 m
.00375 .58054 L
s
0 .58607 m
.00375 .58607 L
s
0 .59096 m
.00375 .59096 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.05556 .01472 m
.0873 .02572 L
.11905 .03709 L
.15079 .05037 L
.18254 .06543 L
.21429 .08194 L
.24603 .09963 L
.27778 .11829 L
.30952 .13783 L
.34127 .1582 L
.37302 .17946 L
.40476 .20184 L
.43651 .22583 L
.46825 .25259 L
.5 .28503 L
.53175 .33301 L
.56349 .36544 L
.59524 .3922 L
.62698 .41619 L
.65873 .43857 L
.69048 .45984 L
.72222 .4802 L
.75397 .49974 L
.78571 .51841 L
.81746 .53609 L
.84921 .55261 L
.88095 .56766 L
.9127 .58095 L
.94444 .59232 L
.97619 .60332 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[33]:=",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/B000`400?l00000o`00003ooooooolQ
ooooo`00oooooolQooooo`00oooooolQooooo`00oooooolQooooo`00oooooolQooooo`00oooooolQ
ooooo`00:_ooool2o`0002Cooooo0ol0000Rooooo`?o00001?ooool2o`0001oooooo0ol00003oooo
o`?o00007Oooool5o`0000?ooooo0_l0000Nooooo`Go00000_ooool3o`0001oooooo0ol00004oooo
o`;o00000oooool002Wooooo00Co0000oooooooooooo00008_ooool01Ol0003ooooooooooooooooo
000002;ooooo00?o0000ooooooooool00_ooool01?l0003oooooooooool0000Oooooo`05o`000?oo
ooooooooooooool000000oooool00ol0003oooooooooo`0Kooooo`04o`000?ooooooooooo`0000;o
oooo00Co0000oooooooooooo00007_ooool01_l0003oooooooooool0003oooooo`0000?ooooo00?o
0000ooooooooool06oooool01Ol0003ooooooooooooooooo000000;ooooo00Co0000oooooooooooo
00000_ooool002Wooooo00Co0000oooooooooooo00009_ooool00ol0003oooooooooo`0Pooooo`03
o`000?oooooooooo00;ooooo00Co0000oooooooooooo00007oooool00ol0003oooooooooo`05oooo
o`03o`000?oooooooooo01cooooo00?o0000ooooooooool00_ooool01?l0003oooooooooool0000O
ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool07oooool01?l0003oooooooooool0
0002ooooo`7o00000Oooool1ooooo`00:Oooool01?l0003oooooooooool0000Vooooo`03o`000?oo
oooooooo023ooooo00?o0000ooooooooool00_ooool01?l0003oooooooooool0000Oooooo`03o`00
0?oooooooooo00Gooooo00?o0000ooooooooool07Oooool01Ol0003ooooooooooooooooo000000;o
oooo00?o0000ooooooooool07_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo01go
oooo0_l00003ooooo`04o`000?ooooooooooo`0000;ooooo000Yooooo`04o`000?ooooooooooo`00
02;ooooo1?l0000Sooooo`03o`000?oooooooooo00;ooooo00Co0000oooooooooooo00007oooool0
1?l0003oooooooooooooool4o`0001gooooo00Go0000ooooooooooooooooo`000002ooooo`04o`00
0?ooooooooooo`0001gooooo00Ko0000ooooooooooooooooo`000?ooool4o`0002;ooooo00Co0000
oooooooooooo00000_ooool1o`00007ooooo0Oooool002Wooooo00Co0000oooooooooooo00008_oo
ool00ol0003oooooooooo`0Sooooo`;o00001?ooool01?l0003oooooooooool0000Nooooo`;o0000
0oooool00ol0003oooooooooo`0Nooooo`05o`000?ooooooooooooooool000000_ooool01?l0003o
ooooooooool0000Mooooo`07o`000?ooooooooooooooool0003oooooo`00000Qooooo`05o`000?oo
ooooooooooooool000000_ooool01?l0003oooooooooool00002ooooo`00:_ooool2o`0002?ooooo
1Ol0000Rooooo`03o`000?oooooooooo00?ooooo0_l0000Pooooo`04o`000?ooooooooooooooo`Go
00007Oooool3o`0000Cooooo0_l0000Oooooo`?o00000_ooool5o`0001kooooo0ol00004ooooo`;o
00000oooool00?oooooo8Oooool00?oooooo8Oooool00?oooooo8Oooool00?oooooo8Oooool002Go
oooon_l00001ooooo`009Oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Gooooo
00?o0000ooooooooool01?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo
00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo
00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo
00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo
00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Cooooo
00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo
00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo
00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo
00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo
00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Cooooo
000Uooooo`03o`000?oooooooooo0?Sooooo0004ooooo`;o00001?ooool00ol0003oooooooooo`03
ooooo`;o00001?ooool2o`0000?ooooo0ol00007ooooo`03o`000?oooooooooo00_ooooo0_l0003[
ooooo`000oooool01?l0003oooooooooool00008ooooo`04o`000?ooooooooooo`0000;ooooo00Co
0000oooooooooooo00000oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00gooooo
0ol0003Xooooo`000oooool01?l0003oooooooooool00008ooooo`04o`000?ooooooooooo`0000;o
oooo00Co0000oooooooooooo00000oooool00ol0003oooooooooo`06ooooo`;o00004Oooool2o`00
0>Kooooo0003ooooo`04o`000?ooooooooooo`0000Sooooo00Co0000oooooooooooo00000_ooool0
1?l0003oooooooooool00003ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool04_oo
ool2o`000>Cooooo0003ooooo`04o`000?ooooooooooo`0000Sooooo00Co0000oooooooooooo0000
0_ooool01?l0003oooooooooool00003ooooo`03o`000?oooooooooo00Kooooo00?o0000oooooooo
ool05?ooool3o`000>7ooooo0003ooooo`04o`000?ooooooooooo`0000Sooooo00Co0000oooooooo
oooo00000_ooool01?l0003oooooooooool00002ooooo`;o00002?ooool00ol0003oooooooooo`0G
ooooo`?o0000g_ooool000Cooooo0_l0000:ooooo`;o00001?ooool2o`0000Cooooo00?o0000oooo
ooooool01_ooool00ol0003oooooooooo`0Jooooo`;o0000g?ooool002Gooooo00?o0000oooooooo
ool07?ooool3o`000=Wooooo000Uooooo`03o`000?oooooooooo01oooooo0ol0003Fooooo`009Ooo
ool00ol0003oooooooooo`0Rooooo`;o0000e?ooool002Gooooo0_l0000Uooooo`;o0000d_ooool0
02Gooooo00?o0000ooooooooool09_ooool2o`000=3ooooo000Uooooo`03o`000?oooooooooo02So
oooo0_l0003>ooooo`009Oooool00ol0003oooooooooo`0Zooooo`;o0000c?ooool002Gooooo0_l0
000]ooooo`;o0000b_ooool002Gooooo00?o0000ooooooooool0;_ooool2o`000<Sooooo000Uoooo
o`03o`000?oooooooooo033ooooo0_l00036ooooo`009Oooool2o`0003?ooooo0_l00034ooooo`00
9Oooool00ol0003oooooooooo`0dooooo`03o`000?oooooooooo0<7ooooo000Uooooo`;o0000=_oo
ool2o`000<7ooooo000Uooooo`03o`000?oooooooooo03Oooooo0_l0002oooooo`009Oooool2o`00
03[ooooo00?o0000ooooooooool0_?ooool002Gooooo00?o0000ooooooooool0>_ooool2o`000;co
oooo000Uooooo`;o0000?Oooool2o`000;[ooooo000:ooooo`;o00001?ooool00ol0003ooooooooo
o`03ooooo`;o00000oooool3o`0000Oooooo0_l0000oooooo`;o0000^?ooool000Wooooo00Co0000
oooooooooooo00002?ooool01?l0003oooooooooool00003ooooo`03o`000?oooooooooo00Kooooo
0_l00011ooooo`;o0000]_ooool000Wooooo00Co0000oooooooooooo00002?ooool01?l0003ooooo
ooooool00003ooooo`03o`000?oooooooooo00Kooooo0_l00013ooooo`;o0000]?ooool000Wooooo
00Co0000oooooooooooo00002?ooool01?l0003oooooooooool00003ooooo`03o`000?oooooooooo
00Kooooo00?o0000ooooooooool0A?ooool00ol0003oooooooooo`2aooooo`002Oooool01?l0003o
ooooooooool00008ooooo`04o`000?ooooooooooo`0000?ooooo00?o0000ooooooooool01_ooool0
0ol0003oooooooooo`15ooooo`;o0000/Oooool000Wooooo00Co0000oooooooooooo00002?ooool0
1?l0003oooooooooool00002ooooo`;o00002?ooool00ol0003oooooooooo`17ooooo`;o0000[ooo
ool000[ooooo0_l0000:ooooo`;o00001?ooool00ol0003oooooooooo`06ooooo`03o`000?oooooo
oooo04Wooooo00?o0000ooooooooool0[?ooool002Gooooo00?o0000ooooooooool0B_ooool2o`00
0:cooooo000Uooooo`03o`000?oooooooooo04cooooo00?o0000ooooooooool0ZOooool002Gooooo
0_l0001>ooooo`;o0000ZOooool002Gooooo00?o0000ooooooooool0Coooool2o`000:Oooooo000U
ooooo`03o`000?oooooooooo057ooooo00?o0000ooooooooool0Y?ooool002Gooooo00?o0000oooo
ooooool0D_ooool2o`000:Cooooo000Uooooo`03o`000?oooooooooo05Cooooo00?o0000oooooooo
ool0XOooool002Gooooo0_l0001Fooooo`03o`000?oooooooooo0:3ooooo000Uooooo`03o`000?oo
oooooooo05Kooooo0_l0002Pooooo`009Oooool00ol0003oooooooooo`1Hooooo`03o`000?oooooo
oooo09gooooo000Uooooo`;o0000F_ooool00ol0003oooooooooo`2Looooo`009Oooool00ol0003o
ooooooooo`1Jooooo`;o0000W?ooool002Gooooo0_l0001Mooooo`03o`000?oooooooooo09Wooooo
000Uooooo`03o`000?oooooooooo05gooooo0_l0002Iooooo`009Oooool2o`00063ooooo0_l0002G
ooooo`009Oooool2o`0006;ooooo00?o0000ooooooooool0U?ooool002Gooooo00?o0000oooooooo
ool0H_ooool2o`0009Cooooo000@ooooo`;o00001?ooool00ol0003oooooooooo`02ooooo`?o0000
1oooool2o`0006Gooooo00?o0000ooooooooool0TOooool000oooooo00Co0000oooooooooooo0000
2Oooool00ol0003oooooooooo`06ooooo`;o0000I_ooool00ol0003oooooooooo`2@ooooo`003ooo
ool01?l0003oooooooooool00009ooooo`03o`000?oooooooooo00Kooooo0_l0001Wooooo`;o0000
T?ooool000oooooo00Co0000oooooooooooo00002Oooool00ol0003oooooooooo`06ooooo`03o`00
0?oooooooooo06Sooooo00?o0000ooooooooool0SOooool000oooooo00Co0000oooooooooooo0000
2Oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo06Wooooo00?o0000ooooooooool0
S?ooool000oooooo00Co0000oooooooooooo00002?ooool2o`0000Sooooo00?o0000ooooooooool0
J_ooool2o`0008cooooo000@ooooo`;o00002_ooool00ol0003oooooooooo`06ooooo`03o`000?oo
oooooooo06cooooo00?o0000ooooooooool0ROooool002Gooooo00?o0000ooooooooool0KOooool0
0ol0003oooooooooo`28ooooo`009Oooool00ol0003oooooooooo`1^ooooo`03o`000?oooooooooo
08Oooooo000Uooooo`;o0000L?ooool00ol0003oooooooooo`26ooooo`009Oooool00ol0003ooooo
ooooo`1`ooooo`03o`000?oooooooooo08Gooooo000Uooooo`03o`000?oooooooooo077ooooo00?o
0000ooooooooool0Q?ooool002Gooooo00?o0000ooooooooool0L_ooool00ol0003oooooooooo`23
ooooo`009Oooool2o`0007Cooooo00?o0000ooooooooool0P_ooool002Gooooo00?o0000oooooooo
ool0M?ooool00ol0003oooooooooo`21ooooo`009Oooool00ol0003oooooooooo`1eooooo`03o`00
0?oooooooooo083ooooo000Uooooo`;o0000Moooool00ol0003oooooooooo`1oooooo`009Oooool0
0ol0003oooooooooo`1gooooo`03o`000?oooooooooo07kooooo000Uooooo`03o`000?oooooooooo
07Sooooo00?o0000ooooooooool0OOooool002Gooooo0_l0001jooooo`03o`000?oooooooooo07co
oooo000Uooooo`03o`000?oooooooooo07[ooooo00?o0000ooooooooool0Noooool002Gooooo0_l0
001kooooo`03o`000?oooooooooo07_ooooo000Uooooo`;o0000O?ooool00ol0003oooooooooo`1j
ooooo`009Oooool00ol0003oooooooooo`1kooooo`03o`000?oooooooooo07[ooooo000Kooooo`?o
00001oooool2o`0007gooooo00?o0000ooooooooool0NOooool001cooooo00?o0000ooooooooool0
1_ooool2o`0007kooooo00?o0000ooooooooool0N?ooool001cooooo00?o0000ooooooooool01_oo
ool2o`0007kooooo00?o0000ooooooooool0N?ooool001cooooo00?o0000ooooooooool01_ooool0
0ol0003oooooooooo`1nooooo`03o`000?oooooooooo07Oooooo000Looooo`03o`000?oooooooooo
00Kooooo00?o0000ooooooooool0O_ooool00ol0003oooooooooo`1gooooo`006oooool2o`0000So
oooo00?o0000ooooooooool0Ooooool00ol0003oooooooooo`1fooooo`007?ooool00ol0003ooooo
ooooo`06ooooo`03o`000?oooooooooo083ooooo00?o0000ooooooooool0MOooool002Gooooo00?o
0000ooooooooool0P?ooool00ol0003oooooooooo`1eooooo`009Oooool00ol0003oooooooooo`21
ooooo`03o`000?oooooooooo07Cooooo000Uooooo`;o0000Poooool00ol0003oooooooooo`1coooo
o`009Oooool00ol0003oooooooooo`23ooooo`03o`000?oooooooooo07;ooooo000Uooooo`03o`00
0?oooooooooo08Cooooo00?o0000ooooooooool0LOooool002Gooooo00?o0000ooooooooool0QOoo
ool00ol0003oooooooooo`1`ooooo`009Oooool2o`0008Oooooo00?o0000ooooooooool0Koooool0
02Gooooo00?o0000ooooooooool0Qoooool00ol0003oooooooooo`1^ooooo`009Oooool00ol0003o
ooooooooo`28ooooo`03o`000?oooooooooo06gooooo000Uooooo`;o0000R_ooool2o`0006gooooo
000Uooooo`03o`000?oooooooooo08_ooooo00?o0000ooooooooool0J_ooool002Gooooo00?o0000
ooooooooool0S?ooool00ol0003oooooooooo`1Yooooo`009Oooool2o`0008kooooo00?o0000oooo
ooooool0J?ooool002Gooooo0_l0002?ooooo`03o`000?oooooooooo06Oooooo000Uooooo`03o`00
0?oooooooooo08oooooo00?o0000ooooooooool0I_ooool002Gooooo0_l0002Aooooo`03o`000?oo
oooooooo06Gooooo000Uooooo`;o0000T_ooool2o`0006Gooooo000Eooooo`?o00001?ooool2o`00
00Oooooo00?o0000ooooooooool0Toooool00ol0003oooooooooo`1Rooooo`005_ooool00ol0003o
ooooooooo`02ooooo`04o`000?ooooooooooo`0000Kooooo0_l0002Eooooo`03o`000?oooooooooo
067ooooo000Fooooo`03o`000?oooooooooo00;ooooo00Co0000oooooooooooo00001_ooool2o`00
09Kooooo0_l0001Qooooo`005_ooool00ol0003oooooooooo`02ooooo`04o`000?ooooooooooo`00
00Kooooo00?o0000ooooooooool0Uoooool00ol0003oooooooooo`1Nooooo`005_ooool00ol0003o
ooooooooo`02ooooo`04o`000?ooooooooooo`0000Kooooo00?o0000ooooooooool0V?ooool00ol0
003oooooooooo`1Mooooo`005Oooool2o`0000Cooooo00Co0000oooooooooooo00001_ooool00ol0
003oooooooooo`2Iooooo`;o0000GOooool001Kooooo00?o0000ooooooooool00oooool2o`0000Oo
oooo00?o0000ooooooooool0Voooool00ol0003oooooooooo`1Jooooo`009Oooool00ol0003ooooo
ooooo`2Looooo`;o0000F_ooool002Gooooo00?o0000ooooooooool0W_ooool2o`0005Sooooo000U
ooooo`;o0000XOooool00ol0003oooooooooo`1Eooooo`009Oooool00ol0003oooooooooo`2Qoooo
o`;o0000EOooool002Gooooo00?o0000ooooooooool0Xoooool00ol0003oooooooooo`1Booooo`00
9Oooool00ol0003oooooooooo`2Tooooo`03o`000?oooooooooo057ooooo000Uooooo`;o0000Y_oo
ool2o`00057ooooo000Uooooo`03o`000?oooooooooo0:Oooooo00?o0000ooooooooool0C_ooool0
02Gooooo00?o0000ooooooooool0Z?ooool00ol0003oooooooooo`1=ooooo`009Oooool2o`000:[o
oooo0_l0001=ooooo`009Oooool00ol0003oooooooooo`2[ooooo`03o`000?oooooooooo04[ooooo
000Uooooo`;o0000[Oooool2o`0004[ooooo000Uooooo`03o`000?oooooooooo0:kooooo0_l00018
ooooo`009Oooool2o`000;7ooooo00?o0000ooooooooool0AOooool002Gooooo00?o0000oooooooo
ool0/Oooool2o`0004Gooooo000Uooooo`;o0000]?ooool00ol0003oooooooooo`12ooooo`009Ooo
ool2o`000;Gooooo0_l00012ooooo`003oooool3o`0000Cooooo0_l00004ooooo`;o00001oooool0
0ol0003oooooooooo`2fooooo`;o0000@?ooool0013ooooo00?o0000ooooooooool00_ooool01?l0
003oooooooooool00002ooooo`04o`000?ooooooooooo`0000Kooooo0_l0002iooooo`03o`000?oo
oooooooo03gooooo000@ooooo`03o`000?oooooooooo00;ooooo00Co0000oooooooooooo00000_oo
ool01?l0003oooooooooool00006ooooo`;o0000^_ooool2o`0003gooooo000@ooooo`03o`000?oo
oooooooo00;ooooo00Co0000oooooooooooo00000_ooool01?l0003oooooooooool00006ooooo`03
o`000?oooooooooo0;_ooooo0_l0000kooooo`004?ooool00ol0003oooooooooo`02ooooo`04o`00
0?ooooooooooo`0000;ooooo00Co0000oooooooooooo00001_ooool00ol0003oooooooooo`2moooo
o`;o0000>Oooool000oooooo0_l00004ooooo`04o`000?ooooooooooo`0000;ooooo00Co0000oooo
oooooooo00001_ooool00ol0003oooooooooo`2oooooo`;o0000=oooool0013ooooo00?o0000oooo
ooooool00oooool2o`0000Cooooo0_l00007ooooo`03o`000?oooooooooo0<7ooooo0_l0000eoooo
o`009Oooool00ol0003oooooooooo`33ooooo`03o`000?oooooooooo03;ooooo000Uooooo`03o`00
0?oooooooooo0<Cooooo0_l0000booooo`009Oooool2o`000<Oooooo0_l0000`ooooo`009Oooool0
0ol0003oooooooooo`38ooooo`03o`000?oooooooooo02gooooo000Uooooo`03o`000?oooooooooo
0<Wooooo0_l0000]ooooo`009Oooool00ol0003oooooooooo`3;ooooo`;o0000:oooool002Gooooo
0_l0003>ooooo`;o0000:Oooool002Gooooo00?o0000ooooooooool0coooool2o`0002Oooooo000U
ooooo`03o`000?oooooooooo0=7ooooo0_l0000Uooooo`009Oooool2o`000=Cooooo0_l0000Soooo
o`009Oooool00ol0003oooooooooo`3Eooooo`;o00008Oooool002Gooooo0_l0003Hooooo`;o0000
7oooool002Gooooo00?o0000ooooooooool0fOooool2o`0001gooooo000Uooooo`;o0000g?ooool3
o`0001[ooooo000Uooooo`03o`000?oooooooooo0=kooooo0ol0000Gooooo`009Oooool2o`000>;o
oooo0_l0000Eooooo`002Oooool3o`0000Cooooo0_l00004ooooo`;o00001?ooool2o`0000Oooooo
0_l0003Tooooo`?o00004_ooool000[ooooo00?o0000ooooooooool00_ooool01?l0003ooooooooo
ool00002ooooo`04o`000?ooooooooooo`0000;ooooo00Co0000oooooooooooo00001_ooool2o`00
0>Oooooo0ol0000?ooooo`002_ooool00ol0003oooooooooo`02ooooo`04o`000?ooooooooooo`00
00;ooooo00Co0000oooooooooooo00000_ooool01?l0003oooooooooool00006ooooo`;o0000j_oo
ool3o`0000cooooo000:ooooo`03o`000?oooooooooo00;ooooo00Co0000oooooooooooo00000_oo
ool01?l0003oooooooooool00002ooooo`04o`000?ooooooooooo`0000Kooooo00?o0000oooooooo
ool0k?ooool4o`0000Sooooo000:ooooo`03o`000?oooooooooo00;ooooo00Co0000oooooooooooo
00000_ooool01?l0003oooooooooool00002ooooo`04o`000?ooooooooooo`0000Kooooo00?o0000
ooooooooool0l?ooool2o`0000Kooooo0009ooooo`;o00001?ooool01?l0003oooooooooool00002
ooooo`04o`000?ooooooooooo`0000;ooooo00Co0000oooooooooooo00001_ooool00ol0003ooooo
ooooo`3hooooo`002_ooool00ol0003oooooooooo`03ooooo`;o00001?ooool2o`0000Cooooo0_l0
0007ooooo`03o`000?oooooooooo0?Sooooo000Uooooo`03o`000?oooooooooo0?Sooooo000Uoooo
o`03o`000?oooooooooo0?Sooooo003oooooob7ooooo003oooooob7ooooo003oooooob7ooooo003o
ooooob7ooooo003oooooob7ooooo0000\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-5.43094, -3.95804, \
0.126089, 0.0419429}}]
}, Open  ]],

Cell["\<\
The edges have a perturbing effect when selection is weak, since \
then allele frequencies do not approach fixation at the edges.\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(LinearLogListPlot[
        1/\((1\/AlleleFrequencyMean[\(res[3, 0.01, ecotone]\)[500]] - 1)\), 
        PlotJoined \[Rule] True];\)\)], "Input",
  CellLabel->"In[34]:="],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.031746 0.309017 0.343763 [
[.02381 -0.0125 -3 -9 ]
[.02381 -0.0125 3 0 ]
[.18254 -0.0125 -3 -9 ]
[.18254 -0.0125 3 0 ]
[.34127 -0.0125 -6 -9 ]
[.34127 -0.0125 6 0 ]
[.5 -0.0125 -6 -9 ]
[.5 -0.0125 6 0 ]
[.65873 -0.0125 -6 -9 ]
[.65873 -0.0125 6 0 ]
[.81746 -0.0125 -6 -9 ]
[.81746 -0.0125 6 0 ]
[.97619 -0.0125 -6 -9 ]
[.97619 -0.0125 6 0 ]
[-0.0125 .06874 -22 -6 ]
[-0.0125 .06874 0 6 ]
[-0.0125 .20553 -22 -6 ]
[-0.0125 .20553 0 6 ]
[-0.0125 .30902 -10 -6 ]
[-0.0125 .30902 0 6 ]
[-0.0125 .4125 -10 -6 ]
[-0.0125 .4125 0 6 ]
[-0.0125 .5493 -10 -6 ]
[-0.0125 .5493 0 6 ]
[ -0.0005 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 0 m
.02381 .00625 L
s
[(0)] .02381 -0.0125 0 1 Mshowa
.18254 0 m
.18254 .00625 L
s
[(5)] .18254 -0.0125 0 1 Mshowa
.34127 0 m
.34127 .00625 L
s
[(10)] .34127 -0.0125 0 1 Mshowa
.5 0 m
.5 .00625 L
s
[(15)] .5 -0.0125 0 1 Mshowa
.65873 0 m
.65873 .00625 L
s
[(20)] .65873 -0.0125 0 1 Mshowa
.81746 0 m
.81746 .00625 L
s
[(25)] .81746 -0.0125 0 1 Mshowa
.97619 0 m
.97619 .00625 L
s
[(30)] .97619 -0.0125 0 1 Mshowa
.125 Mabswid
.05556 0 m
.05556 .00375 L
s
.0873 0 m
.0873 .00375 L
s
.11905 0 m
.11905 .00375 L
s
.15079 0 m
.15079 .00375 L
s
.21429 0 m
.21429 .00375 L
s
.24603 0 m
.24603 .00375 L
s
.27778 0 m
.27778 .00375 L
s
.30952 0 m
.30952 .00375 L
s
.37302 0 m
.37302 .00375 L
s
.40476 0 m
.40476 .00375 L
s
.43651 0 m
.43651 .00375 L
s
.46825 0 m
.46825 .00375 L
s
.53175 0 m
.53175 .00375 L
s
.56349 0 m
.56349 .00375 L
s
.59524 0 m
.59524 .00375 L
s
.62698 0 m
.62698 .00375 L
s
.69048 0 m
.69048 .00375 L
s
.72222 0 m
.72222 .00375 L
s
.75397 0 m
.75397 .00375 L
s
.78571 0 m
.78571 .00375 L
s
.84921 0 m
.84921 .00375 L
s
.88095 0 m
.88095 .00375 L
s
.9127 0 m
.9127 .00375 L
s
.94444 0 m
.94444 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .06874 m
.00625 .06874 L
s
gsave
-0.0125 .06874 -83 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.2) show
81.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 .20553 m
.00625 .20553 L
s
gsave
-0.0125 .20553 -83 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.5) show
81.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 .30902 m
.00625 .30902 L
s
gsave
-0.0125 .30902 -71 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 .4125 m
.00625 .4125 L
s
gsave
-0.0125 .4125 -71 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 .5493 m
.00625 .5493 L
s
gsave
-0.0125 .5493 -71 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(5) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.001 w
0 .12927 m
.00375 .12927 L
s
0 .17222 m
.00375 .17222 L
s
0 .23275 m
.00375 .23275 L
s
0 .25577 m
.00375 .25577 L
s
0 .2757 m
.00375 .2757 L
s
0 .29329 m
.00375 .29329 L
s
0 .47303 m
.00375 .47303 L
s
0 .51598 m
.00375 .51598 L
s
0 .57652 m
.00375 .57652 L
s
0 .59953 m
.00375 .59953 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.05556 .01472 m
.0873 .03791 L
.11905 .05032 L
.15079 .06116 L
.18254 .07249 L
.21429 .08502 L
.24603 .09907 L
.27778 .11484 L
.30952 .13245 L
.34127 .15204 L
.37302 .17378 L
.40476 .19792 L
.43651 .22479 L
.46825 .25493 L
.5 .28917 L
.53175 .32886 L
.56349 .3631 L
.59524 .39324 L
.62698 .42012 L
.65873 .44425 L
.69048 .466 L
.72222 .48559 L
.75397 .5032 L
.78571 .51896 L
.81746 .53302 L
.84921 .54554 L
.88095 .55687 L
.9127 .56771 L
.94444 .58012 L
.97619 .60332 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[34]:=",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/B000`400?l00000o`00003ooooooolQ
ooooo`00oooooolQooooo`007_ooool2o`0002Oooooo0ol0000Sooooo`?o00001?ooool2o`00027o
oooo0ol00003ooooo`?o00007oooool5o`0000?ooooo0_l0000Pooooo`Go00000_ooool3o`00023o
oooo0ol00004ooooo`;o00001?ooool001gooooo00Co0000oooooooooooo00009Oooool01Ol0003o
oooooooooooooooo000002?ooooo00?o0000ooooooooool00_ooool01?l0003oooooooooool0000Q
ooooo`05o`000?ooooooooooooooool000000oooool00ol0003oooooooooo`0Mooooo`04o`000?oo
ooooooooo`0000;ooooo00Co0000oooooooooooo00008?ooool01_l0003oooooooooool0003ooooo
o`0000?ooooo00?o0000ooooooooool07?ooool01Ol0003ooooooooooooooooo000000;ooooo00Co
0000oooooooooooo00000oooool001gooooo00Co0000oooooooooooo0000:Oooool00ol0003ooooo
ooooo`0Qooooo`03o`000?oooooooooo00;ooooo00Co0000oooooooooooo00008Oooool00ol0003o
ooooooooo`05ooooo`03o`000?oooooooooo01kooooo00?o0000ooooooooool00_ooool01?l0003o
ooooooooool0000Qooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool08?ooool01?l0
003oooooooooool00002ooooo`03o`000?oooooooooo007ooooo000Mooooo`04o`000?oooooooooo
o`0002Wooooo00?o0000ooooooooool08Oooool00ol0003oooooooooo`02ooooo`04o`000?oooooo
ooooo`00027ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`0Oooooo`05o`000?oo
ooooooooooooool000000_ooool00ol0003oooooooooo`0Pooooo`03o`000?oooooooooo00Cooooo
00?o0000ooooooooool07_ooool2o`0000?ooooo00Co0000oooooooooooo00000oooool001gooooo
00Co0000oooooooooooo00009Oooool4o`0002Cooooo00?o0000ooooooooool00_ooool01?l0003o
ooooooooool0000Qooooo`04o`000?ooooooooooooooo`Co00007oooool01Ol0003ooooooooooooo
oooo000000;ooooo00Co0000oooooooooooo00007oooool01_l0003ooooooooooooooooo0000oooo
o`Co00008oooool01?l0003oooooooooool00002ooooo`03o`000?oooooooooo007ooooo000Moooo
o`04o`000?ooooooooooo`0002Gooooo00?o0000ooooooooool09?ooool2o`0000Cooooo00Co0000
oooooooooooo00008?ooool2o`0000?ooooo00?o0000ooooooooool08?ooool01Ol0003ooooooooo
oooooooo000000;ooooo00Co0000oooooooooooo00007oooool01ol0003ooooooooooooooooo0000
ooooool000008_ooool01Ol0003ooooooooooooooooo000000;ooooo00Co0000oooooooooooo0000
0oooool001kooooo0_l0000Vooooo`Go00008oooool00ol0003oooooooooo`03ooooo`;o00008_oo
ool01?l0003oooooooooooooool5o`0001oooooo0ol00004ooooo`;o00008Oooool3o`0000;ooooo
1Ol0000Oooooo`?o00001?ooool2o`0000Cooooo003oooooob7ooooo003oooooob7ooooo003ooooo
ob7ooooo003oooooob7ooooo000Ioooooooo00002?l0000001Wooooo00?o0000ooooooooool00ooo
ool00`00003oooooooooo`05ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01Ooo
ool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01Ooo
ool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01_oo
ool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01_oo
ool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01_oo
ool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01_oo
ool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Ooo
ool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Ooo
ool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Ooo
ool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Ooo
ool00ol0003oooooooooo`05ooooo`006Oooool00ol0003oooooooooo`03ooooo`0300000?oooooo
oooo02Oooooo00?o0000ooooooooool09_ooool00ol0003oooooooooo`0Wooooo`03o`000?oooooo
oooo02Kooooo00?o0000ooooooooool09oooool00ol0003oooooooooo`0Vooooo`03o`000?oooooo
oooo00Gooooo000Iooooo`03o`000?oooooooooo0?oooooo1Oooool001Wooooo00?o0000oooooooo
ool02oooool2o`000?Oooooo000Iooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool0
m?ooool001Wooooo00?o0000ooooooooool03_ooool2o`000?Cooooo000Iooooo`03o`000?oooooo
oooo013ooooo00?o0000ooooooooool0lOooool001Wooooo00?o0000ooooooooool04Oooool2o`00
0?7ooooo000Iooooo`03o`000?oooooooooo01?ooooo00?o0000ooooooooool0k_ooool001Wooooo
00?o0000ooooooooool05?ooool2o`000>kooooo000Iooooo`03o`000?oooooooooo01Kooooo0ol0
003[ooooo`006Oooool00ol0003oooooooooo`0Iooooo`?o0000j?ooool001Wooooo00?o0000oooo
ooooool07?ooool2o`000>Kooooo000Iooooo`03o`000?oooooooooo01kooooo0ol0003Sooooo`00
6Oooool00ol0003oooooooooo`0Qooooo`?o0000h?ooool000Cooooo0_l00004ooooo`04o`000?oo
ooooooooooooo`Go00001_ooool00ol0003oooooooooo`0Tooooo`?o0000gOooool000?ooooo00Co
0000oooooooooooo00002?ooool01?l0003oooooooooool00006ooooo`03o`000?oooooooooo02Oo
oooo0ol0003Jooooo`000oooool01?l0003oooooooooool00009ooooo`03o`000?oooooooooo00Ko
oooo0_l0000[ooooo`?o0000eoooool000?ooooo00Co0000oooooooooooo00002_ooool00ol0003o
ooooooooo`05ooooo`03o`000?oooooooooo02gooooo0_l0003Eooooo`000oooool01?l0003ooooo
ooooool00007ooooo`05o`000?ooooooooooooooool000001_ooool00ol0003oooooooooo`0_oooo
o`;o0000doooool000?ooooo00Co0000oooooooooooo00001oooool01Ol0003ooooooooooooooooo
000000Kooooo00?o0000ooooooooool0<Oooool2o`000=7ooooo0004ooooo`;o00002Oooool3o`00
00Oooooo00?o0000ooooooooool0<oooool2o`000<oooooo000Iooooo`03o`000?oooooooooo03Go
oooo0_l0003=ooooo`006Oooool00ol0003oooooooooo`0gooooo`?o0000b_ooool001Wooooo00?o
0000ooooooooool0>_ooool3o`000<Oooooo000Iooooo`03o`000?oooooooooo03gooooo0_l00035
ooooo`006Oooool00ol0003oooooooooo`0oooooo`;o0000`oooool001Wooooo00?o0000oooooooo
ool0@Oooool2o`000<7ooooo000Iooooo`03o`000?oooooooooo04?ooooo0_l0002oooooo`006Ooo
ool00ol0003oooooooooo`15ooooo`;o0000_Oooool001Wooooo00?o0000ooooooooool0Aoooool2
o`000;_ooooo000Iooooo`03o`000?oooooooooo04Wooooo0_l0002iooooo`006Oooool00ol0003o
ooooooooo`1;ooooo`03o`000?oooooooooo0;Kooooo000Iooooo`;o0000COooool2o`000;Kooooo
000Iooooo`03o`000?oooooooooo04kooooo0_l0002dooooo`006Oooool00ol0003oooooooooo`1@
ooooo`03o`000?oooooooooo0;7ooooo000Iooooo`03o`000?oooooooooo057ooooo0_l0002aoooo
o`006Oooool00ol0003oooooooooo`1Cooooo`;o0000[oooool001Wooooo00?o0000ooooooooool0
EOooool00ol0003oooooooooo`2/ooooo`006Oooool00ol0003oooooooooo`1Fooooo`;o0000[?oo
ool001Wooooo00?o0000ooooooooool0F?ooool00ol0003oooooooooo`2Yooooo`006Oooool00ol0
003oooooooooo`1Iooooo`03o`000?oooooooooo0:Sooooo000Iooooo`03o`000?oooooooooo05[o
oooo0_l0002Xooooo`006Oooool00ol0003oooooooooo`1Looooo`03o`000?oooooooooo0:Gooooo
000Iooooo`;o0000G_ooool00ol0003oooooooooo`2Tooooo`006Oooool00ol0003oooooooooo`1N
ooooo`;o0000Y?ooool001Wooooo00?o0000ooooooooool0H?ooool00ol0003oooooooooo`2Qoooo
o`006Oooool00ol0003oooooooooo`1Qooooo`;o0000XOooool001Wooooo00?o0000ooooooooool0
Hoooool00ol0003oooooooooo`2Nooooo`006Oooool00ol0003oooooooooo`1Tooooo`;o0000W_oo
ool001Wooooo00?o0000ooooooooool0I_ooool00ol0003oooooooooo`2Kooooo`001?ooool2o`00
00Cooooo00?o0000ooooooooool00_ooool3o`0000Oooooo00?o0000ooooooooool0Ioooool2o`00
09_ooooo0003ooooo`04o`000?ooooooooooo`0000Oooooo00Go0000ooooooooooooooooo`000006
ooooo`03o`000?oooooooooo06Wooooo00?o0000ooooooooool0V?ooool000?ooooo00Co0000oooo
oooooooo00002oooool00ol0003oooooooooo`04ooooo`;o0000Joooool00ol0003oooooooooo`2G
ooooo`000oooool01?l0003oooooooooool0000;ooooo`03o`000?oooooooooo00Cooooo00?o0000
ooooooooool0Joooool00ol0003oooooooooo`2Fooooo`000oooool01?l0003oooooooooool00007
ooooo`Co00001oooool00ol0003oooooooooo`1/ooooo`03o`000?oooooooooo09Gooooo0003oooo
o`04o`000?ooooooooooo`0000Oooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`1]
ooooo`03o`000?oooooooooo09Cooooo0004ooooo`;o00002?ooool5o`0000Kooooo00?o0000oooo
ooooool0K_ooool00ol0003oooooooooo`2Cooooo`006Oooool00ol0003oooooooooo`1_ooooo`03
o`000?oooooooooo09;ooooo000Iooooo`03o`000?oooooooooo073ooooo00?o0000ooooooooool0
TOooool001Wooooo0_l0001booooo`03o`000?oooooooooo093ooooo000Iooooo`03o`000?oooooo
oooo07;ooooo00?o0000ooooooooool0Soooool001Wooooo00?o0000ooooooooool0Loooool00ol0
003oooooooooo`2>ooooo`006Oooool00ol0003oooooooooo`1dooooo`03o`000?oooooooooo08go
oooo000Iooooo`03o`000?oooooooooo07Gooooo00?o0000ooooooooool0S?ooool001Wooooo00?o
0000ooooooooool0M_ooool00ol0003oooooooooo`2;ooooo`006Oooool2o`0007Sooooo00?o0000
ooooooooool0R_ooool001Wooooo00?o0000ooooooooool0N?ooool00ol0003oooooooooo`29oooo
o`006Oooool00ol0003oooooooooo`1iooooo`03o`000?oooooooooo08Sooooo000Iooooo`03o`00
0?oooooooooo07[ooooo00?o0000ooooooooool0Qoooool001Wooooo00?o0000ooooooooool0Nooo
ool00ol0003oooooooooo`26ooooo`006Oooool2o`0007gooooo00?o0000ooooooooool0QOooool0
01Wooooo00?o0000ooooooooool0OOooool00ol0003oooooooooo`24ooooo`006Oooool00ol0003o
ooooooooo`1nooooo`03o`000?oooooooooo08?ooooo000Iooooo`03o`000?oooooooooo07oooooo
00?o0000ooooooooool0P_ooool001Wooooo00?o0000ooooooooool0P?ooool00ol0003ooooooooo
o`21ooooo`006Oooool2o`00087ooooo00?o0000ooooooooool0POooool001Wooooo00?o0000oooo
ooooool0POooool00ol0003oooooooooo`20ooooo`003oooool3o`0000Oooooo00?o0000oooooooo
ool0P_ooool00ol0003oooooooooo`1oooooo`004?ooool00ol0003oooooooooo`06ooooo`03o`00
0?oooooooooo08?ooooo00?o0000ooooooooool0O_ooool0013ooooo00?o0000ooooooooool01_oo
ool2o`0008Gooooo00?o0000ooooooooool0OOooool0013ooooo00?o0000ooooooooool01_ooool0
0ol0003oooooooooo`24ooooo`03o`000?oooooooooo07gooooo000@ooooo`03o`000?oooooooooo
00Kooooo00?o0000ooooooooool0QOooool00ol0003oooooooooo`1looooo`003oooool2o`0000So
oooo00?o0000ooooooooool0Q_ooool00ol0003oooooooooo`1kooooo`004?ooool00ol0003ooooo
ooooo`06ooooo`03o`000?oooooooooo08Oooooo00?o0000ooooooooool0N_ooool001Wooooo00?o
0000ooooooooool0R?ooool00ol0003oooooooooo`1iooooo`006Oooool00ol0003oooooooooo`28
ooooo`03o`000?oooooooooo07Wooooo000Iooooo`03o`000?oooooooooo08Wooooo00?o0000oooo
ooooool0N?ooool001Wooooo00?o0000ooooooooool0R_ooool00ol0003oooooooooo`1gooooo`00
6Oooool00ol0003oooooooooo`2;ooooo`03o`000?oooooooooo07Kooooo000Iooooo`03o`000?oo
oooooooo08cooooo00?o0000ooooooooool0MOooool001Wooooo00?o0000ooooooooool0SOooool0
0ol0003oooooooooo`1dooooo`006Oooool00ol0003oooooooooo`2>ooooo`03o`000?oooooooooo
07?ooooo000Iooooo`03o`000?oooooooooo08oooooo00?o0000ooooooooool0L_ooool001Wooooo
00?o0000ooooooooool0T?ooool2o`0007;ooooo000Iooooo`03o`000?oooooooooo09;ooooo00?o
0000ooooooooool0Koooool001Wooooo00?o0000ooooooooool0Toooool00ol0003oooooooooo`1^
ooooo`006Oooool00ol0003oooooooooo`2Dooooo`03o`000?oooooooooo06gooooo000Iooooo`03
o`000?oooooooooo09Gooooo00?o0000ooooooooool0K?ooool001Wooooo00?o0000ooooooooool0
U_ooool00ol0003oooooooooo`1[ooooo`006Oooool00ol0003oooooooooo`2Gooooo`03o`000?oo
oooooooo06[ooooo000Iooooo`03o`000?oooooooooo09Sooooo00?o0000ooooooooool0JOooool0
01Wooooo00?o0000ooooooooool0VOooool2o`0006Wooooo000Iooooo`03o`000?oooooooooo09_o
oooo00?o0000ooooooooool0I_ooool001Wooooo00?o0000ooooooooool0W?ooool00ol0003ooooo
ooooo`1Uooooo`003_ooool5o`0000Kooooo00?o0000ooooooooool0WOooool00ol0003ooooooooo
o`1Tooooo`003oooool01?l0003oooooooooool00006ooooo`03o`000?oooooooooo09kooooo00?o
0000ooooooooool0Hoooool0013ooooo00?o0000ooooooooool01_ooool2o`000:3ooooo00?o0000
ooooooooool0H_ooool0017ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`2Poooo
o`03o`000?oooooooooo067ooooo000>ooooo`05o`000?ooooooooooooooool000001_ooool00ol0
003oooooooooo`2Qooooo`;o0000HOooool000kooooo00Go0000ooooooooooooooooo`000006oooo
o`03o`000?oooooooooo0:?ooooo00?o0000ooooooooool0G_ooool000oooooo0ol00007ooooo`03
o`000?oooooooooo0:Cooooo00?o0000ooooooooool0GOooool001Wooooo00?o0000ooooooooool0
YOooool00ol0003oooooooooo`1Looooo`006Oooool00ol0003oooooooooo`2Vooooo`03o`000?oo
oooooooo05_ooooo000Iooooo`03o`000?oooooooooo0:Oooooo00?o0000ooooooooool0F_ooool0
01Wooooo00?o0000ooooooooool0Z?ooool00ol0003oooooooooo`1Iooooo`006Oooool00ol0003o
ooooooooo`2Yooooo`;o0000FOooool001Wooooo00?o0000ooooooooool0Zoooool00ol0003ooooo
ooooo`1Fooooo`006Oooool00ol0003oooooooooo`2/ooooo`;o0000E_ooool001Wooooo00?o0000
ooooooooool0[_ooool2o`0005Cooooo000Iooooo`03o`000?oooooooooo0;3ooooo00?o0000oooo
ooooool0DOooool001Wooooo00?o0000ooooooooool0/Oooool2o`00057ooooo000Iooooo`03o`00
0?oooooooooo0;?ooooo0_l0001?ooooo`006Oooool2o`000;Kooooo0_l0001=ooooo`006Oooool0
0ol0003oooooooooo`2gooooo`03o`000?oooooooooo04[ooooo000Iooooo`03o`000?oooooooooo
0;Sooooo0_l0001:ooooo`006Oooool00ol0003oooooooooo`2jooooo`;o0000B?ooool001Wooooo
00?o0000ooooooooool0_?ooool00ol0003oooooooooo`15ooooo`006Oooool00ol0003ooooooooo
o`2mooooo`;o0000AOooool001Wooooo00?o0000ooooooooool0_oooool2o`0004?ooooo000Ioooo
o`03o`000?oooooooooo0<7ooooo00?o0000ooooooooool0@?ooool001Wooooo00?o0000oooooooo
ool0`_ooool2o`00043ooooo000Iooooo`03o`000?oooooooooo0<Cooooo0_l0000nooooo`006Ooo
ool00ol0003oooooooooo`36ooooo`;o0000??ooool001Wooooo0_l00039ooooo`;o0000>_ooool0
01Wooooo00?o0000ooooooooool0b_ooool2o`0003Sooooo000Iooooo`03o`000?oooooooooo0<co
oooo0_l0000fooooo`006Oooool00ol0003oooooooooo`3>ooooo`?o0000<oooool001Wooooo00?o
0000ooooooooool0dOooool2o`00037ooooo000Iooooo`03o`000?oooooooooo0=?ooooo0_l0000_
ooooo`006Oooool00ol0003oooooooooo`3Eooooo`?o0000;?ooool000oooooo0ol00007ooooo`03
o`000?oooooooooo0=Sooooo0ol0000Yooooo`003_ooool01Ol0003ooooooooooooooooo000000Ko
oooo00?o0000ooooooooool0foooool2o`0002Oooooo000Booooo`03o`000?oooooooooo00Cooooo
0_l0003Nooooo`?o00009?ooool001;ooooo00?o0000ooooooooool01?ooool00ol0003ooooooooo
o`3Pooooo`?o00008Oooool000kooooo1?l00007ooooo`03o`000?oooooooooo0>?ooooo0ol0000N
ooooo`003_ooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo0>Kooooo0ol0000Koooo
o`003_ooool5o`0000Kooooo00?o0000ooooooooool0jOooool3o`0001Sooooo000Iooooo`03o`00
0?oooooooooo0>cooooo0_l0000Fooooo`006Oooool00ol0003oooooooooo`3^ooooo`?o00004ooo
ool001Wooooo0_l0003booooo`?o00004?ooool001Wooooo00?o0000ooooooooool0m?ooool2o`00
00kooooo000Iooooo`03o`000?oooooooooo0?Kooooo00?o0000ooooooooool02oooool001Wooooo
00?o0000ooooooooool0moooool00ol0003oooooooooo`0:ooooo`006Oooool00ol0003ooooooooo
o`3hooooo`;o00002_ooool001Wooooo00?o0000ooooooooool0n_ooool00ol0003oooooooooo`07
ooooo`006Oooool2o`000?cooooo00?o0000ooooooooool01_ooool001Wooooo00?o0000oooooooo
ool0o?ooool00ol0003oooooooooo`05ooooo`006Oooool00ol0003oooooooooo`3oooooo`Gooooo
000Iooooo`03o`000?oooooooooo0?oooooo1Oooool001Wooooo00?o0000ooooooooool0ooooool5
ooooo`006Oooool00ol0003oooooooooo`3oooooo`Gooooo003oooooob7ooooo0000\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-3.79172, -1.0515, 0.120355, \
0.0111146}}]
}, Open  ]]
}, Closed]]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Linkage disequilibrium",
  FontColor->RGBColor[0, 0, 1]]], "SubsectionIcon"],

Cell[CellGroupData[{

Cell[TextData[{
  StyleBox["Q3: ",
    FontColor->RGBColor[0, 0, 1]],
  "What effect does tighter linkage have on the cline?  What would happen \
with more loci than three?"
}], "SubsubsectionIcon"],

Cell["\<\
This sets up simulation results for linkage r=0.05, 0.1, 0.2, \
0.5:\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(\((\(StoreExact[res[3, 0.04, #], MakeCline[30, 3, 100], 
              fitness[0.04, 15, ecotone], 0.5, {500, 20}, 
              Linkage \[Rule] {#, #}, Compiled \[Rule] True, 
              FixedEnds \[Rule] {MakePopulation[3, 0], 
                  MakePopulation[3, 1]}];\))\) &\) /@ {0.05, 0.1, 0.2, 
        0.5}\)], "Input",
  CellLabel->"In[36]:="],

Cell[BoxData[
    \({Null, Null, Null, Null}\)], "Output",
  CellLabel->"Out[36]="]
}, Open  ]],

Cell["\<\
This plots the pattern of LD for increasing recombination, and \
outputs the D at the centre:\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(\((ListPlot[DisequilibriumMean[\(res[3, 0.04, #]\)[500]], 
            PlotJoined \[Rule] 
              True]; \[IndentingNewLine]\(DisequilibriumMean[\(res[3, 
                  0.04, #]\)[
                500]]\)\[LeftDoubleBracket]15\[RightDoubleBracket])\) &\) /@ \
{0.05, 0.1, 0.2, 0.5}\)], "Input",
  CellLabel->"In[37]:="],

Cell[CellGroupData[{

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.031746 0.0147151 5.77785 [
[.18254 .00222 -3 -9 ]
[.18254 .00222 3 0 ]
[.34127 .00222 -6 -9 ]
[.34127 .00222 6 0 ]
[.5 .00222 -6 -9 ]
[.5 .00222 6 0 ]
[.65873 .00222 -6 -9 ]
[.65873 .00222 6 0 ]
[.81746 .00222 -6 -9 ]
[.81746 .00222 6 0 ]
[.97619 .00222 -6 -9 ]
[.97619 .00222 6 0 ]
[.01131 .13027 -24 -4.5 ]
[.01131 .13027 0 4.5 ]
[.01131 .24583 -24 -4.5 ]
[.01131 .24583 0 4.5 ]
[.01131 .36139 -24 -4.5 ]
[.01131 .36139 0 4.5 ]
[.01131 .47694 -24 -4.5 ]
[.01131 .47694 0 4.5 ]
[.01131 .5925 -18 -4.5 ]
[.01131 .5925 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.18254 .01472 m
.18254 .02097 L
s
[(5)] .18254 .00222 0 1 Mshowa
.34127 .01472 m
.34127 .02097 L
s
[(10)] .34127 .00222 0 1 Mshowa
.5 .01472 m
.5 .02097 L
s
[(15)] .5 .00222 0 1 Mshowa
.65873 .01472 m
.65873 .02097 L
s
[(20)] .65873 .00222 0 1 Mshowa
.81746 .01472 m
.81746 .02097 L
s
[(25)] .81746 .00222 0 1 Mshowa
.97619 .01472 m
.97619 .02097 L
s
[(30)] .97619 .00222 0 1 Mshowa
.125 Mabswid
.05556 .01472 m
.05556 .01847 L
s
.0873 .01472 m
.0873 .01847 L
s
.11905 .01472 m
.11905 .01847 L
s
.15079 .01472 m
.15079 .01847 L
s
.21429 .01472 m
.21429 .01847 L
s
.24603 .01472 m
.24603 .01847 L
s
.27778 .01472 m
.27778 .01847 L
s
.30952 .01472 m
.30952 .01847 L
s
.37302 .01472 m
.37302 .01847 L
s
.40476 .01472 m
.40476 .01847 L
s
.43651 .01472 m
.43651 .01847 L
s
.46825 .01472 m
.46825 .01847 L
s
.53175 .01472 m
.53175 .01847 L
s
.56349 .01472 m
.56349 .01847 L
s
.59524 .01472 m
.59524 .01847 L
s
.62698 .01472 m
.62698 .01847 L
s
.69048 .01472 m
.69048 .01847 L
s
.72222 .01472 m
.72222 .01847 L
s
.75397 .01472 m
.75397 .01847 L
s
.78571 .01472 m
.78571 .01847 L
s
.84921 .01472 m
.84921 .01847 L
s
.88095 .01472 m
.88095 .01847 L
s
.9127 .01472 m
.9127 .01847 L
s
.94444 .01472 m
.94444 .01847 L
s
.25 Mabswid
0 .01472 m
1 .01472 L
s
.02381 .13027 m
.03006 .13027 L
s
[(0.02)] .01131 .13027 1 0 Mshowa
.02381 .24583 m
.03006 .24583 L
s
[(0.04)] .01131 .24583 1 0 Mshowa
.02381 .36139 m
.03006 .36139 L
s
[(0.06)] .01131 .36139 1 0 Mshowa
.02381 .47694 m
.03006 .47694 L
s
[(0.08)] .01131 .47694 1 0 Mshowa
.02381 .5925 m
.03006 .5925 L
s
[(0.1)] .01131 .5925 1 0 Mshowa
.125 Mabswid
.02381 .0436 m
.02756 .0436 L
s
.02381 .07249 m
.02756 .07249 L
s
.02381 .10138 m
.02756 .10138 L
s
.02381 .15916 m
.02756 .15916 L
s
.02381 .18805 m
.02756 .18805 L
s
.02381 .21694 m
.02756 .21694 L
s
.02381 .27472 m
.02756 .27472 L
s
.02381 .30361 m
.02756 .30361 L
s
.02381 .3325 m
.02756 .3325 L
s
.02381 .39028 m
.02756 .39028 L
s
.02381 .41916 m
.02756 .41916 L
s
.02381 .44805 m
.02756 .44805 L
s
.02381 .50583 m
.02756 .50583 L
s
.02381 .53472 m
.02756 .53472 L
s
.02381 .56361 m
.02756 .56361 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.05556 .01502 m
.0873 .01514 L
.11905 .01534 L
.15079 .01572 L
.18254 .01642 L
.21429 .01772 L
.24603 .02014 L
.27778 .02472 L
.30952 .03344 L
.34127 .05012 L
.37302 .08181 L
.40476 .14084 L
.43651 .24544 L
.46825 .4108 L
.5 .60332 L
.53175 .60332 L
.56349 .4108 L
.59524 .24544 L
.62698 .14084 L
.65873 .08181 L
.69048 .05012 L
.72222 .03344 L
.75397 .02472 L
.78571 .02014 L
.81746 .01772 L
.84921 .01642 L
.88095 .01572 L
.9127 .01534 L
.94444 .01514 L
.97619 .01502 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[37]:=",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/B000`400?l00000o`00003ooooooolQ
ooooo`00oooooolQooooo`00oooooolQooooo`00@oooool3o`0002Cooooo0ol00004ooooo`;o0000
8Oooool3o`0000?ooooo0ol0000Qooooo`Go00000oooool2o`00023ooooo1Ol00002ooooo`?o0000
8Oooool3o`0000Cooooo0_l00004ooooo`00@_ooool01Ol0003ooooooooooooooooo000002Cooooo
00?o0000ooooooooool00_ooool01?l0003oooooooooool0000Qooooo`05o`000?oooooooooooooo
ool000000oooool00ol0003oooooooooo`0Oooooo`04o`000?ooooooooooo`0000;ooooo00Co0000
oooooooooooo00008?ooool01_l0003oooooooooool0003oooooo`0000?ooooo00?o0000oooooooo
ool07Oooool01Ol0003ooooooooooooooooo000000;ooooo00Co0000oooooooooooo00000oooool0
04Kooooo00?o0000ooooooooool08_ooool00ol0003oooooooooo`02ooooo`04o`000?oooooooooo
o`00027ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`0Pooooo`03o`000?oooooo
oooo00;ooooo00Co0000oooooooooooo00008Oooool00ol0003oooooooooo`05ooooo`03o`000?oo
oooooooo027ooooo00Co0000oooooooooooo00000_ooool00ol0003oooooooooo`01ooooo`00A_oo
ool00ol0003oooooooooo`0Rooooo`03o`000?oooooooooo00;ooooo00Co0000oooooooooooo0000
8Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo027ooooo00Go0000oooooooooooo
ooooo`000002ooooo`03o`000?oooooooooo023ooooo00?o0000ooooooooool01?ooool00ol0003o
ooooooooo`0Oooooo`;o00000oooool01?l0003oooooooooool00003ooooo`00@_ooool4o`0002Go
oooo00?o0000ooooooooool00_ooool01?l0003oooooooooool0000Qooooo`04o`000?oooooooooo
ooooo`Co00008Oooool01Ol0003ooooooooooooooooo000000;ooooo00Co0000oooooooooooo0000
7oooool01_l0003ooooooooooooooooo0000ooooo`Co00009?ooool01?l0003oooooooooool00002
ooooo`03o`000?oooooooooo007ooooo0012ooooo`03o`000?oooooooooo02Gooooo0_l00004oooo
o`04o`000?ooooooooooo`00023ooooo0_l00003ooooo`03o`000?oooooooooo02;ooooo00Go0000
ooooooooooooooooo`000002ooooo`04o`000?ooooooooooo`0001oooooo00Oo0000oooooooooooo
ooooo`000?oooooo000002?ooooo00Go0000ooooooooooooooooo`000002ooooo`04o`000?oooooo
ooooo`0000?ooooo0012ooooo`Go00009?ooool00ol0003oooooooooo`03ooooo`;o00008_ooool0
1?l0003oooooooooooooool5o`00027ooooo0ol00004ooooo`;o00008Oooool3o`0000;ooooo1Ol0
000Pooooo`?o00001?ooool2o`0000Cooooo000Kooooo`03o`000?oooooooooo0?oooooo0oooool0
01_ooooo00?o0000ooooooooool0ooooool3ooooo`006oooool00ol0003oooooooooo`3oooooo`?o
oooo000Kooooo`03o`000?oooooooooo0?oooooo0oooool001Coooooool0000=o`0000006oooool0
0ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01Oooool0
0ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Gooooo00<00000ooooooooool00_ooool?
o`0000Gooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooo
oooo00Kooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`06ooooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`06ooooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooo
oooo00Kooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`06ooooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool00oooool?o`0000Cooooo00?o0000ooooooooool01_ooool0
0ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01Oooool0
0ol0003oooooooooo`05ooooo`006oooool00ol0003oooooooooo`0Wooooo`0300000?oooooooooo
017ooooo1?l0000Booooo`03o`000?oooooooooo02Oooooo00?o0000ooooooooool0:?ooool00ol0
003oooooooooo`0Hooooo`Co00002oooool00ol0003oooooooooo`0Wooooo`03o`000?oooooooooo
00Gooooo000Kooooo`03o`000?oooooooooo03oooooo1?l0001jooooo`Co0000@Oooool001_ooooo
00?o0000ooooooooool0@oooool5o`00077ooooo1?l00015ooooo`006oooool00ol0003ooooooooo
o`18ooooo`?o0000Joooool3o`0004Wooooo000Kooooo`03o`000?oooooooooo04_ooooo0_l0001W
ooooo`;o0000C?ooool001_ooooo00?o0000ooooooooool0COooool2o`0006;ooooo0ol0001>oooo
o`006oooool2o`00053ooooo0_l0001Nooooo`;o0000DOooool001_ooooo00?o0000ooooooooool0
DOooool00ol0003oooooooooo`1Jooooo`03o`000?oooooooooo057ooooo000Kooooo`03o`000?oo
oooooooo05;ooooo00?o0000ooooooooool0FOooool00ol0003oooooooooo`1Aooooo`006oooool0
0ol0003oooooooooo`1Cooooo`03o`000?oooooooooo05Oooooo00?o0000ooooooooool0D_ooool0
01_ooooo00?o0000ooooooooool0E?ooool00ol0003oooooooooo`1Eooooo`03o`000?oooooooooo
05?ooooo000Kooooo`03o`000?oooooooooo05Gooooo00?o0000ooooooooool0Doooool00ol0003o
ooooooooo`1Dooooo`006oooool00ol0003oooooooooo`1Fooooo`03o`000?oooooooooo057ooooo
00?o0000ooooooooool0EOooool001_ooooo0_l0001Hooooo`03o`000?oooooooooo04oooooo00?o
0000ooooooooool0E_ooool001_ooooo00?o0000ooooooooool0F?ooool00ol0003oooooooooo`1=
ooooo`03o`000?oooooooooo05Oooooo000Kooooo`03o`000?oooooooooo05Wooooo00?o0000oooo
ooooool0Boooool00ol0003oooooooooo`1Hooooo`006oooool00ol0003oooooooooo`1Jooooo`03
o`000?oooooooooo04Wooooo00?o0000ooooooooool0FOooool001_ooooo00?o0000ooooooooool0
F_ooool00ol0003oooooooooo`19ooooo`03o`000?oooooooooo05Wooooo000Kooooo`03o`000?oo
oooooooo05_ooooo00?o0000ooooooooool0Aoooool00ol0003oooooooooo`1Jooooo`006oooool0
0ol0003oooooooooo`1Kooooo`03o`000?oooooooooo04Kooooo00?o0000ooooooooool0Foooool0
01_ooooo00?o0000ooooooooool0G?ooool00ol0003oooooooooo`15ooooo`03o`000?oooooooooo
05_ooooo000Kooooo`;o0000GOooool00ol0003oooooooooo`14ooooo`03o`000?oooooooooo05co
oooo000Kooooo`03o`000?oooooooooo05gooooo00?o0000ooooooooool0@oooool00ol0003ooooo
ooooo`1Looooo`006oooool00ol0003oooooooooo`1Mooooo`03o`000?oooooooooo04;ooooo00?o
0000ooooooooool0GOooool001_ooooo00?o0000ooooooooool0G_ooool00ol0003oooooooooo`10
ooooo`03o`000?oooooooooo05kooooo000Kooooo`03o`000?oooooooooo05oooooo00?o0000oooo
ooooool0?oooool00ol0003oooooooooo`1Nooooo`000_ooool2o`0000Cooooo00?o0000oooooooo
ool00oooool2o`0000;ooooo1Ol00004ooooo`03o`000?oooooooooo05oooooo00?o0000oooooooo
ool0?_ooool00ol0003oooooooooo`1Oooooo`0000Goooooo`000?ooooooooooo`000008ooooo`04
o`000?ooooooooooo`0000;ooooo00Co0000oooooooooooo00001?ooool00ol0003oooooooooo`1P
ooooo`03o`000?oooooooooo03gooooo00?o0000ooooooooool0Goooool00005ooooool0003ooooo
ooooool000002?ooool01?l0003oooooooooool00003ooooo`03o`000?oooooooooo00Cooooo00?o
0000ooooooooool0H?ooool00ol0003oooooooooo`0looooo`03o`000?oooooooooo063ooooo0000
1Ooooooo0000oooooooooooo000000Sooooo00Co0000oooooooooooo00001?ooool00ol0003ooooo
ooooo`03ooooo`;o0000H_ooool00ol0003oooooooooo`0jooooo`03o`000?oooooooooo067ooooo
00001Ooooooo0000oooooooooooo000000Sooooo00Ko0000oooooooooooo0000ooooool00003oooo
o`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0HOooool00ol0003oooooooooo`0joooo
o`03o`000?oooooooooo067ooooo00001Ooooooo0000oooooooooooo000000Sooooo00Ko0000oooo
oooooooo0000ooooool00003ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0H_oo
ool00ol0003oooooooooo`0hooooo`03o`000?oooooooooo06;ooooo0002ooooo`;o00002_ooool2
o`0000?ooooo0ol00005ooooo`03o`000?oooooooooo06;ooooo00?o0000ooooooooool0>?ooool0
0ol0003oooooooooo`1Rooooo`006oooool00ol0003oooooooooo`1Rooooo`03o`000?oooooooooo
03Sooooo00?o0000ooooooooool0H_ooool001_ooooo00?o0000ooooooooool0Hoooool00ol0003o
ooooooooo`0fooooo`03o`000?oooooooooo06?ooooo000Kooooo`03o`000?oooooooooo06?ooooo
00?o0000ooooooooool0=_ooool00ol0003oooooooooo`1Sooooo`006oooool2o`0006Cooooo00?o
0000ooooooooool0=_ooool00ol0003oooooooooo`1Sooooo`006oooool00ol0003oooooooooo`1T
ooooo`03o`000?oooooooooo03Cooooo00?o0000ooooooooool0I?ooool001_ooooo00?o0000oooo
ooooool0I?ooool00ol0003oooooooooo`0dooooo`03o`000?oooooooooo06Cooooo000Kooooo`03
o`000?oooooooooo06Cooooo00?o0000ooooooooool0=?ooool00ol0003oooooooooo`1Tooooo`00
6oooool00ol0003oooooooooo`1Uooooo`03o`000?oooooooooo03?ooooo00?o0000ooooooooool0
I?ooool001_ooooo00?o0000ooooooooool0IOooool00ol0003oooooooooo`0booooo`03o`000?oo
oooooooo06Gooooo000Kooooo`03o`000?oooooooooo06Gooooo00?o0000ooooooooool0<_ooool0
0ol0003oooooooooo`1Uooooo`006oooool00ol0003oooooooooo`1Vooooo`03o`000?oooooooooo
037ooooo00?o0000ooooooooool0IOooool001_ooooo0_l0001Wooooo`03o`000?oooooooooo033o
oooo00?o0000ooooooooool0I_ooool001_ooooo00?o0000ooooooooool0I_ooool00ol0003ooooo
ooooo`0`ooooo`03o`000?oooooooooo06Kooooo000Kooooo`03o`000?oooooooooo06Oooooo00?o
0000ooooooooool0;oooool00ol0003oooooooooo`1Vooooo`006oooool00ol0003oooooooooo`1W
ooooo`03o`000?oooooooooo02oooooo00?o0000ooooooooool0I_ooool001_ooooo00?o0000oooo
ooooool0Ioooool00ol0003oooooooooo`0^ooooo`03o`000?oooooooooo06Oooooo000Kooooo`03
o`000?oooooooooo06Sooooo00?o0000ooooooooool0;Oooool00ol0003oooooooooo`1Wooooo`00
6oooool00ol0003oooooooooo`1Xooooo`03o`000?oooooooooo02gooooo00?o0000ooooooooool0
Ioooool001_ooooo00?o0000ooooooooool0J?ooool00ol0003oooooooooo`0/ooooo`03o`000?oo
oooooooo06Sooooo000Kooooo`;o0000J_ooool00ol0003oooooooooo`0[ooooo`03o`000?oooooo
oooo06Sooooo000Kooooo`03o`000?oooooooooo06Wooooo00?o0000ooooooooool0:oooool00ol0
003oooooooooo`1Xooooo`006oooool00ol0003oooooooooo`1Yooooo`03o`000?oooooooooo02_o
oooo00?o0000ooooooooool0J?ooool001_ooooo00?o0000ooooooooool0J_ooool00ol0003ooooo
ooooo`0Yooooo`03o`000?oooooooooo06Wooooo000Kooooo`03o`000?oooooooooo06[ooooo00?o
0000ooooooooool0:Oooool00ol0003oooooooooo`1Yooooo`000_ooool2o`0000Cooooo00?o0000
ooooooooool00oooool2o`0000Cooooo0ol00004ooooo`03o`000?oooooooooo06[ooooo00?o0000
ooooooooool0:Oooool00ol0003oooooooooo`1Yooooo`0000Goooooo`000?ooooooooooo`000008
ooooo`04o`000?ooooooooooo`0000Cooooo00?o0000ooooooooool00oooool00ol0003ooooooooo
o`1[ooooo`03o`000?oooooooooo02Oooooo00?o0000ooooooooool0J_ooool00005ooooool0003o
ooooooooool000002?ooool01Ol0003oooooooooool0003ooooo00Go00001?ooool2o`0006cooooo
00?o0000ooooooooool09oooool00ol0003oooooooooo`1Zooooo`0000Goooooo`000?oooooooooo
o`000008ooooo`06o`000?ooooooooooo`000?oooooo00000_ooool00ol0003oooooooooo`03oooo
o`03o`000?oooooooooo06_ooooo00?o0000ooooooooool09oooool00ol0003oooooooooo`1Zoooo
o`0000Goooooo`000?ooooooooooo`000008ooooo`04o`000?ooooooooooo`0000;ooooo00?o0000
ooooool000001Oooool00ol0003oooooooooo`1[ooooo`03o`000?oooooooooo02Oooooo00?o0000
ooooooooool0J_ooool00005ooooool0003oooooooooool000002?ooool01?l0003oooooooooool0
0003ooooo`;o00001Oooool00ol0003oooooooooo`1[ooooo`03o`000?oooooooooo02Kooooo00?o
0000ooooooooool0Joooool000;ooooo0_l0000:ooooo`;o00001Oooool00ol0003oooooooooo`03
ooooo`03o`000?oooooooooo06cooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`1[
ooooo`006oooool00ol0003oooooooooo`1/ooooo`03o`000?oooooooooo02Gooooo00?o0000oooo
ooooool0Joooool001_ooooo00?o0000ooooooooool0K?ooool00ol0003oooooooooo`0Uooooo`03
o`000?oooooooooo06_ooooo000Kooooo`03o`000?oooooooooo06cooooo00?o0000ooooooooool0
9Oooool00ol0003oooooooooo`1[ooooo`006oooool2o`0006gooooo00?o0000ooooooooool09?oo
ool00ol0003oooooooooo`1/ooooo`006oooool00ol0003oooooooooo`1]ooooo`03o`000?oooooo
oooo02?ooooo00?o0000ooooooooool0K?ooool001_ooooo00?o0000ooooooooool0KOooool00ol0
003oooooooooo`0Sooooo`03o`000?oooooooooo06cooooo000Kooooo`03o`000?oooooooooo06go
oooo00?o0000ooooooooool08oooool00ol0003oooooooooo`1/ooooo`006oooool00ol0003ooooo
ooooo`1]ooooo`03o`000?oooooooooo02?ooooo00?o0000ooooooooool0K?ooool001_ooooo00?o
0000ooooooooool0KOooool00ol0003oooooooooo`0Rooooo`03o`000?oooooooooo06gooooo000K
ooooo`03o`000?oooooooooo06gooooo00?o0000ooooooooool08_ooool00ol0003oooooooooo`1]
ooooo`006oooool00ol0003oooooooooo`1^ooooo`03o`000?oooooooooo027ooooo00?o0000oooo
ooooool0KOooool001_ooooo0_l0001_ooooo`03o`000?oooooooooo027ooooo00?o0000oooooooo
ool0KOooool001_ooooo00?o0000ooooooooool0K_ooool00ol0003oooooooooo`0Qooooo`03o`00
0?oooooooooo06gooooo000Kooooo`03o`000?oooooooooo06kooooo00?o0000ooooooooool08?oo
ool00ol0003oooooooooo`1^ooooo`006oooool00ol0003oooooooooo`1^ooooo`03o`000?oooooo
oooo023ooooo00?o0000ooooooooool0K_ooool001_ooooo00?o0000ooooooooool0Koooool00ol0
003oooooooooo`0Oooooo`03o`000?oooooooooo06kooooo000Kooooo`03o`000?oooooooooo06oo
oooo00?o0000ooooooooool07oooool00ol0003oooooooooo`1^ooooo`006oooool00ol0003ooooo
ooooo`1_ooooo`03o`000?oooooooooo01oooooo00?o0000ooooooooool0K_ooool001_ooooo0_l0
001`ooooo`03o`000?oooooooooo01kooooo00?o0000ooooooooool0Koooool001_ooooo00?o0000
ooooooooool0Koooool00ol0003oooooooooo`0Nooooo`03o`000?oooooooooo06oooooo000Koooo
o`03o`000?oooooooooo06oooooo00?o0000ooooooooool07_ooool00ol0003oooooooooo`1_oooo
o`006oooool00ol0003oooooooooo`1`ooooo`03o`000?oooooooooo01gooooo00?o0000oooooooo
ool0Koooool001_ooooo00?o0000ooooooooool0L?ooool00ol0003oooooooooo`0Mooooo`03o`00
0?oooooooooo06oooooo000Kooooo`03o`000?oooooooooo073ooooo00?o0000ooooooooool07?oo
ool00ol0003oooooooooo`1`ooooo`000_ooool2o`0000Cooooo00?o0000ooooooooool00oooool2
o`0000?ooooo0ol00005ooooo`03o`000?oooooooooo073ooooo00?o0000ooooooooool07?ooool0
0ol0003oooooooooo`1`ooooo`0000Goooooo`000?ooooooooooo`000008ooooo`06o`000?oooooo
ooooo`000?oooooo00000oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo073ooooo
00?o0000ooooooooool07?ooool00ol0003oooooooooo`1`ooooo`0000Goooooo`000?oooooooooo
o`000008ooooo`06o`000?ooooooooooo`000?oooooo00000oooool00ol0003oooooooooo`02oooo
o`;o0000L_ooool00ol0003oooooooooo`0Kooooo`03o`000?oooooooooo073ooooo00001Ooooooo
0000oooooooooooo000000Sooooo00Go0000oooooooooooo0000ooooo`04o`0000Gooooo00?o0000
ooooooooool0LOooool00ol0003oooooooooo`0Kooooo`03o`000?oooooooooo073ooooo00001Ooo
oooo0000oooooooooooo000000Sooooo00Ko0000oooooooooooo0000ooooool00008ooooo`03o`00
0?oooooooooo077ooooo00?o0000ooooooooool06_ooool00ol0003oooooooooo`1aooooo`0000Go
ooooo`000?ooooooooooo`000008ooooo`04o`000?ooooooooooo`0000;ooooo00?o0000oooooooo
ool01Oooool00ol0003oooooooooo`1aooooo`03o`000?oooooooooo01[ooooo00?o0000oooooooo
ool0LOooool000;ooooo0_l0000:ooooo`;o00001?ooool2o`0000Gooooo00?o0000ooooooooool0
LOooool00ol0003oooooooooo`0Jooooo`03o`000?oooooooooo077ooooo000Kooooo`03o`000?oo
oooooooo077ooooo00?o0000ooooooooool06_ooool00ol0003oooooooooo`1aooooo`006oooool0
0ol0003oooooooooo`1booooo`03o`000?oooooooooo01Wooooo00?o0000ooooooooool0LOooool0
01_ooooo00?o0000ooooooooool0L_ooool00ol0003oooooooooo`0Hooooo`03o`000?oooooooooo
07;ooooo000Kooooo`;o0000Loooool00ol0003oooooooooo`0Hooooo`03o`000?oooooooooo07;o
oooo000Kooooo`03o`000?oooooooooo07;ooooo00?o0000ooooooooool06?ooool00ol0003ooooo
ooooo`1booooo`006oooool00ol0003oooooooooo`1booooo`03o`000?oooooooooo01Sooooo00?o
0000ooooooooool0L_ooool001_ooooo00?o0000ooooooooool0Loooool00ol0003oooooooooo`0G
ooooo`03o`000?oooooooooo07;ooooo000Kooooo`03o`000?oooooooooo07?ooooo00?o0000oooo
ooooool05_ooool00ol0003oooooooooo`1cooooo`006oooool00ol0003oooooooooo`1cooooo`03
o`000?oooooooooo01Kooooo00?o0000ooooooooool0Loooool001_ooooo00?o0000ooooooooool0
Loooool00ol0003oooooooooo`0Fooooo`03o`000?oooooooooo07?ooooo000Kooooo`03o`000?oo
oooooooo07?ooooo00?o0000ooooooooool05_ooool00ol0003oooooooooo`1cooooo`006oooool2
o`0007Cooooo00?o0000ooooooooool05_ooool00ol0003oooooooooo`1cooooo`006oooool00ol0
003oooooooooo`1dooooo`03o`000?oooooooooo01Cooooo00?o0000ooooooooool0M?ooool001_o
oooo00?o0000ooooooooool0M?ooool00ol0003oooooooooo`0Dooooo`03o`000?oooooooooo07Co
oooo000Kooooo`03o`000?oooooooooo07Cooooo00?o0000ooooooooool05?ooool00ol0003ooooo
ooooo`1dooooo`006oooool00ol0003oooooooooo`1dooooo`03o`000?oooooooooo01Cooooo00?o
0000ooooooooool0M?ooool001_ooooo00?o0000ooooooooool0M?ooool00ol0003oooooooooo`0D
ooooo`03o`000?oooooooooo07Cooooo000Kooooo`03o`000?oooooooooo07Cooooo00?o0000oooo
ooooool05?ooool00ol0003oooooooooo`1dooooo`006oooool2o`0007Gooooo00?o0000oooooooo
ool05?ooool00ol0003oooooooooo`1dooooo`006oooool00ol0003oooooooooo`1eooooo`03o`00
0?oooooooooo01;ooooo00?o0000ooooooooool0MOooool001_ooooo00?o0000ooooooooool0MOoo
ool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo07Gooooo000Kooooo`03o`000?oooooo
oooo07Gooooo00?o0000ooooooooool04_ooool00ol0003oooooooooo`1eooooo`006oooool00ol0
003oooooooooo`1eooooo`03o`000?oooooooooo01;ooooo00?o0000ooooooooool0MOooool000;o
oooo0_l00004ooooo`03o`000?oooooooooo00?ooooo0_l00003ooooo`?o00001Oooool00ol0003o
ooooooooo`1eooooo`03o`000?oooooooooo01;ooooo00?o0000ooooooooool0MOooool00005oooo
ool0003oooooooooool000002?ooool01_l0003oooooooooool0003oooooo`0000?ooooo00?o0000
ooooooooool00_ooool00ol0003oooooooooo`1eooooo`03o`000?oooooooooo01;ooooo00?o0000
ooooooooool0MOooool00005ooooool0003oooooooooool000002?ooool01_l0003oooooooooool0
003oooooo`0000?ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`1fooooo`03o`00
0?oooooooooo013ooooo00?o0000ooooooooool0M_ooool00005ooooool0003oooooooooool00000
2?ooool01?l0003oooooooooool00002ooooo`?o00001Oooool2o`0007Oooooo00?o0000oooooooo
ool04?ooool00ol0003oooooooooo`1fooooo`0000Goooooo`000?ooooooooooo`000008ooooo`06
o`000?ooooooooooo`000?oooooo00000oooool00ol0003oooooooooo`02ooooo`03o`000?oooooo
oooo07Kooooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`1fooooo`0000Goooooo`00
0?ooooooooooo`000008ooooo`06o`000?ooooooooooo`000?oooooo00000oooool00ol0003ooooo
ooooo`02ooooo`03o`000?oooooooooo07Kooooo00?o0000ooooooooool04?ooool00ol0003ooooo
ooooo`1fooooo`000_ooool2o`0000[ooooo0_l00003ooooo`?o00001Oooool00ol0003ooooooooo
o`1fooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool0M_ooool001_ooooo00?o0000
ooooooooool0M_ooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo07Kooooo000Koooo
o`03o`000?oooooooooo07Kooooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`1foooo
o`006oooool00ol0003oooooooooo`1gooooo`03o`000?oooooooooo00kooooo00?o0000oooooooo
ool0Moooool001_ooooo00?o0000ooooooooool0Moooool00ol0003oooooooooo`0>ooooo`03o`00
0?oooooooooo07Oooooo000Kooooo`;o0000N?ooool00ol0003oooooooooo`0>ooooo`03o`000?oo
oooooooo07Oooooo000Kooooo`03o`000?oooooooooo07Oooooo00?o0000ooooooooool03_ooool0
0ol0003oooooooooo`1gooooo`006oooool00ol0003oooooooooo`1gooooo`03o`000?oooooooooo
00kooooo00?o0000ooooooooool0Moooool001_ooooo00?o0000ooooooooool0Moooool00ol0003o
ooooooooo`0>ooooo`03o`000?oooooooooo07Oooooo000Kooooo`03o`000?oooooooooo07Sooooo
00?o0000ooooooooool03?ooool00ol0003oooooooooo`1hooooo`006oooool00ol0003ooooooooo
o`1hooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool0N?ooool001_ooooo00?o0000
ooooooooool0N?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo07Sooooo000Koooo
o`;o0000NOooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo07Sooooo000Kooooo`03
o`000?oooooooooo07Sooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`1hooooo`00
6oooool00ol0003oooooooooo`1hooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool0
N?ooool001_ooooo00?o0000ooooooooool0N?ooool00ol0003oooooooooo`0<ooooo`03o`000?oo
oooooooo07Sooooo000Kooooo`03o`000?oooooooooo07Wooooo00?o0000ooooooooool02_ooool0
0ol0003oooooooooo`1iooooo`006oooool00ol0003oooooooooo`1iooooo`03o`000?oooooooooo
00[ooooo00?o0000ooooooooool0NOooool001_ooooo00?o0000ooooooooool0NOooool00ol0003o
ooooooooo`0:ooooo`03o`000?oooooooooo07Wooooo000Kooooo`03o`000?oooooooooo07Wooooo
00?o0000ooooooooool02_ooool00ol0003oooooooooo`1iooooo`006oooool2o`0007[ooooo00?o
0000ooooooooool02_ooool00ol0003oooooooooo`1iooooo`006oooool00ol0003oooooooooo`1i
ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool0NOooool001_ooooo00?o0000oooo
ooooool0N_ooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo07[ooooo000Kooooo`03
o`000?oooooooooo07[ooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`1jooooo`00
6oooool00ol0003oooooooooo`1jooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool0
N_ooool000Sooooo0_l00004ooooo`03o`000?oooooooooo00;ooooo0ol00005ooooo`03o`000?oo
oooooooo07[ooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`1jooooo`001oooool0
1?l0003oooooooooool00009ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0N_oo
ool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo07[ooooo0007ooooo`04o`000?oooooo
ooooo`0000Wooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`1jooooo`03o`000?oo
oooooooo00Sooooo00?o0000ooooooooool0N_ooool000Oooooo00Co0000oooooooooooo00002Ooo
ool00ol0003oooooooooo`04ooooo`;o0000Noooool00ol0003oooooooooo`08ooooo`03o`000?oo
oooooooo07[ooooo0007ooooo`04o`000?ooooooooooo`0000Wooooo00?o0000ooooooooool01?oo
ool00ol0003oooooooooo`1kooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0Nooo
ool000Oooooo00Co0000oooooooooooo00002?ooool2o`0000Kooooo00?o0000ooooooooool0Nooo
ool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo07_ooooo0008ooooo`;o00002_ooool0
0ol0003oooooooooo`04ooooo`03o`000?oooooooooo07_ooooo2_l0001mooooo`006oooool00ol0
003oooooooooo`3oooooo`?ooooo000Kooooo`03o`000?oooooooooo0?oooooo0oooool001_ooooo
00?o0000ooooooooool0ooooool3ooooo`00oooooolQooooo`00oooooolQooooo`00\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-3.23594, -0.00936143, \
0.118419, 0.000650643}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.031746 0.0147151 9.17656 [
[.18254 .00222 -3 -9 ]
[.18254 .00222 3 0 ]
[.34127 .00222 -6 -9 ]
[.34127 .00222 6 0 ]
[.5 .00222 -6 -9 ]
[.5 .00222 6 0 ]
[.65873 .00222 -6 -9 ]
[.65873 .00222 6 0 ]
[.81746 .00222 -6 -9 ]
[.81746 .00222 6 0 ]
[.97619 .00222 -6 -9 ]
[.97619 .00222 6 0 ]
[.01131 .10648 -24 -4.5 ]
[.01131 .10648 0 4.5 ]
[.01131 .19825 -24 -4.5 ]
[.01131 .19825 0 4.5 ]
[.01131 .29001 -24 -4.5 ]
[.01131 .29001 0 4.5 ]
[.01131 .38178 -24 -4.5 ]
[.01131 .38178 0 4.5 ]
[.01131 .47354 -24 -4.5 ]
[.01131 .47354 0 4.5 ]
[.01131 .56531 -24 -4.5 ]
[.01131 .56531 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.18254 .01472 m
.18254 .02097 L
s
[(5)] .18254 .00222 0 1 Mshowa
.34127 .01472 m
.34127 .02097 L
s
[(10)] .34127 .00222 0 1 Mshowa
.5 .01472 m
.5 .02097 L
s
[(15)] .5 .00222 0 1 Mshowa
.65873 .01472 m
.65873 .02097 L
s
[(20)] .65873 .00222 0 1 Mshowa
.81746 .01472 m
.81746 .02097 L
s
[(25)] .81746 .00222 0 1 Mshowa
.97619 .01472 m
.97619 .02097 L
s
[(30)] .97619 .00222 0 1 Mshowa
.125 Mabswid
.05556 .01472 m
.05556 .01847 L
s
.0873 .01472 m
.0873 .01847 L
s
.11905 .01472 m
.11905 .01847 L
s
.15079 .01472 m
.15079 .01847 L
s
.21429 .01472 m
.21429 .01847 L
s
.24603 .01472 m
.24603 .01847 L
s
.27778 .01472 m
.27778 .01847 L
s
.30952 .01472 m
.30952 .01847 L
s
.37302 .01472 m
.37302 .01847 L
s
.40476 .01472 m
.40476 .01847 L
s
.43651 .01472 m
.43651 .01847 L
s
.46825 .01472 m
.46825 .01847 L
s
.53175 .01472 m
.53175 .01847 L
s
.56349 .01472 m
.56349 .01847 L
s
.59524 .01472 m
.59524 .01847 L
s
.62698 .01472 m
.62698 .01847 L
s
.69048 .01472 m
.69048 .01847 L
s
.72222 .01472 m
.72222 .01847 L
s
.75397 .01472 m
.75397 .01847 L
s
.78571 .01472 m
.78571 .01847 L
s
.84921 .01472 m
.84921 .01847 L
s
.88095 .01472 m
.88095 .01847 L
s
.9127 .01472 m
.9127 .01847 L
s
.94444 .01472 m
.94444 .01847 L
s
.25 Mabswid
0 .01472 m
1 .01472 L
s
.02381 .10648 m
.03006 .10648 L
s
[(0.01)] .01131 .10648 1 0 Mshowa
.02381 .19825 m
.03006 .19825 L
s
[(0.02)] .01131 .19825 1 0 Mshowa
.02381 .29001 m
.03006 .29001 L
s
[(0.03)] .01131 .29001 1 0 Mshowa
.02381 .38178 m
.03006 .38178 L
s
[(0.04)] .01131 .38178 1 0 Mshowa
.02381 .47354 m
.03006 .47354 L
s
[(0.05)] .01131 .47354 1 0 Mshowa
.02381 .56531 m
.03006 .56531 L
s
[(0.06)] .01131 .56531 1 0 Mshowa
.125 Mabswid
.02381 .03307 m
.02756 .03307 L
s
.02381 .05142 m
.02756 .05142 L
s
.02381 .06977 m
.02756 .06977 L
s
.02381 .08813 m
.02756 .08813 L
s
.02381 .12483 m
.02756 .12483 L
s
.02381 .14319 m
.02756 .14319 L
s
.02381 .16154 m
.02756 .16154 L
s
.02381 .17989 m
.02756 .17989 L
s
.02381 .2166 m
.02756 .2166 L
s
.02381 .23495 m
.02756 .23495 L
s
.02381 .25331 m
.02756 .25331 L
s
.02381 .27166 m
.02756 .27166 L
s
.02381 .30836 m
.02756 .30836 L
s
.02381 .32672 m
.02756 .32672 L
s
.02381 .34507 m
.02756 .34507 L
s
.02381 .36342 m
.02756 .36342 L
s
.02381 .40013 m
.02756 .40013 L
s
.02381 .41848 m
.02756 .41848 L
s
.02381 .43684 m
.02756 .43684 L
s
.02381 .45519 m
.02756 .45519 L
s
.02381 .4919 m
.02756 .4919 L
s
.02381 .51025 m
.02756 .51025 L
s
.02381 .5286 m
.02756 .5286 L
s
.02381 .54696 m
.02756 .54696 L
s
.02381 .58366 m
.02756 .58366 L
s
.02381 .60201 m
.02756 .60201 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.05556 .01491 m
.0873 .01495 L
.11905 .01508 L
.15079 .01534 L
.18254 .01584 L
.21429 .01682 L
.24603 .01873 L
.27778 .02248 L
.30952 .02992 L
.34127 .04467 L
.37302 .07376 L
.40476 .12983 L
.43651 .2326 L
.46825 .4006 L
.5 .60332 L
.53175 .60332 L
.56349 .4006 L
.59524 .2326 L
.62698 .12983 L
.65873 .07376 L
.69048 .04467 L
.72222 .02992 L
.75397 .02248 L
.78571 .01873 L
.81746 .01682 L
.84921 .01584 L
.88095 .01534 L
.9127 .01508 L
.94444 .01495 L
.97619 .01491 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[37]:=",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/B000`400?l00000o`00003ooooooolQ
ooooo`00oooooolQooooo`00oooooolQooooo`00@oooool3o`0002Cooooo0ol00004ooooo`;o0000
8Oooool3o`0000?ooooo0ol0000Qooooo`Go00000oooool2o`00023ooooo1Ol00002ooooo`?o0000
8Oooool3o`0000Cooooo0_l00004ooooo`00@_ooool01Ol0003ooooooooooooooooo000002Cooooo
00?o0000ooooooooool00_ooool01?l0003oooooooooool0000Qooooo`05o`000?oooooooooooooo
ool000000oooool00ol0003oooooooooo`0Oooooo`04o`000?ooooooooooo`0000;ooooo00Co0000
oooooooooooo00008?ooool01_l0003oooooooooool0003oooooo`0000?ooooo00?o0000oooooooo
ool07Oooool01Ol0003ooooooooooooooooo000000;ooooo00Co0000oooooooooooo00000oooool0
04Kooooo00?o0000ooooooooool08_ooool00ol0003oooooooooo`02ooooo`04o`000?oooooooooo
o`00027ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`0Pooooo`03o`000?oooooo
oooo00;ooooo00Co0000oooooooooooo00008Oooool00ol0003oooooooooo`05ooooo`03o`000?oo
oooooooo027ooooo00Co0000oooooooooooo00000_ooool00ol0003oooooooooo`01ooooo`00A_oo
ool00ol0003oooooooooo`0Rooooo`03o`000?oooooooooo00;ooooo00Co0000oooooooooooo0000
8Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo027ooooo00Go0000oooooooooooo
ooooo`000002ooooo`03o`000?oooooooooo023ooooo00?o0000ooooooooool01?ooool00ol0003o
ooooooooo`0Oooooo`;o00000oooool01?l0003oooooooooool00003ooooo`00@_ooool4o`0002Go
oooo00?o0000ooooooooool00_ooool01?l0003oooooooooool0000Qooooo`04o`000?oooooooooo
ooooo`Co00008Oooool01Ol0003ooooooooooooooooo000000;ooooo00Co0000oooooooooooo0000
7oooool01_l0003ooooooooooooooooo0000ooooo`Co00009?ooool01?l0003oooooooooool00002
ooooo`03o`000?oooooooooo007ooooo0012ooooo`03o`000?oooooooooo02Gooooo0_l00004oooo
o`04o`000?ooooooooooo`00023ooooo0_l00003ooooo`03o`000?oooooooooo02;ooooo00Go0000
ooooooooooooooooo`000002ooooo`04o`000?ooooooooooo`0001oooooo00Oo0000oooooooooooo
ooooo`000?oooooo000002?ooooo00Go0000ooooooooooooooooo`000002ooooo`04o`000?oooooo
ooooo`0000?ooooo0012ooooo`Go00009?ooool00ol0003oooooooooo`03ooooo`;o00008_ooool0
1?l0003oooooooooooooool5o`00027ooooo0ol00004ooooo`;o00008Oooool3o`0000;ooooo1Ol0
000Pooooo`?o00001?ooool2o`0000Cooooo000Kooooo`03o`000?oooooooooo0?oooooo0oooool0
01_ooooo00?o0000ooooooooool0ooooool3ooooo`006oooool00ol0003oooooooooo`3oooooo`?o
oooo000Kooooo`03o`000?oooooooooo0?oooooo0oooool001Coooooool0000=o`0000006oooool0
0ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01Oooool0
0ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Gooooo00<00000ooooooooool00_oooolA
o`0000?ooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooo
oooo00Kooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`06ooooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`06ooooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooo
oooo00Kooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`06ooooo`03o`000?oooooo
oooo00Gooooo00Co0000oooooooooooooooo4Ol00004ooooo`03o`000?oooooooooo00Kooooo00?o
0000ooooooooool01Oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Gooooo00?o
0000ooooooooool01Oooool001_ooooo00?o0000ooooooooool09oooool00`00003oooooooooo`0C
ooooo`Ko00003_ooool00ol0003oooooooooo`0Wooooo`03o`000?oooooooooo02Sooooo00?o0000
ooooooooool05?ooool6o`0000gooooo00?o0000ooooooooool09oooool00ol0003oooooooooo`05
ooooo`006oooool00ol0003oooooooooo`13ooooo`Go0000LOooool4o`0004Gooooo000Kooooo`03
o`000?oooooooooo04Sooooo0ol0001[ooooo`?o0000BOooool001_ooooo0_l0001<ooooo`;o0000
Ioooool2o`0004cooooo000Kooooo`03o`000?oooooooooo04gooooo0_l0001Rooooo`?o0000C_oo
ool001_ooooo00?o0000ooooooooool0Coooool2o`0005kooooo0_l0001Aooooo`006oooool00ol0
003oooooooooo`1Aooooo`;o0000Foooool00ol0003oooooooooo`1Aooooo`006oooool00ol0003o
ooooooooo`1Cooooo`03o`000?oooooooooo05Oooooo00?o0000ooooooooool0D_ooool001_ooooo
0_l0001Eooooo`03o`000?oooooooooo05Gooooo00?o0000ooooooooool0Doooool001_ooooo00?o
0000ooooooooool0EOooool00ol0003oooooooooo`1Cooooo`03o`000?oooooooooo05Cooooo000K
ooooo`03o`000?oooooooooo05Kooooo00?o0000ooooooooool0DOooool00ol0003oooooooooo`1E
ooooo`006oooool00ol0003oooooooooo`1Gooooo`03o`000?oooooooooo04oooooo00?o0000oooo
ooooool0E_ooool001_ooooo00?o0000ooooooooool0F?ooool00ol0003oooooooooo`1=ooooo`03
o`000?oooooooooo05Oooooo000Kooooo`;o0000F_ooool00ol0003oooooooooo`1;ooooo`03o`00
0?oooooooooo05Sooooo000Kooooo`03o`000?oooooooooo05[ooooo00?o0000ooooooooool0BOoo
ool00ol0003oooooooooo`1Iooooo`006oooool00ol0003oooooooooo`1Jooooo`03o`000?oooooo
oooo04Wooooo00?o0000ooooooooool0FOooool001_ooooo00?o0000ooooooooool0Foooool00ol0
003oooooooooo`17ooooo`03o`000?oooooooooo05[ooooo000Kooooo`;o0000G?ooool00ol0003o
ooooooooo`16ooooo`03o`000?oooooooooo05_ooooo000Kooooo`03o`000?oooooooooo05cooooo
00?o0000ooooooooool0AOooool00ol0003oooooooooo`1Kooooo`006oooool00ol0003ooooooooo
o`1Looooo`03o`000?oooooooooo04Cooooo00?o0000ooooooooool0G?ooool000;ooooo0_l00004
ooooo`03o`000?oooooooooo00?ooooo0_l00003ooooo`?o00001Oooool00ol0003oooooooooo`1M
ooooo`03o`000?oooooooooo04?ooooo00?o0000ooooooooool0G?ooool00005ooooool0003ooooo
ooooool000002?ooool01?l0003oooooooooool00003ooooo`03o`000?oooooooooo00Cooooo00?o
0000ooooooooool0GOooool00ol0003oooooooooo`12ooooo`03o`000?oooooooooo05gooooo0000
1Ooooooo0000oooooooooooo000000Sooooo00Co0000oooooooooooo00000oooool00ol0003ooooo
ooooo`04ooooo`;o0000Goooool00ol0003oooooooooo`10ooooo`03o`000?oooooooooo05kooooo
00001Ooooooo0000oooooooooooo000000Sooooo00Co0000oooooooooooo00000oooool00ol0003o
ooooooooo`04ooooo`03o`000?oooooooooo05oooooo00?o0000ooooooooool0?oooool00ol0003o
ooooooooo`1Nooooo`0000Goooooo`000?ooooooooooo`000008ooooo`04o`000?ooooooooooo`00
00?ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`1Oooooo`03o`000?oooooooooo
03kooooo00?o0000ooooooooool0Goooool00005ooooool0003oooooooooool000002?ooool01?l0
003oooooooooool00002ooooo`;o00001_ooool00ol0003oooooooooo`1Pooooo`03o`000?oooooo
oooo03gooooo00?o0000ooooooooool0Goooool000;ooooo0_l0000:ooooo`;o00001?ooool00ol0
003oooooooooo`04ooooo`03o`000?oooooooooo063ooooo00?o0000ooooooooool0??ooool00ol0
003oooooooooo`1Pooooo`006oooool2o`0006;ooooo00?o0000ooooooooool0>_ooool00ol0003o
ooooooooo`1Qooooo`006oooool00ol0003oooooooooo`1Qooooo`03o`000?oooooooooo03[ooooo
00?o0000ooooooooool0HOooool001_ooooo00?o0000ooooooooool0H_ooool00ol0003ooooooooo
o`0hooooo`03o`000?oooooooooo06;ooooo000Kooooo`03o`000?oooooooooo06;ooooo00?o0000
ooooooooool0>?ooool00ol0003oooooooooo`1Rooooo`006oooool00ol0003oooooooooo`1Soooo
o`03o`000?oooooooooo03Oooooo00?o0000ooooooooool0H_ooool001_ooooo0_l0001Tooooo`03
o`000?oooooooooo03Kooooo00?o0000ooooooooool0Hoooool001_ooooo00?o0000ooooooooool0
Hoooool00ol0003oooooooooo`0fooooo`03o`000?oooooooooo06?ooooo000Kooooo`03o`000?oo
oooooooo06Cooooo00?o0000ooooooooool0=Oooool00ol0003oooooooooo`1Sooooo`006oooool0
0ol0003oooooooooo`1Tooooo`03o`000?oooooooooo03Cooooo00?o0000ooooooooool0I?ooool0
01_ooooo00?o0000ooooooooool0I?ooool00ol0003oooooooooo`0dooooo`03o`000?oooooooooo
06Cooooo000Kooooo`;o0000I_ooool00ol0003oooooooooo`0cooooo`03o`000?oooooooooo06Co
oooo000Kooooo`03o`000?oooooooooo06Gooooo00?o0000ooooooooool0<_ooool00ol0003ooooo
ooooo`1Uooooo`006oooool00ol0003oooooooooo`1Uooooo`03o`000?oooooooooo03;ooooo00?o
0000ooooooooool0IOooool001_ooooo00?o0000ooooooooool0I_ooool00ol0003oooooooooo`0a
ooooo`03o`000?oooooooooo06Gooooo000Kooooo`03o`000?oooooooooo06Kooooo00?o0000oooo
ooooool0<Oooool00ol0003oooooooooo`1Uooooo`006oooool2o`0006Oooooo00?o0000oooooooo
ool0<?ooool00ol0003oooooooooo`1Vooooo`006oooool00ol0003oooooooooo`1Wooooo`03o`00
0?oooooooooo02oooooo00?o0000ooooooooool0I_ooool000;ooooo0_l00004ooooo`03o`000?oo
oooooooo00?ooooo0_l00002ooooo`Go00001?ooool00ol0003oooooooooo`1Wooooo`03o`000?oo
oooooooo02oooooo00?o0000ooooooooool0I_ooool00005ooooool0003oooooooooool000002?oo
ool01?l0003oooooooooool00002ooooo`04o`000?ooooooooooo`0000Cooooo00?o0000oooooooo
ool0Ioooool00ol0003oooooooooo`0^ooooo`03o`000?oooooooooo06Oooooo00001Ooooooo0000
oooooooooooo000000Sooooo00Co0000oooooooooooo00000oooool00ol0003oooooooooo`04oooo
o`03o`000?oooooooooo06Sooooo00?o0000ooooooooool0;Oooool00ol0003oooooooooo`1Woooo
o`0000Goooooo`000?ooooooooooo`000008ooooo`04o`000?ooooooooooo`0000Cooooo00?o0000
ooooooooool00oooool2o`0006Wooooo00?o0000ooooooooool0;Oooool00ol0003oooooooooo`1W
ooooo`0000Goooooo`000?ooooooooooo`000008ooooo`06o`000?ooooooooooo`000?oooooo0000
0oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo06Sooooo00?o0000ooooooooool0
;Oooool00ol0003oooooooooo`1Wooooo`0000Goooooo`000?ooooooooooo`000008ooooo`06o`00
0?ooooooooooo`000?oooooo00000oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo
06Wooooo00?o0000ooooooooool0:oooool00ol0003oooooooooo`1Xooooo`000_ooool2o`0000[o
oooo0_l00003ooooo`?o00001Oooool00ol0003oooooooooo`1Yooooo`03o`000?oooooooooo02_o
oooo00?o0000ooooooooool0J?ooool001_ooooo00?o0000ooooooooool0JOooool00ol0003ooooo
ooooo`0[ooooo`03o`000?oooooooooo06Sooooo000Kooooo`;o0000Joooool00ol0003ooooooooo
o`0Yooooo`03o`000?oooooooooo06Wooooo000Kooooo`03o`000?oooooooooo06[ooooo00?o0000
ooooooooool0:Oooool00ol0003oooooooooo`1Yooooo`006oooool00ol0003oooooooooo`1Zoooo
o`03o`000?oooooooooo02Wooooo00?o0000ooooooooool0JOooool001_ooooo00?o0000oooooooo
ool0Joooool00ol0003oooooooooo`0Wooooo`03o`000?oooooooooo06[ooooo000Kooooo`03o`00
0?oooooooooo06_ooooo00?o0000ooooooooool09oooool00ol0003oooooooooo`1Zooooo`006ooo
ool2o`0006cooooo00?o0000ooooooooool09oooool00ol0003oooooooooo`1Zooooo`006oooool0
0ol0003oooooooooo`1[ooooo`03o`000?oooooooooo02Oooooo00?o0000ooooooooool0J_ooool0
01_ooooo00?o0000ooooooooool0Joooool00ol0003oooooooooo`0Vooooo`03o`000?oooooooooo
06_ooooo000Kooooo`03o`000?oooooooooo06cooooo00?o0000ooooooooool09Oooool00ol0003o
ooooooooo`1[ooooo`006oooool2o`0006gooooo00?o0000ooooooooool09Oooool00ol0003ooooo
ooooo`1[ooooo`006oooool00ol0003oooooooooo`1/ooooo`03o`000?oooooooooo02Gooooo00?o
0000ooooooooool0Joooool001_ooooo00?o0000ooooooooool0K?ooool00ol0003oooooooooo`0U
ooooo`03o`000?oooooooooo06_ooooo000Kooooo`03o`000?oooooooooo06cooooo00?o0000oooo
ooooool09?ooool00ol0003oooooooooo`1/ooooo`006oooool00ol0003oooooooooo`1]ooooo`03
o`000?oooooooooo02?ooooo00?o0000ooooooooool0K?ooool001_ooooo0_l0001^ooooo`03o`00
0?oooooooooo02?ooooo00?o0000ooooooooool0K?ooool001_ooooo00?o0000ooooooooool0KOoo
ool00ol0003oooooooooo`0Sooooo`03o`000?oooooooooo06cooooo000Kooooo`03o`000?oooooo
oooo06gooooo00?o0000ooooooooool08oooool00ol0003oooooooooo`1/ooooo`000_ooool2o`00
00Cooooo00?o0000ooooooooool00oooool2o`0000?ooooo0ol00005ooooo`03o`000?oooooooooo
06gooooo00?o0000ooooooooool08_ooool00ol0003oooooooooo`1]ooooo`0000Goooooo`000?oo
ooooooooo`000008ooooo`06o`000?ooooooooooo`000?oooooo00000oooool00ol0003ooooooooo
o`02ooooo`03o`000?oooooooooo06gooooo00?o0000ooooooooool08_ooool00ol0003ooooooooo
o`1]ooooo`0000Goooooo`000?ooooooooooo`000008ooooo`04o`000?ooooooooooo`0000Gooooo
00?o0000ooooooooool00_ooool2o`0006oooooo00?o0000ooooooooool08Oooool00ol0003ooooo
ooooo`1]ooooo`0000Goooooo`000?ooooooooooo`000008ooooo`04o`000?ooooooooooo`0000?o
oooo0_l00005ooooo`03o`000?oooooooooo06kooooo00?o0000ooooooooool08Oooool00ol0003o
ooooooooo`1]ooooo`0000Goooooo`000?ooooooooooo`000008ooooo`04o`000?ooooooooooo`00
00Gooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`1^ooooo`03o`000?oooooooooo
027ooooo00?o0000ooooooooool0KOooool00005ooooool0003oooooooooool000002?ooool01_l0
003oooooooooool0003oooooo`0000?ooooo00?o0000ooooooooool00_ooool00ol0003ooooooooo
o`1^ooooo`03o`000?oooooooooo023ooooo00?o0000ooooooooool0K_ooool000;ooooo0_l0000:
ooooo`;o00000oooool3o`0000Gooooo00?o0000ooooooooool0K_ooool00ol0003oooooooooo`0P
ooooo`03o`000?oooooooooo06kooooo000Kooooo`;o0000Koooool00ol0003oooooooooo`0Poooo
o`03o`000?oooooooooo06kooooo000Kooooo`03o`000?oooooooooo06oooooo00?o0000oooooooo
ool07oooool00ol0003oooooooooo`1^ooooo`006oooool00ol0003oooooooooo`1_ooooo`03o`00
0?oooooooooo01oooooo00?o0000ooooooooool0K_ooool001_ooooo00?o0000ooooooooool0Kooo
ool00ol0003oooooooooo`0Nooooo`03o`000?oooooooooo06oooooo000Kooooo`03o`000?oooooo
oooo06oooooo00?o0000ooooooooool07_ooool00ol0003oooooooooo`1_ooooo`006oooool2o`00
073ooooo00?o0000ooooooooool07_ooool00ol0003oooooooooo`1_ooooo`006oooool00ol0003o
ooooooooo`1`ooooo`03o`000?oooooooooo01gooooo00?o0000ooooooooool0Koooool001_ooooo
00?o0000ooooooooool0L?ooool00ol0003oooooooooo`0Mooooo`03o`000?oooooooooo06oooooo
000Kooooo`03o`000?oooooooooo073ooooo00?o0000ooooooooool07?ooool00ol0003ooooooooo
o`1`ooooo`006oooool00ol0003oooooooooo`1`ooooo`03o`000?oooooooooo01cooooo00?o0000
ooooooooool0L?ooool001_ooooo0_l0001aooooo`03o`000?oooooooooo01cooooo00?o0000oooo
ooooool0L?ooool001_ooooo00?o0000ooooooooool0L?ooool00ol0003oooooooooo`0Looooo`03
o`000?oooooooooo073ooooo000Kooooo`03o`000?oooooooooo077ooooo00?o0000ooooooooool0
6oooool00ol0003oooooooooo`1`ooooo`006oooool00ol0003oooooooooo`1aooooo`03o`000?oo
oooooooo01[ooooo00?o0000ooooooooool0LOooool001_ooooo00?o0000ooooooooool0LOooool0
0ol0003oooooooooo`0Jooooo`03o`000?oooooooooo077ooooo000Kooooo`;o0000L_ooool00ol0
003oooooooooo`0Jooooo`03o`000?oooooooooo077ooooo000Kooooo`03o`000?oooooooooo077o
oooo00?o0000ooooooooool06_ooool00ol0003oooooooooo`1aooooo`000_ooool2o`0000Cooooo
00?o0000ooooooooool00oooool2o`0000Cooooo0ol00004ooooo`03o`000?oooooooooo077ooooo
00?o0000ooooooooool06_ooool00ol0003oooooooooo`1aooooo`0000Goooooo`000?oooooooooo
o`000008ooooo`04o`000?ooooooooooo`0000Cooooo00?o0000ooooooooool00oooool00ol0003o
ooooooooo`1booooo`03o`000?oooooooooo01Sooooo00?o0000ooooooooool0L_ooool00005oooo
ool0003oooooooooool000002?ooool01Ol0003oooooooooool0003ooooo00Go00001?ooool00ol0
003oooooooooo`1booooo`03o`000?oooooooooo01Sooooo00?o0000ooooooooool0L_ooool00005
ooooool0003oooooooooool000002?ooool01_l0003oooooooooool0003oooooo`0000;ooooo00?o
0000ooooooooool00oooool2o`0007?ooooo00?o0000ooooooooool06?ooool00ol0003ooooooooo
o`1booooo`0000Goooooo`000?ooooooooooo`000008ooooo`04o`000?ooooooooooo`0000;ooooo
00?o0000ooooool000001Oooool00ol0003oooooooooo`1booooo`03o`000?oooooooooo01Sooooo
00?o0000ooooooooool0L_ooool00005ooooool0003oooooooooool000002?ooool01?l0003ooooo
ooooool00003ooooo`;o00001Oooool00ol0003oooooooooo`1booooo`03o`000?oooooooooo01So
oooo00?o0000ooooooooool0L_ooool000;ooooo0_l0000:ooooo`;o00001Oooool00ol0003ooooo
ooooo`03ooooo`03o`000?oooooooooo07?ooooo00?o0000ooooooooool05_ooool00ol0003ooooo
ooooo`1cooooo`006oooool2o`0007Cooooo00?o0000ooooooooool05_ooool00ol0003ooooooooo
o`1cooooo`006oooool00ol0003oooooooooo`1cooooo`03o`000?oooooooooo01Kooooo00?o0000
ooooooooool0Loooool001_ooooo00?o0000ooooooooool0Loooool00ol0003oooooooooo`0Foooo
o`03o`000?oooooooooo07?ooooo000Kooooo`03o`000?oooooooooo07?ooooo00?o0000oooooooo
ool05_ooool00ol0003oooooooooo`1cooooo`006oooool00ol0003oooooooooo`1cooooo`03o`00
0?oooooooooo01Kooooo00?o0000ooooooooool0Loooool001_ooooo0_l0001eooooo`03o`000?oo
oooooooo01Cooooo00?o0000ooooooooool0M?ooool001_ooooo00?o0000ooooooooool0M?ooool0
0ol0003oooooooooo`0Dooooo`03o`000?oooooooooo07Cooooo000Kooooo`03o`000?oooooooooo
07Cooooo00?o0000ooooooooool05?ooool00ol0003oooooooooo`1dooooo`006oooool00ol0003o
ooooooooo`1dooooo`03o`000?oooooooooo01Cooooo00?o0000ooooooooool0M?ooool001_ooooo
00?o0000ooooooooool0M?ooool00ol0003oooooooooo`0Dooooo`03o`000?oooooooooo07Cooooo
000Kooooo`;o0000MOooool00ol0003oooooooooo`0Dooooo`03o`000?oooooooooo07Cooooo000K
ooooo`03o`000?oooooooooo07Cooooo00?o0000ooooooooool05?ooool00ol0003oooooooooo`1d
ooooo`006oooool00ol0003oooooooooo`1eooooo`03o`000?oooooooooo01;ooooo00?o0000oooo
ooooool0MOooool001_ooooo00?o0000ooooooooool0MOooool00ol0003oooooooooo`0Booooo`03
o`000?oooooooooo07Gooooo000Kooooo`03o`000?oooooooooo07Gooooo00?o0000ooooooooool0
4_ooool00ol0003oooooooooo`1eooooo`006oooool2o`0007Kooooo00?o0000ooooooooool04_oo
ool00ol0003oooooooooo`1eooooo`006oooool00ol0003oooooooooo`1eooooo`03o`000?oooooo
oooo01;ooooo00?o0000ooooooooool0MOooool000;ooooo0_l00004ooooo`03o`000?oooooooooo
00?ooooo0_l00003ooooo`?o00001Oooool00ol0003oooooooooo`1eooooo`03o`000?oooooooooo
01;ooooo00?o0000ooooooooool0MOooool00005ooooool0003oooooooooool000002?ooool01_l0
003oooooooooool0003oooooo`0000?ooooo00?o0000ooooooooool00_ooool00ol0003ooooooooo
o`1eooooo`03o`000?oooooooooo01;ooooo00?o0000ooooooooool0MOooool00005ooooool0003o
ooooooooool000002?ooool01?l0003oooooooooool00005ooooo`03o`000?oooooooooo00;ooooo
00?o0000ooooooooool0M_ooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo07Kooooo
00001Ooooooo0000oooooooooooo000000Sooooo00Co0000oooooooooooo00001Oooool00ol0003o
ooooooooo`02ooooo`;o0000Moooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo07Ko
oooo00001Ooooooo0000oooooooooooo000000Sooooo00Go0000oooooooooooo0000ooooo`04o`00
00Gooooo00?o0000ooooooooool0M_ooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo
07Kooooo00001Ooooooo0000oooooooooooo000000Sooooo00Ko0000oooooooooooo0000ooooool0
0008ooooo`03o`000?oooooooooo07Kooooo00?o0000ooooooooool04?ooool00ol0003ooooooooo
o`1fooooo`000_ooool2o`0000[ooooo0_l00002ooooo`Go00001?ooool00ol0003oooooooooo`1f
ooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool0M_ooool001_ooooo00?o0000oooo
ooooool0M_ooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo07Kooooo000Kooooo`;o
0000Moooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo07Kooooo000Kooooo`03o`00
0?oooooooooo07Oooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`1gooooo`006ooo
ool00ol0003oooooooooo`1gooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool0Mooo
ool001_ooooo00?o0000ooooooooool0Moooool00ol0003oooooooooo`0>ooooo`03o`000?oooooo
oooo07Oooooo000Kooooo`03o`000?oooooooooo07Oooooo00?o0000ooooooooool03_ooool00ol0
003oooooooooo`1gooooo`006oooool2o`0007Sooooo00?o0000ooooooooool03_ooool00ol0003o
ooooooooo`1gooooo`006oooool00ol0003oooooooooo`1gooooo`03o`000?oooooooooo00kooooo
00?o0000ooooooooool0Moooool001_ooooo00?o0000ooooooooool0N?ooool00ol0003ooooooooo
o`0<ooooo`03o`000?oooooooooo07Sooooo000Kooooo`03o`000?oooooooooo07Sooooo00?o0000
ooooooooool03?ooool00ol0003oooooooooo`1hooooo`006oooool00ol0003oooooooooo`1hoooo
o`03o`000?oooooooooo00cooooo00?o0000ooooooooool0N?ooool001_ooooo0_l0001iooooo`03
o`000?oooooooooo00cooooo00?o0000ooooooooool0N?ooool001_ooooo00?o0000ooooooooool0
N?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo07Sooooo000Kooooo`03o`000?oo
oooooooo07Sooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`1hooooo`006oooool0
0ol0003oooooooooo`1hooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool0N?ooool0
01_ooooo00?o0000ooooooooool0NOooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo
07Wooooo000Kooooo`;o0000N_ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo07Wo
oooo000Kooooo`03o`000?oooooooooo07Wooooo00?o0000ooooooooool02_ooool00ol0003ooooo
ooooo`1iooooo`000_ooool2o`0000Cooooo00?o0000ooooooooool00oooool2o`0000?ooooo0ol0
0005ooooo`03o`000?oooooooooo07Wooooo00?o0000ooooooooool02_ooool00ol0003ooooooooo
o`1iooooo`0000Goooooo`000?ooooooooooo`000008ooooo`06o`000?ooooooooooo`000?oooooo
00000oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo07Wooooo00?o0000oooooooo
ool02_ooool00ol0003oooooooooo`1iooooo`0000Goooooo`000?ooooooooooo`000008ooooo`06
o`000?ooooooooooo`000?oooooo00000oooool00ol0003oooooooooo`02ooooo`;o0000N_ooool0
0ol0003oooooooooo`0:ooooo`03o`000?oooooooooo07Wooooo00001Ooooooo0000oooooooooooo
000000Sooooo00Go0000oooooooooooo0000ooooo`04o`0000Gooooo00?o0000ooooooooool0NOoo
ool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo07Wooooo00001Ooooooo0000oooooooo
oooo000000Sooooo00Ko0000oooooooooooo0000ooooool00008ooooo`03o`000?oooooooooo07[o
oooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`1jooooo`0000Goooooo`000?oooooo
ooooo`000008ooooo`04o`000?ooooooooooo`0000;ooooo00?o0000ooooooooool01Oooool00ol0
003oooooooooo`1jooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool0N_ooool000;o
oooo0_l0000:ooooo`;o00001?ooool2o`0000Gooooo00?o0000ooooooooool0N_ooool00ol0003o
ooooooooo`08ooooo`03o`000?oooooooooo07[ooooo000Kooooo`;o0000Noooool00ol0003ooooo
ooooo`08ooooo`03o`000?oooooooooo07[ooooo000Kooooo`03o`000?oooooooooo07[ooooo00?o
0000ooooooooool02?ooool00ol0003oooooooooo`1jooooo`006oooool00ol0003oooooooooo`1j
ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool0N_ooool001_ooooo00?o0000oooo
ooooool0N_ooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo07[ooooo000Kooooo`03
o`000?oooooooooo07_ooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`1kooooo`00
6oooool2o`0007cooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`1kooooo`006ooo
ool00ol0003oooooooooo`1kooooo`[o0000OOooool001_ooooo00?o0000ooooooooool0ooooool3
ooooo`006oooool00ol0003oooooooooo`3oooooo`?ooooo000Kooooo`03o`000?oooooooooo0?oo
oooo0oooool00?oooooo8Oooool00?oooooo8Oooool00001\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-3.23594, -0.00589425, \
0.118419, 0.000409665}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.031746 0.0147151 15.5578 [
[.18254 .00222 -3 -9 ]
[.18254 .00222 3 0 ]
[.34127 .00222 -6 -9 ]
[.34127 .00222 6 0 ]
[.5 .00222 -6 -9 ]
[.5 .00222 6 0 ]
[.65873 .00222 -6 -9 ]
[.65873 .00222 6 0 ]
[.81746 .00222 -6 -9 ]
[.81746 .00222 6 0 ]
[.97619 .00222 -6 -9 ]
[.97619 .00222 6 0 ]
[.01131 .0925 -30 -4.5 ]
[.01131 .0925 0 4.5 ]
[.01131 .17029 -24 -4.5 ]
[.01131 .17029 0 4.5 ]
[.01131 .24808 -30 -4.5 ]
[.01131 .24808 0 4.5 ]
[.01131 .32587 -24 -4.5 ]
[.01131 .32587 0 4.5 ]
[.01131 .40366 -30 -4.5 ]
[.01131 .40366 0 4.5 ]
[.01131 .48145 -24 -4.5 ]
[.01131 .48145 0 4.5 ]
[.01131 .55924 -30 -4.5 ]
[.01131 .55924 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.18254 .01472 m
.18254 .02097 L
s
[(5)] .18254 .00222 0 1 Mshowa
.34127 .01472 m
.34127 .02097 L
s
[(10)] .34127 .00222 0 1 Mshowa
.5 .01472 m
.5 .02097 L
s
[(15)] .5 .00222 0 1 Mshowa
.65873 .01472 m
.65873 .02097 L
s
[(20)] .65873 .00222 0 1 Mshowa
.81746 .01472 m
.81746 .02097 L
s
[(25)] .81746 .00222 0 1 Mshowa
.97619 .01472 m
.97619 .02097 L
s
[(30)] .97619 .00222 0 1 Mshowa
.125 Mabswid
.05556 .01472 m
.05556 .01847 L
s
.0873 .01472 m
.0873 .01847 L
s
.11905 .01472 m
.11905 .01847 L
s
.15079 .01472 m
.15079 .01847 L
s
.21429 .01472 m
.21429 .01847 L
s
.24603 .01472 m
.24603 .01847 L
s
.27778 .01472 m
.27778 .01847 L
s
.30952 .01472 m
.30952 .01847 L
s
.37302 .01472 m
.37302 .01847 L
s
.40476 .01472 m
.40476 .01847 L
s
.43651 .01472 m
.43651 .01847 L
s
.46825 .01472 m
.46825 .01847 L
s
.53175 .01472 m
.53175 .01847 L
s
.56349 .01472 m
.56349 .01847 L
s
.59524 .01472 m
.59524 .01847 L
s
.62698 .01472 m
.62698 .01847 L
s
.69048 .01472 m
.69048 .01847 L
s
.72222 .01472 m
.72222 .01847 L
s
.75397 .01472 m
.75397 .01847 L
s
.78571 .01472 m
.78571 .01847 L
s
.84921 .01472 m
.84921 .01847 L
s
.88095 .01472 m
.88095 .01847 L
s
.9127 .01472 m
.9127 .01847 L
s
.94444 .01472 m
.94444 .01847 L
s
.25 Mabswid
0 .01472 m
1 .01472 L
s
.02381 .0925 m
.03006 .0925 L
s
[(0.005)] .01131 .0925 1 0 Mshowa
.02381 .17029 m
.03006 .17029 L
s
[(0.01)] .01131 .17029 1 0 Mshowa
.02381 .24808 m
.03006 .24808 L
s
[(0.015)] .01131 .24808 1 0 Mshowa
.02381 .32587 m
.03006 .32587 L
s
[(0.02)] .01131 .32587 1 0 Mshowa
.02381 .40366 m
.03006 .40366 L
s
[(0.025)] .01131 .40366 1 0 Mshowa
.02381 .48145 m
.03006 .48145 L
s
[(0.03)] .01131 .48145 1 0 Mshowa
.02381 .55924 m
.03006 .55924 L
s
[(0.035)] .01131 .55924 1 0 Mshowa
.125 Mabswid
.02381 .03027 m
.02756 .03027 L
s
.02381 .04583 m
.02756 .04583 L
s
.02381 .06139 m
.02756 .06139 L
s
.02381 .07695 m
.02756 .07695 L
s
.02381 .10806 m
.02756 .10806 L
s
.02381 .12362 m
.02756 .12362 L
s
.02381 .13918 m
.02756 .13918 L
s
.02381 .15474 m
.02756 .15474 L
s
.02381 .18585 m
.02756 .18585 L
s
.02381 .20141 m
.02756 .20141 L
s
.02381 .21697 m
.02756 .21697 L
s
.02381 .23252 m
.02756 .23252 L
s
.02381 .26364 m
.02756 .26364 L
s
.02381 .2792 m
.02756 .2792 L
s
.02381 .29476 m
.02756 .29476 L
s
.02381 .31031 m
.02756 .31031 L
s
.02381 .34143 m
.02756 .34143 L
s
.02381 .35699 m
.02756 .35699 L
s
.02381 .37254 m
.02756 .37254 L
s
.02381 .3881 m
.02756 .3881 L
s
.02381 .41922 m
.02756 .41922 L
s
.02381 .43478 m
.02756 .43478 L
s
.02381 .45033 m
.02756 .45033 L
s
.02381 .46589 m
.02756 .46589 L
s
.02381 .49701 m
.02756 .49701 L
s
.02381 .51256 m
.02756 .51256 L
s
.02381 .52812 m
.02756 .52812 L
s
.02381 .54368 m
.02756 .54368 L
s
.02381 .5748 m
.02756 .5748 L
s
.02381 .59035 m
.02756 .59035 L
s
.02381 .60591 m
.02756 .60591 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.05556 .0149 m
.0873 .01487 L
.11905 .01494 L
.15079 .01512 L
.18254 .01548 L
.21429 .0162 L
.24603 .01763 L
.27778 .02052 L
.30952 .02642 L
.34127 .03854 L
.37302 .06338 L
.40476 .11357 L
.43651 .21082 L
.46825 .3808 L
.5 .60332 L
.53175 .60332 L
.56349 .3808 L
.59524 .21082 L
.62698 .11357 L
.65873 .06338 L
.69048 .03854 L
.72222 .02642 L
.75397 .02052 L
.78571 .01763 L
.81746 .0162 L
.84921 .01548 L
.88095 .01512 L
.9127 .01494 L
.94444 .01487 L
.97619 .0149 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[37]:=",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/B000`400?l00000o`00003ooooooolQ
ooooo`00oooooolQooooo`00oooooolQooooo`00oooooolQooooo`00B?ooool3o`0002?ooooo0ol0
0004ooooo`;o00008Oooool3o`0000?ooooo0ol0000Oooooo`Go00000oooool2o`0001oooooo1Ol0
0002ooooo`?o00008?ooool3o`0000Cooooo0_l00004ooooo`00Aoooool01Ol0003ooooooooooooo
oooo000002?ooooo00?o0000ooooooooool00_ooool01?l0003oooooooooool0000Qooooo`05o`00
0?ooooooooooooooool000000oooool00ol0003oooooooooo`0Mooooo`04o`000?ooooooooooo`00
00;ooooo00Co0000oooooooooooo00007oooool01_l0003oooooooooool0003oooooo`0000?ooooo
00?o0000ooooooooool07?ooool01Ol0003ooooooooooooooooo000000;ooooo00Co0000oooooooo
oooo00000oooool004_ooooo00?o0000ooooooooool08Oooool00ol0003oooooooooo`02ooooo`04
o`000?ooooooooooo`00027ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`0Noooo
o`03o`000?oooooooooo00;ooooo00Co0000oooooooooooo00008?ooool00ol0003oooooooooo`05
ooooo`03o`000?oooooooooo023ooooo00Co0000oooooooooooo00000_ooool00ol0003ooooooooo
o`01ooooo`00Boooool00ol0003oooooooooo`0Qooooo`03o`000?oooooooooo00;ooooo00Co0000
oooooooooooo00008Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo01oooooo00Go
0000ooooooooooooooooo`000002ooooo`03o`000?oooooooooo01oooooo00?o0000ooooooooool0
1?ooool00ol0003oooooooooo`0Nooooo`;o00000oooool01?l0003oooooooooool00003ooooo`00
Aoooool4o`0002Cooooo00?o0000ooooooooool00_ooool01?l0003oooooooooool0000Qooooo`04
o`000?ooooooooooooooo`Co00007oooool01Ol0003ooooooooooooooooo000000;ooooo00Co0000
oooooooooooo00007_ooool01_l0003ooooooooooooooooo0000ooooo`Co00008oooool01?l0003o
ooooooooool00002ooooo`03o`000?oooooooooo007ooooo0017ooooo`03o`000?oooooooooo02Co
oooo0_l00004ooooo`04o`000?ooooooooooo`00023ooooo0_l00003ooooo`03o`000?oooooooooo
023ooooo00Go0000ooooooooooooooooo`000002ooooo`04o`000?ooooooooooo`0001kooooo00Oo
0000ooooooooooooooooo`000?oooooo000002;ooooo00Go0000ooooooooooooooooo`000002oooo
o`04o`000?ooooooooooo`0000?ooooo0017ooooo`Go00008oooool00ol0003oooooooooo`03oooo
o`;o00008_ooool01?l0003oooooooooooooool5o`0001oooooo0ol00004ooooo`;o00008?ooool3
o`0000;ooooo1Ol0000Oooooo`?o00001?ooool2o`0000Cooooo003oooooob7ooooo000Qooooo`03
o`000?oooooooooo0?cooooo000Qooooo`03o`000?oooooooooo0?cooooo000Qooooo`03o`000?oo
oooooooo0?cooooo000Qooooo`03o`000?oooooooooo0?cooooo000Koooooooo00001_l00000027o
oooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Ko
oooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Go
oooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`02ooooo`Ko00001Oooool00ol0003o
ooooooooo`05ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01Oooool00ol0003o
ooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01_ooool00ol0003o
ooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003o
ooooooooo`06ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003o
ooooooooo`05ooooo`03o`000?oooooooooo00Cooooo1_l00004ooooo`03o`000?oooooooooo00Go
oooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Go
oooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Go
oooo000Qooooo`03o`000?oooooooooo04;ooooo1?l0001^ooooo`Go0000@oooool0027ooooo00?o
0000ooooooooool0A_ooool3o`0006Sooooo0ol00018ooooo`008Oooool2o`0004[ooooo0ol0001R
ooooo`?o0000Boooool0027ooooo00?o0000ooooooooool0C?ooool3o`0005cooooo0ol0001>oooo
o`008Oooool00ol0003oooooooooo`1?ooooo`;o0000F?ooool2o`00057ooooo000Qooooo`03o`00
0?oooooooooo057ooooo00?o0000ooooooooool0E?ooool00ol0003oooooooooo`1Aooooo`008Ooo
ool2o`0005?ooooo0_l0001Cooooo`03o`000?oooooooooo05;ooooo000Qooooo`03o`000?oooooo
oooo05Cooooo00?o0000ooooooooool0C_ooool2o`0005Gooooo000Qooooo`03o`000?oooooooooo
05Gooooo0_l0001=ooooo`03o`000?oooooooooo05Gooooo000Qooooo`03o`000?oooooooooo05Oo
oooo00?o0000ooooooooool0BOooool00ol0003oooooooooo`1Fooooo`008Oooool2o`0005Wooooo
00?o0000ooooooooool0Aoooool00ol0003oooooooooo`1Gooooo`008Oooool00ol0003ooooooooo
o`1Hooooo`03o`000?oooooooooo04Oooooo00?o0000ooooooooool0Eoooool0027ooooo00?o0000
ooooooooool0FOooool00ol0003oooooooooo`15ooooo`03o`000?oooooooooo05Sooooo000Qoooo
o`03o`000?oooooooooo05[ooooo00?o0000ooooooooool0@oooool00ol0003oooooooooo`1Ioooo
o`008Oooool2o`0005_ooooo00?o0000ooooooooool0@oooool00ol0003oooooooooo`1Iooooo`00
0_ooool2o`0000Cooooo00?o0000ooooooooool00oooool2o`0000Cooooo0_l00003ooooo`?o0000
1Oooool00ol0003oooooooooo`1Kooooo`03o`000?oooooooooo047ooooo00?o0000ooooooooool0
F_ooool00005ooooool0003oooooooooool000002?ooool01?l0003oooooooooool00002ooooo`06
o`000?ooooooooooo`000?oooooo00000oooool00ol0003oooooooooo`02ooooo`03o`000?oooooo
oooo05_ooooo00?o0000ooooooooool0@Oooool00ol0003oooooooooo`1Jooooo`0000Goooooo`00
0?ooooooooooo`000008ooooo`04o`000?ooooooooooo`0000;ooooo00Co0000oooooooooooo0000
1Oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo05cooooo00?o0000ooooooooool0
?oooool00ol0003oooooooooo`1Kooooo`0000Goooooo`000?ooooooooooo`000008ooooo`04o`00
0?ooooooooooo`0000;ooooo00Co0000oooooooooooo00001Oooool00ol0003oooooooooo`02oooo
o`;o0000G_ooool00ol0003oooooooooo`0mooooo`03o`000?oooooooooo05cooooo00001Ooooooo
0000oooooooooooo000000Sooooo00Co0000oooooooooooo00000_ooool01Ol0003oooooooooool0
003ooooo00Co00001Oooool00ol0003oooooooooo`1Mooooo`03o`000?oooooooooo03gooooo00?o
0000ooooooooool0G?ooool00005ooooool0003oooooooooool000002?ooool01?l0003ooooooooo
ool00002ooooo`06o`000?ooooooooooo`000?oooooo00002?ooool00ol0003oooooooooo`1Noooo
o`03o`000?oooooooooo03_ooooo00?o0000ooooooooool0GOooool000;ooooo0_l0000:ooooo`;o
00001?ooool2o`0000;ooooo1Ol00004ooooo`03o`000?oooooooooo05kooooo00?o0000oooooooo
ool0>oooool00ol0003oooooooooo`1Mooooo`008Oooool2o`00063ooooo00?o0000ooooooooool0
>Oooool00ol0003oooooooooo`1Nooooo`008Oooool00ol0003oooooooooo`1Pooooo`03o`000?oo
oooooooo03Oooooo00?o0000ooooooooool0Goooool0027ooooo00?o0000ooooooooool0H?ooool0
0ol0003oooooooooo`0gooooo`03o`000?oooooooooo05oooooo000Qooooo`03o`000?oooooooooo
063ooooo00?o0000ooooooooool0=_ooool00ol0003oooooooooo`1Pooooo`008Oooool2o`0006;o
oooo00?o0000ooooooooool0=Oooool00ol0003oooooooooo`1Pooooo`008Oooool00ol0003ooooo
ooooo`1Qooooo`03o`000?oooooooooo03Gooooo00?o0000ooooooooool0H?ooool0027ooooo00?o
0000ooooooooool0HOooool00ol0003oooooooooo`0dooooo`03o`000?oooooooooo067ooooo000Q
ooooo`03o`000?oooooooooo06;ooooo00?o0000ooooooooool0<oooool00ol0003oooooooooo`1Q
ooooo`008Oooool2o`0006?ooooo00?o0000ooooooooool0<oooool00ol0003oooooooooo`1Qoooo
o`008Oooool00ol0003oooooooooo`1Rooooo`03o`000?oooooooooo03;ooooo00?o0000oooooooo
ool0H_ooool0027ooooo00?o0000ooooooooool0Hoooool00ol0003oooooooooo`0aooooo`03o`00
0?oooooooooo06;ooooo000Qooooo`03o`000?oooooooooo06?ooooo00?o0000ooooooooool0<Ooo
ool00ol0003oooooooooo`1Rooooo`008Oooool2o`0006Cooooo00?o0000ooooooooool0<?ooool0
0ol0003oooooooooo`1Sooooo`008Oooool00ol0003oooooooooo`1Tooooo`03o`000?oooooooooo
02oooooo00?o0000ooooooooool0Hoooool000Sooooo0_l00004ooooo`03o`000?oooooooooo00?o
oooo0_l00003ooooo`?o00001Oooool00ol0003oooooooooo`1Tooooo`03o`000?oooooooooo02oo
oooo00?o0000ooooooooool0Hoooool000Oooooo00Co0000oooooooooooo00002?ooool01?l0003o
ooooooooool00003ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0I?ooool00ol0
003oooooooooo`0^ooooo`03o`000?oooooooooo06Cooooo0007ooooo`04o`000?ooooooooooo`00
00Sooooo00Co0000oooooooooooo00000oooool00ol0003oooooooooo`04ooooo`;o0000IOooool0
0ol0003oooooooooo`0^ooooo`03o`000?oooooooooo06Cooooo0007ooooo`04o`000?oooooooooo
o`0000Sooooo00Co0000oooooooooooo00000oooool00ol0003oooooooooo`04ooooo`03o`000?oo
oooooooo06Gooooo00?o0000ooooooooool0;Oooool00ol0003oooooooooo`1Tooooo`001oooool0
1?l0003oooooooooool00008ooooo`04o`000?ooooooooooo`0000?ooooo00?o0000ooooooooool0
1?ooool00ol0003oooooooooo`1Uooooo`03o`000?oooooooooo02cooooo00?o0000ooooooooool0
IOooool000Oooooo00Co0000oooooooooooo00002?ooool01?l0003oooooooooool00002ooooo`;o
00001_ooool00ol0003oooooooooo`1Uooooo`03o`000?oooooooooo02cooooo00?o0000oooooooo
ool0IOooool000Sooooo0_l0000:ooooo`;o00001?ooool00ol0003oooooooooo`04ooooo`;o0000
Ioooool00ol0003oooooooooo`0[ooooo`03o`000?oooooooooo06Gooooo000Qooooo`03o`000?oo
oooooooo06Kooooo00?o0000ooooooooool0:_ooool00ol0003oooooooooo`1Vooooo`008Oooool0
0ol0003oooooooooo`1Vooooo`03o`000?oooooooooo02[ooooo00?o0000ooooooooool0I_ooool0
027ooooo00?o0000ooooooooool0Ioooool00ol0003oooooooooo`0Yooooo`03o`000?oooooooooo
06Kooooo000Qooooo`;o0000J?ooool00ol0003oooooooooo`0Xooooo`03o`000?oooooooooo06Oo
oooo000Qooooo`03o`000?oooooooooo06Oooooo00?o0000ooooooooool0:?ooool00ol0003ooooo
ooooo`1Wooooo`008Oooool00ol0003oooooooooo`1Xooooo`03o`000?oooooooooo02Oooooo00?o
0000ooooooooool0Ioooool0027ooooo00?o0000ooooooooool0J?ooool00ol0003oooooooooo`0V
ooooo`03o`000?oooooooooo06Sooooo000Qooooo`;o0000JOooool00ol0003oooooooooo`0Voooo
o`03o`000?oooooooooo06Sooooo000Qooooo`03o`000?oooooooooo06Sooooo00?o0000oooooooo
ool09_ooool00ol0003oooooooooo`1Xooooo`008Oooool00ol0003oooooooooo`1Xooooo`03o`00
0?oooooooooo02Kooooo00?o0000ooooooooool0J?ooool0027ooooo00?o0000ooooooooool0JOoo
ool00ol0003oooooooooo`0Tooooo`03o`000?oooooooooo06Wooooo000Qooooo`;o0000J_ooool0
0ol0003oooooooooo`0Tooooo`03o`000?oooooooooo06Wooooo000Qooooo`03o`000?oooooooooo
06Wooooo00?o0000ooooooooool09?ooool00ol0003oooooooooo`1Yooooo`000_ooool2o`0000Co
oooo00?o0000ooooooooool00oooool2o`0000?ooooo0ol00003ooooo`?o00001Oooool00ol0003o
ooooooooo`1Yooooo`03o`000?oooooooooo02Cooooo00?o0000ooooooooool0JOooool00005oooo
ool0003oooooooooool000002?ooool01?l0003oooooooooool00003ooooo`05o`000?oooooooooo
ooooool000000oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo06Wooooo00?o0000
ooooooooool09?ooool00ol0003oooooooooo`1Yooooo`0000Goooooo`000?ooooooooooo`000008
ooooo`04o`000?ooooooooooo`0000?ooooo00?o0000ooooooooool01Oooool00ol0003ooooooooo
o`02ooooo`;o0000Joooool00ol0003oooooooooo`0Rooooo`03o`000?oooooooooo06[ooooo0000
1Ooooooo0000oooooooooooo000000Sooooo00Co0000oooooooooooo00000oooool00ol0003ooooo
ooooo`05ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0J_ooool00ol0003ooooo
ooooo`0Rooooo`03o`000?oooooooooo06[ooooo00001Ooooooo0000oooooooooooo000000Sooooo
00Co0000oooooooooooo00000oooool01?l0003oooooooooooooool4o`0000Gooooo00?o0000oooo
ooooool0J_ooool00ol0003oooooooooo`0Rooooo`03o`000?oooooooooo06[ooooo00001Ooooooo
0000oooooooooooo000000Sooooo00Co0000oooooooooooo00000_ooool2o`0000?ooooo00?o0000
ooooooooool01_ooool00ol0003oooooooooo`1Zooooo`03o`000?oooooooooo02;ooooo00?o0000
ooooooooool0J_ooool000;ooooo0_l0000:ooooo`;o00001?ooool01?l0003oooooooooooooool5
o`0000Cooooo0_l0001[ooooo`03o`000?oooooooooo02;ooooo00?o0000ooooooooool0J_ooool0
027ooooo00?o0000ooooooooool0J_ooool00ol0003oooooooooo`0Rooooo`03o`000?oooooooooo
06[ooooo000Qooooo`03o`000?oooooooooo06_ooooo00?o0000ooooooooool08?ooool00ol0003o
ooooooooo`1[ooooo`008Oooool00ol0003oooooooooo`1[ooooo`03o`000?oooooooooo023ooooo
00?o0000ooooooooool0Joooool0027ooooo0_l0001/ooooo`03o`000?oooooooooo023ooooo00?o
0000ooooooooool0Joooool0027ooooo00?o0000ooooooooool0Joooool00ol0003oooooooooo`0P
ooooo`03o`000?oooooooooo06_ooooo000Qooooo`03o`000?oooooooooo06_ooooo00?o0000oooo
ooooool08?ooool00ol0003oooooooooo`1[ooooo`008Oooool00ol0003oooooooooo`1/ooooo`03
o`000?oooooooooo01kooooo00?o0000ooooooooool0K?ooool0027ooooo00?o0000ooooooooool0
K?ooool00ol0003oooooooooo`0Nooooo`03o`000?oooooooooo06cooooo000Qooooo`;o0000KOoo
ool00ol0003oooooooooo`0Nooooo`03o`000?oooooooooo06cooooo000Qooooo`03o`000?oooooo
oooo06cooooo00?o0000ooooooooool07_ooool00ol0003oooooooooo`1/ooooo`008Oooool00ol0
003oooooooooo`1/ooooo`03o`000?oooooooooo01kooooo00?o0000ooooooooool0K?ooool0027o
oooo00?o0000ooooooooool0K?ooool00ol0003oooooooooo`0Nooooo`03o`000?oooooooooo06co
oooo000Qooooo`;o0000K_ooool00ol0003oooooooooo`0Looooo`03o`000?oooooooooo06gooooo
0008ooooo`;o00001?ooool00ol0003oooooooooo`03ooooo`;o00000_ooool5o`0000Cooooo00?o
0000ooooooooool0KOooool00ol0003oooooooooo`0Looooo`03o`000?oooooooooo06gooooo0007
ooooo`04o`000?ooooooooooo`0000Sooooo00Co0000oooooooooooo00000_ooool01?l0003ooooo
ooooool00004ooooo`03o`000?oooooooooo06gooooo00?o0000ooooooooool07?ooool00ol0003o
ooooooooo`1]ooooo`001oooool01?l0003oooooooooool00008ooooo`04o`000?ooooooooooo`00
00?ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`1]ooooo`03o`000?oooooooooo
01cooooo00?o0000ooooooooool0KOooool000Oooooo00Co0000oooooooooooo00002?ooool01?l0
003oooooooooool00004ooooo`03o`000?oooooooooo00?ooooo0_l0001^ooooo`03o`000?oooooo
oooo01cooooo00?o0000ooooooooool0KOooool000Oooooo00Co0000oooooooooooo00002?ooool0
1_l0003oooooooooool0003oooooo`0000?ooooo00?o0000ooooooooool00_ooool00ol0003ooooo
ooooo`1^ooooo`03o`000?oooooooooo01[ooooo00?o0000ooooooooool0K_ooool000Oooooo00Co
0000oooooooooooo00002?ooool01_l0003oooooooooool0003oooooo`0000?ooooo00?o0000oooo
ooooool00_ooool00ol0003oooooooooo`1^ooooo`03o`000?oooooooooo01[ooooo00?o0000oooo
ooooool0K_ooool000Sooooo0_l0000:ooooo`;o00000oooool3o`0000Gooooo00?o0000oooooooo
ool0K_ooool00ol0003oooooooooo`0Jooooo`03o`000?oooooooooo06kooooo000Qooooo`;o0000
Koooool00ol0003oooooooooo`0Jooooo`03o`000?oooooooooo06kooooo000Qooooo`03o`000?oo
oooooooo06kooooo00?o0000ooooooooool06_ooool00ol0003oooooooooo`1^ooooo`008Oooool0
0ol0003oooooooooo`1^ooooo`03o`000?oooooooooo01[ooooo00?o0000ooooooooool0K_ooool0
027ooooo00?o0000ooooooooool0Koooool00ol0003oooooooooo`0Hooooo`03o`000?oooooooooo
06oooooo000Qooooo`;o0000L?ooool00ol0003oooooooooo`0Hooooo`03o`000?oooooooooo06oo
oooo000Qooooo`03o`000?oooooooooo06oooooo00?o0000ooooooooool06?ooool00ol0003ooooo
ooooo`1_ooooo`008Oooool00ol0003oooooooooo`1_ooooo`03o`000?oooooooooo01Sooooo00?o
0000ooooooooool0Koooool0027ooooo00?o0000ooooooooool0Koooool00ol0003oooooooooo`0H
ooooo`03o`000?oooooooooo06oooooo000Qooooo`;o0000LOooool00ol0003oooooooooo`0Foooo
o`03o`000?oooooooooo073ooooo000Qooooo`03o`000?oooooooooo073ooooo00?o0000oooooooo
ool05_ooool00ol0003oooooooooo`1`ooooo`008Oooool00ol0003oooooooooo`1`ooooo`03o`00
0?oooooooooo01Kooooo00?o0000ooooooooool0L?ooool0027ooooo00?o0000ooooooooool0L?oo
ool00ol0003oooooooooo`0Fooooo`03o`000?oooooooooo073ooooo000Qooooo`;o0000LOooool0
0ol0003oooooooooo`0Fooooo`03o`000?oooooooooo073ooooo0002ooooo`;o00001?ooool00ol0
003oooooooooo`03ooooo`;o00000_ooool5o`0000;ooooo0ol00005ooooo`03o`000?oooooooooo
073ooooo00?o0000ooooooooool05_ooool00ol0003oooooooooo`1`ooooo`0000Goooooo`000?oo
ooooooooo`000008ooooo`04o`000?ooooooooooo`0000;ooooo00Ko0000oooooooooooo0000oooo
ool00003ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0LOooool00ol0003ooooo
ooooo`0Eooooo`03o`000?oooooooooo073ooooo00001Ooooooo0000oooooooooooo000000Sooooo
00Co0000oooooooooooo00000oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00;o
oooo00?o0000ooooooooool0LOooool00ol0003oooooooooo`0Dooooo`03o`000?oooooooooo077o
oooo00001Ooooooo0000oooooooooooo000000Sooooo00Co0000oooooooooooo00001?ooool00ol0
003oooooooooo`04ooooo`03o`000?oooooooooo00;ooooo0_l0001booooo`03o`000?oooooooooo
01Cooooo00?o0000ooooooooool0LOooool00005ooooool0003oooooooooool000002?ooool01_l0
003oooooooooool0003oooooo`0000?ooooo00?o0000ooooool000000ol00005ooooo`03o`000?oo
oooooooo077ooooo00?o0000ooooooooool05?ooool00ol0003oooooooooo`1aooooo`0000Gooooo
o`000?ooooooooooo`000008ooooo`06o`000?ooooooooooo`000?oooooo00000oooool00ol0003o
ooooo`000008ooooo`03o`000?oooooooooo077ooooo00?o0000ooooooooool05?ooool00ol0003o
ooooooooo`1aooooo`000_ooool2o`0000[ooooo0_l00003ooooo`?o00000_ooool5o`0000Cooooo
00?o0000ooooooooool0LOooool00ol0003oooooooooo`0Dooooo`03o`000?oooooooooo077ooooo
000Qooooo`;o0000L_ooool00ol0003oooooooooo`0Dooooo`03o`000?oooooooooo077ooooo000Q
ooooo`03o`000?oooooooooo07;ooooo00?o0000ooooooooool04oooool00ol0003oooooooooo`1a
ooooo`008Oooool00ol0003oooooooooo`1booooo`03o`000?oooooooooo01;ooooo00?o0000oooo
ooooool0L_ooool0027ooooo00?o0000ooooooooool0L_ooool00ol0003oooooooooo`0Booooo`03
o`000?oooooooooo07;ooooo000Qooooo`;o0000Loooool00ol0003oooooooooo`0Booooo`03o`00
0?oooooooooo07;ooooo000Qooooo`03o`000?oooooooooo07;ooooo00?o0000ooooooooool04_oo
ool00ol0003oooooooooo`1booooo`008Oooool00ol0003oooooooooo`1booooo`03o`000?oooooo
oooo01;ooooo00?o0000ooooooooool0L_ooool0027ooooo00?o0000ooooooooool0Loooool00ol0
003oooooooooo`0Aooooo`03o`000?oooooooooo07;ooooo000Qooooo`;o0000M?ooool00ol0003o
ooooooooo`0Aooooo`03o`000?oooooooooo07;ooooo000Qooooo`03o`000?oooooooooo07?ooooo
00?o0000ooooooooool04?ooool00ol0003oooooooooo`1cooooo`008Oooool00ol0003ooooooooo
o`1cooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool0Loooool0027ooooo00?o0000
ooooooooool0Loooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo07?ooooo000Qoooo
o`;o0000M?ooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo07?ooooo000Qooooo`03
o`000?oooooooooo07?ooooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`1cooooo`00
2?ooool2o`0000Cooooo00?o0000ooooooooool00oooool2o`0000?ooooo0ol00005ooooo`03o`00
0?oooooooooo07Cooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`1cooooo`001ooo
ool01?l0003oooooooooool00008ooooo`06o`000?ooooooooooo`000?oooooo00000oooool00ol0
003oooooooooo`02ooooo`03o`000?oooooooooo07Cooooo00?o0000ooooooooool03oooool00ol0
003oooooooooo`1cooooo`001oooool01?l0003oooooooooool00008ooooo`04o`000?oooooooooo
o`0000Gooooo00?o0000ooooooooool00_ooool2o`0007Gooooo00?o0000ooooooooool03_ooool0
0ol0003oooooooooo`1dooooo`001oooool01?l0003oooooooooool00008ooooo`04o`000?oooooo
ooooo`0000?ooooo0_l00005ooooo`03o`000?oooooooooo07Cooooo00?o0000ooooooooool03_oo
ool00ol0003oooooooooo`1dooooo`001oooool01?l0003oooooooooool00008ooooo`04o`000?oo
ooooooooo`0000Gooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`1dooooo`03o`00
0?oooooooooo00kooooo00?o0000ooooooooool0M?ooool000Oooooo00Co0000oooooooooooo0000
2?ooool01_l0003oooooooooool0003oooooo`0000?ooooo00?o0000ooooooooool00_ooool00ol0
003oooooooooo`1dooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool0M?ooool000So
oooo0_l0000:ooooo`;o00000oooool3o`0000Gooooo0_l0001fooooo`03o`000?oooooooooo00go
oooo00?o0000ooooooooool0M?ooool0027ooooo00?o0000ooooooooool0MOooool00ol0003ooooo
ooooo`0=ooooo`03o`000?oooooooooo07Cooooo000Qooooo`03o`000?oooooooooo07Gooooo00?o
0000ooooooooool03Oooool00ol0003oooooooooo`1dooooo`008Oooool00ol0003oooooooooo`1e
ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool0M?ooool0027ooooo0_l0001foooo
o`03o`000?oooooooooo00cooooo00?o0000ooooooooool0MOooool0027ooooo00?o0000oooooooo
ool0MOooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo07Gooooo000Qooooo`03o`00
0?oooooooooo07Kooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`1eooooo`008Ooo
ool00ol0003oooooooooo`1fooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool0MOoo
ool0027ooooo0_l0001gooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool0MOooool0
027ooooo00?o0000ooooooooool0M_ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo
07Gooooo000Qooooo`03o`000?oooooooooo07Kooooo00?o0000ooooooooool02oooool00ol0003o
ooooooooo`1eooooo`008Oooool00ol0003oooooooooo`1fooooo`03o`000?oooooooooo00[ooooo
00?o0000ooooooooool0M_ooool0027ooooo0_l0001gooooo`03o`000?oooooooooo00[ooooo00?o
0000ooooooooool0M_ooool0027ooooo00?o0000ooooooooool0Moooool00ol0003oooooooooo`09
ooooo`03o`000?oooooooooo07Kooooo0002ooooo`;o00001?ooool00ol0003oooooooooo`03oooo
o`;o00000oooool3o`0000?ooooo0ol00005ooooo`03o`000?oooooooooo07Oooooo00?o0000oooo
ooooool02Oooool00ol0003oooooooooo`1fooooo`0000Goooooo`000?ooooooooooo`000008oooo
o`06o`000?ooooooooooo`000?oooooo00000oooool00ol0003oooooo`000003ooooo`03o`000?oo
oooooooo00;ooooo00?o0000ooooooooool0Moooool00ol0003oooooooooo`09ooooo`03o`000?oo
oooooooo07Kooooo00001Ooooooo0000oooooooooooo000000Sooooo00Co0000oooooooooooo0000
1Oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00;ooooo0_l0001hooooo`03o`00
0?oooooooooo00Wooooo00?o0000ooooooooool0M_ooool00005ooooool0003oooooooooool00000
2?ooool01?l0003oooooooooool00003ooooo`;o00001_ooool00ol0003oooooooooo`02ooooo`03
o`000?oooooooooo07Oooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`1fooooo`00
00Goooooo`000?ooooooooooo`000008ooooo`04o`000?ooooooooooo`0000Gooooo00?o0000oooo
ool000000ol00005ooooo`03o`000?oooooooooo07Oooooo00?o0000ooooooooool02?ooool00ol0
003oooooooooo`1gooooo`0000Goooooo`000?ooooooooooo`000008ooooo`06o`000?oooooooooo
o`000?oooooo00000oooool00ol0003oooooo`000008ooooo`03o`000?oooooooooo07Sooooo00?o
0000ooooooooool01oooool00ol0003oooooooooo`1gooooo`000_ooool2o`0000[ooooo0_l00003
ooooo`?o00000_ooool5o`0000Cooooo0_l0001iooooo`03o`000?oooooooooo00Oooooo00?o0000
ooooooooool0Moooool0027ooooo00?o0000ooooooooool0N?ooool00ol0003oooooooooo`07oooo
o`03o`000?oooooooooo07Oooooo000Qooooo`03o`000?oooooooooo07Sooooo00?o0000oooooooo
ool01oooool00ol0003oooooooooo`1gooooo`008Oooool00ol0003oooooooooo`1hooooo`03o`00
0?oooooooooo00Oooooo00?o0000ooooooooool0Moooool0027ooooo0_l0001iooooo`03o`000?oo
oooooooo00Oooooo00?o0000ooooooooool0Moooool0027ooooo00?o0000ooooooooool0N?ooool0
0ol0003oooooooooo`06ooooo`03o`000?oooooooooo07Sooooo000Qooooo`03o`000?oooooooooo
07Wooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`1hooooo`008Oooool00ol0003o
ooooooooo`1iooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0N?ooool0027ooooo
0_l0001jooooo`Wo0000N_ooool0027ooooo00?o0000ooooooooool0o?ooool0027ooooo00?o0000
ooooooooool0o?ooool0027ooooo00?o0000ooooooooool0o?ooool0027ooooo00?o0000oooooooo
ool0o?ooool00?oooooo8Oooool00?oooooo8Oooool00?oooooo8Oooool00001\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-4.02939, -0.00400111, \
0.121183, 0.000247277}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.031746 0.0147151 43.2604 [
[.18254 .00222 -3 -9 ]
[.18254 .00222 3 0 ]
[.34127 .00222 -6 -9 ]
[.34127 .00222 6 0 ]
[.5 .00222 -6 -9 ]
[.5 .00222 6 0 ]
[.65873 .00222 -6 -9 ]
[.65873 .00222 6 0 ]
[.81746 .00222 -6 -9 ]
[.81746 .00222 6 0 ]
[.97619 .00222 -6 -9 ]
[.97619 .00222 6 0 ]
[.01131 .10124 -30 -4.5 ]
[.01131 .10124 0 4.5 ]
[.01131 .18776 -30 -4.5 ]
[.01131 .18776 0 4.5 ]
[.01131 .27428 -30 -4.5 ]
[.01131 .27428 0 4.5 ]
[.01131 .3608 -30 -4.5 ]
[.01131 .3608 0 4.5 ]
[.01131 .44732 -24 -4.5 ]
[.01131 .44732 0 4.5 ]
[.01131 .53384 -30 -4.5 ]
[.01131 .53384 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.18254 .01472 m
.18254 .02097 L
s
[(5)] .18254 .00222 0 1 Mshowa
.34127 .01472 m
.34127 .02097 L
s
[(10)] .34127 .00222 0 1 Mshowa
.5 .01472 m
.5 .02097 L
s
[(15)] .5 .00222 0 1 Mshowa
.65873 .01472 m
.65873 .02097 L
s
[(20)] .65873 .00222 0 1 Mshowa
.81746 .01472 m
.81746 .02097 L
s
[(25)] .81746 .00222 0 1 Mshowa
.97619 .01472 m
.97619 .02097 L
s
[(30)] .97619 .00222 0 1 Mshowa
.125 Mabswid
.05556 .01472 m
.05556 .01847 L
s
.0873 .01472 m
.0873 .01847 L
s
.11905 .01472 m
.11905 .01847 L
s
.15079 .01472 m
.15079 .01847 L
s
.21429 .01472 m
.21429 .01847 L
s
.24603 .01472 m
.24603 .01847 L
s
.27778 .01472 m
.27778 .01847 L
s
.30952 .01472 m
.30952 .01847 L
s
.37302 .01472 m
.37302 .01847 L
s
.40476 .01472 m
.40476 .01847 L
s
.43651 .01472 m
.43651 .01847 L
s
.46825 .01472 m
.46825 .01847 L
s
.53175 .01472 m
.53175 .01847 L
s
.56349 .01472 m
.56349 .01847 L
s
.59524 .01472 m
.59524 .01847 L
s
.62698 .01472 m
.62698 .01847 L
s
.69048 .01472 m
.69048 .01847 L
s
.72222 .01472 m
.72222 .01847 L
s
.75397 .01472 m
.75397 .01847 L
s
.78571 .01472 m
.78571 .01847 L
s
.84921 .01472 m
.84921 .01847 L
s
.88095 .01472 m
.88095 .01847 L
s
.9127 .01472 m
.9127 .01847 L
s
.94444 .01472 m
.94444 .01847 L
s
.25 Mabswid
0 .01472 m
1 .01472 L
s
.02381 .10124 m
.03006 .10124 L
s
[(0.002)] .01131 .10124 1 0 Mshowa
.02381 .18776 m
.03006 .18776 L
s
[(0.004)] .01131 .18776 1 0 Mshowa
.02381 .27428 m
.03006 .27428 L
s
[(0.006)] .01131 .27428 1 0 Mshowa
.02381 .3608 m
.03006 .3608 L
s
[(0.008)] .01131 .3608 1 0 Mshowa
.02381 .44732 m
.03006 .44732 L
s
[(0.01)] .01131 .44732 1 0 Mshowa
.02381 .53384 m
.03006 .53384 L
s
[(0.012)] .01131 .53384 1 0 Mshowa
.125 Mabswid
.02381 .03635 m
.02756 .03635 L
s
.02381 .05798 m
.02756 .05798 L
s
.02381 .07961 m
.02756 .07961 L
s
.02381 .12287 m
.02756 .12287 L
s
.02381 .1445 m
.02756 .1445 L
s
.02381 .16613 m
.02756 .16613 L
s
.02381 .20939 m
.02756 .20939 L
s
.02381 .23102 m
.02756 .23102 L
s
.02381 .25265 m
.02756 .25265 L
s
.02381 .29591 m
.02756 .29591 L
s
.02381 .31754 m
.02756 .31754 L
s
.02381 .33917 m
.02756 .33917 L
s
.02381 .38243 m
.02756 .38243 L
s
.02381 .40406 m
.02756 .40406 L
s
.02381 .42569 m
.02756 .42569 L
s
.02381 .46895 m
.02756 .46895 L
s
.02381 .49058 m
.02756 .49058 L
s
.02381 .51221 m
.02756 .51221 L
s
.02381 .55547 m
.02756 .55547 L
s
.02381 .5771 m
.02756 .5771 L
s
.02381 .59873 m
.02756 .59873 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.05556 .01506 m
.0873 .01488 L
.11905 .01495 L
.15079 .01516 L
.18254 .01557 L
.21429 .01639 L
.24603 .01802 L
.27778 .0213 L
.30952 .02796 L
.34127 .04163 L
.37302 .06999 L
.40476 .12898 L
.43651 .25036 L
.46825 .48654 L
s
.46825 .48654 m
.4796 .61803 L
s
.55215 .61803 m
.56349 .48654 L
.59524 .25036 L
.62698 .12898 L
.65873 .06999 L
.69048 .04163 L
.72222 .02796 L
.75397 .0213 L
.78571 .01802 L
.81746 .01639 L
.84921 .01557 L
.88095 .01516 L
.9127 .01495 L
.94444 .01488 L
.97619 .01506 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[37]:=",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/B000`400?l00000o`00003ooooooolQ
ooooo`00oooooolQooooo`00oooooolQooooo`00oooooolQooooo`00B?ooool3o`0002?ooooo0ol0
0004ooooo`;o00008Oooool3o`0000?ooooo0ol0000Oooooo`Go00000oooool2o`0001oooooo1Ol0
0002ooooo`?o00008?ooool3o`0000Cooooo0_l00004ooooo`00Aoooool01Ol0003ooooooooooooo
oooo000002?ooooo00?o0000ooooooooool00_ooool01?l0003oooooooooool0000Qooooo`05o`00
0?ooooooooooooooool000000oooool00ol0003oooooooooo`0Mooooo`04o`000?ooooooooooo`00
00;ooooo00Co0000oooooooooooo00007oooool01_l0003oooooooooool0003oooooo`0000?ooooo
00?o0000ooooooooool07?ooool01Ol0003ooooooooooooooooo000000;ooooo00Co0000oooooooo
oooo00000oooool004_ooooo00?o0000ooooooooool08Oooool00ol0003oooooooooo`02ooooo`04
o`000?ooooooooooo`00027ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`0Noooo
o`03o`000?oooooooooo00;ooooo00Co0000oooooooooooo00008?ooool00ol0003oooooooooo`05
ooooo`03o`000?oooooooooo023ooooo00Co0000oooooooooooo00000_ooool00ol0003ooooooooo
o`01ooooo`00Boooool00ol0003oooooooooo`0Qooooo`03o`000?oooooooooo00;ooooo00Co0000
oooooooooooo00008Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo01oooooo00Go
0000ooooooooooooooooo`000002ooooo`03o`000?oooooooooo01oooooo00?o0000ooooooooool0
1?ooool00ol0003oooooooooo`0Nooooo`;o00000oooool01?l0003oooooooooool00003ooooo`00
Aoooool4o`0002Cooooo00?o0000ooooooooool00_ooool01?l0003oooooooooool0000Qooooo`04
o`000?ooooooooooooooo`Co00007oooool01Ol0003ooooooooooooooooo000000;ooooo00Co0000
oooooooooooo00007_ooool01_l0003ooooooooooooooooo0000ooooo`Co00008oooool01?l0003o
ooooooooool00002ooooo`03o`000?oooooooooo007ooooo0017ooooo`03o`000?oooooooooo02Co
oooo0_l00004ooooo`04o`000?ooooooooooo`00023ooooo0_l00003ooooo`03o`000?oooooooooo
023ooooo00Go0000ooooooooooooooooo`000002ooooo`04o`000?ooooooooooo`0001kooooo00Oo
0000ooooooooooooooooo`000?oooooo000002;ooooo00Go0000ooooooooooooooooo`000002oooo
o`04o`000?ooooooooooo`0000?ooooo0017ooooo`Go00008oooool00ol0003oooooooooo`03oooo
o`;o00008_ooool01?l0003oooooooooooooool5o`0001oooooo0ol00004ooooo`;o00008?ooool3
o`0000;ooooo1Ol0000Oooooo`?o00001?ooool2o`0000Cooooo003oooooob7ooooo000Qooooo`03
o`000?oooooooooo0?cooooo000Qooooo`03o`000?oooooooooo0?cooooo000Qooooo`03o`000?oo
oooooooo0?cooooo000Qooooo`03o`000?oooooooooo0?cooooo000Koooooooo00001_l00000027o
oooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Ko
oooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Go
oooo00?o0000ooooooooool00oooool>o`0000Gooooo00?o0000ooooooooool01Oooool00ol0003o
ooooooooo`06ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003o
ooooooooo`05ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01Oooool00ol0003o
ooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01_ooool00ol0003o
ooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003o
ooooooooo`04ooooo`ko00001?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Ko
oooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Go
oooo00?o0000ooooooooool01Oooool0027ooooo00?o0000ooooooooool0@_ooool4o`0006kooooo
1Ol00013ooooo`008Oooool00ol0003oooooooooo`16ooooo`?o0000J?ooool3o`0004Sooooo000Q
ooooo`03o`000?oooooooooo04Wooooo0_l0001Tooooo`;o0000Boooool0027ooooo0_l0001<oooo
o`;o0000H?ooool2o`0004gooooo000Qooooo`03o`000?oooooooooo04gooooo0_l0001Looooo`;o
0000Coooool0027ooooo00?o0000ooooooooool0Coooool2o`0005Sooooo0_l0001Aooooo`008Ooo
ool00ol0003oooooooooo`1Aooooo`03o`000?oooooooooo05Cooooo00?o0000ooooooooool0DOoo
ool0027ooooo00?o0000ooooooooool0D_ooool00ol0003oooooooooo`1Booooo`03o`000?oooooo
oooo05;ooooo000Qooooo`03o`000?oooooooooo05?ooooo0_l0001Aooooo`03o`000?oooooooooo
05?ooooo000Qooooo`;o0000E_ooool00ol0003oooooooooo`1=ooooo`03o`000?oooooooooo05Co
oooo000Qooooo`03o`000?oooooooooo05Kooooo00?o0000ooooooooool0Boooool00ol0003ooooo
ooooo`1Eooooo`008Oooool00ol0003oooooooooo`1Gooooo`03o`000?oooooooooo04Wooooo00?o
0000ooooooooool0E_ooool0027ooooo00?o0000ooooooooool0F?ooool00ol0003oooooooooo`17
ooooo`03o`000?oooooooooo05Oooooo000Qooooo`03o`000?oooooooooo05Sooooo00?o0000oooo
ooooool0Aoooool00ol0003oooooooooo`1Gooooo`008Oooool00ol0003oooooooooo`1Iooooo`03
o`000?oooooooooo04Gooooo00?o0000ooooooooool0F?ooool0027ooooo0_l0001Jooooo`03o`00
0?oooooooooo04Gooooo00?o0000ooooooooool0F?ooool0027ooooo00?o0000ooooooooool0F_oo
ool00ol0003oooooooooo`13ooooo`03o`000?oooooooooo05Wooooo000Qooooo`03o`000?oooooo
oooo05[ooooo00?o0000ooooooooool0@oooool00ol0003oooooooooo`1Iooooo`000_ooool2o`00
00Cooooo00?o0000ooooooooool00oooool2o`0000Cooooo0_l00002ooooo`Go00001?ooool00ol0
003oooooooooo`1Kooooo`03o`000?oooooooooo047ooooo00?o0000ooooooooool0F_ooool00005
ooooool0003oooooooooool000002?ooool01?l0003oooooooooool00002ooooo`04o`000?oooooo
ooooo`0000;ooooo00Co0000oooooooooooo00001?ooool00ol0003oooooooooo`1Kooooo`03o`00
0?oooooooooo047ooooo00?o0000ooooooooool0F_ooool00005ooooool0003oooooooooool00000
2?ooool01?l0003oooooooooool00002ooooo`04o`000?ooooooooooo`0000?ooooo00?o0000oooo
ooooool01?ooool2o`0005gooooo00?o0000ooooooooool0?oooool00ol0003oooooooooo`1Koooo
o`0000Goooooo`000?ooooooooooo`000008ooooo`04o`000?ooooooooooo`0000;ooooo00Co0000
oooooooooooo00001?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo05gooooo00?o
0000ooooooooool0?Oooool00ol0003oooooooooo`1Looooo`0000Goooooo`000?ooooooooooo`00
0008ooooo`04o`000?ooooooooooo`0000;ooooo00Ko0000oooooooooooo0000ooooool00003oooo
o`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0GOooool00ol0003oooooooooo`0moooo
o`03o`000?oooooooooo05cooooo00001Ooooooo0000oooooooooooo000000Sooooo00Co0000oooo
oooooooo00000_ooool01_l0003oooooooooool0003oooooo`0000?ooooo00?o0000ooooooooool0
0_ooool00ol0003oooooooooo`1Nooooo`03o`000?oooooooooo03_ooooo00?o0000ooooooooool0
GOooool000;ooooo0_l0000:ooooo`;o00001?ooool2o`0000?ooooo0ol00005ooooo`03o`000?oo
oooooooo05kooooo00?o0000ooooooooool0>oooool00ol0003oooooooooo`1Mooooo`008Oooool0
0ol0003oooooooooo`1Oooooo`03o`000?oooooooooo03Wooooo00?o0000ooooooooool0G_ooool0
027ooooo0_l0001Pooooo`03o`000?oooooooooo03Wooooo00?o0000ooooooooool0G_ooool0027o
oooo00?o0000ooooooooool0H?ooool00ol0003oooooooooo`0gooooo`03o`000?oooooooooo05oo
oooo000Qooooo`03o`000?oooooooooo063ooooo00?o0000ooooooooool0=oooool00ol0003ooooo
ooooo`1Oooooo`008Oooool00ol0003oooooooooo`1Pooooo`03o`000?oooooooooo03Oooooo00?o
0000ooooooooool0Goooool0027ooooo00?o0000ooooooooool0HOooool00ol0003oooooooooo`0e
ooooo`03o`000?oooooooooo063ooooo000Qooooo`;o0000H_ooool00ol0003oooooooooo`0eoooo
o`03o`000?oooooooooo063ooooo000Qooooo`03o`000?oooooooooo067ooooo00?o0000oooooooo
ool0=Oooool00ol0003oooooooooo`1Pooooo`008Oooool00ol0003oooooooooo`1Qooooo`03o`00
0?oooooooooo03Cooooo00?o0000ooooooooool0HOooool0027ooooo00?o0000ooooooooool0H_oo
ool00ol0003oooooooooo`0cooooo`03o`000?oooooooooo067ooooo000Qooooo`03o`000?oooooo
oooo06;ooooo00?o0000ooooooooool0<oooool00ol0003oooooooooo`1Qooooo`008Oooool00ol0
003oooooooooo`1Rooooo`03o`000?oooooooooo03?ooooo00?o0000ooooooooool0HOooool0027o
oooo0_l0001Sooooo`03o`000?oooooooooo03;ooooo00?o0000ooooooooool0H_ooool0027ooooo
00?o0000ooooooooool0Hoooool00ol0003oooooooooo`0aooooo`03o`000?oooooooooo06;ooooo
000Qooooo`03o`000?oooooooooo06?ooooo00?o0000ooooooooool0<Oooool00ol0003ooooooooo
o`1Rooooo`000_ooool2o`0000Cooooo00?o0000ooooooooool00oooool2o`0000Cooooo0_l00004
ooooo`?o00001?ooool00ol0003oooooooooo`1Sooooo`03o`000?oooooooooo033ooooo00?o0000
ooooooooool0Hoooool00005ooooool0003oooooooooool000002?ooool01?l0003oooooooooool0
0002ooooo`04o`000?ooooooooooo`0000Cooooo00?o0000ooooooooool00oooool00ol0003ooooo
ooooo`1Sooooo`03o`000?oooooooooo033ooooo00?o0000ooooooooool0Hoooool00005ooooool0
003oooooooooool000002?ooool01?l0003oooooooooool00002ooooo`05o`000?ooooooooooo`00
0?ooool01Ol00004ooooo`03o`000?oooooooooo06Cooooo00?o0000ooooooooool0;oooool00ol0
003oooooooooo`1Sooooo`0000Goooooo`000?ooooooooooo`000008ooooo`04o`000?oooooooooo
o`0000;ooooo00Ko0000oooooooooooo0000ooooool00002ooooo`03o`000?oooooooooo00?ooooo
0_l0001Uooooo`03o`000?oooooooooo02oooooo00?o0000ooooooooool0Hoooool00005ooooool0
003oooooooooool000002?ooool01?l0003oooooooooool00002ooooo`04o`000?ooooooooooo`00
00;ooooo00?o0000ooooool000001Oooool00ol0003oooooooooo`1Tooooo`03o`000?oooooooooo
02kooooo00?o0000ooooooooool0I?ooool00005ooooool0003oooooooooool000002?ooool01?l0
003oooooooooool00002ooooo`04o`000?ooooooooooo`0000?ooooo0_l00005ooooo`03o`000?oo
oooooooo06Cooooo00?o0000ooooooooool0;_ooool00ol0003oooooooooo`1Tooooo`000_ooool2
o`0000[ooooo0_l00004ooooo`;o00001Oooool00ol0003oooooooooo`03ooooo`03o`000?oooooo
oooo06Gooooo00?o0000ooooooooool0;Oooool00ol0003oooooooooo`1Tooooo`008Oooool00ol0
003oooooooooo`1Uooooo`03o`000?oooooooooo02gooooo00?o0000ooooooooool0I?ooool0027o
oooo0_l0001Vooooo`03o`000?oooooooooo02cooooo00?o0000ooooooooool0IOooool0027ooooo
00?o0000ooooooooool0IOooool00ol0003oooooooooo`0/ooooo`03o`000?oooooooooo06Gooooo
000Qooooo`03o`000?oooooooooo06Kooooo00?o0000ooooooooool0:oooool00ol0003ooooooooo
o`1Uooooo`008Oooool00ol0003oooooooooo`1Vooooo`03o`000?oooooooooo02[ooooo00?o0000
ooooooooool0I_ooool0027ooooo00?o0000ooooooooool0I_ooool00ol0003oooooooooo`0Zoooo
o`03o`000?oooooooooo06Kooooo000Qooooo`03o`000?oooooooooo06Kooooo00?o0000oooooooo
ool0:_ooool00ol0003oooooooooo`1Vooooo`008Oooool2o`0006Sooooo00?o0000ooooooooool0
:Oooool00ol0003oooooooooo`1Vooooo`008Oooool00ol0003oooooooooo`1Wooooo`03o`000?oo
oooooooo02Sooooo00?o0000ooooooooool0Ioooool0027ooooo00?o0000ooooooooool0Ioooool0
0ol0003oooooooooo`0Xooooo`03o`000?oooooooooo06Oooooo000Qooooo`03o`000?oooooooooo
06Oooooo00?o0000ooooooooool0:?ooool00ol0003oooooooooo`1Wooooo`008Oooool00ol0003o
ooooooooo`1Xooooo`03o`000?oooooooooo02Kooooo00?o0000ooooooooool0J?ooool0027ooooo
00?o0000ooooooooool0J?ooool00ol0003oooooooooo`0Vooooo`03o`000?oooooooooo06Sooooo
000Qooooo`;o0000JOooool00ol0003oooooooooo`0Vooooo`03o`000?oooooooooo06Sooooo000Q
ooooo`03o`000?oooooooooo06Sooooo00?o0000ooooooooool09_ooool00ol0003oooooooooo`1X
ooooo`008Oooool00ol0003oooooooooo`1Xooooo`03o`000?oooooooooo02Kooooo00?o0000oooo
ooooool0J?ooool000;ooooo0_l00004ooooo`03o`000?oooooooooo00?ooooo0_l00004ooooo`;o
00000oooool3o`0000Gooooo00?o0000ooooooooool0J?ooool00ol0003oooooooooo`0Vooooo`03
o`000?oooooooooo06Sooooo00001Ooooooo0000oooooooooooo000000Sooooo00Co0000oooooooo
oooo00000_ooool01_l0003oooooooooool0003oooooo`0000?ooooo00?o0000ooooooooool00_oo
ool00ol0003oooooooooo`1Yooooo`03o`000?oooooooooo02Cooooo00?o0000ooooooooool0JOoo
ool00005ooooool0003oooooooooool000002?ooool01?l0003oooooooooool00002ooooo`06o`00
0?ooooooooooo`000?oooooo00000oooool00ol0003oooooooooo`02ooooo`;o0000J_ooool00ol0
003oooooooooo`0Tooooo`03o`000?oooooooooo06Wooooo00001Ooooooo0000oooooooooooo0000
00Sooooo00Co0000oooooooooooo00000_ooool01Ol0003oooooooooool0003ooooo00Co00001Ooo
ool00ol0003oooooooooo`1Yooooo`03o`000?oooooooooo02Cooooo00?o0000ooooooooool0JOoo
ool00005ooooool0003oooooooooool000002?ooool01?l0003oooooooooool00002ooooo`06o`00
0?ooooooooooo`000?oooooo00002?ooool00ol0003oooooooooo`1Yooooo`03o`000?oooooooooo
02Cooooo00?o0000ooooooooool0JOooool00005ooooool0003oooooooooool000002?ooool01?l0
003oooooooooool00002ooooo`04o`000?ooooooooooo`0000;ooooo00?o0000ooooooooool01Ooo
ool00ol0003oooooooooo`1Yooooo`03o`000?oooooooooo02Cooooo00?o0000ooooooooool0JOoo
ool000;ooooo0_l0000:ooooo`;o00001?ooool2o`0000Cooooo0_l00005ooooo`03o`000?oooooo
oooo06Wooooo00?o0000ooooooooool09?ooool00ol0003oooooooooo`1Yooooo`008Oooool00ol0
003oooooooooo`1Yooooo`03o`000?oooooooooo02Cooooo00?o0000ooooooooool0JOooool0027o
oooo0_l0001[ooooo`03o`000?oooooooooo02;ooooo00?o0000ooooooooool0J_ooool0027ooooo
00?o0000ooooooooool0J_ooool00ol0003oooooooooo`0Rooooo`03o`000?oooooooooo06[ooooo
000Qooooo`03o`000?oooooooooo06[ooooo00?o0000ooooooooool08_ooool00ol0003ooooooooo
o`1Zooooo`008Oooool00ol0003oooooooooo`1Zooooo`03o`000?oooooooooo02;ooooo00?o0000
ooooooooool0J_ooool0027ooooo00?o0000ooooooooool0J_ooool00ol0003oooooooooo`0Roooo
o`03o`000?oooooooooo06[ooooo000Qooooo`;o0000Joooool00ol0003oooooooooo`0Rooooo`03
o`000?oooooooooo06[ooooo000Qooooo`03o`000?oooooooooo06[ooooo00?o0000ooooooooool0
8_ooool00ol0003oooooooooo`1Zooooo`008Oooool00ol0003oooooooooo`1Zooooo`03o`000?oo
oooooooo02;ooooo00?o0000ooooooooool0J_ooool0027ooooo00?o0000ooooooooool0Joooool0
0ol0003oooooooooo`0Pooooo`03o`000?oooooooooo06_ooooo000Qooooo`03o`000?oooooooooo
06_ooooo00?o0000ooooooooool08?ooool00ol0003oooooooooo`1[ooooo`008Oooool00ol0003o
ooooooooo`1[ooooo`03o`000?oooooooooo023ooooo00?o0000ooooooooool0Joooool0027ooooo
0_l0001/ooooo`03o`000?oooooooooo023ooooo00?o0000ooooooooool0Joooool0027ooooo00?o
0000ooooooooool0Joooool00ol0003oooooooooo`0Pooooo`03o`000?oooooooooo06_ooooo000Q
ooooo`03o`000?oooooooooo06_ooooo00?o0000ooooooooool08?ooool00ol0003oooooooooo`1[
ooooo`000_ooool2o`0000Cooooo00?o0000ooooooooool00oooool2o`0000Cooooo0_l00003oooo
o`?o00001Oooool00ol0003oooooooooo`1[ooooo`03o`000?oooooooooo023ooooo00?o0000oooo
ooooool0Joooool00005ooooool0003oooooooooool000002?ooool01?l0003oooooooooool00002
ooooo`06o`000?ooooooooooo`000?oooooo00000oooool00ol0003oooooooooo`02ooooo`03o`00
0?oooooooooo06_ooooo00?o0000ooooooooool08?ooool00ol0003oooooooooo`1[ooooo`0000Go
ooooo`000?ooooooooooo`000008ooooo`04o`000?ooooooooooo`0000;ooooo00Ko0000oooooooo
oooo0000ooooool00003ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0K?ooool0
0ol0003oooooooooo`0Nooooo`03o`000?oooooooooo06cooooo00001Ooooooo0000oooooooooooo
000000Sooooo00Co0000oooooooooooo00000_ooool01?l0003oooooooooool00002ooooo`?o0000
1Oooool2o`0006gooooo00?o0000ooooooooool07_ooool00ol0003oooooooooo`1/ooooo`0000Go
ooooo`000?ooooooooooo`000008ooooo`04o`000?ooooooooooo`0000;ooooo00Ko0000oooooooo
oooo0000ooooool00003ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0K?ooool0
0ol0003oooooooooo`0Nooooo`03o`000?oooooooooo06cooooo00001Ooooooo0000oooooooooooo
000000Sooooo00Co0000oooooooooooo00000_ooool01_l0003oooooooooool0003oooooo`0000?o
oooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`1/ooooo`03o`000?oooooooooo01ko
oooo00?o0000ooooooooool0K?ooool000;ooooo0_l0000:ooooo`;o00001?ooool2o`0000?ooooo
0ol00005ooooo`03o`000?oooooooooo06cooooo00?o0000ooooooooool07_ooool00ol0003ooooo
ooooo`1/ooooo`008Oooool00ol0003oooooooooo`1/ooooo`03o`000?oooooooooo01kooooo00?o
0000ooooooooool0K?ooool0027ooooo0_l0001]ooooo`03o`000?oooooooooo01kooooo00?o0000
ooooooooool0K?ooool0027ooooo00?o0000ooooooooool0KOooool00ol0003oooooooooo`0Loooo
o`03o`000?oooooooooo06gooooo000Qooooo`03o`000?oooooooooo06gooooo00?o0000oooooooo
ool07?ooool00ol0003oooooooooo`1]ooooo`008Oooool00ol0003oooooooooo`1]ooooo`03o`00
0?oooooooooo01cooooo00?o0000ooooooooool0KOooool0027ooooo00?o0000ooooooooool0KOoo
ool00ol0003oooooooooo`0Looooo`03o`000?oooooooooo06gooooo000Qooooo`03o`000?oooooo
oooo06gooooo00?o0000ooooooooool07?ooool00ol0003oooooooooo`1]ooooo`008Oooool2o`00
06kooooo00?o0000ooooooooool07?ooool00ol0003oooooooooo`1]ooooo`008Oooool00ol0003o
ooooooooo`1]ooooo`03o`000?oooooooooo01cooooo00?o0000ooooooooool0KOooool0027ooooo
00?o0000ooooooooool0KOooool00ol0003oooooooooo`0Looooo`03o`000?oooooooooo06gooooo
000Qooooo`03o`000?oooooooooo06kooooo00?o0000ooooooooool06_ooool00ol0003ooooooooo
o`1^ooooo`008Oooool00ol0003oooooooooo`1^ooooo`03o`000?oooooooooo01[ooooo00?o0000
ooooooooool0K_ooool0027ooooo00?o0000ooooooooool0K_ooool00ol0003oooooooooo`0Joooo
o`03o`000?oooooooooo06kooooo000Qooooo`;o0000Koooool00ol0003oooooooooo`0Jooooo`03
o`000?oooooooooo06kooooo000Qooooo`03o`000?oooooooooo06kooooo00?o0000ooooooooool0
6_ooool00ol0003oooooooooo`1^ooooo`008Oooool00ol0003oooooooooo`1^ooooo`03o`000?oo
oooooooo01[ooooo00?o0000ooooooooool0K_ooool000Sooooo0_l00004ooooo`03o`000?oooooo
oooo00?ooooo0_l00003ooooo`?o00001Oooool00ol0003oooooooooo`1^ooooo`03o`000?oooooo
oooo01[ooooo00?o0000ooooooooool0K_ooool000Oooooo00Co0000oooooooooooo00002?ooool0
1?l0003oooooooooool00003ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0K_oo
ool00ol0003oooooooooo`0Jooooo`03o`000?oooooooooo06kooooo0007ooooo`04o`000?oooooo
ooooo`0000Sooooo00Co0000oooooooooooo00000oooool00ol0003oooooooooo`04ooooo`;o0000
L?ooool00ol0003oooooooooo`0Hooooo`03o`000?oooooooooo06oooooo0007ooooo`04o`000?oo
ooooooooo`0000Sooooo00Co0000oooooooooooo00000oooool00ol0003oooooooooo`04ooooo`03
o`000?oooooooooo06oooooo00?o0000ooooooooool06?ooool00ol0003oooooooooo`1_ooooo`00
1oooool01?l0003oooooooooool00008ooooo`04o`000?ooooooooooo`0000?ooooo00?o0000oooo
ooooool01?ooool00ol0003oooooooooo`1_ooooo`03o`000?oooooooooo01Sooooo00?o0000oooo
ooooool0Koooool000Oooooo00Co0000oooooooooooo00002?ooool01?l0003oooooooooool00002
ooooo`;o00001_ooool00ol0003oooooooooo`1_ooooo`03o`000?oooooooooo01Sooooo00?o0000
ooooooooool0Koooool000Sooooo0_l0000:ooooo`;o00001?ooool00ol0003oooooooooo`04oooo
o`03o`000?oooooooooo06oooooo00?o0000ooooooooool06?ooool00ol0003oooooooooo`1_oooo
o`008Oooool00ol0003oooooooooo`1_ooooo`03o`000?oooooooooo01Sooooo00?o0000oooooooo
ool0Koooool0027ooooo0_l0001`ooooo`03o`000?oooooooooo01Sooooo00?o0000ooooooooool0
Koooool0027ooooo00?o0000ooooooooool0L?ooool00ol0003oooooooooo`0Fooooo`03o`000?oo
oooooooo073ooooo000Qooooo`03o`000?oooooooooo073ooooo00?o0000ooooooooool05_ooool0
0ol0003oooooooooo`1`ooooo`008Oooool00ol0003oooooooooo`1`ooooo`03o`000?oooooooooo
01Kooooo00?o0000ooooooooool0L?ooool0027ooooo00?o0000ooooooooool0L?ooool00ol0003o
ooooooooo`0Fooooo`03o`000?oooooooooo073ooooo000Qooooo`;o0000LOooool00ol0003ooooo
ooooo`0Fooooo`03o`000?oooooooooo073ooooo000Qooooo`03o`000?oooooooooo073ooooo00?o
0000ooooooooool05_ooool00ol0003oooooooooo`1`ooooo`008Oooool00ol0003oooooooooo`1`
ooooo`03o`000?oooooooooo01Kooooo00?o0000ooooooooool0L?ooool0027ooooo00?o0000oooo
ooooool0L?ooool00ol0003oooooooooo`0Fooooo`03o`000?oooooooooo073ooooo000Qooooo`03
o`000?oooooooooo073ooooo00?o0000ooooooooool05_ooool00ol0003oooooooooo`1`ooooo`00
8Oooool00ol0003oooooooooo`1`ooooo`03o`000?oooooooooo01Kooooo00?o0000ooooooooool0
L?ooool0027ooooo0_l0001booooo`03o`000?oooooooooo01Cooooo00?o0000ooooooooool0LOoo
ool0027ooooo00?o0000ooooooooool0LOooool00ol0003oooooooooo`0Dooooo`03o`000?oooooo
oooo077ooooo000Qooooo`03o`000?oooooooooo077ooooo00?o0000ooooooooool05?ooool00ol0
003oooooooooo`1aooooo`000_ooool2o`0000Cooooo00?o0000ooooooooool00oooool2o`0000?o
oooo0ol00002ooooo`Go00001?ooool00ol0003oooooooooo`1aooooo`03o`000?oooooooooo01Co
oooo00?o0000ooooooooool0LOooool00005ooooool0003oooooooooool000002?ooool01?l0003o
ooooooooool00003ooooo`03o`000?oooooooooo00;ooooo00Co0000oooooooooooo00001?ooool0
0ol0003oooooooooo`1aooooo`03o`000?oooooooooo01Cooooo00?o0000ooooooooool0LOooool0
0005ooooool0003oooooooooool000002?ooool01?l0003oooooooooool00003ooooo`03o`000?oo
oooooooo00?ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`1aooooo`03o`000?oo
oooooooo01Cooooo00?o0000ooooooooool0LOooool00005ooooool0003oooooooooool000002?oo
ool01?l0003oooooooooool00003ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0
0oooool2o`0007;ooooo00?o0000ooooooooool05?ooool00ol0003oooooooooo`1aooooo`0000Go
ooooo`000?ooooooooooo`000008ooooo`04o`000?ooooooooooo`0000?ooooo00Go0000oooooooo
ooooooooo`000003ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0LOooool00ol0
003oooooooooo`0Dooooo`03o`000?oooooooooo077ooooo00001Ooooooo0000oooooooooooo0000
00Sooooo00Co0000oooooooooooo00000_ooool2o`0000?ooooo00Go0000ooooooooooooooooo`00
0004ooooo`03o`000?oooooooooo077ooooo00?o0000ooooooooool05?ooool00ol0003ooooooooo
o`1aooooo`000_ooool2o`0000[ooooo0_l00004ooooo`03o`000?oooooooooo00;ooooo0ol00005
ooooo`03o`000?oooooooooo077ooooo00?o0000ooooooooool05?ooool00ol0003oooooooooo`1a
ooooo`008Oooool00ol0003oooooooooo`1aooooo`03o`000?oooooooooo01Cooooo00?o0000oooo
ooooool0LOooool0027ooooo0_l0001cooooo`03o`000?oooooooooo01;ooooo00?o0000oooooooo
ool0L_ooool0027ooooo00?o0000ooooooooool0L_ooool00ol0003oooooooooo`0Booooo`03o`00
0?oooooooooo07;ooooo000Qooooo`03o`000?oooooooooo07;ooooo00?o0000ooooooooool04_oo
ool00ol0003oooooooooo`1booooo`008Oooool00ol0003oooooooooo`1booooo`03o`000?oooooo
oooo01;ooooo00?o0000ooooooooool0L_ooool0027ooooo00?o0000ooooooooool0L_ooool00ol0
003oooooooooo`0Booooo`03o`000?oooooooooo07;ooooo000Qooooo`03o`000?oooooooooo07;o
oooo00?o0000ooooooooool04_ooool00ol0003oooooooooo`1booooo`008Oooool2o`0007?ooooo
00?o0000ooooooooool04_ooool00ol0003oooooooooo`1booooo`008Oooool00ol0003ooooooooo
o`1booooo`03o`000?oooooooooo01;ooooo00?o0000ooooooooool0L_ooool0027ooooo00?o0000
ooooooooool0L_ooool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo07;ooooo000Qoooo
o`03o`000?oooooooooo07;ooooo00?o0000ooooooooool04_ooool00ol0003oooooooooo`1boooo
o`008Oooool00ol0003oooooooooo`1booooo`03o`000?oooooooooo01;ooooo00?o0000oooooooo
ool0L_ooool0027ooooo00?o0000ooooooooool0L_ooool00ol0003oooooooooo`0Booooo`03o`00
0?oooooooooo07;ooooo000Qooooo`;o0000M?ooool00ol0003oooooooooo`0@ooooo`03o`000?oo
oooooooo07?ooooo000Qooooo`03o`000?oooooooooo07?ooooo00?o0000ooooooooool04?ooool0
0ol0003oooooooooo`1cooooo`008Oooool00ol0003oooooooooo`1cooooo`03o`000?oooooooooo
013ooooo00?o0000ooooooooool0Loooool0027ooooo00?o0000ooooooooool0Loooool00ol0003o
ooooooooo`0@ooooo`03o`000?oooooooooo07?ooooo000Qooooo`03o`000?oooooooooo07?ooooo
00?o0000ooooooooool04?ooool00ol0003oooooooooo`1cooooo`008Oooool00ol0003ooooooooo
o`1cooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool0Loooool00?oooooo8Oooool0
0?oooooo8Oooool00?oooooo8Oooool00001\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-4.02939, -0.00143892, \
0.121183, 8.89285*^-5}}]
}, Closed]],

Cell[BoxData[
    \({0.10187238978721752`, 0.06414211088386193`, 0.037833382747226606`, 
      0.019412720566111357`}\)], "Output",
  CellLabel->"Out[37]="]
}, Open  ]],

Cell["\<\
The prediction approaches reasonable accuracy for weak selection \
(though it is still 50% out)  It breaks down for strong selection, because \
\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\({\(DisequilibriumMean[\(res[3, 0.04, #]\)[
                  500]]\)\[LeftDoubleBracket]15\[RightDoubleBracket], \
\((0.5\/#)\)/First[ClineWidth[\(res[3, 0.04, #]\)[500]]]\^2} &\) /@ {0.05, 
          0.1, 0.2, 0.5} // TableForm\)], "Input",
  CellLabel->"In[42]:="],

Cell[BoxData[
    TagBox[GridBox[{
          {"0.10187238978721752`", "0.4651762376195494`"},
          {"0.06414211088386193`", "0.1918499679297967`"},
          {"0.037833382747226606`", "0.08324438828776086`"},
          {"0.019412720566111357`", "0.030200491620022155`"}
          },
        RowSpacings->1,
        ColumnSpacings->3,
        RowAlignments->Baseline,
        ColumnAlignments->{Left}],
      Function[ BoxForm`e$, 
        TableForm[ BoxForm`e$]]]], "Output",
  CellLabel->"Out[42]//TableForm="]
}, Open  ]],

Cell["\<\
With more loci, the effects of linkage disequilibrium become \
stronger.  \
\>", "Text"],

Cell[BoxData[
    \(\(StoreExact[res[5, 0.08], MakeCline[30, 5, 100], 
        fitness[0.04, 15, ecotone], 0.5, {100, 20}, Compiled \[Rule] True, 
        FixedEnds \[Rule] {MakePopulation[5, 0], 
            MakePopulation[5, 1]}];\)\)], "Input",
  CellLabel->"In[51]:="],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(LinearLogListPlot[
        1/\((1\/AlleleFrequencyMean[\(res[5, 0.08]\)[100]] - 1)\), 
        PlotJoined \[Rule] True];\)\)], "Input",
  CellLabel->"In[50]:="],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.031746 0.309017 0.141599 [
[.02381 -0.0125 -3 -9 ]
[.02381 -0.0125 3 0 ]
[.18254 -0.0125 -3 -9 ]
[.18254 -0.0125 3 0 ]
[.34127 -0.0125 -6 -9 ]
[.34127 -0.0125 6 0 ]
[.5 -0.0125 -6 -9 ]
[.5 -0.0125 6 0 ]
[.65873 -0.0125 -6 -9 ]
[.65873 -0.0125 6 0 ]
[.81746 -0.0125 -6 -9 ]
[.81746 -0.0125 6 0 ]
[.97619 -0.0125 -6 -9 ]
[.97619 -0.0125 6 0 ]
[-0.0125 .02582 -28 -6 ]
[-0.0125 .02582 0 6 ]
[-0.0125 .16742 -22 -6 ]
[-0.0125 .16742 0 6 ]
[-0.0125 .30902 -10 -6 ]
[-0.0125 .30902 0 6 ]
[-0.0125 .45062 -16 -6 ]
[-0.0125 .45062 0 6 ]
[-0.0125 .59222 -22 -6 ]
[-0.0125 .59222 0 6 ]
[ -0.0005 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 0 m
.02381 .00625 L
s
[(0)] .02381 -0.0125 0 1 Mshowa
.18254 0 m
.18254 .00625 L
s
[(5)] .18254 -0.0125 0 1 Mshowa
.34127 0 m
.34127 .00625 L
s
[(10)] .34127 -0.0125 0 1 Mshowa
.5 0 m
.5 .00625 L
s
[(15)] .5 -0.0125 0 1 Mshowa
.65873 0 m
.65873 .00625 L
s
[(20)] .65873 -0.0125 0 1 Mshowa
.81746 0 m
.81746 .00625 L
s
[(25)] .81746 -0.0125 0 1 Mshowa
.97619 0 m
.97619 .00625 L
s
[(30)] .97619 -0.0125 0 1 Mshowa
.125 Mabswid
.05556 0 m
.05556 .00375 L
s
.0873 0 m
.0873 .00375 L
s
.11905 0 m
.11905 .00375 L
s
.15079 0 m
.15079 .00375 L
s
.21429 0 m
.21429 .00375 L
s
.24603 0 m
.24603 .00375 L
s
.27778 0 m
.27778 .00375 L
s
.30952 0 m
.30952 .00375 L
s
.37302 0 m
.37302 .00375 L
s
.40476 0 m
.40476 .00375 L
s
.43651 0 m
.43651 .00375 L
s
.46825 0 m
.46825 .00375 L
s
.53175 0 m
.53175 .00375 L
s
.56349 0 m
.56349 .00375 L
s
.59524 0 m
.59524 .00375 L
s
.62698 0 m
.62698 .00375 L
s
.69048 0 m
.69048 .00375 L
s
.72222 0 m
.72222 .00375 L
s
.75397 0 m
.75397 .00375 L
s
.78571 0 m
.78571 .00375 L
s
.84921 0 m
.84921 .00375 L
s
.88095 0 m
.88095 .00375 L
s
.9127 0 m
.9127 .00375 L
s
.94444 0 m
.94444 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .02582 m
.00625 .02582 L
s
gsave
-0.0125 .02582 -89 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.01) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 .16742 m
.00625 .16742 L
s
gsave
-0.0125 .16742 -83 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.1) show
81.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 .30902 m
.00625 .30902 L
s
gsave
-0.0125 .30902 -71 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 .45062 m
.00625 .45062 L
s
gsave
-0.0125 .45062 -77 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(10) show
75.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 .59222 m
.00625 .59222 L
s
gsave
-0.0125 .59222 -83 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(100) show
81.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.001 w
0 .06844 m
.00375 .06844 L
s
0 .09338 m
.00375 .09338 L
s
0 .11107 m
.00375 .11107 L
s
0 .12479 m
.00375 .12479 L
s
0 .136 m
.00375 .136 L
s
0 .14548 m
.00375 .14548 L
s
0 .1537 m
.00375 .1537 L
s
0 .16094 m
.00375 .16094 L
s
0 .21004 m
.00375 .21004 L
s
0 .23498 m
.00375 .23498 L
s
0 .25267 m
.00375 .25267 L
s
0 .26639 m
.00375 .26639 L
s
0 .2776 m
.00375 .2776 L
s
0 .28708 m
.00375 .28708 L
s
0 .29529 m
.00375 .29529 L
s
0 .30254 m
.00375 .30254 L
s
0 .35164 m
.00375 .35164 L
s
0 .37658 m
.00375 .37658 L
s
0 .39427 m
.00375 .39427 L
s
0 .40799 m
.00375 .40799 L
s
0 .4192 m
.00375 .4192 L
s
0 .42868 m
.00375 .42868 L
s
0 .43689 m
.00375 .43689 L
s
0 .44414 m
.00375 .44414 L
s
0 .49324 m
.00375 .49324 L
s
0 .51818 m
.00375 .51818 L
s
0 .53587 m
.00375 .53587 L
s
0 .54959 m
.00375 .54959 L
s
0 .5608 m
.00375 .5608 L
s
0 .57028 m
.00375 .57028 L
s
0 .57849 m
.00375 .57849 L
s
0 .58574 m
.00375 .58574 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.05556 .01472 m
.0873 .02326 L
.11905 .0324 L
.15079 .04358 L
.18254 .05679 L
.21429 .07184 L
.24603 .0885 L
.27778 .1066 L
.30952 .12603 L
.34127 .14678 L
.37302 .16895 L
.40476 .19282 L
.43651 .21899 L
.46825 .24865 L
.5 .2845 L
.53175 .33353 L
.56349 .36938 L
.59524 .39905 L
.62698 .42521 L
.65873 .44908 L
.69048 .47125 L
.72222 .492 L
.75397 .51143 L
.78571 .52953 L
.81746 .54619 L
.84921 .56124 L
.88095 .57446 L
.9127 .58563 L
.94444 .59478 L
.97619 .60332 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[50]:=",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/B000`400?l00000o`00003ooooooolQ
ooooo`00oooooolQooooo`00oooooolQooooo`00oooooolQooooo`009?ooool2o`0002Gooooo0ol0
000Sooooo`?o00001?ooool2o`00023ooooo0ol00003ooooo`?o00007_ooool5o`0000?ooooo0_l0
000Oooooo`Go00000_ooool3o`0001oooooo0ol00004ooooo`;o00001?ooool002?ooooo00Co0000
oooooooooooo00008oooool01Ol0003ooooooooooooooooo000002?ooooo00?o0000ooooooooool0
0_ooool01?l0003oooooooooool0000Pooooo`05o`000?ooooooooooooooool000000oooool00ol0
003oooooooooo`0Looooo`04o`000?ooooooooooo`0000;ooooo00Co0000oooooooooooo00007ooo
ool01_l0003oooooooooool0003oooooo`0000?ooooo00?o0000ooooooooool06oooool01Ol0003o
oooooooooooooooo000000;ooooo00Co0000oooooooooooo00000oooool002?ooooo00Co0000oooo
oooooooo00009oooool00ol0003oooooooooo`0Qooooo`03o`000?oooooooooo00;ooooo00Co0000
oooooooooooo00008?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo01gooooo00?o
0000ooooooooool00_ooool01?l0003oooooooooool0000Pooooo`03o`000?oooooooooo00Gooooo
00?o0000ooooooooool07oooool01?l0003oooooooooool00002ooooo`03o`000?oooooooooo007o
oooo000Sooooo`04o`000?ooooooooooo`0002Oooooo00?o0000ooooooooool08Oooool00ol0003o
ooooooooo`02ooooo`04o`000?ooooooooooo`00023ooooo00?o0000ooooooooool01Oooool00ol0
003oooooooooo`0Nooooo`05o`000?ooooooooooooooool000000_ooool00ol0003oooooooooo`0O
ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool07Oooool2o`0000?ooooo00Co0000
oooooooooooo00000oooool002?ooooo00Co0000oooooooooooo00008oooool4o`0002Cooooo00?o
0000ooooooooool00_ooool01?l0003oooooooooool0000Pooooo`04o`000?ooooooooooooooo`Co
00007_ooool01Ol0003ooooooooooooooooo000000;ooooo00Co0000oooooooooooo00007_ooool0
1_l0003ooooooooooooooooo0000ooooo`Co00008_ooool01?l0003oooooooooool00002ooooo`03
o`000?oooooooooo007ooooo000Sooooo`04o`000?ooooooooooo`0002?ooooo00?o0000oooooooo
ool09?ooool2o`0000Cooooo00Co0000oooooooooooo00007oooool2o`0000?ooooo00?o0000oooo
ooooool07oooool01Ol0003ooooooooooooooooo000000;ooooo00Co0000oooooooooooo00007_oo
ool01ol0003ooooooooooooooooo0000ooooool000008Oooool01Ol0003ooooooooooooooooo0000
00;ooooo00Co0000oooooooooooo00000oooool002Cooooo0_l0000Tooooo`Go00008oooool00ol0
003oooooooooo`03ooooo`;o00008Oooool01?l0003oooooooooooooool5o`0001kooooo0ol00004
ooooo`;o00008?ooool3o`0000;ooooo1Ol0000Nooooo`?o00001?ooool2o`0000Cooooo003ooooo
ob7ooooo003oooooob7ooooo003oooooob7ooooo003oooooob7ooooo000Ooooooooo00000_l00000
01oooooo00?o0000ooooooooool00oooool00`00003oooooooooo`05ooooo`03o`000?oooooooooo
00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo
00Gooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo
00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo
00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo
00Gooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo
00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo
00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo
00Kooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo
00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo
00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`007oooool00ol0003o
ooooooooo`03ooooo`0300000?oooooooooo02Gooooo00?o0000ooooooooool09_ooool00ol0003o
ooooooooo`0Vooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool09_ooool00ol0003o
ooooooooo`0Uooooo`03o`000?oooooooooo00Gooooo000Oooooo`03o`000?oooooooooo0?kooooo
000Oooooo`03o`000?oooooooooo00_ooooo0ol0003`ooooo`001?ooool2o`0000Cooooo00?o0000
ooooooooool00oooool2o`0000?ooooo0ol00007ooooo`03o`000?oooooooooo00kooooo1?l0003/
ooooo`000oooool01?l0003oooooooooool00008ooooo`04o`000?ooooooooooo`0000?ooooo00?o
0000ooooooooool01_ooool00ol0003oooooooooo`0Booooo`Co0000j?ooool000?ooooo00Co0000
oooooooooooo00002?ooool01?l0003oooooooooool00003ooooo`03o`000?oooooooooo00Kooooo
0_l0000Gooooo`Co0000i?ooool000?ooooo00Co0000oooooooooooo00002?ooool01?l0003ooooo
ooooool00003ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool06_ooool3o`000>7o
oooo0003ooooo`04o`000?ooooooooooo`0000Sooooo00Co0000oooooooooooo00000oooool00ol0
003oooooooooo`06ooooo`03o`000?oooooooooo01gooooo0ol0003Nooooo`000oooool01?l0003o
ooooooooool00008ooooo`04o`000?ooooooooooo`0000;ooooo0_l00008ooooo`03o`000?oooooo
oooo023ooooo0ol0003Kooooo`001?ooool2o`0000[ooooo0_l00004ooooo`03o`000?oooooooooo
00Kooooo00?o0000ooooooooool08oooool2o`000=Wooooo000Oooooo`03o`000?oooooooooo02Go
oooo0_l0003Gooooo`007oooool00ol0003oooooooooo`0Wooooo`;o0000eOooool001oooooo00?o
0000ooooooooool0:Oooool2o`000=?ooooo000Oooooo`03o`000?oooooooooo02_ooooo0ol0003@
ooooo`007oooool00ol0003oooooooooo`0^ooooo`?o0000cOooool001oooooo00?o0000oooooooo
ool0<Oooool3o`000<[ooooo000Oooooo`;o0000=Oooool2o`000<Sooooo000Oooooo`03o`000?oo
oooooooo03Kooooo00?o0000ooooooooool0aOooool001oooooo00?o0000ooooooooool0=oooool2
o`000<Gooooo000Oooooo`03o`000?oooooooooo03Wooooo0_l00033ooooo`007oooool00ol0003o
ooooooooo`0kooooo`03o`000?oooooooooo0<3ooooo000Oooooo`03o`000?oooooooooo03cooooo
0_l00030ooooo`007oooool2o`0003oooooo0_l0002nooooo`007oooool00ol0003oooooooooo`10
ooooo`;o0000_?ooool001oooooo00?o0000ooooooooool0@_ooool2o`000;[ooooo000Oooooo`03
o`000?oooooooooo04Cooooo0_l0002hooooo`007oooool2o`0004Oooooo00?o0000ooooooooool0
]Oooool001oooooo00?o0000ooooooooool0Aoooool2o`000;Gooooo000Oooooo`03o`000?oooooo
oooo04Wooooo0_l0002cooooo`007oooool00ol0003oooooooooo`1;ooooo`03o`000?oooooooooo
0;3ooooo000Oooooo`;o0000COooool2o`000;3ooooo000Oooooo`03o`000?oooooooooo04kooooo
00?o0000ooooooooool0[Oooool001oooooo00?o0000ooooooooool0Coooool00ol0003ooooooooo
o`2/ooooo`007oooool2o`00057ooooo0_l0002/ooooo`007oooool00ol0003oooooooooo`1Boooo
o`03o`000?oooooooooo0:Wooooo000Oooooo`;o0000E?ooool00ol0003oooooooooo`2Xooooo`00
7oooool00ol0003oooooooooo`1Dooooo`;o0000Z?ooool001oooooo0_l0001Gooooo`03o`000?oo
oooooooo0:Gooooo000Oooooo`03o`000?oooooooooo05Oooooo0_l0002Uooooo`002_ooool2o`00
00Cooooo00?o0000ooooooooool00_ooool3o`0000Oooooo0_l0001Jooooo`;o0000Xoooool000Wo
oooo00Co0000oooooooooooo00002Oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo
05_ooooo00?o0000ooooooooool0X?ooool000Wooooo00Co0000oooooooooooo00002Oooool00ol0
003oooooooooo`06ooooo`;o0000GOooool2o`000:3ooooo0009ooooo`04o`000?ooooooooooo`00
00Wooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`1Nooooo`03o`000?oooooooooo
09gooooo0009ooooo`04o`000?ooooooooooo`0000Wooooo00?o0000ooooooooool01_ooool00ol0
003oooooooooo`1Oooooo`03o`000?oooooooooo09cooooo0009ooooo`04o`000?ooooooooooo`00
00Sooooo0_l00008ooooo`03o`000?oooooooooo063ooooo0_l0002Looooo`002_ooool2o`0000[o
oooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`1Rooooo`03o`000?oooooooooo09Wo
oooo000Oooooo`03o`000?oooooooooo06?ooooo00?o0000ooooooooool0V?ooool001oooooo00?o
0000ooooooooool0I?ooool2o`0009Sooooo000Oooooo`03o`000?oooooooooo06Kooooo00?o0000
ooooooooool0UOooool001oooooo00?o0000ooooooooool0Ioooool00ol0003oooooooooo`2Doooo
o`007oooool00ol0003oooooooooo`1Xooooo`03o`000?oooooooooo09?ooooo000Oooooo`03o`00
0?oooooooooo06Wooooo00?o0000ooooooooool0T_ooool001oooooo0_l0001[ooooo`03o`000?oo
oooooooo097ooooo000Oooooo`03o`000?oooooooooo06_ooooo00?o0000ooooooooool0T?ooool0
01oooooo00?o0000ooooooooool0K?ooool00ol0003oooooooooo`2?ooooo`007oooool00ol0003o
ooooooooo`1]ooooo`03o`000?oooooooooo08kooooo000Oooooo`03o`000?oooooooooo06kooooo
00?o0000ooooooooool0SOooool001oooooo00?o0000ooooooooool0Koooool00ol0003ooooooooo
o`2<ooooo`007oooool2o`00077ooooo00?o0000ooooooooool0Roooool001oooooo00?o0000oooo
ooooool0LOooool00ol0003oooooooooo`2:ooooo`007oooool00ol0003oooooooooo`1booooo`03
o`000?oooooooooo08Wooooo000Oooooo`03o`000?oooooooooo07?ooooo00?o0000ooooooooool0
R?ooool001oooooo00?o0000ooooooooool0M?ooool00ol0003oooooooooo`27ooooo`007oooool2
o`0007Kooooo00?o0000ooooooooool0Q_ooool001oooooo00?o0000ooooooooool0M_ooool00ol0
003oooooooooo`25ooooo`007oooool00ol0003oooooooooo`1gooooo`03o`000?oooooooooo08Co
oooo000Oooooo`;o0000NOooool00ol0003oooooooooo`23ooooo`007oooool00ol0003ooooooooo
o`1iooooo`03o`000?oooooooooo08;ooooo000Oooooo`03o`000?oooooooooo07[ooooo00?o0000
ooooooooool0POooool001oooooo0_l0001looooo`03o`000?oooooooooo083ooooo000Oooooo`03
o`000?oooooooooo07cooooo00?o0000ooooooooool0Ooooool001oooooo00?o0000ooooooooool0
OOooool00ol0003oooooooooo`1nooooo`007oooool2o`0007kooooo00?o0000ooooooooool0O_oo
ool001oooooo00?o0000ooooooooool0O_ooool00ol0003oooooooooo`1mooooo`007oooool2o`00
083ooooo00?o0000ooooooooool0O?ooool001Gooooo0ol00007ooooo`;o0000P?ooool00ol0003o
ooooooooo`1looooo`005_ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo083ooooo
00?o0000ooooooooool0Noooool001Kooooo00?o0000ooooooooool01_ooool2o`0008;ooooo00?o
0000ooooooooool0N_ooool001Kooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`21
ooooo`03o`000?oooooooooo07[ooooo000Fooooo`03o`000?oooooooooo00Kooooo00?o0000oooo
ooooool0P_ooool00ol0003oooooooooo`1iooooo`005Oooool2o`0000Sooooo00?o0000oooooooo
ool0Poooool00ol0003oooooooooo`1hooooo`005_ooool00ol0003oooooooooo`06ooooo`03o`00
0?oooooooooo08?ooooo00?o0000ooooooooool0N?ooool001oooooo00?o0000ooooooooool0Q?oo
ool00ol0003oooooooooo`1gooooo`007oooool00ol0003oooooooooo`25ooooo`03o`000?oooooo
oooo07Kooooo000Oooooo`03o`000?oooooooooo08Gooooo00?o0000ooooooooool0M_ooool001oo
oooo00?o0000ooooooooool0Q_ooool00ol0003oooooooooo`1eooooo`007oooool00ol0003ooooo
ooooo`27ooooo`03o`000?oooooooooo07Cooooo000Oooooo`03o`000?oooooooooo08Sooooo00?o
0000ooooooooool0Loooool001oooooo0_l0002:ooooo`03o`000?oooooooooo07;ooooo000Ooooo
o`03o`000?oooooooooo08Wooooo00?o0000ooooooooool0L_ooool001oooooo00?o0000oooooooo
ool0R_ooool00ol0003oooooooooo`1aooooo`007oooool00ol0003oooooooooo`2;ooooo`03o`00
0?oooooooooo073ooooo000Oooooo`03o`000?oooooooooo08cooooo00?o0000ooooooooool0Kooo
ool001oooooo00?o0000ooooooooool0SOooool2o`0006oooooo000Oooooo`;o0000T?ooool00ol0
003oooooooooo`1/ooooo`007oooool00ol0003oooooooooo`2@ooooo`03o`000?oooooooooo06_o
oooo000Oooooo`03o`000?oooooooooo097ooooo00?o0000ooooooooool0J_ooool001oooooo00?o
0000ooooooooool0T_ooool00ol0003oooooooooo`1Yooooo`007oooool00ol0003oooooooooo`2C
ooooo`03o`000?oooooooooo06Sooooo000Oooooo`;o0000UOooool00ol0003oooooooooo`1Woooo
o`007oooool00ol0003oooooooooo`2Eooooo`;o0000Ioooool001oooooo00?o0000ooooooooool0
Uoooool00ol0003oooooooooo`1Tooooo`007oooool2o`0009Wooooo00?o0000ooooooooool0Hooo
ool001oooooo00?o0000ooooooooool0VOooool00ol0003oooooooooo`1Rooooo`007oooool00ol0
003oooooooooo`2Jooooo`03o`000?oooooooooo067ooooo000Oooooo`;o0000W?ooool00ol0003o
ooooooooo`1Pooooo`007oooool00ol0003oooooooooo`2Looooo`03o`000?oooooooooo05oooooo
000Oooooo`03o`000?oooooooooo09gooooo0_l0001Oooooo`007oooool2o`000:3ooooo00?o0000
ooooooooool0G?ooool001oooooo00?o0000ooooooooool0X?ooool00ol0003oooooooooo`1Koooo
o`007oooool2o`000:;ooooo0_l0001Kooooo`003oooool3o`0000Cooooo0_l00007ooooo`03o`00
0?oooooooooo0:?ooooo00?o0000ooooooooool0F?ooool0013ooooo00?o0000ooooooooool00_oo
ool01?l0003oooooooooool00006ooooo`;o0000YOooool00ol0003oooooooooo`1Gooooo`004?oo
ool00ol0003oooooooooo`02ooooo`04o`000?ooooooooooo`0000Kooooo0_l0002Vooooo`;o0000
Eoooool0013ooooo00?o0000ooooooooool00_ooool01?l0003oooooooooool00006ooooo`03o`00
0?oooooooooo0:Oooooo00?o0000ooooooooool0E?ooool0013ooooo00?o0000ooooooooool00_oo
ool01?l0003oooooooooool00006ooooo`03o`000?oooooooooo0:Sooooo00?o0000ooooooooool0
Doooool000oooooo0_l00004ooooo`04o`000?ooooooooooo`0000Kooooo00?o0000ooooooooool0
ZOooool2o`0005?ooooo000@ooooo`03o`000?oooooooooo00?ooooo0_l00007ooooo`03o`000?oo
oooooooo0:_ooooo00?o0000ooooooooool0D?ooool001oooooo00?o0000ooooooooool0[?ooool0
0ol0003oooooooooo`1?ooooo`007oooool00ol0003oooooooooo`2]ooooo`;o0000Coooool001oo
oooo00?o0000ooooooooool0[oooool00ol0003oooooooooo`1<ooooo`007oooool00ol0003ooooo
ooooo`2`ooooo`;o0000C?ooool001oooooo00?o0000ooooooooool0/_ooool2o`0004[ooooo000O
ooooo`03o`000?oooooooooo0;Cooooo00?o0000ooooooooool0Aoooool001oooooo0_l0002foooo
o`;o0000Aoooool001oooooo00?o0000ooooooooool0]oooool2o`0004Gooooo000Oooooo`03o`00
0?oooooooooo0;Wooooo0_l00013ooooo`007oooool00ol0003oooooooooo`2kooooo`03o`000?oo
oooooooo043ooooo000Oooooo`03o`000?oooooooooo0;cooooo0_l00010ooooo`007oooool00ol0
003oooooooooo`2nooooo`;o0000?_ooool001oooooo00?o0000ooooooooool0`?ooool00ol0003o
ooooooooo`0kooooo`007oooool2o`000<;ooooo0_l0000kooooo`007oooool00ol0003ooooooooo
o`33ooooo`;o0000>Oooool001oooooo00?o0000ooooooooool0aOooool00ol0003oooooooooo`0f
ooooo`007oooool00ol0003oooooooooo`36ooooo`;o0000=_ooool001oooooo0_l00039ooooo`;o
0000=?ooool001oooooo00?o0000ooooooooool0b_ooool2o`0003;ooooo000Oooooo`03o`000?oo
oooooooo0<cooooo0_l0000`ooooo`007oooool00ol0003oooooooooo`3>ooooo`;o0000;_ooool0
01oooooo0_l0003Aooooo`;o0000;?ooool001oooooo00?o0000ooooooooool0d_ooool2o`0002[o
oooo000Oooooo`03o`000?oooooooooo0=Cooooo0_l0000Xooooo`007oooool2o`000=Oooooo0_l0
000Vooooo`007oooool00ol0003oooooooooo`3Hooooo`?o00008oooool001oooooo0_l0003Loooo
o`?o00008?ooool001oooooo00?o0000ooooooooool0g_ooool2o`0001kooooo000Oooooo`;o0000
hOooool3o`0001_ooooo000Oooooo`03o`000?oooooooooo0>?ooooo0ol0000Hooooo`002Oooool3
o`0000Cooooo0_l00004ooooo`;o00001oooool2o`000>Oooooo0ol0000Eooooo`002_ooool00ol0
003oooooooooo`02ooooo`04o`000?ooooooooooo`0000;ooooo00Co0000oooooooooooo00001_oo
ool00ol0003oooooooooo`3Yooooo`Co00004Oooool000[ooooo00?o0000ooooooooool00_ooool0
1?l0003oooooooooool00002ooooo`04o`000?ooooooooooo`0000Kooooo0_l0003^ooooo`Co0000
3Oooool000[ooooo00?o0000ooooooooool00_ooool01?l0003oooooooooool00002ooooo`04o`00
0?ooooooooooo`0000Kooooo00?o0000ooooooooool0lOooool4o`0000Wooooo000:ooooo`03o`00
0?oooooooooo00;ooooo00Co0000oooooooooooo00000_ooool01?l0003oooooooooool00006oooo
o`03o`000?oooooooooo0?Gooooo0_l00007ooooo`002Oooool2o`0000Cooooo00Co0000oooooooo
oooo00000_ooool01?l0003oooooooooool00006ooooo`03o`000?oooooooooo0?kooooo000:oooo
o`03o`000?oooooooooo00?ooooo0_l00004ooooo`;o00001oooool00ol0003oooooooooo`3noooo
o`007oooool00ol0003oooooooooo`3nooooo`007oooool00ol0003oooooooooo`3nooooo`00oooo
oolQooooo`00oooooolQooooo`00oooooolQooooo`00\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-4.59192, -2.61086, \
0.123143, 0.0276083}}]
}, Open  ]]
}, Open  ]]
}, Open  ]]
},
FrontEndVersion->"4.2 for Macintosh",
ScreenRectangle->{{0, 1276}, {0, 832}},
WindowSize->{1140, 805},
WindowMargins->{{67, Automatic}, {Automatic, 0}},
StyleDefinitions -> "HelpBrowser.nb"
]

(*******************************************************************
Cached data follows.  If you edit this Notebook file directly, not
using Mathematica, you must remove the line containing CacheID at
the top of  the file.  The cache data will then be recreated when
you save this file from within Mathematica.
*******************************************************************)

(*CellTagsOutline
CellTagsIndex->{}
*)

(*CellTagsIndex
CellTagsIndex->{}
*)

(*NotebookFileOutline
Notebook[{

Cell[CellGroupData[{
Cell[1776, 53, 96, 1, 36, "SubsectionIcon"],

Cell[CellGroupData[{
Cell[1897, 58, 208, 5, 24, "SubsubsectionIcon"],
Cell[2108, 65, 187, 4, 24, "Text"],
Cell[2298, 71, 644, 12, 63, "Input"],
Cell[2945, 85, 71, 0, 24, "Text"],

Cell[CellGroupData[{
Cell[3041, 89, 260, 5, 42, "Input"],

Cell[CellGroupData[{
Cell[3326, 98, 16614, 433, 184, 3377, 264, "GraphicsData", "PostScript", \
"Graphics"],
Cell[19943, 533, 17327, 441, 184, 3378, 264, "GraphicsData", "PostScript", \
"Graphics"],
Cell[37273, 976, 17712, 446, 184, 3378, 264, "GraphicsData", "PostScript", \
"Graphics"],
Cell[54988, 1424, 17881, 448, 184, 3377, 264, "GraphicsData", "PostScript", \
"Graphics"],
Cell[72872, 1874, 17991, 450, 184, 3377, 264, "GraphicsData", "PostScript", \
"Graphics"]
}, Closed]]
}, Open  ]],
Cell[90890, 2328, 245, 5, 24, "Text"],

Cell[CellGroupData[{
Cell[91160, 2337, 237, 5, 50, "Input"],
Cell[91400, 2344, 890, 19, 95, "Output"]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[92351, 2370, 37, 0, 36, "SubsectionIcon"],

Cell[CellGroupData[{
Cell[92413, 2374, 414, 10, 24, "SubsubsectionIcon"],
Cell[92830, 2386, 508, 11, 40, "Text"],

Cell[CellGroupData[{
Cell[93363, 2401, 191, 4, 43, "Input"],
Cell[93557, 2407, 28409, 898, 184, 13608, 710, "GraphicsData", "PostScript", \
"Graphics"]
}, Open  ]],
Cell[121981, 3308, 153, 3, 24, "Text"],

Cell[CellGroupData[{
Cell[122159, 3315, 191, 4, 43, "Input"],
Cell[122353, 3321, 23615, 666, 184, 9751, 490, "GraphicsData", "PostScript", \
"Graphics"]
}, Open  ]]
}, Closed]]
}, Open  ]],

Cell[CellGroupData[{
Cell[146029, 3994, 100, 1, 36, "SubsectionIcon"],

Cell[CellGroupData[{
Cell[146154, 3999, 198, 5, 24, "SubsubsectionIcon"],
Cell[146355, 4006, 92, 3, 24, "Text"],

Cell[CellGroupData[{
Cell[146472, 4013, 378, 7, 42, "Input"],
Cell[146853, 4022, 83, 2, 21, "Output"]
}, Open  ]],
Cell[146951, 4027, 117, 3, 24, "Text"],

Cell[CellGroupData[{
Cell[147093, 4034, 352, 7, 42, "Input"],

Cell[CellGroupData[{
Cell[147470, 4045, 23615, 514, 184, 3751, 264, "GraphicsData", "PostScript", \
"Graphics"],
Cell[171088, 4561, 24655, 560, 184, 4244, 303, "GraphicsData", "PostScript", \
"Graphics"],
Cell[195746, 5123, 25603, 589, 184, 4528, 324, "GraphicsData", "PostScript", \
"Graphics"],
Cell[221352, 5714, 25310, 558, 184, 4101, 291, "GraphicsData", "PostScript", \
"Graphics"]
}, Closed]],
Cell[246677, 6275, 156, 3, 23, "Output"]
}, Open  ]],
Cell[246848, 6281, 168, 4, 24, "Text"],

Cell[CellGroupData[{
Cell[247041, 6289, 288, 5, 41, "Input"],
Cell[247332, 6296, 516, 13, 79, "Output"]
}, Open  ]],
Cell[247863, 6312, 98, 3, 24, "Text"],
Cell[247964, 6317, 272, 5, 42, "Input"],

Cell[CellGroupData[{
Cell[248261, 6326, 182, 4, 43, "Input"],
Cell[248446, 6332, 24475, 735, 184, 10391, 556, "GraphicsData", "PostScript", \
"Graphics"]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}
]
*)



(*******************************************************************
End of Mathematica Notebook file.
*******************************************************************)

