(************** Content-type: application/mathematica **************
                     CreatedBy='Mathematica 4.2'

                    Mathematica-Compatible Notebook

This notebook can be used with any Mathematica-compatible
application, such as Mathematica, MathReader or Publicon. The data
for the notebook starts with the line containing stars above.

To get the notebook into a Mathematica-compatible application, do
one of the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the
  application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing
the word CacheID, otherwise Mathematica-compatible applications may
try to use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
*******************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[    547546,      13998]*)
(*NotebookOutlinePosition[    756075,      21280]*)
(*  CellTagsIndexPosition[    756031,      21276]*)
(*WindowFrame->Normal*)



Notebook[{
Cell["Clines", "Subsubsection"],

Cell[CellGroupData[{

Cell["Notes", "SubsubsectionIcon"],

Cell[TextData[{
  "These simulation packages handle a variety of different ways of \
representing populations: allele frequencies, genotype frequencies etc.  \
Here, we will follow genotype frequencies.  This allows us to look at the \
effects of linkage disequilibrium, and gives an exact deterministic model.  \
However, with ",
  Cell[BoxData[
      \(TraditionalForm\`n\)]],
  " loci there ",
  Cell[BoxData[
      \(TraditionalForm\`are\ 2\^\(2  n\)\)]],
  " diploid genotypes: it is not feasible to follow more than about 5 loci \
using these packages."
}], "Text"],

Cell[TextData[{
  "The main limitations are:\n- two alleles per locus\n- immigration into a \
single deme, ",
  StyleBox["or",
    FontSlant->"Italic"],
  " a linear stepping stone model"
}], "Text"],

Cell[TextData[{
  "For deterministic models, two-dimensional populations can be represented \
in one diomension, as long as the cline is ",
  StyleBox["straight",
    FontSlant->"Italic"],
  ".  Thus, the restriction to one dimension is not a problem."
}], "Text"]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Load packages",
  FontColor->RGBColor[1, 0, 0]]], "SubsubsectionIcon"],

Cell["This loads the packages that will be needed", "MathCaption"],

Cell[BoxData[
    \(<< NumericalModels`ExactModel`; << Graphics`; << 
      Statistics`;\)], "Input",
  CellLabel->"In[1]:="],

Cell["Ignore the error messages....", "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Representing fitness",
  FontColor->RGBColor[1, 0, 0]]], "SubsubsectionIcon"],

Cell["\<\
This sets up a stepped cline across 20 demes, with 3 loci in \
each:\
\>", "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[
    \(MakeCline[20, 3, 100]\)], "Input",
  CellLabel->"In[5]:="],

Cell[BoxData[
    \({HaploidFrequencies[{1, 0, 0, 0, 0, 0, 0, 0}, 100], 
      HaploidFrequencies[{1, 0, 0, 0, 0, 0, 0, 0}, 100], 
      HaploidFrequencies[{1, 0, 0, 0, 0, 0, 0, 0}, 100], 
      HaploidFrequencies[{1, 0, 0, 0, 0, 0, 0, 0}, 100], 
      HaploidFrequencies[{1, 0, 0, 0, 0, 0, 0, 0}, 100], 
      HaploidFrequencies[{1, 0, 0, 0, 0, 0, 0, 0}, 100], 
      HaploidFrequencies[{1, 0, 0, 0, 0, 0, 0, 0}, 100], 
      HaploidFrequencies[{1, 0, 0, 0, 0, 0, 0, 0}, 100], 
      HaploidFrequencies[{1, 0, 0, 0, 0, 0, 0, 0}, 100], 
      HaploidFrequencies[{1, 0, 0, 0, 0, 0, 0, 0}, 100], 
      HaploidFrequencies[{0, 0, 0, 0, 0, 0, 0, 1}, 100], 
      HaploidFrequencies[{0, 0, 0, 0, 0, 0, 0, 1}, 100], 
      HaploidFrequencies[{0, 0, 0, 0, 0, 0, 0, 1}, 100], 
      HaploidFrequencies[{0, 0, 0, 0, 0, 0, 0, 1}, 100], 
      HaploidFrequencies[{0, 0, 0, 0, 0, 0, 0, 1}, 100], 
      HaploidFrequencies[{0, 0, 0, 0, 0, 0, 0, 1}, 100], 
      HaploidFrequencies[{0, 0, 0, 0, 0, 0, 0, 1}, 100], 
      HaploidFrequencies[{0, 0, 0, 0, 0, 0, 0, 1}, 100], 
      HaploidFrequencies[{0, 0, 0, 0, 0, 0, 0, 1}, 100], 
      HaploidFrequencies[{0, 0, 0, 0, 0, 0, 0, 1}, 100]}\)], "Output",
  CellLabel->"Out[5]="]
}, Closed]],

Cell[TextData[{
  "Each deme is represented by a list of the 8 haploid genotype frequencies.  \
The deme size ",
  Cell[BoxData[
      \(TraditionalForm\`\((2  N = 100)\)\)]],
  " is arbitrary and will not affect the results."
}], "Text"],

Cell["\<\
Fitness is given by a function of the form f[deme][X,Y].  For \
example,  f[11][{0,0,0},{1,1,1}] gives the fitness of an individual \
heterozygous at all 3 loci, in deme 11.\
\>", "Text"],

Cell["\<\
The function fitness[s,mid,ecotone] specifies multiplicative \
selection +s to the right, -s to the left\
\>", "Text"],

Cell[BoxData[
    \(\(\(\(fitness[s_, mid_, ecotone]\)[i_]\)[X_, Y_] := 
        If[i > mid, \((1 + s)\)\^\(Plus @@ \((X + Y)\) - Length[X]\), \((1 + \
s)\)\^\(-\((Plus @@ \((X + Y)\) - Length[X])\)\)];\)\)], "Input",
  CellLabel->"In[20]:="],

Cell["\<\
For example, this tabulaes fitness of genotype {{0,0,0},{0,0,0}} \
across the cline, for s=0.1 and with midpoint at deme 10:\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(Table[\(\(fitness[0.1, 10, ecotone]\)[i]\)[{0, 0, 0}, {0, 0, 0}], {i, 
        20}]\)], "Input",
  CellLabel->"In[25]:="],

Cell[BoxData[
    \({1.3310000000000004`, 1.3310000000000004`, 1.3310000000000004`, 
      1.3310000000000004`, 1.3310000000000004`, 1.3310000000000004`, 
      1.3310000000000004`, 1.3310000000000004`, 1.3310000000000004`, 
      1.3310000000000004`, 0.7513148009015775`, 0.7513148009015775`, 
      0.7513148009015775`, 0.7513148009015775`, 0.7513148009015775`, 
      0.7513148009015775`, 0.7513148009015775`, 0.7513148009015775`, 
      0.7513148009015775`, 0.7513148009015775`}\)], "Output",
  CellLabel->"Out[25]="]
}, Open  ]],

Cell[TextData[{
  "The fitness changes from ",
  Cell[BoxData[
      \(TraditionalForm\`\((1 + s)\)\^3\)]],
  " to ",
  Cell[BoxData[
      \(TraditionalForm\`\((1 - s)\)\^3\)]]
}], "Text"],

Cell[TextData[{
  "This is similar, but allows for different selection on different loci - s \
can be a list ",
  Cell[BoxData[
      \(TraditionalForm\`{s\_1, \ s\_2, s\_3}\)]],
  ":"
}], "Text"],

Cell[BoxData[
    \(\(\(\(fitness[s_List, mid_, ecotone]\)[i_]\)[X_, Y_] := 
        If[i > mid, 
          Times @@ \(\((1 + s)\)\^\(Plus @@ \((X + Y)\) - Length[X]\)\), 
          Times @@ \(\((1 + 
                    s)\)\^\(-\((Plus @@ \((X + Y)\) - 
                      Length[X])\)\)\)];\)\)], "Input",
  CellLabel->"In[21]:="],

Cell[TextData[{
  "This represents selection ",
  Cell[BoxData[
      \(TraditionalForm\`s\)]],
  " against heterozygotes:"
}], "Text"],

Cell[BoxData[
    \(\(\(\(fitness[s_, mid_, het]\)[i_]\)[X_, 
          Y_] := \((1 - s)\)\^CountHeterozygotes[X, Y];\)\)], "Input",
  CellLabel->"In[21]:="],

Cell[TextData[{
  StyleBox["Note: ",
    FontWeight->"Bold"],
  "In the simulations, fitnesses of each diploid genotype are calculated \
once, and then stored.  This makes calculations much faster, provided that \
selection does not change over time."
}], "Text"]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Simulating a cline",
  FontColor->RGBColor[0, 0, 1]]], "SubsubsectionIcon"],

Cell[TextData[{
  "This simulates the cline with stepped selection s=0.01 on the three loci, \
across 30 demes.  Migration rates between adjacent demes is ",
  Cell[BoxData[
      \(TraditionalForm\`m = 0.5\)]],
  ".  Results are stored at t=0, 20, \[Ellipsis]500"
}], "Text"],

Cell[BoxData[
    \(\(\(fitness[s_, mid_, ecotone]\)[i_]\)[X_, Y_] := 
      If[i > mid, 
        Times @@ \(\((1 + s)\)\^\(Plus @@ \((X + Y)\) - Length[X]\)\), 
        Times @@ \(\((1 + 
                  s)\)\^\(-\((Plus @@ \((X + Y)\) - Length[X])\)\)\)]; 
    StoreExact[res, MakeCline[30, 3, 100], fitness[0.01, 15, ecotone], 
      0.5, {500, 20}, \[IndentingNewLine]Compiled \[Rule] True, 
      FixedEnds \[Rule] {MakePopulation[3, 0], 
          MakePopulation[3, 1]}];\)], "Input",
  CellLabel->"In[2]:="],

Cell[TextData[{
  "Compiled->True compiles the code, which is much faster.\n\
FixedEnds\[Rule]{pop0,pop1} fixes allele frequencies at the ends.  The \
default is to have no gene flow across the ends, which would be fine.  \
However, Compiled->True cannot then be used because of a ",
  StyleBox["BUG",
    FontColor->RGBColor[1, 0, 0]],
  ".  Using FixedEnds->{\[Ellipsis]} is juts a work around this problem."
}], "Text"],

Cell[TextData[{
  StyleBox["Tip: ",
    FontWeight->"Bold"],
  "Instead of using the name ",
  StyleBox["res",
    FontSlant->"Italic"],
  ", you can store results in structures with  more helpful names - eg ",
  StyleBox["res[3,0.01,ecotone]",
    FontSlant->"Italic"],
  " for results with those parameters"
}], "Text"],

Cell["This is the state of the cline at t=500:", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(res[500]\)], "Input",
  CellLabel->"In[3]:="],

Cell[BoxData[
    \({HaploidFrequencies[{0.6798939873586668`, 0.09188824065852177`, 
          0.09188824065852179`, 0.014078727399284308`, 0.09188824065852184`, 
          0.014078727399284311`, 0.014078727399284308`, 
          0.0022051084679150517`}, 4.527444379799348`], 
      HaploidFrequencies[{0.6368890329382652`, 0.10309264944087536`, 
          0.10309264944087537`, 0.01699899028075953`, 0.10309264944087536`, 
          0.01699899028075953`, 0.016998990280759532`, 
          0.0028360478968298625`}, 8.018683075163288`], 
      HaploidFrequencies[{0.6139081878449819`, 0.10830886548816432`, 
          0.10830886548816433`, 0.019241724721762072`, 0.10830886548816433`, 
          0.01924172472176207`, 0.019241724721762075`, 
          0.0034400415252387193`}, 11.437882776890591`], 
      HaploidFrequencies[{0.5935205162380428`, 0.11262250061838143`, 
          0.11262250061838144`, 0.02149520690455997`, 0.11262250061838151`, 
          0.02149520690455997`, 0.02149520690455998`, 
          0.0041263611931326855`}, 14.749951026668521`], 
      HaploidFrequencies[{0.5717322851943929`, 0.11699102223064639`, 
          0.11699102223064645`, 0.024098989175283685`, 0.11699102223064646`, 
          0.024098989175283685`, 0.024098989175283695`, 
          0.004997680587816689`}, 17.920896940783102`], 
      HaploidFrequencies[{0.5470531419397905`, 0.12165135204140208`, 
          0.12165135204140215`, 0.027275344633473614`, 0.12165135204140215`, 
          0.027275344633473614`, 0.027275344633473624`, 
          0.006166768035582252`}, 20.918180422807495`], 
      HaploidFrequencies[{0.5187355325531205`, 0.1266077676550954`, 
          0.12660776765509546`, 0.031220391285519646`, 0.12660776765509543`, 
          0.03122039128551964`, 0.031220391285519653`, 
          0.007779990625034522`}, 23.711046243330117`], 
      HaploidFrequencies[{0.4863441434970184`, 0.13172993145717726`, 
          0.13172993145717735`, 0.03614003153962638`, 0.13172993145717735`, 
          0.036140031539626374`, 0.0361400315396264`, 0.010045967512570591`}, 
        26.270839542624906`], 
      HaploidFrequencies[{0.4496404370491561`, 0.13676495987275633`, 
          0.1367649598727564`, 0.04226339677779082`, 0.1367649598727564`, 
          0.04226339677779082`, 0.04226339677779083`, 0.013274492999202392`}, 
        28.571299526814407`], 
      HaploidFrequencies[{0.40857521971718885`, 0.14132115395538167`, 
          0.1413211539553817`, 0.049842210168436506`, 0.1413211539553817`, 
          0.049842210168436506`, 0.04984221016843654`, 0.01793468791135665`}, 
        30.58882837512604`], 
      HaploidFrequencies[{0.3633341860960132`, 0.1448401496069932`, 
          0.14484014960699326`, 0.05913339614602903`, 0.1448401496069932`, 
          0.05913339614602903`, 0.059133396146029055`, 0.02474517664491991`}, 
        32.30273265062253`], 
      HaploidFrequencies[{0.3144177406426158`, 0.14656813224140453`, 
          0.14656813224140458`, 0.07035420220310466`, 0.1465681322414046`, 
          0.07035420220310468`, 0.07035420220310469`, 0.034815256023856385`}, 
        33.69543480460661`], 
      HaploidFrequencies[{0.2627411645334986`, 0.1455416852274023`, 
          0.14554168522740227`, 0.08359006758994841`, 0.1455416852274023`, 
          0.08359006758994839`, 0.08359006758994843`, 0.049863577014449316`}, 
        34.75265268126528`], 
      HaploidFrequencies[{0.20972153643884678`, 0.140618560351693`, 
          0.14061856035169304`, 0.09862868319474513`, 0.14061856035169304`, 
          0.09862868319474513`, 0.09862868319474516`, 0.07253673292183856`}, 
        35.46354525991277`], 
      HaploidFrequencies[{0.1572245293643382`, 0.1306153746136421`, 
          0.13061537461364214`, 0.11472802574777469`, 0.13061537461364212`, 
          0.11472802574777469`, 0.11472802574777474`, 0.10674526955141134`}, 
        35.82082321379796`], 
      HaploidFrequencies[{0.10674526955141132`, 0.11472802574777465`, 
          0.11472802574777471`, 0.13061537461364212`, 0.11472802574777471`, 
          0.13061537461364212`, 0.13061537461364217`, 0.15722452936433826`}, 
        35.82082321379796`], 
      HaploidFrequencies[{0.07253673292183854`, 0.0986286831947451`, 
          0.09862868319474515`, 0.14061856035169304`, 0.09862868319474515`, 
          0.14061856035169304`, 0.14061856035169312`, 0.20972153643884686`}, 
        35.46354525991277`], 
      HaploidFrequencies[{0.049863577014449295`, 0.0835900675899484`, 
          0.08359006758994843`, 0.1455416852274023`, 0.08359006758994841`, 
          0.14554168522740227`, 0.14554168522740232`, 0.26274116453349877`}, 
        34.75265268126528`], 
      HaploidFrequencies[{0.03481525602385634`, 0.07035420220310463`, 
          0.07035420220310465`, 0.14656813224140458`, 0.07035420220310465`, 
          0.14656813224140455`, 0.1465681322414046`, 0.31441774064261585`}, 
        33.69543480460661`], 
      HaploidFrequencies[{0.024745176644919886`, 0.059133396146029`, 
          0.059133396146029006`, 0.14484014960699318`, 0.059133396146029006`, 
          0.1448401496069932`, 0.1448401496069932`, 0.3633341860960134`}, 
        32.30273265062253`], 
      HaploidFrequencies[{0.017934687911356623`, 0.04984221016843648`, 
          0.04984221016843648`, 0.1413211539553816`, 0.049842210168436485`, 
          0.1413211539553817`, 0.14132115395538167`, 0.4085752197171891`}, 
        30.58882837512604`], 
      HaploidFrequencies[{0.01327449299920237`, 0.042263396777790785`, 
          0.04226339677779078`, 0.13676495987275628`, 0.0422633967777908`, 
          0.1367649598727564`, 0.13676495987275633`, 0.4496404370491563`}, 
        28.571299526814407`], 
      HaploidFrequencies[{0.010045967512570572`, 0.03614003153962634`, 
          0.036140031539626326`, 0.13172993145717724`, 0.03614003153962634`, 
          0.13172993145717732`, 0.13172993145717726`, 0.48634414349701865`}, 
        26.270839542624906`], 
      HaploidFrequencies[{0.0077799906250344995`, 0.031220391285519605`, 
          0.031220391285519577`, 0.12660776765509527`, 0.031220391285519598`, 
          0.1266077676550954`, 0.12660776765509527`, 0.5187355325531207`}, 
        23.711046243330117`], 
      HaploidFrequencies[{0.006166768035582239`, 0.027275344633473593`, 
          0.027275344633473562`, 0.12165135204140205`, 0.0272753446334736`, 
          0.12165135204140222`, 0.12165135204140207`, 0.5470531419397908`}, 
        20.918180422807495`], 
      HaploidFrequencies[{0.004997680587816678`, 0.024098989175283667`, 
          0.024098989175283643`, 0.11699102223064635`, 0.024098989175283667`, 
          0.11699102223064645`, 0.11699102223064635`, 0.5717322851943931`}, 
        17.920896940783102`], 
      HaploidFrequencies[{0.004126361193132675`, 0.021495206904559947`, 
          0.021495206904559923`, 0.11262250061838135`, 0.02149520690455995`, 
          0.11262250061838149`, 0.11262250061838139`, 0.5935205162380432`}, 
        14.749951026668521`], 
      HaploidFrequencies[{0.00344004152523871`, 0.019241724721762044`, 
          0.01924172472176202`, 0.1083088654881642`, 0.01924172472176205`, 
          0.10830886548816433`, 0.10830886548816424`, 0.6139081878449825`}, 
        11.437882776890591`], 
      HaploidFrequencies[{0.0028360478968298543`, 0.0169989902807595`, 
          0.016998990280759487`, 0.10309264944087523`, 0.01699899028075951`, 
          0.10309264944087539`, 0.10309264944087526`, 0.6368890329382658`}, 
        8.018683075163288`], 
      HaploidFrequencies[{0.002205108467915045`, 0.014078727399284287`, 
          0.014078727399284272`, 0.09188824065852168`, 0.014078727399284289`, 
          0.0918882406585218`, 0.0918882406585217`, 0.6798939873586668`}, 
        4.527444379799348`]}\)], "Output",
  CellLabel->"Out[3]="]
}, Closed]],

Cell["\<\
These are the allele frequencies.  By symmetry, they are the same \
at all three loci.\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(AlleleFrequencyTable[res[500]]\)], "Input",
  CellLabel->"In[4]:="],

Cell[BoxData[
    \({{0.12225080392500552`, 0.12225080392500547`, 
        0.12225080392500545`}, {0.13992667789922428`, 0.1399266778992243`, 
        0.13992667789922428`}, {0.1502323564569272`, 0.1502323564569272`, 
        0.1502323564569272`}, {0.15973927562063417`, 0.15973927562063406`, 
        0.15973927562063406`}, {0.17018668116903052`, 0.17018668116903052`, 
        0.17018668116903046`}, {0.18236880934393163`, 0.18236880934393163`, 
        0.18236880934393154`}, {0.19682854085116924`, 0.19682854085116927`, 
        0.19682854085116921`}, {0.21405596204900074`, 0.21405596204900074`, 
        0.21405596204900063`}, {0.23456624642754043`, 0.23456624642754043`, 
        0.23456624642754034`}, {0.2589402622036114`, 0.2589402622036114`, 
        0.2589402622036113`}, {0.2878521185439712`, 0.2878521185439713`, 
        0.2878521185439712`}, {0.32209179267147037`, 0.3220917926714703`, 
        0.32209179267147026`}, {0.36258539742174845`, 0.36258539742174845`, 
        0.36258539742174845`}, {0.4104126596630219`, 0.4104126596630219`, 
        0.4104126596630218`}, {0.46681669566060285`, 0.4668166956606029`, 
        0.4668166956606028`}, {0.5331833043393973`, 0.5331833043393973`, 
        0.5331833043393972`}, {0.5895873403369781`, 0.5895873403369781`, 
        0.589587340336978`}, {0.6374146025782518`, 0.6374146025782519`, 
        0.6374146025782517`}, {0.6779082073285296`, 0.6779082073285296`, 
        0.6779082073285296`}, {0.7121478814560288`, 0.7121478814560288`, 
        0.7121478814560288`}, {0.741059737796389`, 0.7410597377963888`, 
        0.7410597377963888`}, {0.7654337535724598`, 0.7654337535724597`, 
        0.7654337535724598`}, {0.7859440379509997`, 0.7859440379509994`, 
        0.7859440379509995`}, {0.8031714591488309`, 0.8031714591488308`, 
        0.8031714591488309`}, {0.8176311906560687`, 0.8176311906560685`, 
        0.8176311906560687`}, {0.8298133188309695`, 0.8298133188309695`, 
        0.8298133188309695`}, {0.840260724379366`, 0.8402607243793659`, 
        0.840260724379366`}, {0.8497676435430731`, 0.8497676435430729`, 
        0.849767643543073`}, {0.8600733221007759`, 0.8600733221007758`, 
        0.8600733221007759`}, {0.8777491960749946`, 0.8777491960749945`, 
        0.8777491960749946`}}\)], "Output",
  CellLabel->"Out[4]="]
}, Closed]],

Cell["This gives the average:", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(AlleleFrequencyMean[res[500]]\)], "Input",
  CellLabel->"In[5]:="],

Cell[BoxData[
    \({0.12225080392500548`, 0.1399266778992243`, 0.1502323564569272`, 
      0.15973927562063409`, 0.1701866811690305`, 0.1823688093439316`, 
      0.19682854085116921`, 0.2140559620490007`, 0.2345662464275404`, 
      0.2589402622036114`, 0.28785211854397125`, 0.3220917926714703`, 
      0.3625853974217484`, 0.4104126596630218`, 0.46681669566060285`, 
      0.5331833043393973`, 0.5895873403369781`, 0.6374146025782518`, 
      0.6779082073285295`, 0.7121478814560288`, 0.7410597377963889`, 
      0.7654337535724598`, 0.7859440379509995`, 0.8031714591488308`, 
      0.8176311906560686`, 0.8298133188309696`, 0.840260724379366`, 
      0.849767643543073`, 0.8600733221007758`, 
      0.8777491960749946`}\)], "Output",
  CellLabel->"Out[5]="]
}, Closed]],

Cell["This shows how the cline changes over time:", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(Table[
        ListPlot[AlleleFrequencyMean[res[t]], PlotJoined \[Rule] True, 
          PlotRange \[Rule] {{0, 30}, {0, 1}}], {t, 0, 500, 
          20}];\)\)], "Input",
  CellLabel->"In[6]:="],

Cell[CellGroupData[{

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 0.0333333 0 0.618034 [
[.16667 -0.0125 -3 -9 ]
[.16667 -0.0125 3 0 ]
[.33333 -0.0125 -6 -9 ]
[.33333 -0.0125 6 0 ]
[.5 -0.0125 -6 -9 ]
[.5 -0.0125 6 0 ]
[.66667 -0.0125 -6 -9 ]
[.66667 -0.0125 6 0 ]
[.83333 -0.0125 -6 -9 ]
[.83333 -0.0125 6 0 ]
[1 -0.0125 -6 -9 ]
[1 -0.0125 6 0 ]
[-0.0125 .12361 -18 -4.5 ]
[-0.0125 .12361 0 4.5 ]
[-0.0125 .24721 -18 -4.5 ]
[-0.0125 .24721 0 4.5 ]
[-0.0125 .37082 -18 -4.5 ]
[-0.0125 .37082 0 4.5 ]
[-0.0125 .49443 -18 -4.5 ]
[-0.0125 .49443 0 4.5 ]
[-0.0125 .61803 -6 -4.5 ]
[-0.0125 .61803 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.16667 0 m
.16667 .00625 L
s
[(5)] .16667 -0.0125 0 1 Mshowa
.33333 0 m
.33333 .00625 L
s
[(10)] .33333 -0.0125 0 1 Mshowa
.5 0 m
.5 .00625 L
s
[(15)] .5 -0.0125 0 1 Mshowa
.66667 0 m
.66667 .00625 L
s
[(20)] .66667 -0.0125 0 1 Mshowa
.83333 0 m
.83333 .00625 L
s
[(25)] .83333 -0.0125 0 1 Mshowa
1 0 m
1 .00625 L
s
[(30)] 1 -0.0125 0 1 Mshowa
.125 Mabswid
.03333 0 m
.03333 .00375 L
s
.06667 0 m
.06667 .00375 L
s
.1 0 m
.1 .00375 L
s
.13333 0 m
.13333 .00375 L
s
.2 0 m
.2 .00375 L
s
.23333 0 m
.23333 .00375 L
s
.26667 0 m
.26667 .00375 L
s
.3 0 m
.3 .00375 L
s
.36667 0 m
.36667 .00375 L
s
.4 0 m
.4 .00375 L
s
.43333 0 m
.43333 .00375 L
s
.46667 0 m
.46667 .00375 L
s
.53333 0 m
.53333 .00375 L
s
.56667 0 m
.56667 .00375 L
s
.6 0 m
.6 .00375 L
s
.63333 0 m
.63333 .00375 L
s
.7 0 m
.7 .00375 L
s
.73333 0 m
.73333 .00375 L
s
.76667 0 m
.76667 .00375 L
s
.8 0 m
.8 .00375 L
s
.86667 0 m
.86667 .00375 L
s
.9 0 m
.9 .00375 L
s
.93333 0 m
.93333 .00375 L
s
.96667 0 m
.96667 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .12361 m
.00625 .12361 L
s
[(0.2)] -0.0125 .12361 1 0 Mshowa
0 .24721 m
.00625 .24721 L
s
[(0.4)] -0.0125 .24721 1 0 Mshowa
0 .37082 m
.00625 .37082 L
s
[(0.6)] -0.0125 .37082 1 0 Mshowa
0 .49443 m
.00625 .49443 L
s
[(0.8)] -0.0125 .49443 1 0 Mshowa
0 .61803 m
.00625 .61803 L
s
[(1)] -0.0125 .61803 1 0 Mshowa
.125 Mabswid
0 .0309 m
.00375 .0309 L
s
0 .0618 m
.00375 .0618 L
s
0 .09271 m
.00375 .09271 L
s
0 .15451 m
.00375 .15451 L
s
0 .18541 m
.00375 .18541 L
s
0 .21631 m
.00375 .21631 L
s
0 .27812 m
.00375 .27812 L
s
0 .30902 m
.00375 .30902 L
s
0 .33992 m
.00375 .33992 L
s
0 .40172 m
.00375 .40172 L
s
0 .43262 m
.00375 .43262 L
s
0 .46353 m
.00375 .46353 L
s
0 .52533 m
.00375 .52533 L
s
0 .55623 m
.00375 .55623 L
s
0 .58713 m
.00375 .58713 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.03333 0 m
.06667 0 L
.1 0 L
.13333 0 L
.16667 0 L
.2 0 L
.23333 0 L
.26667 0 L
.3 0 L
.33333 0 L
.36667 0 L
.4 0 L
.43333 0 L
.46667 0 L
.5 0 L
.53333 .61803 L
.56667 .61803 L
.6 .61803 L
.63333 .61803 L
.66667 .61803 L
.7 .61803 L
.73333 .61803 L
.76667 .61803 L
.8 .61803 L
.83333 .61803 L
.86667 .61803 L
.9 .61803 L
.93333 .61803 L
.96667 .61803 L
1 .61803 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[6]:=",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/B000`400?l00000o`00003ooooooolQ
ooooo`00?_ooool3o`0002Gooooo0ol00004ooooo`;o00008oooool3o`0000?ooooo0ol0000Qoooo
o`Go00000oooool2o`00027ooooo1Ol00002ooooo`?o00008_ooool3o`0000Cooooo0_l00004oooo
o`00?Oooool01Ol0003ooooooooooooooooo000002Gooooo00?o0000ooooooooool00_ooool01?l0
003oooooooooool0000Sooooo`05o`000?ooooooooooooooool000000oooool00ol0003ooooooooo
o`0Oooooo`04o`000?ooooooooooo`0000;ooooo00Co0000oooooooooooo00008Oooool01_l0003o
ooooooooool0003oooooo`0000?ooooo00?o0000ooooooooool07_ooool01Ol0003ooooooooooooo
oooo000000;ooooo00Co0000oooooooooooo00000oooool0047ooooo00?o0000ooooooooool08ooo
ool00ol0003oooooooooo`02ooooo`04o`000?ooooooooooo`0002?ooooo00?o0000ooooooooool0
1Oooool00ol0003oooooooooo`0Pooooo`03o`000?oooooooooo00;ooooo00Co0000oooooooooooo
00008_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo02;ooooo00Co0000oooooooo
oooo00000_ooool00ol0003oooooooooo`01ooooo`00@Oooool00ol0003oooooooooo`0Sooooo`03
o`000?oooooooooo00;ooooo00Co0000oooooooooooo00008oooool00ol0003oooooooooo`05oooo
o`03o`000?oooooooooo027ooooo00Go0000ooooooooooooooooo`000002ooooo`03o`000?oooooo
oooo027ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`0Pooooo`;o00000oooool0
1?l0003oooooooooool00003ooooo`00?Oooool4o`0002Kooooo00?o0000ooooooooool00_ooool0
1?l0003oooooooooool0000Sooooo`04o`000?ooooooooooooooo`Co00008Oooool01Ol0003ooooo
oooooooooooo000000;ooooo00Co0000oooooooooooo00008?ooool01_l0003ooooooooooooooooo
0000ooooo`Co00009Oooool01?l0003oooooooooool00002ooooo`03o`000?oooooooooo007ooooo
000mooooo`03o`000?oooooooooo02Kooooo0_l00004ooooo`04o`000?ooooooooooo`0002;ooooo
0_l00003ooooo`03o`000?oooooooooo02;ooooo00Go0000ooooooooooooooooo`000002ooooo`04
o`000?ooooooooooo`00023ooooo00Oo0000ooooooooooooooooo`000?oooooo000002Cooooo00Go
0000ooooooooooooooooo`000002ooooo`04o`000?ooooooooooo`0000?ooooo000mooooo`Go0000
9Oooool00ol0003oooooooooo`03ooooo`;o00009?ooool01?l0003oooooooooooooool5o`00027o
oooo0ol00004ooooo`;o00008_ooool3o`0000;ooooo1Ol0000Qooooo`?o00001?ooool2o`0000Co
oooo003oooooob7ooooo003oooooob7ooooo003oooooob7ooooo003oooooob7ooooo000Eoooooooo
00001Ol00007ooooo`005Oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Gooooo
00?o0000ooooooooool01_ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Gooooo
00?o0000ooooooooool01_ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Gooooo
00?o0000ooooooooool01_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Kooooo
00?o0000ooooooooool01_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Kooooo
00?o0000ooooooooool01_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Kooooo
00?o0000ooooooooool01_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Kooooo
00?o0000ooooooooool01Oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Kooooo
00?o0000ooooooooool01Oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Kooooo
00?o0000ooooooooool01Oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Kooooo
00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`005Oooool00ol0003ooooooooo
o`1oooooo`03o`000?oooooooooo08Kooooo000Eooooo`03o`000?oooooooooo07oooooo00?o0000
ooooooooool0Q_ooool001Gooooo00?o0000ooooooooool0Ooooool00ol0003oooooooooo`26oooo
o`005Oooool00ol0003oooooooooo`1oooooo`03o`000?oooooooooo08Kooooo000Eooooo`03o`00
0?oooooooooo07oooooo00?o0000ooooooooool0Q_ooool001Gooooo00?o0000ooooooooool0Oooo
ool00ol0003oooooooooo`26ooooo`005Oooool2o`00083ooooo00?o0000ooooooooool0Q_ooool0
01Gooooo00?o0000ooooooooool0Ooooool00ol0003oooooooooo`26ooooo`005Oooool00ol0003o
ooooooooo`1oooooo`03o`000?oooooooooo08Kooooo000Eooooo`03o`000?oooooooooo083ooooo
00?o0000ooooooooool0QOooool001Gooooo00?o0000ooooooooool0P?ooool00ol0003ooooooooo
o`25ooooo`005Oooool00ol0003oooooooooo`20ooooo`03o`000?oooooooooo08Gooooo000Eoooo
o`03o`000?oooooooooo083ooooo00?o0000ooooooooool0QOooool001Gooooo00?o0000oooooooo
ool0P?ooool00ol0003oooooooooo`25ooooo`005Oooool2o`00087ooooo00?o0000ooooooooool0
QOooool001Gooooo00?o0000ooooooooool0P?ooool00ol0003oooooooooo`25ooooo`005Oooool0
0ol0003oooooooooo`20ooooo`03o`000?oooooooooo08Gooooo000Eooooo`03o`000?oooooooooo
083ooooo00?o0000ooooooooool0QOooool001Gooooo00?o0000ooooooooool0P?ooool00ol0003o
ooooooooo`25ooooo`005Oooool00ol0003oooooooooo`20ooooo`03o`000?oooooooooo08Gooooo
000Eooooo`03o`000?oooooooooo083ooooo00?o0000ooooooooool0QOooool001Gooooo00?o0000
ooooooooool0P?ooool00ol0003oooooooooo`25ooooo`005Oooool2o`00087ooooo00?o0000oooo
ooooool0QOooool001Gooooo00?o0000ooooooooool0P?ooool00ol0003oooooooooo`25ooooo`00
5Oooool00ol0003oooooooooo`20ooooo`03o`000?oooooooooo08Gooooo000Eooooo`03o`000?oo
oooooooo083ooooo00?o0000ooooooooool0QOooool001Gooooo00?o0000ooooooooool0P?ooool0
0ol0003oooooooooo`25ooooo`000_ooool2o`0000Cooooo00Co0000oooooooooooooooo1Ol00004
ooooo`03o`000?oooooooooo083ooooo00?o0000ooooooooool0QOooool00005ooooool0003ooooo
ooooool000002?ooool01?l0003oooooooooool00004ooooo`03o`000?oooooooooo083ooooo00?o
0000ooooooooool0QOooool00005ooooool0003oooooooooool000002Oooool00ol0003ooooooooo
o`04ooooo`03o`000?oooooooooo087ooooo00?o0000ooooooooool0Q?ooool00005ooooool0003o
ooooooooool000002_ooool00ol0003oooooooooo`03ooooo`?o0000POooool00ol0003ooooooooo
o`24ooooo`0000Goooooo`000?ooooooooooo`000007ooooo`05o`000?ooooooooooooooool00000
1?ooool00ol0003oooooooooo`21ooooo`03o`000?oooooooooo08Cooooo00001Ooooooo0000oooo
oooooooo000000Oooooo00Go0000ooooooooooooooooo`000004ooooo`03o`000?oooooooooo087o
oooo00?o0000ooooooooool0Q?ooool000;ooooo0_l00009ooooo`?o00001Oooool00ol0003ooooo
ooooo`21ooooo`03o`000?oooooooooo08Cooooo000Eooooo`03o`000?oooooooooo087ooooo00?o
0000ooooooooool0Q?ooool001Gooooo00?o0000ooooooooool0POooool00ol0003oooooooooo`24
ooooo`005Oooool00ol0003oooooooooo`21ooooo`03o`000?oooooooooo08Cooooo000Eooooo`03
o`000?oooooooooo087ooooo00?o0000ooooooooool0Q?ooool001Gooooo0_l00022ooooo`03o`00
0?oooooooooo08Cooooo000Eooooo`03o`000?oooooooooo087ooooo00?o0000ooooooooool0Q?oo
ool001Gooooo00?o0000ooooooooool0POooool00ol0003oooooooooo`24ooooo`005Oooool00ol0
003oooooooooo`21ooooo`03o`000?oooooooooo08Cooooo000Eooooo`03o`000?oooooooooo087o
oooo00?o0000ooooooooool0Q?ooool001Gooooo00?o0000ooooooooool0POooool00ol0003ooooo
ooooo`24ooooo`005Oooool00ol0003oooooooooo`21ooooo`03o`000?oooooooooo08Cooooo000E
ooooo`03o`000?oooooooooo087ooooo00?o0000ooooooooool0Q?ooool001Gooooo0_l00022oooo
o`03o`000?oooooooooo08Cooooo000Eooooo`03o`000?oooooooooo087ooooo00?o0000oooooooo
ool0Q?ooool001Gooooo00?o0000ooooooooool0POooool00ol0003oooooooooo`24ooooo`005Ooo
ool00ol0003oooooooooo`22ooooo`03o`000?oooooooooo08?ooooo000Eooooo`03o`000?oooooo
oooo08;ooooo00?o0000ooooooooool0Poooool001Gooooo00?o0000ooooooooool0P_ooool00ol0
003oooooooooo`23ooooo`005Oooool00ol0003oooooooooo`22ooooo`03o`000?oooooooooo08?o
oooo000Eooooo`03o`000?oooooooooo08;ooooo00?o0000ooooooooool0Poooool001Gooooo0_l0
0023ooooo`03o`000?oooooooooo08?ooooo000Eooooo`03o`000?oooooooooo08;ooooo00?o0000
ooooooooool0Poooool001Gooooo00?o0000ooooooooool0P_ooool00ol0003oooooooooo`23oooo
o`005Oooool00ol0003oooooooooo`22ooooo`03o`000?oooooooooo08?ooooo000Eooooo`03o`00
0?oooooooooo08;ooooo00?o0000ooooooooool0Poooool000;ooooo0_l00004ooooo`03o`000?oo
oooooooo00?ooooo0ol00004ooooo`03o`000?oooooooooo08;ooooo00?o0000ooooooooool0Pooo
ool00005ooooool0003oooooooooool000002_ooool00ol0003oooooooooo`03ooooo`03o`000?oo
oooooooo08;ooooo00?o0000ooooooooool0Poooool00005ooooool0003oooooooooool000001ooo
ool5o`0000Cooooo00?o0000ooooooooool0P_ooool00ol0003oooooooooo`23ooooo`0000Gooooo
o`000?ooooooooooo`000007ooooo`04o`000?ooooooooooo`0000Gooooo0ol00022ooooo`03o`00
0?oooooooooo08?ooooo00001Ooooooo0000oooooooooooo000000Sooooo00?o0000ooooool00000
1Oooool00ol0003oooooooooo`22ooooo`03o`000?oooooooooo08?ooooo00001Ooooooo0000oooo
oooooooo000000Wooooo0_l00005ooooo`03o`000?oooooooooo08;ooooo00?o0000ooooooooool0
Poooool000;ooooo0_l0000;ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0P_oo
ool00ol0003oooooooooo`23ooooo`005Oooool00ol0003oooooooooo`22ooooo`03o`000?oooooo
oooo08?ooooo000Eooooo`03o`000?oooooooooo08;ooooo00?o0000ooooooooool0Poooool001Go
oooo00?o0000ooooooooool0P_ooool00ol0003oooooooooo`23ooooo`005Oooool00ol0003ooooo
ooooo`23ooooo`03o`000?oooooooooo08;ooooo000Eooooo`;o0000Q?ooool00ol0003ooooooooo
o`22ooooo`005Oooool00ol0003oooooooooo`23ooooo`03o`000?oooooooooo08;ooooo000Eoooo
o`03o`000?oooooooooo08?ooooo00?o0000ooooooooool0P_ooool001Gooooo00?o0000oooooooo
ool0Poooool00ol0003oooooooooo`22ooooo`005Oooool00ol0003oooooooooo`23ooooo`03o`00
0?oooooooooo08;ooooo000Eooooo`03o`000?oooooooooo08?ooooo00?o0000ooooooooool0P_oo
ool001Gooooo00?o0000ooooooooool0Poooool00ol0003oooooooooo`22ooooo`005Oooool00ol0
003oooooooooo`23ooooo`03o`000?oooooooooo08;ooooo000Eooooo`;o0000Q?ooool00ol0003o
ooooooooo`22ooooo`005Oooool00ol0003oooooooooo`23ooooo`03o`000?oooooooooo08;ooooo
000Eooooo`03o`000?oooooooooo08?ooooo00?o0000ooooooooool0P_ooool001Gooooo00?o0000
ooooooooool0Poooool00ol0003oooooooooo`22ooooo`005Oooool00ol0003oooooooooo`23oooo
o`03o`000?oooooooooo08;ooooo000Eooooo`03o`000?oooooooooo08?ooooo00?o0000oooooooo
ool0P_ooool001Gooooo00?o0000ooooooooool0Poooool00ol0003oooooooooo`22ooooo`005Ooo
ool00ol0003oooooooooo`23ooooo`03o`000?oooooooooo08;ooooo000Eooooo`;o0000Q?ooool0
0ol0003oooooooooo`22ooooo`005Oooool00ol0003oooooooooo`23ooooo`03o`000?oooooooooo
08;ooooo000Eooooo`03o`000?oooooooooo08?ooooo00?o0000ooooooooool0P_ooool001Gooooo
00?o0000ooooooooool0Q?ooool00ol0003oooooooooo`21ooooo`005Oooool00ol0003ooooooooo
o`24ooooo`03o`000?oooooooooo087ooooo0002ooooo`;o00001?ooool00ol0003oooooooooo`02
ooooo`?o00001Oooool00ol0003oooooooooo`24ooooo`03o`000?oooooooooo087ooooo00001Ooo
oooo0000oooooooooooo000000Oooooo00Go0000ooooooooooooooooo`000004ooooo`03o`000?oo
oooooooo08Cooooo00?o0000ooooooooool0POooool00005ooooool0003oooooooooool000001ooo
ool01Ol0003ooooooooooooooooo000000Cooooo00?o0000ooooooooool0Q?ooool00ol0003ooooo
ooooo`21ooooo`0000Goooooo`000?ooooooooooo`000007ooooo`Co00001Oooool3o`0008Cooooo
00?o0000ooooooooool0POooool00005ooooool0003oooooooooool000001oooool00ol0003ooooo
ooooo`06ooooo`03o`000?oooooooooo08Cooooo00?o0000ooooooooool0POooool00005ooooool0
003oooooooooool000002?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo08Cooooo
00?o0000ooooooooool0POooool000;ooooo0_l0000:ooooo`;o00001Oooool00ol0003ooooooooo
o`24ooooo`03o`000?oooooooooo087ooooo000Eooooo`03o`000?oooooooooo08Cooooo00?o0000
ooooooooool0POooool001Gooooo00?o0000ooooooooool0Q?ooool00ol0003oooooooooo`21oooo
o`005Oooool00ol0003oooooooooo`24ooooo`03o`000?oooooooooo087ooooo000Eooooo`03o`00
0?oooooooooo08Cooooo00?o0000ooooooooool0POooool001Gooooo0_l00025ooooo`03o`000?oo
oooooooo087ooooo000Eooooo`03o`000?oooooooooo08Cooooo00?o0000ooooooooool0POooool0
01Gooooo00?o0000ooooooooool0Q?ooool00ol0003oooooooooo`21ooooo`005Oooool00ol0003o
ooooooooo`24ooooo`03o`000?oooooooooo087ooooo000Eooooo`03o`000?oooooooooo08Cooooo
00?o0000ooooooooool0POooool001Gooooo00?o0000ooooooooool0Q?ooool00ol0003ooooooooo
o`21ooooo`005Oooool00ol0003oooooooooo`24ooooo`03o`000?oooooooooo087ooooo000Eoooo
o`03o`000?oooooooooo08Gooooo00?o0000ooooooooool0P?ooool001Gooooo0_l00026ooooo`03
o`000?oooooooooo083ooooo000Eooooo`03o`000?oooooooooo08Gooooo00?o0000ooooooooool0
P?ooool001Gooooo00?o0000ooooooooool0QOooool00ol0003oooooooooo`20ooooo`005Oooool0
0ol0003oooooooooo`25ooooo`03o`000?oooooooooo083ooooo000Eooooo`03o`000?oooooooooo
08Gooooo00?o0000ooooooooool0P?ooool001Gooooo00?o0000ooooooooool0QOooool00ol0003o
ooooooooo`20ooooo`005Oooool00ol0003oooooooooo`25ooooo`03o`000?oooooooooo083ooooo
000Eooooo`03o`000?oooooooooo08Gooooo00?o0000ooooooooool0P?ooool001Gooooo0_l00026
ooooo`03o`000?oooooooooo083ooooo000Eooooo`03o`000?oooooooooo08Gooooo00?o0000oooo
ooooool0P?ooool001Gooooo00?o0000ooooooooool0QOooool00ol0003oooooooooo`20ooooo`00
5Oooool00ol0003oooooooooo`25ooooo`03o`000?oooooooooo083ooooo000Eooooo`03o`000?oo
oooooooo08Gooooo00?o0000ooooooooool0P?ooool000;ooooo0_l00004ooooo`03o`000?oooooo
oooo00;ooooo0ol00005ooooo`03o`000?oooooooooo08Gooooo00?o0000ooooooooool0P?ooool0
0005ooooool0003oooooooooool000001oooool01Ol0003ooooooooooooooooo000000Cooooo00?o
0000ooooooooool0QOooool00ol0003oooooooooo`20ooooo`0000Goooooo`000?ooooooooooo`00
0007ooooo`05o`000?ooooooooooooooool000001?ooool00ol0003oooooooooo`25ooooo`03o`00
0?oooooooooo083ooooo00001Ooooooo0000oooooooooooo000000Sooooo0ol00005ooooo`?o0000
QOooool00ol0003oooooooooo`20ooooo`0000Goooooo`000?ooooooooooo`000007ooooo`05o`00
0?ooooooooooooooool000001?ooool00ol0003oooooooooo`25ooooo`03o`000?oooooooooo083o
oooo00001Ooooooo0000oooooooooooo000000Oooooo00Go0000ooooooooooooooooo`000004oooo
o`03o`000?oooooooooo08Gooooo00?o0000ooooooooool0P?ooool000;ooooo0_l00009ooooo`?o
00001Oooool00ol0003oooooooooo`26ooooo`03o`000?oooooooooo07oooooo000Eooooo`03o`00
0?oooooooooo08Kooooo00?o0000ooooooooool0Ooooool001Gooooo00?o0000ooooooooool0Q_oo
ool00ol0003oooooooooo`1oooooo`005Oooool00ol0003oooooooooo`26ooooo`03o`000?oooooo
oooo07oooooo000Eooooo`03o`000?oooooooooo08Kooooo00?o0000ooooooooool0Ooooool001Go
oooo0_l00027ooooo`03o`000?oooooooooo07oooooo000Eooooo`03o`000?oooooooooo08Kooooo
00?o0000ooooooooool0Ooooool001Gooooo00?o0000ooooooooool0Q_ooool00ol0003ooooooooo
o`1oooooo`005Oooool00ol0003oooooooooo`26ooooo`03o`000?oooooooooo07oooooo000Eoooo
o`03o`000?oooooooooo08Kooooo00?o0000ooooooooool0Ooooool001Gooooo00?o0000oooooooo
ool0Q_ooool00ol0003oooooooooo`1oooooo`005Oooool00ol0003oooooooooo`26ooooo`03o`00
0?oooooooooo07oooooo000Eooooo`03o`000?oooooooooo08Kooooo00?o0000ooooooooool0Oooo
ool001Gooooo0_l00027ooooo`03o`000?oooooooooo07oooooo000Eooooo`03o`000?oooooooooo
08Kooooo00?o0000ooooooooool0Ooooool001Gooooo00?o0000ooooooooool0Q_ooool00ol0003o
ooooooooo`1oooooo`005Oooool00ol0003oooooooooo`26ooooo`03o`000?oooooooooo07oooooo
000Eooooo`03o`000?oooooooooo08Kooooo00?o0000ooooooooool0Ooooool001Gooooo00?o0000
ooooooooool0Q_ooool00ol0003oooooooooo`1oooooo`005Oooool00ol0003oooooooooo`26oooo
o`03o`000?oooooooooo07oooooo000Eooooo`03o`000?oooooooooo08Oooooo00?o0000oooooooo
ool0O_ooool001Gooooo0_l00028ooooo`03o`000?oooooooooo07kooooo000Eooooo`03o`000?oo
oooooooo08Oooooo00?o0000ooooooooool0O_ooool001Gooooo00?o0000ooooooooool0Qoooool0
0ol0003oooooooooo`1nooooo`005Oooool00ol0003oooooooooo`27ooooo`03o`000?oooooooooo
07kooooo000Eooooo`03o`000?oooooooooo08Oooooo00?o0000ooooooooool0O_ooool000gooooo
0ol00005ooooo`03o`000?oooooooooo08Oooooo00?o0000ooooooooool0O_ooool000kooooo00?o
0000ooooooooool01?ooool00ol0003oooooooooo`27ooooo`03o`000?oooooooooo07kooooo000>
ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0Qoooool00ol0003oooooooooo`1n
ooooo`003_ooool00ol0003oooooooooo`04ooooo`?o0000Qooooomjo`0000Oooooo000>ooooo`03
o`000?oooooooooo0?oooooo4?ooool000gooooo0_l0003ooooooa;ooooo000>ooooo`03o`000?oo
oooooooo0?oooooo4?ooool00?oooooo8Oooool00001\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-2.49048, -0.0764114, \
0.115739, 0.00624232}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 0.0333333 0 0.618034 [
[.16667 -0.0125 -3 -9 ]
[.16667 -0.0125 3 0 ]
[.33333 -0.0125 -6 -9 ]
[.33333 -0.0125 6 0 ]
[.5 -0.0125 -6 -9 ]
[.5 -0.0125 6 0 ]
[.66667 -0.0125 -6 -9 ]
[.66667 -0.0125 6 0 ]
[.83333 -0.0125 -6 -9 ]
[.83333 -0.0125 6 0 ]
[1 -0.0125 -6 -9 ]
[1 -0.0125 6 0 ]
[-0.0125 .12361 -18 -4.5 ]
[-0.0125 .12361 0 4.5 ]
[-0.0125 .24721 -18 -4.5 ]
[-0.0125 .24721 0 4.5 ]
[-0.0125 .37082 -18 -4.5 ]
[-0.0125 .37082 0 4.5 ]
[-0.0125 .49443 -18 -4.5 ]
[-0.0125 .49443 0 4.5 ]
[-0.0125 .61803 -6 -4.5 ]
[-0.0125 .61803 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.16667 0 m
.16667 .00625 L
s
[(5)] .16667 -0.0125 0 1 Mshowa
.33333 0 m
.33333 .00625 L
s
[(10)] .33333 -0.0125 0 1 Mshowa
.5 0 m
.5 .00625 L
s
[(15)] .5 -0.0125 0 1 Mshowa
.66667 0 m
.66667 .00625 L
s
[(20)] .66667 -0.0125 0 1 Mshowa
.83333 0 m
.83333 .00625 L
s
[(25)] .83333 -0.0125 0 1 Mshowa
1 0 m
1 .00625 L
s
[(30)] 1 -0.0125 0 1 Mshowa
.125 Mabswid
.03333 0 m
.03333 .00375 L
s
.06667 0 m
.06667 .00375 L
s
.1 0 m
.1 .00375 L
s
.13333 0 m
.13333 .00375 L
s
.2 0 m
.2 .00375 L
s
.23333 0 m
.23333 .00375 L
s
.26667 0 m
.26667 .00375 L
s
.3 0 m
.3 .00375 L
s
.36667 0 m
.36667 .00375 L
s
.4 0 m
.4 .00375 L
s
.43333 0 m
.43333 .00375 L
s
.46667 0 m
.46667 .00375 L
s
.53333 0 m
.53333 .00375 L
s
.56667 0 m
.56667 .00375 L
s
.6 0 m
.6 .00375 L
s
.63333 0 m
.63333 .00375 L
s
.7 0 m
.7 .00375 L
s
.73333 0 m
.73333 .00375 L
s
.76667 0 m
.76667 .00375 L
s
.8 0 m
.8 .00375 L
s
.86667 0 m
.86667 .00375 L
s
.9 0 m
.9 .00375 L
s
.93333 0 m
.93333 .00375 L
s
.96667 0 m
.96667 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .12361 m
.00625 .12361 L
s
[(0.2)] -0.0125 .12361 1 0 Mshowa
0 .24721 m
.00625 .24721 L
s
[(0.4)] -0.0125 .24721 1 0 Mshowa
0 .37082 m
.00625 .37082 L
s
[(0.6)] -0.0125 .37082 1 0 Mshowa
0 .49443 m
.00625 .49443 L
s
[(0.8)] -0.0125 .49443 1 0 Mshowa
0 .61803 m
.00625 .61803 L
s
[(1)] -0.0125 .61803 1 0 Mshowa
.125 Mabswid
0 .0309 m
.00375 .0309 L
s
0 .0618 m
.00375 .0618 L
s
0 .09271 m
.00375 .09271 L
s
0 .15451 m
.00375 .15451 L
s
0 .18541 m
.00375 .18541 L
s
0 .21631 m
.00375 .21631 L
s
0 .27812 m
.00375 .27812 L
s
0 .30902 m
.00375 .30902 L
s
0 .33992 m
.00375 .33992 L
s
0 .40172 m
.00375 .40172 L
s
0 .43262 m
.00375 .43262 L
s
0 .46353 m
.00375 .46353 L
s
0 .52533 m
.00375 .52533 L
s
0 .55623 m
.00375 .55623 L
s
0 .58713 m
.00375 .58713 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.03333 0 m
.06667 0 L
.1 2e-05 L
.13333 6e-05 L
.16667 .00019 L
.2 .00058 L
.23333 .00163 L
.26667 .00419 L
.3 .00979 L
.33333 .02082 L
.36667 .0405 L
.4 .07242 L
.43333 .11967 L
.46667 .18371 L
.5 .26341 L
.53333 .35462 L
.56667 .43432 L
.6 .49837 L
.63333 .54561 L
.66667 .57753 L
.7 .59722 L
.73333 .60825 L
.76667 .61384 L
.8 .6164 L
.83333 .61746 L
.86667 .61785 L
.9 .61798 L
.93333 .61802 L
.96667 .61803 L
1 .61803 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[6]:=",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/B000`400?l00000o`00003ooooooolQ
ooooo`00?_ooool3o`0002Gooooo0ol00004ooooo`;o00008oooool3o`0000?ooooo0ol0000Qoooo
o`Go00000oooool2o`00027ooooo1Ol00002ooooo`?o00008_ooool3o`0000Cooooo0_l00004oooo
o`00?Oooool01Ol0003ooooooooooooooooo000002Gooooo00?o0000ooooooooool00_ooool01?l0
003oooooooooool0000Sooooo`05o`000?ooooooooooooooool000000oooool00ol0003ooooooooo
o`0Oooooo`04o`000?ooooooooooo`0000;ooooo00Co0000oooooooooooo00008Oooool01_l0003o
ooooooooool0003oooooo`0000?ooooo00?o0000ooooooooool07_ooool01Ol0003ooooooooooooo
oooo000000;ooooo00Co0000oooooooooooo00000oooool0047ooooo00?o0000ooooooooool08ooo
ool00ol0003oooooooooo`02ooooo`04o`000?ooooooooooo`0002?ooooo00?o0000ooooooooool0
1Oooool00ol0003oooooooooo`0Pooooo`03o`000?oooooooooo00;ooooo00Co0000oooooooooooo
00008_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo02;ooooo00Co0000oooooooo
oooo00000_ooool00ol0003oooooooooo`01ooooo`00@Oooool00ol0003oooooooooo`0Sooooo`03
o`000?oooooooooo00;ooooo00Co0000oooooooooooo00008oooool00ol0003oooooooooo`05oooo
o`03o`000?oooooooooo027ooooo00Go0000ooooooooooooooooo`000002ooooo`03o`000?oooooo
oooo027ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`0Pooooo`;o00000oooool0
1?l0003oooooooooool00003ooooo`00?Oooool4o`0002Kooooo00?o0000ooooooooool00_ooool0
1?l0003oooooooooool0000Sooooo`04o`000?ooooooooooooooo`Co00008Oooool01Ol0003ooooo
oooooooooooo000000;ooooo00Co0000oooooooooooo00008?ooool01_l0003ooooooooooooooooo
0000ooooo`Co00009Oooool01?l0003oooooooooool00002ooooo`03o`000?oooooooooo007ooooo
000mooooo`03o`000?oooooooooo02Kooooo0_l00004ooooo`04o`000?ooooooooooo`0002;ooooo
0_l00003ooooo`03o`000?oooooooooo02;ooooo00Go0000ooooooooooooooooo`000002ooooo`04
o`000?ooooooooooo`00023ooooo00Oo0000ooooooooooooooooo`000?oooooo000002Cooooo00Go
0000ooooooooooooooooo`000002ooooo`04o`000?ooooooooooo`0000?ooooo000mooooo`Go0000
9Oooool00ol0003oooooooooo`03ooooo`;o00009?ooool01?l0003oooooooooooooool5o`00027o
oooo0ol00004ooooo`;o00008_ooool3o`0000;ooooo1Ol0000Qooooo`?o00001?ooool2o`0000Co
oooo003oooooob7ooooo003oooooob7ooooo003oooooob7ooooo003oooooob7ooooo000Eoooooooo
00001Ol00007ooooo`005Oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Gooooo
00?o0000ooooooooool01_ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Gooooo
00?o0000ooooooooool01_ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00;ooooo
2Ol00003ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01_ooool00ol0003ooooo
ooooo`06ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01_ooool00ol0003ooooo
ooooo`06ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01_ooool00ol0003ooooo
ooooo`06ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01_ooool00ol0003ooooo
ooooo`05ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01_ooool00ol0003ooooo
ooooo`05ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01_ooool00ol0003ooooo
ooooo`05ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01_ooool00ol0003ooooo
ooooo`05ooooo`03o`000?oooooooooo00Gooooo000Eooooo`03o`000?oooooooooo04Sooooo1Ol0
002kooooo`005Oooool00ol0003oooooooooo`1=ooooo`?o0000^?ooool001Gooooo00?o0000oooo
ooooool0D?ooool3o`000;Gooooo000Eooooo`03o`000?oooooooooo05?ooooo0_l0002cooooo`00
5Oooool00ol0003oooooooooo`1Eooooo`;o0000/Oooool001Gooooo00?o0000ooooooooool0Eooo
ool2o`000:oooooo000Eooooo`;o0000F_ooool00ol0003oooooooooo`2/ooooo`005Oooool00ol0
003oooooooooo`1Jooooo`;o0000[?ooool001Gooooo00?o0000ooooooooool0G?ooool00ol0003o
ooooooooo`2Yooooo`005Oooool00ol0003oooooooooo`1Mooooo`03o`000?oooooooooo0:Sooooo
000Eooooo`03o`000?oooooooooo05kooooo00?o0000ooooooooool0Yoooool001Gooooo00?o0000
ooooooooool0Goooool00ol0003oooooooooo`2Vooooo`005Oooool00ol0003oooooooooo`1Poooo
o`03o`000?oooooooooo0:Gooooo000Eooooo`03o`000?oooooooooo067ooooo00?o0000oooooooo
ool0Y?ooool001Gooooo0_l0001Sooooo`03o`000?oooooooooo0:?ooooo000Eooooo`03o`000?oo
oooooooo06?ooooo00?o0000ooooooooool0X_ooool001Gooooo00?o0000ooooooooool0I?ooool0
0ol0003oooooooooo`2Qooooo`005Oooool00ol0003oooooooooo`1Uooooo`03o`000?oooooooooo
0:3ooooo000Eooooo`03o`000?oooooooooo06Gooooo00?o0000ooooooooool0X?ooool001Gooooo
00?o0000ooooooooool0I_ooool00ol0003oooooooooo`2Oooooo`005Oooool00ol0003ooooooooo
o`1Wooooo`03o`000?oooooooooo09kooooo000Eooooo`03o`000?oooooooooo06Oooooo00?o0000
ooooooooool0W_ooool001Gooooo0_l0001Yooooo`03o`000?oooooooooo09gooooo000Eooooo`03
o`000?oooooooooo06Wooooo00?o0000ooooooooool0W?ooool001Gooooo00?o0000ooooooooool0
JOooool00ol0003oooooooooo`2Looooo`005Oooool00ol0003oooooooooo`1Zooooo`03o`000?oo
oooooooo09_ooooo000Eooooo`03o`000?oooooooooo06_ooooo00?o0000ooooooooool0V_ooool0
00;ooooo0_l00004ooooo`04o`000?ooooooooooooooo`Go00001?ooool00ol0003oooooooooo`1[
ooooo`03o`000?oooooooooo09[ooooo00001Ooooooo0000oooooooooooo000000Sooooo00Co0000
oooooooooooo00001?ooool00ol0003oooooooooo`1/ooooo`03o`000?oooooooooo09Wooooo0000
1Ooooooo0000oooooooooooo000000Wooooo00?o0000ooooooooool01?ooool00ol0003ooooooooo
o`1]ooooo`03o`000?oooooooooo09Sooooo00001Ooooooo0000oooooooooooo000000[ooooo00?o
0000ooooooooool00oooool3o`0006gooooo00?o0000ooooooooool0V?ooool00005ooooool0003o
ooooooooool000001oooool01Ol0003ooooooooooooooooo000000Cooooo00?o0000ooooooooool0
K_ooool00ol0003oooooooooo`2Gooooo`0000Goooooo`000?ooooooooooo`000007ooooo`05o`00
0?ooooooooooooooool000001?ooool00ol0003oooooooooo`1^ooooo`03o`000?oooooooooo09Oo
oooo0002ooooo`;o00002Oooool3o`0000Gooooo00?o0000ooooooooool0Koooool00ol0003ooooo
ooooo`2Fooooo`005Oooool00ol0003oooooooooo`1`ooooo`03o`000?oooooooooo09Gooooo000E
ooooo`03o`000?oooooooooo073ooooo00?o0000ooooooooool0UOooool001Gooooo00?o0000oooo
ooooool0LOooool00ol0003oooooooooo`2Dooooo`005Oooool00ol0003oooooooooo`1aooooo`03
o`000?oooooooooo09Cooooo000Eooooo`;o0000Loooool00ol0003oooooooooo`2Cooooo`005Ooo
ool00ol0003oooooooooo`1booooo`03o`000?oooooooooo09?ooooo000Eooooo`03o`000?oooooo
oooo07?ooooo00?o0000ooooooooool0T_ooool001Gooooo00?o0000ooooooooool0Loooool00ol0
003oooooooooo`2Booooo`005Oooool00ol0003oooooooooo`1dooooo`03o`000?oooooooooo097o
oooo000Eooooo`03o`000?oooooooooo07Gooooo00?o0000ooooooooool0T?ooool001Gooooo00?o
0000ooooooooool0MOooool00ol0003oooooooooo`2@ooooo`005Oooool00ol0003oooooooooo`1f
ooooo`03o`000?oooooooooo08oooooo000Eooooo`;o0000Moooool00ol0003oooooooooo`2?oooo
o`005Oooool00ol0003oooooooooo`1gooooo`03o`000?oooooooooo08kooooo000Eooooo`03o`00
0?oooooooooo07Oooooo00?o0000ooooooooool0S_ooool001Gooooo00?o0000ooooooooool0N?oo
ool00ol0003oooooooooo`2=ooooo`005Oooool00ol0003oooooooooo`1hooooo`03o`000?oooooo
oooo08gooooo000Eooooo`03o`000?oooooooooo07Sooooo00?o0000ooooooooool0SOooool001Go
oooo00?o0000ooooooooool0NOooool00ol0003oooooooooo`2<ooooo`005Oooool00ol0003ooooo
ooooo`1iooooo`03o`000?oooooooooo08cooooo000Eooooo`;o0000Noooool00ol0003ooooooooo
o`2;ooooo`005Oooool00ol0003oooooooooo`1jooooo`03o`000?oooooooooo08_ooooo000Eoooo
o`03o`000?oooooooooo07_ooooo00?o0000ooooooooool0R_ooool001Gooooo00?o0000oooooooo
ool0Noooool00ol0003oooooooooo`2:ooooo`005Oooool00ol0003oooooooooo`1kooooo`03o`00
0?oooooooooo08[ooooo0002ooooo`;o00001?ooool00ol0003oooooooooo`03ooooo`?o00001?oo
ool00ol0003oooooooooo`1looooo`03o`000?oooooooooo08Wooooo00001Ooooooo0000oooooooo
oooo000000[ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`1looooo`03o`000?oo
oooooooo08Wooooo00001Ooooooo0000oooooooooooo000000Oooooo1Ol00004ooooo`03o`000?oo
oooooooo07gooooo00?o0000ooooooooool0R?ooool00005ooooool0003oooooooooool000001ooo
ool01?l0003oooooooooool00005ooooo`?o0000OOooool00ol0003oooooooooo`28ooooo`0000Go
ooooo`000?ooooooooooo`000008ooooo`03o`000?oooooo000000Gooooo00?o0000ooooooooool0
O_ooool00ol0003oooooooooo`27ooooo`0000Goooooo`000?ooooooooooo`000009ooooo`;o0000
1Oooool00ol0003oooooooooo`1nooooo`03o`000?oooooooooo08Oooooo0002ooooo`;o00002ooo
ool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo07kooooo00?o0000ooooooooool0Qooo
ool001Gooooo00?o0000ooooooooool0Ooooool00ol0003oooooooooo`26ooooo`005Oooool00ol0
003oooooooooo`1oooooo`03o`000?oooooooooo08Kooooo000Eooooo`03o`000?oooooooooo083o
oooo00?o0000ooooooooool0QOooool001Gooooo00?o0000ooooooooool0P?ooool00ol0003ooooo
ooooo`25ooooo`005Oooool2o`00087ooooo00?o0000ooooooooool0QOooool001Gooooo00?o0000
ooooooooool0POooool00ol0003oooooooooo`24ooooo`005Oooool00ol0003oooooooooo`21oooo
o`03o`000?oooooooooo08Cooooo000Eooooo`03o`000?oooooooooo087ooooo00?o0000oooooooo
ool0Q?ooool001Gooooo00?o0000ooooooooool0P_ooool00ol0003oooooooooo`23ooooo`005Ooo
ool00ol0003oooooooooo`22ooooo`03o`000?oooooooooo08?ooooo000Eooooo`03o`000?oooooo
oooo08;ooooo00?o0000ooooooooool0Poooool001Gooooo00?o0000ooooooooool0Poooool00ol0
003oooooooooo`22ooooo`005Oooool2o`0008Cooooo00?o0000ooooooooool0P_ooool001Gooooo
00?o0000ooooooooool0Poooool00ol0003oooooooooo`22ooooo`005Oooool00ol0003ooooooooo
o`24ooooo`03o`000?oooooooooo087ooooo000Eooooo`03o`000?oooooooooo08Cooooo00?o0000
ooooooooool0POooool001Gooooo00?o0000ooooooooool0Q?ooool00ol0003oooooooooo`21oooo
o`005Oooool00ol0003oooooooooo`25ooooo`03o`000?oooooooooo083ooooo000Eooooo`03o`00
0?oooooooooo08Gooooo00?o0000ooooooooool0P?ooool001Gooooo00?o0000ooooooooool0QOoo
ool00ol0003oooooooooo`20ooooo`005Oooool2o`0008Oooooo00?o0000ooooooooool0Ooooool0
01Gooooo00?o0000ooooooooool0Q_ooool00ol0003oooooooooo`1oooooo`005Oooool00ol0003o
ooooooooo`26ooooo`03o`000?oooooooooo07oooooo000Eooooo`03o`000?oooooooooo08Oooooo
00?o0000ooooooooool0O_ooool001Gooooo00?o0000ooooooooool0Qoooool00ol0003ooooooooo
o`1nooooo`000_ooool2o`0000Cooooo00?o0000ooooooooool00_ooool3o`0000Gooooo00?o0000
ooooooooool0Qoooool00ol0003oooooooooo`1nooooo`0000Goooooo`000?ooooooooooo`000007
ooooo`05o`000?ooooooooooooooool000001?ooool00ol0003oooooooooo`28ooooo`03o`000?oo
oooooooo07gooooo00001Ooooooo0000oooooooooooo000000Oooooo00Go0000oooooooooooooooo
o`000004ooooo`03o`000?oooooooooo08Sooooo00?o0000ooooooooool0OOooool00005ooooool0
003oooooooooool000001oooool4o`0000Gooooo0ol00029ooooo`03o`000?oooooooooo07cooooo
00001Ooooooo0000oooooooooooo000000Oooooo00?o0000ooooooooool01_ooool00ol0003ooooo
ooooo`29ooooo`03o`000?oooooooooo07cooooo00001Ooooooo0000oooooooooooo000000Sooooo
00?o0000ooooooooool01Oooool00ol0003oooooooooo`29ooooo`03o`000?oooooooooo07cooooo
0002ooooo`;o00002_ooool2o`0000Gooooo00?o0000ooooooooool0R_ooool00ol0003ooooooooo
o`1kooooo`005Oooool00ol0003oooooooooo`2:ooooo`03o`000?oooooooooo07_ooooo000Eoooo
o`03o`000?oooooooooo08_ooooo00?o0000ooooooooool0N_ooool001Gooooo00?o0000oooooooo
ool0Roooool00ol0003oooooooooo`1jooooo`005Oooool00ol0003oooooooooo`2<ooooo`03o`00
0?oooooooooo07Wooooo000Eooooo`;o0000SOooool00ol0003oooooooooo`1iooooo`005Oooool0
0ol0003oooooooooo`2=ooooo`03o`000?oooooooooo07Sooooo000Eooooo`03o`000?oooooooooo
08gooooo00?o0000ooooooooool0N?ooool001Gooooo00?o0000ooooooooool0S_ooool00ol0003o
ooooooooo`1gooooo`005Oooool00ol0003oooooooooo`2>ooooo`03o`000?oooooooooo07Oooooo
000Eooooo`03o`000?oooooooooo08kooooo00?o0000ooooooooool0Moooool001Gooooo00?o0000
ooooooooool0Soooool00ol0003oooooooooo`1fooooo`005Oooool00ol0003oooooooooo`2?oooo
o`03o`000?oooooooooo07Kooooo000Eooooo`;o0000TOooool00ol0003oooooooooo`1eooooo`00
5Oooool00ol0003oooooooooo`2@ooooo`03o`000?oooooooooo07Gooooo000Eooooo`03o`000?oo
oooooooo097ooooo00?o0000ooooooooool0M?ooool001Gooooo00?o0000ooooooooool0TOooool0
0ol0003oooooooooo`1dooooo`005Oooool00ol0003oooooooooo`2Booooo`03o`000?oooooooooo
07?ooooo000Eooooo`03o`000?oooooooooo09;ooooo00?o0000ooooooooool0Loooool001Gooooo
00?o0000ooooooooool0Toooool00ol0003oooooooooo`1booooo`005Oooool00ol0003ooooooooo
o`2Cooooo`03o`000?oooooooooo07;ooooo000Eooooo`;o0000UOooool00ol0003oooooooooo`1a
ooooo`005Oooool00ol0003oooooooooo`2Eooooo`03o`000?oooooooooo073ooooo000Eooooo`03
o`000?oooooooooo09Gooooo00?o0000ooooooooool0L?ooool001Gooooo00?o0000ooooooooool0
U_ooool00ol0003oooooooooo`1_ooooo`005Oooool00ol0003oooooooooo`2Fooooo`03o`000?oo
oooooooo06oooooo0002ooooo`;o00001?ooool00ol0003oooooooooo`02ooooo`?o00001Oooool0
0ol0003oooooooooo`2Gooooo`03o`000?oooooooooo06kooooo00001Ooooooo0000oooooooooooo
000000Oooooo00Go0000ooooooooooooooooo`000004ooooo`03o`000?oooooooooo09Oooooo00?o
0000ooooooooool0K_ooool00005ooooool0003oooooooooool000001oooool01Ol0003ooooooooo
oooooooo000000Cooooo00?o0000ooooooooool0V?ooool00ol0003oooooooooo`1]ooooo`0000Go
ooooo`000?ooooooooooo`000008ooooo`?o00001Oooool3o`0009Sooooo00?o0000ooooooooool0
KOooool00005ooooool0003oooooooooool000001oooool01Ol0003ooooooooooooooooo000000Co
oooo00?o0000ooooooooool0VOooool00ol0003oooooooooo`1/ooooo`0000Goooooo`000?oooooo
ooooo`000007ooooo`05o`000?ooooooooooooooool000001?ooool00ol0003oooooooooo`2Ioooo
o`03o`000?oooooooooo06cooooo0002ooooo`;o00002Oooool3o`0000Gooooo00?o0000oooooooo
ool0V_ooool00ol0003oooooooooo`1[ooooo`005Oooool00ol0003oooooooooo`2Kooooo`03o`00
0?oooooooooo06[ooooo000Eooooo`03o`000?oooooooooo09_ooooo00?o0000ooooooooool0J_oo
ool001Gooooo00?o0000ooooooooool0W?ooool00ol0003oooooooooo`1Yooooo`005Oooool00ol0
003oooooooooo`2Mooooo`03o`000?oooooooooo06Sooooo000Eooooo`;o0000W_ooool00ol0003o
ooooooooo`1Xooooo`005Oooool00ol0003oooooooooo`2Nooooo`03o`000?oooooooooo06Oooooo
000Eooooo`03o`000?oooooooooo09oooooo00?o0000ooooooooool0I_ooool001Gooooo00?o0000
ooooooooool0Woooool00ol0003oooooooooo`1Vooooo`005Oooool00ol0003oooooooooo`2Poooo
o`03o`000?oooooooooo06Gooooo000Eooooo`03o`000?oooooooooo0:7ooooo0_l0001Uooooo`00
5Oooool00ol0003oooooooooo`2Sooooo`03o`000?oooooooooo06;ooooo000Eooooo`03o`000?oo
oooooooo0:Cooooo00?o0000ooooooooool0HOooool001Gooooo0_l0002Vooooo`03o`000?oooooo
oooo063ooooo000Eooooo`03o`000?oooooooooo0:Kooooo00?o0000ooooooooool0Goooool001Go
oooo00?o0000ooooooooool0Yoooool00ol0003oooooooooo`1Nooooo`005Oooool00ol0003ooooo
ooooo`2Xooooo`03o`000?oooooooooo05gooooo000Eooooo`03o`000?oooooooooo0:Wooooo00?o
0000ooooooooool0G?ooool001Gooooo00?o0000ooooooooool0Z_ooool2o`0005cooooo000Eoooo
o`03o`000?oooooooooo0:cooooo00?o0000ooooooooool0FOooool001Gooooo00?o0000oooooooo
ool0[Oooool00ol0003oooooooooo`1Hooooo`005Oooool2o`000:oooooo0_l0001Hooooo`005Ooo
ool00ol0003oooooooooo`2`ooooo`03o`000?oooooooooo05Gooooo000Eooooo`03o`000?oooooo
oooo0;7ooooo00?o0000ooooooooool0E?ooool001Gooooo00?o0000ooooooooool0/_ooool3o`00
05?ooooo000Eooooo`03o`000?oooooooooo0;Gooooo1Ol0001>ooooo`003Oooool3o`0000Gooooo
00?o0000ooooooooool0^_ooool4o`0004[ooooo000>ooooo`03o`000?oooooooooo00Cooooo00?o
0000ooooooooool0__ooool5o`0004Gooooo000>ooooo`03o`000?oooooooooo00Cooooo00?o0000
ooooooooool0`oooool6o`0003oooooo000>ooooo`03o`000?oooooooooo00Cooooo0ol00039oooo
ocSo00001oooool000kooooo00?o0000ooooooooool0ooooool@ooooo`003Oooool2o`000?oooooo
4_ooool000kooooo00?o0000ooooooooool0ooooool@ooooo`00oooooolQooooo`00\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-2.49048, -0.0764114, \
0.115739, 0.00624232}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 0.0333333 0 0.618034 [
[.16667 -0.0125 -3 -9 ]
[.16667 -0.0125 3 0 ]
[.33333 -0.0125 -6 -9 ]
[.33333 -0.0125 6 0 ]
[.5 -0.0125 -6 -9 ]
[.5 -0.0125 6 0 ]
[.66667 -0.0125 -6 -9 ]
[.66667 -0.0125 6 0 ]
[.83333 -0.0125 -6 -9 ]
[.83333 -0.0125 6 0 ]
[1 -0.0125 -6 -9 ]
[1 -0.0125 6 0 ]
[-0.0125 .12361 -18 -4.5 ]
[-0.0125 .12361 0 4.5 ]
[-0.0125 .24721 -18 -4.5 ]
[-0.0125 .24721 0 4.5 ]
[-0.0125 .37082 -18 -4.5 ]
[-0.0125 .37082 0 4.5 ]
[-0.0125 .49443 -18 -4.5 ]
[-0.0125 .49443 0 4.5 ]
[-0.0125 .61803 -6 -4.5 ]
[-0.0125 .61803 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.16667 0 m
.16667 .00625 L
s
[(5)] .16667 -0.0125 0 1 Mshowa
.33333 0 m
.33333 .00625 L
s
[(10)] .33333 -0.0125 0 1 Mshowa
.5 0 m
.5 .00625 L
s
[(15)] .5 -0.0125 0 1 Mshowa
.66667 0 m
.66667 .00625 L
s
[(20)] .66667 -0.0125 0 1 Mshowa
.83333 0 m
.83333 .00625 L
s
[(25)] .83333 -0.0125 0 1 Mshowa
1 0 m
1 .00625 L
s
[(30)] 1 -0.0125 0 1 Mshowa
.125 Mabswid
.03333 0 m
.03333 .00375 L
s
.06667 0 m
.06667 .00375 L
s
.1 0 m
.1 .00375 L
s
.13333 0 m
.13333 .00375 L
s
.2 0 m
.2 .00375 L
s
.23333 0 m
.23333 .00375 L
s
.26667 0 m
.26667 .00375 L
s
.3 0 m
.3 .00375 L
s
.36667 0 m
.36667 .00375 L
s
.4 0 m
.4 .00375 L
s
.43333 0 m
.43333 .00375 L
s
.46667 0 m
.46667 .00375 L
s
.53333 0 m
.53333 .00375 L
s
.56667 0 m
.56667 .00375 L
s
.6 0 m
.6 .00375 L
s
.63333 0 m
.63333 .00375 L
s
.7 0 m
.7 .00375 L
s
.73333 0 m
.73333 .00375 L
s
.76667 0 m
.76667 .00375 L
s
.8 0 m
.8 .00375 L
s
.86667 0 m
.86667 .00375 L
s
.9 0 m
.9 .00375 L
s
.93333 0 m
.93333 .00375 L
s
.96667 0 m
.96667 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .12361 m
.00625 .12361 L
s
[(0.2)] -0.0125 .12361 1 0 Mshowa
0 .24721 m
.00625 .24721 L
s
[(0.4)] -0.0125 .24721 1 0 Mshowa
0 .37082 m
.00625 .37082 L
s
[(0.6)] -0.0125 .37082 1 0 Mshowa
0 .49443 m
.00625 .49443 L
s
[(0.8)] -0.0125 .49443 1 0 Mshowa
0 .61803 m
.00625 .61803 L
s
[(1)] -0.0125 .61803 1 0 Mshowa
.125 Mabswid
0 .0309 m
.00375 .0309 L
s
0 .0618 m
.00375 .0618 L
s
0 .09271 m
.00375 .09271 L
s
0 .15451 m
.00375 .15451 L
s
0 .18541 m
.00375 .18541 L
s
0 .21631 m
.00375 .21631 L
s
0 .27812 m
.00375 .27812 L
s
0 .30902 m
.00375 .30902 L
s
0 .33992 m
.00375 .33992 L
s
0 .40172 m
.00375 .40172 L
s
0 .43262 m
.00375 .43262 L
s
0 .46353 m
.00375 .46353 L
s
0 .52533 m
.00375 .52533 L
s
0 .55623 m
.00375 .55623 L
s
0 .58713 m
.00375 .58713 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.03333 .00099 m
.06667 .00136 L
.1 .00206 L
.13333 .00331 L
.16667 .00542 L
.2 .00892 L
.23333 .0145 L
.26667 .02314 L
.3 .03603 L
.33333 .05455 L
.36667 .08014 L
.4 .11412 L
.43333 .15748 L
.46667 .21067 L
.5 .27343 L
.53333 .34461 L
.56667 .40736 L
.6 .46055 L
.63333 .50392 L
.66667 .5379 L
.7 .56349 L
.73333 .58201 L
.76667 .59489 L
.8 .60353 L
.83333 .60912 L
.86667 .61261 L
.9 .61473 L
.93333 .61597 L
.96667 .61668 L
1 .61705 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[6]:=",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/B000`400?l00000o`00003ooooooolQ
ooooo`00?_ooool3o`0002Gooooo0ol00004ooooo`;o00008oooool3o`0000?ooooo0ol0000Qoooo
o`Go00000oooool2o`00027ooooo1Ol00002ooooo`?o00008_ooool3o`0000Cooooo0_l00004oooo
o`00?Oooool01Ol0003ooooooooooooooooo000002Gooooo00?o0000ooooooooool00_ooool01?l0
003oooooooooool0000Sooooo`05o`000?ooooooooooooooool000000oooool00ol0003ooooooooo
o`0Oooooo`04o`000?ooooooooooo`0000;ooooo00Co0000oooooooooooo00008Oooool01_l0003o
ooooooooool0003oooooo`0000?ooooo00?o0000ooooooooool07_ooool01Ol0003ooooooooooooo
oooo000000;ooooo00Co0000oooooooooooo00000oooool0047ooooo00?o0000ooooooooool08ooo
ool00ol0003oooooooooo`02ooooo`04o`000?ooooooooooo`0002?ooooo00?o0000ooooooooool0
1Oooool00ol0003oooooooooo`0Pooooo`03o`000?oooooooooo00;ooooo00Co0000oooooooooooo
00008_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo02;ooooo00Co0000oooooooo
oooo00000_ooool00ol0003oooooooooo`01ooooo`00@Oooool00ol0003oooooooooo`0Sooooo`03
o`000?oooooooooo00;ooooo00Co0000oooooooooooo00008oooool00ol0003oooooooooo`05oooo
o`03o`000?oooooooooo027ooooo00Go0000ooooooooooooooooo`000002ooooo`03o`000?oooooo
oooo027ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`0Pooooo`;o00000oooool0
1?l0003oooooooooool00003ooooo`00?Oooool4o`0002Kooooo00?o0000ooooooooool00_ooool0
1?l0003oooooooooool0000Sooooo`04o`000?ooooooooooooooo`Co00008Oooool01Ol0003ooooo
oooooooooooo000000;ooooo00Co0000oooooooooooo00008?ooool01_l0003ooooooooooooooooo
0000ooooo`Co00009Oooool01?l0003oooooooooool00002ooooo`03o`000?oooooooooo007ooooo
000mooooo`03o`000?oooooooooo02Kooooo0_l00004ooooo`04o`000?ooooooooooo`0002;ooooo
0_l00003ooooo`03o`000?oooooooooo02;ooooo00Go0000ooooooooooooooooo`000002ooooo`04
o`000?ooooooooooo`00023ooooo00Oo0000ooooooooooooooooo`000?oooooo000002Cooooo00Go
0000ooooooooooooooooo`000002ooooo`04o`000?ooooooooooo`0000?ooooo000mooooo`Go0000
9Oooool00ol0003oooooooooo`03ooooo`;o00009?ooool01?l0003oooooooooooooool5o`00027o
oooo0ol00004ooooo`;o00008_ooool3o`0000;ooooo1Ol0000Qooooo`?o00001?ooool2o`0000Co
oooo003oooooob7ooooo003oooooob7ooooo003oooooob7ooooo003oooooob7ooooo000Eoooooooo
00001Ol00007ooooo`005Oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Gooooo
00?o0000ooooooooool01_ooool00ol0003oooooooooo`03oooooa7o00000oooool00ol0003ooooo
ooooo`06ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01_ooool00ol0003ooooo
ooooo`05ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01_ooool00ol0003ooooo
ooooo`05ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01_ooool00ol0003ooooo
ooooo`05ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01_ooool00ol0003ooooo
ooooo`05ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01Oooool00ol0003ooooo
ooooo`06ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01Oooool00ol0003ooooo
ooooo`06ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01Oooool00ol0003ooooo
ooooo`06ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01Oooool00ol0003ooooo
ooooo`05ooooo`005Oooool00ol0003oooooooooo`0^ooooo`Ko0000e?ooool001Gooooo00?o0000
ooooooooool0=?ooool5o`000<oooooo000Eooooo`03o`000?oooooooooo03Wooooo1?l0003;oooo
o`005Oooool00ol0003oooooooooo`0mooooo`Co0000aoooool001Gooooo00?o0000ooooooooool0
@Oooool4o`000<?ooooo000Eooooo`03o`000?oooooooooo04Gooooo0ol00030ooooo`005Oooool2
o`0004Wooooo0ol0002mooooo`005Oooool00ol0003oooooooooo`1;ooooo`;o0000^oooool001Go
oooo00?o0000ooooooooool0COooool00ol0003oooooooooo`2hooooo`005Oooool00ol0003ooooo
ooooo`1>ooooo`;o0000^?ooool001Gooooo00?o0000ooooooooool0D?ooool2o`000;Kooooo000E
ooooo`03o`000?oooooooooo05;ooooo00?o0000ooooooooool0/oooool001Gooooo00?o0000oooo
ooooool0Doooool2o`000;?ooooo000Eooooo`03o`000?oooooooooo05Gooooo00?o0000oooooooo
ool0/?ooool001Gooooo0_l0001Gooooo`03o`000?oooooooooo0:oooooo000Eooooo`03o`000?oo
oooooooo05Oooooo0_l0002_ooooo`005Oooool00ol0003oooooooooo`1Iooooo`03o`000?oooooo
oooo0:cooooo000Eooooo`03o`000?oooooooooo05[ooooo00?o0000ooooooooool0Zoooool001Go
oooo00?o0000ooooooooool0Foooool00ol0003oooooooooo`2Zooooo`005Oooool00ol0003ooooo
ooooo`1Looooo`;o0000Z_ooool001Gooooo00?o0000ooooooooool0G_ooool00ol0003ooooooooo
o`2Wooooo`005Oooool00ol0003oooooooooo`1Oooooo`03o`000?oooooooooo0:Kooooo000Eoooo
o`;o0000HOooool00ol0003oooooooooo`2Uooooo`005Oooool00ol0003oooooooooo`1Qooooo`03
o`000?oooooooooo0:Cooooo000Eooooo`03o`000?oooooooooo06;ooooo00?o0000ooooooooool0
Xoooool001Gooooo00?o0000ooooooooool0Hoooool00ol0003oooooooooo`2Rooooo`005Oooool0
0ol0003oooooooooo`1Tooooo`03o`000?oooooooooo0:7ooooo0002ooooo`;o00001?ooool01?l0
003oooooooooooooool5o`0000Cooooo00?o0000ooooooooool0IOooool00ol0003oooooooooo`2P
ooooo`0000Goooooo`000?ooooooooooo`000008ooooo`04o`000?ooooooooooo`0000Cooooo00?o
0000ooooooooool0IOooool00ol0003oooooooooo`2Pooooo`0000Goooooo`000?ooooooooooo`00
0009ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0I_ooool00ol0003ooooooooo
o`2Oooooo`0000Goooooo`000?ooooooooooo`00000:ooooo`03o`000?oooooooooo00?ooooo0ol0
001Wooooo`03o`000?oooooooooo09kooooo00001Ooooooo0000oooooooooooo000000Oooooo00Go
0000ooooooooooooooooo`000004ooooo`03o`000?oooooooooo06Oooooo00?o0000ooooooooool0
W_ooool00005ooooool0003oooooooooool000001oooool01Ol0003ooooooooooooooooo000000Co
oooo00?o0000ooooooooool0J?ooool00ol0003oooooooooo`2Mooooo`000_ooool2o`0000Wooooo
0ol00005ooooo`03o`000?oooooooooo06Wooooo00?o0000ooooooooool0W?ooool001Gooooo00?o
0000ooooooooool0JOooool00ol0003oooooooooo`2Looooo`005Oooool00ol0003oooooooooo`1Z
ooooo`03o`000?oooooooooo09_ooooo000Eooooo`03o`000?oooooooooo06_ooooo00?o0000oooo
ooooool0V_ooool001Gooooo00?o0000ooooooooool0Joooool00ol0003oooooooooo`2Jooooo`00
5Oooool2o`0006gooooo00?o0000ooooooooool0VOooool001Gooooo00?o0000ooooooooool0KOoo
ool00ol0003oooooooooo`2Hooooo`005Oooool00ol0003oooooooooo`1]ooooo`03o`000?oooooo
oooo09Sooooo000Eooooo`03o`000?oooooooooo06kooooo00?o0000ooooooooool0Uoooool001Go
oooo00?o0000ooooooooool0Koooool00ol0003oooooooooo`2Fooooo`005Oooool00ol0003ooooo
ooooo`1_ooooo`03o`000?oooooooooo09Kooooo000Eooooo`03o`000?oooooooooo073ooooo00?o
0000ooooooooool0UOooool001Gooooo00?o0000ooooooooool0LOooool00ol0003oooooooooo`2D
ooooo`005Oooool2o`0007?ooooo00?o0000ooooooooool0Toooool001Gooooo00?o0000oooooooo
ool0L_ooool00ol0003oooooooooo`2Cooooo`005Oooool00ol0003oooooooooo`1cooooo`03o`00
0?oooooooooo09;ooooo000Eooooo`03o`000?oooooooooo07Cooooo00?o0000ooooooooool0TOoo
ool001Gooooo00?o0000ooooooooool0M?ooool00ol0003oooooooooo`2Aooooo`005Oooool00ol0
003oooooooooo`1eooooo`03o`000?oooooooooo093ooooo000Eooooo`03o`000?oooooooooo07Ko
oooo00?o0000ooooooooool0Soooool001Gooooo00?o0000ooooooooool0M_ooool00ol0003ooooo
ooooo`2?ooooo`005Oooool2o`0007Sooooo00?o0000ooooooooool0S_ooool001Gooooo00?o0000
ooooooooool0Moooool00ol0003oooooooooo`2>ooooo`005Oooool00ol0003oooooooooo`1hoooo
o`03o`000?oooooooooo08gooooo000Eooooo`03o`000?oooooooooo07Sooooo00?o0000oooooooo
ool0SOooool001Gooooo00?o0000ooooooooool0NOooool00ol0003oooooooooo`2<ooooo`000_oo
ool2o`0000Cooooo00?o0000ooooooooool00oooool3o`0000Cooooo00?o0000ooooooooool0NOoo
ool00ol0003oooooooooo`2<ooooo`0000Goooooo`000?ooooooooooo`00000:ooooo`03o`000?oo
oooooooo00?ooooo00?o0000ooooooooool0N_ooool00ol0003oooooooooo`2;ooooo`0000Gooooo
o`000?ooooooooooo`000007ooooo`Go00001?ooool00ol0003oooooooooo`1kooooo`03o`000?oo
oooooooo08[ooooo00001Ooooooo0000oooooooooooo000000Oooooo00Co0000oooooooooooo0000
1Oooool3o`0007_ooooo00?o0000ooooooooool0R_ooool00005ooooool0003oooooooooool00000
2?ooool00ol0003oooooo`000005ooooo`03o`000?oooooooooo07cooooo00?o0000ooooooooool0
ROooool00005ooooool0003oooooooooool000002Oooool2o`0000Gooooo00?o0000ooooooooool0
O?ooool00ol0003oooooooooo`29ooooo`000_ooool2o`0000_ooooo00?o0000ooooooooool00ooo
ool00ol0003oooooooooo`1mooooo`03o`000?oooooooooo08Sooooo000Eooooo`03o`000?oooooo
oooo07gooooo00?o0000ooooooooool0R?ooool001Gooooo00?o0000ooooooooool0O_ooool00ol0
003oooooooooo`27ooooo`005Oooool00ol0003oooooooooo`1nooooo`03o`000?oooooooooo08Oo
oooo000Eooooo`03o`000?oooooooooo07oooooo00?o0000ooooooooool0Q_ooool001Gooooo0_l0
0020ooooo`03o`000?oooooooooo08Kooooo000Eooooo`03o`000?oooooooooo083ooooo00?o0000
ooooooooool0QOooool001Gooooo00?o0000ooooooooool0P?ooool00ol0003oooooooooo`25oooo
o`005Oooool00ol0003oooooooooo`21ooooo`03o`000?oooooooooo08Cooooo000Eooooo`03o`00
0?oooooooooo087ooooo00?o0000ooooooooool0Q?ooool001Gooooo00?o0000ooooooooool0POoo
ool00ol0003oooooooooo`24ooooo`005Oooool00ol0003oooooooooo`22ooooo`03o`000?oooooo
oooo08?ooooo000Eooooo`03o`000?oooooooooo08;ooooo00?o0000ooooooooool0Poooool001Go
oooo0_l00024ooooo`03o`000?oooooooooo08;ooooo000Eooooo`03o`000?oooooooooo08?ooooo
00?o0000ooooooooool0P_ooool001Gooooo00?o0000ooooooooool0Q?ooool00ol0003ooooooooo
o`21ooooo`005Oooool00ol0003oooooooooo`24ooooo`03o`000?oooooooooo087ooooo000Eoooo
o`03o`000?oooooooooo08Gooooo00?o0000ooooooooool0P?ooool001Gooooo00?o0000oooooooo
ool0QOooool00ol0003oooooooooo`20ooooo`005Oooool00ol0003oooooooooo`25ooooo`03o`00
0?oooooooooo083ooooo000Eooooo`03o`000?oooooooooo08Kooooo00?o0000ooooooooool0Oooo
ool001Gooooo0_l00027ooooo`03o`000?oooooooooo07oooooo000Eooooo`03o`000?oooooooooo
08Oooooo00?o0000ooooooooool0O_ooool001Gooooo00?o0000ooooooooool0Qoooool00ol0003o
ooooooooo`1nooooo`005Oooool00ol0003oooooooooo`28ooooo`03o`000?oooooooooo07gooooo
000Eooooo`03o`000?oooooooooo08Sooooo00?o0000ooooooooool0OOooool000;ooooo0_l00004
ooooo`03o`000?oooooooooo00;ooooo0ol00005ooooo`03o`000?oooooooooo08Wooooo00?o0000
ooooooooool0O?ooool00005ooooool0003oooooooooool000001oooool01Ol0003ooooooooooooo
oooo000000Cooooo00?o0000ooooooooool0R_ooool00ol0003oooooooooo`1kooooo`0000Gooooo
o`000?ooooooooooo`000007ooooo`05o`000?ooooooooooooooool000001?ooool00ol0003ooooo
ooooo`2:ooooo`03o`000?oooooooooo07_ooooo00001Ooooooo0000oooooooooooo000000Oooooo
1?l00005ooooo`?o0000Roooool00ol0003oooooooooo`1jooooo`0000Goooooo`000?oooooooooo
o`000007ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0Roooool00ol0003ooooo
ooooo`1jooooo`0000Goooooo`000?ooooooooooo`000008ooooo`03o`000?oooooooooo00Gooooo
00?o0000ooooooooool0S?ooool00ol0003oooooooooo`1iooooo`000_ooool2o`0000[ooooo0_l0
0005ooooo`03o`000?oooooooooo08cooooo00?o0000ooooooooool0NOooool001Gooooo00?o0000
ooooooooool0SOooool00ol0003oooooooooo`1hooooo`005Oooool00ol0003oooooooooo`2=oooo
o`03o`000?oooooooooo07Sooooo000Eooooo`03o`000?oooooooooo08kooooo00?o0000oooooooo
ool0Moooool001Gooooo00?o0000ooooooooool0Soooool00ol0003oooooooooo`1fooooo`005Ooo
ool2o`00093ooooo00?o0000ooooooooool0M_ooool001Gooooo00?o0000ooooooooool0T?ooool0
0ol0003oooooooooo`1eooooo`005Oooool00ol0003oooooooooo`2@ooooo`03o`000?oooooooooo
07Gooooo000Eooooo`03o`000?oooooooooo097ooooo00?o0000ooooooooool0M?ooool001Gooooo
00?o0000ooooooooool0T_ooool00ol0003oooooooooo`1cooooo`005Oooool00ol0003ooooooooo
o`2Booooo`03o`000?oooooooooo07?ooooo000Eooooo`03o`000?oooooooooo09?ooooo00?o0000
ooooooooool0L_ooool001Gooooo00?o0000ooooooooool0U?ooool00ol0003oooooooooo`1aoooo
o`005Oooool2o`0009Gooooo00?o0000ooooooooool0LOooool001Gooooo00?o0000ooooooooool0
UOooool00ol0003oooooooooo`1`ooooo`005Oooool00ol0003oooooooooo`2Eooooo`03o`000?oo
oooooooo073ooooo000Eooooo`03o`000?oooooooooo09Kooooo00?o0000ooooooooool0Koooool0
01Gooooo00?o0000ooooooooool0Uoooool00ol0003oooooooooo`1^ooooo`005Oooool00ol0003o
ooooooooo`2Gooooo`03o`000?oooooooooo06kooooo000Eooooo`03o`000?oooooooooo09Sooooo
00?o0000ooooooooool0KOooool001Gooooo00?o0000ooooooooool0VOooool00ol0003ooooooooo
o`1/ooooo`005Oooool2o`0009[ooooo00?o0000ooooooooool0K?ooool001Gooooo00?o0000oooo
ooooool0V_ooool00ol0003oooooooooo`1[ooooo`005Oooool00ol0003oooooooooo`2Kooooo`03
o`000?oooooooooo06[ooooo000Eooooo`03o`000?oooooooooo09cooooo00?o0000ooooooooool0
JOooool001Gooooo00?o0000ooooooooool0W?ooool00ol0003oooooooooo`1Yooooo`000_ooool2
o`0000Cooooo00?o0000ooooooooool00_ooool3o`0000Gooooo00?o0000ooooooooool0WOooool0
0ol0003oooooooooo`1Xooooo`0000Goooooo`000?ooooooooooo`000007ooooo`05o`000?oooooo
ooooooooool000001?ooool00ol0003oooooooooo`2Nooooo`03o`000?oooooooooo06Oooooo0000
1Ooooooo0000oooooooooooo000000Oooooo00Go0000ooooooooooooooooo`000004ooooo`03o`00
0?oooooooooo09kooooo00?o0000ooooooooool0Ioooool00005ooooool0003oooooooooool00000
2?ooool3o`0000Gooooo0ol0002Oooooo`03o`000?oooooooooo06Kooooo00001Ooooooo0000oooo
oooooooo000000Oooooo00Go0000ooooooooooooooooo`000004ooooo`03o`000?oooooooooo0:3o
oooo00?o0000ooooooooool0IOooool00005ooooool0003oooooooooool000001oooool01Ol0003o
oooooooooooooooo000000Cooooo00?o0000ooooooooool0XOooool00ol0003oooooooooo`1Toooo
o`000_ooool2o`0000Wooooo0ol00005ooooo`03o`000?oooooooooo0:;ooooo00?o0000oooooooo
ool0Hoooool001Gooooo00?o0000ooooooooool0Xoooool00ol0003oooooooooo`1Rooooo`005Ooo
ool00ol0003oooooooooo`2Tooooo`03o`000?oooooooooo067ooooo000Eooooo`03o`000?oooooo
oooo0:Gooooo00?o0000ooooooooool0H?ooool001Gooooo00?o0000ooooooooool0Y_ooool00ol0
003oooooooooo`1Oooooo`005Oooool2o`000:Sooooo00?o0000ooooooooool0G_ooool001Gooooo
00?o0000ooooooooool0Z?ooool00ol0003oooooooooo`1Mooooo`005Oooool00ol0003ooooooooo
o`2Yooooo`03o`000?oooooooooo05cooooo000Eooooo`03o`000?oooooooooo0:[ooooo0_l0001L
ooooo`005Oooool00ol0003oooooooooo`2/ooooo`03o`000?oooooooooo05Wooooo000Eooooo`03
o`000?oooooooooo0:gooooo00?o0000ooooooooool0F?ooool001Gooooo00?o0000ooooooooool0
[_ooool00ol0003oooooooooo`1Gooooo`005Oooool00ol0003oooooooooo`2_ooooo`03o`000?oo
oooooooo05Kooooo000Eooooo`;o0000/Oooool00ol0003oooooooooo`1Eooooo`005Oooool00ol0
003oooooooooo`2aooooo`03o`000?oooooooooo05Cooooo000Eooooo`03o`000?oooooooooo0;;o
oooo0_l0001Dooooo`005Oooool00ol0003oooooooooo`2dooooo`;o0000D_ooool001Gooooo00?o
0000ooooooooool0]_ooool2o`00053ooooo000Eooooo`03o`000?oooooooooo0;Sooooo00?o0000
ooooooooool0COooool001Gooooo00?o0000ooooooooool0^Oooool2o`0004gooooo000Eooooo`03
o`000?oooooooooo0;_ooooo0ol0001:ooooo`005Oooool2o`000;oooooo0ol00017ooooo`005Ooo
ool00ol0003oooooooooo`31ooooo`?o0000A?ooool001Gooooo00?o0000ooooooooool0a?ooool3
o`00047ooooo000Eooooo`03o`000?oooooooooo0<Oooooo1?l0000mooooo`005Oooool00ol0003o
ooooooooo`3;ooooo`Co0000>Oooool000gooooo0ol00005ooooo`03o`000?oooooooooo0<oooooo
1Ol0000dooooo`003_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo0=Cooooo1ol0
000]ooooo`003_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo0=_ooooo6_l0000C
ooooo`003_ooool00ol0003oooooooooo`04ooooo`?o0000mOooool<o`0000Oooooo000>ooooo`03
o`000?oooooooooo0?oooooo4?ooool000gooooo0_l0003ooooooa;ooooo000>ooooo`03o`000?oo
oooooooo0?oooooo4?ooool00?oooooo8Oooool00001\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-2.49048, -0.0764114, \
0.115739, 0.00624232}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 0.0333333 0 0.618034 [
[.16667 -0.0125 -3 -9 ]
[.16667 -0.0125 3 0 ]
[.33333 -0.0125 -6 -9 ]
[.33333 -0.0125 6 0 ]
[.5 -0.0125 -6 -9 ]
[.5 -0.0125 6 0 ]
[.66667 -0.0125 -6 -9 ]
[.66667 -0.0125 6 0 ]
[.83333 -0.0125 -6 -9 ]
[.83333 -0.0125 6 0 ]
[1 -0.0125 -6 -9 ]
[1 -0.0125 6 0 ]
[-0.0125 .12361 -18 -4.5 ]
[-0.0125 .12361 0 4.5 ]
[-0.0125 .24721 -18 -4.5 ]
[-0.0125 .24721 0 4.5 ]
[-0.0125 .37082 -18 -4.5 ]
[-0.0125 .37082 0 4.5 ]
[-0.0125 .49443 -18 -4.5 ]
[-0.0125 .49443 0 4.5 ]
[-0.0125 .61803 -6 -4.5 ]
[-0.0125 .61803 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.16667 0 m
.16667 .00625 L
s
[(5)] .16667 -0.0125 0 1 Mshowa
.33333 0 m
.33333 .00625 L
s
[(10)] .33333 -0.0125 0 1 Mshowa
.5 0 m
.5 .00625 L
s
[(15)] .5 -0.0125 0 1 Mshowa
.66667 0 m
.66667 .00625 L
s
[(20)] .66667 -0.0125 0 1 Mshowa
.83333 0 m
.83333 .00625 L
s
[(25)] .83333 -0.0125 0 1 Mshowa
1 0 m
1 .00625 L
s
[(30)] 1 -0.0125 0 1 Mshowa
.125 Mabswid
.03333 0 m
.03333 .00375 L
s
.06667 0 m
.06667 .00375 L
s
.1 0 m
.1 .00375 L
s
.13333 0 m
.13333 .00375 L
s
.2 0 m
.2 .00375 L
s
.23333 0 m
.23333 .00375 L
s
.26667 0 m
.26667 .00375 L
s
.3 0 m
.3 .00375 L
s
.36667 0 m
.36667 .00375 L
s
.4 0 m
.4 .00375 L
s
.43333 0 m
.43333 .00375 L
s
.46667 0 m
.46667 .00375 L
s
.53333 0 m
.53333 .00375 L
s
.56667 0 m
.56667 .00375 L
s
.6 0 m
.6 .00375 L
s
.63333 0 m
.63333 .00375 L
s
.7 0 m
.7 .00375 L
s
.73333 0 m
.73333 .00375 L
s
.76667 0 m
.76667 .00375 L
s
.8 0 m
.8 .00375 L
s
.86667 0 m
.86667 .00375 L
s
.9 0 m
.9 .00375 L
s
.93333 0 m
.93333 .00375 L
s
.96667 0 m
.96667 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .12361 m
.00625 .12361 L
s
[(0.2)] -0.0125 .12361 1 0 Mshowa
0 .24721 m
.00625 .24721 L
s
[(0.4)] -0.0125 .24721 1 0 Mshowa
0 .37082 m
.00625 .37082 L
s
[(0.6)] -0.0125 .37082 1 0 Mshowa
0 .49443 m
.00625 .49443 L
s
[(0.8)] -0.0125 .49443 1 0 Mshowa
0 .61803 m
.00625 .61803 L
s
[(1)] -0.0125 .61803 1 0 Mshowa
.125 Mabswid
0 .0309 m
.00375 .0309 L
s
0 .0618 m
.00375 .0618 L
s
0 .09271 m
.00375 .09271 L
s
0 .15451 m
.00375 .15451 L
s
0 .18541 m
.00375 .18541 L
s
0 .21631 m
.00375 .21631 L
s
0 .27812 m
.00375 .27812 L
s
0 .30902 m
.00375 .30902 L
s
0 .33992 m
.00375 .33992 L
s
0 .40172 m
.00375 .40172 L
s
0 .43262 m
.00375 .43262 L
s
0 .46353 m
.00375 .46353 L
s
0 .52533 m
.00375 .52533 L
s
0 .55623 m
.00375 .55623 L
s
0 .58713 m
.00375 .58713 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.03333 .00661 m
.06667 .00784 L
.1 .00976 L
.13333 .01268 L
.16667 .01697 L
.2 .02306 L
.23333 .03151 L
.26667 .04301 L
.3 .05837 L
.33333 .07845 L
.36667 .10415 L
.4 .13635 L
.43333 .17575 L
.46667 .22284 L
.5 .27778 L
.53333 .34026 L
.56667 .39519 L
.6 .44228 L
.63333 .48168 L
.66667 .51388 L
.7 .53959 L
.73333 .55967 L
.76667 .57502 L
.8 .58653 L
.83333 .59498 L
.86667 .60106 L
.9 .60535 L
.93333 .60828 L
.96667 .6102 L
1 .61142 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[6]:=",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/B000`400?l00000o`00003ooooooolQ
ooooo`00?_ooool3o`0002Gooooo0ol00004ooooo`;o00008oooool3o`0000?ooooo0ol0000Qoooo
o`Go00000oooool2o`00027ooooo1Ol00002ooooo`?o00008_ooool3o`0000Cooooo0_l00004oooo
o`00?Oooool01Ol0003ooooooooooooooooo000002Gooooo00?o0000ooooooooool00_ooool01?l0
003oooooooooool0000Sooooo`05o`000?ooooooooooooooool000000oooool00ol0003ooooooooo
o`0Oooooo`04o`000?ooooooooooo`0000;ooooo00Co0000oooooooooooo00008Oooool01_l0003o
ooooooooool0003oooooo`0000?ooooo00?o0000ooooooooool07_ooool01Ol0003ooooooooooooo
oooo000000;ooooo00Co0000oooooooooooo00000oooool0047ooooo00?o0000ooooooooool08ooo
ool00ol0003oooooooooo`02ooooo`04o`000?ooooooooooo`0002?ooooo00?o0000ooooooooool0
1Oooool00ol0003oooooooooo`0Pooooo`03o`000?oooooooooo00;ooooo00Co0000oooooooooooo
00008_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo02;ooooo00Co0000oooooooo
oooo00000_ooool00ol0003oooooooooo`01ooooo`00@Oooool00ol0003oooooooooo`0Sooooo`03
o`000?oooooooooo00;ooooo00Co0000oooooooooooo00008oooool00ol0003oooooooooo`05oooo
o`03o`000?oooooooooo027ooooo00Go0000ooooooooooooooooo`000002ooooo`03o`000?oooooo
oooo027ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`0Pooooo`;o00000oooool0
1?l0003oooooooooool00003ooooo`00?Oooool4o`0002Kooooo00?o0000ooooooooool00_ooool0
1?l0003oooooooooool0000Sooooo`04o`000?ooooooooooooooo`Co00008Oooool01Ol0003ooooo
oooooooooooo000000;ooooo00Co0000oooooooooooo00008?ooool01_l0003ooooooooooooooooo
0000ooooo`Co00009Oooool01?l0003oooooooooool00002ooooo`03o`000?oooooooooo007ooooo
000mooooo`03o`000?oooooooooo02Kooooo0_l00004ooooo`04o`000?ooooooooooo`0002;ooooo
0_l00003ooooo`03o`000?oooooooooo02;ooooo00Go0000ooooooooooooooooo`000002ooooo`04
o`000?ooooooooooo`00023ooooo00Oo0000ooooooooooooooooo`000?oooooo000002Cooooo00Go
0000ooooooooooooooooo`000002ooooo`04o`000?ooooooooooo`0000?ooooo000mooooo`Go0000
9Oooool00ol0003oooooooooo`03ooooo`;o00009?ooool01?l0003oooooooooooooool5o`00027o
oooo0ol00004ooooo`;o00008_ooool3o`0000;ooooo1Ol0000Qooooo`?o00001?ooool2o`0000Co
oooo003oooooob7ooooo003oooooob7ooooo003oooooob7ooooo003oooooob7ooooo000Eoooooooo
00001Ol00007ooooo`005Oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Gooooo
00?o0000ooooooooool01_ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Gooooo
00?o0000ooooooooool01_ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Gooooo
00?o0000ooooooooool01_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Kooooo
00?o0000ooooooooool01_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Kooooo
00?o0000ooooooooool01_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Kooooo
00?o0000ooooooooool01_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Kooooo
00?o0000ooooooooool01Oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Kooooo
00?o0000ooooooooool01Oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Kooooo
00?o0000ooooooooool01Oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Kooooo
00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`005Oooool00ol0003ooooooooo
o`06oooooaOo0000joooool001Gooooo00?o0000ooooooooool07Oooool8o`000>?ooooo000Eoooo
o`03o`000?oooooooooo02Gooooo1_l0003Mooooo`005Oooool00ol0003oooooooooo`0[ooooo`Go
0000f?ooool001Gooooo00?o0000ooooooooool0<?ooool4o`000=Cooooo000Eooooo`03o`000?oo
oooooooo03Cooooo1Ol0003?ooooo`005Oooool2o`0003[ooooo0ol0003<ooooo`005Oooool00ol0
003oooooooooo`0looooo`?o0000bOooool001Gooooo00?o0000ooooooooool0?oooool3o`000<Ko
oooo000Eooooo`03o`000?oooooooooo04;ooooo0_l00034ooooo`005Oooool00ol0003ooooooooo
o`14ooooo`;o0000`_ooool001Gooooo00?o0000ooooooooool0A_ooool3o`000;oooooo000Eoooo
o`03o`000?oooooooooo04Wooooo0_l0002mooooo`005Oooool00ol0003oooooooooo`1;ooooo`;o
0000^oooool001Gooooo0_l0001>ooooo`03o`000?oooooooooo0;Sooooo000Eooooo`03o`000?oo
oooooooo04kooooo0_l0002hooooo`005Oooool00ol0003oooooooooo`1@ooooo`;o0000]_ooool0
01Gooooo00?o0000ooooooooool0D_ooool00ol0003oooooooooo`2cooooo`005Oooool00ol0003o
ooooooooo`1Cooooo`;o0000/oooool001Gooooo00?o0000ooooooooool0EOooool00ol0003ooooo
ooooo`2`ooooo`005Oooool00ol0003oooooooooo`1Fooooo`03o`000?oooooooooo0:oooooo000E
ooooo`03o`000?oooooooooo05Oooooo0_l0002_ooooo`005Oooool2o`0005[ooooo00?o0000oooo
ooooool0[?ooool001Gooooo00?o0000ooooooooool0F_ooool00ol0003oooooooooo`2[ooooo`00
5Oooool00ol0003oooooooooo`1Kooooo`03o`000?oooooooooo0:[ooooo000Eooooo`03o`000?oo
oooooooo05cooooo0_l0002Zooooo`005Oooool00ol0003oooooooooo`1Nooooo`03o`000?oooooo
oooo0:Oooooo0002ooooo`;o00001?ooool01?l0003oooooooooooooool5o`0000Cooooo00?o0000
ooooooooool0Goooool00ol0003oooooooooo`2Vooooo`0000Goooooo`000?ooooooooooo`000008
ooooo`04o`000?ooooooooooo`0000Cooooo00?o0000ooooooooool0H?ooool00ol0003ooooooooo
o`2Uooooo`0000Goooooo`000?ooooooooooo`000009ooooo`03o`000?oooooooooo00Cooooo00?o
0000ooooooooool0HOooool00ol0003oooooooooo`2Tooooo`0000Goooooo`000?ooooooooooo`00
000:ooooo`03o`000?oooooooooo00?ooooo0ol0001Rooooo`03o`000?oooooooooo0:?ooooo0000
1Ooooooo0000oooooooooooo000000Oooooo00Go0000ooooooooooooooooo`000004ooooo`03o`00
0?oooooooooo06?ooooo00?o0000ooooooooool0X_ooool00005ooooool0003oooooooooool00000
1oooool01Ol0003ooooooooooooooooo000000Cooooo00?o0000ooooooooool0I?ooool00ol0003o
ooooooooo`2Qooooo`000_ooool2o`0000Wooooo0ol00005ooooo`03o`000?oooooooooo06Gooooo
00?o0000ooooooooool0X?ooool001Gooooo00?o0000ooooooooool0IOooool00ol0003ooooooooo
o`2Pooooo`005Oooool00ol0003oooooooooo`1Vooooo`03o`000?oooooooooo09oooooo000Eoooo
o`03o`000?oooooooooo06Oooooo00?o0000ooooooooool0W_ooool001Gooooo00?o0000oooooooo
ool0J?ooool00ol0003oooooooooo`2Mooooo`005Oooool2o`0006[ooooo00?o0000ooooooooool0
W?ooool001Gooooo00?o0000ooooooooool0JOooool00ol0003oooooooooo`2Looooo`005Oooool0
0ol0003oooooooooo`1Zooooo`03o`000?oooooooooo09_ooooo000Eooooo`03o`000?oooooooooo
06_ooooo00?o0000ooooooooool0V_ooool001Gooooo00?o0000ooooooooool0K?ooool00ol0003o
ooooooooo`2Iooooo`005Oooool00ol0003oooooooooo`1]ooooo`03o`000?oooooooooo09Sooooo
000Eooooo`03o`000?oooooooooo06gooooo00?o0000ooooooooool0V?ooool001Gooooo00?o0000
ooooooooool0K_ooool00ol0003oooooooooo`2Gooooo`005Oooool2o`00073ooooo00?o0000oooo
ooooool0U_ooool001Gooooo00?o0000ooooooooool0Koooool00ol0003oooooooooo`2Fooooo`00
5Oooool00ol0003oooooooooo`1`ooooo`03o`000?oooooooooo09Gooooo000Eooooo`03o`000?oo
oooooooo077ooooo00?o0000ooooooooool0U?ooool001Gooooo00?o0000ooooooooool0L_ooool0
0ol0003oooooooooo`2Cooooo`005Oooool00ol0003oooooooooo`1booooo`03o`000?oooooooooo
09?ooooo000Eooooo`03o`000?oooooooooo07?ooooo00?o0000ooooooooool0T_ooool001Gooooo
00?o0000ooooooooool0M?ooool00ol0003oooooooooo`2Aooooo`005Oooool2o`0007Gooooo00?o
0000ooooooooool0TOooool001Gooooo00?o0000ooooooooool0MOooool00ol0003oooooooooo`2@
ooooo`005Oooool00ol0003oooooooooo`1fooooo`03o`000?oooooooooo08oooooo000Eooooo`03
o`000?oooooooooo07Kooooo00?o0000ooooooooool0Soooool001Gooooo00?o0000ooooooooool0
Moooool00ol0003oooooooooo`2>ooooo`000_ooool2o`0000Cooooo00?o0000ooooooooool00ooo
ool3o`0000Cooooo00?o0000ooooooooool0N?ooool00ol0003oooooooooo`2=ooooo`0000Gooooo
o`000?ooooooooooo`00000:ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0N?oo
ool00ol0003oooooooooo`2=ooooo`0000Goooooo`000?ooooooooooo`000007ooooo`Go00001?oo
ool00ol0003oooooooooo`1iooooo`03o`000?oooooooooo08cooooo00001Ooooooo0000oooooooo
oooo000000Oooooo00Co0000oooooooooooo00001Oooool3o`0007[ooooo00?o0000ooooooooool0
Roooool00005ooooool0003oooooooooool000002?ooool00ol0003oooooo`000005ooooo`03o`00
0?oooooooooo07[ooooo00?o0000ooooooooool0Roooool00005ooooool0003oooooooooool00000
2Oooool2o`0000Gooooo00?o0000ooooooooool0Noooool00ol0003oooooooooo`2:ooooo`000_oo
ool2o`0000_ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`1kooooo`03o`000?oo
oooooooo08[ooooo000Eooooo`03o`000?oooooooooo07cooooo00?o0000ooooooooool0ROooool0
01Gooooo00?o0000ooooooooool0OOooool00ol0003oooooooooo`28ooooo`005Oooool00ol0003o
ooooooooo`1mooooo`03o`000?oooooooooo08Sooooo000Eooooo`03o`000?oooooooooo07kooooo
00?o0000ooooooooool0Qoooool001Gooooo0_l00020ooooo`03o`000?oooooooooo08Kooooo000E
ooooo`03o`000?oooooooooo07oooooo00?o0000ooooooooool0Q_ooool001Gooooo00?o0000oooo
ooooool0P?ooool00ol0003oooooooooo`25ooooo`005Oooool00ol0003oooooooooo`20ooooo`03
o`000?oooooooooo08Gooooo000Eooooo`03o`000?oooooooooo087ooooo00?o0000ooooooooool0
Q?ooool001Gooooo00?o0000ooooooooool0POooool00ol0003oooooooooo`24ooooo`005Oooool0
0ol0003oooooooooo`22ooooo`03o`000?oooooooooo08?ooooo000Eooooo`03o`000?oooooooooo
08;ooooo00?o0000ooooooooool0Poooool001Gooooo0_l00024ooooo`03o`000?oooooooooo08;o
oooo000Eooooo`03o`000?oooooooooo08?ooooo00?o0000ooooooooool0P_ooool001Gooooo00?o
0000ooooooooool0Q?ooool00ol0003oooooooooo`21ooooo`005Oooool00ol0003oooooooooo`24
ooooo`03o`000?oooooooooo087ooooo000Eooooo`03o`000?oooooooooo08Gooooo00?o0000oooo
ooooool0P?ooool001Gooooo00?o0000ooooooooool0QOooool00ol0003oooooooooo`20ooooo`00
5Oooool00ol0003oooooooooo`26ooooo`03o`000?oooooooooo07oooooo000Eooooo`03o`000?oo
oooooooo08Kooooo00?o0000ooooooooool0Ooooool001Gooooo0_l00028ooooo`03o`000?oooooo
oooo07kooooo000Eooooo`03o`000?oooooooooo08Oooooo00?o0000ooooooooool0O_ooool001Go
oooo00?o0000ooooooooool0R?ooool00ol0003oooooooooo`1mooooo`005Oooool00ol0003ooooo
ooooo`29ooooo`03o`000?oooooooooo07cooooo000Eooooo`03o`000?oooooooooo08Wooooo00?o
0000ooooooooool0O?ooool000;ooooo0_l00004ooooo`03o`000?oooooooooo00;ooooo0ol00005
ooooo`03o`000?oooooooooo08[ooooo00?o0000ooooooooool0Noooool00005ooooool0003ooooo
ooooool000001oooool01Ol0003ooooooooooooooooo000000Cooooo00?o0000ooooooooool0Rooo
ool00ol0003oooooooooo`1jooooo`0000Goooooo`000?ooooooooooo`000007ooooo`05o`000?oo
ooooooooooooool000001?ooool00ol0003oooooooooo`2;ooooo`03o`000?oooooooooo07[ooooo
00001Ooooooo0000oooooooooooo000000Oooooo1?l00005ooooo`?o0000S?ooool00ol0003ooooo
ooooo`1iooooo`0000Goooooo`000?ooooooooooo`000007ooooo`03o`000?oooooooooo00Kooooo
00?o0000ooooooooool0S?ooool00ol0003oooooooooo`1iooooo`0000Goooooo`000?oooooooooo
o`000008ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0SOooool00ol0003ooooo
ooooo`1hooooo`000_ooool2o`0000[ooooo0_l00005ooooo`03o`000?oooooooooo08kooooo00?o
0000ooooooooool0Moooool001Gooooo00?o0000ooooooooool0S_ooool00ol0003oooooooooo`1g
ooooo`005Oooool00ol0003oooooooooo`2?ooooo`03o`000?oooooooooo07Kooooo000Eooooo`03
o`000?oooooooooo093ooooo00?o0000ooooooooool0MOooool001Gooooo00?o0000ooooooooool0
T?ooool00ol0003oooooooooo`1eooooo`005Oooool2o`0009;ooooo00?o0000ooooooooool0M?oo
ool001Gooooo00?o0000ooooooooool0T_ooool00ol0003oooooooooo`1cooooo`005Oooool00ol0
003oooooooooo`2Cooooo`03o`000?oooooooooo07;ooooo000Eooooo`03o`000?oooooooooo09?o
oooo00?o0000ooooooooool0L_ooool001Gooooo00?o0000ooooooooool0U?ooool00ol0003ooooo
ooooo`1aooooo`005Oooool00ol0003oooooooooo`2Eooooo`03o`000?oooooooooo073ooooo000E
ooooo`03o`000?oooooooooo09Kooooo00?o0000ooooooooool0Koooool001Gooooo00?o0000oooo
ooooool0U_ooool00ol0003oooooooooo`1_ooooo`005Oooool2o`0009Sooooo00?o0000oooooooo
ool0K_ooool001Gooooo00?o0000ooooooooool0V?ooool00ol0003oooooooooo`1]ooooo`005Ooo
ool00ol0003oooooooooo`2Iooooo`03o`000?oooooooooo06cooooo000Eooooo`03o`000?oooooo
oooo09Wooooo00?o0000ooooooooool0K?ooool001Gooooo00?o0000ooooooooool0V_ooool00ol0
003oooooooooo`1[ooooo`005Oooool00ol0003oooooooooo`2Kooooo`03o`000?oooooooooo06[o
oooo000Eooooo`03o`000?oooooooooo09cooooo00?o0000ooooooooool0JOooool001Gooooo00?o
0000ooooooooool0W?ooool00ol0003oooooooooo`1Yooooo`005Oooool2o`0009kooooo00?o0000
ooooooooool0J?ooool001Gooooo00?o0000ooooooooool0W_ooool00ol0003oooooooooo`1Woooo
o`005Oooool00ol0003oooooooooo`2Nooooo`03o`000?oooooooooo06Oooooo000Eooooo`03o`00
0?oooooooooo09oooooo00?o0000ooooooooool0I_ooool001Gooooo00?o0000ooooooooool0X?oo
ool00ol0003oooooooooo`1Uooooo`000_ooool2o`0000Cooooo00?o0000ooooooooool00_ooool3
o`0000Gooooo00?o0000ooooooooool0XOooool2o`0006Gooooo00001Ooooooo0000oooooooooooo
000000Oooooo00Go0000ooooooooooooooooo`000004ooooo`03o`000?oooooooooo0:?ooooo00?o
0000ooooooooool0H_ooool00005ooooool0003oooooooooool000001oooool01Ol0003ooooooooo
oooooooo000000Cooooo00?o0000ooooooooool0Y?ooool00ol0003oooooooooo`1Qooooo`0000Go
ooooo`000?ooooooooooo`000008ooooo`?o00001Oooool3o`000:Gooooo00?o0000ooooooooool0
H?ooool00005ooooool0003oooooooooool000001oooool01Ol0003ooooooooooooooooo000000Co
oooo00?o0000ooooooooool0Y_ooool00ol0003oooooooooo`1Oooooo`0000Goooooo`000?oooooo
ooooo`000007ooooo`05o`000?ooooooooooooooool000001?ooool00ol0003oooooooooo`2Woooo
o`03o`000?oooooooooo05kooooo0002ooooo`;o00002Oooool3o`0000Gooooo00?o0000oooooooo
ool0Z?ooool00ol0003oooooooooo`1Mooooo`005Oooool00ol0003oooooooooo`2Yooooo`03o`00
0?oooooooooo05cooooo000Eooooo`03o`000?oooooooooo0:[ooooo0_l0001Looooo`005Oooool0
0ol0003oooooooooo`2/ooooo`03o`000?oooooooooo05Wooooo000Eooooo`03o`000?oooooooooo
0:gooooo00?o0000ooooooooool0F?ooool001Gooooo0_l0002_ooooo`03o`000?oooooooooo05Oo
oooo000Eooooo`03o`000?oooooooooo0:oooooo00?o0000ooooooooool0E_ooool001Gooooo00?o
0000ooooooooool0/?ooool00ol0003oooooooooo`1Eooooo`005Oooool00ol0003oooooooooo`2a
ooooo`03o`000?oooooooooo05Cooooo000Eooooo`03o`000?oooooooooo0;;ooooo0_l0001Doooo
o`005Oooool00ol0003oooooooooo`2dooooo`;o0000D_ooool001Gooooo00?o0000ooooooooool0
]_ooool2o`00053ooooo000Eooooo`03o`000?oooooooooo0;Sooooo00?o0000ooooooooool0COoo
ool001Gooooo0_l0002jooooo`;o0000COooool001Gooooo00?o0000ooooooooool0^oooool2o`00
04_ooooo000Eooooo`03o`000?oooooooooo0;gooooo0_l00019ooooo`005Oooool00ol0003ooooo
ooooo`2oooooo`?o0000A_ooool001Gooooo00?o0000ooooooooool0`_ooool2o`0004Cooooo000E
ooooo`03o`000?oooooooooo0<Cooooo0_l00012ooooo`005Oooool00ol0003oooooooooo`36oooo
o`?o0000?oooool001Gooooo00?o0000ooooooooool0bOooool3o`0003cooooo000Eooooo`;o0000
cOooool3o`0003Wooooo000Eooooo`03o`000?oooooooooo0<oooooo1Ol0000dooooo`005Oooool0
0ol0003oooooooooo`3Dooooo`Co0000<?ooool001Gooooo00?o0000ooooooooool0f?ooool5o`00
02_ooooo000Eooooo`03o`000?oooooooooo0=gooooo1_l0000Uooooo`003Oooool3o`0000Gooooo
00?o0000ooooooooool0hooooolBo`0001?ooooo000>ooooo`03o`000?oooooooooo00Cooooo00?o
0000ooooooooool0mOooool<o`0000Oooooo000>ooooo`03o`000?oooooooooo00Cooooo00?o0000
ooooooooool0ooooool9ooooo`003_ooool00ol0003oooooooooo`04ooooo`?o0000ooooool9oooo
o`003_ooool00ol0003oooooooooo`3ooooooa3ooooo000=ooooo`;o0000oooooolBooooo`003_oo
ool00ol0003oooooooooo`3ooooooa3ooooo003oooooob7ooooo0000\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-2.49048, -0.0764114, \
0.115739, 0.00624232}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 0.0333333 0 0.618034 [
[.16667 -0.0125 -3 -9 ]
[.16667 -0.0125 3 0 ]
[.33333 -0.0125 -6 -9 ]
[.33333 -0.0125 6 0 ]
[.5 -0.0125 -6 -9 ]
[.5 -0.0125 6 0 ]
[.66667 -0.0125 -6 -9 ]
[.66667 -0.0125 6 0 ]
[.83333 -0.0125 -6 -9 ]
[.83333 -0.0125 6 0 ]
[1 -0.0125 -6 -9 ]
[1 -0.0125 6 0 ]
[-0.0125 .12361 -18 -4.5 ]
[-0.0125 .12361 0 4.5 ]
[-0.0125 .24721 -18 -4.5 ]
[-0.0125 .24721 0 4.5 ]
[-0.0125 .37082 -18 -4.5 ]
[-0.0125 .37082 0 4.5 ]
[-0.0125 .49443 -18 -4.5 ]
[-0.0125 .49443 0 4.5 ]
[-0.0125 .61803 -6 -4.5 ]
[-0.0125 .61803 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.16667 0 m
.16667 .00625 L
s
[(5)] .16667 -0.0125 0 1 Mshowa
.33333 0 m
.33333 .00625 L
s
[(10)] .33333 -0.0125 0 1 Mshowa
.5 0 m
.5 .00625 L
s
[(15)] .5 -0.0125 0 1 Mshowa
.66667 0 m
.66667 .00625 L
s
[(20)] .66667 -0.0125 0 1 Mshowa
.83333 0 m
.83333 .00625 L
s
[(25)] .83333 -0.0125 0 1 Mshowa
1 0 m
1 .00625 L
s
[(30)] 1 -0.0125 0 1 Mshowa
.125 Mabswid
.03333 0 m
.03333 .00375 L
s
.06667 0 m
.06667 .00375 L
s
.1 0 m
.1 .00375 L
s
.13333 0 m
.13333 .00375 L
s
.2 0 m
.2 .00375 L
s
.23333 0 m
.23333 .00375 L
s
.26667 0 m
.26667 .00375 L
s
.3 0 m
.3 .00375 L
s
.36667 0 m
.36667 .00375 L
s
.4 0 m
.4 .00375 L
s
.43333 0 m
.43333 .00375 L
s
.46667 0 m
.46667 .00375 L
s
.53333 0 m
.53333 .00375 L
s
.56667 0 m
.56667 .00375 L
s
.6 0 m
.6 .00375 L
s
.63333 0 m
.63333 .00375 L
s
.7 0 m
.7 .00375 L
s
.73333 0 m
.73333 .00375 L
s
.76667 0 m
.76667 .00375 L
s
.8 0 m
.8 .00375 L
s
.86667 0 m
.86667 .00375 L
s
.9 0 m
.9 .00375 L
s
.93333 0 m
.93333 .00375 L
s
.96667 0 m
.96667 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .12361 m
.00625 .12361 L
s
[(0.2)] -0.0125 .12361 1 0 Mshowa
0 .24721 m
.00625 .24721 L
s
[(0.4)] -0.0125 .24721 1 0 Mshowa
0 .37082 m
.00625 .37082 L
s
[(0.6)] -0.0125 .37082 1 0 Mshowa
0 .49443 m
.00625 .49443 L
s
[(0.8)] -0.0125 .49443 1 0 Mshowa
0 .61803 m
.00625 .61803 L
s
[(1)] -0.0125 .61803 1 0 Mshowa
.125 Mabswid
0 .0309 m
.00375 .0309 L
s
0 .0618 m
.00375 .0618 L
s
0 .09271 m
.00375 .09271 L
s
0 .15451 m
.00375 .15451 L
s
0 .18541 m
.00375 .18541 L
s
0 .21631 m
.00375 .21631 L
s
0 .27812 m
.00375 .27812 L
s
0 .30902 m
.00375 .30902 L
s
0 .33992 m
.00375 .33992 L
s
0 .40172 m
.00375 .40172 L
s
0 .43262 m
.00375 .43262 L
s
0 .46353 m
.00375 .46353 L
s
0 .52533 m
.00375 .52533 L
s
0 .55623 m
.00375 .55623 L
s
0 .58713 m
.00375 .58713 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.03333 .01617 m
.06667 .01825 L
.1 .02106 L
.13333 .02508 L
.16667 .03062 L
.2 .03804 L
.23333 .04777 L
.26667 .06034 L
.3 .07633 L
.33333 .09639 L
.36667 .12119 L
.4 .15143 L
.43333 .18774 L
.46667 .23066 L
.5 .28053 L
.53333 .3375 L
.56667 .38738 L
.6 .43029 L
.63333 .4666 L
.66667 .49684 L
.7 .52165 L
.73333 .5417 L
.76667 .55769 L
.8 .57026 L
.83333 .58 L
.86667 .58742 L
.9 .59295 L
.93333 .59697 L
.96667 .59978 L
1 .60186 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[6]:=",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/B000`400?l00000o`00003ooooooolQ
ooooo`00?_ooool3o`0002Gooooo0ol00004ooooo`;o00008oooool3o`0000?ooooo0ol0000Qoooo
o`Go00000oooool2o`00027ooooo1Ol00002ooooo`?o00008_ooool3o`0000Cooooo0_l00004oooo
o`00?Oooool01Ol0003ooooooooooooooooo000002Gooooo00?o0000ooooooooool00_ooool01?l0
003oooooooooool0000Sooooo`05o`000?ooooooooooooooool000000oooool00ol0003ooooooooo
o`0Oooooo`04o`000?ooooooooooo`0000;ooooo00Co0000oooooooooooo00008Oooool01_l0003o
ooooooooool0003oooooo`0000?ooooo00?o0000ooooooooool07_ooool01Ol0003ooooooooooooo
oooo000000;ooooo00Co0000oooooooooooo00000oooool0047ooooo00?o0000ooooooooool08ooo
ool00ol0003oooooooooo`02ooooo`04o`000?ooooooooooo`0002?ooooo00?o0000ooooooooool0
1Oooool00ol0003oooooooooo`0Pooooo`03o`000?oooooooooo00;ooooo00Co0000oooooooooooo
00008_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo02;ooooo00Co0000oooooooo
oooo00000_ooool00ol0003oooooooooo`01ooooo`00@Oooool00ol0003oooooooooo`0Sooooo`03
o`000?oooooooooo00;ooooo00Co0000oooooooooooo00008oooool00ol0003oooooooooo`05oooo
o`03o`000?oooooooooo027ooooo00Go0000ooooooooooooooooo`000002ooooo`03o`000?oooooo
oooo027ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`0Pooooo`;o00000oooool0
1?l0003oooooooooool00003ooooo`00?Oooool4o`0002Kooooo00?o0000ooooooooool00_ooool0
1?l0003oooooooooool0000Sooooo`04o`000?ooooooooooooooo`Co00008Oooool01Ol0003ooooo
oooooooooooo000000;ooooo00Co0000oooooooooooo00008?ooool01_l0003ooooooooooooooooo
0000ooooo`Co00009Oooool01?l0003oooooooooool00002ooooo`03o`000?oooooooooo007ooooo
000mooooo`03o`000?oooooooooo02Kooooo0_l00004ooooo`04o`000?ooooooooooo`0002;ooooo
0_l00003ooooo`03o`000?oooooooooo02;ooooo00Go0000ooooooooooooooooo`000002ooooo`04
o`000?ooooooooooo`00023ooooo00Oo0000ooooooooooooooooo`000?oooooo000002Cooooo00Go
0000ooooooooooooooooo`000002ooooo`04o`000?ooooooooooo`0000?ooooo000mooooo`Go0000
9Oooool00ol0003oooooooooo`03ooooo`;o00009?ooool01?l0003oooooooooooooool5o`00027o
oooo0ol00004ooooo`;o00008_ooool3o`0000;ooooo1Ol0000Qooooo`?o00001?ooool2o`0000Co
oooo003oooooob7ooooo003oooooob7ooooo003oooooob7ooooo003oooooob7ooooo000Eoooooooo
00001Ol00007ooooo`005Oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Gooooo
00?o0000ooooooooool01_ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Gooooo
00?o0000ooooooooool01_ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Gooooo
00?o0000ooooooooool01_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Kooooo
00?o0000ooooooooool01_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Kooooo
00?o0000ooooooooool01_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Kooooo
00?o0000ooooooooool01_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Kooooo
00?o0000ooooooooool01Oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Kooooo
00?o0000ooooooooool01Oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Kooooo
00?o0000ooooooooool01Oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Kooooo
00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`005Oooool00ol0003ooooooooo
o`3oooooo`Wooooo000Eooooo`03o`000?oooooooooo0?oooooo2Oooool001Gooooo00?o0000oooo
ooooool01_ooool5o`000?gooooo000Eooooo`03o`000?oooooooooo00_ooooo4_l0003[ooooo`00
5Oooool00ol0003oooooooooo`0Mooooo`Ko0000iOooool001Gooooo00?o0000ooooooooool08ooo
ool4o`000>7ooooo000Eooooo`;o0000:?ooool4o`000=gooooo000Eooooo`03o`000?oooooooooo
02_ooooo1Ol0003Hooooo`005Oooool00ol0003oooooooooo`0`ooooo`Co0000e?ooool001Gooooo
00?o0000ooooooooool0=?ooool5o`000<oooooo000Eooooo`03o`000?oooooooooo03Wooooo0ol0
003<ooooo`005Oooool00ol0003oooooooooo`0looooo`?o0000bOooool001Gooooo00?o0000oooo
ooooool0?oooool3o`000<Kooooo000Eooooo`03o`000?oooooooooo04;ooooo0_l00034ooooo`00
5Oooool2o`0004Gooooo0_l00032ooooo`005Oooool00ol0003oooooooooo`16ooooo`;o0000`?oo
ool001Gooooo00?o0000ooooooooool0B?ooool00ol0003oooooooooo`2mooooo`005Oooool00ol0
003oooooooooo`19ooooo`;o0000_Oooool001Gooooo00?o0000ooooooooool0Boooool2o`000;_o
oooo000Eooooo`03o`000?oooooooooo04gooooo00?o0000ooooooooool0^?ooool001Gooooo00?o
0000ooooooooool0C_ooool2o`000;Sooooo000Eooooo`03o`000?oooooooooo053ooooo0_l0002f
ooooo`005Oooool2o`0005?ooooo00?o0000ooooooooool0/oooool001Gooooo00?o0000oooooooo
ool0Doooool2o`000;?ooooo000Eooooo`03o`000?oooooooooo05Gooooo00?o0000ooooooooool0
/?ooool001Gooooo00?o0000ooooooooool0E_ooool2o`000;3ooooo000Eooooo`03o`000?oooooo
oooo05Sooooo00?o0000ooooooooool0[Oooool000;ooooo0_l00004ooooo`04o`000?oooooooooo
ooooo`Go00001?ooool00ol0003oooooooooo`1Iooooo`;o0000[Oooool00005ooooool0003ooooo
ooooool000002?ooool01?l0003oooooooooool00004ooooo`03o`000?oooooooooo05_ooooo00?o
0000ooooooooool0Z_ooool00005ooooool0003oooooooooool000002Oooool00ol0003ooooooooo
o`04ooooo`03o`000?oooooooooo05cooooo0_l0002Zooooo`0000Goooooo`000?ooooooooooo`00
000:ooooo`03o`000?oooooooooo00?ooooo0ol0001Nooooo`03o`000?oooooooooo0:Oooooo0000
1Ooooooo0000oooooooooooo000000Oooooo00Go0000ooooooooooooooooo`000004ooooo`03o`00
0?oooooooooo05oooooo00?o0000ooooooooool0Y_ooool00005ooooool0003oooooooooool00000
1oooool01Ol0003ooooooooooooooooo000000Cooooo00?o0000ooooooooool0H?ooool00ol0003o
ooooooooo`2Uooooo`000_ooool2o`0000Wooooo0ol00005ooooo`03o`000?oooooooooo067ooooo
00?o0000ooooooooool0Y?ooool001Gooooo00?o0000ooooooooool0H_ooool00ol0003ooooooooo
o`2Sooooo`005Oooool00ol0003oooooooooo`1Sooooo`03o`000?oooooooooo0:;ooooo000Eoooo
o`03o`000?oooooooooo06Cooooo00?o0000ooooooooool0XOooool001Gooooo00?o0000oooooooo
ool0IOooool00ol0003oooooooooo`2Pooooo`005Oooool2o`0006Kooooo00?o0000ooooooooool0
X?ooool001Gooooo00?o0000ooooooooool0I_ooool00ol0003oooooooooo`2Oooooo`005Oooool0
0ol0003oooooooooo`1Wooooo`03o`000?oooooooooo09kooooo000Eooooo`03o`000?oooooooooo
06Sooooo00?o0000ooooooooool0WOooool001Gooooo00?o0000ooooooooool0JOooool00ol0003o
ooooooooo`2Looooo`005Oooool00ol0003oooooooooo`1Zooooo`03o`000?oooooooooo09_ooooo
000Eooooo`03o`000?oooooooooo06_ooooo00?o0000ooooooooool0V_ooool001Gooooo00?o0000
ooooooooool0K?ooool00ol0003oooooooooo`2Iooooo`005Oooool2o`0006kooooo00?o0000oooo
ooooool0V?ooool001Gooooo00?o0000ooooooooool0KOooool00ol0003oooooooooo`2Hooooo`00
5Oooool00ol0003oooooooooo`1^ooooo`03o`000?oooooooooo09Oooooo000Eooooo`03o`000?oo
oooooooo06oooooo00?o0000ooooooooool0U_ooool001Gooooo00?o0000ooooooooool0L?ooool0
0ol0003oooooooooo`2Eooooo`005Oooool00ol0003oooooooooo`1`ooooo`03o`000?oooooooooo
09Gooooo000Eooooo`03o`000?oooooooooo077ooooo00?o0000ooooooooool0U?ooool001Gooooo
00?o0000ooooooooool0L_ooool00ol0003oooooooooo`2Cooooo`005Oooool2o`0007Cooooo00?o
0000ooooooooool0T_ooool001Gooooo00?o0000ooooooooool0Loooool00ol0003oooooooooo`2B
ooooo`005Oooool00ol0003oooooooooo`1dooooo`03o`000?oooooooooo097ooooo000Eooooo`03
o`000?oooooooooo07Gooooo00?o0000ooooooooool0T?ooool001Gooooo00?o0000ooooooooool0
M_ooool00ol0003oooooooooo`2?ooooo`000_ooool2o`0000Cooooo00?o0000ooooooooool00ooo
ool3o`0000Cooooo00?o0000ooooooooool0M_ooool00ol0003oooooooooo`2?ooooo`0000Gooooo
o`000?ooooooooooo`00000:ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0Mooo
ool00ol0003oooooooooo`2>ooooo`0000Goooooo`000?ooooooooooo`000007ooooo`Go00001?oo
ool00ol0003oooooooooo`1hooooo`03o`000?oooooooooo08gooooo00001Ooooooo0000oooooooo
oooo000000Oooooo00Co0000oooooooooooo00001Oooool3o`0007Sooooo00?o0000ooooooooool0
SOooool00005ooooool0003oooooooooool000002?ooool00ol0003oooooo`000005ooooo`03o`00
0?oooooooooo07Wooooo00?o0000ooooooooool0S?ooool00005ooooool0003oooooooooool00000
2Oooool2o`0000Gooooo00?o0000ooooooooool0N_ooool00ol0003oooooooooo`2;ooooo`000_oo
ool2o`0000_ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`1kooooo`03o`000?oo
oooooooo08[ooooo000Eooooo`03o`000?oooooooooo07_ooooo00?o0000ooooooooool0R_ooool0
01Gooooo00?o0000ooooooooool0O?ooool00ol0003oooooooooo`29ooooo`005Oooool00ol0003o
ooooooooo`1mooooo`03o`000?oooooooooo08Sooooo000Eooooo`03o`000?oooooooooo07gooooo
00?o0000ooooooooool0R?ooool001Gooooo0_l0001oooooo`03o`000?oooooooooo08Oooooo000E
ooooo`03o`000?oooooooooo07oooooo00?o0000ooooooooool0Q_ooool001Gooooo00?o0000oooo
ooooool0Ooooool00ol0003oooooooooo`26ooooo`005Oooool00ol0003oooooooooo`20ooooo`03
o`000?oooooooooo08Gooooo000Eooooo`03o`000?oooooooooo083ooooo00?o0000ooooooooool0
QOooool001Gooooo00?o0000ooooooooool0POooool00ol0003oooooooooo`24ooooo`005Oooool0
0ol0003oooooooooo`22ooooo`03o`000?oooooooooo08?ooooo000Eooooo`03o`000?oooooooooo
08;ooooo00?o0000ooooooooool0Poooool001Gooooo0_l00024ooooo`03o`000?oooooooooo08;o
oooo000Eooooo`03o`000?oooooooooo08?ooooo00?o0000ooooooooool0P_ooool001Gooooo00?o
0000ooooooooool0Q?ooool00ol0003oooooooooo`21ooooo`005Oooool00ol0003oooooooooo`24
ooooo`03o`000?oooooooooo087ooooo000Eooooo`03o`000?oooooooooo08Gooooo00?o0000oooo
ooooool0P?ooool001Gooooo00?o0000ooooooooool0Q_ooool00ol0003oooooooooo`1oooooo`00
5Oooool00ol0003oooooooooo`26ooooo`03o`000?oooooooooo07oooooo000Eooooo`03o`000?oo
oooooooo08Oooooo00?o0000ooooooooool0O_ooool001Gooooo0_l00028ooooo`03o`000?oooooo
oooo07kooooo000Eooooo`03o`000?oooooooooo08Sooooo00?o0000ooooooooool0OOooool001Go
oooo00?o0000ooooooooool0ROooool00ol0003oooooooooo`1looooo`005Oooool00ol0003ooooo
ooooo`29ooooo`03o`000?oooooooooo07cooooo000Eooooo`03o`000?oooooooooo08[ooooo00?o
0000ooooooooool0Noooool000;ooooo0_l00004ooooo`03o`000?oooooooooo00;ooooo0ol00005
ooooo`03o`000?oooooooooo08_ooooo00?o0000ooooooooool0N_ooool00005ooooool0003ooooo
ooooool000001oooool01Ol0003ooooooooooooooooo000000Cooooo00?o0000ooooooooool0S?oo
ool00ol0003oooooooooo`1iooooo`0000Goooooo`000?ooooooooooo`000007ooooo`05o`000?oo
ooooooooooooool000001?ooool00ol0003oooooooooo`2<ooooo`03o`000?oooooooooo07Wooooo
00001Ooooooo0000oooooooooooo000000Oooooo1?l00005ooooo`?o0000SOooool00ol0003ooooo
ooooo`1hooooo`0000Goooooo`000?ooooooooooo`000007ooooo`03o`000?oooooooooo00Kooooo
00?o0000ooooooooool0S_ooool00ol0003oooooooooo`1gooooo`0000Goooooo`000?oooooooooo
o`000008ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0S_ooool00ol0003ooooo
ooooo`1gooooo`000_ooool2o`0000[ooooo0_l00005ooooo`03o`000?oooooooooo08oooooo00?o
0000ooooooooool0M_ooool001Gooooo00?o0000ooooooooool0T?ooool00ol0003oooooooooo`1e
ooooo`005Oooool00ol0003oooooooooo`2@ooooo`03o`000?oooooooooo07Gooooo000Eooooo`03
o`000?oooooooooo097ooooo00?o0000ooooooooool0M?ooool001Gooooo00?o0000ooooooooool0
T_ooool00ol0003oooooooooo`1cooooo`005Oooool2o`0009Cooooo00?o0000ooooooooool0L_oo
ool001Gooooo00?o0000ooooooooool0U?ooool00ol0003oooooooooo`1aooooo`005Oooool00ol0
003oooooooooo`2Eooooo`03o`000?oooooooooo073ooooo000Eooooo`03o`000?oooooooooo09Go
oooo00?o0000ooooooooool0L?ooool001Gooooo00?o0000ooooooooool0U_ooool00ol0003ooooo
ooooo`1_ooooo`005Oooool00ol0003oooooooooo`2Gooooo`03o`000?oooooooooo06kooooo000E
ooooo`03o`000?oooooooooo09Sooooo00?o0000ooooooooool0KOooool001Gooooo00?o0000oooo
ooooool0VOooool00ol0003oooooooooo`1/ooooo`005Oooool2o`0009[ooooo00?o0000oooooooo
ool0K?ooool001Gooooo00?o0000ooooooooool0V_ooool00ol0003oooooooooo`1[ooooo`005Ooo
ool00ol0003oooooooooo`2Kooooo`03o`000?oooooooooo06[ooooo000Eooooo`03o`000?oooooo
oooo09cooooo00?o0000ooooooooool0JOooool001Gooooo00?o0000ooooooooool0WOooool00ol0
003oooooooooo`1Xooooo`005Oooool00ol0003oooooooooo`2Mooooo`03o`000?oooooooooo06So
oooo000Eooooo`03o`000?oooooooooo09kooooo00?o0000ooooooooool0Ioooool001Gooooo00?o
0000ooooooooool0Woooool00ol0003oooooooooo`1Vooooo`005Oooool2o`000:7ooooo00?o0000
ooooooooool0IOooool001Gooooo00?o0000ooooooooool0XOooool2o`0006Gooooo000Eooooo`03
o`000?oooooooooo0:?ooooo00?o0000ooooooooool0H_ooool001Gooooo00?o0000ooooooooool0
Y?ooool00ol0003oooooooooo`1Qooooo`005Oooool00ol0003oooooooooo`2Uooooo`03o`000?oo
oooooooo063ooooo0002ooooo`;o00001?ooool00ol0003oooooooooo`02ooooo`?o00001Oooool0
0ol0003oooooooooo`2Vooooo`03o`000?oooooooooo05oooooo00001Ooooooo0000oooooooooooo
000000Oooooo00Go0000ooooooooooooooooo`000004ooooo`03o`000?oooooooooo0:Oooooo00?o
0000ooooooooool0G_ooool00005ooooool0003oooooooooool000001oooool01Ol0003ooooooooo
oooooooo000000Cooooo00?o0000ooooooooool0Z?ooool00ol0003oooooooooo`1Mooooo`0000Go
ooooo`000?ooooooooooo`000008ooooo`?o00001Oooool3o`000:Wooooo00?o0000ooooooooool0
G?ooool00005ooooool0003oooooooooool000001oooool01Ol0003ooooooooooooooooo000000Co
oooo00?o0000ooooooooool0Z_ooool2o`0005cooooo00001Ooooooo0000oooooooooooo000000Oo
oooo00Go0000ooooooooooooooooo`000004ooooo`03o`000?oooooooooo0:cooooo00?o0000oooo
ooooool0FOooool000;ooooo0_l00009ooooo`?o00001Oooool00ol0003oooooooooo`2]ooooo`03
o`000?oooooooooo05Sooooo000Eooooo`03o`000?oooooooooo0:kooooo0_l0001Hooooo`005Ooo
ool00ol0003oooooooooo`2`ooooo`03o`000?oooooooooo05Gooooo000Eooooo`03o`000?oooooo
oooo0;7ooooo00?o0000ooooooooool0E?ooool001Gooooo00?o0000ooooooooool0/_ooool2o`00
05Cooooo000Eooooo`;o0000]Oooool2o`0005;ooooo000Eooooo`03o`000?oooooooooo0;Kooooo
0_l0001@ooooo`005Oooool00ol0003oooooooooo`2hooooo`03o`000?oooooooooo04gooooo000E
ooooo`03o`000?oooooooooo0;Wooooo0_l0001=ooooo`005Oooool00ol0003oooooooooo`2koooo
o`;o0000Boooool001Gooooo00?o0000ooooooooool0_Oooool2o`0004Wooooo000Eooooo`03o`00
0?oooooooooo0;oooooo0ol00016ooooo`005Oooool00ol0003oooooooooo`32ooooo`;o0000A?oo
ool001Gooooo0_l00035ooooo`;o0000@_ooool001Gooooo00?o0000ooooooooool0a_ooool2o`00
043ooooo000Eooooo`03o`000?oooooooooo0<Sooooo0_l0000nooooo`005Oooool00ol0003ooooo
ooooo`3:ooooo`;o0000??ooool001Gooooo00?o0000ooooooooool0c?ooool3o`0003Wooooo000E
ooooo`03o`000?oooooooooo0<oooooo1Ol0000dooooo`005Oooool00ol0003oooooooooo`3Doooo
o`Co0000<?ooool001Gooooo00?o0000ooooooooool0f?ooool5o`0002_ooooo000Eooooo`;o0000
g_ooool6o`0002Gooooo000Eooooo`03o`000?oooooooooo0>?ooooo1_l0000Oooooo`005Oooool0
0ol0003oooooooooo`3Yooooo`Go00006_ooool001Gooooo00?o0000ooooooooool0k_ooool?o`00
00_ooooo000Eooooo`03o`000?oooooooooo0?gooooo1?l00007ooooo`003Oooool3o`0000Gooooo
00?o0000ooooooooool0ooooool9ooooo`003_ooool00ol0003oooooooooo`04ooooo`03o`000?oo
oooooooo0?oooooo2Oooool000kooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`3o
ooooo`Wooooo000>ooooo`03o`000?oooooooooo00Cooooo0ol0003oooooo`Wooooo000>ooooo`03
o`000?oooooooooo0?oooooo4?ooool000gooooo0_l0003ooooooa;ooooo000>ooooo`03o`000?oo
oooooooo0?oooooo4?ooool00?oooooo8Oooool00001\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-2.49048, -0.0764114, \
0.115739, 0.00624232}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 0.0333333 0 0.618034 [
[.16667 -0.0125 -3 -9 ]
[.16667 -0.0125 3 0 ]
[.33333 -0.0125 -6 -9 ]
[.33333 -0.0125 6 0 ]
[.5 -0.0125 -6 -9 ]
[.5 -0.0125 6 0 ]
[.66667 -0.0125 -6 -9 ]
[.66667 -0.0125 6 0 ]
[.83333 -0.0125 -6 -9 ]
[.83333 -0.0125 6 0 ]
[1 -0.0125 -6 -9 ]
[1 -0.0125 6 0 ]
[-0.0125 .12361 -18 -4.5 ]
[-0.0125 .12361 0 4.5 ]
[-0.0125 .24721 -18 -4.5 ]
[-0.0125 .24721 0 4.5 ]
[-0.0125 .37082 -18 -4.5 ]
[-0.0125 .37082 0 4.5 ]
[-0.0125 .49443 -18 -4.5 ]
[-0.0125 .49443 0 4.5 ]
[-0.0125 .61803 -6 -4.5 ]
[-0.0125 .61803 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.16667 0 m
.16667 .00625 L
s
[(5)] .16667 -0.0125 0 1 Mshowa
.33333 0 m
.33333 .00625 L
s
[(10)] .33333 -0.0125 0 1 Mshowa
.5 0 m
.5 .00625 L
s
[(15)] .5 -0.0125 0 1 Mshowa
.66667 0 m
.66667 .00625 L
s
[(20)] .66667 -0.0125 0 1 Mshowa
.83333 0 m
.83333 .00625 L
s
[(25)] .83333 -0.0125 0 1 Mshowa
1 0 m
1 .00625 L
s
[(30)] 1 -0.0125 0 1 Mshowa
.125 Mabswid
.03333 0 m
.03333 .00375 L
s
.06667 0 m
.06667 .00375 L
s
.1 0 m
.1 .00375 L
s
.13333 0 m
.13333 .00375 L
s
.2 0 m
.2 .00375 L
s
.23333 0 m
.23333 .00375 L
s
.26667 0 m
.26667 .00375 L
s
.3 0 m
.3 .00375 L
s
.36667 0 m
.36667 .00375 L
s
.4 0 m
.4 .00375 L
s
.43333 0 m
.43333 .00375 L
s
.46667 0 m
.46667 .00375 L
s
.53333 0 m
.53333 .00375 L
s
.56667 0 m
.56667 .00375 L
s
.6 0 m
.6 .00375 L
s
.63333 0 m
.63333 .00375 L
s
.7 0 m
.7 .00375 L
s
.73333 0 m
.73333 .00375 L
s
.76667 0 m
.76667 .00375 L
s
.8 0 m
.8 .00375 L
s
.86667 0 m
.86667 .00375 L
s
.9 0 m
.9 .00375 L
s
.93333 0 m
.93333 .00375 L
s
.96667 0 m
.96667 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .12361 m
.00625 .12361 L
s
[(0.2)] -0.0125 .12361 1 0 Mshowa
0 .24721 m
.00625 .24721 L
s
[(0.4)] -0.0125 .24721 1 0 Mshowa
0 .37082 m
.00625 .37082 L
s
[(0.6)] -0.0125 .37082 1 0 Mshowa
0 .49443 m
.00625 .49443 L
s
[(0.8)] -0.0125 .49443 1 0 Mshowa
0 .61803 m
.00625 .61803 L
s
[(1)] -0.0125 .61803 1 0 Mshowa
.125 Mabswid
0 .0309 m
.00375 .0309 L
s
0 .0618 m
.00375 .0618 L
s
0 .09271 m
.00375 .09271 L
s
0 .15451 m
.00375 .15451 L
s
0 .18541 m
.00375 .18541 L
s
0 .21631 m
.00375 .21631 L
s
0 .27812 m
.00375 .27812 L
s
0 .30902 m
.00375 .30902 L
s
0 .33992 m
.00375 .33992 L
s
0 .40172 m
.00375 .40172 L
s
0 .43262 m
.00375 .43262 L
s
0 .46353 m
.00375 .46353 L
s
0 .52533 m
.00375 .52533 L
s
0 .55623 m
.00375 .55623 L
s
0 .58713 m
.00375 .58713 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.03333 .02692 m
.06667 .02977 L
.1 .03315 L
.13333 .03775 L
.16667 .04389 L
.2 .05189 L
.23333 .0621 L
.26667 .07492 L
.3 .09084 L
.33333 .11037 L
.36667 .13409 L
.4 .16259 L
.43333 .19646 L
.46667 .23626 L
.5 .2825 L
.53333 .33554 L
.56667 .38177 L
.6 .42158 L
.63333 .45545 L
.66667 .48394 L
.7 .50766 L
.73333 .52719 L
.76667 .54311 L
.8 .55594 L
.83333 .56614 L
.86667 .57414 L
.9 .58028 L
.93333 .58488 L
.96667 .58826 L
1 .59111 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[6]:=",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/B000`400?l00000o`00003ooooooolQ
ooooo`00?_ooool3o`0002Gooooo0ol00004ooooo`;o00008oooool3o`0000?ooooo0ol0000Qoooo
o`Go00000oooool2o`00027ooooo1Ol00002ooooo`?o00008_ooool3o`0000Cooooo0_l00004oooo
o`00?Oooool01Ol0003ooooooooooooooooo000002Gooooo00?o0000ooooooooool00_ooool01?l0
003oooooooooool0000Sooooo`05o`000?ooooooooooooooool000000oooool00ol0003ooooooooo
o`0Oooooo`04o`000?ooooooooooo`0000;ooooo00Co0000oooooooooooo00008Oooool01_l0003o
ooooooooool0003oooooo`0000?ooooo00?o0000ooooooooool07_ooool01Ol0003ooooooooooooo
oooo000000;ooooo00Co0000oooooooooooo00000oooool0047ooooo00?o0000ooooooooool08ooo
ool00ol0003oooooooooo`02ooooo`04o`000?ooooooooooo`0002?ooooo00?o0000ooooooooool0
1Oooool00ol0003oooooooooo`0Pooooo`03o`000?oooooooooo00;ooooo00Co0000oooooooooooo
00008_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo02;ooooo00Co0000oooooooo
oooo00000_ooool00ol0003oooooooooo`01ooooo`00@Oooool00ol0003oooooooooo`0Sooooo`03
o`000?oooooooooo00;ooooo00Co0000oooooooooooo00008oooool00ol0003oooooooooo`05oooo
o`03o`000?oooooooooo027ooooo00Go0000ooooooooooooooooo`000002ooooo`03o`000?oooooo
oooo027ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`0Pooooo`;o00000oooool0
1?l0003oooooooooool00003ooooo`00?Oooool4o`0002Kooooo00?o0000ooooooooool00_ooool0
1?l0003oooooooooool0000Sooooo`04o`000?ooooooooooooooo`Co00008Oooool01Ol0003ooooo
oooooooooooo000000;ooooo00Co0000oooooooooooo00008?ooool01_l0003ooooooooooooooooo
0000ooooo`Co00009Oooool01?l0003oooooooooool00002ooooo`03o`000?oooooooooo007ooooo
000mooooo`03o`000?oooooooooo02Kooooo0_l00004ooooo`04o`000?ooooooooooo`0002;ooooo
0_l00003ooooo`03o`000?oooooooooo02;ooooo00Go0000ooooooooooooooooo`000002ooooo`04
o`000?ooooooooooo`00023ooooo00Oo0000ooooooooooooooooo`000?oooooo000002Cooooo00Go
0000ooooooooooooooooo`000002ooooo`04o`000?ooooooooooo`0000?ooooo000mooooo`Go0000
9Oooool00ol0003oooooooooo`03ooooo`;o00009?ooool01?l0003oooooooooooooool5o`00027o
oooo0ol00004ooooo`;o00008_ooool3o`0000;ooooo1Ol0000Qooooo`?o00001?ooool2o`0000Co
oooo003oooooob7ooooo003oooooob7ooooo003oooooob7ooooo003oooooob7ooooo000Eoooooooo
00001Ol00007ooooo`005Oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Gooooo
00?o0000ooooooooool01_ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Gooooo
00?o0000ooooooooool01_ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Gooooo
00?o0000ooooooooool01_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Kooooo
00?o0000ooooooooool01_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Kooooo
00?o0000ooooooooool01_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Kooooo
00?o0000ooooooooool01_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Kooooo
00?o0000ooooooooool01Oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Kooooo
00?o0000ooooooooool01Oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Kooooo
00?o0000ooooooooool01Oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Kooooo
00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`005Oooool00ol0003ooooooooo
o`3oooooo`Wooooo000Eooooo`03o`000?oooooooooo0?oooooo2Oooool001Gooooo00?o0000oooo
ooooool0ooooool9ooooo`005Oooool00ol0003oooooooooo`3oooooo`Wooooo000Eooooo`03o`00
0?oooooooooo0?oooooo2Oooool001Gooooo00?o0000ooooooooool01_ooool5o`000?gooooo000E
ooooo`;o00003?ooool?o`000>kooooo000Eooooo`03o`000?oooooooooo01[ooooo1Ol0003Yoooo
o`005Oooool00ol0003oooooooooo`0Oooooo`Ko0000hoooool001Gooooo00?o0000ooooooooool0
9Oooool6o`000=gooooo000Eooooo`03o`000?oooooooooo02_ooooo1Ol0003Hooooo`005Oooool0
0ol0003oooooooooo`0`ooooo`Co0000e?ooool001Gooooo00?o0000ooooooooool0=?ooool3o`00
0=7ooooo000Eooooo`03o`000?oooooooooo03Oooooo0ol0003>ooooo`005Oooool2o`0003_ooooo
0_l0003<ooooo`005Oooool00ol0003oooooooooo`0looooo`?o0000bOooool001Gooooo00?o0000
ooooooooool0?oooool3o`000<Kooooo000Eooooo`03o`000?oooooooooo04;ooooo0_l00034oooo
o`005Oooool00ol0003oooooooooo`14ooooo`;o0000`_ooool001Gooooo00?o0000ooooooooool0
A_ooool3o`000;oooooo000Eooooo`03o`000?oooooooooo04Wooooo0_l0002mooooo`005Oooool0
0ol0003oooooooooo`1;ooooo`;o0000^oooool001Gooooo0_l0001>ooooo`03o`000?oooooooooo
0;Sooooo000Eooooo`03o`000?oooooooooo04kooooo0_l0002hooooo`005Oooool00ol0003ooooo
ooooo`1@ooooo`;o0000]_ooool001Gooooo00?o0000ooooooooool0D_ooool00ol0003ooooooooo
o`2cooooo`005Oooool00ol0003oooooooooo`1Cooooo`;o0000/oooool000;ooooo0_l00004oooo
o`04o`000?ooooooooooooooo`Go00001?ooool00ol0003oooooooooo`1Eooooo`03o`000?oooooo
oooo0;3ooooo00001Ooooooo0000oooooooooooo000000Sooooo00Co0000oooooooooooo00001?oo
ool00ol0003oooooooooo`1Fooooo`03o`000?oooooooooo0:oooooo00001Ooooooo0000oooooooo
oooo000000Wooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`1Gooooo`;o0000[ooo
ool00005ooooool0003oooooooooool000002_ooool00ol0003oooooooooo`03ooooo`?o0000FOoo
ool00ol0003oooooooooo`2/ooooo`0000Goooooo`000?ooooooooooo`000007ooooo`05o`000?oo
ooooooooooooool000001?ooool00ol0003oooooooooo`1Jooooo`03o`000?oooooooooo0:_ooooo
00001Ooooooo0000oooooooooooo000000Oooooo00Go0000ooooooooooooooooo`000004ooooo`03
o`000?oooooooooo05_ooooo00?o0000ooooooooool0Z_ooool000;ooooo0_l00009ooooo`?o0000
1Oooool00ol0003oooooooooo`1Looooo`;o0000Z_ooool001Gooooo00?o0000ooooooooool0G_oo
ool00ol0003oooooooooo`2Wooooo`005Oooool00ol0003oooooooooo`1Oooooo`03o`000?oooooo
oooo0:Kooooo000Eooooo`03o`000?oooooooooo063ooooo0_l0002Vooooo`005Oooool00ol0003o
ooooooooo`1Rooooo`03o`000?oooooooooo0:?ooooo000Eooooo`;o0000I?ooool00ol0003ooooo
ooooo`2Rooooo`005Oooool00ol0003oooooooooo`1Tooooo`03o`000?oooooooooo0:7ooooo000E
ooooo`03o`000?oooooooooo06Gooooo00?o0000ooooooooool0X?ooool001Gooooo00?o0000oooo
ooooool0IOooool00ol0003oooooooooo`2Pooooo`005Oooool00ol0003oooooooooo`1Vooooo`03
o`000?oooooooooo09oooooo000Eooooo`03o`000?oooooooooo06Oooooo00?o0000ooooooooool0
W_ooool001Gooooo00?o0000ooooooooool0J?ooool00ol0003oooooooooo`2Mooooo`005Oooool0
0ol0003oooooooooo`1Yooooo`03o`000?oooooooooo09cooooo000Eooooo`;o0000Joooool00ol0
003oooooooooo`2Kooooo`005Oooool00ol0003oooooooooo`1[ooooo`03o`000?oooooooooo09[o
oooo000Eooooo`03o`000?oooooooooo06cooooo00?o0000ooooooooool0VOooool001Gooooo00?o
0000ooooooooool0KOooool00ol0003oooooooooo`2Hooooo`005Oooool00ol0003oooooooooo`1]
ooooo`03o`000?oooooooooo09Sooooo000Eooooo`03o`000?oooooooooo06kooooo00?o0000oooo
ooooool0Uoooool001Gooooo00?o0000ooooooooool0Koooool00ol0003oooooooooo`2Fooooo`00
5Oooool00ol0003oooooooooo`1`ooooo`03o`000?oooooooooo09Gooooo000Eooooo`;o0000L_oo
ool00ol0003oooooooooo`2Dooooo`005Oooool00ol0003oooooooooo`1booooo`03o`000?oooooo
oooo09?ooooo000Eooooo`03o`000?oooooooooo07?ooooo00?o0000ooooooooool0T_ooool001Go
oooo00?o0000ooooooooool0M?ooool00ol0003oooooooooo`2Aooooo`005Oooool00ol0003ooooo
ooooo`1eooooo`03o`000?oooooooooo093ooooo0002ooooo`;o00001?ooool00ol0003ooooooooo
o`03ooooo`?o00001?ooool00ol0003oooooooooo`1fooooo`03o`000?oooooooooo08oooooo0000
1Ooooooo0000oooooooooooo000000[ooooo00?o0000ooooooooool00oooool00ol0003ooooooooo
o`1fooooo`03o`000?oooooooooo08oooooo00001Ooooooo0000oooooooooooo000000Oooooo1Ol0
0004ooooo`03o`000?oooooooooo07Oooooo00?o0000ooooooooool0S_ooool00005ooooool0003o
ooooooooool000001oooool01?l0003oooooooooool00005ooooo`?o0000N?ooool00ol0003ooooo
ooooo`2=ooooo`0000Goooooo`000?ooooooooooo`000008ooooo`03o`000?oooooo000000Gooooo
00?o0000ooooooooool0NOooool00ol0003oooooooooo`2<ooooo`0000Goooooo`000?oooooooooo
o`000009ooooo`;o00001Oooool00ol0003oooooooooo`1iooooo`03o`000?oooooooooo08cooooo
0002ooooo`;o00002oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo07[ooooo00?o
0000ooooooooool0Roooool001Gooooo00?o0000ooooooooool0Noooool00ol0003oooooooooo`2:
ooooo`005Oooool00ol0003oooooooooo`1looooo`03o`000?oooooooooo08Wooooo000Eooooo`03
o`000?oooooooooo07cooooo00?o0000ooooooooool0ROooool001Gooooo00?o0000ooooooooool0
OOooool00ol0003oooooooooo`28ooooo`005Oooool2o`0007oooooo00?o0000ooooooooool0Qooo
ool001Gooooo00?o0000ooooooooool0Ooooool00ol0003oooooooooo`26ooooo`005Oooool00ol0
003oooooooooo`1oooooo`03o`000?oooooooooo08Kooooo000Eooooo`03o`000?oooooooooo083o
oooo00?o0000ooooooooool0QOooool001Gooooo00?o0000ooooooooool0P?ooool00ol0003ooooo
ooooo`25ooooo`005Oooool00ol0003oooooooooo`21ooooo`03o`000?oooooooooo08Cooooo000E
ooooo`03o`000?oooooooooo08;ooooo00?o0000ooooooooool0Poooool001Gooooo00?o0000oooo
ooooool0P_ooool00ol0003oooooooooo`23ooooo`005Oooool2o`0008Cooooo00?o0000oooooooo
ool0P_ooool001Gooooo00?o0000ooooooooool0Poooool00ol0003oooooooooo`22ooooo`005Ooo
ool00ol0003oooooooooo`24ooooo`03o`000?oooooooooo087ooooo000Eooooo`03o`000?oooooo
oooo08Cooooo00?o0000ooooooooool0POooool001Gooooo00?o0000ooooooooool0QOooool00ol0
003oooooooooo`20ooooo`005Oooool00ol0003oooooooooo`26ooooo`03o`000?oooooooooo07oo
oooo000Eooooo`03o`000?oooooooooo08Kooooo00?o0000ooooooooool0Ooooool001Gooooo00?o
0000ooooooooool0Qoooool00ol0003oooooooooo`1nooooo`005Oooool2o`0008Sooooo00?o0000
ooooooooool0O_ooool001Gooooo00?o0000ooooooooool0R?ooool00ol0003oooooooooo`1moooo
o`005Oooool00ol0003oooooooooo`29ooooo`03o`000?oooooooooo07cooooo000Eooooo`03o`00
0?oooooooooo08[ooooo00?o0000ooooooooool0Noooool001Gooooo00?o0000ooooooooool0R_oo
ool00ol0003oooooooooo`1kooooo`000_ooool2o`0000Cooooo00?o0000ooooooooool00_ooool3
o`0000Gooooo00?o0000ooooooooool0Roooool00ol0003oooooooooo`1jooooo`0000Goooooo`00
0?ooooooooooo`000007ooooo`05o`000?ooooooooooooooool000001?ooool00ol0003ooooooooo
o`2<ooooo`03o`000?oooooooooo07Wooooo00001Ooooooo0000oooooooooooo000000Oooooo00Go
0000ooooooooooooooooo`000004ooooo`03o`000?oooooooooo08gooooo00?o0000ooooooooool0
N?ooool00005ooooool0003oooooooooool000001oooool4o`0000Gooooo0ol0002=ooooo`03o`00
0?oooooooooo07Sooooo00001Ooooooo0000oooooooooooo000000Oooooo00?o0000ooooooooool0
1_ooool00ol0003oooooooooo`2>ooooo`03o`000?oooooooooo07Oooooo00001Ooooooo0000oooo
oooooooo000000Sooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`2?ooooo`03o`00
0?oooooooooo07Kooooo0002ooooo`;o00002_ooool2o`0000Gooooo00?o0000ooooooooool0T?oo
ool00ol0003oooooooooo`1eooooo`005Oooool00ol0003oooooooooo`2@ooooo`03o`000?oooooo
oooo07Gooooo000Eooooo`03o`000?oooooooooo097ooooo00?o0000ooooooooool0M?ooool001Go
oooo00?o0000ooooooooool0T_ooool00ol0003oooooooooo`1cooooo`005Oooool00ol0003ooooo
ooooo`2Cooooo`03o`000?oooooooooo07;ooooo000Eooooo`;o0000UOooool00ol0003ooooooooo
o`1aooooo`005Oooool00ol0003oooooooooo`2Eooooo`03o`000?oooooooooo073ooooo000Eoooo
o`03o`000?oooooooooo09Kooooo00?o0000ooooooooool0Koooool001Gooooo00?o0000oooooooo
ool0Uoooool00ol0003oooooooooo`1^ooooo`005Oooool00ol0003oooooooooo`2Hooooo`03o`00
0?oooooooooo06gooooo000Eooooo`03o`000?oooooooooo09Wooooo00?o0000ooooooooool0K?oo
ool001Gooooo00?o0000ooooooooool0VOooool00ol0003oooooooooo`1/ooooo`005Oooool00ol0
003oooooooooo`2Jooooo`03o`000?oooooooooo06_ooooo000Eooooo`;o0000W?ooool00ol0003o
ooooooooo`1Zooooo`005Oooool00ol0003oooooooooo`2Looooo`03o`000?oooooooooo06Wooooo
000Eooooo`03o`000?oooooooooo09gooooo00?o0000ooooooooool0J?ooool001Gooooo00?o0000
ooooooooool0W_ooool00ol0003oooooooooo`1Wooooo`005Oooool00ol0003oooooooooo`2Ooooo
o`03o`000?oooooooooo06Kooooo000Eooooo`03o`000?oooooooooo0:3ooooo00?o0000oooooooo
ool0IOooool001Gooooo00?o0000ooooooooool0XOooool2o`0006Gooooo000Eooooo`03o`000?oo
oooooooo0:?ooooo00?o0000ooooooooool0H_ooool001Gooooo0_l0002Uooooo`03o`000?oooooo
oooo067ooooo000Eooooo`03o`000?oooooooooo0:Gooooo0_l0001Qooooo`005Oooool00ol0003o
ooooooooo`2Wooooo`03o`000?oooooooooo05kooooo000Eooooo`03o`000?oooooooooo0:Sooooo
00?o0000ooooooooool0GOooool001Gooooo00?o0000ooooooooool0ZOooool00ol0003ooooooooo
o`1Looooo`000_ooool2o`0000Cooooo00?o0000ooooooooool00_ooool3o`0000Gooooo00?o0000
ooooooooool0Z_ooool2o`0005cooooo00001Ooooooo0000oooooooooooo000000Oooooo00Go0000
ooooooooooooooooo`000004ooooo`03o`000?oooooooooo0:cooooo00?o0000ooooooooool0FOoo
ool00005ooooool0003oooooooooool000001oooool01Ol0003ooooooooooooooooo000000Cooooo
00?o0000ooooooooool0[Oooool00ol0003oooooooooo`1Hooooo`0000Goooooo`000?oooooooooo
o`000008ooooo`?o00001Oooool3o`000:kooooo0_l0001Hooooo`0000Goooooo`000?oooooooooo
o`000007ooooo`05o`000?ooooooooooooooool000001?ooool00ol0003oooooooooo`2`ooooo`03
o`000?oooooooooo05Gooooo00001Ooooooo0000oooooooooooo000000Oooooo00Go0000oooooooo
ooooooooo`000004ooooo`03o`000?oooooooooo0;7ooooo00?o0000ooooooooool0E?ooool000;o
oooo0_l00009ooooo`?o00001Oooool00ol0003oooooooooo`2booooo`;o0000E?ooool001Gooooo
00?o0000ooooooooool0]?ooool2o`0005;ooooo000Eooooo`03o`000?oooooooooo0;Kooooo0_l0
001@ooooo`005Oooool00ol0003oooooooooo`2hooooo`03o`000?oooooooooo04gooooo000Eoooo
o`03o`000?oooooooooo0;Wooooo0_l0001=ooooo`005Oooool2o`000;cooooo0_l0001;ooooo`00
5Oooool00ol0003oooooooooo`2mooooo`;o0000BOooool001Gooooo00?o0000ooooooooool0_ooo
ool2o`0004Oooooo000Eooooo`03o`000?oooooooooo0<7ooooo00?o0000ooooooooool0A?ooool0
01Gooooo00?o0000ooooooooool0`_ooool2o`0004Cooooo000Eooooo`03o`000?oooooooooo0<Co
oooo0_l00012ooooo`005Oooool00ol0003oooooooooo`36ooooo`?o0000?oooool001Gooooo00?o
0000ooooooooool0bOooool3o`0003cooooo000Eooooo`;o0000cOooool3o`0003Wooooo000Eoooo
o`03o`000?oooooooooo0<oooooo0ol0000fooooo`005Oooool00ol0003oooooooooo`3Booooo`?o
0000<oooool001Gooooo00?o0000ooooooooool0eOooool3o`00033ooooo000Eooooo`03o`000?oo
oooooooo0=Sooooo1Ol0000[ooooo`005Oooool00ol0003oooooooooo`3Mooooo`Ko00009Oooool0
01Gooooo00?o0000ooooooooool0hoooool9o`0001cooooo000Eooooo`03o`000?oooooooooo0>co
oooo2Ol0000Cooooo`005Oooool2o`000?Kooooo2?l0000;ooooo`005Oooool00ol0003ooooooooo
o`3mooooo`Co00001oooool001Gooooo00?o0000ooooooooool0ooooool9ooooo`005Oooool00ol0
003oooooooooo`3oooooo`Wooooo000Eooooo`03o`000?oooooooooo0?oooooo2Oooool000gooooo
0ol00005ooooo`03o`000?oooooooooo0?oooooo2Oooool000kooooo00?o0000ooooooooool01?oo
ool00ol0003oooooooooo`3oooooo`Wooooo000>ooooo`03o`000?oooooooooo00Cooooo00?o0000
ooooooooool0ooooool9ooooo`003_ooool00ol0003oooooooooo`04ooooo`?o0000ooooool9oooo
o`003_ooool00ol0003oooooooooo`3ooooooa3ooooo000=ooooo`;o0000oooooolBooooo`003_oo
ool00ol0003oooooooooo`3ooooooa3ooooo003oooooob7ooooo0000\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-2.49048, -0.0764114, \
0.115739, 0.00624232}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 0.0333333 0 0.618034 [
[.16667 -0.0125 -3 -9 ]
[.16667 -0.0125 3 0 ]
[.33333 -0.0125 -6 -9 ]
[.33333 -0.0125 6 0 ]
[.5 -0.0125 -6 -9 ]
[.5 -0.0125 6 0 ]
[.66667 -0.0125 -6 -9 ]
[.66667 -0.0125 6 0 ]
[.83333 -0.0125 -6 -9 ]
[.83333 -0.0125 6 0 ]
[1 -0.0125 -6 -9 ]
[1 -0.0125 6 0 ]
[-0.0125 .12361 -18 -4.5 ]
[-0.0125 .12361 0 4.5 ]
[-0.0125 .24721 -18 -4.5 ]
[-0.0125 .24721 0 4.5 ]
[-0.0125 .37082 -18 -4.5 ]
[-0.0125 .37082 0 4.5 ]
[-0.0125 .49443 -18 -4.5 ]
[-0.0125 .49443 0 4.5 ]
[-0.0125 .61803 -6 -4.5 ]
[-0.0125 .61803 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.16667 0 m
.16667 .00625 L
s
[(5)] .16667 -0.0125 0 1 Mshowa
.33333 0 m
.33333 .00625 L
s
[(10)] .33333 -0.0125 0 1 Mshowa
.5 0 m
.5 .00625 L
s
[(15)] .5 -0.0125 0 1 Mshowa
.66667 0 m
.66667 .00625 L
s
[(20)] .66667 -0.0125 0 1 Mshowa
.83333 0 m
.83333 .00625 L
s
[(25)] .83333 -0.0125 0 1 Mshowa
1 0 m
1 .00625 L
s
[(30)] 1 -0.0125 0 1 Mshowa
.125 Mabswid
.03333 0 m
.03333 .00375 L
s
.06667 0 m
.06667 .00375 L
s
.1 0 m
.1 .00375 L
s
.13333 0 m
.13333 .00375 L
s
.2 0 m
.2 .00375 L
s
.23333 0 m
.23333 .00375 L
s
.26667 0 m
.26667 .00375 L
s
.3 0 m
.3 .00375 L
s
.36667 0 m
.36667 .00375 L
s
.4 0 m
.4 .00375 L
s
.43333 0 m
.43333 .00375 L
s
.46667 0 m
.46667 .00375 L
s
.53333 0 m
.53333 .00375 L
s
.56667 0 m
.56667 .00375 L
s
.6 0 m
.6 .00375 L
s
.63333 0 m
.63333 .00375 L
s
.7 0 m
.7 .00375 L
s
.73333 0 m
.73333 .00375 L
s
.76667 0 m
.76667 .00375 L
s
.8 0 m
.8 .00375 L
s
.86667 0 m
.86667 .00375 L
s
.9 0 m
.9 .00375 L
s
.93333 0 m
.93333 .00375 L
s
.96667 0 m
.96667 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .12361 m
.00625 .12361 L
s
[(0.2)] -0.0125 .12361 1 0 Mshowa
0 .24721 m
.00625 .24721 L
s
[(0.4)] -0.0125 .24721 1 0 Mshowa
0 .37082 m
.00625 .37082 L
s
[(0.6)] -0.0125 .37082 1 0 Mshowa
0 .49443 m
.00625 .49443 L
s
[(0.8)] -0.0125 .49443 1 0 Mshowa
0 .61803 m
.00625 .61803 L
s
[(1)] -0.0125 .61803 1 0 Mshowa
.125 Mabswid
0 .0309 m
.00375 .0309 L
s
0 .0618 m
.00375 .0618 L
s
0 .09271 m
.00375 .09271 L
s
0 .15451 m
.00375 .15451 L
s
0 .18541 m
.00375 .18541 L
s
0 .21631 m
.00375 .21631 L
s
0 .27812 m
.00375 .27812 L
s
0 .30902 m
.00375 .30902 L
s
0 .33992 m
.00375 .33992 L
s
0 .40172 m
.00375 .40172 L
s
0 .43262 m
.00375 .43262 L
s
0 .46353 m
.00375 .46353 L
s
0 .52533 m
.00375 .52533 L
s
0 .55623 m
.00375 .55623 L
s
0 .58713 m
.00375 .58713 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.03333 .03719 m
.06667 .04072 L
.1 .04447 L
.13333 .04937 L
.16667 .05577 L
.2 .06396 L
.23333 .07424 L
.26667 .08696 L
.3 .10253 L
.33333 .12139 L
.36667 .14406 L
.4 .17107 L
.43333 .203 L
.46667 .24043 L
.5 .28395 L
.53333 .33408 L
.56667 .3776 L
.6 .41504 L
.63333 .44697 L
.66667 .47398 L
.7 .49664 L
.73333 .51551 L
.76667 .53107 L
.8 .5438 L
.83333 .55408 L
.86667 .56226 L
.9 .56866 L
.93333 .57356 L
.96667 .57731 L
1 .58085 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[6]:=",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/B000`400?l00000o`00003ooooooolQ
ooooo`00?_ooool3o`0002Gooooo0ol00004ooooo`;o00008oooool3o`0000?ooooo0ol0000Qoooo
o`Go00000oooool2o`00027ooooo1Ol00002ooooo`?o00008_ooool3o`0000Cooooo0_l00004oooo
o`00?Oooool01Ol0003ooooooooooooooooo000002Gooooo00?o0000ooooooooool00_ooool01?l0
003oooooooooool0000Sooooo`05o`000?ooooooooooooooool000000oooool00ol0003ooooooooo
o`0Oooooo`04o`000?ooooooooooo`0000;ooooo00Co0000oooooooooooo00008Oooool01_l0003o
ooooooooool0003oooooo`0000?ooooo00?o0000ooooooooool07_ooool01Ol0003ooooooooooooo
oooo000000;ooooo00Co0000oooooooooooo00000oooool0047ooooo00?o0000ooooooooool08ooo
ool00ol0003oooooooooo`02ooooo`04o`000?ooooooooooo`0002?ooooo00?o0000ooooooooool0
1Oooool00ol0003oooooooooo`0Pooooo`03o`000?oooooooooo00;ooooo00Co0000oooooooooooo
00008_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo02;ooooo00Co0000oooooooo
oooo00000_ooool00ol0003oooooooooo`01ooooo`00@Oooool00ol0003oooooooooo`0Sooooo`03
o`000?oooooooooo00;ooooo00Co0000oooooooooooo00008oooool00ol0003oooooooooo`05oooo
o`03o`000?oooooooooo027ooooo00Go0000ooooooooooooooooo`000002ooooo`03o`000?oooooo
oooo027ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`0Pooooo`;o00000oooool0
1?l0003oooooooooool00003ooooo`00?Oooool4o`0002Kooooo00?o0000ooooooooool00_ooool0
1?l0003oooooooooool0000Sooooo`04o`000?ooooooooooooooo`Co00008Oooool01Ol0003ooooo
oooooooooooo000000;ooooo00Co0000oooooooooooo00008?ooool01_l0003ooooooooooooooooo
0000ooooo`Co00009Oooool01?l0003oooooooooool00002ooooo`03o`000?oooooooooo007ooooo
000mooooo`03o`000?oooooooooo02Kooooo0_l00004ooooo`04o`000?ooooooooooo`0002;ooooo
0_l00003ooooo`03o`000?oooooooooo02;ooooo00Go0000ooooooooooooooooo`000002ooooo`04
o`000?ooooooooooo`00023ooooo00Oo0000ooooooooooooooooo`000?oooooo000002Cooooo00Go
0000ooooooooooooooooo`000002ooooo`04o`000?ooooooooooo`0000?ooooo000mooooo`Go0000
9Oooool00ol0003oooooooooo`03ooooo`;o00009?ooool01?l0003oooooooooooooool5o`00027o
oooo0ol00004ooooo`;o00008_ooool3o`0000;ooooo1Ol0000Qooooo`?o00001?ooool2o`0000Co
oooo003oooooob7ooooo003oooooob7ooooo003oooooob7ooooo003oooooob7ooooo000Eoooooooo
00001Ol00007ooooo`005Oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Gooooo
00?o0000ooooooooool01_ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Gooooo
00?o0000ooooooooool01_ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Gooooo
00?o0000ooooooooool01_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Kooooo
00?o0000ooooooooool01_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Kooooo
00?o0000ooooooooool01_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Kooooo
00?o0000ooooooooool01_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Kooooo
00?o0000ooooooooool01Oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Kooooo
00?o0000ooooooooool01Oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Kooooo
00?o0000ooooooooool01Oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Kooooo
00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`005Oooool00ol0003ooooooooo
o`3oooooo`Wooooo000Eooooo`03o`000?oooooooooo0?oooooo2Oooool001Gooooo00?o0000oooo
ooooool0ooooool9ooooo`005Oooool00ol0003oooooooooo`3oooooo`Wooooo000Eooooo`03o`00
0?oooooooooo0?oooooo2Oooool001Gooooo00?o0000ooooooooool0ooooool9ooooo`005Oooool2
o`000?oooooo2_ooool001Gooooo00?o0000ooooooooool01_ooool5o`000?gooooo000Eooooo`03
o`000?oooooooooo00_ooooo2Ol0003dooooo`005Oooool00ol0003oooooooooo`0Dooooo`Ko0000
k_ooool001Gooooo00?o0000ooooooooool06_ooool5o`000>Wooooo000Eooooo`03o`000?oooooo
oooo01oooooo1_l0003Sooooo`005Oooool00ol0003oooooooooo`0Uooooo`Ko0000gOooool001Go
oooo00?o0000ooooooooool0:oooool5o`000=Sooooo000Eooooo`;o0000<Oooool4o`000=Cooooo
000Eooooo`03o`000?oooooooooo03Cooooo0ol0003Aooooo`005Oooool00ol0003oooooooooo`0g
ooooo`?o0000c_ooool001Gooooo00?o0000ooooooooool0>_ooool2o`000<cooooo000Eooooo`03
o`000?oooooooooo03cooooo0ol00039ooooo`005Oooool00ol0003oooooooooo`0oooooo`?o0000
a_ooool001Gooooo00?o0000ooooooooool0@_ooool2o`000<Cooooo000Eooooo`03o`000?oooooo
oooo04Cooooo0_l00032ooooo`005Oooool2o`0004Oooooo0ol0002oooooo`005Oooool00ol0003o
ooooooooo`19ooooo`;o0000_Oooool001Gooooo00?o0000ooooooooool0Boooool2o`000;_ooooo
000Eooooo`03o`000?oooooooooo04gooooo00?o0000ooooooooool0^?ooool001Gooooo00?o0000
ooooooooool0C_ooool2o`000;Sooooo0002ooooo`;o00001?ooool01?l0003oooooooooooooool5
o`0000Cooooo00?o0000ooooooooool0D?ooool2o`000;Kooooo00001Ooooooo0000oooooooooooo
000000Sooooo00Co0000oooooooooooo00001?ooool00ol0003oooooooooo`1Booooo`03o`000?oo
oooooooo0;?ooooo00001Ooooooo0000oooooooooooo000000Wooooo00?o0000ooooooooool01?oo
ool00ol0003oooooooooo`1Cooooo`;o0000/oooool00005ooooool0003oooooooooool000002_oo
ool00ol0003oooooooooo`03ooooo`?o0000EOooool00ol0003oooooooooo`2`ooooo`0000Gooooo
o`000?ooooooooooo`000007ooooo`05o`000?ooooooooooooooool000001?ooool00ol0003ooooo
ooooo`1Fooooo`;o0000/?ooool00005ooooool0003oooooooooool000001oooool01Ol0003ooooo
oooooooooooo000000Cooooo00?o0000ooooooooool0F?ooool00ol0003oooooooooo`2]ooooo`00
0_ooool2o`0000Wooooo0ol00005ooooo`03o`000?oooooooooo05Wooooo0_l0002]ooooo`005Ooo
ool00ol0003oooooooooo`1Kooooo`03o`000?oooooooooo0:[ooooo000Eooooo`03o`000?oooooo
oooo05cooooo0_l0002Zooooo`005Oooool00ol0003oooooooooo`1Nooooo`03o`000?oooooooooo
0:Oooooo000Eooooo`03o`000?oooooooooo05oooooo00?o0000ooooooooool0Y_ooool001Gooooo
0_l0001Qooooo`;o0000Y_ooool001Gooooo00?o0000ooooooooool0H_ooool00ol0003ooooooooo
o`2Sooooo`005Oooool00ol0003oooooooooo`1Sooooo`03o`000?oooooooooo0:;ooooo000Eoooo
o`03o`000?oooooooooo06Cooooo00?o0000ooooooooool0XOooool001Gooooo00?o0000oooooooo
ool0IOooool00ol0003oooooooooo`2Pooooo`005Oooool00ol0003oooooooooo`1Vooooo`03o`00
0?oooooooooo09oooooo000Eooooo`03o`000?oooooooooo06Oooooo00?o0000ooooooooool0W_oo
ool001Gooooo00?o0000ooooooooool0J?ooool00ol0003oooooooooo`2Mooooo`005Oooool2o`00
06[ooooo00?o0000ooooooooool0W?ooool001Gooooo00?o0000ooooooooool0J_ooool00ol0003o
ooooooooo`2Kooooo`005Oooool00ol0003oooooooooo`1[ooooo`03o`000?oooooooooo09[ooooo
000Eooooo`03o`000?oooooooooo06cooooo00?o0000ooooooooool0VOooool001Gooooo00?o0000
ooooooooool0KOooool00ol0003oooooooooo`2Hooooo`005Oooool00ol0003oooooooooo`1]oooo
o`03o`000?oooooooooo09Sooooo000Eooooo`03o`000?oooooooooo06kooooo00?o0000oooooooo
ool0Uoooool001Gooooo00?o0000ooooooooool0Koooool00ol0003oooooooooo`2Fooooo`005Ooo
ool2o`00077ooooo00?o0000ooooooooool0UOooool001Gooooo00?o0000ooooooooool0LOooool0
0ol0003oooooooooo`2Dooooo`005Oooool00ol0003oooooooooo`1booooo`03o`000?oooooooooo
09?ooooo000Eooooo`03o`000?oooooooooo07?ooooo00?o0000ooooooooool0T_ooool001Gooooo
00?o0000ooooooooool0M?ooool00ol0003oooooooooo`2Aooooo`000_ooool2o`0000Cooooo00?o
0000ooooooooool00oooool3o`0000Cooooo00?o0000ooooooooool0MOooool00ol0003ooooooooo
o`2@ooooo`0000Goooooo`000?ooooooooooo`00000:ooooo`03o`000?oooooooooo00?ooooo00?o
0000ooooooooool0M_ooool00ol0003oooooooooo`2?ooooo`0000Goooooo`000?ooooooooooo`00
0007ooooo`Go00001?ooool00ol0003oooooooooo`1fooooo`03o`000?oooooooooo08oooooo0000
1Ooooooo0000oooooooooooo000000Oooooo00Co0000oooooooooooo00001Oooool3o`0007Oooooo
00?o0000ooooooooool0S_ooool00005ooooool0003oooooooooool000002?ooool00ol0003ooooo
o`000005ooooo`03o`000?oooooooooo07Sooooo00?o0000ooooooooool0SOooool00005ooooool0
003oooooooooool000002Oooool2o`0000Gooooo00?o0000ooooooooool0NOooool00ol0003ooooo
ooooo`2<ooooo`000_ooool2o`0000_ooooo00?o0000ooooooooool00oooool00ol0003ooooooooo
o`1jooooo`03o`000?oooooooooo08_ooooo000Eooooo`03o`000?oooooooooo07_ooooo00?o0000
ooooooooool0R_ooool001Gooooo00?o0000ooooooooool0Noooool00ol0003oooooooooo`2:oooo
o`005Oooool00ol0003oooooooooo`1looooo`03o`000?oooooooooo08Wooooo000Eooooo`03o`00
0?oooooooooo07gooooo00?o0000ooooooooool0R?ooool001Gooooo0_l0001oooooo`03o`000?oo
oooooooo08Oooooo000Eooooo`03o`000?oooooooooo07oooooo00?o0000ooooooooool0Q_ooool0
01Gooooo00?o0000ooooooooool0Ooooool00ol0003oooooooooo`26ooooo`005Oooool00ol0003o
ooooooooo`20ooooo`03o`000?oooooooooo08Gooooo000Eooooo`03o`000?oooooooooo087ooooo
00?o0000ooooooooool0Q?ooool001Gooooo00?o0000ooooooooool0POooool00ol0003ooooooooo
o`24ooooo`005Oooool00ol0003oooooooooo`22ooooo`03o`000?oooooooooo08?ooooo000Eoooo
o`03o`000?oooooooooo08;ooooo00?o0000ooooooooool0Poooool001Gooooo0_l00024ooooo`03
o`000?oooooooooo08;ooooo000Eooooo`03o`000?oooooooooo08Cooooo00?o0000ooooooooool0
POooool001Gooooo00?o0000ooooooooool0Q?ooool00ol0003oooooooooo`21ooooo`005Oooool0
0ol0003oooooooooo`25ooooo`03o`000?oooooooooo083ooooo000Eooooo`03o`000?oooooooooo
08Gooooo00?o0000ooooooooool0P?ooool001Gooooo00?o0000ooooooooool0Q_ooool00ol0003o
ooooooooo`1oooooo`005Oooool00ol0003oooooooooo`27ooooo`03o`000?oooooooooo07kooooo
000Eooooo`03o`000?oooooooooo08Oooooo00?o0000ooooooooool0O_ooool001Gooooo0_l00029
ooooo`03o`000?oooooooooo07gooooo000Eooooo`03o`000?oooooooooo08Wooooo00?o0000oooo
ooooool0O?ooool001Gooooo00?o0000ooooooooool0R_ooool00ol0003oooooooooo`1kooooo`00
5Oooool00ol0003oooooooooo`2:ooooo`03o`000?oooooooooo07_ooooo000Eooooo`03o`000?oo
oooooooo08_ooooo00?o0000ooooooooool0N_ooool000;ooooo0_l00004ooooo`03o`000?oooooo
oooo00;ooooo0ol00005ooooo`03o`000?oooooooooo08cooooo00?o0000ooooooooool0NOooool0
0005ooooool0003oooooooooool000001oooool01Ol0003ooooooooooooooooo000000Cooooo00?o
0000ooooooooool0SOooool00ol0003oooooooooo`1hooooo`0000Goooooo`000?ooooooooooo`00
0007ooooo`05o`000?ooooooooooooooool000001?ooool00ol0003oooooooooo`2=ooooo`03o`00
0?oooooooooo07Sooooo00001Ooooooo0000oooooooooooo000000Oooooo1?l00005ooooo`?o0000
S_ooool00ol0003oooooooooo`1gooooo`0000Goooooo`000?ooooooooooo`000007ooooo`03o`00
0?oooooooooo00Kooooo00?o0000ooooooooool0Soooool00ol0003oooooooooo`1fooooo`0000Go
ooooo`000?ooooooooooo`000008ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0
T?ooool00ol0003oooooooooo`1eooooo`000_ooool2o`0000[ooooo0_l00005ooooo`03o`000?oo
oooooooo097ooooo00?o0000ooooooooool0M?ooool001Gooooo00?o0000ooooooooool0T_ooool0
0ol0003oooooooooo`1cooooo`005Oooool00ol0003oooooooooo`2Cooooo`03o`000?oooooooooo
07;ooooo000Eooooo`03o`000?oooooooooo09Cooooo00?o0000ooooooooool0LOooool001Gooooo
00?o0000ooooooooool0UOooool00ol0003oooooooooo`1`ooooo`005Oooool2o`0009Oooooo00?o
0000ooooooooool0Koooool001Gooooo00?o0000ooooooooool0Uoooool00ol0003oooooooooo`1^
ooooo`005Oooool00ol0003oooooooooo`2Hooooo`03o`000?oooooooooo06gooooo000Eooooo`03
o`000?oooooooooo09Wooooo00?o0000ooooooooool0K?ooool001Gooooo00?o0000ooooooooool0
VOooool00ol0003oooooooooo`1/ooooo`005Oooool00ol0003oooooooooo`2Jooooo`03o`000?oo
oooooooo06_ooooo000Eooooo`03o`000?oooooooooo09_ooooo00?o0000ooooooooool0J_ooool0
01Gooooo00?o0000ooooooooool0W?ooool00ol0003oooooooooo`1Yooooo`005Oooool2o`0009ko
oooo00?o0000ooooooooool0J?ooool001Gooooo00?o0000ooooooooool0W_ooool00ol0003ooooo
ooooo`1Wooooo`005Oooool00ol0003oooooooooo`2Oooooo`03o`000?oooooooooo06Kooooo000E
ooooo`03o`000?oooooooooo0:3ooooo00?o0000ooooooooool0IOooool001Gooooo00?o0000oooo
ooooool0XOooool2o`0006Gooooo000Eooooo`03o`000?oooooooooo0:?ooooo00?o0000oooooooo
ool0H_ooool001Gooooo00?o0000ooooooooool0Y?ooool00ol0003oooooooooo`1Qooooo`005Ooo
ool00ol0003oooooooooo`2Uooooo`;o0000HOooool001Gooooo0_l0002Xooooo`03o`000?oooooo
oooo05kooooo000Eooooo`03o`000?oooooooooo0:Sooooo00?o0000ooooooooool0GOooool001Go
oooo00?o0000ooooooooool0ZOooool00ol0003oooooooooo`1Looooo`005Oooool00ol0003ooooo
ooooo`2Zooooo`;o0000G?ooool001Gooooo00?o0000ooooooooool0[?ooool00ol0003ooooooooo
o`1Iooooo`000_ooool2o`0000Cooooo00?o0000ooooooooool00_ooool3o`0000Gooooo00?o0000
ooooooooool0[Oooool00ol0003oooooooooo`1Hooooo`0000Goooooo`000?ooooooooooo`000007
ooooo`05o`000?ooooooooooooooool000001?ooool00ol0003oooooooooo`2^ooooo`;o0000F?oo
ool00005ooooool0003oooooooooool000001oooool01Ol0003ooooooooooooooooo000000Cooooo
00?o0000ooooooooool0/?ooool00ol0003oooooooooo`1Eooooo`0000Goooooo`000?oooooooooo
o`000008ooooo`?o00001Oooool3o`000;7ooooo00?o0000ooooooooool0E?ooool00005ooooool0
003oooooooooool000001oooool01Ol0003ooooooooooooooooo000000Cooooo00?o0000oooooooo
ool0/_ooool2o`0005Cooooo00001Ooooooo0000oooooooooooo000000Oooooo00Go0000oooooooo
ooooooooo`000004ooooo`03o`000?oooooooooo0;Cooooo0_l0001Booooo`000_ooool2o`0000Wo
oooo0ol00005ooooo`03o`000?oooooooooo0;Kooooo0ol0001?ooooo`005Oooool00ol0003ooooo
ooooo`2iooooo`;o0000COooool001Gooooo00?o0000ooooooooool0^oooool2o`0004_ooooo000E
ooooo`03o`000?oooooooooo0;gooooo0_l00019ooooo`005Oooool00ol0003oooooooooo`2ooooo
o`?o0000A_ooool001Gooooo0_l00033ooooo`;o0000A?ooool001Gooooo00?o0000ooooooooool0
a?ooool2o`0004;ooooo000Eooooo`03o`000?oooooooooo0<Kooooo0_l00010ooooo`005Oooool0
0ol0003oooooooooo`38ooooo`;o0000?_ooool001Gooooo00?o0000ooooooooool0b_ooool2o`00
03cooooo000Eooooo`03o`000?oooooooooo0<cooooo0ol0000iooooo`005Oooool00ol0003ooooo
ooooo`3?ooooo`Go0000=?ooool001Gooooo00?o0000ooooooooool0e?ooool4o`00033ooooo000E
ooooo`;o0000fOooool3o`0002gooooo000Eooooo`03o`000?oooooooooo0=_ooooo0ol0000Zoooo
o`005Oooool00ol0003oooooooooo`3Nooooo`Go00009Oooool001Gooooo00?o0000ooooooooool0
hoooool9o`0001cooooo000Eooooo`03o`000?oooooooooo0>cooooo2Ol0000Cooooo`005Oooool0
0ol0003oooooooooo`3eooooo`So00002oooool001Gooooo00?o0000ooooooooool0oOooool4o`00
00Oooooo000Eooooo`03o`000?oooooooooo0?oooooo2Oooool001Gooooo0_l0003oooooo`[ooooo
000Eooooo`03o`000?oooooooooo0?oooooo2Oooool001Gooooo00?o0000ooooooooool0ooooool9
ooooo`005Oooool00ol0003oooooooooo`3oooooo`Wooooo000Eooooo`03o`000?oooooooooo0?oo
oooo2Oooool000gooooo0ol00005ooooo`03o`000?oooooooooo0?oooooo2Oooool000kooooo00?o
0000ooooooooool01?ooool00ol0003oooooooooo`3oooooo`Wooooo000>ooooo`03o`000?oooooo
oooo00Cooooo00?o0000ooooooooool0ooooool9ooooo`003_ooool00ol0003oooooooooo`04oooo
o`?o0000ooooool9ooooo`003_ooool00ol0003oooooooooo`3ooooooa3ooooo000=ooooo`;o0000
oooooolBooooo`003_ooool00ol0003oooooooooo`3ooooooa3ooooo003oooooob7ooooo0000\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-2.49048, -0.0764114, \
0.115739, 0.00624232}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 0.0333333 0 0.618034 [
[.16667 -0.0125 -3 -9 ]
[.16667 -0.0125 3 0 ]
[.33333 -0.0125 -6 -9 ]
[.33333 -0.0125 6 0 ]
[.5 -0.0125 -6 -9 ]
[.5 -0.0125 6 0 ]
[.66667 -0.0125 -6 -9 ]
[.66667 -0.0125 6 0 ]
[.83333 -0.0125 -6 -9 ]
[.83333 -0.0125 6 0 ]
[1 -0.0125 -6 -9 ]
[1 -0.0125 6 0 ]
[-0.0125 .12361 -18 -4.5 ]
[-0.0125 .12361 0 4.5 ]
[-0.0125 .24721 -18 -4.5 ]
[-0.0125 .24721 0 4.5 ]
[-0.0125 .37082 -18 -4.5 ]
[-0.0125 .37082 0 4.5 ]
[-0.0125 .49443 -18 -4.5 ]
[-0.0125 .49443 0 4.5 ]
[-0.0125 .61803 -6 -4.5 ]
[-0.0125 .61803 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.16667 0 m
.16667 .00625 L
s
[(5)] .16667 -0.0125 0 1 Mshowa
.33333 0 m
.33333 .00625 L
s
[(10)] .33333 -0.0125 0 1 Mshowa
.5 0 m
.5 .00625 L
s
[(15)] .5 -0.0125 0 1 Mshowa
.66667 0 m
.66667 .00625 L
s
[(20)] .66667 -0.0125 0 1 Mshowa
.83333 0 m
.83333 .00625 L
s
[(25)] .83333 -0.0125 0 1 Mshowa
1 0 m
1 .00625 L
s
[(30)] 1 -0.0125 0 1 Mshowa
.125 Mabswid
.03333 0 m
.03333 .00375 L
s
.06667 0 m
.06667 .00375 L
s
.1 0 m
.1 .00375 L
s
.13333 0 m
.13333 .00375 L
s
.2 0 m
.2 .00375 L
s
.23333 0 m
.23333 .00375 L
s
.26667 0 m
.26667 .00375 L
s
.3 0 m
.3 .00375 L
s
.36667 0 m
.36667 .00375 L
s
.4 0 m
.4 .00375 L
s
.43333 0 m
.43333 .00375 L
s
.46667 0 m
.46667 .00375 L
s
.53333 0 m
.53333 .00375 L
s
.56667 0 m
.56667 .00375 L
s
.6 0 m
.6 .00375 L
s
.63333 0 m
.63333 .00375 L
s
.7 0 m
.7 .00375 L
s
.73333 0 m
.73333 .00375 L
s
.76667 0 m
.76667 .00375 L
s
.8 0 m
.8 .00375 L
s
.86667 0 m
.86667 .00375 L
s
.9 0 m
.9 .00375 L
s
.93333 0 m
.93333 .00375 L
s
.96667 0 m
.96667 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .12361 m
.00625 .12361 L
s
[(0.2)] -0.0125 .12361 1 0 Mshowa
0 .24721 m
.00625 .24721 L
s
[(0.4)] -0.0125 .24721 1 0 Mshowa
0 .37082 m
.00625 .37082 L
s
[(0.6)] -0.0125 .37082 1 0 Mshowa
0 .49443 m
.00625 .49443 L
s
[(0.8)] -0.0125 .49443 1 0 Mshowa
0 .61803 m
.00625 .61803 L
s
[(1)] -0.0125 .61803 1 0 Mshowa
.125 Mabswid
0 .0309 m
.00375 .0309 L
s
0 .0618 m
.00375 .0618 L
s
0 .09271 m
.00375 .09271 L
s
0 .15451 m
.00375 .15451 L
s
0 .18541 m
.00375 .18541 L
s
0 .21631 m
.00375 .21631 L
s
0 .27812 m
.00375 .27812 L
s
0 .30902 m
.00375 .30902 L
s
0 .33992 m
.00375 .33992 L
s
0 .40172 m
.00375 .40172 L
s
0 .43262 m
.00375 .43262 L
s
0 .46353 m
.00375 .46353 L
s
0 .52533 m
.00375 .52533 L
s
0 .55623 m
.00375 .55623 L
s
0 .58713 m
.00375 .58713 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.03333 .04624 m
.06667 .0504 L
.1 .0544 L
.13333 .05945 L
.16667 .06593 L
.2 .07411 L
.23333 .08428 L
.26667 .09675 L
.3 .11188 L
.33333 .13007 L
.36667 .1518 L
.4 .17758 L
.43333 .20797 L
.46667 .24358 L
.5 .28504 L
.53333 .33299 L
.56667 .37446 L
.6 .41007 L
.63333 .44046 L
.66667 .46623 L
.7 .48796 L
.73333 .50616 L
.76667 .52128 L
.8 .53375 L
.83333 .54392 L
.86667 .5521 L
.9 .55858 L
.93333 .56363 L
.96667 .56764 L
1 .57179 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[6]:=",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/B000`400?l00000o`00003ooooooolQ
ooooo`00?_ooool3o`0002Gooooo0ol00004ooooo`;o00008oooool3o`0000?ooooo0ol0000Qoooo
o`Go00000oooool2o`00027ooooo1Ol00002ooooo`?o00008_ooool3o`0000Cooooo0_l00004oooo
o`00?Oooool01Ol0003ooooooooooooooooo000002Gooooo00?o0000ooooooooool00_ooool01?l0
003oooooooooool0000Sooooo`05o`000?ooooooooooooooool000000oooool00ol0003ooooooooo
o`0Oooooo`04o`000?ooooooooooo`0000;ooooo00Co0000oooooooooooo00008Oooool01_l0003o
ooooooooool0003oooooo`0000?ooooo00?o0000ooooooooool07_ooool01Ol0003ooooooooooooo
oooo000000;ooooo00Co0000oooooooooooo00000oooool0047ooooo00?o0000ooooooooool08ooo
ool00ol0003oooooooooo`02ooooo`04o`000?ooooooooooo`0002?ooooo00?o0000ooooooooool0
1Oooool00ol0003oooooooooo`0Pooooo`03o`000?oooooooooo00;ooooo00Co0000oooooooooooo
00008_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo02;ooooo00Co0000oooooooo
oooo00000_ooool00ol0003oooooooooo`01ooooo`00@Oooool00ol0003oooooooooo`0Sooooo`03
o`000?oooooooooo00;ooooo00Co0000oooooooooooo00008oooool00ol0003oooooooooo`05oooo
o`03o`000?oooooooooo027ooooo00Go0000ooooooooooooooooo`000002ooooo`03o`000?oooooo
oooo027ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`0Pooooo`;o00000oooool0
1?l0003oooooooooool00003ooooo`00?Oooool4o`0002Kooooo00?o0000ooooooooool00_ooool0
1?l0003oooooooooool0000Sooooo`04o`000?ooooooooooooooo`Co00008Oooool01Ol0003ooooo
oooooooooooo000000;ooooo00Co0000oooooooooooo00008?ooool01_l0003ooooooooooooooooo
0000ooooo`Co00009Oooool01?l0003oooooooooool00002ooooo`03o`000?oooooooooo007ooooo
000mooooo`03o`000?oooooooooo02Kooooo0_l00004ooooo`04o`000?ooooooooooo`0002;ooooo
0_l00003ooooo`03o`000?oooooooooo02;ooooo00Go0000ooooooooooooooooo`000002ooooo`04
o`000?ooooooooooo`00023ooooo00Oo0000ooooooooooooooooo`000?oooooo000002Cooooo00Go
0000ooooooooooooooooo`000002ooooo`04o`000?ooooooooooo`0000?ooooo000mooooo`Go0000
9Oooool00ol0003oooooooooo`03ooooo`;o00009?ooool01?l0003oooooooooooooool5o`00027o
oooo0ol00004ooooo`;o00008_ooool3o`0000;ooooo1Ol0000Qooooo`?o00001?ooool2o`0000Co
oooo003oooooob7ooooo003oooooob7ooooo003oooooob7ooooo003oooooob7ooooo000Eoooooooo
00001Ol00007ooooo`005Oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Gooooo
00?o0000ooooooooool01_ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Gooooo
00?o0000ooooooooool01_ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Gooooo
00?o0000ooooooooool01_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Kooooo
00?o0000ooooooooool01_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Kooooo
00?o0000ooooooooool01_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Kooooo
00?o0000ooooooooool01_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Kooooo
00?o0000ooooooooool01Oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Kooooo
00?o0000ooooooooool01Oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Kooooo
00?o0000ooooooooool01Oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Kooooo
00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`005Oooool00ol0003ooooooooo
o`3oooooo`Wooooo000Eooooo`03o`000?oooooooooo0?oooooo2Oooool001Gooooo00?o0000oooo
ooooool0ooooool9ooooo`005Oooool00ol0003oooooooooo`3oooooo`Wooooo000Eooooo`03o`00
0?oooooooooo0?oooooo2Oooool001Gooooo00?o0000ooooooooool0ooooool9ooooo`005Oooool2
o`000?oooooo2_ooool001Gooooo00?o0000ooooooooool0ooooool9ooooo`005Oooool00ol0003o
ooooooooo`3oooooo`Wooooo000Eooooo`03o`000?oooooooooo0?oooooo2Oooool001Gooooo00?o
0000ooooooooool01_ooool5o`000?gooooo000Eooooo`03o`000?oooooooooo00_ooooo2Ol0003d
ooooo`005Oooool00ol0003oooooooooo`0Dooooo`Wo0000joooool001Gooooo00?o0000oooooooo
ool07Oooool6o`000>Gooooo000Eooooo`;o00009?ooool4o`000>7ooooo000Eooooo`03o`000?oo
oooooooo02Oooooo1?l0003Mooooo`005Oooool00ol0003oooooooooo`0[ooooo`Go0000f?ooool0
01Gooooo00?o0000ooooooooool0<?ooool4o`000=Cooooo000Eooooo`03o`000?oooooooooo03Co
oooo0ol0003Aooooo`005Oooool00ol0003oooooooooo`0gooooo`?o0000c_ooool001Gooooo00?o
0000ooooooooool0>_ooool2o`000<cooooo000Eooooo`03o`000?oooooooooo03cooooo0ol00039
ooooo`005Oooool2o`00043ooooo0ol00036ooooo`005Oooool00ol0003oooooooooo`12ooooo`;o
0000a?ooool001Gooooo00?o0000ooooooooool0A?ooool2o`000<;ooooo000Eooooo`03o`000?oo
oooooooo04Kooooo0ol0002oooooo`005Oooool00ol0003oooooooooo`19ooooo`;o0000_Oooool0
00;ooooo0_l00004ooooo`04o`000?ooooooooooooooo`Go00001?ooool00ol0003oooooooooo`1;
ooooo`;o0000^oooool00005ooooool0003oooooooooool000002?ooool01?l0003oooooooooool0
0004ooooo`03o`000?oooooooooo04gooooo00?o0000ooooooooool0^?ooool00005ooooool0003o
ooooooooool000002Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo04kooooo0_l0
002hooooo`0000Goooooo`000?ooooooooooo`00000:ooooo`03o`000?oooooooooo00?ooooo0ol0
001@ooooo`;o0000]_ooool00005ooooool0003oooooooooool000001oooool01Ol0003ooooooooo
oooooooo000000Cooooo00?o0000ooooooooool0D_ooool00ol0003oooooooooo`2cooooo`0000Go
ooooo`000?ooooooooooo`000007ooooo`05o`000?ooooooooooooooool000001?ooool00ol0003o
ooooooooo`1Cooooo`;o0000/oooool000;ooooo0_l00009ooooo`?o00001Oooool00ol0003ooooo
ooooo`1Eooooo`;o0000/Oooool001Gooooo00?o0000ooooooooool0Eoooool2o`000:oooooo000E
ooooo`03o`000?oooooooooo05Wooooo00?o0000ooooooooool0[?ooool001Gooooo00?o0000oooo
ooooool0F_ooool2o`000:cooooo000Eooooo`03o`000?oooooooooo05cooooo0_l0002Zooooo`00
5Oooool2o`0005oooooo00?o0000ooooooooool0Yoooool001Gooooo00?o0000ooooooooool0Gooo
ool00ol0003oooooooooo`2Vooooo`005Oooool00ol0003oooooooooo`1Pooooo`;o0000Y_ooool0
01Gooooo00?o0000ooooooooool0H_ooool00ol0003oooooooooo`2Sooooo`005Oooool00ol0003o
ooooooooo`1Sooooo`03o`000?oooooooooo0:;ooooo000Eooooo`03o`000?oooooooooo06Cooooo
00?o0000ooooooooool0XOooool001Gooooo00?o0000ooooooooool0IOooool00ol0003ooooooooo
o`2Pooooo`005Oooool00ol0003oooooooooo`1Vooooo`03o`000?oooooooooo09oooooo000Eoooo
o`;o0000J?ooool00ol0003oooooooooo`2Nooooo`005Oooool00ol0003oooooooooo`1Xooooo`03
o`000?oooooooooo09gooooo000Eooooo`03o`000?oooooooooo06Wooooo00?o0000ooooooooool0
W?ooool001Gooooo00?o0000ooooooooool0J_ooool00ol0003oooooooooo`2Kooooo`005Oooool0
0ol0003oooooooooo`1[ooooo`03o`000?oooooooooo09[ooooo000Eooooo`03o`000?oooooooooo
06cooooo00?o0000ooooooooool0VOooool001Gooooo00?o0000ooooooooool0KOooool00ol0003o
ooooooooo`2Hooooo`005Oooool00ol0003oooooooooo`1^ooooo`03o`000?oooooooooo09Oooooo
000Eooooo`;o0000L?ooool00ol0003oooooooooo`2Fooooo`005Oooool00ol0003oooooooooo`1`
ooooo`03o`000?oooooooooo09Gooooo000Eooooo`03o`000?oooooooooo077ooooo00?o0000oooo
ooooool0U?ooool001Gooooo00?o0000ooooooooool0L_ooool00ol0003oooooooooo`2Cooooo`00
5Oooool00ol0003oooooooooo`1cooooo`03o`000?oooooooooo09;ooooo0002ooooo`;o00001?oo
ool00ol0003oooooooooo`03ooooo`?o00001?ooool00ol0003oooooooooo`1dooooo`03o`000?oo
oooooooo097ooooo00001Ooooooo0000oooooooooooo000000[ooooo00?o0000ooooooooool00ooo
ool00ol0003oooooooooo`1eooooo`03o`000?oooooooooo093ooooo00001Ooooooo0000oooooooo
oooo000000Oooooo1Ol00004ooooo`03o`000?oooooooooo07Kooooo00?o0000ooooooooool0Sooo
ool00005ooooool0003oooooooooool000001oooool01?l0003oooooooooool00005ooooo`?o0000
M_ooool00ol0003oooooooooo`2?ooooo`0000Goooooo`000?ooooooooooo`000008ooooo`03o`00
0?oooooo000000Gooooo00?o0000ooooooooool0Moooool00ol0003oooooooooo`2>ooooo`0000Go
ooooo`000?ooooooooooo`000009ooooo`;o00001Oooool00ol0003oooooooooo`1hooooo`03o`00
0?oooooooooo08gooooo0002ooooo`;o00002oooool00ol0003oooooooooo`03ooooo`03o`000?oo
oooooooo07Wooooo00?o0000ooooooooool0S?ooool001Gooooo00?o0000ooooooooool0N_ooool0
0ol0003oooooooooo`2;ooooo`005Oooool00ol0003oooooooooo`1kooooo`03o`000?oooooooooo
08[ooooo000Eooooo`03o`000?oooooooooo07_ooooo00?o0000ooooooooool0R_ooool001Gooooo
00?o0000ooooooooool0O?ooool00ol0003oooooooooo`29ooooo`005Oooool2o`0007kooooo00?o
0000ooooooooool0R?ooool001Gooooo00?o0000ooooooooool0O_ooool00ol0003oooooooooo`27
ooooo`005Oooool00ol0003oooooooooo`1oooooo`03o`000?oooooooooo08Kooooo000Eooooo`03
o`000?oooooooooo07oooooo00?o0000ooooooooool0Q_ooool001Gooooo00?o0000ooooooooool0
P?ooool00ol0003oooooooooo`25ooooo`005Oooool00ol0003oooooooooo`21ooooo`03o`000?oo
oooooooo08Cooooo000Eooooo`03o`000?oooooooooo087ooooo00?o0000ooooooooool0Q?ooool0
01Gooooo00?o0000ooooooooool0P_ooool00ol0003oooooooooo`23ooooo`005Oooool2o`0008Co
oooo00?o0000ooooooooool0P_ooool001Gooooo00?o0000ooooooooool0Poooool00ol0003ooooo
ooooo`22ooooo`005Oooool00ol0003oooooooooo`24ooooo`03o`000?oooooooooo087ooooo000E
ooooo`03o`000?oooooooooo08Gooooo00?o0000ooooooooool0P?ooool001Gooooo00?o0000oooo
ooooool0QOooool00ol0003oooooooooo`20ooooo`005Oooool00ol0003oooooooooo`26ooooo`03
o`000?oooooooooo07oooooo000Eooooo`03o`000?oooooooooo08Oooooo00?o0000ooooooooool0
O_ooool001Gooooo00?o0000ooooooooool0Qoooool00ol0003oooooooooo`1nooooo`005Oooool2
o`0008Wooooo00?o0000ooooooooool0OOooool001Gooooo00?o0000ooooooooool0ROooool00ol0
003oooooooooo`1looooo`005Oooool00ol0003oooooooooo`2:ooooo`03o`000?oooooooooo07_o
oooo000Eooooo`03o`000?oooooooooo08_ooooo00?o0000ooooooooool0N_ooool001Gooooo00?o
0000ooooooooool0S?ooool00ol0003oooooooooo`1iooooo`000_ooool2o`0000Cooooo00?o0000
ooooooooool00_ooool3o`0000Gooooo00?o0000ooooooooool0S?ooool00ol0003oooooooooo`1i
ooooo`0000Goooooo`000?ooooooooooo`000007ooooo`05o`000?ooooooooooooooool000001?oo
ool00ol0003oooooooooo`2=ooooo`03o`000?oooooooooo07Sooooo00001Ooooooo0000oooooooo
oooo000000Oooooo00Go0000ooooooooooooooooo`000004ooooo`03o`000?oooooooooo08kooooo
00?o0000ooooooooool0Moooool00005ooooool0003oooooooooool000001oooool4o`0000Gooooo
0ol0002?ooooo`03o`000?oooooooooo07Kooooo00001Ooooooo0000oooooooooooo000000Oooooo
00?o0000ooooooooool01_ooool00ol0003oooooooooo`2@ooooo`03o`000?oooooooooo07Gooooo
00001Ooooooo0000oooooooooooo000000Sooooo00?o0000ooooooooool01Oooool00ol0003ooooo
ooooo`2Aooooo`03o`000?oooooooooo07Cooooo0002ooooo`;o00002_ooool2o`0000Gooooo00?o
0000ooooooooool0T_ooool00ol0003oooooooooo`1cooooo`005Oooool00ol0003oooooooooo`2C
ooooo`03o`000?oooooooooo07;ooooo000Eooooo`03o`000?oooooooooo09Cooooo00?o0000oooo
ooooool0LOooool001Gooooo00?o0000ooooooooool0UOooool00ol0003oooooooooo`1`ooooo`00
5Oooool00ol0003oooooooooo`2Fooooo`03o`000?oooooooooo06oooooo000Eooooo`;o0000V?oo
ool00ol0003oooooooooo`1^ooooo`005Oooool00ol0003oooooooooo`2Hooooo`03o`000?oooooo
oooo06gooooo000Eooooo`03o`000?oooooooooo09Wooooo00?o0000ooooooooool0K?ooool001Go
oooo00?o0000ooooooooool0V_ooool00ol0003oooooooooo`1[ooooo`005Oooool00ol0003ooooo
ooooo`2Kooooo`03o`000?oooooooooo06[ooooo000Eooooo`03o`000?oooooooooo09cooooo00?o
0000ooooooooool0JOooool001Gooooo00?o0000ooooooooool0WOooool00ol0003oooooooooo`1X
ooooo`005Oooool00ol0003oooooooooo`2Nooooo`03o`000?oooooooooo06Oooooo000Eooooo`;o
0000X?ooool00ol0003oooooooooo`1Vooooo`005Oooool00ol0003oooooooooo`2Pooooo`03o`00
0?oooooooooo06Gooooo000Eooooo`03o`000?oooooooooo0:7ooooo0_l0001Uooooo`005Oooool0
0ol0003oooooooooo`2Sooooo`03o`000?oooooooooo06;ooooo000Eooooo`03o`000?oooooooooo
0:Cooooo00?o0000ooooooooool0HOooool001Gooooo00?o0000ooooooooool0YOooool2o`00067o
oooo000Eooooo`03o`000?oooooooooo0:Oooooo00?o0000ooooooooool0G_ooool001Gooooo00?o
0000ooooooooool0Z?ooool00ol0003oooooooooo`1Mooooo`005Oooool2o`000:[ooooo00?o0000
ooooooooool0G?ooool001Gooooo00?o0000ooooooooool0Z_ooool2o`0005cooooo000Eooooo`03
o`000?oooooooooo0:cooooo00?o0000ooooooooool0FOooool001Gooooo00?o0000ooooooooool0
[Oooool2o`0005Wooooo000Eooooo`03o`000?oooooooooo0:oooooo0_l0001Gooooo`000_ooool2
o`0000Cooooo00?o0000ooooooooool00_ooool3o`0000Gooooo00?o0000ooooooooool0/Oooool0
0ol0003oooooooooo`1Dooooo`0000Goooooo`000?ooooooooooo`000007ooooo`05o`000?oooooo
ooooooooool000001?ooool00ol0003oooooooooo`2booooo`;o0000E?ooool00005ooooool0003o
ooooooooool000001oooool01Ol0003ooooooooooooooooo000000Cooooo00?o0000ooooooooool0
]?ooool2o`0005;ooooo00001Ooooooo0000oooooooooooo000000Sooooo0ol00005ooooo`?o0000
]_ooool2o`00053ooooo00001Ooooooo0000oooooooooooo000000Oooooo00Go0000oooooooooooo
ooooo`000004ooooo`03o`000?oooooooooo0;Sooooo00?o0000ooooooooool0COooool00005oooo
ool0003oooooooooool000001oooool01Ol0003ooooooooooooooooo000000Cooooo00?o0000oooo
ooooool0^Oooool2o`0004gooooo0002ooooo`;o00002Oooool3o`0000Gooooo00?o0000oooooooo
ool0^oooool2o`0004_ooooo000Eooooo`03o`000?oooooooooo0;gooooo0_l00019ooooo`005Ooo
ool00ol0003oooooooooo`2oooooo`?o0000A_ooool001Gooooo00?o0000ooooooooool0`_ooool2
o`0004Cooooo000Eooooo`03o`000?oooooooooo0<Cooooo0_l00012ooooo`005Oooool2o`000<Oo
oooo0ol0000oooooo`005Oooool00ol0003oooooooooo`39ooooo`?o0000??ooool001Gooooo00?o
0000ooooooooool0c?ooool3o`0003Wooooo000Eooooo`03o`000?oooooooooo0<oooooo0ol0000f
ooooo`005Oooool00ol0003oooooooooo`3Booooo`?o0000<oooool001Gooooo00?o0000oooooooo
ool0eOooool3o`00033ooooo000Eooooo`03o`000?oooooooooo0=Sooooo1Ol0000[ooooo`005Ooo
ool00ol0003oooooooooo`3Mooooo`Co00009oooool001Gooooo0_l0003Rooooo`Co00008oooool0
01Gooooo00?o0000ooooooooool0iOooool7o`0001cooooo000Eooooo`03o`000?oooooooooo0>co
oooo2Ol0000Cooooo`005Oooool00ol0003oooooooooo`3eooooo`So00002oooool001Gooooo00?o
0000ooooooooool0oOooool4o`0000Oooooo000Eooooo`03o`000?oooooooooo0?oooooo2Oooool0
01Gooooo00?o0000ooooooooool0ooooool9ooooo`005Oooool00ol0003oooooooooo`3oooooo`Wo
oooo000Eooooo`;o0000ooooool:ooooo`005Oooool00ol0003oooooooooo`3oooooo`Wooooo000E
ooooo`03o`000?oooooooooo0?oooooo2Oooool001Gooooo00?o0000ooooooooool0ooooool9oooo
o`005Oooool00ol0003oooooooooo`3oooooo`Wooooo000=ooooo`?o00001Oooool00ol0003ooooo
ooooo`3oooooo`Wooooo000>ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0oooo
ool9ooooo`003_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo0?oooooo2Oooool0
00kooooo00?o0000ooooooooool01?ooool3o`000?oooooo2Oooool000kooooo00?o0000oooooooo
ool0ooooool@ooooo`003Oooool2o`000?oooooo4_ooool000kooooo00?o0000ooooooooool0oooo
ool@ooooo`00oooooolQooooo`00\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-2.49048, -0.0764114, \
0.115739, 0.00624232}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 0.0333333 0 0.618034 [
[.16667 -0.0125 -3 -9 ]
[.16667 -0.0125 3 0 ]
[.33333 -0.0125 -6 -9 ]
[.33333 -0.0125 6 0 ]
[.5 -0.0125 -6 -9 ]
[.5 -0.0125 6 0 ]
[.66667 -0.0125 -6 -9 ]
[.66667 -0.0125 6 0 ]
[.83333 -0.0125 -6 -9 ]
[.83333 -0.0125 6 0 ]
[1 -0.0125 -6 -9 ]
[1 -0.0125 6 0 ]
[-0.0125 .12361 -18 -4.5 ]
[-0.0125 .12361 0 4.5 ]
[-0.0125 .24721 -18 -4.5 ]
[-0.0125 .24721 0 4.5 ]
[-0.0125 .37082 -18 -4.5 ]
[-0.0125 .37082 0 4.5 ]
[-0.0125 .49443 -18 -4.5 ]
[-0.0125 .49443 0 4.5 ]
[-0.0125 .61803 -6 -4.5 ]
[-0.0125 .61803 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.16667 0 m
.16667 .00625 L
s
[(5)] .16667 -0.0125 0 1 Mshowa
.33333 0 m
.33333 .00625 L
s
[(10)] .33333 -0.0125 0 1 Mshowa
.5 0 m
.5 .00625 L
s
[(15)] .5 -0.0125 0 1 Mshowa
.66667 0 m
.66667 .00625 L
s
[(20)] .66667 -0.0125 0 1 Mshowa
.83333 0 m
.83333 .00625 L
s
[(25)] .83333 -0.0125 0 1 Mshowa
1 0 m
1 .00625 L
s
[(30)] 1 -0.0125 0 1 Mshowa
.125 Mabswid
.03333 0 m
.03333 .00375 L
s
.06667 0 m
.06667 .00375 L
s
.1 0 m
.1 .00375 L
s
.13333 0 m
.13333 .00375 L
s
.2 0 m
.2 .00375 L
s
.23333 0 m
.23333 .00375 L
s
.26667 0 m
.26667 .00375 L
s
.3 0 m
.3 .00375 L
s
.36667 0 m
.36667 .00375 L
s
.4 0 m
.4 .00375 L
s
.43333 0 m
.43333 .00375 L
s
.46667 0 m
.46667 .00375 L
s
.53333 0 m
.53333 .00375 L
s
.56667 0 m
.56667 .00375 L
s
.6 0 m
.6 .00375 L
s
.63333 0 m
.63333 .00375 L
s
.7 0 m
.7 .00375 L
s
.73333 0 m
.73333 .00375 L
s
.76667 0 m
.76667 .00375 L
s
.8 0 m
.8 .00375 L
s
.86667 0 m
.86667 .00375 L
s
.9 0 m
.9 .00375 L
s
.93333 0 m
.93333 .00375 L
s
.96667 0 m
.96667 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .12361 m
.00625 .12361 L
s
[(0.2)] -0.0125 .12361 1 0 Mshowa
0 .24721 m
.00625 .24721 L
s
[(0.4)] -0.0125 .24721 1 0 Mshowa
0 .37082 m
.00625 .37082 L
s
[(0.6)] -0.0125 .37082 1 0 Mshowa
0 .49443 m
.00625 .49443 L
s
[(0.8)] -0.0125 .49443 1 0 Mshowa
0 .61803 m
.00625 .61803 L
s
[(1)] -0.0125 .61803 1 0 Mshowa
.125 Mabswid
0 .0309 m
.00375 .0309 L
s
0 .0618 m
.00375 .0618 L
s
0 .09271 m
.00375 .09271 L
s
0 .15451 m
.00375 .15451 L
s
0 .18541 m
.00375 .18541 L
s
0 .21631 m
.00375 .21631 L
s
0 .27812 m
.00375 .27812 L
s
0 .30902 m
.00375 .30902 L
s
0 .33992 m
.00375 .33992 L
s
0 .40172 m
.00375 .40172 L
s
0 .43262 m
.00375 .43262 L
s
0 .46353 m
.00375 .46353 L
s
0 .52533 m
.00375 .52533 L
s
0 .55623 m
.00375 .55623 L
s
0 .58713 m
.00375 .58713 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.03333 .05388 m
.06667 .0586 L
.1 .0628 L
.13333 .06791 L
.16667 .07438 L
.2 .08247 L
.23333 .09246 L
.26667 .10462 L
.3 .11931 L
.33333 .1369 L
.36667 .15782 L
.4 .1826 L
.43333 .21177 L
.46667 .24597 L
.5 .28587 L
.53333 .33216 L
.56667 .37206 L
.6 .40626 L
.63333 .43544 L
.66667 .46021 L
.7 .48114 L
.73333 .49873 L
.76667 .51341 L
.8 .52558 L
.83333 .53556 L
.86667 .54365 L
.9 .55012 L
.93333 .55524 L
.96667 .55944 L
1 .56416 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[6]:=",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/B000`400?l00000o`00003ooooooolQ
ooooo`00?_ooool3o`0002Gooooo0ol00004ooooo`;o00008oooool3o`0000?ooooo0ol0000Qoooo
o`Go00000oooool2o`00027ooooo1Ol00002ooooo`?o00008_ooool3o`0000Cooooo0_l00004oooo
o`00?Oooool01Ol0003ooooooooooooooooo000002Gooooo00?o0000ooooooooool00_ooool01?l0
003oooooooooool0000Sooooo`05o`000?ooooooooooooooool000000oooool00ol0003ooooooooo
o`0Oooooo`04o`000?ooooooooooo`0000;ooooo00Co0000oooooooooooo00008Oooool01_l0003o
ooooooooool0003oooooo`0000?ooooo00?o0000ooooooooool07_ooool01Ol0003ooooooooooooo
oooo000000;ooooo00Co0000oooooooooooo00000oooool0047ooooo00?o0000ooooooooool08ooo
ool00ol0003oooooooooo`02ooooo`04o`000?ooooooooooo`0002?ooooo00?o0000ooooooooool0
1Oooool00ol0003oooooooooo`0Pooooo`03o`000?oooooooooo00;ooooo00Co0000oooooooooooo
00008_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo02;ooooo00Co0000oooooooo
oooo00000_ooool00ol0003oooooooooo`01ooooo`00@Oooool00ol0003oooooooooo`0Sooooo`03
o`000?oooooooooo00;ooooo00Co0000oooooooooooo00008oooool00ol0003oooooooooo`05oooo
o`03o`000?oooooooooo027ooooo00Go0000ooooooooooooooooo`000002ooooo`03o`000?oooooo
oooo027ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`0Pooooo`;o00000oooool0
1?l0003oooooooooool00003ooooo`00?Oooool4o`0002Kooooo00?o0000ooooooooool00_ooool0
1?l0003oooooooooool0000Sooooo`04o`000?ooooooooooooooo`Co00008Oooool01Ol0003ooooo
oooooooooooo000000;ooooo00Co0000oooooooooooo00008?ooool01_l0003ooooooooooooooooo
0000ooooo`Co00009Oooool01?l0003oooooooooool00002ooooo`03o`000?oooooooooo007ooooo
000mooooo`03o`000?oooooooooo02Kooooo0_l00004ooooo`04o`000?ooooooooooo`0002;ooooo
0_l00003ooooo`03o`000?oooooooooo02;ooooo00Go0000ooooooooooooooooo`000002ooooo`04
o`000?ooooooooooo`00023ooooo00Oo0000ooooooooooooooooo`000?oooooo000002Cooooo00Go
0000ooooooooooooooooo`000002ooooo`04o`000?ooooooooooo`0000?ooooo000mooooo`Go0000
9Oooool00ol0003oooooooooo`03ooooo`;o00009?ooool01?l0003oooooooooooooool5o`00027o
oooo0ol00004ooooo`;o00008_ooool3o`0000;ooooo1Ol0000Qooooo`?o00001?ooool2o`0000Co
oooo003oooooob7ooooo003oooooob7ooooo003oooooob7ooooo003oooooob7ooooo000Eoooooooo
00001Ol00007ooooo`005Oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Gooooo
00?o0000ooooooooool01_ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Gooooo
00?o0000ooooooooool01_ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Gooooo
00?o0000ooooooooool01_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Kooooo
00?o0000ooooooooool01_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Kooooo
00?o0000ooooooooool01_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Kooooo
00?o0000ooooooooool01_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Kooooo
00?o0000ooooooooool01Oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Kooooo
00?o0000ooooooooool01Oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Kooooo
00?o0000ooooooooool01Oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Kooooo
00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`005Oooool00ol0003ooooooooo
o`3oooooo`Wooooo000Eooooo`03o`000?oooooooooo0?oooooo2Oooool001Gooooo00?o0000oooo
ooooool0ooooool9ooooo`005Oooool00ol0003oooooooooo`3oooooo`Wooooo000Eooooo`03o`00
0?oooooooooo0?oooooo2Oooool001Gooooo00?o0000ooooooooool0ooooool9ooooo`005Oooool2
o`000?oooooo2_ooool001Gooooo00?o0000ooooooooool0ooooool9ooooo`005Oooool00ol0003o
ooooooooo`3oooooo`Wooooo000Eooooo`03o`000?oooooooooo0?oooooo2Oooool001Gooooo00?o
0000ooooooooool0ooooool9ooooo`005Oooool00ol0003oooooooooo`3oooooo`Wooooo000Eoooo
o`03o`000?oooooooooo00Kooooo1Ol0003mooooo`005Oooool00ol0003oooooooooo`0;ooooo`Wo
0000m?ooool001Gooooo0_l0000Eooooo`Wo0000joooool001Gooooo00?o0000ooooooooool07Ooo
ool6o`000>Gooooo000Eooooo`03o`000?oooooooooo02?ooooo1?l0003Qooooo`005Oooool00ol0
003oooooooooo`0Wooooo`Co0000gOooool001Gooooo00?o0000ooooooooool0:oooool5o`000=So
oooo000Eooooo`03o`000?oooooooooo033ooooo1?l0003Dooooo`005Oooool00ol0003ooooooooo
o`0dooooo`?o0000dOooool001Gooooo00?o0000ooooooooool0=oooool3o`000<kooooo000Eoooo
o`;o0000>oooool2o`000<cooooo000Eooooo`03o`000?oooooooooo03cooooo0ol00039ooooo`00
5Oooool00ol0003oooooooooo`0oooooo`?o0000a_ooool001Gooooo00?o0000ooooooooool0@_oo
ool2o`000<Cooooo000Eooooo`03o`000?oooooooooo04Cooooo0_l00032ooooo`000_ooool2o`00
00Cooooo00Co0000oooooooooooooooo1Ol00004ooooo`03o`000?oooooooooo04Kooooo0ol0002o
ooooo`0000Goooooo`000?ooooooooooo`000008ooooo`04o`000?ooooooooooo`0000Cooooo00?o
0000ooooooooool0BOooool2o`000;gooooo00001Ooooooo0000oooooooooooo000000Wooooo00?o
0000ooooooooool01?ooool00ol0003oooooooooo`1;ooooo`;o0000^oooool00005ooooool0003o
ooooooooool000002_ooool00ol0003oooooooooo`03ooooo`?o0000COooool2o`000;Wooooo0000
1Ooooooo0000oooooooooooo000000Oooooo00Go0000ooooooooooooooooo`000004ooooo`03o`00
0?oooooooooo04oooooo0_l0002gooooo`0000Goooooo`000?ooooooooooo`000007ooooo`05o`00
0?ooooooooooooooool000001?ooool00ol0003oooooooooo`1Aooooo`;o0000]Oooool000;ooooo
0_l00009ooooo`?o00001Oooool00ol0003oooooooooo`1Cooooo`;o0000/oooool001Gooooo00?o
0000ooooooooool0EOooool00ol0003oooooooooo`2`ooooo`005Oooool00ol0003oooooooooo`1F
ooooo`;o0000/?ooool001Gooooo00?o0000ooooooooool0F?ooool00ol0003oooooooooo`2]oooo
o`005Oooool00ol0003oooooooooo`1Iooooo`;o0000[Oooool001Gooooo0_l0001Looooo`03o`00
0?oooooooooo0:[ooooo000Eooooo`03o`000?oooooooooo05cooooo0_l0002Zooooo`005Oooool0
0ol0003oooooooooo`1Nooooo`03o`000?oooooooooo0:Oooooo000Eooooo`03o`000?oooooooooo
05oooooo0_l0002Wooooo`005Oooool00ol0003oooooooooo`1Qooooo`03o`000?oooooooooo0:Co
oooo000Eooooo`03o`000?oooooooooo06;ooooo0_l0002Tooooo`005Oooool00ol0003ooooooooo
o`1Tooooo`03o`000?oooooooooo0:7ooooo000Eooooo`03o`000?oooooooooo06Gooooo00?o0000
ooooooooool0X?ooool001Gooooo0_l0001Wooooo`03o`000?oooooooooo09oooooo000Eooooo`03
o`000?oooooooooo06Oooooo00?o0000ooooooooool0W_ooool001Gooooo00?o0000ooooooooool0
J?ooool00ol0003oooooooooo`2Mooooo`005Oooool00ol0003oooooooooo`1Yooooo`03o`000?oo
oooooooo09cooooo000Eooooo`03o`000?oooooooooo06[ooooo00?o0000ooooooooool0Voooool0
01Gooooo00?o0000ooooooooool0Joooool00ol0003oooooooooo`2Jooooo`005Oooool00ol0003o
ooooooooo`1/ooooo`03o`000?oooooooooo09Wooooo000Eooooo`03o`000?oooooooooo06gooooo
00?o0000ooooooooool0V?ooool001Gooooo0_l0001_ooooo`03o`000?oooooooooo09Oooooo000E
ooooo`03o`000?oooooooooo06oooooo00?o0000ooooooooool0U_ooool001Gooooo00?o0000oooo
ooooool0L?ooool00ol0003oooooooooo`2Eooooo`005Oooool00ol0003oooooooooo`1aooooo`03
o`000?oooooooooo09Cooooo000Eooooo`03o`000?oooooooooo07;ooooo00?o0000ooooooooool0
Toooool000;ooooo0_l00004ooooo`03o`000?oooooooooo00?ooooo0ol00004ooooo`03o`000?oo
oooooooo07?ooooo00?o0000ooooooooool0T_ooool00005ooooool0003oooooooooool000002_oo
ool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo07Cooooo00?o0000ooooooooool0TOoo
ool00005ooooool0003oooooooooool000001oooool5o`0000Cooooo00?o0000ooooooooool0MOoo
ool00ol0003oooooooooo`2@ooooo`0000Goooooo`000?ooooooooooo`000007ooooo`04o`000?oo
ooooooooo`0000Gooooo0ol0001fooooo`03o`000?oooooooooo08oooooo00001Ooooooo0000oooo
oooooooo000000Sooooo00?o0000ooooool000001Oooool00ol0003oooooooooo`1fooooo`03o`00
0?oooooooooo08oooooo00001Ooooooo0000oooooooooooo000000Wooooo0_l00005ooooo`03o`00
0?oooooooooo07Oooooo00?o0000ooooooooool0S_ooool000;ooooo0_l0000;ooooo`03o`000?oo
oooooooo00?ooooo00?o0000ooooooooool0N?ooool00ol0003oooooooooo`2=ooooo`005Oooool0
0ol0003oooooooooo`1iooooo`03o`000?oooooooooo08cooooo000Eooooo`03o`000?oooooooooo
07[ooooo00?o0000ooooooooool0Roooool001Gooooo00?o0000ooooooooool0Noooool00ol0003o
ooooooooo`2:ooooo`005Oooool00ol0003oooooooooo`1looooo`03o`000?oooooooooo08Wooooo
000Eooooo`;o0000O_ooool00ol0003oooooooooo`28ooooo`005Oooool00ol0003oooooooooo`1n
ooooo`03o`000?oooooooooo08Oooooo000Eooooo`03o`000?oooooooooo07oooooo00?o0000oooo
ooooool0Q_ooool001Gooooo00?o0000ooooooooool0Ooooool00ol0003oooooooooo`26ooooo`00
5Oooool00ol0003oooooooooo`20ooooo`03o`000?oooooooooo08Gooooo000Eooooo`03o`000?oo
oooooooo087ooooo00?o0000ooooooooool0Q?ooool001Gooooo00?o0000ooooooooool0POooool0
0ol0003oooooooooo`24ooooo`005Oooool00ol0003oooooooooo`22ooooo`03o`000?oooooooooo
08?ooooo000Eooooo`;o0000Q?ooool00ol0003oooooooooo`22ooooo`005Oooool00ol0003ooooo
ooooo`23ooooo`03o`000?oooooooooo08;ooooo000Eooooo`03o`000?oooooooooo08Cooooo00?o
0000ooooooooool0POooool001Gooooo00?o0000ooooooooool0QOooool00ol0003oooooooooo`20
ooooo`005Oooool00ol0003oooooooooo`25ooooo`03o`000?oooooooooo083ooooo000Eooooo`03
o`000?oooooooooo08Kooooo00?o0000ooooooooool0Ooooool001Gooooo00?o0000ooooooooool0
Qoooool00ol0003oooooooooo`1nooooo`005Oooool00ol0003oooooooooo`27ooooo`03o`000?oo
oooooooo07kooooo000Eooooo`;o0000ROooool00ol0003oooooooooo`1mooooo`005Oooool00ol0
003oooooooooo`29ooooo`03o`000?oooooooooo07cooooo000Eooooo`03o`000?oooooooooo08[o
oooo00?o0000ooooooooool0Noooool001Gooooo00?o0000ooooooooool0Roooool00ol0003ooooo
ooooo`1jooooo`005Oooool00ol0003oooooooooo`2<ooooo`03o`000?oooooooooo07Wooooo0002
ooooo`;o00001?ooool00ol0003oooooooooo`02ooooo`?o00001Oooool00ol0003oooooooooo`2=
ooooo`03o`000?oooooooooo07Sooooo00001Ooooooo0000oooooooooooo000000Oooooo00Go0000
ooooooooooooooooo`000004ooooo`03o`000?oooooooooo08kooooo00?o0000ooooooooool0Mooo
ool00005ooooool0003oooooooooool000001oooool01Ol0003ooooooooooooooooo000000Cooooo
00?o0000ooooooooool0Soooool00ol0003oooooooooo`1fooooo`0000Goooooo`000?oooooooooo
o`000007ooooo`Co00001Oooool3o`00093ooooo00?o0000ooooooooool0MOooool00005ooooool0
003oooooooooool000001oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo097ooooo
00?o0000ooooooooool0M?ooool00005ooooool0003oooooooooool000002?ooool00ol0003ooooo
ooooo`05ooooo`03o`000?oooooooooo09;ooooo00?o0000ooooooooool0Loooool000;ooooo0_l0
000:ooooo`;o00001Oooool00ol0003oooooooooo`2Cooooo`03o`000?oooooooooo07;ooooo000E
ooooo`03o`000?oooooooooo09Cooooo00?o0000ooooooooool0LOooool001Gooooo00?o0000oooo
ooooool0UOooool00ol0003oooooooooo`1`ooooo`005Oooool00ol0003oooooooooo`2Fooooo`03
o`000?oooooooooo06oooooo000Eooooo`03o`000?oooooooooo09Oooooo00?o0000ooooooooool0
K_ooool001Gooooo0_l0002Iooooo`03o`000?oooooooooo06gooooo000Eooooo`03o`000?oooooo
oooo09Wooooo00?o0000ooooooooool0K?ooool001Gooooo00?o0000ooooooooool0V_ooool00ol0
003oooooooooo`1[ooooo`005Oooool00ol0003oooooooooo`2Kooooo`03o`000?oooooooooo06[o
oooo000Eooooo`03o`000?oooooooooo09cooooo00?o0000ooooooooool0JOooool001Gooooo00?o
0000ooooooooool0WOooool00ol0003oooooooooo`1Xooooo`005Oooool00ol0003oooooooooo`2N
ooooo`03o`000?oooooooooo06Oooooo000Eooooo`03o`000?oooooooooo09oooooo00?o0000oooo
ooooool0I_ooool001Gooooo0_l0002Qooooo`03o`000?oooooooooo06Gooooo000Eooooo`03o`00
0?oooooooooo0:7ooooo0_l0001Uooooo`005Oooool00ol0003oooooooooo`2Sooooo`03o`000?oo
oooooooo06;ooooo000Eooooo`03o`000?oooooooooo0:Cooooo0_l0001Rooooo`005Oooool00ol0
003oooooooooo`2Vooooo`03o`000?oooooooooo05oooooo000Eooooo`03o`000?oooooooooo0:Oo
oooo0_l0001Oooooo`005Oooool00ol0003oooooooooo`2Yooooo`03o`000?oooooooooo05cooooo
000Eooooo`03o`000?oooooooooo0:[ooooo0_l0001Looooo`005Oooool2o`000:gooooo00?o0000
ooooooooool0FOooool001Gooooo00?o0000ooooooooool0[Oooool00ol0003oooooooooo`1Hoooo
o`005Oooool00ol0003oooooooooo`2^ooooo`;o0000F?ooool001Gooooo00?o0000ooooooooool0
/?ooool00ol0003oooooooooo`1Eooooo`005Oooool00ol0003oooooooooo`2aooooo`03o`000?oo
oooooooo05Cooooo0002ooooo`;o00001?ooool00ol0003oooooooooo`02ooooo`?o00001Oooool0
0ol0003oooooooooo`2booooo`;o0000E?ooool00005ooooool0003oooooooooool000001oooool0
1Ol0003ooooooooooooooooo000000Cooooo00?o0000ooooooooool0]?ooool2o`0005;ooooo0000
1Ooooooo0000oooooooooooo000000Oooooo00Go0000ooooooooooooooooo`000004ooooo`03o`00
0?oooooooooo0;Kooooo0ol0001?ooooo`0000Goooooo`000?ooooooooooo`000008ooooo`?o0000
1Oooool3o`000;Wooooo0_l0001=ooooo`0000Goooooo`000?ooooooooooo`000007ooooo`05o`00
0?ooooooooooooooool000001?ooool00ol0003oooooooooo`2kooooo`;o0000Boooool00005oooo
ool0003oooooooooool000001oooool01Ol0003ooooooooooooooooo000000Cooooo00?o0000oooo
ooooool0_Oooool2o`0004Wooooo0002ooooo`;o00002Oooool3o`0000Gooooo00?o0000oooooooo
ool0_oooool3o`0004Kooooo000Eooooo`03o`000?oooooooooo0<;ooooo0_l00014ooooo`005Ooo
ool00ol0003oooooooooo`34ooooo`;o0000@_ooool001Gooooo00?o0000ooooooooool0a_ooool3
o`0003oooooo000Eooooo`03o`000?oooooooooo0<Wooooo0ol0000looooo`005Oooool2o`000<go
oooo0ol0000iooooo`005Oooool00ol0003oooooooooo`3?ooooo`?o0000=_ooool001Gooooo00?o
0000ooooooooool0d_ooool3o`0003?ooooo000Eooooo`03o`000?oooooooooo0=Gooooo0ol0000`
ooooo`005Oooool00ol0003oooooooooo`3Hooooo`Go0000:oooool001Gooooo00?o0000oooooooo
ool0gOooool6o`0002Gooooo000Eooooo`03o`000?oooooooooo0>?ooooo1_l0000Oooooo`005Ooo
ool00ol0003oooooooooo`3Yooooo`Go00006_ooool001Gooooo0_l0003_ooooo`Oo00004oooool0
01Gooooo00?o0000ooooooooool0mOooool8o`0000_ooooo000Eooooo`03o`000?oooooooooo0?go
oooo1?l00007ooooo`005Oooool00ol0003oooooooooo`3oooooo`Wooooo000Eooooo`03o`000?oo
oooooooo0?oooooo2Oooool001Gooooo00?o0000ooooooooool0ooooool9ooooo`005Oooool00ol0
003oooooooooo`3oooooo`Wooooo000Eooooo`03o`000?oooooooooo0?oooooo2Oooool001Gooooo
0_l0003oooooo`[ooooo000Eooooo`03o`000?oooooooooo0?oooooo2Oooool001Gooooo00?o0000
ooooooooool0ooooool9ooooo`005Oooool00ol0003oooooooooo`3oooooo`Wooooo000Eooooo`03
o`000?oooooooooo0?oooooo2Oooool000gooooo0ol00005ooooo`03o`000?oooooooooo0?oooooo
2Oooool000kooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`3oooooo`Wooooo000>
ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0ooooool9ooooo`003_ooool00ol0
003oooooooooo`04ooooo`?o0000ooooool9ooooo`003_ooool00ol0003oooooooooo`3ooooooa3o
oooo000=ooooo`;o0000oooooolBooooo`003_ooool00ol0003oooooooooo`3ooooooa3ooooo003o
ooooob7ooooo0000\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-2.49048, -0.0764114, \
0.115739, 0.00624232}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 0.0333333 0 0.618034 [
[.16667 -0.0125 -3 -9 ]
[.16667 -0.0125 3 0 ]
[.33333 -0.0125 -6 -9 ]
[.33333 -0.0125 6 0 ]
[.5 -0.0125 -6 -9 ]
[.5 -0.0125 6 0 ]
[.66667 -0.0125 -6 -9 ]
[.66667 -0.0125 6 0 ]
[.83333 -0.0125 -6 -9 ]
[.83333 -0.0125 6 0 ]
[1 -0.0125 -6 -9 ]
[1 -0.0125 6 0 ]
[-0.0125 .12361 -18 -4.5 ]
[-0.0125 .12361 0 4.5 ]
[-0.0125 .24721 -18 -4.5 ]
[-0.0125 .24721 0 4.5 ]
[-0.0125 .37082 -18 -4.5 ]
[-0.0125 .37082 0 4.5 ]
[-0.0125 .49443 -18 -4.5 ]
[-0.0125 .49443 0 4.5 ]
[-0.0125 .61803 -6 -4.5 ]
[-0.0125 .61803 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.16667 0 m
.16667 .00625 L
s
[(5)] .16667 -0.0125 0 1 Mshowa
.33333 0 m
.33333 .00625 L
s
[(10)] .33333 -0.0125 0 1 Mshowa
.5 0 m
.5 .00625 L
s
[(15)] .5 -0.0125 0 1 Mshowa
.66667 0 m
.66667 .00625 L
s
[(20)] .66667 -0.0125 0 1 Mshowa
.83333 0 m
.83333 .00625 L
s
[(25)] .83333 -0.0125 0 1 Mshowa
1 0 m
1 .00625 L
s
[(30)] 1 -0.0125 0 1 Mshowa
.125 Mabswid
.03333 0 m
.03333 .00375 L
s
.06667 0 m
.06667 .00375 L
s
.1 0 m
.1 .00375 L
s
.13333 0 m
.13333 .00375 L
s
.2 0 m
.2 .00375 L
s
.23333 0 m
.23333 .00375 L
s
.26667 0 m
.26667 .00375 L
s
.3 0 m
.3 .00375 L
s
.36667 0 m
.36667 .00375 L
s
.4 0 m
.4 .00375 L
s
.43333 0 m
.43333 .00375 L
s
.46667 0 m
.46667 .00375 L
s
.53333 0 m
.53333 .00375 L
s
.56667 0 m
.56667 .00375 L
s
.6 0 m
.6 .00375 L
s
.63333 0 m
.63333 .00375 L
s
.7 0 m
.7 .00375 L
s
.73333 0 m
.73333 .00375 L
s
.76667 0 m
.76667 .00375 L
s
.8 0 m
.8 .00375 L
s
.86667 0 m
.86667 .00375 L
s
.9 0 m
.9 .00375 L
s
.93333 0 m
.93333 .00375 L
s
.96667 0 m
.96667 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .12361 m
.00625 .12361 L
s
[(0.2)] -0.0125 .12361 1 0 Mshowa
0 .24721 m
.00625 .24721 L
s
[(0.4)] -0.0125 .24721 1 0 Mshowa
0 .37082 m
.00625 .37082 L
s
[(0.6)] -0.0125 .37082 1 0 Mshowa
0 .49443 m
.00625 .49443 L
s
[(0.8)] -0.0125 .49443 1 0 Mshowa
0 .61803 m
.00625 .61803 L
s
[(1)] -0.0125 .61803 1 0 Mshowa
.125 Mabswid
0 .0309 m
.00375 .0309 L
s
0 .0618 m
.00375 .0618 L
s
0 .09271 m
.00375 .09271 L
s
0 .15451 m
.00375 .15451 L
s
0 .18541 m
.00375 .18541 L
s
0 .21631 m
.00375 .21631 L
s
0 .27812 m
.00375 .27812 L
s
0 .30902 m
.00375 .30902 L
s
0 .33992 m
.00375 .33992 L
s
0 .40172 m
.00375 .40172 L
s
0 .43262 m
.00375 .43262 L
s
0 .46353 m
.00375 .46353 L
s
0 .52533 m
.00375 .52533 L
s
0 .55623 m
.00375 .55623 L
s
0 .58713 m
.00375 .58713 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.03333 .06012 m
.06667 .06536 L
.1 .06971 L
.13333 .07486 L
.16667 .08127 L
.2 .08924 L
.23333 .09902 L
.26667 .1109 L
.3 .12518 L
.33333 .14224 L
.36667 .16251 L
.4 .18647 L
.43333 .21469 L
.46667 .2478 L
.5 .2865 L
.53333 .33153 L
.56667 .37023 L
.6 .40334 L
.63333 .43156 L
.66667 .45553 L
.7 .47579 L
.73333 .49285 L
.76667 .50714 L
.8 .51901 L
.83333 .52879 L
.86667 .53676 L
.9 .54318 L
.93333 .54832 L
.96667 .55268 L
1 .55791 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[6]:=",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/B000`400?l00000o`00003ooooooolQ
ooooo`00?_ooool3o`0002Gooooo0ol00004ooooo`;o00008oooool3o`0000?ooooo0ol0000Qoooo
o`Go00000oooool2o`00027ooooo1Ol00002ooooo`?o00008_ooool3o`0000Cooooo0_l00004oooo
o`00?Oooool01Ol0003ooooooooooooooooo000002Gooooo00?o0000ooooooooool00_ooool01?l0
003oooooooooool0000Sooooo`05o`000?ooooooooooooooool000000oooool00ol0003ooooooooo
o`0Oooooo`04o`000?ooooooooooo`0000;ooooo00Co0000oooooooooooo00008Oooool01_l0003o
ooooooooool0003oooooo`0000?ooooo00?o0000ooooooooool07_ooool01Ol0003ooooooooooooo
oooo000000;ooooo00Co0000oooooooooooo00000oooool0047ooooo00?o0000ooooooooool08ooo
ool00ol0003oooooooooo`02ooooo`04o`000?ooooooooooo`0002?ooooo00?o0000ooooooooool0
1Oooool00ol0003oooooooooo`0Pooooo`03o`000?oooooooooo00;ooooo00Co0000oooooooooooo
00008_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo02;ooooo00Co0000oooooooo
oooo00000_ooool00ol0003oooooooooo`01ooooo`00@Oooool00ol0003oooooooooo`0Sooooo`03
o`000?oooooooooo00;ooooo00Co0000oooooooooooo00008oooool00ol0003oooooooooo`05oooo
o`03o`000?oooooooooo027ooooo00Go0000ooooooooooooooooo`000002ooooo`03o`000?oooooo
oooo027ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`0Pooooo`;o00000oooool0
1?l0003oooooooooool00003ooooo`00?Oooool4o`0002Kooooo00?o0000ooooooooool00_ooool0
1?l0003oooooooooool0000Sooooo`04o`000?ooooooooooooooo`Co00008Oooool01Ol0003ooooo
oooooooooooo000000;ooooo00Co0000oooooooooooo00008?ooool01_l0003ooooooooooooooooo
0000ooooo`Co00009Oooool01?l0003oooooooooool00002ooooo`03o`000?oooooooooo007ooooo
000mooooo`03o`000?oooooooooo02Kooooo0_l00004ooooo`04o`000?ooooooooooo`0002;ooooo
0_l00003ooooo`03o`000?oooooooooo02;ooooo00Go0000ooooooooooooooooo`000002ooooo`04
o`000?ooooooooooo`00023ooooo00Oo0000ooooooooooooooooo`000?oooooo000002Cooooo00Go
0000ooooooooooooooooo`000002ooooo`04o`000?ooooooooooo`0000?ooooo000mooooo`Go0000
9Oooool00ol0003oooooooooo`03ooooo`;o00009?ooool01?l0003oooooooooooooool5o`00027o
oooo0ol00004ooooo`;o00008_ooool3o`0000;ooooo1Ol0000Qooooo`?o00001?ooool2o`0000Co
oooo003oooooob7ooooo003oooooob7ooooo003oooooob7ooooo003oooooob7ooooo000Eoooooooo
00001Ol00007ooooo`005Oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Gooooo
00?o0000ooooooooool01_ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Gooooo
00?o0000ooooooooool01_ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Gooooo
00?o0000ooooooooool01_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Kooooo
00?o0000ooooooooool01_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Kooooo
00?o0000ooooooooool01_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Kooooo
00?o0000ooooooooool01_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Kooooo
00?o0000ooooooooool01Oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Kooooo
00?o0000ooooooooool01Oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Kooooo
00?o0000ooooooooool01Oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Kooooo
00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`005Oooool00ol0003ooooooooo
o`3oooooo`Wooooo000Eooooo`03o`000?oooooooooo0?oooooo2Oooool001Gooooo00?o0000oooo
ooooool0ooooool9ooooo`005Oooool00ol0003oooooooooo`3oooooo`Wooooo000Eooooo`03o`00
0?oooooooooo0?oooooo2Oooool001Gooooo00?o0000ooooooooool0ooooool9ooooo`005Oooool2
o`000?oooooo2_ooool001Gooooo00?o0000ooooooooool0ooooool9ooooo`005Oooool00ol0003o
ooooooooo`3oooooo`Wooooo000Eooooo`03o`000?oooooooooo0?oooooo2Oooool001Gooooo00?o
0000ooooooooool0ooooool9ooooo`005Oooool00ol0003oooooooooo`3oooooo`Wooooo000Eoooo
o`03o`000?oooooooooo0?oooooo2Oooool001Gooooo00?o0000ooooooooool01_ooool3o`000?oo
oooo000Eooooo`;o00002_ooool4o`000?_ooooo000Eooooo`03o`000?oooooooooo00gooooo1ol0
003dooooo`005Oooool00ol0003oooooooooo`0Dooooo`Wo0000joooool001Gooooo00?o0000oooo
ooooool07Oooool6o`000>Gooooo000Eooooo`03o`000?oooooooooo02?ooooo1?l0003Qooooo`00
5Oooool00ol0003oooooooooo`0Wooooo`Co0000gOooool001Gooooo00?o0000ooooooooool0:ooo
ool5o`000=Sooooo000Eooooo`03o`000?oooooooooo033ooooo1?l0003Dooooo`005Oooool2o`00
03Gooooo1Ol0003?ooooo`005Oooool00ol0003oooooooooo`0iooooo`?o0000c?ooool001Gooooo
00?o0000ooooooooool0??ooool2o`000<[ooooo000Eooooo`03o`000?oooooooooo03kooooo0_l0
0038ooooo`005Oooool00ol0003oooooooooo`10ooooo`;o0000a_ooool000;ooooo0_l00004oooo
o`04o`000?ooooooooooooooo`Go00001?ooool00ol0003oooooooooo`12ooooo`?o0000`oooool0
0005ooooool0003oooooooooool000002?ooool01?l0003oooooooooool00004ooooo`03o`000?oo
oooooooo04Gooooo0ol00030ooooo`0000Goooooo`000?ooooooooooo`000009ooooo`03o`000?oo
oooooooo00Cooooo00?o0000ooooooooool0B?ooool3o`000;gooooo00001Ooooooo0000oooooooo
oooo000000[ooooo00?o0000ooooooooool00oooool3o`0004_ooooo0_l0002kooooo`0000Gooooo
o`000?ooooooooooo`000007ooooo`05o`000?ooooooooooooooool000001?ooool00ol0003ooooo
ooooo`1=ooooo`03o`000?oooooooooo0;Sooooo00001Ooooooo0000oooooooooooo000000Oooooo
00Go0000ooooooooooooooooo`000004ooooo`03o`000?oooooooooo04kooooo0_l0002hooooo`00
0_ooool2o`0000Wooooo0ol00005ooooo`03o`000?oooooooooo053ooooo0_l0002fooooo`005Ooo
ool00ol0003oooooooooo`1Booooo`03o`000?oooooooooo0;?ooooo000Eooooo`03o`000?oooooo
oooo05?ooooo0_l0002cooooo`005Oooool00ol0003oooooooooo`1Eooooo`;o0000/Oooool001Go
oooo00?o0000ooooooooool0Eoooool2o`000:oooooo000Eooooo`;o0000F_ooool00ol0003ooooo
ooooo`2/ooooo`005Oooool00ol0003oooooooooo`1Jooooo`;o0000[?ooool001Gooooo00?o0000
ooooooooool0G?ooool2o`000:[ooooo000Eooooo`03o`000?oooooooooo05kooooo00?o0000oooo
ooooool0Yoooool001Gooooo00?o0000ooooooooool0Goooool2o`000:Oooooo000Eooooo`03o`00
0?oooooooooo067ooooo00?o0000ooooooooool0Y?ooool001Gooooo00?o0000ooooooooool0H_oo
ool2o`000:Cooooo000Eooooo`03o`000?oooooooooo06Cooooo00?o0000ooooooooool0XOooool0
01Gooooo0_l0001Vooooo`;o0000XOooool001Gooooo00?o0000ooooooooool0Ioooool00ol0003o
ooooooooo`2Nooooo`005Oooool00ol0003oooooooooo`1Xooooo`03o`000?oooooooooo09gooooo
000Eooooo`03o`000?oooooooooo06Wooooo00?o0000ooooooooool0W?ooool001Gooooo00?o0000
ooooooooool0J_ooool00ol0003oooooooooo`2Kooooo`005Oooool00ol0003oooooooooo`1[oooo
o`03o`000?oooooooooo09[ooooo000Eooooo`03o`000?oooooooooo06cooooo00?o0000oooooooo
ool0VOooool001Gooooo00?o0000ooooooooool0KOooool00ol0003oooooooooo`2Hooooo`005Ooo
ool2o`0006oooooo00?o0000ooooooooool0Uoooool001Gooooo00?o0000ooooooooool0Koooool0
0ol0003oooooooooo`2Fooooo`005Oooool00ol0003oooooooooo`1`ooooo`03o`000?oooooooooo
09Gooooo000Eooooo`03o`000?oooooooooo077ooooo00?o0000ooooooooool0U?ooool001Gooooo
00?o0000ooooooooool0L_ooool00ol0003oooooooooo`2Cooooo`000_ooool2o`0000Cooooo00?o
0000ooooooooool00oooool3o`0000Cooooo00?o0000ooooooooool0Loooool00ol0003ooooooooo
o`2Booooo`0000Goooooo`000?ooooooooooo`00000:ooooo`03o`000?oooooooooo00?ooooo00?o
0000ooooooooool0M?ooool00ol0003oooooooooo`2Aooooo`0000Goooooo`000?ooooooooooo`00
0007ooooo`Go00001?ooool00ol0003oooooooooo`1eooooo`03o`000?oooooooooo093ooooo0000
1Ooooooo0000oooooooooooo000000Oooooo00Co0000oooooooooooo00001Oooool3o`0007Kooooo
00?o0000ooooooooool0Soooool00005ooooool0003oooooooooool000002?ooool00ol0003ooooo
o`000005ooooo`03o`000?oooooooooo07Kooooo00?o0000ooooooooool0Soooool00005ooooool0
003oooooooooool000002Oooool2o`0000Gooooo00?o0000ooooooooool0Moooool00ol0003ooooo
ooooo`2>ooooo`000_ooool2o`0000_ooooo00?o0000ooooooooool00oooool00ol0003ooooooooo
o`1hooooo`03o`000?oooooooooo08gooooo000Eooooo`03o`000?oooooooooo07Wooooo00?o0000
ooooooooool0S?ooool001Gooooo00?o0000ooooooooool0N_ooool00ol0003oooooooooo`2;oooo
o`005Oooool00ol0003oooooooooo`1kooooo`03o`000?oooooooooo08[ooooo000Eooooo`03o`00
0?oooooooooo07cooooo00?o0000ooooooooool0ROooool001Gooooo0_l0001nooooo`03o`000?oo
oooooooo08Sooooo000Eooooo`03o`000?oooooooooo07kooooo00?o0000ooooooooool0Qoooool0
01Gooooo00?o0000ooooooooool0Ooooool00ol0003oooooooooo`26ooooo`005Oooool00ol0003o
ooooooooo`1oooooo`03o`000?oooooooooo08Kooooo000Eooooo`03o`000?oooooooooo083ooooo
00?o0000ooooooooool0QOooool001Gooooo00?o0000ooooooooool0POooool00ol0003ooooooooo
o`24ooooo`005Oooool00ol0003oooooooooo`21ooooo`03o`000?oooooooooo08Cooooo000Eoooo
o`03o`000?oooooooooo08;ooooo00?o0000ooooooooool0Poooool001Gooooo0_l00024ooooo`03
o`000?oooooooooo08;ooooo000Eooooo`03o`000?oooooooooo08?ooooo00?o0000ooooooooool0
P_ooool001Gooooo00?o0000ooooooooool0Q?ooool00ol0003oooooooooo`21ooooo`005Oooool0
0ol0003oooooooooo`25ooooo`03o`000?oooooooooo083ooooo000Eooooo`03o`000?oooooooooo
08Gooooo00?o0000ooooooooool0P?ooool001Gooooo00?o0000ooooooooool0Q_ooool00ol0003o
ooooooooo`1oooooo`005Oooool00ol0003oooooooooo`27ooooo`03o`000?oooooooooo07kooooo
000Eooooo`03o`000?oooooooooo08Oooooo00?o0000ooooooooool0O_ooool001Gooooo0_l00029
ooooo`03o`000?oooooooooo07gooooo000Eooooo`03o`000?oooooooooo08Wooooo00?o0000oooo
ooooool0O?ooool001Gooooo00?o0000ooooooooool0R_ooool00ol0003oooooooooo`1kooooo`00
5Oooool00ol0003oooooooooo`2;ooooo`03o`000?oooooooooo07[ooooo000Eooooo`03o`000?oo
oooooooo08cooooo00?o0000ooooooooool0NOooool000;ooooo0_l00004ooooo`03o`000?oooooo
oooo00;ooooo0ol00005ooooo`03o`000?oooooooooo08gooooo00?o0000ooooooooool0N?ooool0
0005ooooool0003oooooooooool000001oooool01Ol0003ooooooooooooooooo000000Cooooo00?o
0000ooooooooool0S_ooool00ol0003oooooooooo`1gooooo`0000Goooooo`000?ooooooooooo`00
0007ooooo`05o`000?ooooooooooooooool000001?ooool00ol0003oooooooooo`2?ooooo`03o`00
0?oooooooooo07Kooooo00001Ooooooo0000oooooooooooo000000Oooooo1?l00005ooooo`?o0000
T?ooool2o`0007Kooooo00001Ooooooo0000oooooooooooo000000Oooooo00?o0000ooooooooool0
1_ooool00ol0003oooooooooo`2Booooo`03o`000?oooooooooo07?ooooo00001Ooooooo0000oooo
oooooooo000000Sooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`2Cooooo`03o`00
0?oooooooooo07;ooooo0002ooooo`;o00002_ooool2o`0000Gooooo00?o0000ooooooooool0U?oo
ool00ol0003oooooooooo`1aooooo`005Oooool00ol0003oooooooooo`2Eooooo`03o`000?oooooo
oooo073ooooo000Eooooo`03o`000?oooooooooo09Kooooo00?o0000ooooooooool0Koooool001Go
oooo00?o0000ooooooooool0Uoooool00ol0003oooooooooo`1^ooooo`005Oooool00ol0003ooooo
ooooo`2Hooooo`03o`000?oooooooooo06gooooo000Eooooo`;o0000V_ooool00ol0003ooooooooo
o`1/ooooo`005Oooool00ol0003oooooooooo`2Jooooo`03o`000?oooooooooo06_ooooo000Eoooo
o`03o`000?oooooooooo09_ooooo00?o0000ooooooooool0J_ooool001Gooooo00?o0000oooooooo
ool0W?ooool00ol0003oooooooooo`1Yooooo`005Oooool00ol0003oooooooooo`2Mooooo`03o`00
0?oooooooooo06Sooooo000Eooooo`03o`000?oooooooooo09kooooo00?o0000ooooooooool0Iooo
ool001Gooooo00?o0000ooooooooool0Woooool00ol0003oooooooooo`1Vooooo`005Oooool00ol0
003oooooooooo`2Pooooo`03o`000?oooooooooo06Gooooo000Eooooo`;o0000X_ooool2o`0006Go
oooo000Eooooo`03o`000?oooooooooo0:?ooooo00?o0000ooooooooool0H_ooool001Gooooo00?o
0000ooooooooool0Y?ooool2o`0006;ooooo000Eooooo`03o`000?oooooooooo0:Kooooo00?o0000
ooooooooool0Goooool001Gooooo00?o0000ooooooooool0Yoooool2o`0005oooooo000Eooooo`03
o`000?oooooooooo0:Wooooo00?o0000ooooooooool0G?ooool001Gooooo00?o0000ooooooooool0
Z_ooool2o`0005cooooo000Eooooo`03o`000?oooooooooo0:cooooo00?o0000ooooooooool0FOoo
ool001Gooooo0_l0002^ooooo`;o0000FOooool001Gooooo00?o0000ooooooooool0[oooool2o`00
05Oooooo000Eooooo`03o`000?oooooooooo0;7ooooo00?o0000ooooooooool0E?ooool001Gooooo
00?o0000ooooooooool0/_ooool2o`0005Cooooo000Eooooo`03o`000?oooooooooo0;Cooooo0_l0
001Booooo`000_ooool2o`0000Cooooo00?o0000ooooooooool00_ooool3o`0000Gooooo00?o0000
ooooooooool0]_ooool2o`00053ooooo00001Ooooooo0000oooooooooooo000000Oooooo00Go0000
ooooooooooooooooo`000004ooooo`03o`000?oooooooooo0;Sooooo00?o0000ooooooooool0COoo
ool00005ooooool0003oooooooooool000001oooool01Ol0003ooooooooooooooooo000000Cooooo
00?o0000ooooooooool0^Oooool2o`0004gooooo00001Ooooooo0000oooooooooooo000000Sooooo
0ol00005ooooo`?o0000^oooool3o`0004[ooooo00001Ooooooo0000oooooooooooo000000Oooooo
00Go0000ooooooooooooooooo`000004ooooo`03o`000?oooooooooo0;kooooo0ol00017ooooo`00
00Goooooo`000?ooooooooooo`000007ooooo`05o`000?ooooooooooooooool000001?ooool00ol0
003oooooooooo`31ooooo`?o0000A?ooool000;ooooo0_l00009ooooo`?o00001Oooool00ol0003o
ooooooooo`34ooooo`;o0000@_ooool001Gooooo00?o0000ooooooooool0a_ooool3o`0003oooooo
000Eooooo`03o`000?oooooooooo0<Wooooo0ol0000looooo`005Oooool00ol0003oooooooooo`3<
ooooo`?o0000>Oooool001Gooooo00?o0000ooooooooool0coooool3o`0003Kooooo000Eooooo`;o
0000doooool3o`0003?ooooo000Eooooo`03o`000?oooooooooo0=Gooooo0ol0000`ooooo`005Ooo
ool00ol0003oooooooooo`3Hooooo`Go0000:oooool001Gooooo00?o0000ooooooooool0gOooool4
o`0002Oooooo000Eooooo`03o`000?oooooooooo0>7ooooo1?l0000Sooooo`005Oooool00ol0003o
ooooooooo`3Uooooo`Oo00007?ooool001Gooooo00?o0000ooooooooool0k?ooool9o`0001?ooooo
000Eooooo`03o`000?oooooooooo0?Gooooo2?l0000;ooooo`005Oooool2o`000?kooooo1?l00007
ooooo`005Oooool00ol0003oooooooooo`3oooooo`Wooooo000Eooooo`03o`000?oooooooooo0?oo
oooo2Oooool001Gooooo00?o0000ooooooooool0ooooool9ooooo`005Oooool00ol0003ooooooooo
o`3oooooo`Wooooo000Eooooo`03o`000?oooooooooo0?oooooo2Oooool001Gooooo00?o0000oooo
ooooool0ooooool9ooooo`005Oooool00ol0003oooooooooo`3oooooo`Wooooo000Eooooo`;o0000
ooooool:ooooo`005Oooool00ol0003oooooooooo`3oooooo`Wooooo000Eooooo`03o`000?oooooo
oooo0?oooooo2Oooool001Gooooo00?o0000ooooooooool0ooooool9ooooo`005Oooool00ol0003o
ooooooooo`3oooooo`Wooooo000=ooooo`?o00001Oooool00ol0003oooooooooo`3oooooo`Wooooo
000>ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0ooooool9ooooo`003_ooool0
0ol0003oooooooooo`04ooooo`03o`000?oooooooooo0?oooooo2Oooool000kooooo00?o0000oooo
ooooool01?ooool3o`000?oooooo2Oooool000kooooo00?o0000ooooooooool0ooooool@ooooo`00
3Oooool2o`000?oooooo4_ooool000kooooo00?o0000ooooooooool0ooooool@ooooo`00oooooolQ
ooooo`00\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-2.49048, -0.0764114, \
0.115739, 0.00624232}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 0.0333333 0 0.618034 [
[.16667 -0.0125 -3 -9 ]
[.16667 -0.0125 3 0 ]
[.33333 -0.0125 -6 -9 ]
[.33333 -0.0125 6 0 ]
[.5 -0.0125 -6 -9 ]
[.5 -0.0125 6 0 ]
[.66667 -0.0125 -6 -9 ]
[.66667 -0.0125 6 0 ]
[.83333 -0.0125 -6 -9 ]
[.83333 -0.0125 6 0 ]
[1 -0.0125 -6 -9 ]
[1 -0.0125 6 0 ]
[-0.0125 .12361 -18 -4.5 ]
[-0.0125 .12361 0 4.5 ]
[-0.0125 .24721 -18 -4.5 ]
[-0.0125 .24721 0 4.5 ]
[-0.0125 .37082 -18 -4.5 ]
[-0.0125 .37082 0 4.5 ]
[-0.0125 .49443 -18 -4.5 ]
[-0.0125 .49443 0 4.5 ]
[-0.0125 .61803 -6 -4.5 ]
[-0.0125 .61803 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.16667 0 m
.16667 .00625 L
s
[(5)] .16667 -0.0125 0 1 Mshowa
.33333 0 m
.33333 .00625 L
s
[(10)] .33333 -0.0125 0 1 Mshowa
.5 0 m
.5 .00625 L
s
[(15)] .5 -0.0125 0 1 Mshowa
.66667 0 m
.66667 .00625 L
s
[(20)] .66667 -0.0125 0 1 Mshowa
.83333 0 m
.83333 .00625 L
s
[(25)] .83333 -0.0125 0 1 Mshowa
1 0 m
1 .00625 L
s
[(30)] 1 -0.0125 0 1 Mshowa
.125 Mabswid
.03333 0 m
.03333 .00375 L
s
.06667 0 m
.06667 .00375 L
s
.1 0 m
.1 .00375 L
s
.13333 0 m
.13333 .00375 L
s
.2 0 m
.2 .00375 L
s
.23333 0 m
.23333 .00375 L
s
.26667 0 m
.26667 .00375 L
s
.3 0 m
.3 .00375 L
s
.36667 0 m
.36667 .00375 L
s
.4 0 m
.4 .00375 L
s
.43333 0 m
.43333 .00375 L
s
.46667 0 m
.46667 .00375 L
s
.53333 0 m
.53333 .00375 L
s
.56667 0 m
.56667 .00375 L
s
.6 0 m
.6 .00375 L
s
.63333 0 m
.63333 .00375 L
s
.7 0 m
.7 .00375 L
s
.73333 0 m
.73333 .00375 L
s
.76667 0 m
.76667 .00375 L
s
.8 0 m
.8 .00375 L
s
.86667 0 m
.86667 .00375 L
s
.9 0 m
.9 .00375 L
s
.93333 0 m
.93333 .00375 L
s
.96667 0 m
.96667 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .12361 m
.00625 .12361 L
s
[(0.2)] -0.0125 .12361 1 0 Mshowa
0 .24721 m
.00625 .24721 L
s
[(0.4)] -0.0125 .24721 1 0 Mshowa
0 .37082 m
.00625 .37082 L
s
[(0.6)] -0.0125 .37082 1 0 Mshowa
0 .49443 m
.00625 .49443 L
s
[(0.8)] -0.0125 .49443 1 0 Mshowa
0 .61803 m
.00625 .61803 L
s
[(1)] -0.0125 .61803 1 0 Mshowa
.125 Mabswid
0 .0309 m
.00375 .0309 L
s
0 .0618 m
.00375 .0618 L
s
0 .09271 m
.00375 .09271 L
s
0 .15451 m
.00375 .15451 L
s
0 .18541 m
.00375 .18541 L
s
0 .21631 m
.00375 .21631 L
s
0 .27812 m
.00375 .27812 L
s
0 .30902 m
.00375 .30902 L
s
0 .33992 m
.00375 .33992 L
s
0 .40172 m
.00375 .40172 L
s
0 .43262 m
.00375 .43262 L
s
0 .46353 m
.00375 .46353 L
s
0 .52533 m
.00375 .52533 L
s
0 .55623 m
.00375 .55623 L
s
0 .58713 m
.00375 .58713 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.03333 .06511 m
.06667 .07082 L
.1 .0753 L
.13333 .08046 L
.16667 .08682 L
.2 .09466 L
.23333 .10425 L
.26667 .11586 L
.3 .12979 L
.33333 .14642 L
.36667 .16615 L
.4 .18947 L
.43333 .21694 L
.46667 .24921 L
.5 .28699 L
.53333 .33105 L
.56667 .36883 L
.6 .40109 L
.63333 .42857 L
.66667 .45189 L
.7 .47162 L
.73333 .48824 L
.76667 .50217 L
.8 .51378 L
.83333 .52337 L
.86667 .53122 L
.9 .53757 L
.93333 .54273 L
.96667 .54721 L
1 .55292 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[6]:=",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/B000`400?l00000o`00003ooooooolQ
ooooo`00?_ooool3o`0002Gooooo0ol00004ooooo`;o00008oooool3o`0000?ooooo0ol0000Qoooo
o`Go00000oooool2o`00027ooooo1Ol00002ooooo`?o00008_ooool3o`0000Cooooo0_l00004oooo
o`00?Oooool01Ol0003ooooooooooooooooo000002Gooooo00?o0000ooooooooool00_ooool01?l0
003oooooooooool0000Sooooo`05o`000?ooooooooooooooool000000oooool00ol0003ooooooooo
o`0Oooooo`04o`000?ooooooooooo`0000;ooooo00Co0000oooooooooooo00008Oooool01_l0003o
ooooooooool0003oooooo`0000?ooooo00?o0000ooooooooool07_ooool01Ol0003ooooooooooooo
oooo000000;ooooo00Co0000oooooooooooo00000oooool0047ooooo00?o0000ooooooooool08ooo
ool00ol0003oooooooooo`02ooooo`04o`000?ooooooooooo`0002?ooooo00?o0000ooooooooool0
1Oooool00ol0003oooooooooo`0Pooooo`03o`000?oooooooooo00;ooooo00Co0000oooooooooooo
00008_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo02;ooooo00Co0000oooooooo
oooo00000_ooool00ol0003oooooooooo`01ooooo`00@Oooool00ol0003oooooooooo`0Sooooo`03
o`000?oooooooooo00;ooooo00Co0000oooooooooooo00008oooool00ol0003oooooooooo`05oooo
o`03o`000?oooooooooo027ooooo00Go0000ooooooooooooooooo`000002ooooo`03o`000?oooooo
oooo027ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`0Pooooo`;o00000oooool0
1?l0003oooooooooool00003ooooo`00?Oooool4o`0002Kooooo00?o0000ooooooooool00_ooool0
1?l0003oooooooooool0000Sooooo`04o`000?ooooooooooooooo`Co00008Oooool01Ol0003ooooo
oooooooooooo000000;ooooo00Co0000oooooooooooo00008?ooool01_l0003ooooooooooooooooo
0000ooooo`Co00009Oooool01?l0003oooooooooool00002ooooo`03o`000?oooooooooo007ooooo
000mooooo`03o`000?oooooooooo02Kooooo0_l00004ooooo`04o`000?ooooooooooo`0002;ooooo
0_l00003ooooo`03o`000?oooooooooo02;ooooo00Go0000ooooooooooooooooo`000002ooooo`04
o`000?ooooooooooo`00023ooooo00Oo0000ooooooooooooooooo`000?oooooo000002Cooooo00Go
0000ooooooooooooooooo`000002ooooo`04o`000?ooooooooooo`0000?ooooo000mooooo`Go0000
9Oooool00ol0003oooooooooo`03ooooo`;o00009?ooool01?l0003oooooooooooooool5o`00027o
oooo0ol00004ooooo`;o00008_ooool3o`0000;ooooo1Ol0000Qooooo`?o00001?ooool2o`0000Co
oooo003oooooob7ooooo003oooooob7ooooo003oooooob7ooooo003oooooob7ooooo000Eoooooooo
00001Ol00007ooooo`005Oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Gooooo
00?o0000ooooooooool01_ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Gooooo
00?o0000ooooooooool01_ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Gooooo
00?o0000ooooooooool01_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Kooooo
00?o0000ooooooooool01_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Kooooo
00?o0000ooooooooool01_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Kooooo
00?o0000ooooooooool01_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Kooooo
00?o0000ooooooooool01Oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Kooooo
00?o0000ooooooooool01Oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Kooooo
00?o0000ooooooooool01Oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Kooooo
00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`005Oooool00ol0003ooooooooo
o`3oooooo`Wooooo000Eooooo`03o`000?oooooooooo0?oooooo2Oooool001Gooooo00?o0000oooo
ooooool0ooooool9ooooo`005Oooool00ol0003oooooooooo`3oooooo`Wooooo000Eooooo`03o`00
0?oooooooooo0?oooooo2Oooool001Gooooo00?o0000ooooooooool0ooooool9ooooo`005Oooool2
o`000?oooooo2_ooool001Gooooo00?o0000ooooooooool0ooooool9ooooo`005Oooool00ol0003o
ooooooooo`3oooooo`Wooooo000Eooooo`03o`000?oooooooooo0?oooooo2Oooool001Gooooo00?o
0000ooooooooool0ooooool9ooooo`005Oooool00ol0003oooooooooo`3oooooo`Wooooo000Eoooo
o`03o`000?oooooooooo0?oooooo2Oooool001Gooooo00?o0000ooooooooool0ooooool9ooooo`00
5Oooool2o`000?oooooo2_ooool001Gooooo00?o0000ooooooooool01_ooool5o`000?gooooo000E
ooooo`03o`000?oooooooooo00_ooooo2Ol0003dooooo`005Oooool00ol0003oooooooooo`0Doooo
o`Ko0000k_ooool001Gooooo00?o0000ooooooooool06_ooool5o`000>Wooooo000Eooooo`03o`00
0?oooooooooo01oooooo1_l0003Sooooo`005Oooool00ol0003oooooooooo`0Uooooo`Ko0000gOoo
ool001Gooooo00?o0000ooooooooool0:oooool5o`000=Sooooo000Eooooo`;o0000<Oooool4o`00
0=Cooooo000Eooooo`03o`000?oooooooooo03Cooooo0ol0003Aooooo`005Oooool00ol0003ooooo
ooooo`0gooooo`?o0000c_ooool001Gooooo00?o0000ooooooooool0>_ooool2o`000<cooooo000E
ooooo`03o`000?oooooooooo03cooooo0ol00039ooooo`000_ooool2o`0000Cooooo00Co0000oooo
oooooooooooo1Ol00004ooooo`03o`000?oooooooooo03oooooo0ol00036ooooo`0000Goooooo`00
0?ooooooooooo`000008ooooo`04o`000?ooooooooooo`0000Cooooo00?o0000ooooooooool0@_oo
ool3o`000<?ooooo00001Ooooooo0000oooooooooooo000000Wooooo00?o0000ooooooooool01?oo
ool00ol0003oooooooooo`15ooooo`?o0000`?ooool00005ooooool0003oooooooooool000002_oo
ool00ol0003oooooooooo`03ooooo`?o0000B?ooool3o`000;gooooo00001Ooooooo0000oooooooo
oooo000000Oooooo00Go0000ooooooooooooooooo`000004ooooo`03o`000?oooooooooo04_ooooo
0_l0002kooooo`0000Goooooo`000?ooooooooooo`000007ooooo`05o`000?ooooooooooooooool0
00001?ooool00ol0003oooooooooo`1=ooooo`03o`000?oooooooooo0;Sooooo0002ooooo`;o0000
2Oooool3o`0000Gooooo00?o0000ooooooooool0C_ooool2o`000;Sooooo000Eooooo`03o`000?oo
oooooooo053ooooo0_l0002fooooo`005Oooool00ol0003oooooooooo`1Booooo`03o`000?oooooo
oooo0;?ooooo000Eooooo`03o`000?oooooooooo05?ooooo0_l0002cooooo`005Oooool00ol0003o
ooooooooo`1Eooooo`;o0000/Oooool001Gooooo0_l0001Hooooo`;o0000[oooool001Gooooo00?o
0000ooooooooool0FOooool00ol0003oooooooooo`2/ooooo`005Oooool00ol0003oooooooooo`1J
ooooo`;o0000[?ooool001Gooooo00?o0000ooooooooool0G?ooool2o`000:[ooooo000Eooooo`03
o`000?oooooooooo05kooooo00?o0000ooooooooool0Yoooool001Gooooo00?o0000ooooooooool0
Goooool2o`000:Oooooo000Eooooo`03o`000?oooooooooo067ooooo00?o0000ooooooooool0Y?oo
ool001Gooooo00?o0000ooooooooool0H_ooool2o`000:Cooooo000Eooooo`;o0000IOooool00ol0
003oooooooooo`2Qooooo`005Oooool00ol0003oooooooooo`1Uooooo`;o0000XOooool001Gooooo
00?o0000ooooooooool0Ioooool00ol0003oooooooooo`2Nooooo`005Oooool00ol0003ooooooooo
o`1Xooooo`03o`000?oooooooooo09gooooo000Eooooo`03o`000?oooooooooo06Wooooo00?o0000
ooooooooool0W?ooool001Gooooo00?o0000ooooooooool0J_ooool00ol0003oooooooooo`2Koooo
o`005Oooool00ol0003oooooooooo`1[ooooo`03o`000?oooooooooo09[ooooo000Eooooo`03o`00
0?oooooooooo06cooooo00?o0000ooooooooool0VOooool001Gooooo0_l0001^ooooo`;o0000VOoo
ool001Gooooo00?o0000ooooooooool0Koooool00ol0003oooooooooo`2Fooooo`005Oooool00ol0
003oooooooooo`1`ooooo`03o`000?oooooooooo09Gooooo000Eooooo`03o`000?oooooooooo077o
oooo00?o0000ooooooooool0U?ooool001Gooooo00?o0000ooooooooool0L_ooool00ol0003ooooo
ooooo`2Cooooo`000_ooool2o`0000Cooooo00?o0000ooooooooool00oooool3o`0000Cooooo00?o
0000ooooooooool0Loooool00ol0003oooooooooo`2Booooo`0000Goooooo`000?ooooooooooo`00
000:ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0M?ooool00ol0003ooooooooo
o`2Aooooo`0000Goooooo`000?ooooooooooo`000007ooooo`Go00001?ooool00ol0003ooooooooo
o`1eooooo`03o`000?oooooooooo093ooooo00001Ooooooo0000oooooooooooo000000Oooooo00Co
0000oooooooooooo00001Oooool3o`0007Kooooo00?o0000ooooooooool0Soooool00005ooooool0
003oooooooooool000002?ooool00ol0003oooooo`000005ooooo`03o`000?oooooooooo07Kooooo
00?o0000ooooooooool0Soooool00005ooooool0003oooooooooool000002Oooool2o`0000Gooooo
00?o0000ooooooooool0Moooool00ol0003oooooooooo`2>ooooo`000_ooool2o`0000_ooooo00?o
0000ooooooooool00oooool00ol0003oooooooooo`1hooooo`03o`000?oooooooooo08gooooo000E
ooooo`03o`000?oooooooooo07Wooooo00?o0000ooooooooool0S?ooool001Gooooo00?o0000oooo
ooooool0N_ooool00ol0003oooooooooo`2;ooooo`005Oooool00ol0003oooooooooo`1kooooo`03
o`000?oooooooooo08[ooooo000Eooooo`03o`000?oooooooooo07cooooo00?o0000ooooooooool0
ROooool001Gooooo0_l0001nooooo`03o`000?oooooooooo08Sooooo000Eooooo`03o`000?oooooo
oooo07kooooo00?o0000ooooooooool0Qoooool001Gooooo00?o0000ooooooooool0Ooooool00ol0
003oooooooooo`26ooooo`005Oooool00ol0003oooooooooo`1oooooo`03o`000?oooooooooo08Ko
oooo000Eooooo`03o`000?oooooooooo083ooooo00?o0000ooooooooool0QOooool001Gooooo00?o
0000ooooooooool0POooool00ol0003oooooooooo`24ooooo`005Oooool00ol0003oooooooooo`21
ooooo`03o`000?oooooooooo08Cooooo000Eooooo`03o`000?oooooooooo08;ooooo00?o0000oooo
ooooool0Poooool001Gooooo0_l00024ooooo`03o`000?oooooooooo08;ooooo000Eooooo`03o`00
0?oooooooooo08?ooooo00?o0000ooooooooool0P_ooool001Gooooo00?o0000ooooooooool0Q?oo
ool00ol0003oooooooooo`21ooooo`005Oooool00ol0003oooooooooo`25ooooo`03o`000?oooooo
oooo083ooooo000Eooooo`03o`000?oooooooooo08Gooooo00?o0000ooooooooool0P?ooool001Go
oooo00?o0000ooooooooool0Q_ooool00ol0003oooooooooo`1oooooo`005Oooool00ol0003ooooo
ooooo`27ooooo`03o`000?oooooooooo07kooooo000Eooooo`03o`000?oooooooooo08Sooooo00?o
0000ooooooooool0OOooool001Gooooo0_l0002:ooooo`03o`000?oooooooooo07cooooo000Eoooo
o`03o`000?oooooooooo08[ooooo00?o0000ooooooooool0Noooool001Gooooo00?o0000oooooooo
ool0Roooool00ol0003oooooooooo`1jooooo`005Oooool00ol0003oooooooooo`2<ooooo`03o`00
0?oooooooooo07Wooooo000Eooooo`03o`000?oooooooooo08gooooo00?o0000ooooooooool0N?oo
ool000;ooooo0_l00004ooooo`03o`000?oooooooooo00;ooooo0ol00005ooooo`03o`000?oooooo
oooo08kooooo00?o0000ooooooooool0Moooool00005ooooool0003oooooooooool000001oooool0
1Ol0003ooooooooooooooooo000000Cooooo00?o0000ooooooooool0Soooool00ol0003ooooooooo
o`1fooooo`0000Goooooo`000?ooooooooooo`000007ooooo`05o`000?ooooooooooooooool00000
1?ooool00ol0003oooooooooo`2@ooooo`03o`000?oooooooooo07Gooooo00001Ooooooo0000oooo
oooooooo000000Oooooo1?l00005ooooo`?o0000TOooool00ol0003oooooooooo`1dooooo`0000Go
ooooo`000?ooooooooooo`000007ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0
T_ooool00ol0003oooooooooo`1cooooo`0000Goooooo`000?ooooooooooo`000008ooooo`03o`00
0?oooooooooo00Gooooo00?o0000ooooooooool0Toooool00ol0003oooooooooo`1booooo`000_oo
ool2o`0000[ooooo0_l00005ooooo`03o`000?oooooooooo09Cooooo00?o0000ooooooooool0LOoo
ool001Gooooo00?o0000ooooooooool0UOooool00ol0003oooooooooo`1`ooooo`005Oooool00ol0
003oooooooooo`2Fooooo`03o`000?oooooooooo06oooooo000Eooooo`03o`000?oooooooooo09Oo
oooo00?o0000ooooooooool0K_ooool001Gooooo00?o0000ooooooooool0V?ooool00ol0003ooooo
ooooo`1]ooooo`005Oooool2o`0009[ooooo0_l0001]ooooo`005Oooool00ol0003oooooooooo`2K
ooooo`03o`000?oooooooooo06[ooooo000Eooooo`03o`000?oooooooooo09cooooo00?o0000oooo
ooooool0JOooool001Gooooo00?o0000ooooooooool0WOooool00ol0003oooooooooo`1Xooooo`00
5Oooool00ol0003oooooooooo`2Nooooo`03o`000?oooooooooo06Oooooo000Eooooo`03o`000?oo
oooooooo09oooooo00?o0000ooooooooool0I_ooool001Gooooo00?o0000ooooooooool0X?ooool0
0ol0003oooooooooo`1Uooooo`005Oooool00ol0003oooooooooo`2Qooooo`;o0000IOooool001Go
oooo0_l0002Tooooo`03o`000?oooooooooo06;ooooo000Eooooo`03o`000?oooooooooo0:Cooooo
0_l0001Rooooo`005Oooool00ol0003oooooooooo`2Vooooo`03o`000?oooooooooo05oooooo000E
ooooo`03o`000?oooooooooo0:Oooooo0_l0001Oooooo`005Oooool00ol0003oooooooooo`2Yoooo
o`03o`000?oooooooooo05cooooo000Eooooo`03o`000?oooooooooo0:[ooooo0_l0001Looooo`00
5Oooool00ol0003oooooooooo`2/ooooo`03o`000?oooooooooo05Wooooo000Eooooo`03o`000?oo
oooooooo0:gooooo0_l0001Iooooo`005Oooool2o`000;3ooooo0_l0001Gooooo`005Oooool00ol0
003oooooooooo`2aooooo`03o`000?oooooooooo05Cooooo000Eooooo`03o`000?oooooooooo0;;o
oooo0_l0001Dooooo`005Oooool00ol0003oooooooooo`2dooooo`;o0000D_ooool001Gooooo00?o
0000ooooooooool0]_ooool3o`0004oooooo0002ooooo`;o00001?ooool00ol0003oooooooooo`02
ooooo`?o00001Oooool00ol0003oooooooooo`2iooooo`;o0000COooool00005ooooool0003ooooo
ooooool000001oooool01Ol0003ooooooooooooooooo000000Cooooo00?o0000ooooooooool0^ooo
ool2o`0004_ooooo00001Ooooooo0000oooooooooooo000000Oooooo00Go0000oooooooooooooooo
o`000004ooooo`03o`000?oooooooooo0;gooooo0_l00019ooooo`0000Goooooo`000?oooooooooo
o`000008ooooo`?o00001Oooool3o`000;oooooo0ol00016ooooo`0000Goooooo`000?oooooooooo
o`000007ooooo`05o`000?ooooooooooooooool000001?ooool00ol0003oooooooooo`32ooooo`;o
0000A?ooool00005ooooool0003oooooooooool000001oooool01Ol0003ooooooooooooooooo0000
00Cooooo00?o0000ooooooooool0a?ooool2o`0004;ooooo0002ooooo`;o00002Oooool3o`0000Go
oooo00?o0000ooooooooool0a_ooool3o`0003oooooo000Eooooo`03o`000?oooooooooo0<Wooooo
0ol0000looooo`005Oooool00ol0003oooooooooo`3<ooooo`?o0000>Oooool001Gooooo00?o0000
ooooooooool0coooool5o`0003Cooooo000Eooooo`03o`000?oooooooooo0=Cooooo1?l0000`oooo
o`005Oooool2o`000=Wooooo1Ol0000[ooooo`005Oooool00ol0003oooooooooo`3Mooooo`Co0000
9oooool001Gooooo00?o0000ooooooooool0hOooool4o`0002?ooooo000Eooooo`03o`000?oooooo
oooo0>Gooooo1ol0000Looooo`005Oooool00ol0003oooooooooo`3/ooooo`Ko00005_ooool001Go
oooo00?o0000ooooooooool0l_ooool5o`00017ooooo000Eooooo`03o`000?oooooooooo0?Oooooo
1_l0000;ooooo`005Oooool00ol0003oooooooooo`3mooooo`Co00001oooool001Gooooo0_l0003o
ooooo`[ooooo000Eooooo`03o`000?oooooooooo0?oooooo2Oooool001Gooooo00?o0000oooooooo
ool0ooooool9ooooo`005Oooool00ol0003oooooooooo`3oooooo`Wooooo000Eooooo`03o`000?oo
oooooooo0?oooooo2Oooool001Gooooo00?o0000ooooooooool0ooooool9ooooo`005Oooool00ol0
003oooooooooo`3oooooo`Wooooo000Eooooo`03o`000?oooooooooo0?oooooo2Oooool001Gooooo
0_l0003oooooo`[ooooo000Eooooo`03o`000?oooooooooo0?oooooo2Oooool001Gooooo00?o0000
ooooooooool0ooooool9ooooo`005Oooool00ol0003oooooooooo`3oooooo`Wooooo000Eooooo`03
o`000?oooooooooo0?oooooo2Oooool000gooooo0ol00005ooooo`03o`000?oooooooooo0?oooooo
2Oooool000kooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`3oooooo`Wooooo000>
ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0ooooool9ooooo`003_ooool00ol0
003oooooooooo`04ooooo`?o0000ooooool9ooooo`003_ooool00ol0003oooooooooo`3ooooooa3o
oooo000=ooooo`;o0000oooooolBooooo`003_ooool00ol0003oooooooooo`3ooooooa3ooooo003o
ooooob7ooooo0000\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-2.49048, -0.0764114, \
0.115739, 0.00624232}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 0.0333333 0 0.618034 [
[.16667 -0.0125 -3 -9 ]
[.16667 -0.0125 3 0 ]
[.33333 -0.0125 -6 -9 ]
[.33333 -0.0125 6 0 ]
[.5 -0.0125 -6 -9 ]
[.5 -0.0125 6 0 ]
[.66667 -0.0125 -6 -9 ]
[.66667 -0.0125 6 0 ]
[.83333 -0.0125 -6 -9 ]
[.83333 -0.0125 6 0 ]
[1 -0.0125 -6 -9 ]
[1 -0.0125 6 0 ]
[-0.0125 .12361 -18 -4.5 ]
[-0.0125 .12361 0 4.5 ]
[-0.0125 .24721 -18 -4.5 ]
[-0.0125 .24721 0 4.5 ]
[-0.0125 .37082 -18 -4.5 ]
[-0.0125 .37082 0 4.5 ]
[-0.0125 .49443 -18 -4.5 ]
[-0.0125 .49443 0 4.5 ]
[-0.0125 .61803 -6 -4.5 ]
[-0.0125 .61803 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.16667 0 m
.16667 .00625 L
s
[(5)] .16667 -0.0125 0 1 Mshowa
.33333 0 m
.33333 .00625 L
s
[(10)] .33333 -0.0125 0 1 Mshowa
.5 0 m
.5 .00625 L
s
[(15)] .5 -0.0125 0 1 Mshowa
.66667 0 m
.66667 .00625 L
s
[(20)] .66667 -0.0125 0 1 Mshowa
.83333 0 m
.83333 .00625 L
s
[(25)] .83333 -0.0125 0 1 Mshowa
1 0 m
1 .00625 L
s
[(30)] 1 -0.0125 0 1 Mshowa
.125 Mabswid
.03333 0 m
.03333 .00375 L
s
.06667 0 m
.06667 .00375 L
s
.1 0 m
.1 .00375 L
s
.13333 0 m
.13333 .00375 L
s
.2 0 m
.2 .00375 L
s
.23333 0 m
.23333 .00375 L
s
.26667 0 m
.26667 .00375 L
s
.3 0 m
.3 .00375 L
s
.36667 0 m
.36667 .00375 L
s
.4 0 m
.4 .00375 L
s
.43333 0 m
.43333 .00375 L
s
.46667 0 m
.46667 .00375 L
s
.53333 0 m
.53333 .00375 L
s
.56667 0 m
.56667 .00375 L
s
.6 0 m
.6 .00375 L
s
.63333 0 m
.63333 .00375 L
s
.7 0 m
.7 .00375 L
s
.73333 0 m
.73333 .00375 L
s
.76667 0 m
.76667 .00375 L
s
.8 0 m
.8 .00375 L
s
.86667 0 m
.86667 .00375 L
s
.9 0 m
.9 .00375 L
s
.93333 0 m
.93333 .00375 L
s
.96667 0 m
.96667 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .12361 m
.00625 .12361 L
s
[(0.2)] -0.0125 .12361 1 0 Mshowa
0 .24721 m
.00625 .24721 L
s
[(0.4)] -0.0125 .24721 1 0 Mshowa
0 .37082 m
.00625 .37082 L
s
[(0.6)] -0.0125 .37082 1 0 Mshowa
0 .49443 m
.00625 .49443 L
s
[(0.8)] -0.0125 .49443 1 0 Mshowa
0 .61803 m
.00625 .61803 L
s
[(1)] -0.0125 .61803 1 0 Mshowa
.125 Mabswid
0 .0309 m
.00375 .0309 L
s
0 .0618 m
.00375 .0618 L
s
0 .09271 m
.00375 .09271 L
s
0 .15451 m
.00375 .15451 L
s
0 .18541 m
.00375 .18541 L
s
0 .21631 m
.00375 .21631 L
s
0 .27812 m
.00375 .27812 L
s
0 .30902 m
.00375 .30902 L
s
0 .33992 m
.00375 .33992 L
s
0 .40172 m
.00375 .40172 L
s
0 .43262 m
.00375 .43262 L
s
0 .46353 m
.00375 .46353 L
s
0 .52533 m
.00375 .52533 L
s
0 .55623 m
.00375 .55623 L
s
0 .58713 m
.00375 .58713 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.03333 .06902 m
.06667 .07516 L
.1 .07977 L
.13333 .08493 L
.16667 .09123 L
.2 .09896 L
.23333 .10838 L
.26667 .11976 L
.3 .13341 L
.33333 .14967 L
.36667 .16897 L
.4 .19178 L
.43333 .21867 L
.46667 .25029 L
.5 .28736 L
.53333 .33068 L
.56667 .36775 L
.6 .39936 L
.63333 .42625 L
.66667 .44907 L
.7 .46836 L
.73333 .48463 L
.76667 .49827 L
.8 .50965 L
.83333 .51907 L
.86667 .5268 L
.9 .5331 L
.93333 .53827 L
.96667 .54287 L
1 .54902 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[6]:=",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/B000`400?l00000o`00003ooooooolQ
ooooo`00?_ooool3o`0002Gooooo0ol00004ooooo`;o00008oooool3o`0000?ooooo0ol0000Qoooo
o`Go00000oooool2o`00027ooooo1Ol00002ooooo`?o00008_ooool3o`0000Cooooo0_l00004oooo
o`00?Oooool01Ol0003ooooooooooooooooo000002Gooooo00?o0000ooooooooool00_ooool01?l0
003oooooooooool0000Sooooo`05o`000?ooooooooooooooool000000oooool00ol0003ooooooooo
o`0Oooooo`04o`000?ooooooooooo`0000;ooooo00Co0000oooooooooooo00008Oooool01_l0003o
ooooooooool0003oooooo`0000?ooooo00?o0000ooooooooool07_ooool01Ol0003ooooooooooooo
oooo000000;ooooo00Co0000oooooooooooo00000oooool0047ooooo00?o0000ooooooooool08ooo
ool00ol0003oooooooooo`02ooooo`04o`000?ooooooooooo`0002?ooooo00?o0000ooooooooool0
1Oooool00ol0003oooooooooo`0Pooooo`03o`000?oooooooooo00;ooooo00Co0000oooooooooooo
00008_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo02;ooooo00Co0000oooooooo
oooo00000_ooool00ol0003oooooooooo`01ooooo`00@Oooool00ol0003oooooooooo`0Sooooo`03
o`000?oooooooooo00;ooooo00Co0000oooooooooooo00008oooool00ol0003oooooooooo`05oooo
o`03o`000?oooooooooo027ooooo00Go0000ooooooooooooooooo`000002ooooo`03o`000?oooooo
oooo027ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`0Pooooo`;o00000oooool0
1?l0003oooooooooool00003ooooo`00?Oooool4o`0002Kooooo00?o0000ooooooooool00_ooool0
1?l0003oooooooooool0000Sooooo`04o`000?ooooooooooooooo`Co00008Oooool01Ol0003ooooo
oooooooooooo000000;ooooo00Co0000oooooooooooo00008?ooool01_l0003ooooooooooooooooo
0000ooooo`Co00009Oooool01?l0003oooooooooool00002ooooo`03o`000?oooooooooo007ooooo
000mooooo`03o`000?oooooooooo02Kooooo0_l00004ooooo`04o`000?ooooooooooo`0002;ooooo
0_l00003ooooo`03o`000?oooooooooo02;ooooo00Go0000ooooooooooooooooo`000002ooooo`04
o`000?ooooooooooo`00023ooooo00Oo0000ooooooooooooooooo`000?oooooo000002Cooooo00Go
0000ooooooooooooooooo`000002ooooo`04o`000?ooooooooooo`0000?ooooo000mooooo`Go0000
9Oooool00ol0003oooooooooo`03ooooo`;o00009?ooool01?l0003oooooooooooooool5o`00027o
oooo0ol00004ooooo`;o00008_ooool3o`0000;ooooo1Ol0000Qooooo`?o00001?ooool2o`0000Co
oooo003oooooob7ooooo003oooooob7ooooo003oooooob7ooooo003oooooob7ooooo000Eoooooooo
00001Ol00007ooooo`005Oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Gooooo
00?o0000ooooooooool01_ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Gooooo
00?o0000ooooooooool01_ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Gooooo
00?o0000ooooooooool01_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Kooooo
00?o0000ooooooooool01_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Kooooo
00?o0000ooooooooool01_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Kooooo
00?o0000ooooooooool01_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Kooooo
00?o0000ooooooooool01Oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Kooooo
00?o0000ooooooooool01Oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Kooooo
00?o0000ooooooooool01Oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Kooooo
00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`005Oooool00ol0003ooooooooo
o`3oooooo`Wooooo000Eooooo`03o`000?oooooooooo0?oooooo2Oooool001Gooooo00?o0000oooo
ooooool0ooooool9ooooo`005Oooool00ol0003oooooooooo`3oooooo`Wooooo000Eooooo`03o`00
0?oooooooooo0?oooooo2Oooool001Gooooo00?o0000ooooooooool0ooooool9ooooo`005Oooool2
o`000?oooooo2_ooool001Gooooo00?o0000ooooooooool0ooooool9ooooo`005Oooool00ol0003o
ooooooooo`3oooooo`Wooooo000Eooooo`03o`000?oooooooooo0?oooooo2Oooool001Gooooo00?o
0000ooooooooool0ooooool9ooooo`005Oooool00ol0003oooooooooo`3oooooo`Wooooo000Eoooo
o`03o`000?oooooooooo0?oooooo2Oooool001Gooooo00?o0000ooooooooool0ooooool9ooooo`00
5Oooool2o`000?oooooo2_ooool001Gooooo00?o0000ooooooooool0ooooool9ooooo`005Oooool0
0ol0003oooooooooo`06ooooo`Go0000oOooool001Gooooo00?o0000ooooooooool02oooool9o`00
0?Cooooo000Eooooo`03o`000?oooooooooo01Cooooo1_l0003^ooooo`005Oooool00ol0003ooooo
ooooo`0Jooooo`Go0000jOooool001Gooooo00?o0000ooooooooool07oooool6o`000>?ooooo000E
ooooo`03o`000?oooooooooo02Gooooo1_l0003Mooooo`005Oooool2o`0002cooooo1Ol0003Hoooo
o`005Oooool00ol0003oooooooooo`0`ooooo`Co0000e?ooool001Gooooo00?o0000ooooooooool0
=?ooool3o`000=7ooooo000Eooooo`03o`000?oooooooooo03Oooooo0ol0003>ooooo`005Oooool0
0ol0003oooooooooo`0jooooo`;o0000c?ooool000;ooooo0_l00004ooooo`04o`000?oooooooooo
ooooo`Go00001?ooool00ol0003oooooooooo`0looooo`?o0000bOooool00005ooooool0003ooooo
ooooool000002?ooool01?l0003oooooooooool00004ooooo`03o`000?oooooooooo03oooooo0ol0
0036ooooo`0000Goooooo`000?ooooooooooo`000009ooooo`03o`000?oooooooooo00Cooooo00?o
0000ooooooooool0@_ooool3o`000<?ooooo00001Ooooooo0000oooooooooooo000000[ooooo00?o
0000ooooooooool00oooool3o`0004Gooooo0ol00030ooooo`0000Goooooo`000?ooooooooooo`00
0007ooooo`05o`000?ooooooooooooooool000001?ooool00ol0003oooooooooo`18ooooo`?o0000
_Oooool00005ooooool0003oooooooooool000001oooool01Ol0003ooooooooooooooooo000000Co
oooo00?o0000ooooooooool0Boooool2o`000;_ooooo0002ooooo`;o00002Oooool3o`0000Gooooo
00?o0000ooooooooool0COooool00ol0003oooooooooo`2hooooo`005Oooool00ol0003ooooooooo
o`1>ooooo`;o0000^?ooool001Gooooo00?o0000ooooooooool0D?ooool2o`000;Kooooo000Eoooo
o`03o`000?oooooooooo05;ooooo00?o0000ooooooooool0/oooool001Gooooo00?o0000oooooooo
ool0Doooool2o`000;?ooooo000Eooooo`;o0000E_ooool2o`000;7ooooo000Eooooo`03o`000?oo
oooooooo05Oooooo0_l0002_ooooo`005Oooool00ol0003oooooooooo`1Iooooo`03o`000?oooooo
oooo0:cooooo000Eooooo`03o`000?oooooooooo05[ooooo0_l0002/ooooo`005Oooool00ol0003o
ooooooooo`1Looooo`;o0000Z_ooool001Gooooo00?o0000ooooooooool0G_ooool00ol0003ooooo
ooooo`2Wooooo`005Oooool00ol0003oooooooooo`1Oooooo`;o0000Yoooool001Gooooo00?o0000
ooooooooool0HOooool00ol0003oooooooooo`2Tooooo`005Oooool2o`0006?ooooo0_l0002Toooo
o`005Oooool00ol0003oooooooooo`1Tooooo`03o`000?oooooooooo0:7ooooo000Eooooo`03o`00
0?oooooooooo06Gooooo0_l0002Qooooo`005Oooool00ol0003oooooooooo`1Wooooo`03o`000?oo
oooooooo09kooooo000Eooooo`03o`000?oooooooooo06Sooooo00?o0000ooooooooool0WOooool0
01Gooooo00?o0000ooooooooool0JOooool2o`0009gooooo000Eooooo`03o`000?oooooooooo06_o
oooo00?o0000ooooooooool0V_ooool001Gooooo00?o0000ooooooooool0K?ooool00ol0003ooooo
ooooo`2Iooooo`005Oooool2o`0006kooooo00?o0000ooooooooool0V?ooool001Gooooo00?o0000
ooooooooool0K_ooool00ol0003oooooooooo`2Gooooo`005Oooool00ol0003oooooooooo`1_oooo
o`03o`000?oooooooooo09Kooooo000Eooooo`03o`000?oooooooooo073ooooo00?o0000oooooooo
ool0UOooool001Gooooo00?o0000ooooooooool0LOooool00ol0003oooooooooo`2Dooooo`000_oo
ool2o`0000Cooooo00?o0000ooooooooool00oooool3o`0000Cooooo00?o0000ooooooooool0L_oo
ool00ol0003oooooooooo`2Cooooo`0000Goooooo`000?ooooooooooo`00000:ooooo`03o`000?oo
oooooooo00?ooooo00?o0000ooooooooool0Loooool00ol0003oooooooooo`2Booooo`0000Gooooo
o`000?ooooooooooo`000007ooooo`Go00001?ooool00ol0003oooooooooo`1dooooo`03o`000?oo
oooooooo097ooooo00001Ooooooo0000oooooooooooo000000Oooooo00Co0000oooooooooooo0000
1Oooool3o`0007Gooooo00?o0000ooooooooool0T?ooool00005ooooool0003oooooooooool00000
2?ooool00ol0003oooooo`000005ooooo`03o`000?oooooooooo07Kooooo00?o0000ooooooooool0
Soooool00005ooooool0003oooooooooool000002Oooool2o`0000Gooooo00?o0000ooooooooool0
Moooool00ol0003oooooooooo`2>ooooo`000_ooool2o`0000_ooooo00?o0000ooooooooool00ooo
ool00ol0003oooooooooo`1hooooo`03o`000?oooooooooo08gooooo000Eooooo`03o`000?oooooo
oooo07Wooooo00?o0000ooooooooool0S?ooool001Gooooo00?o0000ooooooooool0N_ooool00ol0
003oooooooooo`2;ooooo`005Oooool00ol0003oooooooooo`1kooooo`03o`000?oooooooooo08[o
oooo000Eooooo`03o`000?oooooooooo07cooooo00?o0000ooooooooool0ROooool001Gooooo0_l0
001nooooo`03o`000?oooooooooo08Sooooo000Eooooo`03o`000?oooooooooo07kooooo00?o0000
ooooooooool0Qoooool001Gooooo00?o0000ooooooooool0Ooooool00ol0003oooooooooo`26oooo
o`005Oooool00ol0003oooooooooo`1oooooo`03o`000?oooooooooo08Kooooo000Eooooo`03o`00
0?oooooooooo083ooooo00?o0000ooooooooool0QOooool001Gooooo00?o0000ooooooooool0POoo
ool00ol0003oooooooooo`24ooooo`005Oooool00ol0003oooooooooo`21ooooo`03o`000?oooooo
oooo08Cooooo000Eooooo`03o`000?oooooooooo08;ooooo00?o0000ooooooooool0Poooool001Go
oooo0_l00024ooooo`03o`000?oooooooooo08;ooooo000Eooooo`03o`000?oooooooooo08?ooooo
00?o0000ooooooooool0P_ooool001Gooooo00?o0000ooooooooool0Q?ooool00ol0003ooooooooo
o`21ooooo`005Oooool00ol0003oooooooooo`25ooooo`03o`000?oooooooooo083ooooo000Eoooo
o`03o`000?oooooooooo08Gooooo00?o0000ooooooooool0P?ooool001Gooooo00?o0000oooooooo
ool0Q_ooool00ol0003oooooooooo`1oooooo`005Oooool00ol0003oooooooooo`27ooooo`03o`00
0?oooooooooo07kooooo000Eooooo`03o`000?oooooooooo08Sooooo00?o0000ooooooooool0OOoo
ool001Gooooo0_l0002:ooooo`03o`000?oooooooooo07cooooo000Eooooo`03o`000?oooooooooo
08[ooooo00?o0000ooooooooool0Noooool001Gooooo00?o0000ooooooooool0Roooool00ol0003o
ooooooooo`1jooooo`005Oooool00ol0003oooooooooo`2<ooooo`03o`000?oooooooooo07Wooooo
000Eooooo`03o`000?oooooooooo08gooooo00?o0000ooooooooool0N?ooool000;ooooo0_l00004
ooooo`03o`000?oooooooooo00;ooooo0ol00005ooooo`03o`000?oooooooooo08kooooo00?o0000
ooooooooool0Moooool00005ooooool0003oooooooooool000001oooool01Ol0003ooooooooooooo
oooo000000Cooooo00?o0000ooooooooool0Soooool00ol0003oooooooooo`1fooooo`0000Gooooo
o`000?ooooooooooo`000007ooooo`05o`000?ooooooooooooooool000001?ooool00ol0003ooooo
ooooo`2@ooooo`;o0000M_ooool00005ooooool0003oooooooooool000001oooool4o`0000Gooooo
0ol0002Booooo`03o`000?oooooooooo07?ooooo00001Ooooooo0000oooooooooooo000000Oooooo
00?o0000ooooooooool01_ooool00ol0003oooooooooo`2Cooooo`03o`000?oooooooooo07;ooooo
00001Ooooooo0000oooooooooooo000000Sooooo00?o0000ooooooooool01Oooool00ol0003ooooo
ooooo`2Dooooo`03o`000?oooooooooo077ooooo0002ooooo`;o00002_ooool2o`0000Gooooo00?o
0000ooooooooool0UOooool00ol0003oooooooooo`1`ooooo`005Oooool00ol0003oooooooooo`2F
ooooo`03o`000?oooooooooo06oooooo000Eooooo`03o`000?oooooooooo09Oooooo00?o0000oooo
ooooool0K_ooool001Gooooo00?o0000ooooooooool0V?ooool00ol0003oooooooooo`1]ooooo`00
5Oooool00ol0003oooooooooo`2Iooooo`;o0000KOooool001Gooooo0_l0002Looooo`03o`000?oo
oooooooo06[ooooo000Eooooo`03o`000?oooooooooo09cooooo00?o0000ooooooooool0JOooool0
01Gooooo00?o0000ooooooooool0WOooool00ol0003oooooooooo`1Xooooo`005Oooool00ol0003o
ooooooooo`2Nooooo`03o`000?oooooooooo06Oooooo000Eooooo`03o`000?oooooooooo09oooooo
00?o0000ooooooooool0I_ooool001Gooooo00?o0000ooooooooool0X?ooool00ol0003ooooooooo
o`1Uooooo`005Oooool00ol0003oooooooooo`2Qooooo`;o0000IOooool001Gooooo00?o0000oooo
ooooool0Xoooool00ol0003oooooooooo`1Rooooo`005Oooool2o`000:Gooooo0_l0001Rooooo`00
5Oooool00ol0003oooooooooo`2Vooooo`03o`000?oooooooooo05oooooo000Eooooo`03o`000?oo
oooooooo0:Oooooo0_l0001Oooooo`005Oooool00ol0003oooooooooo`2Yooooo`03o`000?oooooo
oooo05cooooo000Eooooo`03o`000?oooooooooo0:[ooooo0_l0001Looooo`005Oooool00ol0003o
ooooooooo`2/ooooo`03o`000?oooooooooo05Wooooo000Eooooo`03o`000?oooooooooo0:gooooo
0_l0001Iooooo`005Oooool00ol0003oooooooooo`2_ooooo`;o0000Eoooool001Gooooo0_l0002b
ooooo`03o`000?oooooooooo05Cooooo000Eooooo`03o`000?oooooooooo0;;ooooo0_l0001Doooo
o`005Oooool00ol0003oooooooooo`2dooooo`;o0000D_ooool001Gooooo00?o0000ooooooooool0
]_ooool3o`0004oooooo000Eooooo`03o`000?oooooooooo0;Wooooo0_l0001=ooooo`000_ooool2
o`0000Cooooo00?o0000ooooooooool00_ooool3o`0000Gooooo00?o0000ooooooooool0^oooool2
o`0004_ooooo00001Ooooooo0000oooooooooooo000000Oooooo00Go0000ooooooooooooooooo`00
0004ooooo`03o`000?oooooooooo0;gooooo0_l00019ooooo`0000Goooooo`000?ooooooooooo`00
0007ooooo`05o`000?ooooooooooooooool000001?ooool00ol0003oooooooooo`2oooooo`?o0000
A_ooool00005ooooool0003oooooooooool000002?ooool3o`0000Gooooo0ol00032ooooo`;o0000
A?ooool00005ooooool0003oooooooooool000001oooool01Ol0003ooooooooooooooooo000000Co
oooo00?o0000ooooooooool0a?ooool2o`0004;ooooo00001Ooooooo0000oooooooooooo000000Oo
oooo00Go0000ooooooooooooooooo`000004ooooo`03o`000?oooooooooo0<Kooooo0ol0000ooooo
o`000_ooool2o`0000Wooooo0ol00005ooooo`03o`000?oooooooooo0<Wooooo0ol0000looooo`00
5Oooool00ol0003oooooooooo`3<ooooo`?o0000>Oooool001Gooooo00?o0000ooooooooool0cooo
ool5o`0003Cooooo000Eooooo`03o`000?oooooooooo0=Cooooo1?l0000`ooooo`005Oooool00ol0
003oooooooooo`3Hooooo`Go0000:oooool001Gooooo0_l0003Nooooo`Co00009oooool001Gooooo
00?o0000ooooooooool0hOooool4o`0002?ooooo000Eooooo`03o`000?oooooooooo0>Gooooo1ol0
000Looooo`005Oooool00ol0003oooooooooo`3/ooooo`Ko00005_ooool001Gooooo00?o0000oooo
ooooool0l_ooool5o`00017ooooo000Eooooo`03o`000?oooooooooo0?Oooooo1_l0000;ooooo`00
5Oooool00ol0003oooooooooo`3mooooo`Co00001oooool001Gooooo00?o0000ooooooooool0oooo
ool9ooooo`005Oooool2o`000?oooooo2_ooool001Gooooo00?o0000ooooooooool0ooooool9oooo
o`005Oooool00ol0003oooooooooo`3oooooo`Wooooo000Eooooo`03o`000?oooooooooo0?oooooo
2Oooool001Gooooo00?o0000ooooooooool0ooooool9ooooo`005Oooool00ol0003oooooooooo`3o
ooooo`Wooooo000Eooooo`03o`000?oooooooooo0?oooooo2Oooool001Gooooo00?o0000oooooooo
ool0ooooool9ooooo`005Oooool2o`000?oooooo2_ooool001Gooooo00?o0000ooooooooool0oooo
ool9ooooo`005Oooool00ol0003oooooooooo`3oooooo`Wooooo000Eooooo`03o`000?oooooooooo
0?oooooo2Oooool001Gooooo00?o0000ooooooooool0ooooool9ooooo`003Oooool3o`0000Gooooo
00?o0000ooooooooool0ooooool9ooooo`003_ooool00ol0003oooooooooo`04ooooo`03o`000?oo
oooooooo0?oooooo2Oooool000kooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`3o
ooooo`Wooooo000>ooooo`03o`000?oooooooooo00Cooooo0ol0003oooooo`Wooooo000>ooooo`03
o`000?oooooooooo0?oooooo4?ooool000gooooo0_l0003ooooooa;ooooo000>ooooo`03o`000?oo
oooooooo0?oooooo4?ooool00?oooooo8Oooool00001\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-2.49048, -0.0764114, \
0.115739, 0.00624232}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 0.0333333 0 0.618034 [
[.16667 -0.0125 -3 -9 ]
[.16667 -0.0125 3 0 ]
[.33333 -0.0125 -6 -9 ]
[.33333 -0.0125 6 0 ]
[.5 -0.0125 -6 -9 ]
[.5 -0.0125 6 0 ]
[.66667 -0.0125 -6 -9 ]
[.66667 -0.0125 6 0 ]
[.83333 -0.0125 -6 -9 ]
[.83333 -0.0125 6 0 ]
[1 -0.0125 -6 -9 ]
[1 -0.0125 6 0 ]
[-0.0125 .12361 -18 -4.5 ]
[-0.0125 .12361 0 4.5 ]
[-0.0125 .24721 -18 -4.5 ]
[-0.0125 .24721 0 4.5 ]
[-0.0125 .37082 -18 -4.5 ]
[-0.0125 .37082 0 4.5 ]
[-0.0125 .49443 -18 -4.5 ]
[-0.0125 .49443 0 4.5 ]
[-0.0125 .61803 -6 -4.5 ]
[-0.0125 .61803 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.16667 0 m
.16667 .00625 L
s
[(5)] .16667 -0.0125 0 1 Mshowa
.33333 0 m
.33333 .00625 L
s
[(10)] .33333 -0.0125 0 1 Mshowa
.5 0 m
.5 .00625 L
s
[(15)] .5 -0.0125 0 1 Mshowa
.66667 0 m
.66667 .00625 L
s
[(20)] .66667 -0.0125 0 1 Mshowa
.83333 0 m
.83333 .00625 L
s
[(25)] .83333 -0.0125 0 1 Mshowa
1 0 m
1 .00625 L
s
[(30)] 1 -0.0125 0 1 Mshowa
.125 Mabswid
.03333 0 m
.03333 .00375 L
s
.06667 0 m
.06667 .00375 L
s
.1 0 m
.1 .00375 L
s
.13333 0 m
.13333 .00375 L
s
.2 0 m
.2 .00375 L
s
.23333 0 m
.23333 .00375 L
s
.26667 0 m
.26667 .00375 L
s
.3 0 m
.3 .00375 L
s
.36667 0 m
.36667 .00375 L
s
.4 0 m
.4 .00375 L
s
.43333 0 m
.43333 .00375 L
s
.46667 0 m
.46667 .00375 L
s
.53333 0 m
.53333 .00375 L
s
.56667 0 m
.56667 .00375 L
s
.6 0 m
.6 .00375 L
s
.63333 0 m
.63333 .00375 L
s
.7 0 m
.7 .00375 L
s
.73333 0 m
.73333 .00375 L
s
.76667 0 m
.76667 .00375 L
s
.8 0 m
.8 .00375 L
s
.86667 0 m
.86667 .00375 L
s
.9 0 m
.9 .00375 L
s
.93333 0 m
.93333 .00375 L
s
.96667 0 m
.96667 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .12361 m
.00625 .12361 L
s
[(0.2)] -0.0125 .12361 1 0 Mshowa
0 .24721 m
.00625 .24721 L
s
[(0.4)] -0.0125 .24721 1 0 Mshowa
0 .37082 m
.00625 .37082 L
s
[(0.6)] -0.0125 .37082 1 0 Mshowa
0 .49443 m
.00625 .49443 L
s
[(0.8)] -0.0125 .49443 1 0 Mshowa
0 .61803 m
.00625 .61803 L
s
[(1)] -0.0125 .61803 1 0 Mshowa
.125 Mabswid
0 .0309 m
.00375 .0309 L
s
0 .0618 m
.00375 .0618 L
s
0 .09271 m
.00375 .09271 L
s
0 .15451 m
.00375 .15451 L
s
0 .18541 m
.00375 .18541 L
s
0 .21631 m
.00375 .21631 L
s
0 .27812 m
.00375 .27812 L
s
0 .30902 m
.00375 .30902 L
s
0 .33992 m
.00375 .33992 L
s
0 .40172 m
.00375 .40172 L
s
0 .43262 m
.00375 .43262 L
s
0 .46353 m
.00375 .46353 L
s
0 .52533 m
.00375 .52533 L
s
0 .55623 m
.00375 .55623 L
s
0 .58713 m
.00375 .58713 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.03333 .07201 m
.06667 .07857 L
.1 .08328 L
.13333 .08846 L
.16667 .09471 L
.2 .10235 L
.23333 .11163 L
.26667 .12282 L
.3 .13623 L
.33333 .1522 L
.36667 .17115 L
.4 .19357 L
.43333 .22001 L
.46667 .25112 L
.5 .28764 L
.53333 .33039 L
.56667 .36692 L
.6 .39803 L
.63333 .42447 L
.66667 .44688 L
.7 .46583 L
.73333 .48181 L
.76667 .49522 L
.8 .50641 L
.83333 .51569 L
.86667 .52332 L
.9 .52957 L
.93333 .53475 L
.96667 .53947 L
1 .54602 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[6]:=",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/B000`400?l00000o`00003ooooooolQ
ooooo`00?_ooool3o`0002Gooooo0ol00004ooooo`;o00008oooool3o`0000?ooooo0ol0000Qoooo
o`Go00000oooool2o`00027ooooo1Ol00002ooooo`?o00008_ooool3o`0000Cooooo0_l00004oooo
o`00?Oooool01Ol0003ooooooooooooooooo000002Gooooo00?o0000ooooooooool00_ooool01?l0
003oooooooooool0000Sooooo`05o`000?ooooooooooooooool000000oooool00ol0003ooooooooo
o`0Oooooo`04o`000?ooooooooooo`0000;ooooo00Co0000oooooooooooo00008Oooool01_l0003o
ooooooooool0003oooooo`0000?ooooo00?o0000ooooooooool07_ooool01Ol0003ooooooooooooo
oooo000000;ooooo00Co0000oooooooooooo00000oooool0047ooooo00?o0000ooooooooool08ooo
ool00ol0003oooooooooo`02ooooo`04o`000?ooooooooooo`0002?ooooo00?o0000ooooooooool0
1Oooool00ol0003oooooooooo`0Pooooo`03o`000?oooooooooo00;ooooo00Co0000oooooooooooo
00008_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo02;ooooo00Co0000oooooooo
oooo00000_ooool00ol0003oooooooooo`01ooooo`00@Oooool00ol0003oooooooooo`0Sooooo`03
o`000?oooooooooo00;ooooo00Co0000oooooooooooo00008oooool00ol0003oooooooooo`05oooo
o`03o`000?oooooooooo027ooooo00Go0000ooooooooooooooooo`000002ooooo`03o`000?oooooo
oooo027ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`0Pooooo`;o00000oooool0
1?l0003oooooooooool00003ooooo`00?Oooool4o`0002Kooooo00?o0000ooooooooool00_ooool0
1?l0003oooooooooool0000Sooooo`04o`000?ooooooooooooooo`Co00008Oooool01Ol0003ooooo
oooooooooooo000000;ooooo00Co0000oooooooooooo00008?ooool01_l0003ooooooooooooooooo
0000ooooo`Co00009Oooool01?l0003oooooooooool00002ooooo`03o`000?oooooooooo007ooooo
000mooooo`03o`000?oooooooooo02Kooooo0_l00004ooooo`04o`000?ooooooooooo`0002;ooooo
0_l00003ooooo`03o`000?oooooooooo02;ooooo00Go0000ooooooooooooooooo`000002ooooo`04
o`000?ooooooooooo`00023ooooo00Oo0000ooooooooooooooooo`000?oooooo000002Cooooo00Go
0000ooooooooooooooooo`000002ooooo`04o`000?ooooooooooo`0000?ooooo000mooooo`Go0000
9Oooool00ol0003oooooooooo`03ooooo`;o00009?ooool01?l0003oooooooooooooool5o`00027o
oooo0ol00004ooooo`;o00008_ooool3o`0000;ooooo1Ol0000Qooooo`?o00001?ooool2o`0000Co
oooo003oooooob7ooooo003oooooob7ooooo003oooooob7ooooo003oooooob7ooooo000Eoooooooo
00001Ol00007ooooo`005Oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Gooooo
00?o0000ooooooooool01_ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Gooooo
00?o0000ooooooooool01_ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Gooooo
00?o0000ooooooooool01_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Kooooo
00?o0000ooooooooool01_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Kooooo
00?o0000ooooooooool01_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Kooooo
00?o0000ooooooooool01_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Kooooo
00?o0000ooooooooool01Oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Kooooo
00?o0000ooooooooool01Oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Kooooo
00?o0000ooooooooool01Oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Kooooo
00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`005Oooool00ol0003ooooooooo
o`3oooooo`Wooooo000Eooooo`03o`000?oooooooooo0?oooooo2Oooool001Gooooo00?o0000oooo
ooooool0ooooool9ooooo`005Oooool00ol0003oooooooooo`3oooooo`Wooooo000Eooooo`03o`00
0?oooooooooo0?oooooo2Oooool001Gooooo00?o0000ooooooooool0ooooool9ooooo`005Oooool2
o`000?oooooo2_ooool001Gooooo00?o0000ooooooooool0ooooool9ooooo`005Oooool00ol0003o
ooooooooo`3oooooo`Wooooo000Eooooo`03o`000?oooooooooo0?oooooo2Oooool001Gooooo00?o
0000ooooooooool0ooooool9ooooo`005Oooool00ol0003oooooooooo`3oooooo`Wooooo000Eoooo
o`03o`000?oooooooooo0?oooooo2Oooool001Gooooo00?o0000ooooooooool0ooooool9ooooo`00
5Oooool2o`000?oooooo2_ooool001Gooooo00?o0000ooooooooool0ooooool9ooooo`005Oooool0
0ol0003oooooooooo`06ooooo`?o0000ooooool001Gooooo00?o0000ooooooooool02Oooool4o`00
0?_ooooo000Eooooo`03o`000?oooooooooo00gooooo1ol0003dooooo`005Oooool00ol0003ooooo
ooooo`0Dooooo`Ko0000k_ooool001Gooooo00?o0000ooooooooool06_ooool5o`000>Wooooo000E
ooooo`03o`000?oooooooooo01oooooo1_l0003Sooooo`005Oooool2o`0002Kooooo1_l0003Moooo
o`005Oooool00ol0003oooooooooo`0[ooooo`Go0000f?ooool001Gooooo00?o0000ooooooooool0
<?ooool4o`000=Cooooo000Eooooo`03o`000?oooooooooo03Cooooo0ol0003Aooooo`005Oooool0
0ol0003oooooooooo`0gooooo`?o0000c_ooool000;ooooo0_l00004ooooo`04o`000?oooooooooo
ooooo`Go00001?ooool00ol0003oooooooooo`0jooooo`;o0000c?ooool00005ooooool0003ooooo
ooooool000002?ooool01?l0003oooooooooool00004ooooo`03o`000?oooooooooo03cooooo0ol0
0039ooooo`0000Goooooo`000?ooooooooooo`000009ooooo`03o`000?oooooooooo00Cooooo00?o
0000ooooooooool0?oooool3o`000<Kooooo00001Ooooooo0000oooooooooooo000000[ooooo00?o
0000ooooooooool00oooool3o`0004;ooooo0ol00033ooooo`0000Goooooo`000?ooooooooooo`00
0007ooooo`05o`000?ooooooooooooooool000001?ooool00ol0003oooooooooo`15ooooo`?o0000
`?ooool00005ooooool0003oooooooooool000001oooool01Ol0003ooooooooooooooooo000000Co
oooo00?o0000ooooooooool0B?ooool3o`000;gooooo0002ooooo`;o00002Oooool3o`0000Gooooo
00?o0000ooooooooool0Boooool2o`000;_ooooo000Eooooo`03o`000?oooooooooo04gooooo0_l0
002iooooo`005Oooool00ol0003oooooooooo`1?ooooo`;o0000]oooool001Gooooo00?o0000oooo
ooooool0DOooool2o`000;Gooooo000Eooooo`03o`000?oooooooooo05?ooooo0_l0002cooooo`00
5Oooool2o`0005Kooooo0_l0002aooooo`005Oooool00ol0003oooooooooo`1Gooooo`;o0000[ooo
ool001Gooooo00?o0000ooooooooool0FOooool00ol0003oooooooooo`2/ooooo`005Oooool00ol0
003oooooooooo`1Jooooo`;o0000[?ooool001Gooooo00?o0000ooooooooool0G?ooool2o`000:[o
oooo000Eooooo`03o`000?oooooooooo05kooooo00?o0000ooooooooool0Yoooool001Gooooo00?o
0000ooooooooool0Goooool2o`000:Oooooo000Eooooo`03o`000?oooooooooo067ooooo00?o0000
ooooooooool0Y?ooool001Gooooo0_l0001Sooooo`;o0000Y?ooool001Gooooo00?o0000oooooooo
ool0I?ooool00ol0003oooooooooo`2Qooooo`005Oooool00ol0003oooooooooo`1Uooooo`;o0000
XOooool001Gooooo00?o0000ooooooooool0Ioooool00ol0003oooooooooo`2Nooooo`005Oooool0
0ol0003oooooooooo`1Xooooo`03o`000?oooooooooo09gooooo000Eooooo`03o`000?oooooooooo
06Wooooo00?o0000ooooooooool0W?ooool001Gooooo00?o0000ooooooooool0J_ooool00ol0003o
ooooooooo`2Kooooo`005Oooool00ol0003oooooooooo`1[ooooo`03o`000?oooooooooo09[ooooo
000Eooooo`;o0000KOooool00ol0003oooooooooo`2Iooooo`005Oooool00ol0003oooooooooo`1]
ooooo`;o0000VOooool001Gooooo00?o0000ooooooooool0Koooool00ol0003oooooooooo`2Foooo
o`005Oooool00ol0003oooooooooo`1`ooooo`03o`000?oooooooooo09Gooooo000Eooooo`03o`00
0?oooooooooo077ooooo00?o0000ooooooooool0U?ooool000;ooooo0_l00004ooooo`03o`000?oo
oooooooo00?ooooo0ol00004ooooo`03o`000?oooooooooo07;ooooo00?o0000ooooooooool0Tooo
ool00005ooooool0003oooooooooool000002_ooool00ol0003oooooooooo`03ooooo`03o`000?oo
oooooooo07?ooooo00?o0000ooooooooool0T_ooool00005ooooool0003oooooooooool000001ooo
ool5o`0000Cooooo00?o0000ooooooooool0M?ooool00ol0003oooooooooo`2Aooooo`0000Gooooo
o`000?ooooooooooo`000007ooooo`04o`000?ooooooooooo`0000Gooooo0ol0001eooooo`03o`00
0?oooooooooo093ooooo00001Ooooooo0000oooooooooooo000000Sooooo00?o0000ooooool00000
1Oooool00ol0003oooooooooo`1fooooo`03o`000?oooooooooo08oooooo00001Ooooooo0000oooo
oooooooo000000Wooooo0_l00005ooooo`03o`000?oooooooooo07Oooooo00?o0000ooooooooool0
S_ooool000;ooooo0_l0000;ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0N?oo
ool00ol0003oooooooooo`2=ooooo`005Oooool00ol0003oooooooooo`1iooooo`03o`000?oooooo
oooo08cooooo000Eooooo`03o`000?oooooooooo07[ooooo00?o0000ooooooooool0Roooool001Go
oooo00?o0000ooooooooool0Noooool00ol0003oooooooooo`2:ooooo`005Oooool00ol0003ooooo
ooooo`1looooo`03o`000?oooooooooo08Wooooo000Eooooo`;o0000O_ooool00ol0003ooooooooo
o`28ooooo`005Oooool00ol0003oooooooooo`1nooooo`03o`000?oooooooooo08Oooooo000Eoooo
o`03o`000?oooooooooo07oooooo00?o0000ooooooooool0Q_ooool001Gooooo00?o0000oooooooo
ool0Ooooool00ol0003oooooooooo`26ooooo`005Oooool00ol0003oooooooooo`20ooooo`03o`00
0?oooooooooo08Gooooo000Eooooo`03o`000?oooooooooo087ooooo00?o0000ooooooooool0Q?oo
ool001Gooooo00?o0000ooooooooool0P_ooool00ol0003oooooooooo`23ooooo`005Oooool00ol0
003oooooooooo`22ooooo`03o`000?oooooooooo08?ooooo000Eooooo`;o0000Q?ooool00ol0003o
ooooooooo`22ooooo`005Oooool00ol0003oooooooooo`24ooooo`03o`000?oooooooooo087ooooo
000Eooooo`03o`000?oooooooooo08Cooooo00?o0000ooooooooool0POooool001Gooooo00?o0000
ooooooooool0QOooool00ol0003oooooooooo`20ooooo`005Oooool00ol0003oooooooooo`26oooo
o`03o`000?oooooooooo07oooooo000Eooooo`03o`000?oooooooooo08Oooooo00?o0000oooooooo
ool0O_ooool001Gooooo00?o0000ooooooooool0Qoooool00ol0003oooooooooo`1nooooo`005Ooo
ool00ol0003oooooooooo`28ooooo`03o`000?oooooooooo07gooooo000Eooooo`;o0000R_ooool0
0ol0003oooooooooo`1looooo`005Oooool00ol0003oooooooooo`2:ooooo`03o`000?oooooooooo
07_ooooo000Eooooo`03o`000?oooooooooo08_ooooo00?o0000ooooooooool0N_ooool001Gooooo
00?o0000ooooooooool0S?ooool00ol0003oooooooooo`1iooooo`005Oooool00ol0003ooooooooo
o`2=ooooo`03o`000?oooooooooo07Sooooo0002ooooo`;o00001?ooool00ol0003oooooooooo`02
ooooo`?o00001Oooool00ol0003oooooooooo`2>ooooo`03o`000?oooooooooo07Oooooo00001Ooo
oooo0000oooooooooooo000000Oooooo00Go0000ooooooooooooooooo`000004ooooo`03o`000?oo
oooooooo08oooooo00?o0000ooooooooool0M_ooool00005ooooool0003oooooooooool000001ooo
ool01Ol0003ooooooooooooooooo000000Cooooo00?o0000ooooooooool0T?ooool2o`0007Kooooo
00001Ooooooo0000oooooooooooo000000Oooooo1?l00005ooooo`?o0000T_ooool00ol0003ooooo
ooooo`1cooooo`0000Goooooo`000?ooooooooooo`000007ooooo`03o`000?oooooooooo00Kooooo
00?o0000ooooooooool0Toooool00ol0003oooooooooo`1booooo`0000Goooooo`000?oooooooooo
o`000008ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0U?ooool00ol0003ooooo
ooooo`1aooooo`000_ooool2o`0000[ooooo0_l00005ooooo`03o`000?oooooooooo09Gooooo00?o
0000ooooooooool0L?ooool001Gooooo00?o0000ooooooooool0U_ooool00ol0003oooooooooo`1_
ooooo`005Oooool00ol0003oooooooooo`2Gooooo`03o`000?oooooooooo06kooooo000Eooooo`03
o`000?oooooooooo09Sooooo00?o0000ooooooooool0KOooool001Gooooo00?o0000ooooooooool0
VOooool2o`0006gooooo000Eooooo`;o0000W?ooool00ol0003oooooooooo`1Zooooo`005Oooool0
0ol0003oooooooooo`2Looooo`03o`000?oooooooooo06Wooooo000Eooooo`03o`000?oooooooooo
09gooooo00?o0000ooooooooool0J?ooool001Gooooo00?o0000ooooooooool0W_ooool00ol0003o
ooooooooo`1Wooooo`005Oooool00ol0003oooooooooo`2Oooooo`03o`000?oooooooooo06Kooooo
000Eooooo`03o`000?oooooooooo0:3ooooo00?o0000ooooooooool0IOooool001Gooooo00?o0000
ooooooooool0XOooool2o`0006Gooooo000Eooooo`03o`000?oooooooooo0:?ooooo00?o0000oooo
ooooool0H_ooool001Gooooo0_l0002Uooooo`;o0000H_ooool001Gooooo00?o0000ooooooooool0
Y_ooool00ol0003oooooooooo`1Oooooo`005Oooool00ol0003oooooooooo`2Wooooo`;o0000Gooo
ool001Gooooo00?o0000ooooooooool0ZOooool00ol0003oooooooooo`1Looooo`005Oooool00ol0
003oooooooooo`2Zooooo`;o0000G?ooool001Gooooo00?o0000ooooooooool0[?ooool00ol0003o
ooooooooo`1Iooooo`005Oooool00ol0003oooooooooo`2]ooooo`;o0000FOooool001Gooooo00?o
0000ooooooooool0[oooool2o`0005Oooooo000Eooooo`;o0000/_ooool00ol0003oooooooooo`1D
ooooo`005Oooool00ol0003oooooooooo`2booooo`;o0000E?ooool001Gooooo00?o0000oooooooo
ool0]?ooool2o`0005;ooooo000Eooooo`03o`000?oooooooooo0;Kooooo0ol0001?ooooo`005Ooo
ool00ol0003oooooooooo`2iooooo`;o0000COooool000;ooooo0_l00004ooooo`03o`000?oooooo
oooo00;ooooo0ol00005ooooo`03o`000?oooooooooo0;_ooooo0ol0001:ooooo`0000Goooooo`00
0?ooooooooooo`000007ooooo`05o`000?ooooooooooooooool000001?ooool00ol0003ooooooooo
o`2nooooo`?o0000Aoooool00005ooooool0003oooooooooool000001oooool01Ol0003ooooooooo
oooooooo000000Cooooo00?o0000ooooooooool0`Oooool3o`0004Cooooo00001Ooooooo0000oooo
oooooooo000000Sooooo0ol00005ooooo`?o0000a?ooool2o`0004;ooooo00001Ooooooo0000oooo
oooooooo000000Oooooo00Go0000ooooooooooooooooo`000004ooooo`03o`000?oooooooooo0<Ko
oooo0ol0000oooooo`0000Goooooo`000?ooooooooooo`000007ooooo`05o`000?oooooooooooooo
ool000001?ooool00ol0003oooooooooo`39ooooo`?o0000??ooool000;ooooo0_l00009ooooo`?o
00001Oooool00ol0003oooooooooo`3<ooooo`?o0000>Oooool001Gooooo00?o0000ooooooooool0
coooool5o`0003Cooooo000Eooooo`03o`000?oooooooooo0=Cooooo1?l0000`ooooo`005Oooool0
0ol0003oooooooooo`3Hooooo`Go0000:oooool001Gooooo00?o0000ooooooooool0gOooool4o`00
02Oooooo000Eooooo`;o0000h_ooool4o`0002?ooooo000Eooooo`03o`000?oooooooooo0>Gooooo
1ol0000Looooo`005Oooool00ol0003oooooooooo`3/ooooo`Ko00005_ooool001Gooooo00?o0000
ooooooooool0l_ooool5o`00017ooooo000Eooooo`03o`000?oooooooooo0?Oooooo1_l0000;oooo
o`005Oooool00ol0003oooooooooo`3mooooo`Co00001oooool001Gooooo00?o0000ooooooooool0
ooooool9ooooo`005Oooool00ol0003oooooooooo`3oooooo`Wooooo000Eooooo`;o0000ooooool:
ooooo`005Oooool00ol0003oooooooooo`3oooooo`Wooooo000Eooooo`03o`000?oooooooooo0?oo
oooo2Oooool001Gooooo00?o0000ooooooooool0ooooool9ooooo`005Oooool00ol0003ooooooooo
o`3oooooo`Wooooo000Eooooo`03o`000?oooooooooo0?oooooo2Oooool001Gooooo00?o0000oooo
ooooool0ooooool9ooooo`005Oooool00ol0003oooooooooo`3oooooo`Wooooo000Eooooo`;o0000
ooooool:ooooo`005Oooool00ol0003oooooooooo`3oooooo`Wooooo000Eooooo`03o`000?oooooo
oooo0?oooooo2Oooool001Gooooo00?o0000ooooooooool0ooooool9ooooo`005Oooool00ol0003o
ooooooooo`3oooooo`Wooooo000=ooooo`?o00001Oooool00ol0003oooooooooo`3oooooo`Wooooo
000>ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0ooooool9ooooo`003_ooool0
0ol0003oooooooooo`04ooooo`03o`000?oooooooooo0?oooooo2Oooool000kooooo00?o0000oooo
ooooool01?ooool3o`000?oooooo2Oooool000kooooo00?o0000ooooooooool0ooooool@ooooo`00
3Oooool2o`000?oooooo4_ooool000kooooo00?o0000ooooooooool0ooooool@ooooo`00oooooolQ
ooooo`00\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-2.49048, -0.0764114, \
0.115739, 0.00624232}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 0.0333333 0 0.618034 [
[.16667 -0.0125 -3 -9 ]
[.16667 -0.0125 3 0 ]
[.33333 -0.0125 -6 -9 ]
[.33333 -0.0125 6 0 ]
[.5 -0.0125 -6 -9 ]
[.5 -0.0125 6 0 ]
[.66667 -0.0125 -6 -9 ]
[.66667 -0.0125 6 0 ]
[.83333 -0.0125 -6 -9 ]
[.83333 -0.0125 6 0 ]
[1 -0.0125 -6 -9 ]
[1 -0.0125 6 0 ]
[-0.0125 .12361 -18 -4.5 ]
[-0.0125 .12361 0 4.5 ]
[-0.0125 .24721 -18 -4.5 ]
[-0.0125 .24721 0 4.5 ]
[-0.0125 .37082 -18 -4.5 ]
[-0.0125 .37082 0 4.5 ]
[-0.0125 .49443 -18 -4.5 ]
[-0.0125 .49443 0 4.5 ]
[-0.0125 .61803 -6 -4.5 ]
[-0.0125 .61803 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.16667 0 m
.16667 .00625 L
s
[(5)] .16667 -0.0125 0 1 Mshowa
.33333 0 m
.33333 .00625 L
s
[(10)] .33333 -0.0125 0 1 Mshowa
.5 0 m
.5 .00625 L
s
[(15)] .5 -0.0125 0 1 Mshowa
.66667 0 m
.66667 .00625 L
s
[(20)] .66667 -0.0125 0 1 Mshowa
.83333 0 m
.83333 .00625 L
s
[(25)] .83333 -0.0125 0 1 Mshowa
1 0 m
1 .00625 L
s
[(30)] 1 -0.0125 0 1 Mshowa
.125 Mabswid
.03333 0 m
.03333 .00375 L
s
.06667 0 m
.06667 .00375 L
s
.1 0 m
.1 .00375 L
s
.13333 0 m
.13333 .00375 L
s
.2 0 m
.2 .00375 L
s
.23333 0 m
.23333 .00375 L
s
.26667 0 m
.26667 .00375 L
s
.3 0 m
.3 .00375 L
s
.36667 0 m
.36667 .00375 L
s
.4 0 m
.4 .00375 L
s
.43333 0 m
.43333 .00375 L
s
.46667 0 m
.46667 .00375 L
s
.53333 0 m
.53333 .00375 L
s
.56667 0 m
.56667 .00375 L
s
.6 0 m
.6 .00375 L
s
.63333 0 m
.63333 .00375 L
s
.7 0 m
.7 .00375 L
s
.73333 0 m
.73333 .00375 L
s
.76667 0 m
.76667 .00375 L
s
.8 0 m
.8 .00375 L
s
.86667 0 m
.86667 .00375 L
s
.9 0 m
.9 .00375 L
s
.93333 0 m
.93333 .00375 L
s
.96667 0 m
.96667 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .12361 m
.00625 .12361 L
s
[(0.2)] -0.0125 .12361 1 0 Mshowa
0 .24721 m
.00625 .24721 L
s
[(0.4)] -0.0125 .24721 1 0 Mshowa
0 .37082 m
.00625 .37082 L
s
[(0.6)] -0.0125 .37082 1 0 Mshowa
0 .49443 m
.00625 .49443 L
s
[(0.8)] -0.0125 .49443 1 0 Mshowa
0 .61803 m
.00625 .61803 L
s
[(1)] -0.0125 .61803 1 0 Mshowa
.125 Mabswid
0 .0309 m
.00375 .0309 L
s
0 .0618 m
.00375 .0618 L
s
0 .09271 m
.00375 .09271 L
s
0 .15451 m
.00375 .15451 L
s
0 .18541 m
.00375 .18541 L
s
0 .21631 m
.00375 .21631 L
s
0 .27812 m
.00375 .27812 L
s
0 .30902 m
.00375 .30902 L
s
0 .33992 m
.00375 .33992 L
s
0 .40172 m
.00375 .40172 L
s
0 .43262 m
.00375 .43262 L
s
0 .46353 m
.00375 .46353 L
s
0 .52533 m
.00375 .52533 L
s
0 .55623 m
.00375 .55623 L
s
0 .58713 m
.00375 .58713 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.03333 .07426 m
.06667 .08119 L
.1 .08602 L
.13333 .09122 L
.16667 .09744 L
.2 .10499 L
.23333 .11416 L
.26667 .1252 L
.3 .13842 L
.33333 .15416 L
.36667 .17285 L
.4 .19495 L
.43333 .22103 L
.46667 .25175 L
.5 .28786 L
.53333 .33017 L
.56667 .36628 L
.6 .397 L
.63333 .42309 L
.66667 .44519 L
.7 .46387 L
.73333 .47962 L
.76667 .49284 L
.8 .50388 L
.83333 .51304 L
.86667 .5206 L
.9 .52681 L
.93333 .53201 L
.96667 .53684 L
1 .54378 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[6]:=",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/B000`400?l00000o`00003ooooooolQ
ooooo`00?_ooool3o`0002Gooooo0ol00004ooooo`;o00008oooool3o`0000?ooooo0ol0000Qoooo
o`Go00000oooool2o`00027ooooo1Ol00002ooooo`?o00008_ooool3o`0000Cooooo0_l00004oooo
o`00?Oooool01Ol0003ooooooooooooooooo000002Gooooo00?o0000ooooooooool00_ooool01?l0
003oooooooooool0000Sooooo`05o`000?ooooooooooooooool000000oooool00ol0003ooooooooo
o`0Oooooo`04o`000?ooooooooooo`0000;ooooo00Co0000oooooooooooo00008Oooool01_l0003o
ooooooooool0003oooooo`0000?ooooo00?o0000ooooooooool07_ooool01Ol0003ooooooooooooo
oooo000000;ooooo00Co0000oooooooooooo00000oooool0047ooooo00?o0000ooooooooool08ooo
ool00ol0003oooooooooo`02ooooo`04o`000?ooooooooooo`0002?ooooo00?o0000ooooooooool0
1Oooool00ol0003oooooooooo`0Pooooo`03o`000?oooooooooo00;ooooo00Co0000oooooooooooo
00008_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo02;ooooo00Co0000oooooooo
oooo00000_ooool00ol0003oooooooooo`01ooooo`00@Oooool00ol0003oooooooooo`0Sooooo`03
o`000?oooooooooo00;ooooo00Co0000oooooooooooo00008oooool00ol0003oooooooooo`05oooo
o`03o`000?oooooooooo027ooooo00Go0000ooooooooooooooooo`000002ooooo`03o`000?oooooo
oooo027ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`0Pooooo`;o00000oooool0
1?l0003oooooooooool00003ooooo`00?Oooool4o`0002Kooooo00?o0000ooooooooool00_ooool0
1?l0003oooooooooool0000Sooooo`04o`000?ooooooooooooooo`Co00008Oooool01Ol0003ooooo
oooooooooooo000000;ooooo00Co0000oooooooooooo00008?ooool01_l0003ooooooooooooooooo
0000ooooo`Co00009Oooool01?l0003oooooooooool00002ooooo`03o`000?oooooooooo007ooooo
000mooooo`03o`000?oooooooooo02Kooooo0_l00004ooooo`04o`000?ooooooooooo`0002;ooooo
0_l00003ooooo`03o`000?oooooooooo02;ooooo00Go0000ooooooooooooooooo`000002ooooo`04
o`000?ooooooooooo`00023ooooo00Oo0000ooooooooooooooooo`000?oooooo000002Cooooo00Go
0000ooooooooooooooooo`000002ooooo`04o`000?ooooooooooo`0000?ooooo000mooooo`Go0000
9Oooool00ol0003oooooooooo`03ooooo`;o00009?ooool01?l0003oooooooooooooool5o`00027o
oooo0ol00004ooooo`;o00008_ooool3o`0000;ooooo1Ol0000Qooooo`?o00001?ooool2o`0000Co
oooo003oooooob7ooooo003oooooob7ooooo003oooooob7ooooo003oooooob7ooooo000Eoooooooo
00001Ol00007ooooo`005Oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Gooooo
00?o0000ooooooooool01_ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Gooooo
00?o0000ooooooooool01_ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Gooooo
00?o0000ooooooooool01_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Kooooo
00?o0000ooooooooool01_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Kooooo
00?o0000ooooooooool01_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Kooooo
00?o0000ooooooooool01_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Kooooo
00?o0000ooooooooool01Oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Kooooo
00?o0000ooooooooool01Oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Kooooo
00?o0000ooooooooool01Oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Kooooo
00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`005Oooool00ol0003ooooooooo
o`3oooooo`Wooooo000Eooooo`03o`000?oooooooooo0?oooooo2Oooool001Gooooo00?o0000oooo
ooooool0ooooool9ooooo`005Oooool00ol0003oooooooooo`3oooooo`Wooooo000Eooooo`03o`00
0?oooooooooo0?oooooo2Oooool001Gooooo00?o0000ooooooooool0ooooool9ooooo`005Oooool2
o`000?oooooo2_ooool001Gooooo00?o0000ooooooooool0ooooool9ooooo`005Oooool00ol0003o
ooooooooo`3oooooo`Wooooo000Eooooo`03o`000?oooooooooo0?oooooo2Oooool001Gooooo00?o
0000ooooooooool0ooooool9ooooo`005Oooool00ol0003oooooooooo`3oooooo`Wooooo000Eoooo
o`03o`000?oooooooooo0?oooooo2Oooool001Gooooo00?o0000ooooooooool0ooooool9ooooo`00
5Oooool2o`000?oooooo2_ooool001Gooooo00?o0000ooooooooool0ooooool9ooooo`005Oooool0
0ol0003oooooooooo`3oooooo`Wooooo000Eooooo`03o`000?oooooooooo00Kooooo0ol0003ooooo
o`005Oooool00ol0003oooooooooo`09ooooo`Co0000noooool001Gooooo00?o0000ooooooooool0
3Oooool7o`000?Cooooo000Eooooo`03o`000?oooooooooo01Cooooo2Ol0003[ooooo`005Oooool0
0ol0003oooooooooo`0Mooooo`Ko0000iOooool001Gooooo0_l0000Tooooo`Co0000hOooool001Go
oooo00?o0000ooooooooool09oooool4o`000=gooooo000Eooooo`03o`000?oooooooooo02_ooooo
1Ol0003Hooooo`005Oooool00ol0003oooooooooo`0`ooooo`Co0000e?ooool001Gooooo00?o0000
ooooooooool0=?ooool5o`000<oooooo0002ooooo`;o00001?ooool01?l0003oooooooooooooool5
o`0000Cooooo00?o0000ooooooooool0>Oooool3o`000<cooooo00001Ooooooo0000oooooooooooo
000000Sooooo00Co0000oooooooooooo00001?ooool00ol0003oooooooooo`0looooo`?o0000bOoo
ool00005ooooool0003oooooooooool000002Oooool00ol0003oooooooooo`04ooooo`03o`000?oo
oooooooo03oooooo0ol00036ooooo`0000Goooooo`000?ooooooooooo`00000:ooooo`03o`000?oo
oooooooo00?ooooo0ol00012ooooo`;o0000a?ooool00005ooooool0003oooooooooool000001ooo
ool01Ol0003ooooooooooooooooo000000Cooooo00?o0000ooooooooool0A?ooool2o`000<;ooooo
00001Ooooooo0000oooooooooooo000000Oooooo00Go0000ooooooooooooooooo`000004ooooo`03
o`000?oooooooooo04Kooooo0ol0002oooooo`000_ooool2o`0000Wooooo0ol00005ooooo`03o`00
0?oooooooooo04Wooooo0_l0002mooooo`005Oooool00ol0003oooooooooo`1;ooooo`;o0000^ooo
ool001Gooooo00?o0000ooooooooool0COooool2o`000;Wooooo000Eooooo`03o`000?oooooooooo
04oooooo0_l0002gooooo`005Oooool00ol0003oooooooooo`1Aooooo`;o0000]Oooool001Gooooo
0_l0001Dooooo`;o0000/oooool001Gooooo00?o0000ooooooooool0EOooool2o`000;7ooooo000E
ooooo`03o`000?oooooooooo05Oooooo0_l0002_ooooo`005Oooool00ol0003oooooooooo`1Ioooo
o`03o`000?oooooooooo0:cooooo000Eooooo`03o`000?oooooooooo05[ooooo0_l0002/ooooo`00
5Oooool00ol0003oooooooooo`1Looooo`;o0000Z_ooool001Gooooo00?o0000ooooooooool0G_oo
ool2o`000:Sooooo000Eooooo`03o`000?oooooooooo063ooooo0_l0002Vooooo`005Oooool2o`00
06?ooooo00?o0000ooooooooool0Xoooool001Gooooo00?o0000ooooooooool0Hoooool2o`000:?o
oooo000Eooooo`03o`000?oooooooooo06Gooooo0_l0002Qooooo`005Oooool00ol0003ooooooooo
o`1Wooooo`03o`000?oooooooooo09kooooo000Eooooo`03o`000?oooooooooo06Sooooo00?o0000
ooooooooool0WOooool001Gooooo00?o0000ooooooooool0JOooool00ol0003oooooooooo`2Loooo
o`005Oooool00ol0003oooooooooo`1Zooooo`03o`000?oooooooooo09_ooooo000Eooooo`03o`00
0?oooooooooo06_ooooo00?o0000ooooooooool0V_ooool001Gooooo0_l0001]ooooo`03o`000?oo
oooooooo09Wooooo000Eooooo`03o`000?oooooooooo06gooooo0_l0002Iooooo`005Oooool00ol0
003oooooooooo`1_ooooo`03o`000?oooooooooo09Kooooo000Eooooo`03o`000?oooooooooo073o
oooo00?o0000ooooooooool0UOooool001Gooooo00?o0000ooooooooool0LOooool00ol0003ooooo
ooooo`2Dooooo`000_ooool2o`0000Cooooo00?o0000ooooooooool00oooool3o`0000Cooooo00?o
0000ooooooooool0L_ooool00ol0003oooooooooo`2Cooooo`0000Goooooo`000?ooooooooooo`00
000:ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0Loooool00ol0003ooooooooo
o`2Booooo`0000Goooooo`000?ooooooooooo`000007ooooo`Go00001?ooool00ol0003ooooooooo
o`1dooooo`03o`000?oooooooooo097ooooo00001Ooooooo0000oooooooooooo000000Oooooo00Co
0000oooooooooooo00001Oooool3o`0007Gooooo00?o0000ooooooooool0T?ooool00005ooooool0
003oooooooooool000002?ooool00ol0003oooooo`000005ooooo`03o`000?oooooooooo07Kooooo
00?o0000ooooooooool0Soooool00005ooooool0003oooooooooool000002Oooool2o`0000Gooooo
00?o0000ooooooooool0Moooool00ol0003oooooooooo`2>ooooo`000_ooool2o`0000_ooooo00?o
0000ooooooooool00oooool00ol0003oooooooooo`1hooooo`03o`000?oooooooooo08gooooo000E
ooooo`03o`000?oooooooooo07Wooooo00?o0000ooooooooool0S?ooool001Gooooo00?o0000oooo
ooooool0N_ooool00ol0003oooooooooo`2;ooooo`005Oooool00ol0003oooooooooo`1kooooo`03
o`000?oooooooooo08[ooooo000Eooooo`03o`000?oooooooooo07cooooo00?o0000ooooooooool0
ROooool001Gooooo0_l0001nooooo`03o`000?oooooooooo08Sooooo000Eooooo`03o`000?oooooo
oooo07kooooo00?o0000ooooooooool0Qoooool001Gooooo00?o0000ooooooooool0Ooooool00ol0
003oooooooooo`26ooooo`005Oooool00ol0003oooooooooo`1oooooo`03o`000?oooooooooo08Ko
oooo000Eooooo`03o`000?oooooooooo083ooooo00?o0000ooooooooool0QOooool001Gooooo00?o
0000ooooooooool0POooool00ol0003oooooooooo`24ooooo`005Oooool00ol0003oooooooooo`22
ooooo`03o`000?oooooooooo08?ooooo000Eooooo`03o`000?oooooooooo08;ooooo00?o0000oooo
ooooool0Poooool001Gooooo0_l00024ooooo`03o`000?oooooooooo08;ooooo000Eooooo`03o`00
0?oooooooooo08Cooooo00?o0000ooooooooool0POooool001Gooooo00?o0000ooooooooool0Q?oo
ool00ol0003oooooooooo`21ooooo`005Oooool00ol0003oooooooooo`25ooooo`03o`000?oooooo
oooo083ooooo000Eooooo`03o`000?oooooooooo08Kooooo00?o0000ooooooooool0Ooooool001Go
oooo00?o0000ooooooooool0Qoooool00ol0003oooooooooo`1nooooo`005Oooool00ol0003ooooo
ooooo`27ooooo`03o`000?oooooooooo07kooooo000Eooooo`03o`000?oooooooooo08Sooooo00?o
0000ooooooooool0OOooool001Gooooo0_l0002:ooooo`03o`000?oooooooooo07cooooo000Eoooo
o`03o`000?oooooooooo08[ooooo00?o0000ooooooooool0Noooool001Gooooo00?o0000oooooooo
ool0Roooool00ol0003oooooooooo`1jooooo`005Oooool00ol0003oooooooooo`2<ooooo`03o`00
0?oooooooooo07Wooooo000Eooooo`03o`000?oooooooooo08gooooo00?o0000ooooooooool0N?oo
ool000;ooooo0_l00004ooooo`03o`000?oooooooooo00;ooooo0ol00005ooooo`03o`000?oooooo
oooo08kooooo00?o0000ooooooooool0Moooool00005ooooool0003oooooooooool000001oooool0
1Ol0003ooooooooooooooooo000000Cooooo00?o0000ooooooooool0Soooool00ol0003ooooooooo
o`1fooooo`0000Goooooo`000?ooooooooooo`000007ooooo`05o`000?ooooooooooooooool00000
1?ooool00ol0003oooooooooo`2@ooooo`;o0000M_ooool00005ooooool0003oooooooooool00000
1oooool4o`0000Gooooo0ol0002Booooo`03o`000?oooooooooo07?ooooo00001Ooooooo0000oooo
oooooooo000000Oooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`2Cooooo`03o`00
0?oooooooooo07;ooooo00001Ooooooo0000oooooooooooo000000Sooooo00?o0000ooooooooool0
1Oooool00ol0003oooooooooo`2Dooooo`03o`000?oooooooooo077ooooo0002ooooo`;o00002_oo
ool2o`0000Gooooo00?o0000ooooooooool0UOooool00ol0003oooooooooo`1`ooooo`005Oooool0
0ol0003oooooooooo`2Fooooo`03o`000?oooooooooo06oooooo000Eooooo`03o`000?oooooooooo
09Oooooo00?o0000ooooooooool0K_ooool001Gooooo00?o0000ooooooooool0V?ooool00ol0003o
ooooooooo`1]ooooo`005Oooool00ol0003oooooooooo`2Iooooo`;o0000KOooool001Gooooo0_l0
002Looooo`03o`000?oooooooooo06[ooooo000Eooooo`03o`000?oooooooooo09cooooo00?o0000
ooooooooool0JOooool001Gooooo00?o0000ooooooooool0WOooool2o`0006Wooooo000Eooooo`03
o`000?oooooooooo09oooooo00?o0000ooooooooool0I_ooool001Gooooo00?o0000ooooooooool0
X?ooool00ol0003oooooooooo`1Uooooo`005Oooool00ol0003oooooooooo`2Qooooo`;o0000IOoo
ool001Gooooo00?o0000ooooooooool0Xoooool00ol0003oooooooooo`1Rooooo`005Oooool00ol0
003oooooooooo`2Tooooo`;o0000H_ooool001Gooooo0_l0002Wooooo`03o`000?oooooooooo05oo
oooo000Eooooo`03o`000?oooooooooo0:Oooooo0_l0001Oooooo`005Oooool00ol0003ooooooooo
o`2Yooooo`03o`000?oooooooooo05cooooo000Eooooo`03o`000?oooooooooo0:[ooooo0_l0001L
ooooo`005Oooool00ol0003oooooooooo`2/ooooo`03o`000?oooooooooo05Wooooo000Eooooo`03
o`000?oooooooooo0:gooooo0_l0001Iooooo`005Oooool00ol0003oooooooooo`2_ooooo`;o0000
Eoooool001Gooooo00?o0000ooooooooool0/Oooool00ol0003oooooooooo`1Dooooo`005Oooool2
o`000;?ooooo0_l0001Dooooo`005Oooool00ol0003oooooooooo`2dooooo`;o0000D_ooool001Go
oooo00?o0000ooooooooool0]_ooool3o`0004oooooo000Eooooo`03o`000?oooooooooo0;Wooooo
0_l0001=ooooo`005Oooool00ol0003oooooooooo`2kooooo`;o0000Boooool000;ooooo0_l00004
ooooo`03o`000?oooooooooo00;ooooo0ol00005ooooo`03o`000?oooooooooo0;gooooo0_l00019
ooooo`0000Goooooo`000?ooooooooooo`000007ooooo`05o`000?ooooooooooooooool000001?oo
ool00ol0003oooooooooo`2oooooo`?o0000A_ooool00005ooooool0003oooooooooool000001ooo
ool01Ol0003ooooooooooooooooo000000Cooooo00?o0000ooooooooool0`_ooool2o`0004Cooooo
00001Ooooooo0000oooooooooooo000000Sooooo0ol00005ooooo`?o0000a?ooool3o`00047ooooo
00001Ooooooo0000oooooooooooo000000Oooooo00Go0000ooooooooooooooooo`000004ooooo`03
o`000?oooooooooo0<Oooooo1?l0000mooooo`0000Goooooo`000?ooooooooooo`000007ooooo`05
o`000?ooooooooooooooool000001?ooool00ol0003oooooooooo`3;ooooo`Co0000>Oooool000;o
oooo0_l00009ooooo`?o00001Oooool00ol0003oooooooooo`3?ooooo`?o0000=_ooool001Gooooo
00?o0000ooooooooool0d_ooool3o`0003?ooooo000Eooooo`03o`000?oooooooooo0=Gooooo0ol0
000`ooooo`005Oooool00ol0003oooooooooo`3Hooooo`Go0000:oooool001Gooooo00?o0000oooo
ooooool0gOooool6o`0002Gooooo000Eooooo`;o0000i?ooool6o`0001oooooo000Eooooo`03o`00
0?oooooooooo0>Wooooo1Ol0000Jooooo`005Oooool00ol0003oooooooooo`3^ooooo`Oo00004ooo
ool001Gooooo00?o0000ooooooooool0mOooool6o`0000gooooo000Eooooo`03o`000?oooooooooo
0?_ooooo1?l00009ooooo`005Oooool00ol0003oooooooooo`3oooooo`;o00001oooool001Gooooo
00?o0000ooooooooool0ooooool9ooooo`005Oooool00ol0003oooooooooo`3oooooo`Wooooo000E
ooooo`;o0000ooooool:ooooo`005Oooool00ol0003oooooooooo`3oooooo`Wooooo000Eooooo`03
o`000?oooooooooo0?oooooo2Oooool001Gooooo00?o0000ooooooooool0ooooool9ooooo`005Ooo
ool00ol0003oooooooooo`3oooooo`Wooooo000Eooooo`03o`000?oooooooooo0?oooooo2Oooool0
01Gooooo00?o0000ooooooooool0ooooool9ooooo`005Oooool00ol0003oooooooooo`3oooooo`Wo
oooo000Eooooo`;o0000ooooool:ooooo`005Oooool00ol0003oooooooooo`3oooooo`Wooooo000E
ooooo`03o`000?oooooooooo0?oooooo2Oooool001Gooooo00?o0000ooooooooool0ooooool9oooo
o`005Oooool00ol0003oooooooooo`3oooooo`Wooooo000=ooooo`?o00001Oooool00ol0003ooooo
ooooo`3oooooo`Wooooo000>ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0oooo
ool9ooooo`003_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo0?oooooo2Oooool0
00kooooo00?o0000ooooooooool01?ooool3o`000?oooooo2Oooool000kooooo00?o0000oooooooo
ool0ooooool@ooooo`003Oooool2o`000?oooooo4_ooool000kooooo00?o0000ooooooooool0oooo
ool@ooooo`00oooooolQooooo`00\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-2.49048, -0.0764114, \
0.115739, 0.00624232}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 0.0333333 0 0.618034 [
[.16667 -0.0125 -3 -9 ]
[.16667 -0.0125 3 0 ]
[.33333 -0.0125 -6 -9 ]
[.33333 -0.0125 6 0 ]
[.5 -0.0125 -6 -9 ]
[.5 -0.0125 6 0 ]
[.66667 -0.0125 -6 -9 ]
[.66667 -0.0125 6 0 ]
[.83333 -0.0125 -6 -9 ]
[.83333 -0.0125 6 0 ]
[1 -0.0125 -6 -9 ]
[1 -0.0125 6 0 ]
[-0.0125 .12361 -18 -4.5 ]
[-0.0125 .12361 0 4.5 ]
[-0.0125 .24721 -18 -4.5 ]
[-0.0125 .24721 0 4.5 ]
[-0.0125 .37082 -18 -4.5 ]
[-0.0125 .37082 0 4.5 ]
[-0.0125 .49443 -18 -4.5 ]
[-0.0125 .49443 0 4.5 ]
[-0.0125 .61803 -6 -4.5 ]
[-0.0125 .61803 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.16667 0 m
.16667 .00625 L
s
[(5)] .16667 -0.0125 0 1 Mshowa
.33333 0 m
.33333 .00625 L
s
[(10)] .33333 -0.0125 0 1 Mshowa
.5 0 m
.5 .00625 L
s
[(15)] .5 -0.0125 0 1 Mshowa
.66667 0 m
.66667 .00625 L
s
[(20)] .66667 -0.0125 0 1 Mshowa
.83333 0 m
.83333 .00625 L
s
[(25)] .83333 -0.0125 0 1 Mshowa
1 0 m
1 .00625 L
s
[(30)] 1 -0.0125 0 1 Mshowa
.125 Mabswid
.03333 0 m
.03333 .00375 L
s
.06667 0 m
.06667 .00375 L
s
.1 0 m
.1 .00375 L
s
.13333 0 m
.13333 .00375 L
s
.2 0 m
.2 .00375 L
s
.23333 0 m
.23333 .00375 L
s
.26667 0 m
.26667 .00375 L
s
.3 0 m
.3 .00375 L
s
.36667 0 m
.36667 .00375 L
s
.4 0 m
.4 .00375 L
s
.43333 0 m
.43333 .00375 L
s
.46667 0 m
.46667 .00375 L
s
.53333 0 m
.53333 .00375 L
s
.56667 0 m
.56667 .00375 L
s
.6 0 m
.6 .00375 L
s
.63333 0 m
.63333 .00375 L
s
.7 0 m
.7 .00375 L
s
.73333 0 m
.73333 .00375 L
s
.76667 0 m
.76667 .00375 L
s
.8 0 m
.8 .00375 L
s
.86667 0 m
.86667 .00375 L
s
.9 0 m
.9 .00375 L
s
.93333 0 m
.93333 .00375 L
s
.96667 0 m
.96667 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .12361 m
.00625 .12361 L
s
[(0.2)] -0.0125 .12361 1 0 Mshowa
0 .24721 m
.00625 .24721 L
s
[(0.4)] -0.0125 .24721 1 0 Mshowa
0 .37082 m
.00625 .37082 L
s
[(0.6)] -0.0125 .37082 1 0 Mshowa
0 .49443 m
.00625 .49443 L
s
[(0.8)] -0.0125 .49443 1 0 Mshowa
0 .61803 m
.00625 .61803 L
s
[(1)] -0.0125 .61803 1 0 Mshowa
.125 Mabswid
0 .0309 m
.00375 .0309 L
s
0 .0618 m
.00375 .0618 L
s
0 .09271 m
.00375 .09271 L
s
0 .15451 m
.00375 .15451 L
s
0 .18541 m
.00375 .18541 L
s
0 .21631 m
.00375 .21631 L
s
0 .27812 m
.00375 .27812 L
s
0 .30902 m
.00375 .30902 L
s
0 .33992 m
.00375 .33992 L
s
0 .40172 m
.00375 .40172 L
s
0 .43262 m
.00375 .43262 L
s
0 .46353 m
.00375 .46353 L
s
0 .52533 m
.00375 .52533 L
s
0 .55623 m
.00375 .55623 L
s
0 .58713 m
.00375 .58713 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.03333 .07589 m
.06667 .08319 L
.1 .08814 L
.13333 .09336 L
.16667 .09955 L
.2 .10705 L
.23333 .11612 L
.26667 .12704 L
.3 .14011 L
.33333 .15568 L
.36667 .17415 L
.4 .19601 L
.43333 .22182 L
.46667 .25224 L
.5 .28803 L
.53333 .33001 L
.56667 .36579 L
.6 .39621 L
.63333 .42203 L
.66667 .44389 L
.7 .46236 L
.73333 .47792 L
.76667 .49099 L
.8 .50191 L
.83333 .51099 L
.86667 .51849 L
.9 .52467 L
.93333 .5299 L
.96667 .53484 L
1 .54214 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[6]:=",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/B000`400?l00000o`00003ooooooolQ
ooooo`00?_ooool3o`0002Gooooo0ol00004ooooo`;o00008oooool3o`0000?ooooo0ol0000Qoooo
o`Go00000oooool2o`00027ooooo1Ol00002ooooo`?o00008_ooool3o`0000Cooooo0_l00004oooo
o`00?Oooool01Ol0003ooooooooooooooooo000002Gooooo00?o0000ooooooooool00_ooool01?l0
003oooooooooool0000Sooooo`05o`000?ooooooooooooooool000000oooool00ol0003ooooooooo
o`0Oooooo`04o`000?ooooooooooo`0000;ooooo00Co0000oooooooooooo00008Oooool01_l0003o
ooooooooool0003oooooo`0000?ooooo00?o0000ooooooooool07_ooool01Ol0003ooooooooooooo
oooo000000;ooooo00Co0000oooooooooooo00000oooool0047ooooo00?o0000ooooooooool08ooo
ool00ol0003oooooooooo`02ooooo`04o`000?ooooooooooo`0002?ooooo00?o0000ooooooooool0
1Oooool00ol0003oooooooooo`0Pooooo`03o`000?oooooooooo00;ooooo00Co0000oooooooooooo
00008_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo02;ooooo00Co0000oooooooo
oooo00000_ooool00ol0003oooooooooo`01ooooo`00@Oooool00ol0003oooooooooo`0Sooooo`03
o`000?oooooooooo00;ooooo00Co0000oooooooooooo00008oooool00ol0003oooooooooo`05oooo
o`03o`000?oooooooooo027ooooo00Go0000ooooooooooooooooo`000002ooooo`03o`000?oooooo
oooo027ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`0Pooooo`;o00000oooool0
1?l0003oooooooooool00003ooooo`00?Oooool4o`0002Kooooo00?o0000ooooooooool00_ooool0
1?l0003oooooooooool0000Sooooo`04o`000?ooooooooooooooo`Co00008Oooool01Ol0003ooooo
oooooooooooo000000;ooooo00Co0000oooooooooooo00008?ooool01_l0003ooooooooooooooooo
0000ooooo`Co00009Oooool01?l0003oooooooooool00002ooooo`03o`000?oooooooooo007ooooo
000mooooo`03o`000?oooooooooo02Kooooo0_l00004ooooo`04o`000?ooooooooooo`0002;ooooo
0_l00003ooooo`03o`000?oooooooooo02;ooooo00Go0000ooooooooooooooooo`000002ooooo`04
o`000?ooooooooooo`00023ooooo00Oo0000ooooooooooooooooo`000?oooooo000002Cooooo00Go
0000ooooooooooooooooo`000002ooooo`04o`000?ooooooooooo`0000?ooooo000mooooo`Go0000
9Oooool00ol0003oooooooooo`03ooooo`;o00009?ooool01?l0003oooooooooooooool5o`00027o
oooo0ol00004ooooo`;o00008_ooool3o`0000;ooooo1Ol0000Qooooo`?o00001?ooool2o`0000Co
oooo003oooooob7ooooo003oooooob7ooooo003oooooob7ooooo003oooooob7ooooo000Eoooooooo
00001Ol00007ooooo`005Oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Gooooo
00?o0000ooooooooool01_ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Gooooo
00?o0000ooooooooool01_ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Gooooo
00?o0000ooooooooool01_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Kooooo
00?o0000ooooooooool01_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Kooooo
00?o0000ooooooooool01_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Kooooo
00?o0000ooooooooool01_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Kooooo
00?o0000ooooooooool01Oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Kooooo
00?o0000ooooooooool01Oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Kooooo
00?o0000ooooooooool01Oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Kooooo
00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`005Oooool00ol0003ooooooooo
o`3oooooo`Wooooo000Eooooo`03o`000?oooooooooo0?oooooo2Oooool001Gooooo00?o0000oooo
ooooool0ooooool9ooooo`005Oooool00ol0003oooooooooo`3oooooo`Wooooo000Eooooo`03o`00
0?oooooooooo0?oooooo2Oooool001Gooooo00?o0000ooooooooool0ooooool9ooooo`005Oooool2
o`000?oooooo2_ooool001Gooooo00?o0000ooooooooool0ooooool9ooooo`005Oooool00ol0003o
ooooooooo`3oooooo`Wooooo000Eooooo`03o`000?oooooooooo0?oooooo2Oooool001Gooooo00?o
0000ooooooooool0ooooool9ooooo`005Oooool00ol0003oooooooooo`3oooooo`Wooooo000Eoooo
o`03o`000?oooooooooo0?oooooo2Oooool001Gooooo00?o0000ooooooooool0ooooool9ooooo`00
5Oooool2o`000?oooooo2_ooool001Gooooo00?o0000ooooooooool0ooooool9ooooo`005Oooool0
0ol0003oooooooooo`3oooooo`Wooooo000Eooooo`03o`000?oooooooooo00Kooooo0ol0003ooooo
o`005Oooool00ol0003oooooooooo`09ooooo`Co0000noooool001Gooooo00?o0000ooooooooool0
3Oooool4o`000?Oooooo000Eooooo`03o`000?oooooooooo017ooooo1Ol0003booooo`005Oooool0
0ol0003oooooooooo`0Fooooo`Oo0000joooool001Gooooo0_l0000Nooooo`Ko0000iOooool001Go
oooo00?o0000ooooooooool08oooool4o`000>7ooooo000Eooooo`03o`000?oooooooooo02Oooooo
1?l0003Mooooo`005Oooool00ol0003oooooooooo`0[ooooo`Go0000f?ooool001Gooooo00?o0000
ooooooooool0<?ooool4o`000=Cooooo0002ooooo`;o00001?ooool01?l0003oooooooooooooool5
o`0000Cooooo00?o0000ooooooooool0=?ooool5o`000<oooooo00001Ooooooo0000oooooooooooo
000000Sooooo00Co0000oooooooooooo00001?ooool00ol0003oooooooooo`0iooooo`?o0000c?oo
ool00005ooooool0003oooooooooool000002Oooool00ol0003oooooooooo`04ooooo`03o`000?oo
oooooooo03cooooo0ol00039ooooo`0000Goooooo`000?ooooooooooo`00000:ooooo`03o`000?oo
oooooooo00?ooooo0ol0000oooooo`?o0000a_ooool00005ooooool0003oooooooooool000001ooo
ool01Ol0003ooooooooooooooooo000000Cooooo00?o0000ooooooooool0@_ooool3o`000<?ooooo
00001Ooooooo0000oooooooooooo000000Oooooo00Go0000ooooooooooooooooo`000004ooooo`03
o`000?oooooooooo04Gooooo0ol00030ooooo`000_ooool2o`0000Wooooo0ol00005ooooo`03o`00
0?oooooooooo04Sooooo0ol0002mooooo`005Oooool00ol0003oooooooooo`1;ooooo`;o0000^ooo
ool001Gooooo00?o0000ooooooooool0COooool2o`000;Wooooo000Eooooo`03o`000?oooooooooo
04oooooo0_l0002gooooo`005Oooool00ol0003oooooooooo`1Aooooo`;o0000]Oooool001Gooooo
0_l0001Dooooo`;o0000/oooool001Gooooo00?o0000ooooooooool0EOooool2o`000;7ooooo000E
ooooo`03o`000?oooooooooo05Oooooo0_l0002_ooooo`005Oooool00ol0003oooooooooo`1Ioooo
o`03o`000?oooooooooo0:cooooo000Eooooo`03o`000?oooooooooo05[ooooo0_l0002/ooooo`00
5Oooool00ol0003oooooooooo`1Looooo`;o0000Z_ooool001Gooooo00?o0000ooooooooool0G_oo
ool00ol0003oooooooooo`2Wooooo`005Oooool00ol0003oooooooooo`1Oooooo`;o0000Yoooool0
01Gooooo0_l0001Rooooo`03o`000?oooooooooo0:Cooooo000Eooooo`03o`000?oooooooooo06;o
oooo0_l0002Tooooo`005Oooool00ol0003oooooooooo`1Tooooo`03o`000?oooooooooo0:7ooooo
000Eooooo`03o`000?oooooooooo06Gooooo0_l0002Qooooo`005Oooool00ol0003oooooooooo`1W
ooooo`03o`000?oooooooooo09kooooo000Eooooo`03o`000?oooooooooo06Sooooo00?o0000oooo
ooooool0WOooool001Gooooo00?o0000ooooooooool0JOooool2o`0009gooooo000Eooooo`03o`00
0?oooooooooo06_ooooo00?o0000ooooooooool0V_ooool001Gooooo0_l0001]ooooo`03o`000?oo
oooooooo09Wooooo000Eooooo`03o`000?oooooooooo06gooooo0_l0002Iooooo`005Oooool00ol0
003oooooooooo`1_ooooo`03o`000?oooooooooo09Kooooo000Eooooo`03o`000?oooooooooo073o
oooo00?o0000ooooooooool0UOooool001Gooooo00?o0000ooooooooool0LOooool00ol0003ooooo
ooooo`2Dooooo`000_ooool2o`0000Cooooo00?o0000ooooooooool00oooool3o`0000Cooooo00?o
0000ooooooooool0L_ooool00ol0003oooooooooo`2Cooooo`0000Goooooo`000?ooooooooooo`00
000:ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0Loooool00ol0003ooooooooo
o`2Booooo`0000Goooooo`000?ooooooooooo`000007ooooo`Go00001?ooool00ol0003ooooooooo
o`1dooooo`03o`000?oooooooooo097ooooo00001Ooooooo0000oooooooooooo000000Oooooo00Co
0000oooooooooooo00001Oooool3o`0007Gooooo00?o0000ooooooooool0T?ooool00005ooooool0
003oooooooooool000002?ooool00ol0003oooooo`000005ooooo`03o`000?oooooooooo07Kooooo
00?o0000ooooooooool0Soooool00005ooooool0003oooooooooool000002Oooool2o`0000Gooooo
00?o0000ooooooooool0Moooool00ol0003oooooooooo`2>ooooo`000_ooool2o`0000_ooooo00?o
0000ooooooooool00oooool00ol0003oooooooooo`1hooooo`03o`000?oooooooooo08gooooo000E
ooooo`03o`000?oooooooooo07Wooooo00?o0000ooooooooool0S?ooool001Gooooo00?o0000oooo
ooooool0N_ooool00ol0003oooooooooo`2;ooooo`005Oooool00ol0003oooooooooo`1kooooo`03
o`000?oooooooooo08[ooooo000Eooooo`03o`000?oooooooooo07cooooo00?o0000ooooooooool0
ROooool001Gooooo0_l0001nooooo`03o`000?oooooooooo08Sooooo000Eooooo`03o`000?oooooo
oooo07kooooo00?o0000ooooooooool0Qoooool001Gooooo00?o0000ooooooooool0Ooooool00ol0
003oooooooooo`26ooooo`005Oooool00ol0003oooooooooo`1oooooo`03o`000?oooooooooo08Ko
oooo000Eooooo`03o`000?oooooooooo083ooooo00?o0000ooooooooool0QOooool001Gooooo00?o
0000ooooooooool0POooool00ol0003oooooooooo`24ooooo`005Oooool00ol0003oooooooooo`22
ooooo`03o`000?oooooooooo08?ooooo000Eooooo`03o`000?oooooooooo08;ooooo00?o0000oooo
ooooool0Poooool001Gooooo0_l00024ooooo`03o`000?oooooooooo08;ooooo000Eooooo`03o`00
0?oooooooooo08Cooooo00?o0000ooooooooool0POooool001Gooooo00?o0000ooooooooool0Q?oo
ool00ol0003oooooooooo`21ooooo`005Oooool00ol0003oooooooooo`25ooooo`03o`000?oooooo
oooo083ooooo000Eooooo`03o`000?oooooooooo08Kooooo00?o0000ooooooooool0Ooooool001Go
oooo00?o0000ooooooooool0Qoooool00ol0003oooooooooo`1nooooo`005Oooool00ol0003ooooo
ooooo`27ooooo`03o`000?oooooooooo07kooooo000Eooooo`03o`000?oooooooooo08Sooooo00?o
0000ooooooooool0OOooool001Gooooo0_l0002:ooooo`03o`000?oooooooooo07cooooo000Eoooo
o`03o`000?oooooooooo08[ooooo00?o0000ooooooooool0Noooool001Gooooo00?o0000oooooooo
ool0Roooool00ol0003oooooooooo`1jooooo`005Oooool00ol0003oooooooooo`2<ooooo`03o`00
0?oooooooooo07Wooooo000Eooooo`03o`000?oooooooooo08gooooo00?o0000ooooooooool0N?oo
ool000;ooooo0_l00004ooooo`03o`000?oooooooooo00;ooooo0ol00005ooooo`03o`000?oooooo
oooo08kooooo00?o0000ooooooooool0Moooool00005ooooool0003oooooooooool000001oooool0
1Ol0003ooooooooooooooooo000000Cooooo00?o0000ooooooooool0Soooool00ol0003ooooooooo
o`1fooooo`0000Goooooo`000?ooooooooooo`000007ooooo`05o`000?ooooooooooooooool00000
1?ooool00ol0003oooooooooo`2@ooooo`;o0000M_ooool00005ooooool0003oooooooooool00000
1oooool4o`0000Gooooo0ol0002Booooo`03o`000?oooooooooo07?ooooo00001Ooooooo0000oooo
oooooooo000000Oooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`2Cooooo`03o`00
0?oooooooooo07;ooooo00001Ooooooo0000oooooooooooo000000Sooooo00?o0000ooooooooool0
1Oooool00ol0003oooooooooo`2Dooooo`03o`000?oooooooooo077ooooo0002ooooo`;o00002_oo
ool2o`0000Gooooo00?o0000ooooooooool0UOooool00ol0003oooooooooo`1`ooooo`005Oooool0
0ol0003oooooooooo`2Fooooo`03o`000?oooooooooo06oooooo000Eooooo`03o`000?oooooooooo
09Oooooo00?o0000ooooooooool0K_ooool001Gooooo00?o0000ooooooooool0V?ooool00ol0003o
ooooooooo`1]ooooo`005Oooool00ol0003oooooooooo`2Iooooo`;o0000KOooool001Gooooo0_l0
002Looooo`03o`000?oooooooooo06[ooooo000Eooooo`03o`000?oooooooooo09cooooo00?o0000
ooooooooool0JOooool001Gooooo00?o0000ooooooooool0WOooool2o`0006Wooooo000Eooooo`03
o`000?oooooooooo09oooooo00?o0000ooooooooool0I_ooool001Gooooo00?o0000ooooooooool0
X?ooool00ol0003oooooooooo`1Uooooo`005Oooool00ol0003oooooooooo`2Qooooo`;o0000IOoo
ool001Gooooo00?o0000ooooooooool0Xoooool00ol0003oooooooooo`1Rooooo`005Oooool00ol0
003oooooooooo`2Tooooo`;o0000H_ooool001Gooooo0_l0002Wooooo`03o`000?oooooooooo05oo
oooo000Eooooo`03o`000?oooooooooo0:Oooooo0_l0001Oooooo`005Oooool00ol0003ooooooooo
o`2Yooooo`03o`000?oooooooooo05cooooo000Eooooo`03o`000?oooooooooo0:[ooooo0_l0001L
ooooo`005Oooool00ol0003oooooooooo`2/ooooo`03o`000?oooooooooo05Wooooo000Eooooo`03
o`000?oooooooooo0:gooooo0_l0001Iooooo`005Oooool00ol0003oooooooooo`2_ooooo`;o0000
Eoooool001Gooooo00?o0000ooooooooool0/Oooool00ol0003oooooooooo`1Dooooo`005Oooool2
o`000;?ooooo0_l0001Dooooo`005Oooool00ol0003oooooooooo`2dooooo`;o0000D_ooool001Go
oooo00?o0000ooooooooool0]_ooool3o`0004oooooo000Eooooo`03o`000?oooooooooo0;Wooooo
0_l0001=ooooo`005Oooool00ol0003oooooooooo`2kooooo`?o0000B_ooool000;ooooo0_l00004
ooooo`03o`000?oooooooooo00;ooooo0ol00005ooooo`03o`000?oooooooooo0;kooooo0ol00017
ooooo`0000Goooooo`000?ooooooooooo`000007ooooo`05o`000?ooooooooooooooool000001?oo
ool00ol0003oooooooooo`31ooooo`?o0000A?ooool00005ooooool0003oooooooooool000001ooo
ool01Ol0003ooooooooooooooooo000000Cooooo00?o0000ooooooooool0a?ooool2o`0004;ooooo
00001Ooooooo0000oooooooooooo000000Sooooo0ol00005ooooo`?o0000a_ooool3o`0003oooooo
00001Ooooooo0000oooooooooooo000000Oooooo00Go0000ooooooooooooooooo`000004ooooo`03
o`000?oooooooooo0<Wooooo0ol0000looooo`0000Goooooo`000?ooooooooooo`000007ooooo`05
o`000?ooooooooooooooool000001?ooool00ol0003oooooooooo`3<ooooo`?o0000>Oooool000;o
oooo0_l00009ooooo`?o00001Oooool00ol0003oooooooooo`3?ooooo`Go0000=?ooool001Gooooo
00?o0000ooooooooool0e?ooool4o`00033ooooo000Eooooo`03o`000?oooooooooo0=Sooooo1Ol0
000[ooooo`005Oooool00ol0003oooooooooo`3Mooooo`Co00009oooool001Gooooo00?o0000oooo
ooooool0hOooool4o`0002?ooooo000Eooooo`;o0000i_ooool7o`0001cooooo000Eooooo`03o`00
0?oooooooooo0>cooooo2Ol0000Cooooo`005Oooool00ol0003oooooooooo`3eooooo`Ko00003Ooo
ool001Gooooo00?o0000ooooooooool0noooool4o`0000Wooooo000Eooooo`03o`000?oooooooooo
0?oooooo0_l00007ooooo`005Oooool00ol0003oooooooooo`3oooooo`Wooooo000Eooooo`03o`00
0?oooooooooo0?oooooo2Oooool001Gooooo00?o0000ooooooooool0ooooool9ooooo`005Oooool2
o`000?oooooo2_ooool001Gooooo00?o0000ooooooooool0ooooool9ooooo`005Oooool00ol0003o
ooooooooo`3oooooo`Wooooo000Eooooo`03o`000?oooooooooo0?oooooo2Oooool001Gooooo00?o
0000ooooooooool0ooooool9ooooo`005Oooool00ol0003oooooooooo`3oooooo`Wooooo000Eoooo
o`03o`000?oooooooooo0?oooooo2Oooool001Gooooo00?o0000ooooooooool0ooooool9ooooo`00
5Oooool2o`000?oooooo2_ooool001Gooooo00?o0000ooooooooool0ooooool9ooooo`005Oooool0
0ol0003oooooooooo`3oooooo`Wooooo000Eooooo`03o`000?oooooooooo0?oooooo2Oooool001Go
oooo00?o0000ooooooooool0ooooool9ooooo`003Oooool3o`0000Gooooo00?o0000ooooooooool0
ooooool9ooooo`003_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo0?oooooo2Ooo
ool000kooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`3oooooo`Wooooo000>oooo
o`03o`000?oooooooooo00Cooooo0ol0003oooooo`Wooooo000>ooooo`03o`000?oooooooooo0?oo
oooo4?ooool000gooooo0_l0003ooooooa;ooooo000>ooooo`03o`000?oooooooooo0?oooooo4?oo
ool00?oooooo8Oooool00001\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-2.49048, -0.0764114, \
0.115739, 0.00624232}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 0.0333333 0 0.618034 [
[.16667 -0.0125 -3 -9 ]
[.16667 -0.0125 3 0 ]
[.33333 -0.0125 -6 -9 ]
[.33333 -0.0125 6 0 ]
[.5 -0.0125 -6 -9 ]
[.5 -0.0125 6 0 ]
[.66667 -0.0125 -6 -9 ]
[.66667 -0.0125 6 0 ]
[.83333 -0.0125 -6 -9 ]
[.83333 -0.0125 6 0 ]
[1 -0.0125 -6 -9 ]
[1 -0.0125 6 0 ]
[-0.0125 .12361 -18 -4.5 ]
[-0.0125 .12361 0 4.5 ]
[-0.0125 .24721 -18 -4.5 ]
[-0.0125 .24721 0 4.5 ]
[-0.0125 .37082 -18 -4.5 ]
[-0.0125 .37082 0 4.5 ]
[-0.0125 .49443 -18 -4.5 ]
[-0.0125 .49443 0 4.5 ]
[-0.0125 .61803 -6 -4.5 ]
[-0.0125 .61803 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.16667 0 m
.16667 .00625 L
s
[(5)] .16667 -0.0125 0 1 Mshowa
.33333 0 m
.33333 .00625 L
s
[(10)] .33333 -0.0125 0 1 Mshowa
.5 0 m
.5 .00625 L
s
[(15)] .5 -0.0125 0 1 Mshowa
.66667 0 m
.66667 .00625 L
s
[(20)] .66667 -0.0125 0 1 Mshowa
.83333 0 m
.83333 .00625 L
s
[(25)] .83333 -0.0125 0 1 Mshowa
1 0 m
1 .00625 L
s
[(30)] 1 -0.0125 0 1 Mshowa
.125 Mabswid
.03333 0 m
.03333 .00375 L
s
.06667 0 m
.06667 .00375 L
s
.1 0 m
.1 .00375 L
s
.13333 0 m
.13333 .00375 L
s
.2 0 m
.2 .00375 L
s
.23333 0 m
.23333 .00375 L
s
.26667 0 m
.26667 .00375 L
s
.3 0 m
.3 .00375 L
s
.36667 0 m
.36667 .00375 L
s
.4 0 m
.4 .00375 L
s
.43333 0 m
.43333 .00375 L
s
.46667 0 m
.46667 .00375 L
s
.53333 0 m
.53333 .00375 L
s
.56667 0 m
.56667 .00375 L
s
.6 0 m
.6 .00375 L
s
.63333 0 m
.63333 .00375 L
s
.7 0 m
.7 .00375 L
s
.73333 0 m
.73333 .00375 L
s
.76667 0 m
.76667 .00375 L
s
.8 0 m
.8 .00375 L
s
.86667 0 m
.86667 .00375 L
s
.9 0 m
.9 .00375 L
s
.93333 0 m
.93333 .00375 L
s
.96667 0 m
.96667 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .12361 m
.00625 .12361 L
s
[(0.2)] -0.0125 .12361 1 0 Mshowa
0 .24721 m
.00625 .24721 L
s
[(0.4)] -0.0125 .24721 1 0 Mshowa
0 .37082 m
.00625 .37082 L
s
[(0.6)] -0.0125 .37082 1 0 Mshowa
0 .49443 m
.00625 .49443 L
s
[(0.8)] -0.0125 .49443 1 0 Mshowa
0 .61803 m
.00625 .61803 L
s
[(1)] -0.0125 .61803 1 0 Mshowa
.125 Mabswid
0 .0309 m
.00375 .0309 L
s
0 .0618 m
.00375 .0618 L
s
0 .09271 m
.00375 .09271 L
s
0 .15451 m
.00375 .15451 L
s
0 .18541 m
.00375 .18541 L
s
0 .21631 m
.00375 .21631 L
s
0 .27812 m
.00375 .27812 L
s
0 .30902 m
.00375 .30902 L
s
0 .33992 m
.00375 .33992 L
s
0 .40172 m
.00375 .40172 L
s
0 .43262 m
.00375 .43262 L
s
0 .46353 m
.00375 .46353 L
s
0 .52533 m
.00375 .52533 L
s
0 .55623 m
.00375 .55623 L
s
0 .58713 m
.00375 .58713 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.03333 .07703 m
.06667 .08469 L
.1 .08974 L
.13333 .095 L
.16667 .10118 L
.2 .10863 L
.23333 .11763 L
.26667 .12846 L
.3 .14142 L
.33333 .15684 L
.36667 .17515 L
.4 .19682 L
.43333 .22243 L
.46667 .25262 L
.5 .28816 L
.53333 .32988 L
.56667 .36542 L
.6 .39561 L
.63333 .42121 L
.66667 .44288 L
.7 .46119 L
.73333 .47662 L
.76667 .48957 L
.8 .5004 L
.83333 .50941 L
.86667 .51686 L
.9 .52304 L
.93333 .52829 L
.96667 .53335 L
1 .541 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[6]:=",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/B000`400?l00000o`00003ooooooolQ
ooooo`00?_ooool3o`0002Gooooo0ol00004ooooo`;o00008oooool3o`0000?ooooo0ol0000Qoooo
o`Go00000oooool2o`00027ooooo1Ol00002ooooo`?o00008_ooool3o`0000Cooooo0_l00004oooo
o`00?Oooool01Ol0003ooooooooooooooooo000002Gooooo00?o0000ooooooooool00_ooool01?l0
003oooooooooool0000Sooooo`05o`000?ooooooooooooooool000000oooool00ol0003ooooooooo
o`0Oooooo`04o`000?ooooooooooo`0000;ooooo00Co0000oooooooooooo00008Oooool01_l0003o
ooooooooool0003oooooo`0000?ooooo00?o0000ooooooooool07_ooool01Ol0003ooooooooooooo
oooo000000;ooooo00Co0000oooooooooooo00000oooool0047ooooo00?o0000ooooooooool08ooo
ool00ol0003oooooooooo`02ooooo`04o`000?ooooooooooo`0002?ooooo00?o0000ooooooooool0
1Oooool00ol0003oooooooooo`0Pooooo`03o`000?oooooooooo00;ooooo00Co0000oooooooooooo
00008_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo02;ooooo00Co0000oooooooo
oooo00000_ooool00ol0003oooooooooo`01ooooo`00@Oooool00ol0003oooooooooo`0Sooooo`03
o`000?oooooooooo00;ooooo00Co0000oooooooooooo00008oooool00ol0003oooooooooo`05oooo
o`03o`000?oooooooooo027ooooo00Go0000ooooooooooooooooo`000002ooooo`03o`000?oooooo
oooo027ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`0Pooooo`;o00000oooool0
1?l0003oooooooooool00003ooooo`00?Oooool4o`0002Kooooo00?o0000ooooooooool00_ooool0
1?l0003oooooooooool0000Sooooo`04o`000?ooooooooooooooo`Co00008Oooool01Ol0003ooooo
oooooooooooo000000;ooooo00Co0000oooooooooooo00008?ooool01_l0003ooooooooooooooooo
0000ooooo`Co00009Oooool01?l0003oooooooooool00002ooooo`03o`000?oooooooooo007ooooo
000mooooo`03o`000?oooooooooo02Kooooo0_l00004ooooo`04o`000?ooooooooooo`0002;ooooo
0_l00003ooooo`03o`000?oooooooooo02;ooooo00Go0000ooooooooooooooooo`000002ooooo`04
o`000?ooooooooooo`00023ooooo00Oo0000ooooooooooooooooo`000?oooooo000002Cooooo00Go
0000ooooooooooooooooo`000002ooooo`04o`000?ooooooooooo`0000?ooooo000mooooo`Go0000
9Oooool00ol0003oooooooooo`03ooooo`;o00009?ooool01?l0003oooooooooooooool5o`00027o
oooo0ol00004ooooo`;o00008_ooool3o`0000;ooooo1Ol0000Qooooo`?o00001?ooool2o`0000Co
oooo003oooooob7ooooo003oooooob7ooooo003oooooob7ooooo003oooooob7ooooo000Eoooooooo
00001Ol00007ooooo`005Oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Gooooo
00?o0000ooooooooool01_ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Gooooo
00?o0000ooooooooool01_ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Gooooo
00?o0000ooooooooool01_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Kooooo
00?o0000ooooooooool01_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Kooooo
00?o0000ooooooooool01_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Kooooo
00?o0000ooooooooool01_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Kooooo
00?o0000ooooooooool01Oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Kooooo
00?o0000ooooooooool01Oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Kooooo
00?o0000ooooooooool01Oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Kooooo
00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`005Oooool00ol0003ooooooooo
o`3oooooo`Wooooo000Eooooo`03o`000?oooooooooo0?oooooo2Oooool001Gooooo00?o0000oooo
ooooool0ooooool9ooooo`005Oooool00ol0003oooooooooo`3oooooo`Wooooo000Eooooo`03o`00
0?oooooooooo0?oooooo2Oooool001Gooooo00?o0000ooooooooool0ooooool9ooooo`005Oooool2
o`000?oooooo2_ooool001Gooooo00?o0000ooooooooool0ooooool9ooooo`005Oooool00ol0003o
ooooooooo`3oooooo`Wooooo000Eooooo`03o`000?oooooooooo0?oooooo2Oooool001Gooooo00?o
0000ooooooooool0ooooool9ooooo`005Oooool00ol0003oooooooooo`3oooooo`Wooooo000Eoooo
o`03o`000?oooooooooo0?oooooo2Oooool001Gooooo00?o0000ooooooooool0ooooool9ooooo`00
5Oooool2o`000?oooooo2_ooool001Gooooo00?o0000ooooooooool0ooooool9ooooo`005Oooool0
0ol0003oooooooooo`3oooooo`Wooooo000Eooooo`03o`000?oooooooooo0?oooooo2Oooool001Go
oooo00?o0000ooooooooool01_ooool3o`000?oooooo000Eooooo`03o`000?oooooooooo00Wooooo
1?l0003kooooo`005Oooool00ol0003oooooooooo`0=ooooo`Oo0000m?ooool001Gooooo00?o0000
ooooooooool05?ooool9o`000>_ooooo000Eooooo`;o00007_ooool6o`000>Gooooo000Eooooo`03
o`000?oooooooooo02?ooooo1?l0003Qooooo`005Oooool00ol0003oooooooooo`0Wooooo`Co0000
gOooool001Gooooo00?o0000ooooooooool0:oooool5o`000=Sooooo000Eooooo`03o`000?oooooo
oooo033ooooo1?l0003Dooooo`000_ooool2o`0000Cooooo00Co0000oooooooooooooooo1Ol00004
ooooo`03o`000?oooooooooo03Cooooo1Ol0003?ooooo`0000Goooooo`000?ooooooooooo`000008
ooooo`04o`000?ooooooooooo`0000Cooooo00?o0000ooooooooool0>Oooool3o`000<cooooo0000
1Ooooooo0000oooooooooooo000000Wooooo00?o0000ooooooooool01?ooool00ol0003ooooooooo
o`0looooo`?o0000bOooool00005ooooool0003oooooooooool000002_ooool00ol0003ooooooooo
o`03ooooo`?o0000?oooool3o`000<Kooooo00001Ooooooo0000oooooooooooo000000Oooooo00Go
0000ooooooooooooooooo`000004ooooo`03o`000?oooooooooo04;ooooo0ol00033ooooo`0000Go
ooooo`000?ooooooooooo`000007ooooo`05o`000?ooooooooooooooool000001?ooool00ol0003o
ooooooooo`15ooooo`?o0000`?ooool000;ooooo0_l00009ooooo`?o00001Oooool00ol0003ooooo
ooooo`18ooooo`?o0000_Oooool001Gooooo00?o0000ooooooooool0Boooool2o`000;_ooooo000E
ooooo`03o`000?oooooooooo04gooooo0_l0002iooooo`005Oooool00ol0003oooooooooo`1?oooo
o`;o0000]oooool001Gooooo00?o0000ooooooooool0DOooool2o`000;Gooooo000Eooooo`;o0000
E?ooool2o`000;?ooooo000Eooooo`03o`000?oooooooooo05Gooooo0_l0002aooooo`005Oooool0
0ol0003oooooooooo`1Gooooo`;o0000[oooool001Gooooo00?o0000ooooooooool0FOooool00ol0
003oooooooooo`2/ooooo`005Oooool00ol0003oooooooooo`1Jooooo`;o0000[?ooool001Gooooo
00?o0000ooooooooool0G?ooool2o`000:[ooooo000Eooooo`03o`000?oooooooooo05kooooo00?o
0000ooooooooool0Yoooool001Gooooo00?o0000ooooooooool0Goooool2o`000:Oooooo000Eoooo
o`;o0000H_ooool00ol0003oooooooooo`2Tooooo`005Oooool00ol0003oooooooooo`1Rooooo`;o
0000Y?ooool001Gooooo00?o0000ooooooooool0I?ooool00ol0003oooooooooo`2Qooooo`005Ooo
ool00ol0003oooooooooo`1Uooooo`;o0000XOooool001Gooooo00?o0000ooooooooool0Ioooool0
0ol0003oooooooooo`2Nooooo`005Oooool00ol0003oooooooooo`1Xooooo`03o`000?oooooooooo
09gooooo000Eooooo`03o`000?oooooooooo06Wooooo0_l0002Mooooo`005Oooool00ol0003ooooo
ooooo`1[ooooo`03o`000?oooooooooo09[ooooo000Eooooo`;o0000KOooool00ol0003ooooooooo
o`2Iooooo`005Oooool00ol0003oooooooooo`1]ooooo`;o0000VOooool001Gooooo00?o0000oooo
ooooool0Koooool00ol0003oooooooooo`2Fooooo`005Oooool00ol0003oooooooooo`1`ooooo`03
o`000?oooooooooo09Gooooo000Eooooo`03o`000?oooooooooo077ooooo00?o0000ooooooooool0
U?ooool000;ooooo0_l00004ooooo`03o`000?oooooooooo00?ooooo0ol00004ooooo`03o`000?oo
oooooooo07;ooooo00?o0000ooooooooool0Toooool00005ooooool0003oooooooooool000002_oo
ool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo07?ooooo00?o0000ooooooooool0T_oo
ool00005ooooool0003oooooooooool000001oooool5o`0000Cooooo00?o0000ooooooooool0M?oo
ool00ol0003oooooooooo`2Aooooo`0000Goooooo`000?ooooooooooo`000007ooooo`04o`000?oo
ooooooooo`0000Gooooo0ol0001eooooo`03o`000?oooooooooo093ooooo00001Ooooooo0000oooo
oooooooo000000Sooooo00?o0000ooooool000001Oooool00ol0003oooooooooo`1fooooo`03o`00
0?oooooooooo08oooooo00001Ooooooo0000oooooooooooo000000Wooooo0_l00005ooooo`03o`00
0?oooooooooo07Oooooo00?o0000ooooooooool0S_ooool000;ooooo0_l0000;ooooo`03o`000?oo
oooooooo00?ooooo00?o0000ooooooooool0N?ooool00ol0003oooooooooo`2=ooooo`005Oooool0
0ol0003oooooooooo`1iooooo`03o`000?oooooooooo08cooooo000Eooooo`03o`000?oooooooooo
07[ooooo00?o0000ooooooooool0Roooool001Gooooo00?o0000ooooooooool0Noooool00ol0003o
ooooooooo`2:ooooo`005Oooool00ol0003oooooooooo`1looooo`03o`000?oooooooooo08Wooooo
000Eooooo`;o0000O_ooool00ol0003oooooooooo`28ooooo`005Oooool00ol0003oooooooooo`1n
ooooo`03o`000?oooooooooo08Oooooo000Eooooo`03o`000?oooooooooo07oooooo00?o0000oooo
ooooool0Q_ooool001Gooooo00?o0000ooooooooool0Ooooool00ol0003oooooooooo`26ooooo`00
5Oooool00ol0003oooooooooo`20ooooo`03o`000?oooooooooo08Gooooo000Eooooo`03o`000?oo
oooooooo087ooooo00?o0000ooooooooool0Q?ooool001Gooooo00?o0000ooooooooool0P_ooool0
0ol0003oooooooooo`23ooooo`005Oooool00ol0003oooooooooo`22ooooo`03o`000?oooooooooo
08?ooooo000Eooooo`;o0000Q?ooool00ol0003oooooooooo`22ooooo`005Oooool00ol0003ooooo
ooooo`24ooooo`03o`000?oooooooooo087ooooo000Eooooo`03o`000?oooooooooo08Cooooo00?o
0000ooooooooool0POooool001Gooooo00?o0000ooooooooool0QOooool00ol0003oooooooooo`20
ooooo`005Oooool00ol0003oooooooooo`26ooooo`03o`000?oooooooooo07oooooo000Eooooo`03
o`000?oooooooooo08Oooooo00?o0000ooooooooool0O_ooool001Gooooo00?o0000ooooooooool0
Qoooool00ol0003oooooooooo`1nooooo`005Oooool00ol0003oooooooooo`28ooooo`03o`000?oo
oooooooo07gooooo000Eooooo`;o0000R_ooool00ol0003oooooooooo`1looooo`005Oooool00ol0
003oooooooooo`2:ooooo`03o`000?oooooooooo07_ooooo000Eooooo`03o`000?oooooooooo08_o
oooo00?o0000ooooooooool0N_ooool001Gooooo00?o0000ooooooooool0S?ooool00ol0003ooooo
ooooo`1iooooo`005Oooool00ol0003oooooooooo`2=ooooo`03o`000?oooooooooo07Sooooo0002
ooooo`;o00001?ooool00ol0003oooooooooo`02ooooo`?o00001Oooool00ol0003oooooooooo`2>
ooooo`03o`000?oooooooooo07Oooooo00001Ooooooo0000oooooooooooo000000Oooooo00Go0000
ooooooooooooooooo`000004ooooo`03o`000?oooooooooo08oooooo00?o0000ooooooooool0M_oo
ool00005ooooool0003oooooooooool000001oooool01Ol0003ooooooooooooooooo000000Cooooo
00?o0000ooooooooool0T?ooool2o`0007Kooooo00001Ooooooo0000oooooooooooo000000Oooooo
1?l00005ooooo`?o0000T_ooool00ol0003oooooooooo`1cooooo`0000Goooooo`000?oooooooooo
o`000007ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0Toooool00ol0003ooooo
ooooo`1booooo`0000Goooooo`000?ooooooooooo`000008ooooo`03o`000?oooooooooo00Gooooo
00?o0000ooooooooool0U?ooool2o`0007;ooooo0002ooooo`;o00002_ooool2o`0000Gooooo00?o
0000ooooooooool0U_ooool00ol0003oooooooooo`1_ooooo`005Oooool00ol0003oooooooooo`2G
ooooo`03o`000?oooooooooo06kooooo000Eooooo`03o`000?oooooooooo09Sooooo00?o0000oooo
ooooool0KOooool001Gooooo00?o0000ooooooooool0VOooool2o`0006gooooo000Eooooo`03o`00
0?oooooooooo09_ooooo00?o0000ooooooooool0J_ooool001Gooooo0_l0002Mooooo`03o`000?oo
oooooooo06Wooooo000Eooooo`03o`000?oooooooooo09gooooo00?o0000ooooooooool0J?ooool0
01Gooooo00?o0000ooooooooool0W_ooool00ol0003oooooooooo`1Wooooo`005Oooool00ol0003o
ooooooooo`2Oooooo`03o`000?oooooooooo06Kooooo000Eooooo`03o`000?oooooooooo0:3ooooo
00?o0000ooooooooool0IOooool001Gooooo00?o0000ooooooooool0XOooool2o`0006Gooooo000E
ooooo`03o`000?oooooooooo0:?ooooo00?o0000ooooooooool0H_ooool001Gooooo00?o0000oooo
ooooool0Y?ooool2o`0006;ooooo000Eooooo`;o0000Yoooool00ol0003oooooooooo`1Oooooo`00
5Oooool00ol0003oooooooooo`2Wooooo`;o0000Goooool001Gooooo00?o0000ooooooooool0ZOoo
ool00ol0003oooooooooo`1Looooo`005Oooool00ol0003oooooooooo`2Zooooo`;o0000G?ooool0
01Gooooo00?o0000ooooooooool0[?ooool2o`0005[ooooo000Eooooo`03o`000?oooooooooo0:ko
oooo0_l0001Hooooo`005Oooool00ol0003oooooooooo`2`ooooo`;o0000E_ooool001Gooooo00?o
0000ooooooooool0/_ooool2o`0005Cooooo000Eooooo`;o0000]Oooool2o`0005;ooooo000Eoooo
o`03o`000?oooooooooo0;Kooooo0ol0001?ooooo`005Oooool00ol0003oooooooooo`2iooooo`;o
0000COooool001Gooooo00?o0000ooooooooool0^oooool2o`0004_ooooo000Eooooo`03o`000?oo
oooooooo0;gooooo0_l00019ooooo`000_ooool2o`0000Cooooo00?o0000ooooooooool00_ooool3
o`0000Gooooo00?o0000ooooooooool0_oooool3o`0004Kooooo00001Ooooooo0000oooooooooooo
000000Oooooo00Go0000ooooooooooooooooo`000004ooooo`03o`000?oooooooooo0<;ooooo0_l0
0014ooooo`0000Goooooo`000?ooooooooooo`000007ooooo`05o`000?ooooooooooooooool00000
1?ooool00ol0003oooooooooo`34ooooo`;o0000@_ooool00005ooooool0003oooooooooool00000
2?ooool3o`0000Gooooo0ol00036ooooo`?o0000?oooool00005ooooool0003oooooooooool00000
1oooool01Ol0003ooooooooooooooooo000000Cooooo00?o0000ooooooooool0bOooool3o`0003co
oooo00001Ooooooo0000oooooooooooo000000Oooooo00Go0000ooooooooooooooooo`000004oooo
o`03o`000?oooooooooo0<cooooo0ol0000iooooo`000_ooool2o`0000Wooooo0ol00005ooooo`03
o`000?oooooooooo0<oooooo1Ol0000dooooo`005Oooool00ol0003oooooooooo`3Dooooo`Co0000
<?ooool001Gooooo00?o0000ooooooooool0f?ooool5o`0002_ooooo000Eooooo`03o`000?oooooo
oooo0=gooooo1_l0000Uooooo`005Oooool00ol0003oooooooooo`3Sooooo`Ko00007oooool001Go
oooo0_l0003Zooooo`Go00006_ooool001Gooooo00?o0000ooooooooool0k_ooool7o`0001?ooooo
000Eooooo`03o`000?oooooooooo0?Gooooo1_l0000=ooooo`005Oooool00ol0003oooooooooo`3k
ooooo`Co00002Oooool001Gooooo00?o0000ooooooooool0ooooool2o`0000Oooooo000Eooooo`03
o`000?oooooooooo0?oooooo2Oooool001Gooooo00?o0000ooooooooool0ooooool9ooooo`005Ooo
ool00ol0003oooooooooo`3oooooo`Wooooo000Eooooo`;o0000ooooool:ooooo`005Oooool00ol0
003oooooooooo`3oooooo`Wooooo000Eooooo`03o`000?oooooooooo0?oooooo2Oooool001Gooooo
00?o0000ooooooooool0ooooool9ooooo`005Oooool00ol0003oooooooooo`3oooooo`Wooooo000E
ooooo`03o`000?oooooooooo0?oooooo2Oooool001Gooooo00?o0000ooooooooool0ooooool9oooo
o`005Oooool00ol0003oooooooooo`3oooooo`Wooooo000Eooooo`;o0000ooooool:ooooo`005Ooo
ool00ol0003oooooooooo`3oooooo`Wooooo000Eooooo`03o`000?oooooooooo0?oooooo2Oooool0
01Gooooo00?o0000ooooooooool0ooooool9ooooo`005Oooool00ol0003oooooooooo`3oooooo`Wo
oooo000=ooooo`?o00001Oooool00ol0003oooooooooo`3oooooo`Wooooo000>ooooo`03o`000?oo
oooooooo00Cooooo00?o0000ooooooooool0ooooool9ooooo`003_ooool00ol0003oooooooooo`04
ooooo`03o`000?oooooooooo0?oooooo2Oooool000kooooo00?o0000ooooooooool01?ooool3o`00
0?oooooo2Oooool000kooooo00?o0000ooooooooool0ooooool@ooooo`003Oooool2o`000?oooooo
4_ooool000kooooo00?o0000ooooooooool0ooooool@ooooo`00oooooolQooooo`00\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-2.49048, -0.0764114, \
0.115739, 0.00624232}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 0.0333333 0 0.618034 [
[.16667 -0.0125 -3 -9 ]
[.16667 -0.0125 3 0 ]
[.33333 -0.0125 -6 -9 ]
[.33333 -0.0125 6 0 ]
[.5 -0.0125 -6 -9 ]
[.5 -0.0125 6 0 ]
[.66667 -0.0125 -6 -9 ]
[.66667 -0.0125 6 0 ]
[.83333 -0.0125 -6 -9 ]
[.83333 -0.0125 6 0 ]
[1 -0.0125 -6 -9 ]
[1 -0.0125 6 0 ]
[-0.0125 .12361 -18 -4.5 ]
[-0.0125 .12361 0 4.5 ]
[-0.0125 .24721 -18 -4.5 ]
[-0.0125 .24721 0 4.5 ]
[-0.0125 .37082 -18 -4.5 ]
[-0.0125 .37082 0 4.5 ]
[-0.0125 .49443 -18 -4.5 ]
[-0.0125 .49443 0 4.5 ]
[-0.0125 .61803 -6 -4.5 ]
[-0.0125 .61803 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.16667 0 m
.16667 .00625 L
s
[(5)] .16667 -0.0125 0 1 Mshowa
.33333 0 m
.33333 .00625 L
s
[(10)] .33333 -0.0125 0 1 Mshowa
.5 0 m
.5 .00625 L
s
[(15)] .5 -0.0125 0 1 Mshowa
.66667 0 m
.66667 .00625 L
s
[(20)] .66667 -0.0125 0 1 Mshowa
.83333 0 m
.83333 .00625 L
s
[(25)] .83333 -0.0125 0 1 Mshowa
1 0 m
1 .00625 L
s
[(30)] 1 -0.0125 0 1 Mshowa
.125 Mabswid
.03333 0 m
.03333 .00375 L
s
.06667 0 m
.06667 .00375 L
s
.1 0 m
.1 .00375 L
s
.13333 0 m
.13333 .00375 L
s
.2 0 m
.2 .00375 L
s
.23333 0 m
.23333 .00375 L
s
.26667 0 m
.26667 .00375 L
s
.3 0 m
.3 .00375 L
s
.36667 0 m
.36667 .00375 L
s
.4 0 m
.4 .00375 L
s
.43333 0 m
.43333 .00375 L
s
.46667 0 m
.46667 .00375 L
s
.53333 0 m
.53333 .00375 L
s
.56667 0 m
.56667 .00375 L
s
.6 0 m
.6 .00375 L
s
.63333 0 m
.63333 .00375 L
s
.7 0 m
.7 .00375 L
s
.73333 0 m
.73333 .00375 L
s
.76667 0 m
.76667 .00375 L
s
.8 0 m
.8 .00375 L
s
.86667 0 m
.86667 .00375 L
s
.9 0 m
.9 .00375 L
s
.93333 0 m
.93333 .00375 L
s
.96667 0 m
.96667 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .12361 m
.00625 .12361 L
s
[(0.2)] -0.0125 .12361 1 0 Mshowa
0 .24721 m
.00625 .24721 L
s
[(0.4)] -0.0125 .24721 1 0 Mshowa
0 .37082 m
.00625 .37082 L
s
[(0.6)] -0.0125 .37082 1 0 Mshowa
0 .49443 m
.00625 .49443 L
s
[(0.8)] -0.0125 .49443 1 0 Mshowa
0 .61803 m
.00625 .61803 L
s
[(1)] -0.0125 .61803 1 0 Mshowa
.125 Mabswid
0 .0309 m
.00375 .0309 L
s
0 .0618 m
.00375 .0618 L
s
0 .09271 m
.00375 .09271 L
s
0 .15451 m
.00375 .15451 L
s
0 .18541 m
.00375 .18541 L
s
0 .21631 m
.00375 .21631 L
s
0 .27812 m
.00375 .27812 L
s
0 .30902 m
.00375 .30902 L
s
0 .33992 m
.00375 .33992 L
s
0 .40172 m
.00375 .40172 L
s
0 .43262 m
.00375 .43262 L
s
0 .46353 m
.00375 .46353 L
s
0 .52533 m
.00375 .52533 L
s
0 .55623 m
.00375 .55623 L
s
0 .58713 m
.00375 .58713 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.03333 .07778 m
.06667 .08577 L
.1 .09094 L
.13333 .09624 L
.16667 .10241 L
.2 .10984 L
.23333 .11879 L
.26667 .12955 L
.3 .14241 L
.33333 .15773 L
.36667 .17592 L
.4 .19745 L
.43333 .22289 L
.46667 .2529 L
.5 .28825 L
.53333 .32978 L
.56667 .36513 L
.6 .39515 L
.63333 .42059 L
.66667 .44212 L
.7 .4603 L
.73333 .47562 L
.76667 .48848 L
.8 .49924 L
.83333 .5082 L
.86667 .51562 L
.9 .5218 L
.93333 .52709 L
.96667 .53226 L
1 .54026 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[6]:=",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/B000`400?l00000o`00003ooooooolQ
ooooo`00?_ooool3o`0002Gooooo0ol00004ooooo`;o00008oooool3o`0000?ooooo0ol0000Qoooo
o`Go00000oooool2o`00027ooooo1Ol00002ooooo`?o00008_ooool3o`0000Cooooo0_l00004oooo
o`00?Oooool01Ol0003ooooooooooooooooo000002Gooooo00?o0000ooooooooool00_ooool01?l0
003oooooooooool0000Sooooo`05o`000?ooooooooooooooool000000oooool00ol0003ooooooooo
o`0Oooooo`04o`000?ooooooooooo`0000;ooooo00Co0000oooooooooooo00008Oooool01_l0003o
ooooooooool0003oooooo`0000?ooooo00?o0000ooooooooool07_ooool01Ol0003ooooooooooooo
oooo000000;ooooo00Co0000oooooooooooo00000oooool0047ooooo00?o0000ooooooooool08ooo
ool00ol0003oooooooooo`02ooooo`04o`000?ooooooooooo`0002?ooooo00?o0000ooooooooool0
1Oooool00ol0003oooooooooo`0Pooooo`03o`000?oooooooooo00;ooooo00Co0000oooooooooooo
00008_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo02;ooooo00Co0000oooooooo
oooo00000_ooool00ol0003oooooooooo`01ooooo`00@Oooool00ol0003oooooooooo`0Sooooo`03
o`000?oooooooooo00;ooooo00Co0000oooooooooooo00008oooool00ol0003oooooooooo`05oooo
o`03o`000?oooooooooo027ooooo00Go0000ooooooooooooooooo`000002ooooo`03o`000?oooooo
oooo027ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`0Pooooo`;o00000oooool0
1?l0003oooooooooool00003ooooo`00?Oooool4o`0002Kooooo00?o0000ooooooooool00_ooool0
1?l0003oooooooooool0000Sooooo`04o`000?ooooooooooooooo`Co00008Oooool01Ol0003ooooo
oooooooooooo000000;ooooo00Co0000oooooooooooo00008?ooool01_l0003ooooooooooooooooo
0000ooooo`Co00009Oooool01?l0003oooooooooool00002ooooo`03o`000?oooooooooo007ooooo
000mooooo`03o`000?oooooooooo02Kooooo0_l00004ooooo`04o`000?ooooooooooo`0002;ooooo
0_l00003ooooo`03o`000?oooooooooo02;ooooo00Go0000ooooooooooooooooo`000002ooooo`04
o`000?ooooooooooo`00023ooooo00Oo0000ooooooooooooooooo`000?oooooo000002Cooooo00Go
0000ooooooooooooooooo`000002ooooo`04o`000?ooooooooooo`0000?ooooo000mooooo`Go0000
9Oooool00ol0003oooooooooo`03ooooo`;o00009?ooool01?l0003oooooooooooooool5o`00027o
oooo0ol00004ooooo`;o00008_ooool3o`0000;ooooo1Ol0000Qooooo`?o00001?ooool2o`0000Co
oooo003oooooob7ooooo003oooooob7ooooo003oooooob7ooooo003oooooob7ooooo000Eoooooooo
00001Ol00007ooooo`005Oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Gooooo
00?o0000ooooooooool01_ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Gooooo
00?o0000ooooooooool01_ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Gooooo
00?o0000ooooooooool01_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Kooooo
00?o0000ooooooooool01_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Kooooo
00?o0000ooooooooool01_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Kooooo
00?o0000ooooooooool01_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Kooooo
00?o0000ooooooooool01Oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Kooooo
00?o0000ooooooooool01Oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Kooooo
00?o0000ooooooooool01Oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Kooooo
00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`005Oooool00ol0003ooooooooo
o`3oooooo`Wooooo000Eooooo`03o`000?oooooooooo0?oooooo2Oooool001Gooooo00?o0000oooo
ooooool0ooooool9ooooo`005Oooool00ol0003oooooooooo`3oooooo`Wooooo000Eooooo`03o`00
0?oooooooooo0?oooooo2Oooool001Gooooo00?o0000ooooooooool0ooooool9ooooo`005Oooool2
o`000?oooooo2_ooool001Gooooo00?o0000ooooooooool0ooooool9ooooo`005Oooool00ol0003o
ooooooooo`3oooooo`Wooooo000Eooooo`03o`000?oooooooooo0?oooooo2Oooool001Gooooo00?o
0000ooooooooool0ooooool9ooooo`005Oooool00ol0003oooooooooo`3oooooo`Wooooo000Eoooo
o`03o`000?oooooooooo0?oooooo2Oooool001Gooooo00?o0000ooooooooool0ooooool9ooooo`00
5Oooool2o`000?oooooo2_ooool001Gooooo00?o0000ooooooooool0ooooool9ooooo`005Oooool0
0ol0003oooooooooo`3oooooo`Wooooo000Eooooo`03o`000?oooooooooo0?oooooo2Oooool001Go
oooo00?o0000ooooooooool01_ooool3o`000?oooooo000Eooooo`03o`000?oooooooooo00Wooooo
1?l0003kooooo`005Oooool00ol0003oooooooooo`0=ooooo`Oo0000m?ooool001Gooooo00?o0000
ooooooooool05?ooool6o`000>kooooo000Eooooo`;o00006oooool5o`000>Wooooo000Eooooo`03
o`000?oooooooooo01oooooo1_l0003Sooooo`005Oooool00ol0003oooooooooo`0Uooooo`Ko0000
gOooool001Gooooo00?o0000ooooooooool0:oooool5o`000=Sooooo000Eooooo`03o`000?oooooo
oooo033ooooo1?l0003Dooooo`000_ooool2o`0000Cooooo00Co0000oooooooooooooooo1Ol00004
ooooo`03o`000?oooooooooo03Cooooo0ol0003Aooooo`0000Goooooo`000?ooooooooooo`000008
ooooo`04o`000?ooooooooooo`0000Cooooo00?o0000ooooooooool0=oooool3o`000<kooooo0000
1Ooooooo0000oooooooooooo000000Wooooo00?o0000ooooooooool01?ooool00ol0003ooooooooo
o`0jooooo`?o0000boooool00005ooooool0003oooooooooool000002_ooool00ol0003ooooooooo
o`03ooooo`?o0000?Oooool4o`000<Oooooo00001Ooooooo0000oooooooooooo000000Oooooo00Go
0000ooooooooooooooooo`000004ooooo`03o`000?oooooooooo047ooooo0ol00034ooooo`0000Go
ooooo`000?ooooooooooo`000007ooooo`05o`000?ooooooooooooooool000001?ooool00ol0003o
ooooooooo`14ooooo`;o0000`_ooool000;ooooo0_l00009ooooo`?o00001Oooool00ol0003ooooo
ooooo`16ooooo`?o0000_oooool001Gooooo00?o0000ooooooooool0BOooool2o`000;gooooo000E
ooooo`03o`000?oooooooooo04_ooooo0_l0002kooooo`005Oooool00ol0003oooooooooo`1=oooo
o`;o0000^Oooool001Gooooo00?o0000ooooooooool0Coooool2o`000;Oooooo000Eooooo`;o0000
D_ooool2o`000;Gooooo000Eooooo`03o`000?oooooooooo05?ooooo0_l0002cooooo`005Oooool0
0ol0003oooooooooo`1Eooooo`;o0000/Oooool001Gooooo00?o0000ooooooooool0Eoooool3o`00
0:kooooo000Eooooo`03o`000?oooooooooo05[ooooo0_l0002/ooooo`005Oooool00ol0003ooooo
ooooo`1Looooo`;o0000Z_ooool001Gooooo00?o0000ooooooooool0G_ooool00ol0003ooooooooo
o`2Wooooo`005Oooool00ol0003oooooooooo`1Oooooo`;o0000Yoooool001Gooooo0_l0001Roooo
o`03o`000?oooooooooo0:Cooooo000Eooooo`03o`000?oooooooooo06;ooooo0_l0002Tooooo`00
5Oooool00ol0003oooooooooo`1Tooooo`03o`000?oooooooooo0:7ooooo000Eooooo`03o`000?oo
oooooooo06Gooooo0_l0002Qooooo`005Oooool00ol0003oooooooooo`1Wooooo`03o`000?oooooo
oooo09kooooo000Eooooo`03o`000?oooooooooo06Sooooo00?o0000ooooooooool0WOooool001Go
oooo00?o0000ooooooooool0JOooool00ol0003oooooooooo`2Looooo`005Oooool00ol0003ooooo
ooooo`1Zooooo`03o`000?oooooooooo09_ooooo000Eooooo`;o0000K?ooool00ol0003ooooooooo
o`2Jooooo`005Oooool00ol0003oooooooooo`1/ooooo`03o`000?oooooooooo09Wooooo000Eoooo
o`03o`000?oooooooooo06gooooo0_l0002Iooooo`005Oooool00ol0003oooooooooo`1_ooooo`03
o`000?oooooooooo09Kooooo000Eooooo`03o`000?oooooooooo073ooooo00?o0000ooooooooool0
UOooool000;ooooo0_l00004ooooo`03o`000?oooooooooo00?ooooo0ol00004ooooo`03o`000?oo
oooooooo077ooooo0_l0002Eooooo`0000Goooooo`000?ooooooooooo`00000:ooooo`03o`000?oo
oooooooo00?ooooo00?o0000ooooooooool0Loooool00ol0003oooooooooo`2Booooo`0000Gooooo
o`000?ooooooooooo`000007ooooo`Go00001?ooool00ol0003oooooooooo`1dooooo`03o`000?oo
oooooooo097ooooo00001Ooooooo0000oooooooooooo000000Oooooo00Co0000oooooooooooo0000
1Oooool3o`0007Gooooo00?o0000ooooooooool0T?ooool00005ooooool0003oooooooooool00000
2?ooool00ol0003oooooo`000005ooooo`03o`000?oooooooooo07Kooooo00?o0000ooooooooool0
Soooool00005ooooool0003oooooooooool000002Oooool2o`0000Gooooo00?o0000ooooooooool0
M_ooool00ol0003oooooooooo`2?ooooo`000_ooool2o`0000_ooooo00?o0000ooooooooool00ooo
ool00ol0003oooooooooo`1gooooo`03o`000?oooooooooo08kooooo000Eooooo`03o`000?oooooo
oooo07Sooooo00?o0000ooooooooool0SOooool001Gooooo00?o0000ooooooooool0NOooool00ol0
003oooooooooo`2<ooooo`005Oooool00ol0003oooooooooo`1jooooo`03o`000?oooooooooo08_o
oooo000Eooooo`03o`000?oooooooooo07_ooooo00?o0000ooooooooool0R_ooool001Gooooo0_l0
001mooooo`03o`000?oooooooooo08Wooooo000Eooooo`03o`000?oooooooooo07gooooo00?o0000
ooooooooool0R?ooool001Gooooo00?o0000ooooooooool0O_ooool00ol0003oooooooooo`27oooo
o`005Oooool00ol0003oooooooooo`1oooooo`03o`000?oooooooooo08Kooooo000Eooooo`03o`00
0?oooooooooo07oooooo00?o0000ooooooooool0Q_ooool001Gooooo00?o0000ooooooooool0P?oo
ool00ol0003oooooooooo`25ooooo`005Oooool00ol0003oooooooooo`21ooooo`03o`000?oooooo
oooo08Cooooo000Eooooo`03o`000?oooooooooo08;ooooo00?o0000ooooooooool0Poooool001Go
oooo0_l00024ooooo`03o`000?oooooooooo08;ooooo000Eooooo`03o`000?oooooooooo08?ooooo
00?o0000ooooooooool0P_ooool001Gooooo00?o0000ooooooooool0Q?ooool00ol0003ooooooooo
o`21ooooo`005Oooool00ol0003oooooooooo`25ooooo`03o`000?oooooooooo083ooooo000Eoooo
o`03o`000?oooooooooo08Kooooo00?o0000ooooooooool0Ooooool001Gooooo00?o0000oooooooo
ool0Qoooool00ol0003oooooooooo`1nooooo`005Oooool00ol0003oooooooooo`28ooooo`03o`00
0?oooooooooo07gooooo000Eooooo`03o`000?oooooooooo08Wooooo00?o0000ooooooooool0O?oo
ool001Gooooo0_l0002;ooooo`03o`000?oooooooooo07_ooooo000Eooooo`03o`000?oooooooooo
08_ooooo00?o0000ooooooooool0N_ooool001Gooooo00?o0000ooooooooool0S?ooool00ol0003o
ooooooooo`1iooooo`005Oooool00ol0003oooooooooo`2=ooooo`03o`000?oooooooooo07Sooooo
000Eooooo`03o`000?oooooooooo08kooooo00?o0000ooooooooool0Moooool000;ooooo0_l00004
ooooo`03o`000?oooooooooo00;ooooo0ol00005ooooo`03o`000?oooooooooo08oooooo00?o0000
ooooooooool0M_ooool00005ooooool0003oooooooooool000001oooool01Ol0003ooooooooooooo
oooo000000Cooooo00?o0000ooooooooool0T?ooool2o`0007Kooooo00001Ooooooo0000oooooooo
oooo000000Oooooo00Go0000ooooooooooooooooo`000004ooooo`03o`000?oooooooooo09;ooooo
00?o0000ooooooooool0Loooool00005ooooool0003oooooooooool000001oooool4o`0000Gooooo
0ol0002Cooooo`03o`000?oooooooooo07;ooooo00001Ooooooo0000oooooooooooo000000Oooooo
00?o0000ooooooooool01_ooool00ol0003oooooooooo`2Dooooo`03o`000?oooooooooo077ooooo
00001Ooooooo0000oooooooooooo000000Sooooo00?o0000ooooooooool01Oooool00ol0003ooooo
ooooo`2Eooooo`03o`000?oooooooooo073ooooo0002ooooo`;o00002_ooool2o`0000Gooooo00?o
0000ooooooooool0U_ooool00ol0003oooooooooo`1_ooooo`005Oooool00ol0003oooooooooo`2G
ooooo`03o`000?oooooooooo06kooooo000Eooooo`03o`000?oooooooooo09Sooooo00?o0000oooo
ooooool0KOooool001Gooooo00?o0000ooooooooool0VOooool2o`0006gooooo000Eooooo`03o`00
0?oooooooooo09_ooooo00?o0000ooooooooool0J_ooool001Gooooo0_l0002Mooooo`03o`000?oo
oooooooo06Wooooo000Eooooo`03o`000?oooooooooo09gooooo00?o0000ooooooooool0J?ooool0
01Gooooo00?o0000ooooooooool0W_ooool00ol0003oooooooooo`1Wooooo`005Oooool00ol0003o
ooooooooo`2Oooooo`03o`000?oooooooooo06Kooooo000Eooooo`03o`000?oooooooooo0:3ooooo
00?o0000ooooooooool0IOooool001Gooooo00?o0000ooooooooool0XOooool2o`0006Gooooo000E
ooooo`03o`000?oooooooooo0:?ooooo0_l0001Sooooo`005Oooool00ol0003oooooooooo`2Uoooo
o`;o0000HOooool001Gooooo0_l0002Xooooo`03o`000?oooooooooo05kooooo000Eooooo`03o`00
0?oooooooooo0:Sooooo0_l0001Nooooo`005Oooool00ol0003oooooooooo`2Zooooo`;o0000G?oo
ool001Gooooo00?o0000ooooooooool0[?ooool00ol0003oooooooooo`1Iooooo`005Oooool00ol0
003oooooooooo`2]ooooo`;o0000FOooool001Gooooo00?o0000ooooooooool0[oooool2o`0005Oo
oooo000Eooooo`03o`000?oooooooooo0;7ooooo00?o0000ooooooooool0E?ooool001Gooooo00?o
0000ooooooooool0/_ooool2o`0005Cooooo000Eooooo`;o0000]Oooool2o`0005;ooooo000Eoooo
o`03o`000?oooooooooo0;Kooooo0ol0001?ooooo`005Oooool00ol0003oooooooooo`2iooooo`;o
0000COooool001Gooooo00?o0000ooooooooool0^oooool3o`0004[ooooo000Eooooo`03o`000?oo
oooooooo0;kooooo0ol00017ooooo`000_ooool2o`0000Cooooo00?o0000ooooooooool00_ooool3
o`0000Gooooo00?o0000ooooooooool0`Oooool3o`0004Cooooo00001Ooooooo0000oooooooooooo
000000Oooooo00Go0000ooooooooooooooooo`000004ooooo`03o`000?oooooooooo0<Cooooo0_l0
0012ooooo`0000Goooooo`000?ooooooooooo`000007ooooo`05o`000?ooooooooooooooool00000
1?ooool00ol0003oooooooooo`36ooooo`?o0000?oooool00005ooooool0003oooooooooool00000
2?ooool3o`0000Gooooo0ol00039ooooo`?o0000??ooool00005ooooool0003oooooooooool00000
1oooool01Ol0003ooooooooooooooooo000000Cooooo00?o0000ooooooooool0c?ooool3o`0003Wo
oooo00001Ooooooo0000oooooooooooo000000Oooooo00Go0000ooooooooooooooooo`000004oooo
o`03o`000?oooooooooo0<oooooo0ol0000fooooo`000_ooool2o`0000Wooooo0ol00005ooooo`03
o`000?oooooooooo0=;ooooo0ol0000cooooo`005Oooool00ol0003oooooooooo`3Eooooo`Ko0000
;Oooool001Gooooo00?o0000ooooooooool0foooool6o`0002Oooooo000Eooooo`03o`000?oooooo
oooo0>7ooooo1?l0000Sooooo`005Oooool00ol0003oooooooooo`3Uooooo`Oo00007?ooool001Go
oooo0_l0003]ooooo`Ko00005_ooool001Gooooo00?o0000ooooooooool0l_ooool5o`00017ooooo
000Eooooo`03o`000?oooooooooo0?Oooooo1?l0000=ooooo`005Oooool00ol0003oooooooooo`3k
ooooo`Co00002Oooool001Gooooo00?o0000ooooooooool0ooooool2o`0000Oooooo000Eooooo`03
o`000?oooooooooo0?oooooo2Oooool001Gooooo00?o0000ooooooooool0ooooool9ooooo`005Ooo
ool00ol0003oooooooooo`3oooooo`Wooooo000Eooooo`;o0000ooooool:ooooo`005Oooool00ol0
003oooooooooo`3oooooo`Wooooo000Eooooo`03o`000?oooooooooo0?oooooo2Oooool001Gooooo
00?o0000ooooooooool0ooooool9ooooo`005Oooool00ol0003oooooooooo`3oooooo`Wooooo000E
ooooo`03o`000?oooooooooo0?oooooo2Oooool001Gooooo00?o0000ooooooooool0ooooool9oooo
o`005Oooool00ol0003oooooooooo`3oooooo`Wooooo000Eooooo`;o0000ooooool:ooooo`005Ooo
ool00ol0003oooooooooo`3oooooo`Wooooo000Eooooo`03o`000?oooooooooo0?oooooo2Oooool0
01Gooooo00?o0000ooooooooool0ooooool9ooooo`005Oooool00ol0003oooooooooo`3oooooo`Wo
oooo000=ooooo`?o00001Oooool00ol0003oooooooooo`3oooooo`Wooooo000>ooooo`03o`000?oo
oooooooo00Cooooo00?o0000ooooooooool0ooooool9ooooo`003_ooool00ol0003oooooooooo`04
ooooo`03o`000?oooooooooo0?oooooo2Oooool000kooooo00?o0000ooooooooool01?ooool3o`00
0?oooooo2Oooool000kooooo00?o0000ooooooooool0ooooool@ooooo`003Oooool2o`000?oooooo
4_ooool000kooooo00?o0000ooooooooool0ooooool@ooooo`00oooooolQooooo`00\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-2.49048, -0.0764114, \
0.115739, 0.00624232}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 0.0333333 0 0.618034 [
[.16667 -0.0125 -3 -9 ]
[.16667 -0.0125 3 0 ]
[.33333 -0.0125 -6 -9 ]
[.33333 -0.0125 6 0 ]
[.5 -0.0125 -6 -9 ]
[.5 -0.0125 6 0 ]
[.66667 -0.0125 -6 -9 ]
[.66667 -0.0125 6 0 ]
[.83333 -0.0125 -6 -9 ]
[.83333 -0.0125 6 0 ]
[1 -0.0125 -6 -9 ]
[1 -0.0125 6 0 ]
[-0.0125 .12361 -18 -4.5 ]
[-0.0125 .12361 0 4.5 ]
[-0.0125 .24721 -18 -4.5 ]
[-0.0125 .24721 0 4.5 ]
[-0.0125 .37082 -18 -4.5 ]
[-0.0125 .37082 0 4.5 ]
[-0.0125 .49443 -18 -4.5 ]
[-0.0125 .49443 0 4.5 ]
[-0.0125 .61803 -6 -4.5 ]
[-0.0125 .61803 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.16667 0 m
.16667 .00625 L
s
[(5)] .16667 -0.0125 0 1 Mshowa
.33333 0 m
.33333 .00625 L
s
[(10)] .33333 -0.0125 0 1 Mshowa
.5 0 m
.5 .00625 L
s
[(15)] .5 -0.0125 0 1 Mshowa
.66667 0 m
.66667 .00625 L
s
[(20)] .66667 -0.0125 0 1 Mshowa
.83333 0 m
.83333 .00625 L
s
[(25)] .83333 -0.0125 0 1 Mshowa
1 0 m
1 .00625 L
s
[(30)] 1 -0.0125 0 1 Mshowa
.125 Mabswid
.03333 0 m
.03333 .00375 L
s
.06667 0 m
.06667 .00375 L
s
.1 0 m
.1 .00375 L
s
.13333 0 m
.13333 .00375 L
s
.2 0 m
.2 .00375 L
s
.23333 0 m
.23333 .00375 L
s
.26667 0 m
.26667 .00375 L
s
.3 0 m
.3 .00375 L
s
.36667 0 m
.36667 .00375 L
s
.4 0 m
.4 .00375 L
s
.43333 0 m
.43333 .00375 L
s
.46667 0 m
.46667 .00375 L
s
.53333 0 m
.53333 .00375 L
s
.56667 0 m
.56667 .00375 L
s
.6 0 m
.6 .00375 L
s
.63333 0 m
.63333 .00375 L
s
.7 0 m
.7 .00375 L
s
.73333 0 m
.73333 .00375 L
s
.76667 0 m
.76667 .00375 L
s
.8 0 m
.8 .00375 L
s
.86667 0 m
.86667 .00375 L
s
.9 0 m
.9 .00375 L
s
.93333 0 m
.93333 .00375 L
s
.96667 0 m
.96667 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .12361 m
.00625 .12361 L
s
[(0.2)] -0.0125 .12361 1 0 Mshowa
0 .24721 m
.00625 .24721 L
s
[(0.4)] -0.0125 .24721 1 0 Mshowa
0 .37082 m
.00625 .37082 L
s
[(0.6)] -0.0125 .37082 1 0 Mshowa
0 .49443 m
.00625 .49443 L
s
[(0.8)] -0.0125 .49443 1 0 Mshowa
0 .61803 m
.00625 .61803 L
s
[(1)] -0.0125 .61803 1 0 Mshowa
.125 Mabswid
0 .0309 m
.00375 .0309 L
s
0 .0618 m
.00375 .0618 L
s
0 .09271 m
.00375 .09271 L
s
0 .15451 m
.00375 .15451 L
s
0 .18541 m
.00375 .18541 L
s
0 .21631 m
.00375 .21631 L
s
0 .27812 m
.00375 .27812 L
s
0 .30902 m
.00375 .30902 L
s
0 .33992 m
.00375 .33992 L
s
0 .40172 m
.00375 .40172 L
s
0 .43262 m
.00375 .43262 L
s
0 .46353 m
.00375 .46353 L
s
0 .52533 m
.00375 .52533 L
s
0 .55623 m
.00375 .55623 L
s
0 .58713 m
.00375 .58713 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.03333 .0782 m
.06667 .08653 L
.1 .09182 L
.13333 .09716 L
.16667 .10334 L
.2 .11075 L
.23333 .11967 L
.26667 .13038 L
.3 .14317 L
.33333 .15841 L
.36667 .1765 L
.4 .19792 L
.43333 .22324 L
.46667 .25312 L
.5 .28833 L
.53333 .32971 L
.56667 .36491 L
.6 .3948 L
.63333 .42012 L
.66667 .44154 L
.7 .45962 L
.73333 .47486 L
.76667 .48766 L
.8 .49836 L
.83333 .50728 L
.86667 .51469 L
.9 .52087 L
.93333 .52621 L
.96667 .53151 L
1 .53983 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[6]:=",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/B000`400?l00000o`00003ooooooolQ
ooooo`00?_ooool3o`0002Gooooo0ol00004ooooo`;o00008oooool3o`0000?ooooo0ol0000Qoooo
o`Go00000oooool2o`00027ooooo1Ol00002ooooo`?o00008_ooool3o`0000Cooooo0_l00004oooo
o`00?Oooool01Ol0003ooooooooooooooooo000002Gooooo00?o0000ooooooooool00_ooool01?l0
003oooooooooool0000Sooooo`05o`000?ooooooooooooooool000000oooool00ol0003ooooooooo
o`0Oooooo`04o`000?ooooooooooo`0000;ooooo00Co0000oooooooooooo00008Oooool01_l0003o
ooooooooool0003oooooo`0000?ooooo00?o0000ooooooooool07_ooool01Ol0003ooooooooooooo
oooo000000;ooooo00Co0000oooooooooooo00000oooool0047ooooo00?o0000ooooooooool08ooo
ool00ol0003oooooooooo`02ooooo`04o`000?ooooooooooo`0002?ooooo00?o0000ooooooooool0
1Oooool00ol0003oooooooooo`0Pooooo`03o`000?oooooooooo00;ooooo00Co0000oooooooooooo
00008_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo02;ooooo00Co0000oooooooo
oooo00000_ooool00ol0003oooooooooo`01ooooo`00@Oooool00ol0003oooooooooo`0Sooooo`03
o`000?oooooooooo00;ooooo00Co0000oooooooooooo00008oooool00ol0003oooooooooo`05oooo
o`03o`000?oooooooooo027ooooo00Go0000ooooooooooooooooo`000002ooooo`03o`000?oooooo
oooo027ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`0Pooooo`;o00000oooool0
1?l0003oooooooooool00003ooooo`00?Oooool4o`0002Kooooo00?o0000ooooooooool00_ooool0
1?l0003oooooooooool0000Sooooo`04o`000?ooooooooooooooo`Co00008Oooool01Ol0003ooooo
oooooooooooo000000;ooooo00Co0000oooooooooooo00008?ooool01_l0003ooooooooooooooooo
0000ooooo`Co00009Oooool01?l0003oooooooooool00002ooooo`03o`000?oooooooooo007ooooo
000mooooo`03o`000?oooooooooo02Kooooo0_l00004ooooo`04o`000?ooooooooooo`0002;ooooo
0_l00003ooooo`03o`000?oooooooooo02;ooooo00Go0000ooooooooooooooooo`000002ooooo`04
o`000?ooooooooooo`00023ooooo00Oo0000ooooooooooooooooo`000?oooooo000002Cooooo00Go
0000ooooooooooooooooo`000002ooooo`04o`000?ooooooooooo`0000?ooooo000mooooo`Go0000
9Oooool00ol0003oooooooooo`03ooooo`;o00009?ooool01?l0003oooooooooooooool5o`00027o
oooo0ol00004ooooo`;o00008_ooool3o`0000;ooooo1Ol0000Qooooo`?o00001?ooool2o`0000Co
oooo003oooooob7ooooo003oooooob7ooooo003oooooob7ooooo003oooooob7ooooo000Eoooooooo
00001Ol00007ooooo`005Oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Gooooo
00?o0000ooooooooool01_ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Gooooo
00?o0000ooooooooool01_ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Gooooo
00?o0000ooooooooool01_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Kooooo
00?o0000ooooooooool01_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Kooooo
00?o0000ooooooooool01_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Kooooo
00?o0000ooooooooool01_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Kooooo
00?o0000ooooooooool01Oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Kooooo
00?o0000ooooooooool01Oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Kooooo
00?o0000ooooooooool01Oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Kooooo
00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`005Oooool00ol0003ooooooooo
o`3oooooo`Wooooo000Eooooo`03o`000?oooooooooo0?oooooo2Oooool001Gooooo00?o0000oooo
ooooool0ooooool9ooooo`005Oooool00ol0003oooooooooo`3oooooo`Wooooo000Eooooo`03o`00
0?oooooooooo0?oooooo2Oooool001Gooooo00?o0000ooooooooool0ooooool9ooooo`005Oooool2
o`000?oooooo2_ooool001Gooooo00?o0000ooooooooool0ooooool9ooooo`005Oooool00ol0003o
ooooooooo`3oooooo`Wooooo000Eooooo`03o`000?oooooooooo0?oooooo2Oooool001Gooooo00?o
0000ooooooooool0ooooool9ooooo`005Oooool00ol0003oooooooooo`3oooooo`Wooooo000Eoooo
o`03o`000?oooooooooo0?oooooo2Oooool001Gooooo00?o0000ooooooooool0ooooool9ooooo`00
5Oooool2o`000?oooooo2_ooool001Gooooo00?o0000ooooooooool0ooooool9ooooo`005Oooool0
0ol0003oooooooooo`3oooooo`Wooooo000Eooooo`03o`000?oooooooooo0?oooooo2Oooool001Go
oooo00?o0000ooooooooool01_ooool3o`000?oooooo000Eooooo`03o`000?oooooooooo00Wooooo
1?l0003kooooo`005Oooool00ol0003oooooooooo`0=ooooo`Co0000moooool001Gooooo00?o0000
ooooooooool04Oooool5o`000?;ooooo000Eooooo`;o00005oooool7o`000>_ooooo000Eooooo`03
o`000?oooooooooo01gooooo1_l0003Uooooo`005Oooool00ol0003oooooooooo`0Sooooo`Co0000
hOooool001Gooooo00?o0000ooooooooool09oooool4o`000=gooooo000Eooooo`03o`000?oooooo
oooo02_ooooo1Ol0003Hooooo`000_ooool2o`0000Cooooo00Co0000oooooooooooooooo1Ol00004
ooooo`03o`000?oooooooooo033ooooo1?l0003Dooooo`0000Goooooo`000?ooooooooooo`000008
ooooo`04o`000?ooooooooooo`0000Cooooo00?o0000ooooooooool0=?ooool5o`000<oooooo0000
1Ooooooo0000oooooooooooo000000Wooooo00?o0000ooooooooool01?ooool00ol0003ooooooooo
o`0iooooo`?o0000c?ooool00005ooooool0003oooooooooool000002_ooool00ol0003ooooooooo
o`03ooooo`?o0000??ooool3o`000<Wooooo00001Ooooooo0000oooooooooooo000000Oooooo00Go
0000ooooooooooooooooo`000004ooooo`03o`000?oooooooooo03oooooo0ol00036ooooo`0000Go
ooooo`000?ooooooooooo`000007ooooo`05o`000?ooooooooooooooool000001?ooool00ol0003o
ooooooooo`12ooooo`?o0000`oooool000;ooooo0_l00009ooooo`?o00001Oooool00ol0003ooooo
ooooo`15ooooo`?o0000`?ooool001Gooooo00?o0000ooooooooool0B?ooool3o`000;gooooo000E
ooooo`03o`000?oooooooooo04_ooooo0_l0002kooooo`005Oooool00ol0003oooooooooo`1=oooo
o`;o0000^Oooool001Gooooo00?o0000ooooooooool0Coooool2o`000;Oooooo000Eooooo`;o0000
D_ooool2o`000;Gooooo000Eooooo`03o`000?oooooooooo05?ooooo0_l0002cooooo`005Oooool0
0ol0003oooooooooo`1Eooooo`;o0000/Oooool001Gooooo00?o0000ooooooooool0Eoooool2o`00
0:oooooo000Eooooo`03o`000?oooooooooo05Wooooo00?o0000ooooooooool0[?ooool001Gooooo
00?o0000ooooooooool0F_ooool2o`000:cooooo000Eooooo`03o`000?oooooooooo05cooooo0_l0
002Zooooo`005Oooool00ol0003oooooooooo`1Nooooo`;o0000Z?ooool001Gooooo0_l0001Qoooo
o`;o0000Y_ooool001Gooooo00?o0000ooooooooool0H_ooool00ol0003oooooooooo`2Sooooo`00
5Oooool00ol0003oooooooooo`1Sooooo`;o0000Xoooool001Gooooo00?o0000ooooooooool0IOoo
ool2o`000:7ooooo000Eooooo`03o`000?oooooooooo06Oooooo00?o0000ooooooooool0W_ooool0
01Gooooo00?o0000ooooooooool0J?ooool00ol0003oooooooooo`2Mooooo`005Oooool00ol0003o
ooooooooo`1Yooooo`03o`000?oooooooooo09cooooo000Eooooo`03o`000?oooooooooo06[ooooo
00?o0000ooooooooool0Voooool001Gooooo0_l0001/ooooo`03o`000?oooooooooo09[ooooo000E
ooooo`03o`000?oooooooooo06cooooo00?o0000ooooooooool0VOooool001Gooooo00?o0000oooo
ooooool0KOooool2o`0009Wooooo000Eooooo`03o`000?oooooooooo06oooooo00?o0000oooooooo
ool0U_ooool001Gooooo00?o0000ooooooooool0L?ooool00ol0003oooooooooo`2Eooooo`000_oo
ool2o`0000Cooooo00?o0000ooooooooool00oooool3o`0000Cooooo00?o0000ooooooooool0LOoo
ool2o`0009Gooooo00001Ooooooo0000oooooooooooo000000[ooooo00?o0000ooooooooool00ooo
ool00ol0003oooooooooo`1cooooo`03o`000?oooooooooo09;ooooo00001Ooooooo0000oooooooo
oooo000000Oooooo1Ol00004ooooo`03o`000?oooooooooo07Cooooo00?o0000ooooooooool0TOoo
ool00005ooooool0003oooooooooool000001oooool01?l0003oooooooooool00005ooooo`?o0000
MOooool00ol0003oooooooooo`2@ooooo`0000Goooooo`000?ooooooooooo`000008ooooo`03o`00
0?oooooo000000Gooooo00?o0000ooooooooool0M_ooool00ol0003oooooooooo`2?ooooo`0000Go
ooooo`000?ooooooooooo`000009ooooo`;o00001Oooool00ol0003oooooooooo`1fooooo`03o`00
0?oooooooooo08oooooo0002ooooo`;o00002oooool00ol0003oooooooooo`03ooooo`03o`000?oo
oooooooo07Oooooo00?o0000ooooooooool0S_ooool001Gooooo00?o0000ooooooooool0N?ooool0
0ol0003oooooooooo`2=ooooo`005Oooool00ol0003oooooooooo`1iooooo`03o`000?oooooooooo
08cooooo000Eooooo`03o`000?oooooooooo07[ooooo00?o0000ooooooooool0Roooool001Gooooo
00?o0000ooooooooool0Noooool00ol0003oooooooooo`2:ooooo`005Oooool2o`0007gooooo00?o
0000ooooooooool0ROooool001Gooooo00?o0000ooooooooool0OOooool00ol0003oooooooooo`28
ooooo`005Oooool00ol0003oooooooooo`1nooooo`03o`000?oooooooooo08Oooooo000Eooooo`03
o`000?oooooooooo07oooooo00?o0000ooooooooool0Q_ooool001Gooooo00?o0000ooooooooool0
Ooooool00ol0003oooooooooo`26ooooo`005Oooool00ol0003oooooooooo`20ooooo`03o`000?oo
oooooooo08Gooooo000Eooooo`03o`000?oooooooooo087ooooo00?o0000ooooooooool0Q?ooool0
01Gooooo00?o0000ooooooooool0P_ooool00ol0003oooooooooo`23ooooo`005Oooool2o`0008Co
oooo00?o0000ooooooooool0P_ooool001Gooooo00?o0000ooooooooool0Poooool00ol0003ooooo
ooooo`22ooooo`005Oooool00ol0003oooooooooo`24ooooo`03o`000?oooooooooo087ooooo000E
ooooo`03o`000?oooooooooo08Gooooo00?o0000ooooooooool0P?ooool001Gooooo00?o0000oooo
ooooool0Q_ooool00ol0003oooooooooo`1oooooo`005Oooool00ol0003oooooooooo`27ooooo`03
o`000?oooooooooo07kooooo000Eooooo`03o`000?oooooooooo08Sooooo00?o0000ooooooooool0
OOooool001Gooooo00?o0000ooooooooool0ROooool00ol0003oooooooooo`1looooo`005Oooool2
o`0008_ooooo00?o0000ooooooooool0Noooool001Gooooo00?o0000ooooooooool0Roooool00ol0
003oooooooooo`1jooooo`005Oooool00ol0003oooooooooo`2<ooooo`03o`000?oooooooooo07Wo
oooo000Eooooo`03o`000?oooooooooo08gooooo00?o0000ooooooooool0N?ooool001Gooooo00?o
0000ooooooooool0S_ooool00ol0003oooooooooo`1gooooo`000_ooool2o`0000Cooooo00?o0000
ooooooooool00_ooool3o`0000Gooooo00?o0000ooooooooool0Soooool00ol0003oooooooooo`1f
ooooo`0000Goooooo`000?ooooooooooo`000007ooooo`05o`000?ooooooooooooooool000001?oo
ool00ol0003oooooooooo`2@ooooo`;o0000M_ooool00005ooooool0003oooooooooool000001ooo
ool01Ol0003ooooooooooooooooo000000Cooooo00?o0000ooooooooool0T_ooool00ol0003ooooo
ooooo`1cooooo`0000Goooooo`000?ooooooooooo`000007ooooo`Co00001Oooool3o`0009?ooooo
00?o0000ooooooooool0L_ooool00005ooooool0003oooooooooool000001oooool00ol0003ooooo
ooooo`06ooooo`03o`000?oooooooooo09Cooooo00?o0000ooooooooool0LOooool00005ooooool0
003oooooooooool000002?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo09Gooooo
00?o0000ooooooooool0L?ooool000;ooooo0_l0000:ooooo`;o00001Oooool00ol0003ooooooooo
o`2Fooooo`03o`000?oooooooooo06oooooo000Eooooo`03o`000?oooooooooo09Oooooo00?o0000
ooooooooool0K_ooool001Gooooo00?o0000ooooooooool0V?ooool00ol0003oooooooooo`1]oooo
o`005Oooool00ol0003oooooooooo`2Iooooo`;o0000KOooool001Gooooo00?o0000ooooooooool0
Voooool00ol0003oooooooooo`1Zooooo`005Oooool2o`0009gooooo00?o0000ooooooooool0JOoo
ool001Gooooo00?o0000ooooooooool0WOooool00ol0003oooooooooo`1Xooooo`005Oooool00ol0
003oooooooooo`2Nooooo`03o`000?oooooooooo06Oooooo000Eooooo`03o`000?oooooooooo09oo
oooo00?o0000ooooooooool0I_ooool001Gooooo00?o0000ooooooooool0X?ooool00ol0003ooooo
ooooo`1Uooooo`005Oooool00ol0003oooooooooo`2Qooooo`;o0000IOooool001Gooooo00?o0000
ooooooooool0Xoooool2o`0006?ooooo000Eooooo`03o`000?oooooooooo0:Gooooo0_l0001Qoooo
o`005Oooool2o`000:Sooooo00?o0000ooooooooool0G_ooool001Gooooo00?o0000ooooooooool0
Z?ooool2o`0005kooooo000Eooooo`03o`000?oooooooooo0:[ooooo0_l0001Looooo`005Oooool0
0ol0003oooooooooo`2/ooooo`03o`000?oooooooooo05Wooooo000Eooooo`03o`000?oooooooooo
0:gooooo0_l0001Iooooo`005Oooool00ol0003oooooooooo`2_ooooo`;o0000Eoooool001Gooooo
00?o0000ooooooooool0/Oooool00ol0003oooooooooo`1Dooooo`005Oooool00ol0003ooooooooo
o`2booooo`;o0000E?ooool001Gooooo0_l0002eooooo`;o0000D_ooool001Gooooo00?o0000oooo
ooooool0]_ooool3o`0004oooooo000Eooooo`03o`000?oooooooooo0;Wooooo0_l0001=ooooo`00
5Oooool00ol0003oooooooooo`2kooooo`?o0000B_ooool001Gooooo00?o0000ooooooooool0__oo
ool3o`0004Oooooo0002ooooo`;o00001?ooool00ol0003oooooooooo`02ooooo`?o00001Oooool0
0ol0003oooooooooo`31ooooo`?o0000A?ooool00005ooooool0003oooooooooool000001oooool0
1Ol0003ooooooooooooooooo000000Cooooo00?o0000ooooooooool0a?ooool2o`0004;ooooo0000
1Ooooooo0000oooooooooooo000000Oooooo00Go0000ooooooooooooooooo`000004ooooo`03o`00
0?oooooooooo0<Kooooo0ol0000oooooo`0000Goooooo`000?ooooooooooo`000008ooooo`?o0000
1Oooool3o`000<Wooooo0ol0000looooo`0000Goooooo`000?ooooooooooo`000007ooooo`05o`00
0?ooooooooooooooool000001?ooool00ol0003oooooooooo`3<ooooo`?o0000>Oooool00005oooo
ool0003oooooooooool000001oooool01Ol0003ooooooooooooooooo000000Cooooo00?o0000oooo
ooooool0coooool5o`0003Cooooo0002ooooo`;o00002Oooool3o`0000Gooooo00?o0000oooooooo
ool0e?ooool4o`00033ooooo000Eooooo`03o`000?oooooooooo0=Sooooo1Ol0000[ooooo`005Ooo
ool00ol0003oooooooooo`3Mooooo`Co00009oooool001Gooooo00?o0000ooooooooool0hOooool4
o`0002?ooooo000Eooooo`03o`000?oooooooooo0>Gooooo1ol0000Looooo`005Oooool2o`000>go
oooo1_l0000Fooooo`005Oooool00ol0003oooooooooo`3booooo`Go00004Oooool001Gooooo00?o
0000ooooooooool0moooool4o`0000gooooo000Eooooo`03o`000?oooooooooo0?_ooooo1?l00009
ooooo`005Oooool00ol0003oooooooooo`3oooooo`;o00001oooool001Gooooo00?o0000oooooooo
ool0ooooool9ooooo`005Oooool00ol0003oooooooooo`3oooooo`Wooooo000Eooooo`03o`000?oo
oooooooo0?oooooo2Oooool001Gooooo0_l0003oooooo`[ooooo000Eooooo`03o`000?oooooooooo
0?oooooo2Oooool001Gooooo00?o0000ooooooooool0ooooool9ooooo`005Oooool00ol0003ooooo
ooooo`3oooooo`Wooooo000Eooooo`03o`000?oooooooooo0?oooooo2Oooool001Gooooo00?o0000
ooooooooool0ooooool9ooooo`005Oooool00ol0003oooooooooo`3oooooo`Wooooo000Eooooo`03
o`000?oooooooooo0?oooooo2Oooool001Gooooo0_l0003oooooo`[ooooo000Eooooo`03o`000?oo
oooooooo0?oooooo2Oooool001Gooooo00?o0000ooooooooool0ooooool9ooooo`005Oooool00ol0
003oooooooooo`3oooooo`Wooooo000Eooooo`03o`000?oooooooooo0?oooooo2Oooool000gooooo
0ol00005ooooo`03o`000?oooooooooo0?oooooo2Oooool000kooooo00?o0000ooooooooool01?oo
ool00ol0003oooooooooo`3oooooo`Wooooo000>ooooo`03o`000?oooooooooo00Cooooo00?o0000
ooooooooool0ooooool9ooooo`003_ooool00ol0003oooooooooo`04ooooo`?o0000ooooool9oooo
o`003_ooool00ol0003oooooooooo`3ooooooa3ooooo000=ooooo`;o0000oooooolBooooo`003_oo
ool00ol0003oooooooooo`3ooooooa3ooooo003oooooob7ooooo0000\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-2.49048, -0.0764114, \
0.115739, 0.00624232}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 0.0333333 0 0.618034 [
[.16667 -0.0125 -3 -9 ]
[.16667 -0.0125 3 0 ]
[.33333 -0.0125 -6 -9 ]
[.33333 -0.0125 6 0 ]
[.5 -0.0125 -6 -9 ]
[.5 -0.0125 6 0 ]
[.66667 -0.0125 -6 -9 ]
[.66667 -0.0125 6 0 ]
[.83333 -0.0125 -6 -9 ]
[.83333 -0.0125 6 0 ]
[1 -0.0125 -6 -9 ]
[1 -0.0125 6 0 ]
[-0.0125 .12361 -18 -4.5 ]
[-0.0125 .12361 0 4.5 ]
[-0.0125 .24721 -18 -4.5 ]
[-0.0125 .24721 0 4.5 ]
[-0.0125 .37082 -18 -4.5 ]
[-0.0125 .37082 0 4.5 ]
[-0.0125 .49443 -18 -4.5 ]
[-0.0125 .49443 0 4.5 ]
[-0.0125 .61803 -6 -4.5 ]
[-0.0125 .61803 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.16667 0 m
.16667 .00625 L
s
[(5)] .16667 -0.0125 0 1 Mshowa
.33333 0 m
.33333 .00625 L
s
[(10)] .33333 -0.0125 0 1 Mshowa
.5 0 m
.5 .00625 L
s
[(15)] .5 -0.0125 0 1 Mshowa
.66667 0 m
.66667 .00625 L
s
[(20)] .66667 -0.0125 0 1 Mshowa
.83333 0 m
.83333 .00625 L
s
[(25)] .83333 -0.0125 0 1 Mshowa
1 0 m
1 .00625 L
s
[(30)] 1 -0.0125 0 1 Mshowa
.125 Mabswid
.03333 0 m
.03333 .00375 L
s
.06667 0 m
.06667 .00375 L
s
.1 0 m
.1 .00375 L
s
.13333 0 m
.13333 .00375 L
s
.2 0 m
.2 .00375 L
s
.23333 0 m
.23333 .00375 L
s
.26667 0 m
.26667 .00375 L
s
.3 0 m
.3 .00375 L
s
.36667 0 m
.36667 .00375 L
s
.4 0 m
.4 .00375 L
s
.43333 0 m
.43333 .00375 L
s
.46667 0 m
.46667 .00375 L
s
.53333 0 m
.53333 .00375 L
s
.56667 0 m
.56667 .00375 L
s
.6 0 m
.6 .00375 L
s
.63333 0 m
.63333 .00375 L
s
.7 0 m
.7 .00375 L
s
.73333 0 m
.73333 .00375 L
s
.76667 0 m
.76667 .00375 L
s
.8 0 m
.8 .00375 L
s
.86667 0 m
.86667 .00375 L
s
.9 0 m
.9 .00375 L
s
.93333 0 m
.93333 .00375 L
s
.96667 0 m
.96667 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .12361 m
.00625 .12361 L
s
[(0.2)] -0.0125 .12361 1 0 Mshowa
0 .24721 m
.00625 .24721 L
s
[(0.4)] -0.0125 .24721 1 0 Mshowa
0 .37082 m
.00625 .37082 L
s
[(0.6)] -0.0125 .37082 1 0 Mshowa
0 .49443 m
.00625 .49443 L
s
[(0.8)] -0.0125 .49443 1 0 Mshowa
0 .61803 m
.00625 .61803 L
s
[(1)] -0.0125 .61803 1 0 Mshowa
.125 Mabswid
0 .0309 m
.00375 .0309 L
s
0 .0618 m
.00375 .0618 L
s
0 .09271 m
.00375 .09271 L
s
0 .15451 m
.00375 .15451 L
s
0 .18541 m
.00375 .18541 L
s
0 .21631 m
.00375 .21631 L
s
0 .27812 m
.00375 .27812 L
s
0 .30902 m
.00375 .30902 L
s
0 .33992 m
.00375 .33992 L
s
0 .40172 m
.00375 .40172 L
s
0 .43262 m
.00375 .43262 L
s
0 .46353 m
.00375 .46353 L
s
0 .52533 m
.00375 .52533 L
s
0 .55623 m
.00375 .55623 L
s
0 .58713 m
.00375 .58713 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.03333 .07837 m
.06667 .08703 L
.1 .09244 L
.13333 .09783 L
.16667 .10403 L
.2 .11143 L
.23333 .12033 L
.26667 .131 L
.3 .14374 L
.33333 .15892 L
.36667 .17694 L
.4 .19827 L
.43333 .2235 L
.46667 .25329 L
.5 .28838 L
.53333 .32965 L
.56667 .36475 L
.6 .39453 L
.63333 .41976 L
.66667 .4411 L
.7 .45911 L
.73333 .47429 L
.76667 .48704 L
.8 .49771 L
.83333 .5066 L
.86667 .514 L
.9 .5202 L
.93333 .52559 L
.96667 .53101 L
1 .53966 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[6]:=",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/B000`400?l00000o`00003ooooooolQ
ooooo`00?_ooool3o`0002Gooooo0ol00004ooooo`;o00008oooool3o`0000?ooooo0ol0000Qoooo
o`Go00000oooool2o`00027ooooo1Ol00002ooooo`?o00008_ooool3o`0000Cooooo0_l00004oooo
o`00?Oooool01Ol0003ooooooooooooooooo000002Gooooo00?o0000ooooooooool00_ooool01?l0
003oooooooooool0000Sooooo`05o`000?ooooooooooooooool000000oooool00ol0003ooooooooo
o`0Oooooo`04o`000?ooooooooooo`0000;ooooo00Co0000oooooooooooo00008Oooool01_l0003o
ooooooooool0003oooooo`0000?ooooo00?o0000ooooooooool07_ooool01Ol0003ooooooooooooo
oooo000000;ooooo00Co0000oooooooooooo00000oooool0047ooooo00?o0000ooooooooool08ooo
ool00ol0003oooooooooo`02ooooo`04o`000?ooooooooooo`0002?ooooo00?o0000ooooooooool0
1Oooool00ol0003oooooooooo`0Pooooo`03o`000?oooooooooo00;ooooo00Co0000oooooooooooo
00008_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo02;ooooo00Co0000oooooooo
oooo00000_ooool00ol0003oooooooooo`01ooooo`00@Oooool00ol0003oooooooooo`0Sooooo`03
o`000?oooooooooo00;ooooo00Co0000oooooooooooo00008oooool00ol0003oooooooooo`05oooo
o`03o`000?oooooooooo027ooooo00Go0000ooooooooooooooooo`000002ooooo`03o`000?oooooo
oooo027ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`0Pooooo`;o00000oooool0
1?l0003oooooooooool00003ooooo`00?Oooool4o`0002Kooooo00?o0000ooooooooool00_ooool0
1?l0003oooooooooool0000Sooooo`04o`000?ooooooooooooooo`Co00008Oooool01Ol0003ooooo
oooooooooooo000000;ooooo00Co0000oooooooooooo00008?ooool01_l0003ooooooooooooooooo
0000ooooo`Co00009Oooool01?l0003oooooooooool00002ooooo`03o`000?oooooooooo007ooooo
000mooooo`03o`000?oooooooooo02Kooooo0_l00004ooooo`04o`000?ooooooooooo`0002;ooooo
0_l00003ooooo`03o`000?oooooooooo02;ooooo00Go0000ooooooooooooooooo`000002ooooo`04
o`000?ooooooooooo`00023ooooo00Oo0000ooooooooooooooooo`000?oooooo000002Cooooo00Go
0000ooooooooooooooooo`000002ooooo`04o`000?ooooooooooo`0000?ooooo000mooooo`Go0000
9Oooool00ol0003oooooooooo`03ooooo`;o00009?ooool01?l0003oooooooooooooool5o`00027o
oooo0ol00004ooooo`;o00008_ooool3o`0000;ooooo1Ol0000Qooooo`?o00001?ooool2o`0000Co
oooo003oooooob7ooooo003oooooob7ooooo003oooooob7ooooo003oooooob7ooooo000Eoooooooo
00001Ol00007ooooo`005Oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Gooooo
00?o0000ooooooooool01_ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Gooooo
00?o0000ooooooooool01_ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Gooooo
00?o0000ooooooooool01_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Kooooo
00?o0000ooooooooool01_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Kooooo
00?o0000ooooooooool01_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Kooooo
00?o0000ooooooooool01_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Kooooo
00?o0000ooooooooool01Oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Kooooo
00?o0000ooooooooool01Oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Kooooo
00?o0000ooooooooool01Oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Kooooo
00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`005Oooool00ol0003ooooooooo
o`3oooooo`Wooooo000Eooooo`03o`000?oooooooooo0?oooooo2Oooool001Gooooo00?o0000oooo
ooooool0ooooool9ooooo`005Oooool00ol0003oooooooooo`3oooooo`Wooooo000Eooooo`03o`00
0?oooooooooo0?oooooo2Oooool001Gooooo00?o0000ooooooooool0ooooool9ooooo`005Oooool2
o`000?oooooo2_ooool001Gooooo00?o0000ooooooooool0ooooool9ooooo`005Oooool00ol0003o
ooooooooo`3oooooo`Wooooo000Eooooo`03o`000?oooooooooo0?oooooo2Oooool001Gooooo00?o
0000ooooooooool0ooooool9ooooo`005Oooool00ol0003oooooooooo`3oooooo`Wooooo000Eoooo
o`03o`000?oooooooooo0?oooooo2Oooool001Gooooo00?o0000ooooooooool0ooooool9ooooo`00
5Oooool2o`000?oooooo2_ooool001Gooooo00?o0000ooooooooool0ooooool9ooooo`005Oooool0
0ol0003oooooooooo`3oooooo`Wooooo000Eooooo`03o`000?oooooooooo0?oooooo2Oooool001Go
oooo00?o0000ooooooooool01_ooool3o`000?oooooo000Eooooo`03o`000?oooooooooo00Wooooo
1?l0003kooooo`005Oooool00ol0003oooooooooo`0=ooooo`Co0000moooool001Gooooo00?o0000
ooooooooool04Oooool5o`000?;ooooo000Eooooo`;o00005oooool7o`000>_ooooo000Eooooo`03
o`000?oooooooooo01gooooo1_l0003Uooooo`005Oooool00ol0003oooooooooo`0Sooooo`Co0000
hOooool001Gooooo00?o0000ooooooooool09oooool4o`000=gooooo000Eooooo`03o`000?oooooo
oooo02_ooooo1Ol0003Hooooo`000_ooool2o`0000Cooooo00Co0000oooooooooooooooo1Ol00004
ooooo`03o`000?oooooooooo033ooooo1?l0003Dooooo`0000Goooooo`000?ooooooooooo`000008
ooooo`04o`000?ooooooooooo`0000Cooooo00?o0000ooooooooool0=?ooool5o`000<oooooo0000
1Ooooooo0000oooooooooooo000000Wooooo00?o0000ooooooooool01?ooool00ol0003ooooooooo
o`0iooooo`?o0000c?ooool00005ooooool0003oooooooooool000002_ooool00ol0003ooooooooo
o`03ooooo`?o0000??ooool3o`000<Wooooo00001Ooooooo0000oooooooooooo000000Oooooo00Go
0000ooooooooooooooooo`000004ooooo`03o`000?oooooooooo03oooooo0ol00036ooooo`0000Go
ooooo`000?ooooooooooo`000007ooooo`05o`000?ooooooooooooooool000001?ooool00ol0003o
ooooooooo`12ooooo`?o0000`oooool000;ooooo0_l00009ooooo`?o00001Oooool00ol0003ooooo
ooooo`15ooooo`?o0000`?ooool001Gooooo00?o0000ooooooooool0B?ooool3o`000;gooooo000E
ooooo`03o`000?oooooooooo04_ooooo0_l0002kooooo`005Oooool00ol0003oooooooooo`1=oooo
o`;o0000^Oooool001Gooooo00?o0000ooooooooool0Coooool2o`000;Oooooo000Eooooo`;o0000
D_ooool2o`000;Gooooo000Eooooo`03o`000?oooooooooo05?ooooo0_l0002cooooo`005Oooool0
0ol0003oooooooooo`1Eooooo`;o0000/Oooool001Gooooo00?o0000ooooooooool0Eoooool2o`00
0:oooooo000Eooooo`03o`000?oooooooooo05Wooooo00?o0000ooooooooool0[?ooool001Gooooo
00?o0000ooooooooool0F_ooool2o`000:cooooo000Eooooo`03o`000?oooooooooo05cooooo0_l0
002Zooooo`005Oooool00ol0003oooooooooo`1Nooooo`;o0000Z?ooool001Gooooo0_l0001Qoooo
o`;o0000Y_ooool001Gooooo00?o0000ooooooooool0H_ooool00ol0003oooooooooo`2Sooooo`00
5Oooool00ol0003oooooooooo`1Sooooo`;o0000Xoooool001Gooooo00?o0000ooooooooool0IOoo
ool2o`000:7ooooo000Eooooo`03o`000?oooooooooo06Oooooo00?o0000ooooooooool0W_ooool0
01Gooooo00?o0000ooooooooool0J?ooool00ol0003oooooooooo`2Mooooo`005Oooool00ol0003o
ooooooooo`1Yooooo`03o`000?oooooooooo09cooooo000Eooooo`03o`000?oooooooooo06[ooooo
00?o0000ooooooooool0Voooool001Gooooo0_l0001/ooooo`03o`000?oooooooooo09[ooooo000E
ooooo`03o`000?oooooooooo06cooooo00?o0000ooooooooool0VOooool001Gooooo00?o0000oooo
ooooool0KOooool2o`0009Wooooo000Eooooo`03o`000?oooooooooo06oooooo00?o0000oooooooo
ool0U_ooool001Gooooo00?o0000ooooooooool0L?ooool00ol0003oooooooooo`2Eooooo`000_oo
ool2o`0000Cooooo00?o0000ooooooooool00oooool3o`0000Cooooo00?o0000ooooooooool0LOoo
ool2o`0009Gooooo00001Ooooooo0000oooooooooooo000000[ooooo00?o0000ooooooooool00ooo
ool00ol0003oooooooooo`1cooooo`03o`000?oooooooooo09;ooooo00001Ooooooo0000oooooooo
oooo000000Oooooo1Ol00004ooooo`03o`000?oooooooooo07Cooooo00?o0000ooooooooool0TOoo
ool00005ooooool0003oooooooooool000001oooool01?l0003oooooooooool00005ooooo`?o0000
MOooool00ol0003oooooooooo`2@ooooo`0000Goooooo`000?ooooooooooo`000008ooooo`03o`00
0?oooooo000000Gooooo00?o0000ooooooooool0M_ooool00ol0003oooooooooo`2?ooooo`0000Go
ooooo`000?ooooooooooo`000009ooooo`;o00001Oooool00ol0003oooooooooo`1fooooo`03o`00
0?oooooooooo08oooooo0002ooooo`;o00002oooool00ol0003oooooooooo`03ooooo`03o`000?oo
oooooooo07Oooooo00?o0000ooooooooool0S_ooool001Gooooo00?o0000ooooooooool0N?ooool0
0ol0003oooooooooo`2=ooooo`005Oooool00ol0003oooooooooo`1iooooo`03o`000?oooooooooo
08cooooo000Eooooo`03o`000?oooooooooo07[ooooo00?o0000ooooooooool0Roooool001Gooooo
00?o0000ooooooooool0Noooool00ol0003oooooooooo`2:ooooo`005Oooool2o`0007gooooo00?o
0000ooooooooool0ROooool001Gooooo00?o0000ooooooooool0OOooool00ol0003oooooooooo`28
ooooo`005Oooool00ol0003oooooooooo`1nooooo`03o`000?oooooooooo08Oooooo000Eooooo`03
o`000?oooooooooo07oooooo00?o0000ooooooooool0Q_ooool001Gooooo00?o0000ooooooooool0
Ooooool00ol0003oooooooooo`26ooooo`005Oooool00ol0003oooooooooo`20ooooo`03o`000?oo
oooooooo08Gooooo000Eooooo`03o`000?oooooooooo087ooooo00?o0000ooooooooool0Q?ooool0
01Gooooo00?o0000ooooooooool0P_ooool00ol0003oooooooooo`23ooooo`005Oooool2o`0008Co
oooo00?o0000ooooooooool0P_ooool001Gooooo00?o0000ooooooooool0Poooool00ol0003ooooo
ooooo`22ooooo`005Oooool00ol0003oooooooooo`24ooooo`03o`000?oooooooooo087ooooo000E
ooooo`03o`000?oooooooooo08Gooooo00?o0000ooooooooool0P?ooool001Gooooo00?o0000oooo
ooooool0Q_ooool00ol0003oooooooooo`1oooooo`005Oooool00ol0003oooooooooo`27ooooo`03
o`000?oooooooooo07kooooo000Eooooo`03o`000?oooooooooo08Sooooo00?o0000ooooooooool0
OOooool001Gooooo00?o0000ooooooooool0ROooool00ol0003oooooooooo`1looooo`005Oooool2
o`0008_ooooo00?o0000ooooooooool0Noooool001Gooooo00?o0000ooooooooool0Roooool00ol0
003oooooooooo`1jooooo`005Oooool00ol0003oooooooooo`2<ooooo`03o`000?oooooooooo07Wo
oooo000Eooooo`03o`000?oooooooooo08gooooo00?o0000ooooooooool0N?ooool001Gooooo00?o
0000ooooooooool0S_ooool00ol0003oooooooooo`1gooooo`000_ooool2o`0000Cooooo00?o0000
ooooooooool00_ooool3o`0000Gooooo00?o0000ooooooooool0Soooool00ol0003oooooooooo`1f
ooooo`0000Goooooo`000?ooooooooooo`000007ooooo`05o`000?ooooooooooooooool000001?oo
ool00ol0003oooooooooo`2@ooooo`;o0000M_ooool00005ooooool0003oooooooooool000001ooo
ool01Ol0003ooooooooooooooooo000000Cooooo00?o0000ooooooooool0T_ooool00ol0003ooooo
ooooo`1cooooo`0000Goooooo`000?ooooooooooo`000007ooooo`Co00001Oooool3o`0009?ooooo
00?o0000ooooooooool0L_ooool00005ooooool0003oooooooooool000001oooool00ol0003ooooo
ooooo`06ooooo`03o`000?oooooooooo09Cooooo00?o0000ooooooooool0LOooool00005ooooool0
003oooooooooool000002?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo09Gooooo
00?o0000ooooooooool0L?ooool000;ooooo0_l0000:ooooo`;o00001Oooool00ol0003ooooooooo
o`2Fooooo`03o`000?oooooooooo06oooooo000Eooooo`03o`000?oooooooooo09Oooooo00?o0000
ooooooooool0K_ooool001Gooooo00?o0000ooooooooool0V?ooool00ol0003oooooooooo`1]oooo
o`005Oooool00ol0003oooooooooo`2Iooooo`;o0000KOooool001Gooooo00?o0000ooooooooool0
Voooool00ol0003oooooooooo`1Zooooo`005Oooool2o`0009gooooo00?o0000ooooooooool0JOoo
ool001Gooooo00?o0000ooooooooool0WOooool00ol0003oooooooooo`1Xooooo`005Oooool00ol0
003oooooooooo`2Nooooo`03o`000?oooooooooo06Oooooo000Eooooo`03o`000?oooooooooo09oo
oooo00?o0000ooooooooool0I_ooool001Gooooo00?o0000ooooooooool0X?ooool00ol0003ooooo
ooooo`1Uooooo`005Oooool00ol0003oooooooooo`2Qooooo`;o0000IOooool001Gooooo00?o0000
ooooooooool0Xoooool2o`0006?ooooo000Eooooo`03o`000?oooooooooo0:Gooooo0_l0001Qoooo
o`005Oooool2o`000:Sooooo00?o0000ooooooooool0G_ooool001Gooooo00?o0000ooooooooool0
Z?ooool2o`0005kooooo000Eooooo`03o`000?oooooooooo0:[ooooo0_l0001Looooo`005Oooool0
0ol0003oooooooooo`2/ooooo`03o`000?oooooooooo05Wooooo000Eooooo`03o`000?oooooooooo
0:gooooo0_l0001Iooooo`005Oooool00ol0003oooooooooo`2_ooooo`;o0000Eoooool001Gooooo
00?o0000ooooooooool0/Oooool00ol0003oooooooooo`1Dooooo`005Oooool00ol0003ooooooooo
o`2booooo`;o0000E?ooool001Gooooo0_l0002eooooo`;o0000D_ooool001Gooooo00?o0000oooo
ooooool0]_ooool3o`0004oooooo000Eooooo`03o`000?oooooooooo0;Wooooo0_l0001=ooooo`00
5Oooool00ol0003oooooooooo`2kooooo`?o0000B_ooool001Gooooo00?o0000ooooooooool0__oo
ool3o`0004Oooooo0002ooooo`;o00001?ooool00ol0003oooooooooo`02ooooo`?o00001Oooool0
0ol0003oooooooooo`31ooooo`?o0000A?ooool00005ooooool0003oooooooooool000001oooool0
1Ol0003ooooooooooooooooo000000Cooooo00?o0000ooooooooool0a?ooool2o`0004;ooooo0000
1Ooooooo0000oooooooooooo000000Oooooo00Go0000ooooooooooooooooo`000004ooooo`03o`00
0?oooooooooo0<Kooooo0ol0000oooooo`0000Goooooo`000?ooooooooooo`000008ooooo`?o0000
1Oooool3o`000<Wooooo0ol0000looooo`0000Goooooo`000?ooooooooooo`000007ooooo`05o`00
0?ooooooooooooooool000001?ooool00ol0003oooooooooo`3<ooooo`?o0000>Oooool00005oooo
ool0003oooooooooool000001oooool01Ol0003ooooooooooooooooo000000Cooooo00?o0000oooo
ooooool0coooool5o`0003Cooooo0002ooooo`;o00002Oooool3o`0000Gooooo00?o0000oooooooo
ool0e?ooool4o`00033ooooo000Eooooo`03o`000?oooooooooo0=Sooooo1Ol0000[ooooo`005Ooo
ool00ol0003oooooooooo`3Mooooo`Co00009oooool001Gooooo00?o0000ooooooooool0hOooool4
o`0002?ooooo000Eooooo`03o`000?oooooooooo0>Gooooo1ol0000Looooo`005Oooool2o`000>go
oooo2Ol0000Cooooo`005Oooool00ol0003oooooooooo`3eooooo`Go00003_ooool001Gooooo00?o
0000ooooooooool0n_ooool3o`0000_ooooo000Eooooo`03o`000?oooooooooo0?gooooo0ol00008
ooooo`005Oooool00ol0003oooooooooo`3oooooo`7ooooo00?o0000ooooooooool01Oooool001Go
oooo00?o0000ooooooooool0ooooool9ooooo`005Oooool00ol0003oooooooooo`3oooooo`Wooooo
000Eooooo`03o`000?oooooooooo0?oooooo2Oooool001Gooooo0_l0003oooooo`[ooooo000Eoooo
o`03o`000?oooooooooo0?oooooo2Oooool001Gooooo00?o0000ooooooooool0ooooool9ooooo`00
5Oooool00ol0003oooooooooo`3oooooo`Wooooo000Eooooo`03o`000?oooooooooo0?oooooo2Ooo
ool001Gooooo00?o0000ooooooooool0ooooool9ooooo`005Oooool00ol0003oooooooooo`3ooooo
o`Wooooo000Eooooo`03o`000?oooooooooo0?oooooo2Oooool001Gooooo0_l0003oooooo`[ooooo
000Eooooo`03o`000?oooooooooo0?oooooo2Oooool001Gooooo00?o0000ooooooooool0ooooool9
ooooo`005Oooool00ol0003oooooooooo`3oooooo`Wooooo000Eooooo`03o`000?oooooooooo0?oo
oooo2Oooool000gooooo0ol00005ooooo`03o`000?oooooooooo0?oooooo2Oooool000kooooo00?o
0000ooooooooool01?ooool00ol0003oooooooooo`3oooooo`Wooooo000>ooooo`03o`000?oooooo
oooo00Cooooo00?o0000ooooooooool0ooooool9ooooo`003_ooool00ol0003oooooooooo`04oooo
o`?o0000ooooool9ooooo`003_ooool00ol0003oooooooooo`3ooooooa3ooooo000=ooooo`;o0000
oooooolBooooo`003_ooool00ol0003oooooooooo`3ooooooa3ooooo003oooooob7ooooo0000\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-2.49048, -0.0764114, \
0.115739, 0.00624232}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 0.0333333 0 0.618034 [
[.16667 -0.0125 -3 -9 ]
[.16667 -0.0125 3 0 ]
[.33333 -0.0125 -6 -9 ]
[.33333 -0.0125 6 0 ]
[.5 -0.0125 -6 -9 ]
[.5 -0.0125 6 0 ]
[.66667 -0.0125 -6 -9 ]
[.66667 -0.0125 6 0 ]
[.83333 -0.0125 -6 -9 ]
[.83333 -0.0125 6 0 ]
[1 -0.0125 -6 -9 ]
[1 -0.0125 6 0 ]
[-0.0125 .12361 -18 -4.5 ]
[-0.0125 .12361 0 4.5 ]
[-0.0125 .24721 -18 -4.5 ]
[-0.0125 .24721 0 4.5 ]
[-0.0125 .37082 -18 -4.5 ]
[-0.0125 .37082 0 4.5 ]
[-0.0125 .49443 -18 -4.5 ]
[-0.0125 .49443 0 4.5 ]
[-0.0125 .61803 -6 -4.5 ]
[-0.0125 .61803 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.16667 0 m
.16667 .00625 L
s
[(5)] .16667 -0.0125 0 1 Mshowa
.33333 0 m
.33333 .00625 L
s
[(10)] .33333 -0.0125 0 1 Mshowa
.5 0 m
.5 .00625 L
s
[(15)] .5 -0.0125 0 1 Mshowa
.66667 0 m
.66667 .00625 L
s
[(20)] .66667 -0.0125 0 1 Mshowa
.83333 0 m
.83333 .00625 L
s
[(25)] .83333 -0.0125 0 1 Mshowa
1 0 m
1 .00625 L
s
[(30)] 1 -0.0125 0 1 Mshowa
.125 Mabswid
.03333 0 m
.03333 .00375 L
s
.06667 0 m
.06667 .00375 L
s
.1 0 m
.1 .00375 L
s
.13333 0 m
.13333 .00375 L
s
.2 0 m
.2 .00375 L
s
.23333 0 m
.23333 .00375 L
s
.26667 0 m
.26667 .00375 L
s
.3 0 m
.3 .00375 L
s
.36667 0 m
.36667 .00375 L
s
.4 0 m
.4 .00375 L
s
.43333 0 m
.43333 .00375 L
s
.46667 0 m
.46667 .00375 L
s
.53333 0 m
.53333 .00375 L
s
.56667 0 m
.56667 .00375 L
s
.6 0 m
.6 .00375 L
s
.63333 0 m
.63333 .00375 L
s
.7 0 m
.7 .00375 L
s
.73333 0 m
.73333 .00375 L
s
.76667 0 m
.76667 .00375 L
s
.8 0 m
.8 .00375 L
s
.86667 0 m
.86667 .00375 L
s
.9 0 m
.9 .00375 L
s
.93333 0 m
.93333 .00375 L
s
.96667 0 m
.96667 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .12361 m
.00625 .12361 L
s
[(0.2)] -0.0125 .12361 1 0 Mshowa
0 .24721 m
.00625 .24721 L
s
[(0.4)] -0.0125 .24721 1 0 Mshowa
0 .37082 m
.00625 .37082 L
s
[(0.6)] -0.0125 .37082 1 0 Mshowa
0 .49443 m
.00625 .49443 L
s
[(0.8)] -0.0125 .49443 1 0 Mshowa
0 .61803 m
.00625 .61803 L
s
[(1)] -0.0125 .61803 1 0 Mshowa
.125 Mabswid
0 .0309 m
.00375 .0309 L
s
0 .0618 m
.00375 .0618 L
s
0 .09271 m
.00375 .09271 L
s
0 .15451 m
.00375 .15451 L
s
0 .18541 m
.00375 .18541 L
s
0 .21631 m
.00375 .21631 L
s
0 .27812 m
.00375 .27812 L
s
0 .30902 m
.00375 .30902 L
s
0 .33992 m
.00375 .33992 L
s
0 .40172 m
.00375 .40172 L
s
0 .43262 m
.00375 .43262 L
s
0 .46353 m
.00375 .46353 L
s
0 .52533 m
.00375 .52533 L
s
0 .55623 m
.00375 .55623 L
s
0 .58713 m
.00375 .58713 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.03333 .07834 m
.06667 .08732 L
.1 .09286 L
.13333 .0983 L
.16667 .10453 L
.2 .11193 L
.23333 .12081 L
.26667 .13146 L
.3 .14417 L
.33333 .1593 L
.36667 .17726 L
.4 .19854 L
.43333 .2237 L
.46667 .25341 L
.5 .28843 L
.53333 .32961 L
.56667 .36463 L
.6 .39434 L
.63333 .4195 L
.66667 .44077 L
.7 .45873 L
.73333 .47387 L
.76667 .48658 L
.8 .49722 L
.83333 .5061 L
.86667 .51351 L
.9 .51973 L
.93333 .52518 L
.96667 .53072 L
1 .53969 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[6]:=",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/B000`400?l00000o`00003ooooooolQ
ooooo`00?_ooool3o`0002Gooooo0ol00004ooooo`;o00008oooool3o`0000?ooooo0ol0000Qoooo
o`Go00000oooool2o`00027ooooo1Ol00002ooooo`?o00008_ooool3o`0000Cooooo0_l00004oooo
o`00?Oooool01Ol0003ooooooooooooooooo000002Gooooo00?o0000ooooooooool00_ooool01?l0
003oooooooooool0000Sooooo`05o`000?ooooooooooooooool000000oooool00ol0003ooooooooo
o`0Oooooo`04o`000?ooooooooooo`0000;ooooo00Co0000oooooooooooo00008Oooool01_l0003o
ooooooooool0003oooooo`0000?ooooo00?o0000ooooooooool07_ooool01Ol0003ooooooooooooo
oooo000000;ooooo00Co0000oooooooooooo00000oooool0047ooooo00?o0000ooooooooool08ooo
ool00ol0003oooooooooo`02ooooo`04o`000?ooooooooooo`0002?ooooo00?o0000ooooooooool0
1Oooool00ol0003oooooooooo`0Pooooo`03o`000?oooooooooo00;ooooo00Co0000oooooooooooo
00008_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo02;ooooo00Co0000oooooooo
oooo00000_ooool00ol0003oooooooooo`01ooooo`00@Oooool00ol0003oooooooooo`0Sooooo`03
o`000?oooooooooo00;ooooo00Co0000oooooooooooo00008oooool00ol0003oooooooooo`05oooo
o`03o`000?oooooooooo027ooooo00Go0000ooooooooooooooooo`000002ooooo`03o`000?oooooo
oooo027ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`0Pooooo`;o00000oooool0
1?l0003oooooooooool00003ooooo`00?Oooool4o`0002Kooooo00?o0000ooooooooool00_ooool0
1?l0003oooooooooool0000Sooooo`04o`000?ooooooooooooooo`Co00008Oooool01Ol0003ooooo
oooooooooooo000000;ooooo00Co0000oooooooooooo00008?ooool01_l0003ooooooooooooooooo
0000ooooo`Co00009Oooool01?l0003oooooooooool00002ooooo`03o`000?oooooooooo007ooooo
000mooooo`03o`000?oooooooooo02Kooooo0_l00004ooooo`04o`000?ooooooooooo`0002;ooooo
0_l00003ooooo`03o`000?oooooooooo02;ooooo00Go0000ooooooooooooooooo`000002ooooo`04
o`000?ooooooooooo`00023ooooo00Oo0000ooooooooooooooooo`000?oooooo000002Cooooo00Go
0000ooooooooooooooooo`000002ooooo`04o`000?ooooooooooo`0000?ooooo000mooooo`Go0000
9Oooool00ol0003oooooooooo`03ooooo`;o00009?ooool01?l0003oooooooooooooool5o`00027o
oooo0ol00004ooooo`;o00008_ooool3o`0000;ooooo1Ol0000Qooooo`?o00001?ooool2o`0000Co
oooo003oooooob7ooooo003oooooob7ooooo003oooooob7ooooo003oooooob7ooooo000Eoooooooo
00001Ol00007ooooo`005Oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Gooooo
00?o0000ooooooooool01_ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Gooooo
00?o0000ooooooooool01_ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Gooooo
00?o0000ooooooooool01_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Kooooo
00?o0000ooooooooool01_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Kooooo
00?o0000ooooooooool01_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Kooooo
00?o0000ooooooooool01_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Kooooo
00?o0000ooooooooool01Oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Kooooo
00?o0000ooooooooool01Oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Kooooo
00?o0000ooooooooool01Oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Kooooo
00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`005Oooool00ol0003ooooooooo
o`3oooooo`Wooooo000Eooooo`03o`000?oooooooooo0?oooooo2Oooool001Gooooo00?o0000oooo
ooooool0ooooool9ooooo`005Oooool00ol0003oooooooooo`3oooooo`Wooooo000Eooooo`03o`00
0?oooooooooo0?oooooo2Oooool001Gooooo00?o0000ooooooooool0ooooool9ooooo`005Oooool2
o`000?oooooo2_ooool001Gooooo00?o0000ooooooooool0ooooool9ooooo`005Oooool00ol0003o
ooooooooo`3oooooo`Wooooo000Eooooo`03o`000?oooooooooo0?oooooo2Oooool001Gooooo00?o
0000ooooooooool0ooooool9ooooo`005Oooool00ol0003oooooooooo`3oooooo`Wooooo000Eoooo
o`03o`000?oooooooooo0?oooooo2Oooool001Gooooo00?o0000ooooooooool0ooooool9ooooo`00
5Oooool2o`000?oooooo2_ooool001Gooooo00?o0000ooooooooool0ooooool9ooooo`005Oooool0
0ol0003oooooooooo`3oooooo`Wooooo000Eooooo`03o`000?oooooooooo0?oooooo2Oooool001Go
oooo00?o0000ooooooooool01_ooool3o`000?oooooo000Eooooo`03o`000?oooooooooo00Wooooo
1?l0003kooooo`005Oooool00ol0003oooooooooo`0=ooooo`Co0000moooool001Gooooo00?o0000
ooooooooool04Oooool5o`000?;ooooo000Eooooo`;o00005oooool7o`000>_ooooo000Eooooo`03
o`000?oooooooooo01gooooo1_l0003Uooooo`005Oooool00ol0003oooooooooo`0Sooooo`Co0000
hOooool001Gooooo00?o0000ooooooooool09oooool4o`000=gooooo000Eooooo`03o`000?oooooo
oooo02_ooooo1Ol0003Hooooo`000_ooool2o`0000Cooooo00Co0000oooooooooooooooo1Ol00004
ooooo`03o`000?oooooooooo033ooooo1?l0003Dooooo`0000Goooooo`000?ooooooooooo`000008
ooooo`04o`000?ooooooooooo`0000Cooooo00?o0000ooooooooool0=?ooool5o`000<oooooo0000
1Ooooooo0000oooooooooooo000000Wooooo00?o0000ooooooooool01?ooool00ol0003ooooooooo
o`0iooooo`?o0000c?ooool00005ooooool0003oooooooooool000002_ooool00ol0003ooooooooo
o`03ooooo`?o0000??ooool3o`000<Wooooo00001Ooooooo0000oooooooooooo000000Oooooo00Go
0000ooooooooooooooooo`000004ooooo`03o`000?oooooooooo03oooooo0ol00036ooooo`0000Go
ooooo`000?ooooooooooo`000007ooooo`05o`000?ooooooooooooooool000001?ooool00ol0003o
ooooooooo`12ooooo`?o0000`oooool000;ooooo0_l00009ooooo`?o00001Oooool00ol0003ooooo
ooooo`15ooooo`?o0000`?ooool001Gooooo00?o0000ooooooooool0B?ooool3o`000;gooooo000E
ooooo`03o`000?oooooooooo04_ooooo0_l0002kooooo`005Oooool00ol0003oooooooooo`1=oooo
o`;o0000^Oooool001Gooooo00?o0000ooooooooool0Coooool2o`000;Oooooo000Eooooo`;o0000
D_ooool2o`000;Gooooo000Eooooo`03o`000?oooooooooo05?ooooo0_l0002cooooo`005Oooool0
0ol0003oooooooooo`1Eooooo`;o0000/Oooool001Gooooo00?o0000ooooooooool0Eoooool2o`00
0:oooooo000Eooooo`03o`000?oooooooooo05Wooooo00?o0000ooooooooool0[?ooool001Gooooo
00?o0000ooooooooool0F_ooool2o`000:cooooo000Eooooo`03o`000?oooooooooo05cooooo0_l0
002Zooooo`005Oooool00ol0003oooooooooo`1Nooooo`;o0000Z?ooool001Gooooo0_l0001Qoooo
o`;o0000Y_ooool001Gooooo00?o0000ooooooooool0H_ooool00ol0003oooooooooo`2Sooooo`00
5Oooool00ol0003oooooooooo`1Sooooo`;o0000Xoooool001Gooooo00?o0000ooooooooool0IOoo
ool2o`000:7ooooo000Eooooo`03o`000?oooooooooo06Oooooo00?o0000ooooooooool0W_ooool0
01Gooooo00?o0000ooooooooool0J?ooool00ol0003oooooooooo`2Mooooo`005Oooool00ol0003o
ooooooooo`1Yooooo`03o`000?oooooooooo09cooooo000Eooooo`03o`000?oooooooooo06[ooooo
00?o0000ooooooooool0Voooool001Gooooo0_l0001/ooooo`03o`000?oooooooooo09[ooooo000E
ooooo`03o`000?oooooooooo06cooooo00?o0000ooooooooool0VOooool001Gooooo00?o0000oooo
ooooool0KOooool2o`0009Wooooo000Eooooo`03o`000?oooooooooo06oooooo00?o0000oooooooo
ool0U_ooool001Gooooo00?o0000ooooooooool0L?ooool00ol0003oooooooooo`2Eooooo`000_oo
ool2o`0000Cooooo00?o0000ooooooooool00oooool3o`0000Cooooo00?o0000ooooooooool0LOoo
ool2o`0009Gooooo00001Ooooooo0000oooooooooooo000000[ooooo00?o0000ooooooooool00ooo
ool00ol0003oooooooooo`1cooooo`03o`000?oooooooooo09;ooooo00001Ooooooo0000oooooooo
oooo000000Oooooo1Ol00004ooooo`03o`000?oooooooooo07Cooooo00?o0000ooooooooool0TOoo
ool00005ooooool0003oooooooooool000001oooool01?l0003oooooooooool00005ooooo`?o0000
MOooool00ol0003oooooooooo`2@ooooo`0000Goooooo`000?ooooooooooo`000008ooooo`03o`00
0?oooooo000000Gooooo00?o0000ooooooooool0M_ooool00ol0003oooooooooo`2?ooooo`0000Go
ooooo`000?ooooooooooo`000009ooooo`;o00001Oooool00ol0003oooooooooo`1fooooo`03o`00
0?oooooooooo08oooooo0002ooooo`;o00002oooool00ol0003oooooooooo`03ooooo`03o`000?oo
oooooooo07Oooooo00?o0000ooooooooool0S_ooool001Gooooo00?o0000ooooooooool0N?ooool0
0ol0003oooooooooo`2=ooooo`005Oooool00ol0003oooooooooo`1iooooo`03o`000?oooooooooo
08cooooo000Eooooo`03o`000?oooooooooo07[ooooo00?o0000ooooooooool0Roooool001Gooooo
00?o0000ooooooooool0Noooool00ol0003oooooooooo`2:ooooo`005Oooool2o`0007gooooo00?o
0000ooooooooool0ROooool001Gooooo00?o0000ooooooooool0OOooool00ol0003oooooooooo`28
ooooo`005Oooool00ol0003oooooooooo`1nooooo`03o`000?oooooooooo08Oooooo000Eooooo`03
o`000?oooooooooo07oooooo00?o0000ooooooooool0Q_ooool001Gooooo00?o0000ooooooooool0
Ooooool00ol0003oooooooooo`26ooooo`005Oooool00ol0003oooooooooo`20ooooo`03o`000?oo
oooooooo08Gooooo000Eooooo`03o`000?oooooooooo087ooooo00?o0000ooooooooool0Q?ooool0
01Gooooo00?o0000ooooooooool0P_ooool00ol0003oooooooooo`23ooooo`005Oooool2o`0008Co
oooo00?o0000ooooooooool0P_ooool001Gooooo00?o0000ooooooooool0Poooool00ol0003ooooo
ooooo`22ooooo`005Oooool00ol0003oooooooooo`24ooooo`03o`000?oooooooooo087ooooo000E
ooooo`03o`000?oooooooooo08Gooooo00?o0000ooooooooool0P?ooool001Gooooo00?o0000oooo
ooooool0Q_ooool00ol0003oooooooooo`1oooooo`005Oooool00ol0003oooooooooo`27ooooo`03
o`000?oooooooooo07kooooo000Eooooo`03o`000?oooooooooo08Sooooo00?o0000ooooooooool0
OOooool001Gooooo00?o0000ooooooooool0ROooool00ol0003oooooooooo`1looooo`005Oooool2
o`0008_ooooo00?o0000ooooooooool0Noooool001Gooooo00?o0000ooooooooool0Roooool00ol0
003oooooooooo`1jooooo`005Oooool00ol0003oooooooooo`2<ooooo`03o`000?oooooooooo07Wo
oooo000Eooooo`03o`000?oooooooooo08gooooo00?o0000ooooooooool0N?ooool001Gooooo00?o
0000ooooooooool0S_ooool00ol0003oooooooooo`1gooooo`000_ooool2o`0000Cooooo00?o0000
ooooooooool00_ooool3o`0000Gooooo00?o0000ooooooooool0Soooool00ol0003oooooooooo`1f
ooooo`0000Goooooo`000?ooooooooooo`000007ooooo`05o`000?ooooooooooooooool000001?oo
ool00ol0003oooooooooo`2@ooooo`;o0000M_ooool00005ooooool0003oooooooooool000001ooo
ool01Ol0003ooooooooooooooooo000000Cooooo00?o0000ooooooooool0T_ooool00ol0003ooooo
ooooo`1cooooo`0000Goooooo`000?ooooooooooo`000007ooooo`Co00001Oooool3o`0009?ooooo
00?o0000ooooooooool0L_ooool00005ooooool0003oooooooooool000001oooool00ol0003ooooo
ooooo`06ooooo`03o`000?oooooooooo09Cooooo00?o0000ooooooooool0LOooool00005ooooool0
003oooooooooool000002?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo09Gooooo
00?o0000ooooooooool0L?ooool000;ooooo0_l0000:ooooo`;o00001Oooool00ol0003ooooooooo
o`2Fooooo`03o`000?oooooooooo06oooooo000Eooooo`03o`000?oooooooooo09Oooooo00?o0000
ooooooooool0K_ooool001Gooooo00?o0000ooooooooool0V?ooool00ol0003oooooooooo`1]oooo
o`005Oooool00ol0003oooooooooo`2Iooooo`;o0000KOooool001Gooooo00?o0000ooooooooool0
Voooool00ol0003oooooooooo`1Zooooo`005Oooool2o`0009gooooo00?o0000ooooooooool0JOoo
ool001Gooooo00?o0000ooooooooool0WOooool00ol0003oooooooooo`1Xooooo`005Oooool00ol0
003oooooooooo`2Nooooo`03o`000?oooooooooo06Oooooo000Eooooo`03o`000?oooooooooo09oo
oooo00?o0000ooooooooool0I_ooool001Gooooo00?o0000ooooooooool0X?ooool00ol0003ooooo
ooooo`1Uooooo`005Oooool00ol0003oooooooooo`2Qooooo`;o0000IOooool001Gooooo00?o0000
ooooooooool0Xoooool2o`0006?ooooo000Eooooo`03o`000?oooooooooo0:Gooooo0_l0001Qoooo
o`005Oooool2o`000:Sooooo00?o0000ooooooooool0G_ooool001Gooooo00?o0000ooooooooool0
Z?ooool2o`0005kooooo000Eooooo`03o`000?oooooooooo0:[ooooo0_l0001Looooo`005Oooool0
0ol0003oooooooooo`2/ooooo`03o`000?oooooooooo05Wooooo000Eooooo`03o`000?oooooooooo
0:gooooo0_l0001Iooooo`005Oooool00ol0003oooooooooo`2_ooooo`;o0000Eoooool001Gooooo
00?o0000ooooooooool0/Oooool00ol0003oooooooooo`1Dooooo`005Oooool00ol0003ooooooooo
o`2booooo`;o0000E?ooool001Gooooo0_l0002eooooo`;o0000D_ooool001Gooooo00?o0000oooo
ooooool0]_ooool3o`0004oooooo000Eooooo`03o`000?oooooooooo0;Wooooo0_l0001=ooooo`00
5Oooool00ol0003oooooooooo`2kooooo`?o0000B_ooool001Gooooo00?o0000ooooooooool0__oo
ool3o`0004Oooooo0002ooooo`;o00001?ooool00ol0003oooooooooo`02ooooo`?o00001Oooool0
0ol0003oooooooooo`31ooooo`?o0000A?ooool00005ooooool0003oooooooooool000001oooool0
1Ol0003ooooooooooooooooo000000Cooooo00?o0000ooooooooool0a?ooool2o`0004;ooooo0000
1Ooooooo0000oooooooooooo000000Oooooo00Go0000ooooooooooooooooo`000004ooooo`03o`00
0?oooooooooo0<Kooooo0ol0000oooooo`0000Goooooo`000?ooooooooooo`000008ooooo`?o0000
1Oooool3o`000<Wooooo0ol0000looooo`0000Goooooo`000?ooooooooooo`000007ooooo`05o`00
0?ooooooooooooooool000001?ooool00ol0003oooooooooo`3<ooooo`?o0000>Oooool00005oooo
ool0003oooooooooool000001oooool01Ol0003ooooooooooooooooo000000Cooooo00?o0000oooo
ooooool0coooool5o`0003Cooooo0002ooooo`;o00002Oooool3o`0000Gooooo00?o0000oooooooo
ool0e?ooool4o`00033ooooo000Eooooo`03o`000?oooooooooo0=Sooooo1Ol0000[ooooo`005Ooo
ool00ol0003oooooooooo`3Mooooo`Co00009oooool001Gooooo00?o0000ooooooooool0hOooool4
o`0002?ooooo000Eooooo`03o`000?oooooooooo0>Gooooo1ol0000Looooo`005Oooool2o`000>go
oooo2Ol0000Cooooo`005Oooool00ol0003oooooooooo`3eooooo`Go00003_ooool001Gooooo00?o
0000ooooooooool0n_ooool3o`0000_ooooo000Eooooo`03o`000?oooooooooo0?gooooo0ol00008
ooooo`005Oooool00ol0003oooooooooo`3oooooo`7ooooo00?o0000ooooooooool01Oooool001Go
oooo00?o0000ooooooooool0ooooool9ooooo`005Oooool00ol0003oooooooooo`3oooooo`Wooooo
000Eooooo`03o`000?oooooooooo0?oooooo2Oooool001Gooooo0_l0003oooooo`[ooooo000Eoooo
o`03o`000?oooooooooo0?oooooo2Oooool001Gooooo00?o0000ooooooooool0ooooool9ooooo`00
5Oooool00ol0003oooooooooo`3oooooo`Wooooo000Eooooo`03o`000?oooooooooo0?oooooo2Ooo
ool001Gooooo00?o0000ooooooooool0ooooool9ooooo`005Oooool00ol0003oooooooooo`3ooooo
o`Wooooo000Eooooo`03o`000?oooooooooo0?oooooo2Oooool001Gooooo0_l0003oooooo`[ooooo
000Eooooo`03o`000?oooooooooo0?oooooo2Oooool001Gooooo00?o0000ooooooooool0ooooool9
ooooo`005Oooool00ol0003oooooooooo`3oooooo`Wooooo000Eooooo`03o`000?oooooooooo0?oo
oooo2Oooool000gooooo0ol00005ooooo`03o`000?oooooooooo0?oooooo2Oooool000kooooo00?o
0000ooooooooool01?ooool00ol0003oooooooooo`3oooooo`Wooooo000>ooooo`03o`000?oooooo
oooo00Cooooo00?o0000ooooooooool0ooooool9ooooo`003_ooool00ol0003oooooooooo`04oooo
o`?o0000ooooool9ooooo`003_ooool00ol0003oooooooooo`3ooooooa3ooooo000=ooooo`;o0000
oooooolBooooo`003_ooool00ol0003oooooooooo`3ooooooa3ooooo003oooooob7ooooo0000\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-2.49048, -0.0764114, \
0.115739, 0.00624232}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 0.0333333 0 0.618034 [
[.16667 -0.0125 -3 -9 ]
[.16667 -0.0125 3 0 ]
[.33333 -0.0125 -6 -9 ]
[.33333 -0.0125 6 0 ]
[.5 -0.0125 -6 -9 ]
[.5 -0.0125 6 0 ]
[.66667 -0.0125 -6 -9 ]
[.66667 -0.0125 6 0 ]
[.83333 -0.0125 -6 -9 ]
[.83333 -0.0125 6 0 ]
[1 -0.0125 -6 -9 ]
[1 -0.0125 6 0 ]
[-0.0125 .12361 -18 -4.5 ]
[-0.0125 .12361 0 4.5 ]
[-0.0125 .24721 -18 -4.5 ]
[-0.0125 .24721 0 4.5 ]
[-0.0125 .37082 -18 -4.5 ]
[-0.0125 .37082 0 4.5 ]
[-0.0125 .49443 -18 -4.5 ]
[-0.0125 .49443 0 4.5 ]
[-0.0125 .61803 -6 -4.5 ]
[-0.0125 .61803 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.16667 0 m
.16667 .00625 L
s
[(5)] .16667 -0.0125 0 1 Mshowa
.33333 0 m
.33333 .00625 L
s
[(10)] .33333 -0.0125 0 1 Mshowa
.5 0 m
.5 .00625 L
s
[(15)] .5 -0.0125 0 1 Mshowa
.66667 0 m
.66667 .00625 L
s
[(20)] .66667 -0.0125 0 1 Mshowa
.83333 0 m
.83333 .00625 L
s
[(25)] .83333 -0.0125 0 1 Mshowa
1 0 m
1 .00625 L
s
[(30)] 1 -0.0125 0 1 Mshowa
.125 Mabswid
.03333 0 m
.03333 .00375 L
s
.06667 0 m
.06667 .00375 L
s
.1 0 m
.1 .00375 L
s
.13333 0 m
.13333 .00375 L
s
.2 0 m
.2 .00375 L
s
.23333 0 m
.23333 .00375 L
s
.26667 0 m
.26667 .00375 L
s
.3 0 m
.3 .00375 L
s
.36667 0 m
.36667 .00375 L
s
.4 0 m
.4 .00375 L
s
.43333 0 m
.43333 .00375 L
s
.46667 0 m
.46667 .00375 L
s
.53333 0 m
.53333 .00375 L
s
.56667 0 m
.56667 .00375 L
s
.6 0 m
.6 .00375 L
s
.63333 0 m
.63333 .00375 L
s
.7 0 m
.7 .00375 L
s
.73333 0 m
.73333 .00375 L
s
.76667 0 m
.76667 .00375 L
s
.8 0 m
.8 .00375 L
s
.86667 0 m
.86667 .00375 L
s
.9 0 m
.9 .00375 L
s
.93333 0 m
.93333 .00375 L
s
.96667 0 m
.96667 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .12361 m
.00625 .12361 L
s
[(0.2)] -0.0125 .12361 1 0 Mshowa
0 .24721 m
.00625 .24721 L
s
[(0.4)] -0.0125 .24721 1 0 Mshowa
0 .37082 m
.00625 .37082 L
s
[(0.6)] -0.0125 .37082 1 0 Mshowa
0 .49443 m
.00625 .49443 L
s
[(0.8)] -0.0125 .49443 1 0 Mshowa
0 .61803 m
.00625 .61803 L
s
[(1)] -0.0125 .61803 1 0 Mshowa
.125 Mabswid
0 .0309 m
.00375 .0309 L
s
0 .0618 m
.00375 .0618 L
s
0 .09271 m
.00375 .09271 L
s
0 .15451 m
.00375 .15451 L
s
0 .18541 m
.00375 .18541 L
s
0 .21631 m
.00375 .21631 L
s
0 .27812 m
.00375 .27812 L
s
0 .30902 m
.00375 .30902 L
s
0 .33992 m
.00375 .33992 L
s
0 .40172 m
.00375 .40172 L
s
0 .43262 m
.00375 .43262 L
s
0 .46353 m
.00375 .46353 L
s
0 .52533 m
.00375 .52533 L
s
0 .55623 m
.00375 .55623 L
s
0 .58713 m
.00375 .58713 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.03333 .07814 m
.06667 .08744 L
.1 .09311 L
.13333 .09862 L
.16667 .10487 L
.2 .11228 L
.23333 .12116 L
.26667 .13179 L
.3 .14448 L
.33333 .15958 L
.36667 .1775 L
.4 .19873 L
.43333 .22384 L
.46667 .2535 L
.5 .28846 L
.53333 .32958 L
.56667 .36454 L
.6 .39419 L
.63333 .4193 L
.66667 .44053 L
.7 .45846 L
.73333 .47356 L
.76667 .48625 L
.8 .49688 L
.83333 .50575 L
.86667 .51317 L
.9 .51942 L
.93333 .52493 L
.96667 .53059 L
1 .53989 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[6]:=",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/B000`400?l00000o`00003ooooooolQ
ooooo`00?_ooool3o`0002Gooooo0ol00004ooooo`;o00008oooool3o`0000?ooooo0ol0000Qoooo
o`Go00000oooool2o`00027ooooo1Ol00002ooooo`?o00008_ooool3o`0000Cooooo0_l00004oooo
o`00?Oooool01Ol0003ooooooooooooooooo000002Gooooo00?o0000ooooooooool00_ooool01?l0
003oooooooooool0000Sooooo`05o`000?ooooooooooooooool000000oooool00ol0003ooooooooo
o`0Oooooo`04o`000?ooooooooooo`0000;ooooo00Co0000oooooooooooo00008Oooool01_l0003o
ooooooooool0003oooooo`0000?ooooo00?o0000ooooooooool07_ooool01Ol0003ooooooooooooo
oooo000000;ooooo00Co0000oooooooooooo00000oooool0047ooooo00?o0000ooooooooool08ooo
ool00ol0003oooooooooo`02ooooo`04o`000?ooooooooooo`0002?ooooo00?o0000ooooooooool0
1Oooool00ol0003oooooooooo`0Pooooo`03o`000?oooooooooo00;ooooo00Co0000oooooooooooo
00008_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo02;ooooo00Co0000oooooooo
oooo00000_ooool00ol0003oooooooooo`01ooooo`00@Oooool00ol0003oooooooooo`0Sooooo`03
o`000?oooooooooo00;ooooo00Co0000oooooooooooo00008oooool00ol0003oooooooooo`05oooo
o`03o`000?oooooooooo027ooooo00Go0000ooooooooooooooooo`000002ooooo`03o`000?oooooo
oooo027ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`0Pooooo`;o00000oooool0
1?l0003oooooooooool00003ooooo`00?Oooool4o`0002Kooooo00?o0000ooooooooool00_ooool0
1?l0003oooooooooool0000Sooooo`04o`000?ooooooooooooooo`Co00008Oooool01Ol0003ooooo
oooooooooooo000000;ooooo00Co0000oooooooooooo00008?ooool01_l0003ooooooooooooooooo
0000ooooo`Co00009Oooool01?l0003oooooooooool00002ooooo`03o`000?oooooooooo007ooooo
000mooooo`03o`000?oooooooooo02Kooooo0_l00004ooooo`04o`000?ooooooooooo`0002;ooooo
0_l00003ooooo`03o`000?oooooooooo02;ooooo00Go0000ooooooooooooooooo`000002ooooo`04
o`000?ooooooooooo`00023ooooo00Oo0000ooooooooooooooooo`000?oooooo000002Cooooo00Go
0000ooooooooooooooooo`000002ooooo`04o`000?ooooooooooo`0000?ooooo000mooooo`Go0000
9Oooool00ol0003oooooooooo`03ooooo`;o00009?ooool01?l0003oooooooooooooool5o`00027o
oooo0ol00004ooooo`;o00008_ooool3o`0000;ooooo1Ol0000Qooooo`?o00001?ooool2o`0000Co
oooo003oooooob7ooooo003oooooob7ooooo003oooooob7ooooo003oooooob7ooooo000Eoooooooo
00001Ol00007ooooo`005Oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Gooooo
00?o0000ooooooooool01_ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Gooooo
00?o0000ooooooooool01_ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Gooooo
00?o0000ooooooooool01_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Kooooo
00?o0000ooooooooool01_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Kooooo
00?o0000ooooooooool01_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Kooooo
00?o0000ooooooooool01_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Kooooo
00?o0000ooooooooool01Oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Kooooo
00?o0000ooooooooool01Oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Kooooo
00?o0000ooooooooool01Oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Kooooo
00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`005Oooool00ol0003ooooooooo
o`3oooooo`Wooooo000Eooooo`03o`000?oooooooooo0?oooooo2Oooool001Gooooo00?o0000oooo
ooooool0ooooool9ooooo`005Oooool00ol0003oooooooooo`3oooooo`Wooooo000Eooooo`03o`00
0?oooooooooo0?oooooo2Oooool001Gooooo00?o0000ooooooooool0ooooool9ooooo`005Oooool2
o`000?oooooo2_ooool001Gooooo00?o0000ooooooooool0ooooool9ooooo`005Oooool00ol0003o
ooooooooo`3oooooo`Wooooo000Eooooo`03o`000?oooooooooo0?oooooo2Oooool001Gooooo00?o
0000ooooooooool0ooooool9ooooo`005Oooool00ol0003oooooooooo`3oooooo`Wooooo000Eoooo
o`03o`000?oooooooooo0?oooooo2Oooool001Gooooo00?o0000ooooooooool0ooooool9ooooo`00
5Oooool2o`000?oooooo2_ooool001Gooooo00?o0000ooooooooool0ooooool9ooooo`005Oooool0
0ol0003oooooooooo`3oooooo`Wooooo000Eooooo`03o`000?oooooooooo0?oooooo2Oooool001Go
oooo00?o0000ooooooooool01_ooool3o`000?oooooo000Eooooo`03o`000?oooooooooo00Wooooo
1?l0003kooooo`005Oooool00ol0003oooooooooo`0=ooooo`Co0000moooool001Gooooo00?o0000
ooooooooool04Oooool5o`000?;ooooo000Eooooo`;o00005oooool7o`000>_ooooo000Eooooo`03
o`000?oooooooooo01gooooo1_l0003Uooooo`005Oooool00ol0003oooooooooo`0Sooooo`Co0000
hOooool001Gooooo00?o0000ooooooooool09oooool4o`000=gooooo000Eooooo`03o`000?oooooo
oooo02_ooooo1Ol0003Hooooo`000_ooool2o`0000Cooooo00Co0000oooooooooooooooo1Ol00004
ooooo`03o`000?oooooooooo033ooooo1?l0003Dooooo`0000Goooooo`000?ooooooooooo`000008
ooooo`04o`000?ooooooooooo`0000Cooooo00?o0000ooooooooool0=?ooool5o`000<oooooo0000
1Ooooooo0000oooooooooooo000000Wooooo00?o0000ooooooooool01?ooool00ol0003ooooooooo
o`0iooooo`?o0000c?ooool00005ooooool0003oooooooooool000002_ooool00ol0003ooooooooo
o`03ooooo`?o0000??ooool3o`000<Wooooo00001Ooooooo0000oooooooooooo000000Oooooo00Go
0000ooooooooooooooooo`000004ooooo`03o`000?oooooooooo03oooooo0ol00036ooooo`0000Go
ooooo`000?ooooooooooo`000007ooooo`05o`000?ooooooooooooooool000001?ooool00ol0003o
ooooooooo`12ooooo`?o0000`oooool000;ooooo0_l00009ooooo`?o00001Oooool00ol0003ooooo
ooooo`15ooooo`?o0000`?ooool001Gooooo00?o0000ooooooooool0B?ooool3o`000;gooooo000E
ooooo`03o`000?oooooooooo04_ooooo0_l0002kooooo`005Oooool00ol0003oooooooooo`1=oooo
o`;o0000^Oooool001Gooooo00?o0000ooooooooool0Coooool2o`000;Oooooo000Eooooo`;o0000
D_ooool2o`000;Gooooo000Eooooo`03o`000?oooooooooo05?ooooo0_l0002cooooo`005Oooool0
0ol0003oooooooooo`1Eooooo`;o0000/Oooool001Gooooo00?o0000ooooooooool0Eoooool2o`00
0:oooooo000Eooooo`03o`000?oooooooooo05Wooooo00?o0000ooooooooool0[?ooool001Gooooo
00?o0000ooooooooool0F_ooool2o`000:cooooo000Eooooo`03o`000?oooooooooo05cooooo0_l0
002Zooooo`005Oooool00ol0003oooooooooo`1Nooooo`;o0000Z?ooool001Gooooo0_l0001Qoooo
o`;o0000Y_ooool001Gooooo00?o0000ooooooooool0H_ooool00ol0003oooooooooo`2Sooooo`00
5Oooool00ol0003oooooooooo`1Sooooo`;o0000Xoooool001Gooooo00?o0000ooooooooool0IOoo
ool2o`000:7ooooo000Eooooo`03o`000?oooooooooo06Oooooo00?o0000ooooooooool0W_ooool0
01Gooooo00?o0000ooooooooool0J?ooool00ol0003oooooooooo`2Mooooo`005Oooool00ol0003o
ooooooooo`1Yooooo`03o`000?oooooooooo09cooooo000Eooooo`03o`000?oooooooooo06[ooooo
00?o0000ooooooooool0Voooool001Gooooo0_l0001/ooooo`03o`000?oooooooooo09[ooooo000E
ooooo`03o`000?oooooooooo06cooooo00?o0000ooooooooool0VOooool001Gooooo00?o0000oooo
ooooool0KOooool2o`0009Wooooo000Eooooo`03o`000?oooooooooo06oooooo00?o0000oooooooo
ool0U_ooool001Gooooo00?o0000ooooooooool0L?ooool00ol0003oooooooooo`2Eooooo`000_oo
ool2o`0000Cooooo00?o0000ooooooooool00oooool3o`0000Cooooo00?o0000ooooooooool0LOoo
ool00ol0003oooooooooo`2Dooooo`0000Goooooo`000?ooooooooooo`00000:ooooo`03o`000?oo
oooooooo00?ooooo00?o0000ooooooooool0L_ooool00ol0003oooooooooo`2Cooooo`0000Gooooo
o`000?ooooooooooo`000007ooooo`Go00001?ooool00ol0003oooooooooo`1cooooo`03o`000?oo
oooooooo09;ooooo00001Ooooooo0000oooooooooooo000000Oooooo00Co0000oooooooooooo0000
1Oooool3o`0007Cooooo00?o0000ooooooooool0TOooool00005ooooool0003oooooooooool00000
2?ooool00ol0003oooooo`000005ooooo`03o`000?oooooooooo07Gooooo00?o0000ooooooooool0
T?ooool00005ooooool0003oooooooooool000002Oooool2o`0000Gooooo00?o0000ooooooooool0
M_ooool00ol0003oooooooooo`2?ooooo`000_ooool2o`0000_ooooo00?o0000ooooooooool00ooo
ool00ol0003oooooooooo`1gooooo`03o`000?oooooooooo08kooooo000Eooooo`03o`000?oooooo
oooo07Sooooo00?o0000ooooooooool0SOooool001Gooooo00?o0000ooooooooool0NOooool00ol0
003oooooooooo`2<ooooo`005Oooool00ol0003oooooooooo`1jooooo`03o`000?oooooooooo08_o
oooo000Eooooo`03o`000?oooooooooo07_ooooo00?o0000ooooooooool0R_ooool001Gooooo0_l0
001mooooo`03o`000?oooooooooo08Wooooo000Eooooo`03o`000?oooooooooo07gooooo00?o0000
ooooooooool0R?ooool001Gooooo00?o0000ooooooooool0O_ooool00ol0003oooooooooo`27oooo
o`005Oooool00ol0003oooooooooo`1oooooo`03o`000?oooooooooo08Kooooo000Eooooo`03o`00
0?oooooooooo07oooooo00?o0000ooooooooool0Q_ooool001Gooooo00?o0000ooooooooool0P?oo
ool00ol0003oooooooooo`25ooooo`005Oooool00ol0003oooooooooo`21ooooo`03o`000?oooooo
oooo08Cooooo000Eooooo`03o`000?oooooooooo08;ooooo00?o0000ooooooooool0Poooool001Go
oooo0_l00024ooooo`03o`000?oooooooooo08;ooooo000Eooooo`03o`000?oooooooooo08?ooooo
00?o0000ooooooooool0P_ooool001Gooooo00?o0000ooooooooool0Q?ooool00ol0003ooooooooo
o`21ooooo`005Oooool00ol0003oooooooooo`25ooooo`03o`000?oooooooooo083ooooo000Eoooo
o`03o`000?oooooooooo08Kooooo00?o0000ooooooooool0Ooooool001Gooooo00?o0000oooooooo
ool0Qoooool00ol0003oooooooooo`1nooooo`005Oooool00ol0003oooooooooo`28ooooo`03o`00
0?oooooooooo07gooooo000Eooooo`03o`000?oooooooooo08Wooooo00?o0000ooooooooool0O?oo
ool001Gooooo0_l0002;ooooo`03o`000?oooooooooo07_ooooo000Eooooo`03o`000?oooooooooo
08_ooooo00?o0000ooooooooool0N_ooool001Gooooo00?o0000ooooooooool0S?ooool00ol0003o
ooooooooo`1iooooo`005Oooool00ol0003oooooooooo`2=ooooo`03o`000?oooooooooo07Sooooo
000Eooooo`03o`000?oooooooooo08kooooo00?o0000ooooooooool0Moooool000;ooooo0_l00004
ooooo`03o`000?oooooooooo00;ooooo0ol00005ooooo`03o`000?oooooooooo08oooooo00?o0000
ooooooooool0M_ooool00005ooooool0003oooooooooool000001oooool01Ol0003ooooooooooooo
oooo000000Cooooo00?o0000ooooooooool0T?ooool2o`0007Kooooo00001Ooooooo0000oooooooo
oooo000000Oooooo00Go0000ooooooooooooooooo`000004ooooo`03o`000?oooooooooo09;ooooo
00?o0000ooooooooool0Loooool00005ooooool0003oooooooooool000001oooool4o`0000Gooooo
0ol0002Cooooo`03o`000?oooooooooo07;ooooo00001Ooooooo0000oooooooooooo000000Oooooo
00?o0000ooooooooool01_ooool00ol0003oooooooooo`2Dooooo`03o`000?oooooooooo077ooooo
00001Ooooooo0000oooooooooooo000000Sooooo00?o0000ooooooooool01Oooool00ol0003ooooo
ooooo`2Eooooo`03o`000?oooooooooo073ooooo0002ooooo`;o00002_ooool2o`0000Gooooo00?o
0000ooooooooool0U_ooool00ol0003oooooooooo`1_ooooo`005Oooool00ol0003oooooooooo`2G
ooooo`03o`000?oooooooooo06kooooo000Eooooo`03o`000?oooooooooo09Sooooo00?o0000oooo
ooooool0KOooool001Gooooo00?o0000ooooooooool0VOooool2o`0006gooooo000Eooooo`03o`00
0?oooooooooo09_ooooo00?o0000ooooooooool0J_ooool001Gooooo0_l0002Mooooo`03o`000?oo
oooooooo06Wooooo000Eooooo`03o`000?oooooooooo09gooooo0_l0001Yooooo`005Oooool00ol0
003oooooooooo`2Oooooo`03o`000?oooooooooo06Kooooo000Eooooo`03o`000?oooooooooo0:3o
oooo00?o0000ooooooooool0IOooool001Gooooo00?o0000ooooooooool0XOooool2o`0006Gooooo
000Eooooo`03o`000?oooooooooo0:?ooooo00?o0000ooooooooool0H_ooool001Gooooo00?o0000
ooooooooool0Y?ooool2o`0006;ooooo000Eooooo`03o`000?oooooooooo0:Kooooo00?o0000oooo
ooooool0Goooool001Gooooo0_l0002Xooooo`;o0000Goooool001Gooooo00?o0000ooooooooool0
ZOooool00ol0003oooooooooo`1Looooo`005Oooool00ol0003oooooooooo`2Zooooo`;o0000G?oo
ool001Gooooo00?o0000ooooooooool0[?ooool00ol0003oooooooooo`1Iooooo`005Oooool00ol0
003oooooooooo`2]ooooo`;o0000FOooool001Gooooo00?o0000ooooooooool0[oooool2o`0005Oo
oooo000Eooooo`03o`000?oooooooooo0;7ooooo00?o0000ooooooooool0E?ooool001Gooooo00?o
0000ooooooooool0/_ooool2o`0005Cooooo000Eooooo`;o0000]Oooool2o`0005;ooooo000Eoooo
o`03o`000?oooooooooo0;Kooooo0ol0001?ooooo`005Oooool00ol0003oooooooooo`2iooooo`;o
0000COooool001Gooooo00?o0000ooooooooool0^oooool3o`0004[ooooo000Eooooo`03o`000?oo
oooooooo0;kooooo0ol00017ooooo`000_ooool2o`0000Cooooo00?o0000ooooooooool00_ooool3
o`0000Gooooo00?o0000ooooooooool0`Oooool3o`0004Cooooo00001Ooooooo0000oooooooooooo
000000Oooooo00Go0000ooooooooooooooooo`000004ooooo`03o`000?oooooooooo0<Cooooo0_l0
0012ooooo`0000Goooooo`000?ooooooooooo`000007ooooo`05o`000?ooooooooooooooool00000
1?ooool00ol0003oooooooooo`36ooooo`?o0000?oooool00005ooooool0003oooooooooool00000
2?ooool3o`0000Gooooo0ol00039ooooo`?o0000??ooool00005ooooool0003oooooooooool00000
1oooool01Ol0003ooooooooooooooooo000000Cooooo00?o0000ooooooooool0c?ooool3o`0003Wo
oooo00001Ooooooo0000oooooooooooo000000Oooooo00Go0000ooooooooooooooooo`000004oooo
o`03o`000?oooooooooo0<oooooo1Ol0000dooooo`000_ooool2o`0000Wooooo0ol00005ooooo`03
o`000?oooooooooo0=Cooooo1?l0000`ooooo`005Oooool00ol0003oooooooooo`3Hooooo`Go0000
:oooool001Gooooo00?o0000ooooooooool0gOooool6o`0002Gooooo000Eooooo`03o`000?oooooo
oooo0>?ooooo1_l0000Oooooo`005Oooool00ol0003oooooooooo`3Yooooo`Go00006_ooool001Go
oooo0_l0003_ooooo`Oo00004oooool001Gooooo00?o0000ooooooooool0mOooool5o`0000kooooo
000Eooooo`03o`000?oooooooooo0?[ooooo0ol0000;ooooo`005Oooool00ol0003oooooooooo`3m
ooooo`?o00002?ooool001Gooooo00?o0000ooooooooool0ooooool1ooooo`03o`000?oooooooooo
00Gooooo000Eooooo`03o`000?oooooooooo0?oooooo2Oooool001Gooooo00?o0000ooooooooool0
ooooool9ooooo`005Oooool00ol0003oooooooooo`3oooooo`Wooooo000Eooooo`;o0000ooooool:
ooooo`005Oooool00ol0003oooooooooo`3oooooo`Wooooo000Eooooo`03o`000?oooooooooo0?oo
oooo2Oooool001Gooooo00?o0000ooooooooool0ooooool9ooooo`005Oooool00ol0003ooooooooo
o`3oooooo`Wooooo000Eooooo`03o`000?oooooooooo0?oooooo2Oooool001Gooooo00?o0000oooo
ooooool0ooooool9ooooo`005Oooool00ol0003oooooooooo`3oooooo`Wooooo000Eooooo`;o0000
ooooool:ooooo`005Oooool00ol0003oooooooooo`3oooooo`Wooooo000Eooooo`03o`000?oooooo
oooo0?oooooo2Oooool001Gooooo00?o0000ooooooooool0ooooool9ooooo`005Oooool00ol0003o
ooooooooo`3oooooo`Wooooo000=ooooo`?o00001Oooool00ol0003oooooooooo`3oooooo`Wooooo
000>ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0ooooool9ooooo`003_ooool0
0ol0003oooooooooo`04ooooo`03o`000?oooooooooo0?oooooo2Oooool000kooooo00?o0000oooo
ooooool01?ooool3o`000?oooooo2Oooool000kooooo00?o0000ooooooooool0ooooool@ooooo`00
3Oooool2o`000?oooooo4_ooool000kooooo00?o0000ooooooooool0ooooool@ooooo`00oooooolQ
ooooo`00\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-2.49048, -0.0764114, \
0.115739, 0.00624232}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 0.0333333 0 0.618034 [
[.16667 -0.0125 -3 -9 ]
[.16667 -0.0125 3 0 ]
[.33333 -0.0125 -6 -9 ]
[.33333 -0.0125 6 0 ]
[.5 -0.0125 -6 -9 ]
[.5 -0.0125 6 0 ]
[.66667 -0.0125 -6 -9 ]
[.66667 -0.0125 6 0 ]
[.83333 -0.0125 -6 -9 ]
[.83333 -0.0125 6 0 ]
[1 -0.0125 -6 -9 ]
[1 -0.0125 6 0 ]
[-0.0125 .12361 -18 -4.5 ]
[-0.0125 .12361 0 4.5 ]
[-0.0125 .24721 -18 -4.5 ]
[-0.0125 .24721 0 4.5 ]
[-0.0125 .37082 -18 -4.5 ]
[-0.0125 .37082 0 4.5 ]
[-0.0125 .49443 -18 -4.5 ]
[-0.0125 .49443 0 4.5 ]
[-0.0125 .61803 -6 -4.5 ]
[-0.0125 .61803 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.16667 0 m
.16667 .00625 L
s
[(5)] .16667 -0.0125 0 1 Mshowa
.33333 0 m
.33333 .00625 L
s
[(10)] .33333 -0.0125 0 1 Mshowa
.5 0 m
.5 .00625 L
s
[(15)] .5 -0.0125 0 1 Mshowa
.66667 0 m
.66667 .00625 L
s
[(20)] .66667 -0.0125 0 1 Mshowa
.83333 0 m
.83333 .00625 L
s
[(25)] .83333 -0.0125 0 1 Mshowa
1 0 m
1 .00625 L
s
[(30)] 1 -0.0125 0 1 Mshowa
.125 Mabswid
.03333 0 m
.03333 .00375 L
s
.06667 0 m
.06667 .00375 L
s
.1 0 m
.1 .00375 L
s
.13333 0 m
.13333 .00375 L
s
.2 0 m
.2 .00375 L
s
.23333 0 m
.23333 .00375 L
s
.26667 0 m
.26667 .00375 L
s
.3 0 m
.3 .00375 L
s
.36667 0 m
.36667 .00375 L
s
.4 0 m
.4 .00375 L
s
.43333 0 m
.43333 .00375 L
s
.46667 0 m
.46667 .00375 L
s
.53333 0 m
.53333 .00375 L
s
.56667 0 m
.56667 .00375 L
s
.6 0 m
.6 .00375 L
s
.63333 0 m
.63333 .00375 L
s
.7 0 m
.7 .00375 L
s
.73333 0 m
.73333 .00375 L
s
.76667 0 m
.76667 .00375 L
s
.8 0 m
.8 .00375 L
s
.86667 0 m
.86667 .00375 L
s
.9 0 m
.9 .00375 L
s
.93333 0 m
.93333 .00375 L
s
.96667 0 m
.96667 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .12361 m
.00625 .12361 L
s
[(0.2)] -0.0125 .12361 1 0 Mshowa
0 .24721 m
.00625 .24721 L
s
[(0.4)] -0.0125 .24721 1 0 Mshowa
0 .37082 m
.00625 .37082 L
s
[(0.6)] -0.0125 .37082 1 0 Mshowa
0 .49443 m
.00625 .49443 L
s
[(0.8)] -0.0125 .49443 1 0 Mshowa
0 .61803 m
.00625 .61803 L
s
[(1)] -0.0125 .61803 1 0 Mshowa
.125 Mabswid
0 .0309 m
.00375 .0309 L
s
0 .0618 m
.00375 .0618 L
s
0 .09271 m
.00375 .09271 L
s
0 .15451 m
.00375 .15451 L
s
0 .18541 m
.00375 .18541 L
s
0 .21631 m
.00375 .21631 L
s
0 .27812 m
.00375 .27812 L
s
0 .30902 m
.00375 .30902 L
s
0 .33992 m
.00375 .33992 L
s
0 .40172 m
.00375 .40172 L
s
0 .43262 m
.00375 .43262 L
s
0 .46353 m
.00375 .46353 L
s
0 .52533 m
.00375 .52533 L
s
0 .55623 m
.00375 .55623 L
s
0 .58713 m
.00375 .58713 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.03333 .07781 m
.06667 .08743 L
.1 .09323 L
.13333 .09881 L
.16667 .10509 L
.2 .11252 L
.23333 .1214 L
.26667 .13202 L
.3 .14469 L
.33333 .15977 L
.36667 .17767 L
.4 .19887 L
.43333 .22394 L
.46667 .25356 L
.5 .28848 L
.53333 .32956 L
.56667 .36448 L
.6 .39409 L
.63333 .41916 L
.66667 .44037 L
.7 .45826 L
.73333 .47334 L
.76667 .48602 L
.8 .49664 L
.83333 .50552 L
.86667 .51294 L
.9 .51923 L
.93333 .5248 L
.96667 .5306 L
1 .54023 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[6]:=",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/B000`400?l00000o`00003ooooooolQ
ooooo`00?_ooool3o`0002Gooooo0ol00004ooooo`;o00008oooool3o`0000?ooooo0ol0000Qoooo
o`Go00000oooool2o`00027ooooo1Ol00002ooooo`?o00008_ooool3o`0000Cooooo0_l00004oooo
o`00?Oooool01Ol0003ooooooooooooooooo000002Gooooo00?o0000ooooooooool00_ooool01?l0
003oooooooooool0000Sooooo`05o`000?ooooooooooooooool000000oooool00ol0003ooooooooo
o`0Oooooo`04o`000?ooooooooooo`0000;ooooo00Co0000oooooooooooo00008Oooool01_l0003o
ooooooooool0003oooooo`0000?ooooo00?o0000ooooooooool07_ooool01Ol0003ooooooooooooo
oooo000000;ooooo00Co0000oooooooooooo00000oooool0047ooooo00?o0000ooooooooool08ooo
ool00ol0003oooooooooo`02ooooo`04o`000?ooooooooooo`0002?ooooo00?o0000ooooooooool0
1Oooool00ol0003oooooooooo`0Pooooo`03o`000?oooooooooo00;ooooo00Co0000oooooooooooo
00008_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo02;ooooo00Co0000oooooooo
oooo00000_ooool00ol0003oooooooooo`01ooooo`00@Oooool00ol0003oooooooooo`0Sooooo`03
o`000?oooooooooo00;ooooo00Co0000oooooooooooo00008oooool00ol0003oooooooooo`05oooo
o`03o`000?oooooooooo027ooooo00Go0000ooooooooooooooooo`000002ooooo`03o`000?oooooo
oooo027ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`0Pooooo`;o00000oooool0
1?l0003oooooooooool00003ooooo`00?Oooool4o`0002Kooooo00?o0000ooooooooool00_ooool0
1?l0003oooooooooool0000Sooooo`04o`000?ooooooooooooooo`Co00008Oooool01Ol0003ooooo
oooooooooooo000000;ooooo00Co0000oooooooooooo00008?ooool01_l0003ooooooooooooooooo
0000ooooo`Co00009Oooool01?l0003oooooooooool00002ooooo`03o`000?oooooooooo007ooooo
000mooooo`03o`000?oooooooooo02Kooooo0_l00004ooooo`04o`000?ooooooooooo`0002;ooooo
0_l00003ooooo`03o`000?oooooooooo02;ooooo00Go0000ooooooooooooooooo`000002ooooo`04
o`000?ooooooooooo`00023ooooo00Oo0000ooooooooooooooooo`000?oooooo000002Cooooo00Go
0000ooooooooooooooooo`000002ooooo`04o`000?ooooooooooo`0000?ooooo000mooooo`Go0000
9Oooool00ol0003oooooooooo`03ooooo`;o00009?ooool01?l0003oooooooooooooool5o`00027o
oooo0ol00004ooooo`;o00008_ooool3o`0000;ooooo1Ol0000Qooooo`?o00001?ooool2o`0000Co
oooo003oooooob7ooooo003oooooob7ooooo003oooooob7ooooo003oooooob7ooooo000Eoooooooo
00001Ol00007ooooo`005Oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Gooooo
00?o0000ooooooooool01_ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Gooooo
00?o0000ooooooooool01_ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Gooooo
00?o0000ooooooooool01_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Kooooo
00?o0000ooooooooool01_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Kooooo
00?o0000ooooooooool01_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Kooooo
00?o0000ooooooooool01_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Kooooo
00?o0000ooooooooool01Oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Kooooo
00?o0000ooooooooool01Oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Kooooo
00?o0000ooooooooool01Oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Kooooo
00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`005Oooool00ol0003ooooooooo
o`3oooooo`Wooooo000Eooooo`03o`000?oooooooooo0?oooooo2Oooool001Gooooo00?o0000oooo
ooooool0ooooool9ooooo`005Oooool00ol0003oooooooooo`3oooooo`Wooooo000Eooooo`03o`00
0?oooooooooo0?oooooo2Oooool001Gooooo00?o0000ooooooooool0ooooool9ooooo`005Oooool2
o`000?oooooo2_ooool001Gooooo00?o0000ooooooooool0ooooool9ooooo`005Oooool00ol0003o
ooooooooo`3oooooo`Wooooo000Eooooo`03o`000?oooooooooo0?oooooo2Oooool001Gooooo00?o
0000ooooooooool0ooooool9ooooo`005Oooool00ol0003oooooooooo`3oooooo`Wooooo000Eoooo
o`03o`000?oooooooooo0?oooooo2Oooool001Gooooo00?o0000ooooooooool0ooooool9ooooo`00
5Oooool2o`000?oooooo2_ooool001Gooooo00?o0000ooooooooool0ooooool9ooooo`005Oooool0
0ol0003oooooooooo`3oooooo`Wooooo000Eooooo`03o`000?oooooooooo0?oooooo2Oooool001Go
oooo00?o0000ooooooooool01_ooool3o`000?oooooo000Eooooo`03o`000?oooooooooo00Wooooo
1?l0003kooooo`005Oooool00ol0003oooooooooo`0=ooooo`Co0000moooool001Gooooo00?o0000
ooooooooool04Oooool5o`000?;ooooo000Eooooo`;o00005oooool7o`000>_ooooo000Eooooo`03
o`000?oooooooooo01gooooo1_l0003Uooooo`005Oooool00ol0003oooooooooo`0Sooooo`Co0000
hOooool001Gooooo00?o0000ooooooooool09oooool4o`000=gooooo000Eooooo`03o`000?oooooo
oooo02_ooooo1Ol0003Hooooo`000_ooool2o`0000Cooooo00Co0000oooooooooooooooo1Ol00004
ooooo`03o`000?oooooooooo033ooooo1?l0003Dooooo`0000Goooooo`000?ooooooooooo`000008
ooooo`04o`000?ooooooooooo`0000Cooooo00?o0000ooooooooool0=?ooool5o`000<oooooo0000
1Ooooooo0000oooooooooooo000000Wooooo00?o0000ooooooooool01?ooool00ol0003ooooooooo
o`0iooooo`?o0000c?ooool00005ooooool0003oooooooooool000002_ooool00ol0003ooooooooo
o`03ooooo`?o0000??ooool3o`000<Wooooo00001Ooooooo0000oooooooooooo000000Oooooo00Go
0000ooooooooooooooooo`000004ooooo`03o`000?oooooooooo03oooooo0ol00036ooooo`0000Go
ooooo`000?ooooooooooo`000007ooooo`05o`000?ooooooooooooooool000001?ooool00ol0003o
ooooooooo`12ooooo`?o0000`oooool000;ooooo0_l00009ooooo`?o00001Oooool00ol0003ooooo
ooooo`15ooooo`?o0000`?ooool001Gooooo00?o0000ooooooooool0B?ooool3o`000;gooooo000E
ooooo`03o`000?oooooooooo04_ooooo0_l0002kooooo`005Oooool00ol0003oooooooooo`1=oooo
o`;o0000^Oooool001Gooooo00?o0000ooooooooool0Coooool2o`000;Oooooo000Eooooo`;o0000
D_ooool2o`000;Gooooo000Eooooo`03o`000?oooooooooo05?ooooo0_l0002cooooo`005Oooool0
0ol0003oooooooooo`1Eooooo`;o0000/Oooool001Gooooo00?o0000ooooooooool0Eoooool2o`00
0:oooooo000Eooooo`03o`000?oooooooooo05Wooooo00?o0000ooooooooool0[?ooool001Gooooo
00?o0000ooooooooool0F_ooool2o`000:cooooo000Eooooo`03o`000?oooooooooo05cooooo0_l0
002Zooooo`005Oooool00ol0003oooooooooo`1Nooooo`;o0000Z?ooool001Gooooo0_l0001Qoooo
o`;o0000Y_ooool001Gooooo00?o0000ooooooooool0H_ooool00ol0003oooooooooo`2Sooooo`00
5Oooool00ol0003oooooooooo`1Sooooo`;o0000Xoooool001Gooooo00?o0000ooooooooool0IOoo
ool2o`000:7ooooo000Eooooo`03o`000?oooooooooo06Oooooo00?o0000ooooooooool0W_ooool0
01Gooooo00?o0000ooooooooool0J?ooool00ol0003oooooooooo`2Mooooo`005Oooool00ol0003o
ooooooooo`1Yooooo`03o`000?oooooooooo09cooooo000Eooooo`03o`000?oooooooooo06[ooooo
00?o0000ooooooooool0Voooool001Gooooo0_l0001/ooooo`03o`000?oooooooooo09[ooooo000E
ooooo`03o`000?oooooooooo06cooooo00?o0000ooooooooool0VOooool001Gooooo00?o0000oooo
ooooool0KOooool2o`0009Wooooo000Eooooo`03o`000?oooooooooo06oooooo00?o0000oooooooo
ool0U_ooool001Gooooo00?o0000ooooooooool0L?ooool00ol0003oooooooooo`2Eooooo`000_oo
ool2o`0000Cooooo00?o0000ooooooooool00oooool3o`0000Cooooo00?o0000ooooooooool0LOoo
ool00ol0003oooooooooo`2Dooooo`0000Goooooo`000?ooooooooooo`00000:ooooo`03o`000?oo
oooooooo00?ooooo00?o0000ooooooooool0L_ooool00ol0003oooooooooo`2Cooooo`0000Gooooo
o`000?ooooooooooo`000007ooooo`Go00001?ooool00ol0003oooooooooo`1cooooo`03o`000?oo
oooooooo09;ooooo00001Ooooooo0000oooooooooooo000000Oooooo00Co0000oooooooooooo0000
1Oooool3o`0007Cooooo00?o0000ooooooooool0TOooool00005ooooool0003oooooooooool00000
2?ooool00ol0003oooooo`000005ooooo`03o`000?oooooooooo07Gooooo00?o0000ooooooooool0
T?ooool00005ooooool0003oooooooooool000002Oooool2o`0000Gooooo00?o0000ooooooooool0
M_ooool00ol0003oooooooooo`2?ooooo`000_ooool2o`0000_ooooo00?o0000ooooooooool00ooo
ool00ol0003oooooooooo`1gooooo`03o`000?oooooooooo08kooooo000Eooooo`03o`000?oooooo
oooo07Sooooo00?o0000ooooooooool0SOooool001Gooooo00?o0000ooooooooool0NOooool00ol0
003oooooooooo`2<ooooo`005Oooool00ol0003oooooooooo`1jooooo`03o`000?oooooooooo08_o
oooo000Eooooo`03o`000?oooooooooo07_ooooo00?o0000ooooooooool0R_ooool001Gooooo0_l0
001mooooo`03o`000?oooooooooo08Wooooo000Eooooo`03o`000?oooooooooo07gooooo00?o0000
ooooooooool0R?ooool001Gooooo00?o0000ooooooooool0O_ooool00ol0003oooooooooo`27oooo
o`005Oooool00ol0003oooooooooo`1oooooo`03o`000?oooooooooo08Kooooo000Eooooo`03o`00
0?oooooooooo07oooooo00?o0000ooooooooool0Q_ooool001Gooooo00?o0000ooooooooool0P?oo
ool00ol0003oooooooooo`25ooooo`005Oooool00ol0003oooooooooo`21ooooo`03o`000?oooooo
oooo08Cooooo000Eooooo`03o`000?oooooooooo08;ooooo00?o0000ooooooooool0Poooool001Go
oooo0_l00024ooooo`03o`000?oooooooooo08;ooooo000Eooooo`03o`000?oooooooooo08?ooooo
00?o0000ooooooooool0P_ooool001Gooooo00?o0000ooooooooool0Q?ooool00ol0003ooooooooo
o`21ooooo`005Oooool00ol0003oooooooooo`25ooooo`03o`000?oooooooooo083ooooo000Eoooo
o`03o`000?oooooooooo08Kooooo00?o0000ooooooooool0Ooooool001Gooooo00?o0000oooooooo
ool0Qoooool00ol0003oooooooooo`1nooooo`005Oooool00ol0003oooooooooo`28ooooo`03o`00
0?oooooooooo07gooooo000Eooooo`03o`000?oooooooooo08Wooooo00?o0000ooooooooool0O?oo
ool001Gooooo0_l0002;ooooo`03o`000?oooooooooo07_ooooo000Eooooo`03o`000?oooooooooo
08_ooooo00?o0000ooooooooool0N_ooool001Gooooo00?o0000ooooooooool0S?ooool00ol0003o
ooooooooo`1iooooo`005Oooool00ol0003oooooooooo`2=ooooo`03o`000?oooooooooo07Sooooo
000Eooooo`03o`000?oooooooooo08kooooo00?o0000ooooooooool0Moooool000;ooooo0_l00004
ooooo`03o`000?oooooooooo00;ooooo0ol00005ooooo`03o`000?oooooooooo08oooooo00?o0000
ooooooooool0M_ooool00005ooooool0003oooooooooool000001oooool01Ol0003ooooooooooooo
oooo000000Cooooo00?o0000ooooooooool0T?ooool2o`0007Kooooo00001Ooooooo0000oooooooo
oooo000000Oooooo00Go0000ooooooooooooooooo`000004ooooo`03o`000?oooooooooo09;ooooo
00?o0000ooooooooool0Loooool00005ooooool0003oooooooooool000001oooool4o`0000Gooooo
0ol0002Cooooo`03o`000?oooooooooo07;ooooo00001Ooooooo0000oooooooooooo000000Oooooo
00?o0000ooooooooool01_ooool00ol0003oooooooooo`2Dooooo`03o`000?oooooooooo077ooooo
00001Ooooooo0000oooooooooooo000000Sooooo00?o0000ooooooooool01Oooool00ol0003ooooo
ooooo`2Eooooo`03o`000?oooooooooo073ooooo0002ooooo`;o00002_ooool2o`0000Gooooo00?o
0000ooooooooool0U_ooool00ol0003oooooooooo`1_ooooo`005Oooool00ol0003oooooooooo`2G
ooooo`03o`000?oooooooooo06kooooo000Eooooo`03o`000?oooooooooo09Sooooo00?o0000oooo
ooooool0KOooool001Gooooo00?o0000ooooooooool0VOooool2o`0006gooooo000Eooooo`03o`00
0?oooooooooo09_ooooo00?o0000ooooooooool0J_ooool001Gooooo0_l0002Mooooo`03o`000?oo
oooooooo06Wooooo000Eooooo`03o`000?oooooooooo09gooooo0_l0001Yooooo`005Oooool00ol0
003oooooooooo`2Oooooo`03o`000?oooooooooo06Kooooo000Eooooo`03o`000?oooooooooo0:3o
oooo00?o0000ooooooooool0IOooool001Gooooo00?o0000ooooooooool0XOooool2o`0006Gooooo
000Eooooo`03o`000?oooooooooo0:?ooooo00?o0000ooooooooool0H_ooool001Gooooo00?o0000
ooooooooool0Y?ooool2o`0006;ooooo000Eooooo`03o`000?oooooooooo0:Kooooo00?o0000oooo
ooooool0Goooool001Gooooo0_l0002Xooooo`;o0000Goooool001Gooooo00?o0000ooooooooool0
ZOooool00ol0003oooooooooo`1Looooo`005Oooool00ol0003oooooooooo`2Zooooo`;o0000G?oo
ool001Gooooo00?o0000ooooooooool0[?ooool00ol0003oooooooooo`1Iooooo`005Oooool00ol0
003oooooooooo`2]ooooo`;o0000FOooool001Gooooo00?o0000ooooooooool0[oooool2o`0005Oo
oooo000Eooooo`03o`000?oooooooooo0;7ooooo00?o0000ooooooooool0E?ooool001Gooooo00?o
0000ooooooooool0/_ooool3o`0005?ooooo000Eooooo`;o0000]_ooool3o`00053ooooo000Eoooo
o`03o`000?oooooooooo0;Sooooo0ol0001=ooooo`005Oooool00ol0003oooooooooo`2kooooo`;o
0000Boooool001Gooooo00?o0000ooooooooool0_Oooool2o`0004Wooooo000Eooooo`03o`000?oo
oooooooo0;oooooo0ol00016ooooo`000_ooool2o`0000Cooooo00?o0000ooooooooool00_ooool3
o`0000Gooooo00?o0000ooooooooool0`_ooool2o`0004Cooooo00001Ooooooo0000oooooooooooo
000000Oooooo00Go0000ooooooooooooooooo`000004ooooo`03o`000?oooooooooo0<Cooooo0_l0
0012ooooo`0000Goooooo`000?ooooooooooo`000007ooooo`05o`000?ooooooooooooooool00000
1?ooool00ol0003oooooooooo`36ooooo`?o0000?oooool00005ooooool0003oooooooooool00000
2?ooool3o`0000Gooooo0ol00039ooooo`?o0000??ooool00005ooooool0003oooooooooool00000
1oooool01Ol0003ooooooooooooooooo000000Cooooo00?o0000ooooooooool0c?ooool3o`0003Wo
oooo00001Ooooooo0000oooooooooooo000000Oooooo00Go0000ooooooooooooooooo`000004oooo
o`03o`000?oooooooooo0<oooooo1Ol0000dooooo`000_ooool2o`0000Wooooo0ol00005ooooo`03
o`000?oooooooooo0=Cooooo1?l0000`ooooo`005Oooool00ol0003oooooooooo`3Hooooo`Go0000
:oooool001Gooooo00?o0000ooooooooool0gOooool6o`0002Gooooo000Eooooo`03o`000?oooooo
oooo0>?ooooo1_l0000Oooooo`005Oooool00ol0003oooooooooo`3Yooooo`Go00006_ooool001Go
oooo0_l0003_ooooo`Oo00004oooool001Gooooo00?o0000ooooooooool0mOooool5o`0000kooooo
000Eooooo`03o`000?oooooooooo0?[ooooo0ol0000;ooooo`005Oooool00ol0003oooooooooo`3m
ooooo`?o00002?ooool001Gooooo00?o0000ooooooooool0ooooool1ooooo`03o`000?oooooooooo
00Gooooo000Eooooo`03o`000?oooooooooo0?oooooo2Oooool001Gooooo00?o0000ooooooooool0
ooooool9ooooo`005Oooool00ol0003oooooooooo`3oooooo`Wooooo000Eooooo`;o0000ooooool:
ooooo`005Oooool00ol0003oooooooooo`3oooooo`Wooooo000Eooooo`03o`000?oooooooooo0?oo
oooo2Oooool001Gooooo00?o0000ooooooooool0ooooool9ooooo`005Oooool00ol0003ooooooooo
o`3oooooo`Wooooo000Eooooo`03o`000?oooooooooo0?oooooo2Oooool001Gooooo00?o0000oooo
ooooool0ooooool9ooooo`005Oooool00ol0003oooooooooo`3oooooo`Wooooo000Eooooo`;o0000
ooooool:ooooo`005Oooool00ol0003oooooooooo`3oooooo`Wooooo000Eooooo`03o`000?oooooo
oooo0?oooooo2Oooool001Gooooo00?o0000ooooooooool0ooooool9ooooo`005Oooool00ol0003o
ooooooooo`3oooooo`Wooooo000=ooooo`?o00001Oooool00ol0003oooooooooo`3oooooo`Wooooo
000>ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0ooooool9ooooo`003_ooool0
0ol0003oooooooooo`04ooooo`03o`000?oooooooooo0?oooooo2Oooool000kooooo00?o0000oooo
ooooool01?ooool3o`000?oooooo2Oooool000kooooo00?o0000ooooooooool0ooooool@ooooo`00
3Oooool2o`000?oooooo4_ooool000kooooo00?o0000ooooooooool0ooooool@ooooo`00oooooolQ
ooooo`00\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-2.49048, -0.0764114, \
0.115739, 0.00624232}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 0.0333333 0 0.618034 [
[.16667 -0.0125 -3 -9 ]
[.16667 -0.0125 3 0 ]
[.33333 -0.0125 -6 -9 ]
[.33333 -0.0125 6 0 ]
[.5 -0.0125 -6 -9 ]
[.5 -0.0125 6 0 ]
[.66667 -0.0125 -6 -9 ]
[.66667 -0.0125 6 0 ]
[.83333 -0.0125 -6 -9 ]
[.83333 -0.0125 6 0 ]
[1 -0.0125 -6 -9 ]
[1 -0.0125 6 0 ]
[-0.0125 .12361 -18 -4.5 ]
[-0.0125 .12361 0 4.5 ]
[-0.0125 .24721 -18 -4.5 ]
[-0.0125 .24721 0 4.5 ]
[-0.0125 .37082 -18 -4.5 ]
[-0.0125 .37082 0 4.5 ]
[-0.0125 .49443 -18 -4.5 ]
[-0.0125 .49443 0 4.5 ]
[-0.0125 .61803 -6 -4.5 ]
[-0.0125 .61803 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.16667 0 m
.16667 .00625 L
s
[(5)] .16667 -0.0125 0 1 Mshowa
.33333 0 m
.33333 .00625 L
s
[(10)] .33333 -0.0125 0 1 Mshowa
.5 0 m
.5 .00625 L
s
[(15)] .5 -0.0125 0 1 Mshowa
.66667 0 m
.66667 .00625 L
s
[(20)] .66667 -0.0125 0 1 Mshowa
.83333 0 m
.83333 .00625 L
s
[(25)] .83333 -0.0125 0 1 Mshowa
1 0 m
1 .00625 L
s
[(30)] 1 -0.0125 0 1 Mshowa
.125 Mabswid
.03333 0 m
.03333 .00375 L
s
.06667 0 m
.06667 .00375 L
s
.1 0 m
.1 .00375 L
s
.13333 0 m
.13333 .00375 L
s
.2 0 m
.2 .00375 L
s
.23333 0 m
.23333 .00375 L
s
.26667 0 m
.26667 .00375 L
s
.3 0 m
.3 .00375 L
s
.36667 0 m
.36667 .00375 L
s
.4 0 m
.4 .00375 L
s
.43333 0 m
.43333 .00375 L
s
.46667 0 m
.46667 .00375 L
s
.53333 0 m
.53333 .00375 L
s
.56667 0 m
.56667 .00375 L
s
.6 0 m
.6 .00375 L
s
.63333 0 m
.63333 .00375 L
s
.7 0 m
.7 .00375 L
s
.73333 0 m
.73333 .00375 L
s
.76667 0 m
.76667 .00375 L
s
.8 0 m
.8 .00375 L
s
.86667 0 m
.86667 .00375 L
s
.9 0 m
.9 .00375 L
s
.93333 0 m
.93333 .00375 L
s
.96667 0 m
.96667 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .12361 m
.00625 .12361 L
s
[(0.2)] -0.0125 .12361 1 0 Mshowa
0 .24721 m
.00625 .24721 L
s
[(0.4)] -0.0125 .24721 1 0 Mshowa
0 .37082 m
.00625 .37082 L
s
[(0.6)] -0.0125 .37082 1 0 Mshowa
0 .49443 m
.00625 .49443 L
s
[(0.8)] -0.0125 .49443 1 0 Mshowa
0 .61803 m
.00625 .61803 L
s
[(1)] -0.0125 .61803 1 0 Mshowa
.125 Mabswid
0 .0309 m
.00375 .0309 L
s
0 .0618 m
.00375 .0618 L
s
0 .09271 m
.00375 .09271 L
s
0 .15451 m
.00375 .15451 L
s
0 .18541 m
.00375 .18541 L
s
0 .21631 m
.00375 .21631 L
s
0 .27812 m
.00375 .27812 L
s
0 .30902 m
.00375 .30902 L
s
0 .33992 m
.00375 .33992 L
s
0 .40172 m
.00375 .40172 L
s
0 .43262 m
.00375 .43262 L
s
0 .46353 m
.00375 .46353 L
s
0 .52533 m
.00375 .52533 L
s
0 .55623 m
.00375 .55623 L
s
0 .58713 m
.00375 .58713 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.03333 .07736 m
.06667 .08731 L
.1 .09325 L
.13333 .09889 L
.16667 .10521 L
.2 .11266 L
.23333 .12155 L
.26667 .13217 L
.3 .14484 L
.33333 .1599 L
.36667 .17778 L
.4 .19896 L
.43333 .22401 L
.46667 .2536 L
.5 .28849 L
.53333 .32954 L
.56667 .36443 L
.6 .39402 L
.63333 .41907 L
.66667 .44025 L
.7 .45813 L
.73333 .4732 L
.76667 .48586 L
.8 .49649 L
.83333 .50537 L
.86667 .51282 L
.9 .51914 L
.93333 .52479 L
.96667 .53072 L
1 .54067 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[6]:=",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/B000`400?l00000o`00003ooooooolQ
ooooo`00?_ooool3o`0002Gooooo0ol00004ooooo`;o00008oooool3o`0000?ooooo0ol0000Qoooo
o`Go00000oooool2o`00027ooooo1Ol00002ooooo`?o00008_ooool3o`0000Cooooo0_l00004oooo
o`00?Oooool01Ol0003ooooooooooooooooo000002Gooooo00?o0000ooooooooool00_ooool01?l0
003oooooooooool0000Sooooo`05o`000?ooooooooooooooool000000oooool00ol0003ooooooooo
o`0Oooooo`04o`000?ooooooooooo`0000;ooooo00Co0000oooooooooooo00008Oooool01_l0003o
ooooooooool0003oooooo`0000?ooooo00?o0000ooooooooool07_ooool01Ol0003ooooooooooooo
oooo000000;ooooo00Co0000oooooooooooo00000oooool0047ooooo00?o0000ooooooooool08ooo
ool00ol0003oooooooooo`02ooooo`04o`000?ooooooooooo`0002?ooooo00?o0000ooooooooool0
1Oooool00ol0003oooooooooo`0Pooooo`03o`000?oooooooooo00;ooooo00Co0000oooooooooooo
00008_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo02;ooooo00Co0000oooooooo
oooo00000_ooool00ol0003oooooooooo`01ooooo`00@Oooool00ol0003oooooooooo`0Sooooo`03
o`000?oooooooooo00;ooooo00Co0000oooooooooooo00008oooool00ol0003oooooooooo`05oooo
o`03o`000?oooooooooo027ooooo00Go0000ooooooooooooooooo`000002ooooo`03o`000?oooooo
oooo027ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`0Pooooo`;o00000oooool0
1?l0003oooooooooool00003ooooo`00?Oooool4o`0002Kooooo00?o0000ooooooooool00_ooool0
1?l0003oooooooooool0000Sooooo`04o`000?ooooooooooooooo`Co00008Oooool01Ol0003ooooo
oooooooooooo000000;ooooo00Co0000oooooooooooo00008?ooool01_l0003ooooooooooooooooo
0000ooooo`Co00009Oooool01?l0003oooooooooool00002ooooo`03o`000?oooooooooo007ooooo
000mooooo`03o`000?oooooooooo02Kooooo0_l00004ooooo`04o`000?ooooooooooo`0002;ooooo
0_l00003ooooo`03o`000?oooooooooo02;ooooo00Go0000ooooooooooooooooo`000002ooooo`04
o`000?ooooooooooo`00023ooooo00Oo0000ooooooooooooooooo`000?oooooo000002Cooooo00Go
0000ooooooooooooooooo`000002ooooo`04o`000?ooooooooooo`0000?ooooo000mooooo`Go0000
9Oooool00ol0003oooooooooo`03ooooo`;o00009?ooool01?l0003oooooooooooooool5o`00027o
oooo0ol00004ooooo`;o00008_ooool3o`0000;ooooo1Ol0000Qooooo`?o00001?ooool2o`0000Co
oooo003oooooob7ooooo003oooooob7ooooo003oooooob7ooooo003oooooob7ooooo000Eoooooooo
00001Ol00007ooooo`005Oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Gooooo
00?o0000ooooooooool01_ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Gooooo
00?o0000ooooooooool01_ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Gooooo
00?o0000ooooooooool01_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Kooooo
00?o0000ooooooooool01_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Kooooo
00?o0000ooooooooool01_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Kooooo
00?o0000ooooooooool01_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Kooooo
00?o0000ooooooooool01Oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Kooooo
00?o0000ooooooooool01Oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Kooooo
00?o0000ooooooooool01Oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Kooooo
00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`005Oooool00ol0003ooooooooo
o`3oooooo`Wooooo000Eooooo`03o`000?oooooooooo0?oooooo2Oooool001Gooooo00?o0000oooo
ooooool0ooooool9ooooo`005Oooool00ol0003oooooooooo`3oooooo`Wooooo000Eooooo`03o`00
0?oooooooooo0?oooooo2Oooool001Gooooo00?o0000ooooooooool0ooooool9ooooo`005Oooool2
o`000?oooooo2_ooool001Gooooo00?o0000ooooooooool0ooooool9ooooo`005Oooool00ol0003o
ooooooooo`3oooooo`Wooooo000Eooooo`03o`000?oooooooooo0?oooooo2Oooool001Gooooo00?o
0000ooooooooool0ooooool9ooooo`005Oooool00ol0003oooooooooo`3oooooo`Wooooo000Eoooo
o`03o`000?oooooooooo0?oooooo2Oooool001Gooooo00?o0000ooooooooool0ooooool9ooooo`00
5Oooool2o`000?oooooo2_ooool001Gooooo00?o0000ooooooooool0ooooool9ooooo`005Oooool0
0ol0003oooooooooo`3oooooo`Wooooo000Eooooo`03o`000?oooooooooo0?oooooo2Oooool001Go
oooo00?o0000ooooooooool01_ooool3o`000?oooooo000Eooooo`03o`000?oooooooooo00Wooooo
1?l0003kooooo`005Oooool00ol0003oooooooooo`0=ooooo`Co0000moooool001Gooooo00?o0000
ooooooooool04Oooool5o`000?;ooooo000Eooooo`;o00005oooool7o`000>_ooooo000Eooooo`03
o`000?oooooooooo01gooooo1_l0003Uooooo`005Oooool00ol0003oooooooooo`0Sooooo`Co0000
hOooool001Gooooo00?o0000ooooooooool09oooool4o`000=gooooo000Eooooo`03o`000?oooooo
oooo02_ooooo1Ol0003Hooooo`000_ooool2o`0000Cooooo00Co0000oooooooooooooooo1Ol00004
ooooo`03o`000?oooooooooo033ooooo1?l0003Dooooo`0000Goooooo`000?ooooooooooo`000008
ooooo`04o`000?ooooooooooo`0000Cooooo00?o0000ooooooooool0=?ooool5o`000<oooooo0000
1Ooooooo0000oooooooooooo000000Wooooo00?o0000ooooooooool01?ooool00ol0003ooooooooo
o`0iooooo`?o0000c?ooool00005ooooool0003oooooooooool000002_ooool00ol0003ooooooooo
o`03ooooo`?o0000??ooool3o`000<Wooooo00001Ooooooo0000oooooooooooo000000Oooooo00Go
0000ooooooooooooooooo`000004ooooo`03o`000?oooooooooo03oooooo0ol00036ooooo`0000Go
ooooo`000?ooooooooooo`000007ooooo`05o`000?ooooooooooooooool000001?ooool00ol0003o
ooooooooo`12ooooo`?o0000`oooool000;ooooo0_l00009ooooo`?o00001Oooool00ol0003ooooo
ooooo`15ooooo`?o0000`?ooool001Gooooo00?o0000ooooooooool0B?ooool3o`000;gooooo000E
ooooo`03o`000?oooooooooo04_ooooo0_l0002kooooo`005Oooool00ol0003oooooooooo`1=oooo
o`;o0000^Oooool001Gooooo00?o0000ooooooooool0Coooool2o`000;Oooooo000Eooooo`;o0000
D_ooool2o`000;Gooooo000Eooooo`03o`000?oooooooooo05?ooooo0_l0002cooooo`005Oooool0
0ol0003oooooooooo`1Eooooo`;o0000/Oooool001Gooooo00?o0000ooooooooool0Eoooool2o`00
0:oooooo000Eooooo`03o`000?oooooooooo05Wooooo00?o0000ooooooooool0[?ooool001Gooooo
00?o0000ooooooooool0F_ooool2o`000:cooooo000Eooooo`03o`000?oooooooooo05cooooo0_l0
002Zooooo`005Oooool00ol0003oooooooooo`1Nooooo`;o0000Z?ooool001Gooooo0_l0001Qoooo
o`;o0000Y_ooool001Gooooo00?o0000ooooooooool0H_ooool00ol0003oooooooooo`2Sooooo`00
5Oooool00ol0003oooooooooo`1Sooooo`;o0000Xoooool001Gooooo00?o0000ooooooooool0IOoo
ool2o`000:7ooooo000Eooooo`03o`000?oooooooooo06Oooooo00?o0000ooooooooool0W_ooool0
01Gooooo00?o0000ooooooooool0J?ooool00ol0003oooooooooo`2Mooooo`005Oooool00ol0003o
ooooooooo`1Yooooo`03o`000?oooooooooo09cooooo000Eooooo`03o`000?oooooooooo06[ooooo
00?o0000ooooooooool0Voooool001Gooooo0_l0001/ooooo`03o`000?oooooooooo09[ooooo000E
ooooo`03o`000?oooooooooo06cooooo00?o0000ooooooooool0VOooool001Gooooo00?o0000oooo
ooooool0KOooool2o`0009Wooooo000Eooooo`03o`000?oooooooooo06oooooo00?o0000oooooooo
ool0U_ooool001Gooooo00?o0000ooooooooool0L?ooool00ol0003oooooooooo`2Eooooo`000_oo
ool2o`0000Cooooo00?o0000ooooooooool00oooool3o`0000Cooooo00?o0000ooooooooool0LOoo
ool00ol0003oooooooooo`2Dooooo`0000Goooooo`000?ooooooooooo`00000:ooooo`03o`000?oo
oooooooo00?ooooo00?o0000ooooooooool0L_ooool00ol0003oooooooooo`2Cooooo`0000Gooooo
o`000?ooooooooooo`000007ooooo`Go00001?ooool00ol0003oooooooooo`1cooooo`03o`000?oo
oooooooo09;ooooo00001Ooooooo0000oooooooooooo000000Oooooo00Co0000oooooooooooo0000
1Oooool3o`0007Cooooo00?o0000ooooooooool0TOooool00005ooooool0003oooooooooool00000
2?ooool00ol0003oooooo`000005ooooo`03o`000?oooooooooo07Gooooo00?o0000ooooooooool0
T?ooool00005ooooool0003oooooooooool000002Oooool2o`0000Gooooo00?o0000ooooooooool0
M_ooool00ol0003oooooooooo`2?ooooo`000_ooool2o`0000_ooooo00?o0000ooooooooool00ooo
ool00ol0003oooooooooo`1gooooo`03o`000?oooooooooo08kooooo000Eooooo`03o`000?oooooo
oooo07Sooooo00?o0000ooooooooool0SOooool001Gooooo00?o0000ooooooooool0NOooool00ol0
003oooooooooo`2<ooooo`005Oooool00ol0003oooooooooo`1jooooo`03o`000?oooooooooo08_o
oooo000Eooooo`03o`000?oooooooooo07_ooooo00?o0000ooooooooool0R_ooool001Gooooo0_l0
001mooooo`03o`000?oooooooooo08Wooooo000Eooooo`03o`000?oooooooooo07gooooo00?o0000
ooooooooool0R?ooool001Gooooo00?o0000ooooooooool0O_ooool00ol0003oooooooooo`27oooo
o`005Oooool00ol0003oooooooooo`1oooooo`03o`000?oooooooooo08Kooooo000Eooooo`03o`00
0?oooooooooo07oooooo00?o0000ooooooooool0Q_ooool001Gooooo00?o0000ooooooooool0P?oo
ool00ol0003oooooooooo`25ooooo`005Oooool00ol0003oooooooooo`21ooooo`03o`000?oooooo
oooo08Cooooo000Eooooo`03o`000?oooooooooo08;ooooo00?o0000ooooooooool0Poooool001Go
oooo0_l00024ooooo`03o`000?oooooooooo08;ooooo000Eooooo`03o`000?oooooooooo08?ooooo
00?o0000ooooooooool0P_ooool001Gooooo00?o0000ooooooooool0Q?ooool00ol0003ooooooooo
o`21ooooo`005Oooool00ol0003oooooooooo`25ooooo`03o`000?oooooooooo083ooooo000Eoooo
o`03o`000?oooooooooo08Kooooo00?o0000ooooooooool0Ooooool001Gooooo00?o0000oooooooo
ool0Qoooool00ol0003oooooooooo`1nooooo`005Oooool00ol0003oooooooooo`28ooooo`03o`00
0?oooooooooo07gooooo000Eooooo`03o`000?oooooooooo08Wooooo00?o0000ooooooooool0O?oo
ool001Gooooo0_l0002;ooooo`03o`000?oooooooooo07_ooooo000Eooooo`03o`000?oooooooooo
08_ooooo00?o0000ooooooooool0N_ooool001Gooooo00?o0000ooooooooool0S?ooool00ol0003o
ooooooooo`1iooooo`005Oooool00ol0003oooooooooo`2=ooooo`03o`000?oooooooooo07Sooooo
000Eooooo`03o`000?oooooooooo08kooooo00?o0000ooooooooool0Moooool000;ooooo0_l00004
ooooo`03o`000?oooooooooo00;ooooo0ol00005ooooo`03o`000?oooooooooo08oooooo00?o0000
ooooooooool0M_ooool00005ooooool0003oooooooooool000001oooool01Ol0003ooooooooooooo
oooo000000Cooooo00?o0000ooooooooool0T?ooool2o`0007Kooooo00001Ooooooo0000oooooooo
oooo000000Oooooo00Go0000ooooooooooooooooo`000004ooooo`03o`000?oooooooooo09;ooooo
00?o0000ooooooooool0Loooool00005ooooool0003oooooooooool000001oooool4o`0000Gooooo
0ol0002Cooooo`03o`000?oooooooooo07;ooooo00001Ooooooo0000oooooooooooo000000Oooooo
00?o0000ooooooooool01_ooool00ol0003oooooooooo`2Dooooo`03o`000?oooooooooo077ooooo
00001Ooooooo0000oooooooooooo000000Sooooo00?o0000ooooooooool01Oooool00ol0003ooooo
ooooo`2Eooooo`03o`000?oooooooooo073ooooo0002ooooo`;o00002_ooool2o`0000Gooooo00?o
0000ooooooooool0U_ooool00ol0003oooooooooo`1_ooooo`005Oooool00ol0003oooooooooo`2G
ooooo`03o`000?oooooooooo06kooooo000Eooooo`03o`000?oooooooooo09Sooooo00?o0000oooo
ooooool0KOooool001Gooooo00?o0000ooooooooool0VOooool2o`0006gooooo000Eooooo`03o`00
0?oooooooooo09_ooooo00?o0000ooooooooool0J_ooool001Gooooo0_l0002Mooooo`03o`000?oo
oooooooo06Wooooo000Eooooo`03o`000?oooooooooo09gooooo0_l0001Yooooo`005Oooool00ol0
003oooooooooo`2Oooooo`03o`000?oooooooooo06Kooooo000Eooooo`03o`000?oooooooooo0:3o
oooo00?o0000ooooooooool0IOooool001Gooooo00?o0000ooooooooool0XOooool2o`0006Gooooo
000Eooooo`03o`000?oooooooooo0:?ooooo00?o0000ooooooooool0H_ooool001Gooooo00?o0000
ooooooooool0Y?ooool2o`0006;ooooo000Eooooo`03o`000?oooooooooo0:Kooooo00?o0000oooo
ooooool0Goooool001Gooooo0_l0002Xooooo`;o0000Goooool001Gooooo00?o0000ooooooooool0
ZOooool00ol0003oooooooooo`1Looooo`005Oooool00ol0003oooooooooo`2Zooooo`;o0000G?oo
ool001Gooooo00?o0000ooooooooool0[?ooool00ol0003oooooooooo`1Iooooo`005Oooool00ol0
003oooooooooo`2]ooooo`;o0000FOooool001Gooooo00?o0000ooooooooool0[oooool2o`0005Oo
oooo000Eooooo`03o`000?oooooooooo0;7ooooo00?o0000ooooooooool0E?ooool001Gooooo00?o
0000ooooooooool0/_ooool3o`0005?ooooo000Eooooo`;o0000]_ooool3o`00053ooooo000Eoooo
o`03o`000?oooooooooo0;Sooooo0ol0001=ooooo`005Oooool00ol0003oooooooooo`2kooooo`;o
0000Boooool001Gooooo00?o0000ooooooooool0_Oooool2o`0004Wooooo000Eooooo`03o`000?oo
oooooooo0;oooooo0ol00016ooooo`000_ooool2o`0000Cooooo00?o0000ooooooooool00_ooool3
o`0000Gooooo00?o0000ooooooooool0`_ooool2o`0004Cooooo00001Ooooooo0000oooooooooooo
000000Oooooo00Go0000ooooooooooooooooo`000004ooooo`03o`000?oooooooooo0<Cooooo0ol0
0011ooooo`0000Goooooo`000?ooooooooooo`000007ooooo`05o`000?ooooooooooooooool00000
1?ooool00ol0003oooooooooo`37ooooo`Co0000?Oooool00005ooooool0003oooooooooool00000
2?ooool3o`0000Gooooo0ol0003;ooooo`Co0000>Oooool00005ooooool0003oooooooooool00000
1oooool01Ol0003ooooooooooooooooo000000Cooooo00?o0000ooooooooool0coooool3o`0003Ko
oooo00001Ooooooo0000oooooooooooo000000Oooooo00Go0000ooooooooooooooooo`000004oooo
o`03o`000?oooooooooo0=;ooooo0ol0000cooooo`000_ooool2o`0000Wooooo0ol00005ooooo`03
o`000?oooooooooo0=Gooooo0ol0000`ooooo`005Oooool00ol0003oooooooooo`3Hooooo`Go0000
:oooool001Gooooo00?o0000ooooooooool0gOooool6o`0002Gooooo000Eooooo`03o`000?oooooo
oooo0>?ooooo1_l0000Oooooo`005Oooool00ol0003oooooooooo`3Yooooo`Go00006_ooool001Go
oooo0_l0003_ooooo`Oo00004oooool001Gooooo00?o0000ooooooooool0mOooool5o`0000kooooo
000Eooooo`03o`000?oooooooooo0?[ooooo0ol0000;ooooo`005Oooool00ol0003oooooooooo`3m
ooooo`?o00002?ooool001Gooooo00?o0000ooooooooool0ooooool1ooooo`03o`000?oooooooooo
00Gooooo000Eooooo`03o`000?oooooooooo0?oooooo2Oooool001Gooooo00?o0000ooooooooool0
ooooool9ooooo`005Oooool00ol0003oooooooooo`3oooooo`Wooooo000Eooooo`;o0000ooooool:
ooooo`005Oooool00ol0003oooooooooo`3oooooo`Wooooo000Eooooo`03o`000?oooooooooo0?oo
oooo2Oooool001Gooooo00?o0000ooooooooool0ooooool9ooooo`005Oooool00ol0003ooooooooo
o`3oooooo`Wooooo000Eooooo`03o`000?oooooooooo0?oooooo2Oooool001Gooooo00?o0000oooo
ooooool0ooooool9ooooo`005Oooool00ol0003oooooooooo`3oooooo`Wooooo000Eooooo`;o0000
ooooool:ooooo`005Oooool00ol0003oooooooooo`3oooooo`Wooooo000Eooooo`03o`000?oooooo
oooo0?oooooo2Oooool001Gooooo00?o0000ooooooooool0ooooool9ooooo`005Oooool00ol0003o
ooooooooo`3oooooo`Wooooo000=ooooo`?o00001Oooool00ol0003oooooooooo`3oooooo`Wooooo
000>ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0ooooool9ooooo`003_ooool0
0ol0003oooooooooo`04ooooo`03o`000?oooooooooo0?oooooo2Oooool000kooooo00?o0000oooo
ooooool01?ooool3o`000?oooooo2Oooool000kooooo00?o0000ooooooooool0ooooool@ooooo`00
3Oooool2o`000?oooooo4_ooool000kooooo00?o0000ooooooooool0ooooool@ooooo`00oooooolQ
ooooo`00\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-2.49048, -0.0764114, \
0.115739, 0.00624232}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 0.0333333 0 0.618034 [
[.16667 -0.0125 -3 -9 ]
[.16667 -0.0125 3 0 ]
[.33333 -0.0125 -6 -9 ]
[.33333 -0.0125 6 0 ]
[.5 -0.0125 -6 -9 ]
[.5 -0.0125 6 0 ]
[.66667 -0.0125 -6 -9 ]
[.66667 -0.0125 6 0 ]
[.83333 -0.0125 -6 -9 ]
[.83333 -0.0125 6 0 ]
[1 -0.0125 -6 -9 ]
[1 -0.0125 6 0 ]
[-0.0125 .12361 -18 -4.5 ]
[-0.0125 .12361 0 4.5 ]
[-0.0125 .24721 -18 -4.5 ]
[-0.0125 .24721 0 4.5 ]
[-0.0125 .37082 -18 -4.5 ]
[-0.0125 .37082 0 4.5 ]
[-0.0125 .49443 -18 -4.5 ]
[-0.0125 .49443 0 4.5 ]
[-0.0125 .61803 -6 -4.5 ]
[-0.0125 .61803 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.16667 0 m
.16667 .00625 L
s
[(5)] .16667 -0.0125 0 1 Mshowa
.33333 0 m
.33333 .00625 L
s
[(10)] .33333 -0.0125 0 1 Mshowa
.5 0 m
.5 .00625 L
s
[(15)] .5 -0.0125 0 1 Mshowa
.66667 0 m
.66667 .00625 L
s
[(20)] .66667 -0.0125 0 1 Mshowa
.83333 0 m
.83333 .00625 L
s
[(25)] .83333 -0.0125 0 1 Mshowa
1 0 m
1 .00625 L
s
[(30)] 1 -0.0125 0 1 Mshowa
.125 Mabswid
.03333 0 m
.03333 .00375 L
s
.06667 0 m
.06667 .00375 L
s
.1 0 m
.1 .00375 L
s
.13333 0 m
.13333 .00375 L
s
.2 0 m
.2 .00375 L
s
.23333 0 m
.23333 .00375 L
s
.26667 0 m
.26667 .00375 L
s
.3 0 m
.3 .00375 L
s
.36667 0 m
.36667 .00375 L
s
.4 0 m
.4 .00375 L
s
.43333 0 m
.43333 .00375 L
s
.46667 0 m
.46667 .00375 L
s
.53333 0 m
.53333 .00375 L
s
.56667 0 m
.56667 .00375 L
s
.6 0 m
.6 .00375 L
s
.63333 0 m
.63333 .00375 L
s
.7 0 m
.7 .00375 L
s
.73333 0 m
.73333 .00375 L
s
.76667 0 m
.76667 .00375 L
s
.8 0 m
.8 .00375 L
s
.86667 0 m
.86667 .00375 L
s
.9 0 m
.9 .00375 L
s
.93333 0 m
.93333 .00375 L
s
.96667 0 m
.96667 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .12361 m
.00625 .12361 L
s
[(0.2)] -0.0125 .12361 1 0 Mshowa
0 .24721 m
.00625 .24721 L
s
[(0.4)] -0.0125 .24721 1 0 Mshowa
0 .37082 m
.00625 .37082 L
s
[(0.6)] -0.0125 .37082 1 0 Mshowa
0 .49443 m
.00625 .49443 L
s
[(0.8)] -0.0125 .49443 1 0 Mshowa
0 .61803 m
.00625 .61803 L
s
[(1)] -0.0125 .61803 1 0 Mshowa
.125 Mabswid
0 .0309 m
.00375 .0309 L
s
0 .0618 m
.00375 .0618 L
s
0 .09271 m
.00375 .09271 L
s
0 .15451 m
.00375 .15451 L
s
0 .18541 m
.00375 .18541 L
s
0 .21631 m
.00375 .21631 L
s
0 .27812 m
.00375 .27812 L
s
0 .30902 m
.00375 .30902 L
s
0 .33992 m
.00375 .33992 L
s
0 .40172 m
.00375 .40172 L
s
0 .43262 m
.00375 .43262 L
s
0 .46353 m
.00375 .46353 L
s
0 .52533 m
.00375 .52533 L
s
0 .55623 m
.00375 .55623 L
s
0 .58713 m
.00375 .58713 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.03333 .07683 m
.06667 .0871 L
.1 .09318 L
.13333 .0989 L
.16667 .10526 L
.2 .11273 L
.23333 .12163 L
.26667 .13226 L
.3 .14492 L
.33333 .15998 L
.36667 .17785 L
.4 .19902 L
.43333 .22406 L
.46667 .25363 L
.5 .2885 L
.53333 .32953 L
.56667 .3644 L
.6 .39398 L
.63333 .41901 L
.66667 .44018 L
.7 .45805 L
.73333 .47311 L
.76667 .48578 L
.8 .4964 L
.83333 .5053 L
.86667 .51277 L
.9 .51914 L
.93333 .52485 L
.96667 .53093 L
1 .5412 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[6]:=",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/B000`400?l00000o`00003ooooooolQ
ooooo`00?_ooool3o`0002Gooooo0ol00004ooooo`;o00008oooool3o`0000?ooooo0ol0000Qoooo
o`Go00000oooool2o`00027ooooo1Ol00002ooooo`?o00008_ooool3o`0000Cooooo0_l00004oooo
o`00?Oooool01Ol0003ooooooooooooooooo000002Gooooo00?o0000ooooooooool00_ooool01?l0
003oooooooooool0000Sooooo`05o`000?ooooooooooooooool000000oooool00ol0003ooooooooo
o`0Oooooo`04o`000?ooooooooooo`0000;ooooo00Co0000oooooooooooo00008Oooool01_l0003o
ooooooooool0003oooooo`0000?ooooo00?o0000ooooooooool07_ooool01Ol0003ooooooooooooo
oooo000000;ooooo00Co0000oooooooooooo00000oooool0047ooooo00?o0000ooooooooool08ooo
ool00ol0003oooooooooo`02ooooo`04o`000?ooooooooooo`0002?ooooo00?o0000ooooooooool0
1Oooool00ol0003oooooooooo`0Pooooo`03o`000?oooooooooo00;ooooo00Co0000oooooooooooo
00008_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo02;ooooo00Co0000oooooooo
oooo00000_ooool00ol0003oooooooooo`01ooooo`00@Oooool00ol0003oooooooooo`0Sooooo`03
o`000?oooooooooo00;ooooo00Co0000oooooooooooo00008oooool00ol0003oooooooooo`05oooo
o`03o`000?oooooooooo027ooooo00Go0000ooooooooooooooooo`000002ooooo`03o`000?oooooo
oooo027ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`0Pooooo`;o00000oooool0
1?l0003oooooooooool00003ooooo`00?Oooool4o`0002Kooooo00?o0000ooooooooool00_ooool0
1?l0003oooooooooool0000Sooooo`04o`000?ooooooooooooooo`Co00008Oooool01Ol0003ooooo
oooooooooooo000000;ooooo00Co0000oooooooooooo00008?ooool01_l0003ooooooooooooooooo
0000ooooo`Co00009Oooool01?l0003oooooooooool00002ooooo`03o`000?oooooooooo007ooooo
000mooooo`03o`000?oooooooooo02Kooooo0_l00004ooooo`04o`000?ooooooooooo`0002;ooooo
0_l00003ooooo`03o`000?oooooooooo02;ooooo00Go0000ooooooooooooooooo`000002ooooo`04
o`000?ooooooooooo`00023ooooo00Oo0000ooooooooooooooooo`000?oooooo000002Cooooo00Go
0000ooooooooooooooooo`000002ooooo`04o`000?ooooooooooo`0000?ooooo000mooooo`Go0000
9Oooool00ol0003oooooooooo`03ooooo`;o00009?ooool01?l0003oooooooooooooool5o`00027o
oooo0ol00004ooooo`;o00008_ooool3o`0000;ooooo1Ol0000Qooooo`?o00001?ooool2o`0000Co
oooo003oooooob7ooooo003oooooob7ooooo003oooooob7ooooo003oooooob7ooooo000Eoooooooo
00001Ol00007ooooo`005Oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Gooooo
00?o0000ooooooooool01_ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Gooooo
00?o0000ooooooooool01_ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Gooooo
00?o0000ooooooooool01_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Kooooo
00?o0000ooooooooool01_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Kooooo
00?o0000ooooooooool01_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Kooooo
00?o0000ooooooooool01_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Kooooo
00?o0000ooooooooool01Oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Kooooo
00?o0000ooooooooool01Oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Kooooo
00?o0000ooooooooool01Oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Kooooo
00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`005Oooool00ol0003ooooooooo
o`3oooooo`Wooooo000Eooooo`03o`000?oooooooooo0?oooooo2Oooool001Gooooo00?o0000oooo
ooooool0ooooool9ooooo`005Oooool00ol0003oooooooooo`3oooooo`Wooooo000Eooooo`03o`00
0?oooooooooo0?oooooo2Oooool001Gooooo00?o0000ooooooooool0ooooool9ooooo`005Oooool2
o`000?oooooo2_ooool001Gooooo00?o0000ooooooooool0ooooool9ooooo`005Oooool00ol0003o
ooooooooo`3oooooo`Wooooo000Eooooo`03o`000?oooooooooo0?oooooo2Oooool001Gooooo00?o
0000ooooooooool0ooooool9ooooo`005Oooool00ol0003oooooooooo`3oooooo`Wooooo000Eoooo
o`03o`000?oooooooooo0?oooooo2Oooool001Gooooo00?o0000ooooooooool0ooooool9ooooo`00
5Oooool2o`000?oooooo2_ooool001Gooooo00?o0000ooooooooool0ooooool9ooooo`005Oooool0
0ol0003oooooooooo`3oooooo`Wooooo000Eooooo`03o`000?oooooooooo0?oooooo2Oooool001Go
oooo00?o0000ooooooooool01_ooool3o`000?oooooo000Eooooo`03o`000?oooooooooo00Wooooo
1?l0003kooooo`005Oooool00ol0003oooooooooo`0=ooooo`Co0000moooool001Gooooo00?o0000
ooooooooool04Oooool5o`000?;ooooo000Eooooo`;o00005oooool7o`000>_ooooo000Eooooo`03
o`000?oooooooooo01gooooo1_l0003Uooooo`005Oooool00ol0003oooooooooo`0Sooooo`Co0000
hOooool001Gooooo00?o0000ooooooooool09oooool4o`000=gooooo000Eooooo`03o`000?oooooo
oooo02_ooooo1Ol0003Hooooo`000_ooool2o`0000Cooooo00Co0000oooooooooooooooo1Ol00004
ooooo`03o`000?oooooooooo033ooooo1?l0003Dooooo`0000Goooooo`000?ooooooooooo`000008
ooooo`04o`000?ooooooooooo`0000Cooooo00?o0000ooooooooool0=?ooool5o`000<oooooo0000
1Ooooooo0000oooooooooooo000000Wooooo00?o0000ooooooooool01?ooool00ol0003ooooooooo
o`0iooooo`?o0000c?ooool00005ooooool0003oooooooooool000002_ooool00ol0003ooooooooo
o`03ooooo`?o0000??ooool3o`000<Wooooo00001Ooooooo0000oooooooooooo000000Oooooo00Go
0000ooooooooooooooooo`000004ooooo`03o`000?oooooooooo03oooooo0ol00036ooooo`0000Go
ooooo`000?ooooooooooo`000007ooooo`05o`000?ooooooooooooooool000001?ooool00ol0003o
ooooooooo`12ooooo`?o0000`oooool000;ooooo0_l00009ooooo`?o00001Oooool00ol0003ooooo
ooooo`15ooooo`?o0000`?ooool001Gooooo00?o0000ooooooooool0B?ooool3o`000;gooooo000E
ooooo`03o`000?oooooooooo04_ooooo0_l0002kooooo`005Oooool00ol0003oooooooooo`1=oooo
o`;o0000^Oooool001Gooooo00?o0000ooooooooool0Coooool2o`000;Oooooo000Eooooo`;o0000
D_ooool2o`000;Gooooo000Eooooo`03o`000?oooooooooo05?ooooo0_l0002cooooo`005Oooool0
0ol0003oooooooooo`1Eooooo`;o0000/Oooool001Gooooo00?o0000ooooooooool0Eoooool2o`00
0:oooooo000Eooooo`03o`000?oooooooooo05Wooooo00?o0000ooooooooool0[?ooool001Gooooo
00?o0000ooooooooool0F_ooool2o`000:cooooo000Eooooo`03o`000?oooooooooo05cooooo0_l0
002Zooooo`005Oooool00ol0003oooooooooo`1Nooooo`;o0000Z?ooool001Gooooo0_l0001Qoooo
o`;o0000Y_ooool001Gooooo00?o0000ooooooooool0H_ooool00ol0003oooooooooo`2Sooooo`00
5Oooool00ol0003oooooooooo`1Sooooo`;o0000Xoooool001Gooooo00?o0000ooooooooool0IOoo
ool2o`000:7ooooo000Eooooo`03o`000?oooooooooo06Oooooo00?o0000ooooooooool0W_ooool0
01Gooooo00?o0000ooooooooool0J?ooool00ol0003oooooooooo`2Mooooo`005Oooool00ol0003o
ooooooooo`1Yooooo`03o`000?oooooooooo09cooooo000Eooooo`03o`000?oooooooooo06[ooooo
00?o0000ooooooooool0Voooool001Gooooo0_l0001/ooooo`03o`000?oooooooooo09[ooooo000E
ooooo`03o`000?oooooooooo06cooooo00?o0000ooooooooool0VOooool001Gooooo00?o0000oooo
ooooool0KOooool2o`0009Wooooo000Eooooo`03o`000?oooooooooo06oooooo00?o0000oooooooo
ool0U_ooool001Gooooo00?o0000ooooooooool0L?ooool00ol0003oooooooooo`2Eooooo`000_oo
ool2o`0000Cooooo00?o0000ooooooooool00oooool3o`0000Cooooo00?o0000ooooooooool0LOoo
ool00ol0003oooooooooo`2Dooooo`0000Goooooo`000?ooooooooooo`00000:ooooo`03o`000?oo
oooooooo00?ooooo00?o0000ooooooooool0L_ooool00ol0003oooooooooo`2Cooooo`0000Gooooo
o`000?ooooooooooo`000007ooooo`Go00001?ooool00ol0003oooooooooo`1cooooo`03o`000?oo
oooooooo09;ooooo00001Ooooooo0000oooooooooooo000000Oooooo00Co0000oooooooooooo0000
1Oooool3o`0007Cooooo00?o0000ooooooooool0TOooool00005ooooool0003oooooooooool00000
2?ooool00ol0003oooooo`000005ooooo`03o`000?oooooooooo07Gooooo00?o0000ooooooooool0
T?ooool00005ooooool0003oooooooooool000002Oooool2o`0000Gooooo00?o0000ooooooooool0
M_ooool00ol0003oooooooooo`2?ooooo`000_ooool2o`0000_ooooo00?o0000ooooooooool00ooo
ool00ol0003oooooooooo`1gooooo`03o`000?oooooooooo08kooooo000Eooooo`03o`000?oooooo
oooo07Sooooo00?o0000ooooooooool0SOooool001Gooooo00?o0000ooooooooool0NOooool00ol0
003oooooooooo`2<ooooo`005Oooool00ol0003oooooooooo`1jooooo`03o`000?oooooooooo08_o
oooo000Eooooo`03o`000?oooooooooo07_ooooo00?o0000ooooooooool0R_ooool001Gooooo0_l0
001mooooo`03o`000?oooooooooo08Wooooo000Eooooo`03o`000?oooooooooo07gooooo00?o0000
ooooooooool0R?ooool001Gooooo00?o0000ooooooooool0O_ooool00ol0003oooooooooo`27oooo
o`005Oooool00ol0003oooooooooo`1oooooo`03o`000?oooooooooo08Kooooo000Eooooo`03o`00
0?oooooooooo07oooooo00?o0000ooooooooool0Q_ooool001Gooooo00?o0000ooooooooool0P?oo
ool00ol0003oooooooooo`25ooooo`005Oooool00ol0003oooooooooo`21ooooo`03o`000?oooooo
oooo08Cooooo000Eooooo`03o`000?oooooooooo08;ooooo00?o0000ooooooooool0Poooool001Go
oooo0_l00024ooooo`03o`000?oooooooooo08;ooooo000Eooooo`03o`000?oooooooooo08?ooooo
00?o0000ooooooooool0P_ooool001Gooooo00?o0000ooooooooool0Q?ooool00ol0003ooooooooo
o`21ooooo`005Oooool00ol0003oooooooooo`25ooooo`03o`000?oooooooooo083ooooo000Eoooo
o`03o`000?oooooooooo08Kooooo00?o0000ooooooooool0Ooooool001Gooooo00?o0000oooooooo
ool0Qoooool00ol0003oooooooooo`1nooooo`005Oooool00ol0003oooooooooo`28ooooo`03o`00
0?oooooooooo07gooooo000Eooooo`03o`000?oooooooooo08Wooooo00?o0000ooooooooool0O?oo
ool001Gooooo0_l0002;ooooo`03o`000?oooooooooo07_ooooo000Eooooo`03o`000?oooooooooo
08_ooooo00?o0000ooooooooool0N_ooool001Gooooo00?o0000ooooooooool0S?ooool00ol0003o
ooooooooo`1iooooo`005Oooool00ol0003oooooooooo`2=ooooo`03o`000?oooooooooo07Sooooo
000Eooooo`03o`000?oooooooooo08kooooo00?o0000ooooooooool0Moooool000;ooooo0_l00004
ooooo`03o`000?oooooooooo00;ooooo0ol00005ooooo`03o`000?oooooooooo08oooooo00?o0000
ooooooooool0M_ooool00005ooooool0003oooooooooool000001oooool01Ol0003ooooooooooooo
oooo000000Cooooo00?o0000ooooooooool0T?ooool2o`0007Kooooo00001Ooooooo0000oooooooo
oooo000000Oooooo00Go0000ooooooooooooooooo`000004ooooo`03o`000?oooooooooo09;ooooo
00?o0000ooooooooool0Loooool00005ooooool0003oooooooooool000001oooool4o`0000Gooooo
0ol0002Cooooo`03o`000?oooooooooo07;ooooo00001Ooooooo0000oooooooooooo000000Oooooo
00?o0000ooooooooool01_ooool00ol0003oooooooooo`2Dooooo`03o`000?oooooooooo077ooooo
00001Ooooooo0000oooooooooooo000000Sooooo00?o0000ooooooooool01Oooool00ol0003ooooo
ooooo`2Eooooo`03o`000?oooooooooo073ooooo0002ooooo`;o00002_ooool2o`0000Gooooo00?o
0000ooooooooool0U_ooool00ol0003oooooooooo`1_ooooo`005Oooool00ol0003oooooooooo`2G
ooooo`03o`000?oooooooooo06kooooo000Eooooo`03o`000?oooooooooo09Sooooo00?o0000oooo
ooooool0KOooool001Gooooo00?o0000ooooooooool0VOooool2o`0006gooooo000Eooooo`03o`00
0?oooooooooo09_ooooo00?o0000ooooooooool0J_ooool001Gooooo0_l0002Mooooo`03o`000?oo
oooooooo06Wooooo000Eooooo`03o`000?oooooooooo09gooooo0_l0001Yooooo`005Oooool00ol0
003oooooooooo`2Oooooo`03o`000?oooooooooo06Kooooo000Eooooo`03o`000?oooooooooo0:3o
oooo00?o0000ooooooooool0IOooool001Gooooo00?o0000ooooooooool0XOooool2o`0006Gooooo
000Eooooo`03o`000?oooooooooo0:?ooooo00?o0000ooooooooool0H_ooool001Gooooo00?o0000
ooooooooool0Y?ooool2o`0006;ooooo000Eooooo`03o`000?oooooooooo0:Kooooo00?o0000oooo
ooooool0Goooool001Gooooo0_l0002Xooooo`;o0000Goooool001Gooooo00?o0000ooooooooool0
ZOooool00ol0003oooooooooo`1Looooo`005Oooool00ol0003oooooooooo`2Zooooo`;o0000G?oo
ool001Gooooo00?o0000ooooooooool0[?ooool00ol0003oooooooooo`1Iooooo`005Oooool00ol0
003oooooooooo`2]ooooo`;o0000FOooool001Gooooo00?o0000ooooooooool0[oooool2o`0005Oo
oooo000Eooooo`03o`000?oooooooooo0;7ooooo00?o0000ooooooooool0E?ooool001Gooooo00?o
0000ooooooooool0/_ooool3o`0005?ooooo000Eooooo`;o0000]_ooool3o`00053ooooo000Eoooo
o`03o`000?oooooooooo0;Sooooo0ol0001=ooooo`005Oooool00ol0003oooooooooo`2kooooo`;o
0000Boooool001Gooooo00?o0000ooooooooool0_Oooool2o`0004Wooooo000Eooooo`03o`000?oo
oooooooo0;oooooo0ol00016ooooo`000_ooool2o`0000Cooooo00?o0000ooooooooool00_ooool3
o`0000Gooooo00?o0000ooooooooool0`_ooool2o`0004Cooooo00001Ooooooo0000oooooooooooo
000000Oooooo00Go0000ooooooooooooooooo`000004ooooo`03o`000?oooooooooo0<Cooooo0ol0
0011ooooo`0000Goooooo`000?ooooooooooo`000007ooooo`05o`000?ooooooooooooooool00000
1?ooool00ol0003oooooooooo`37ooooo`Co0000?Oooool00005ooooool0003oooooooooool00000
2?ooool3o`0000Gooooo0ol0003;ooooo`Co0000>Oooool00005ooooool0003oooooooooool00000
1oooool01Ol0003ooooooooooooooooo000000Cooooo00?o0000ooooooooool0coooool3o`0003Ko
oooo00001Ooooooo0000oooooooooooo000000Oooooo00Go0000ooooooooooooooooo`000004oooo
o`03o`000?oooooooooo0=;ooooo0ol0000cooooo`000_ooool2o`0000Wooooo0ol00005ooooo`03
o`000?oooooooooo0=Gooooo0ol0000`ooooo`005Oooool00ol0003oooooooooo`3Hooooo`Go0000
:oooool001Gooooo00?o0000ooooooooool0gOooool6o`0002Gooooo000Eooooo`03o`000?oooooo
oooo0>?ooooo1_l0000Oooooo`005Oooool00ol0003oooooooooo`3Yooooo`Go00006_ooool001Go
oooo0_l0003_ooooo`Oo00004oooool001Gooooo00?o0000ooooooooool0mOooool5o`0000kooooo
000Eooooo`03o`000?oooooooooo0?[ooooo0ol0000;ooooo`005Oooool00ol0003oooooooooo`3m
ooooo`?o00002?ooool001Gooooo00?o0000ooooooooool0ooooool1ooooo`03o`000?oooooooooo
00Gooooo000Eooooo`03o`000?oooooooooo0?oooooo2Oooool001Gooooo00?o0000ooooooooool0
ooooool9ooooo`005Oooool00ol0003oooooooooo`3oooooo`Wooooo000Eooooo`;o0000ooooool:
ooooo`005Oooool00ol0003oooooooooo`3oooooo`Wooooo000Eooooo`03o`000?oooooooooo0?oo
oooo2Oooool001Gooooo00?o0000ooooooooool0ooooool9ooooo`005Oooool00ol0003ooooooooo
o`3oooooo`Wooooo000Eooooo`03o`000?oooooooooo0?oooooo2Oooool001Gooooo00?o0000oooo
ooooool0ooooool9ooooo`005Oooool00ol0003oooooooooo`3oooooo`Wooooo000Eooooo`;o0000
ooooool:ooooo`005Oooool00ol0003oooooooooo`3oooooo`Wooooo000Eooooo`03o`000?oooooo
oooo0?oooooo2Oooool001Gooooo00?o0000ooooooooool0ooooool9ooooo`005Oooool00ol0003o
ooooooooo`3oooooo`Wooooo000=ooooo`?o00001Oooool00ol0003oooooooooo`3oooooo`Wooooo
000>ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0ooooool9ooooo`003_ooool0
0ol0003oooooooooo`04ooooo`03o`000?oooooooooo0?oooooo2Oooool000kooooo00?o0000oooo
ooooool01?ooool3o`000?oooooo2Oooool000kooooo00?o0000ooooooooool0ooooool@ooooo`00
3Oooool2o`000?oooooo4_ooool000kooooo00?o0000ooooooooool0ooooool@ooooo`00oooooolQ
ooooo`00\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-2.49048, -0.0764114, \
0.115739, 0.00624232}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 0.0333333 0 0.618034 [
[.16667 -0.0125 -3 -9 ]
[.16667 -0.0125 3 0 ]
[.33333 -0.0125 -6 -9 ]
[.33333 -0.0125 6 0 ]
[.5 -0.0125 -6 -9 ]
[.5 -0.0125 6 0 ]
[.66667 -0.0125 -6 -9 ]
[.66667 -0.0125 6 0 ]
[.83333 -0.0125 -6 -9 ]
[.83333 -0.0125 6 0 ]
[1 -0.0125 -6 -9 ]
[1 -0.0125 6 0 ]
[-0.0125 .12361 -18 -4.5 ]
[-0.0125 .12361 0 4.5 ]
[-0.0125 .24721 -18 -4.5 ]
[-0.0125 .24721 0 4.5 ]
[-0.0125 .37082 -18 -4.5 ]
[-0.0125 .37082 0 4.5 ]
[-0.0125 .49443 -18 -4.5 ]
[-0.0125 .49443 0 4.5 ]
[-0.0125 .61803 -6 -4.5 ]
[-0.0125 .61803 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.16667 0 m
.16667 .00625 L
s
[(5)] .16667 -0.0125 0 1 Mshowa
.33333 0 m
.33333 .00625 L
s
[(10)] .33333 -0.0125 0 1 Mshowa
.5 0 m
.5 .00625 L
s
[(15)] .5 -0.0125 0 1 Mshowa
.66667 0 m
.66667 .00625 L
s
[(20)] .66667 -0.0125 0 1 Mshowa
.83333 0 m
.83333 .00625 L
s
[(25)] .83333 -0.0125 0 1 Mshowa
1 0 m
1 .00625 L
s
[(30)] 1 -0.0125 0 1 Mshowa
.125 Mabswid
.03333 0 m
.03333 .00375 L
s
.06667 0 m
.06667 .00375 L
s
.1 0 m
.1 .00375 L
s
.13333 0 m
.13333 .00375 L
s
.2 0 m
.2 .00375 L
s
.23333 0 m
.23333 .00375 L
s
.26667 0 m
.26667 .00375 L
s
.3 0 m
.3 .00375 L
s
.36667 0 m
.36667 .00375 L
s
.4 0 m
.4 .00375 L
s
.43333 0 m
.43333 .00375 L
s
.46667 0 m
.46667 .00375 L
s
.53333 0 m
.53333 .00375 L
s
.56667 0 m
.56667 .00375 L
s
.6 0 m
.6 .00375 L
s
.63333 0 m
.63333 .00375 L
s
.7 0 m
.7 .00375 L
s
.73333 0 m
.73333 .00375 L
s
.76667 0 m
.76667 .00375 L
s
.8 0 m
.8 .00375 L
s
.86667 0 m
.86667 .00375 L
s
.9 0 m
.9 .00375 L
s
.93333 0 m
.93333 .00375 L
s
.96667 0 m
.96667 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .12361 m
.00625 .12361 L
s
[(0.2)] -0.0125 .12361 1 0 Mshowa
0 .24721 m
.00625 .24721 L
s
[(0.4)] -0.0125 .24721 1 0 Mshowa
0 .37082 m
.00625 .37082 L
s
[(0.6)] -0.0125 .37082 1 0 Mshowa
0 .49443 m
.00625 .49443 L
s
[(0.8)] -0.0125 .49443 1 0 Mshowa
0 .61803 m
.00625 .61803 L
s
[(1)] -0.0125 .61803 1 0 Mshowa
.125 Mabswid
0 .0309 m
.00375 .0309 L
s
0 .0618 m
.00375 .0618 L
s
0 .09271 m
.00375 .09271 L
s
0 .15451 m
.00375 .15451 L
s
0 .18541 m
.00375 .18541 L
s
0 .21631 m
.00375 .21631 L
s
0 .27812 m
.00375 .27812 L
s
0 .30902 m
.00375 .30902 L
s
0 .33992 m
.00375 .33992 L
s
0 .40172 m
.00375 .40172 L
s
0 .43262 m
.00375 .43262 L
s
0 .46353 m
.00375 .46353 L
s
0 .52533 m
.00375 .52533 L
s
0 .55623 m
.00375 .55623 L
s
0 .58713 m
.00375 .58713 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.03333 .07623 m
.06667 .08682 L
.1 .09304 L
.13333 .09884 L
.16667 .10525 L
.2 .11274 L
.23333 .12166 L
.26667 .1323 L
.3 .14496 L
.33333 .16002 L
.36667 .17789 L
.4 .19905 L
.43333 .22408 L
.46667 .25364 L
.5 .28851 L
.53333 .32953 L
.56667 .36439 L
.6 .39395 L
.63333 .41898 L
.66667 .44014 L
.7 .45801 L
.73333 .47307 L
.76667 .48574 L
.8 .49637 L
.83333 .50529 L
.86667 .51279 L
.9 .5192 L
.93333 .52499 L
.96667 .53121 L
1 .54181 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[6]:=",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/B000`400?l00000o`00003ooooooolQ
ooooo`00?_ooool3o`0002Gooooo0ol00004ooooo`;o00008oooool3o`0000?ooooo0ol0000Qoooo
o`Go00000oooool2o`00027ooooo1Ol00002ooooo`?o00008_ooool3o`0000Cooooo0_l00004oooo
o`00?Oooool01Ol0003ooooooooooooooooo000002Gooooo00?o0000ooooooooool00_ooool01?l0
003oooooooooool0000Sooooo`05o`000?ooooooooooooooool000000oooool00ol0003ooooooooo
o`0Oooooo`04o`000?ooooooooooo`0000;ooooo00Co0000oooooooooooo00008Oooool01_l0003o
ooooooooool0003oooooo`0000?ooooo00?o0000ooooooooool07_ooool01Ol0003ooooooooooooo
oooo000000;ooooo00Co0000oooooooooooo00000oooool0047ooooo00?o0000ooooooooool08ooo
ool00ol0003oooooooooo`02ooooo`04o`000?ooooooooooo`0002?ooooo00?o0000ooooooooool0
1Oooool00ol0003oooooooooo`0Pooooo`03o`000?oooooooooo00;ooooo00Co0000oooooooooooo
00008_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo02;ooooo00Co0000oooooooo
oooo00000_ooool00ol0003oooooooooo`01ooooo`00@Oooool00ol0003oooooooooo`0Sooooo`03
o`000?oooooooooo00;ooooo00Co0000oooooooooooo00008oooool00ol0003oooooooooo`05oooo
o`03o`000?oooooooooo027ooooo00Go0000ooooooooooooooooo`000002ooooo`03o`000?oooooo
oooo027ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`0Pooooo`;o00000oooool0
1?l0003oooooooooool00003ooooo`00?Oooool4o`0002Kooooo00?o0000ooooooooool00_ooool0
1?l0003oooooooooool0000Sooooo`04o`000?ooooooooooooooo`Co00008Oooool01Ol0003ooooo
oooooooooooo000000;ooooo00Co0000oooooooooooo00008?ooool01_l0003ooooooooooooooooo
0000ooooo`Co00009Oooool01?l0003oooooooooool00002ooooo`03o`000?oooooooooo007ooooo
000mooooo`03o`000?oooooooooo02Kooooo0_l00004ooooo`04o`000?ooooooooooo`0002;ooooo
0_l00003ooooo`03o`000?oooooooooo02;ooooo00Go0000ooooooooooooooooo`000002ooooo`04
o`000?ooooooooooo`00023ooooo00Oo0000ooooooooooooooooo`000?oooooo000002Cooooo00Go
0000ooooooooooooooooo`000002ooooo`04o`000?ooooooooooo`0000?ooooo000mooooo`Go0000
9Oooool00ol0003oooooooooo`03ooooo`;o00009?ooool01?l0003oooooooooooooool5o`00027o
oooo0ol00004ooooo`;o00008_ooool3o`0000;ooooo1Ol0000Qooooo`?o00001?ooool2o`0000Co
oooo003oooooob7ooooo003oooooob7ooooo003oooooob7ooooo003oooooob7ooooo000Eoooooooo
00001Ol00007ooooo`005Oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Gooooo
00?o0000ooooooooool01_ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Gooooo
00?o0000ooooooooool01_ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Gooooo
00?o0000ooooooooool01_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Kooooo
00?o0000ooooooooool01_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Kooooo
00?o0000ooooooooool01_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Kooooo
00?o0000ooooooooool01_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Kooooo
00?o0000ooooooooool01Oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Kooooo
00?o0000ooooooooool01Oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Kooooo
00?o0000ooooooooool01Oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Kooooo
00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`005Oooool00ol0003ooooooooo
o`3oooooo`Wooooo000Eooooo`03o`000?oooooooooo0?oooooo2Oooool001Gooooo00?o0000oooo
ooooool0ooooool9ooooo`005Oooool00ol0003oooooooooo`3oooooo`Wooooo000Eooooo`03o`00
0?oooooooooo0?oooooo2Oooool001Gooooo00?o0000ooooooooool0ooooool9ooooo`005Oooool2
o`000?oooooo2_ooool001Gooooo00?o0000ooooooooool0ooooool9ooooo`005Oooool00ol0003o
ooooooooo`3oooooo`Wooooo000Eooooo`03o`000?oooooooooo0?oooooo2Oooool001Gooooo00?o
0000ooooooooool0ooooool9ooooo`005Oooool00ol0003oooooooooo`3oooooo`Wooooo000Eoooo
o`03o`000?oooooooooo0?oooooo2Oooool001Gooooo00?o0000ooooooooool0ooooool9ooooo`00
5Oooool2o`000?oooooo2_ooool001Gooooo00?o0000ooooooooool0ooooool9ooooo`005Oooool0
0ol0003oooooooooo`3oooooo`Wooooo000Eooooo`03o`000?oooooooooo0?oooooo2Oooool001Go
oooo00?o0000ooooooooool01_ooool3o`000?oooooo000Eooooo`03o`000?oooooooooo00Wooooo
1?l0003kooooo`005Oooool00ol0003oooooooooo`0=ooooo`Co0000moooool001Gooooo00?o0000
ooooooooool04Oooool5o`000?;ooooo000Eooooo`;o00005oooool7o`000>_ooooo000Eooooo`03
o`000?oooooooooo01gooooo1_l0003Uooooo`005Oooool00ol0003oooooooooo`0Sooooo`Co0000
hOooool001Gooooo00?o0000ooooooooool09oooool4o`000=gooooo000Eooooo`03o`000?oooooo
oooo02_ooooo1Ol0003Hooooo`000_ooool2o`0000Cooooo00Co0000oooooooooooooooo1Ol00004
ooooo`03o`000?oooooooooo033ooooo1?l0003Dooooo`0000Goooooo`000?ooooooooooo`000008
ooooo`04o`000?ooooooooooo`0000Cooooo00?o0000ooooooooool0=?ooool5o`000<oooooo0000
1Ooooooo0000oooooooooooo000000Wooooo00?o0000ooooooooool01?ooool00ol0003ooooooooo
o`0iooooo`?o0000c?ooool00005ooooool0003oooooooooool000002_ooool00ol0003ooooooooo
o`03ooooo`?o0000??ooool3o`000<Wooooo00001Ooooooo0000oooooooooooo000000Oooooo00Go
0000ooooooooooooooooo`000004ooooo`03o`000?oooooooooo03oooooo0ol00036ooooo`0000Go
ooooo`000?ooooooooooo`000007ooooo`05o`000?ooooooooooooooool000001?ooool00ol0003o
ooooooooo`12ooooo`?o0000`oooool000;ooooo0_l00009ooooo`?o00001Oooool00ol0003ooooo
ooooo`15ooooo`?o0000`?ooool001Gooooo00?o0000ooooooooool0B?ooool3o`000;gooooo000E
ooooo`03o`000?oooooooooo04_ooooo0_l0002kooooo`005Oooool00ol0003oooooooooo`1=oooo
o`;o0000^Oooool001Gooooo00?o0000ooooooooool0Coooool2o`000;Oooooo000Eooooo`;o0000
D_ooool2o`000;Gooooo000Eooooo`03o`000?oooooooooo05?ooooo0_l0002cooooo`005Oooool0
0ol0003oooooooooo`1Eooooo`;o0000/Oooool001Gooooo00?o0000ooooooooool0Eoooool2o`00
0:oooooo000Eooooo`03o`000?oooooooooo05Wooooo00?o0000ooooooooool0[?ooool001Gooooo
00?o0000ooooooooool0F_ooool2o`000:cooooo000Eooooo`03o`000?oooooooooo05cooooo0_l0
002Zooooo`005Oooool00ol0003oooooooooo`1Nooooo`;o0000Z?ooool001Gooooo0_l0001Qoooo
o`;o0000Y_ooool001Gooooo00?o0000ooooooooool0H_ooool00ol0003oooooooooo`2Sooooo`00
5Oooool00ol0003oooooooooo`1Sooooo`;o0000Xoooool001Gooooo00?o0000ooooooooool0IOoo
ool2o`000:7ooooo000Eooooo`03o`000?oooooooooo06Oooooo00?o0000ooooooooool0W_ooool0
01Gooooo00?o0000ooooooooool0J?ooool00ol0003oooooooooo`2Mooooo`005Oooool00ol0003o
ooooooooo`1Yooooo`03o`000?oooooooooo09cooooo000Eooooo`03o`000?oooooooooo06[ooooo
00?o0000ooooooooool0Voooool001Gooooo0_l0001/ooooo`03o`000?oooooooooo09[ooooo000E
ooooo`03o`000?oooooooooo06cooooo00?o0000ooooooooool0VOooool001Gooooo00?o0000oooo
ooooool0KOooool2o`0009Wooooo000Eooooo`03o`000?oooooooooo06oooooo00?o0000oooooooo
ool0U_ooool001Gooooo00?o0000ooooooooool0L?ooool00ol0003oooooooooo`2Eooooo`000_oo
ool2o`0000Cooooo00?o0000ooooooooool00oooool3o`0000Cooooo00?o0000ooooooooool0LOoo
ool00ol0003oooooooooo`2Dooooo`0000Goooooo`000?ooooooooooo`00000:ooooo`03o`000?oo
oooooooo00?ooooo00?o0000ooooooooool0L_ooool00ol0003oooooooooo`2Cooooo`0000Gooooo
o`000?ooooooooooo`000007ooooo`Go00001?ooool00ol0003oooooooooo`1cooooo`03o`000?oo
oooooooo09;ooooo00001Ooooooo0000oooooooooooo000000Oooooo00Co0000oooooooooooo0000
1Oooool3o`0007Cooooo00?o0000ooooooooool0TOooool00005ooooool0003oooooooooool00000
2?ooool00ol0003oooooo`000005ooooo`03o`000?oooooooooo07Gooooo00?o0000ooooooooool0
T?ooool00005ooooool0003oooooooooool000002Oooool2o`0000Gooooo00?o0000ooooooooool0
M_ooool00ol0003oooooooooo`2?ooooo`000_ooool2o`0000_ooooo00?o0000ooooooooool00ooo
ool00ol0003oooooooooo`1gooooo`03o`000?oooooooooo08kooooo000Eooooo`03o`000?oooooo
oooo07Sooooo00?o0000ooooooooool0SOooool001Gooooo00?o0000ooooooooool0NOooool00ol0
003oooooooooo`2<ooooo`005Oooool00ol0003oooooooooo`1jooooo`03o`000?oooooooooo08_o
oooo000Eooooo`03o`000?oooooooooo07_ooooo00?o0000ooooooooool0R_ooool001Gooooo0_l0
001mooooo`03o`000?oooooooooo08Wooooo000Eooooo`03o`000?oooooooooo07gooooo00?o0000
ooooooooool0R?ooool001Gooooo00?o0000ooooooooool0O_ooool00ol0003oooooooooo`27oooo
o`005Oooool00ol0003oooooooooo`1oooooo`03o`000?oooooooooo08Kooooo000Eooooo`03o`00
0?oooooooooo07oooooo00?o0000ooooooooool0Q_ooool001Gooooo00?o0000ooooooooool0P?oo
ool00ol0003oooooooooo`25ooooo`005Oooool00ol0003oooooooooo`21ooooo`03o`000?oooooo
oooo08Cooooo000Eooooo`03o`000?oooooooooo08;ooooo00?o0000ooooooooool0Poooool001Go
oooo0_l00024ooooo`03o`000?oooooooooo08;ooooo000Eooooo`03o`000?oooooooooo08?ooooo
00?o0000ooooooooool0P_ooool001Gooooo00?o0000ooooooooool0Q?ooool00ol0003ooooooooo
o`21ooooo`005Oooool00ol0003oooooooooo`25ooooo`03o`000?oooooooooo083ooooo000Eoooo
o`03o`000?oooooooooo08Kooooo00?o0000ooooooooool0Ooooool001Gooooo00?o0000oooooooo
ool0Qoooool00ol0003oooooooooo`1nooooo`005Oooool00ol0003oooooooooo`28ooooo`03o`00
0?oooooooooo07gooooo000Eooooo`03o`000?oooooooooo08Wooooo00?o0000ooooooooool0O?oo
ool001Gooooo0_l0002;ooooo`03o`000?oooooooooo07_ooooo000Eooooo`03o`000?oooooooooo
08_ooooo00?o0000ooooooooool0N_ooool001Gooooo00?o0000ooooooooool0S?ooool00ol0003o
ooooooooo`1iooooo`005Oooool00ol0003oooooooooo`2=ooooo`03o`000?oooooooooo07Sooooo
000Eooooo`03o`000?oooooooooo08kooooo00?o0000ooooooooool0Moooool000;ooooo0_l00004
ooooo`03o`000?oooooooooo00;ooooo0ol00005ooooo`03o`000?oooooooooo08oooooo00?o0000
ooooooooool0M_ooool00005ooooool0003oooooooooool000001oooool01Ol0003ooooooooooooo
oooo000000Cooooo00?o0000ooooooooool0T?ooool2o`0007Kooooo00001Ooooooo0000oooooooo
oooo000000Oooooo00Go0000ooooooooooooooooo`000004ooooo`03o`000?oooooooooo09;ooooo
00?o0000ooooooooool0Loooool00005ooooool0003oooooooooool000001oooool4o`0000Gooooo
0ol0002Cooooo`03o`000?oooooooooo07;ooooo00001Ooooooo0000oooooooooooo000000Oooooo
00?o0000ooooooooool01_ooool00ol0003oooooooooo`2Dooooo`03o`000?oooooooooo077ooooo
00001Ooooooo0000oooooooooooo000000Sooooo00?o0000ooooooooool01Oooool00ol0003ooooo
ooooo`2Eooooo`03o`000?oooooooooo073ooooo0002ooooo`;o00002_ooool2o`0000Gooooo00?o
0000ooooooooool0U_ooool00ol0003oooooooooo`1_ooooo`005Oooool00ol0003oooooooooo`2G
ooooo`03o`000?oooooooooo06kooooo000Eooooo`03o`000?oooooooooo09Sooooo00?o0000oooo
ooooool0KOooool001Gooooo00?o0000ooooooooool0VOooool2o`0006gooooo000Eooooo`03o`00
0?oooooooooo09_ooooo00?o0000ooooooooool0J_ooool001Gooooo0_l0002Mooooo`03o`000?oo
oooooooo06Wooooo000Eooooo`03o`000?oooooooooo09gooooo0_l0001Yooooo`005Oooool00ol0
003oooooooooo`2Oooooo`03o`000?oooooooooo06Kooooo000Eooooo`03o`000?oooooooooo0:3o
oooo00?o0000ooooooooool0IOooool001Gooooo00?o0000ooooooooool0XOooool2o`0006Gooooo
000Eooooo`03o`000?oooooooooo0:?ooooo00?o0000ooooooooool0H_ooool001Gooooo00?o0000
ooooooooool0Y?ooool2o`0006;ooooo000Eooooo`03o`000?oooooooooo0:Kooooo00?o0000oooo
ooooool0Goooool001Gooooo0_l0002Xooooo`;o0000Goooool001Gooooo00?o0000ooooooooool0
ZOooool00ol0003oooooooooo`1Looooo`005Oooool00ol0003oooooooooo`2Zooooo`;o0000G?oo
ool001Gooooo00?o0000ooooooooool0[?ooool00ol0003oooooooooo`1Iooooo`005Oooool00ol0
003oooooooooo`2]ooooo`;o0000FOooool001Gooooo00?o0000ooooooooool0[oooool2o`0005Oo
oooo000Eooooo`03o`000?oooooooooo0;7ooooo00?o0000ooooooooool0E?ooool001Gooooo00?o
0000ooooooooool0/_ooool3o`0005?ooooo000Eooooo`;o0000]_ooool3o`00053ooooo000Eoooo
o`03o`000?oooooooooo0;Sooooo0ol0001=ooooo`005Oooool00ol0003oooooooooo`2kooooo`;o
0000Boooool001Gooooo00?o0000ooooooooool0_Oooool2o`0004Wooooo000Eooooo`03o`000?oo
oooooooo0;oooooo0ol00016ooooo`000_ooool2o`0000Cooooo00?o0000ooooooooool00_ooool3
o`0000Gooooo00?o0000ooooooooool0`_ooool2o`0004Cooooo00001Ooooooo0000oooooooooooo
000000Oooooo00Go0000ooooooooooooooooo`000004ooooo`03o`000?oooooooooo0<Cooooo0ol0
0011ooooo`0000Goooooo`000?ooooooooooo`000007ooooo`05o`000?ooooooooooooooool00000
1?ooool00ol0003oooooooooo`37ooooo`Co0000?Oooool00005ooooool0003oooooooooool00000
2?ooool3o`0000Gooooo0ol0003;ooooo`Co0000>Oooool00005ooooool0003oooooooooool00000
1oooool01Ol0003ooooooooooooooooo000000Cooooo00?o0000ooooooooool0coooool3o`0003Ko
oooo00001Ooooooo0000oooooooooooo000000Oooooo00Go0000ooooooooooooooooo`000004oooo
o`03o`000?oooooooooo0=;ooooo0ol0000cooooo`000_ooool2o`0000Wooooo0ol00005ooooo`03
o`000?oooooooooo0=Gooooo0ol0000`ooooo`005Oooool00ol0003oooooooooo`3Hooooo`Go0000
:oooool001Gooooo00?o0000ooooooooool0gOooool6o`0002Gooooo000Eooooo`03o`000?oooooo
oooo0>?ooooo1_l0000Oooooo`005Oooool00ol0003oooooooooo`3Yooooo`Go00006_ooool001Go
oooo0_l0003_ooooo`Oo00004oooool001Gooooo00?o0000ooooooooool0mOooool5o`0000kooooo
000Eooooo`03o`000?oooooooooo0?[ooooo0ol0000;ooooo`005Oooool00ol0003oooooooooo`3m
ooooo`?o00002?ooool001Gooooo00?o0000ooooooooool0ooooool1ooooo`03o`000?oooooooooo
00Gooooo000Eooooo`03o`000?oooooooooo0?oooooo2Oooool001Gooooo00?o0000ooooooooool0
ooooool9ooooo`005Oooool00ol0003oooooooooo`3oooooo`Wooooo000Eooooo`;o0000ooooool:
ooooo`005Oooool00ol0003oooooooooo`3oooooo`Wooooo000Eooooo`03o`000?oooooooooo0?oo
oooo2Oooool001Gooooo00?o0000ooooooooool0ooooool9ooooo`005Oooool00ol0003ooooooooo
o`3oooooo`Wooooo000Eooooo`03o`000?oooooooooo0?oooooo2Oooool001Gooooo00?o0000oooo
ooooool0ooooool9ooooo`005Oooool00ol0003oooooooooo`3oooooo`Wooooo000Eooooo`;o0000
ooooool:ooooo`005Oooool00ol0003oooooooooo`3oooooo`Wooooo000Eooooo`03o`000?oooooo
oooo0?oooooo2Oooool001Gooooo00?o0000ooooooooool0ooooool9ooooo`005Oooool00ol0003o
ooooooooo`3oooooo`Wooooo000=ooooo`?o00001Oooool00ol0003oooooooooo`3oooooo`Wooooo
000>ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0ooooool9ooooo`003_ooool0
0ol0003oooooooooo`04ooooo`03o`000?oooooooooo0?oooooo2Oooool000kooooo00?o0000oooo
ooooool01?ooool3o`000?oooooo2Oooool000kooooo00?o0000ooooooooool0ooooool@ooooo`00
3Oooool2o`000?oooooo4_ooool000kooooo00?o0000ooooooooool0ooooool@ooooo`00oooooolQ
ooooo`00\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-2.49048, -0.0764114, \
0.115739, 0.00624232}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 0.0333333 0 0.618034 [
[.16667 -0.0125 -3 -9 ]
[.16667 -0.0125 3 0 ]
[.33333 -0.0125 -6 -9 ]
[.33333 -0.0125 6 0 ]
[.5 -0.0125 -6 -9 ]
[.5 -0.0125 6 0 ]
[.66667 -0.0125 -6 -9 ]
[.66667 -0.0125 6 0 ]
[.83333 -0.0125 -6 -9 ]
[.83333 -0.0125 6 0 ]
[1 -0.0125 -6 -9 ]
[1 -0.0125 6 0 ]
[-0.0125 .12361 -18 -4.5 ]
[-0.0125 .12361 0 4.5 ]
[-0.0125 .24721 -18 -4.5 ]
[-0.0125 .24721 0 4.5 ]
[-0.0125 .37082 -18 -4.5 ]
[-0.0125 .37082 0 4.5 ]
[-0.0125 .49443 -18 -4.5 ]
[-0.0125 .49443 0 4.5 ]
[-0.0125 .61803 -6 -4.5 ]
[-0.0125 .61803 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.16667 0 m
.16667 .00625 L
s
[(5)] .16667 -0.0125 0 1 Mshowa
.33333 0 m
.33333 .00625 L
s
[(10)] .33333 -0.0125 0 1 Mshowa
.5 0 m
.5 .00625 L
s
[(15)] .5 -0.0125 0 1 Mshowa
.66667 0 m
.66667 .00625 L
s
[(20)] .66667 -0.0125 0 1 Mshowa
.83333 0 m
.83333 .00625 L
s
[(25)] .83333 -0.0125 0 1 Mshowa
1 0 m
1 .00625 L
s
[(30)] 1 -0.0125 0 1 Mshowa
.125 Mabswid
.03333 0 m
.03333 .00375 L
s
.06667 0 m
.06667 .00375 L
s
.1 0 m
.1 .00375 L
s
.13333 0 m
.13333 .00375 L
s
.2 0 m
.2 .00375 L
s
.23333 0 m
.23333 .00375 L
s
.26667 0 m
.26667 .00375 L
s
.3 0 m
.3 .00375 L
s
.36667 0 m
.36667 .00375 L
s
.4 0 m
.4 .00375 L
s
.43333 0 m
.43333 .00375 L
s
.46667 0 m
.46667 .00375 L
s
.53333 0 m
.53333 .00375 L
s
.56667 0 m
.56667 .00375 L
s
.6 0 m
.6 .00375 L
s
.63333 0 m
.63333 .00375 L
s
.7 0 m
.7 .00375 L
s
.73333 0 m
.73333 .00375 L
s
.76667 0 m
.76667 .00375 L
s
.8 0 m
.8 .00375 L
s
.86667 0 m
.86667 .00375 L
s
.9 0 m
.9 .00375 L
s
.93333 0 m
.93333 .00375 L
s
.96667 0 m
.96667 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .12361 m
.00625 .12361 L
s
[(0.2)] -0.0125 .12361 1 0 Mshowa
0 .24721 m
.00625 .24721 L
s
[(0.4)] -0.0125 .24721 1 0 Mshowa
0 .37082 m
.00625 .37082 L
s
[(0.6)] -0.0125 .37082 1 0 Mshowa
0 .49443 m
.00625 .49443 L
s
[(0.8)] -0.0125 .49443 1 0 Mshowa
0 .61803 m
.00625 .61803 L
s
[(1)] -0.0125 .61803 1 0 Mshowa
.125 Mabswid
0 .0309 m
.00375 .0309 L
s
0 .0618 m
.00375 .0618 L
s
0 .09271 m
.00375 .09271 L
s
0 .15451 m
.00375 .15451 L
s
0 .18541 m
.00375 .18541 L
s
0 .21631 m
.00375 .21631 L
s
0 .27812 m
.00375 .27812 L
s
0 .30902 m
.00375 .30902 L
s
0 .33992 m
.00375 .33992 L
s
0 .40172 m
.00375 .40172 L
s
0 .43262 m
.00375 .43262 L
s
0 .46353 m
.00375 .46353 L
s
0 .52533 m
.00375 .52533 L
s
0 .55623 m
.00375 .55623 L
s
0 .58713 m
.00375 .58713 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.03333 .07556 m
.06667 .08648 L
.1 .09285 L
.13333 .09872 L
.16667 .10518 L
.2 .11271 L
.23333 .12165 L
.26667 .13229 L
.3 .14497 L
.33333 .16003 L
.36667 .1779 L
.4 .19906 L
.43333 .22409 L
.46667 .25365 L
.5 .28851 L
.53333 .32953 L
.56667 .36439 L
.6 .39394 L
.63333 .41897 L
.66667 .44013 L
.7 .458 L
.73333 .47306 L
.76667 .48574 L
.8 .49639 L
.83333 .50532 L
.86667 .51285 L
.9 .51931 L
.93333 .52519 L
.96667 .53155 L
1 .54248 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[6]:=",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/B000`400?l00000o`00003ooooooolQ
ooooo`00?_ooool3o`0002Gooooo0ol00004ooooo`;o00008oooool3o`0000?ooooo0ol0000Qoooo
o`Go00000oooool2o`00027ooooo1Ol00002ooooo`?o00008_ooool3o`0000Cooooo0_l00004oooo
o`00?Oooool01Ol0003ooooooooooooooooo000002Gooooo00?o0000ooooooooool00_ooool01?l0
003oooooooooool0000Sooooo`05o`000?ooooooooooooooool000000oooool00ol0003ooooooooo
o`0Oooooo`04o`000?ooooooooooo`0000;ooooo00Co0000oooooooooooo00008Oooool01_l0003o
ooooooooool0003oooooo`0000?ooooo00?o0000ooooooooool07_ooool01Ol0003ooooooooooooo
oooo000000;ooooo00Co0000oooooooooooo00000oooool0047ooooo00?o0000ooooooooool08ooo
ool00ol0003oooooooooo`02ooooo`04o`000?ooooooooooo`0002?ooooo00?o0000ooooooooool0
1Oooool00ol0003oooooooooo`0Pooooo`03o`000?oooooooooo00;ooooo00Co0000oooooooooooo
00008_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo02;ooooo00Co0000oooooooo
oooo00000_ooool00ol0003oooooooooo`01ooooo`00@Oooool00ol0003oooooooooo`0Sooooo`03
o`000?oooooooooo00;ooooo00Co0000oooooooooooo00008oooool00ol0003oooooooooo`05oooo
o`03o`000?oooooooooo027ooooo00Go0000ooooooooooooooooo`000002ooooo`03o`000?oooooo
oooo027ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`0Pooooo`;o00000oooool0
1?l0003oooooooooool00003ooooo`00?Oooool4o`0002Kooooo00?o0000ooooooooool00_ooool0
1?l0003oooooooooool0000Sooooo`04o`000?ooooooooooooooo`Co00008Oooool01Ol0003ooooo
oooooooooooo000000;ooooo00Co0000oooooooooooo00008?ooool01_l0003ooooooooooooooooo
0000ooooo`Co00009Oooool01?l0003oooooooooool00002ooooo`03o`000?oooooooooo007ooooo
000mooooo`03o`000?oooooooooo02Kooooo0_l00004ooooo`04o`000?ooooooooooo`0002;ooooo
0_l00003ooooo`03o`000?oooooooooo02;ooooo00Go0000ooooooooooooooooo`000002ooooo`04
o`000?ooooooooooo`00023ooooo00Oo0000ooooooooooooooooo`000?oooooo000002Cooooo00Go
0000ooooooooooooooooo`000002ooooo`04o`000?ooooooooooo`0000?ooooo000mooooo`Go0000
9Oooool00ol0003oooooooooo`03ooooo`;o00009?ooool01?l0003oooooooooooooool5o`00027o
oooo0ol00004ooooo`;o00008_ooool3o`0000;ooooo1Ol0000Qooooo`?o00001?ooool2o`0000Co
oooo003oooooob7ooooo003oooooob7ooooo003oooooob7ooooo003oooooob7ooooo000Eoooooooo
00001Ol00007ooooo`005Oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Gooooo
00?o0000ooooooooool01_ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Gooooo
00?o0000ooooooooool01_ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Gooooo
00?o0000ooooooooool01_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Kooooo
00?o0000ooooooooool01_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Kooooo
00?o0000ooooooooool01_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Kooooo
00?o0000ooooooooool01_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Kooooo
00?o0000ooooooooool01Oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Kooooo
00?o0000ooooooooool01Oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Kooooo
00?o0000ooooooooool01Oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Kooooo
00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`005Oooool00ol0003ooooooooo
o`3oooooo`Wooooo000Eooooo`03o`000?oooooooooo0?oooooo2Oooool001Gooooo00?o0000oooo
ooooool0ooooool9ooooo`005Oooool00ol0003oooooooooo`3oooooo`Wooooo000Eooooo`03o`00
0?oooooooooo0?oooooo2Oooool001Gooooo00?o0000ooooooooool0ooooool9ooooo`005Oooool2
o`000?oooooo2_ooool001Gooooo00?o0000ooooooooool0ooooool9ooooo`005Oooool00ol0003o
ooooooooo`3oooooo`Wooooo000Eooooo`03o`000?oooooooooo0?oooooo2Oooool001Gooooo00?o
0000ooooooooool0ooooool9ooooo`005Oooool00ol0003oooooooooo`3oooooo`Wooooo000Eoooo
o`03o`000?oooooooooo0?oooooo2Oooool001Gooooo00?o0000ooooooooool0ooooool9ooooo`00
5Oooool2o`000?oooooo2_ooool001Gooooo00?o0000ooooooooool0ooooool9ooooo`005Oooool0
0ol0003oooooooooo`3oooooo`Wooooo000Eooooo`03o`000?oooooooooo00Kooooo0_l0003ooooo
o`7ooooo000Eooooo`03o`000?oooooooooo00Sooooo0ol0003mooooo`005Oooool00ol0003ooooo
ooooo`0;ooooo`?o0000n_ooool001Gooooo00?o0000ooooooooool03_ooool3o`000?Oooooo000E
ooooo`03o`000?oooooooooo017ooooo1Ol0003booooo`005Oooool2o`0001Oooooo1ol0003[oooo
o`005Oooool00ol0003oooooooooo`0Mooooo`Ko0000iOooool001Gooooo00?o0000ooooooooool0
8oooool4o`000>7ooooo000Eooooo`03o`000?oooooooooo02Oooooo1?l0003Mooooo`005Oooool0
0ol0003oooooooooo`0[ooooo`Go0000f?ooool000;ooooo0_l00004ooooo`04o`000?oooooooooo
ooooo`Go00001?ooool00ol0003oooooooooo`0`ooooo`Co0000e?ooool00005ooooool0003ooooo
ooooool000002?ooool01?l0003oooooooooool00004ooooo`03o`000?oooooooooo03Cooooo1Ol0
003?ooooo`0000Goooooo`000?ooooooooooo`000009ooooo`03o`000?oooooooooo00Cooooo00?o
0000ooooooooool0>Oooool3o`000<cooooo00001Ooooooo0000oooooooooooo000000[ooooo00?o
0000ooooooooool00oooool3o`0003cooooo0ol00039ooooo`0000Goooooo`000?ooooooooooo`00
0007ooooo`05o`000?ooooooooooooooool000001?ooool00ol0003oooooooooo`0oooooo`?o0000
a_ooool00005ooooool0003oooooooooool000001oooool01Ol0003ooooooooooooooooo000000Co
oooo00?o0000ooooooooool0@_ooool3o`000<?ooooo0002ooooo`;o00002Oooool3o`0000Gooooo
00?o0000ooooooooool0AOooool3o`000<3ooooo000Eooooo`03o`000?oooooooooo04Sooooo0ol0
002mooooo`005Oooool00ol0003oooooooooo`1;ooooo`;o0000^oooool001Gooooo00?o0000oooo
ooooool0COooool2o`000;Wooooo000Eooooo`03o`000?oooooooooo04oooooo0_l0002gooooo`00
5Oooool2o`0005;ooooo0_l0002eooooo`005Oooool00ol0003oooooooooo`1Cooooo`;o0000/ooo
ool001Gooooo00?o0000ooooooooool0EOooool2o`000;7ooooo000Eooooo`03o`000?oooooooooo
05Oooooo0_l0002_ooooo`005Oooool00ol0003oooooooooo`1Iooooo`03o`000?oooooooooo0:co
oooo000Eooooo`03o`000?oooooooooo05[ooooo0_l0002/ooooo`005Oooool00ol0003ooooooooo
o`1Looooo`;o0000Z_ooool001Gooooo00?o0000ooooooooool0G_ooool2o`000:Sooooo000Eoooo
o`;o0000HOooool2o`000:Kooooo000Eooooo`03o`000?oooooooooo06;ooooo00?o0000oooooooo
ool0Xoooool001Gooooo00?o0000ooooooooool0Hoooool2o`000:?ooooo000Eooooo`03o`000?oo
oooooooo06Gooooo0_l0002Qooooo`005Oooool00ol0003oooooooooo`1Wooooo`03o`000?oooooo
oooo09kooooo000Eooooo`03o`000?oooooooooo06Sooooo00?o0000ooooooooool0WOooool001Go
oooo00?o0000ooooooooool0JOooool00ol0003oooooooooo`2Looooo`005Oooool00ol0003ooooo
ooooo`1Zooooo`03o`000?oooooooooo09_ooooo000Eooooo`;o0000K?ooool00ol0003ooooooooo
o`2Jooooo`005Oooool00ol0003oooooooooo`1/ooooo`03o`000?oooooooooo09Wooooo000Eoooo
o`03o`000?oooooooooo06gooooo0_l0002Iooooo`005Oooool00ol0003oooooooooo`1_ooooo`03
o`000?oooooooooo09Kooooo000Eooooo`03o`000?oooooooooo073ooooo00?o0000ooooooooool0
UOooool000;ooooo0_l00004ooooo`03o`000?oooooooooo00?ooooo0ol00004ooooo`03o`000?oo
oooooooo077ooooo00?o0000ooooooooool0U?ooool00005ooooool0003oooooooooool000002_oo
ool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo07;ooooo00?o0000ooooooooool0Tooo
ool00005ooooool0003oooooooooool000001oooool5o`0000Cooooo00?o0000ooooooooool0Looo
ool00ol0003oooooooooo`2Booooo`0000Goooooo`000?ooooooooooo`000007ooooo`04o`000?oo
ooooooooo`0000Gooooo0ol0001dooooo`03o`000?oooooooooo097ooooo00001Ooooooo0000oooo
oooooooo000000Sooooo00?o0000ooooool000001Oooool00ol0003oooooooooo`1eooooo`03o`00
0?oooooooooo093ooooo00001Ooooooo0000oooooooooooo000000Wooooo0_l00005ooooo`03o`00
0?oooooooooo07Kooooo00?o0000ooooooooool0Soooool000;ooooo0_l0000;ooooo`03o`000?oo
oooooooo00?ooooo00?o0000ooooooooool0Moooool00ol0003oooooooooo`2>ooooo`005Oooool0
0ol0003oooooooooo`1hooooo`03o`000?oooooooooo08gooooo000Eooooo`03o`000?oooooooooo
07Wooooo00?o0000ooooooooool0S?ooool001Gooooo00?o0000ooooooooool0N_ooool00ol0003o
ooooooooo`2;ooooo`005Oooool00ol0003oooooooooo`1kooooo`03o`000?oooooooooo08[ooooo
000Eooooo`;o0000OOooool00ol0003oooooooooo`29ooooo`005Oooool00ol0003oooooooooo`1m
ooooo`03o`000?oooooooooo08Sooooo000Eooooo`03o`000?oooooooooo07kooooo00?o0000oooo
ooooool0Qoooool001Gooooo00?o0000ooooooooool0Ooooool00ol0003oooooooooo`26ooooo`00
5Oooool00ol0003oooooooooo`1oooooo`03o`000?oooooooooo08Kooooo000Eooooo`03o`000?oo
oooooooo083ooooo00?o0000ooooooooool0QOooool001Gooooo00?o0000ooooooooool0POooool0
0ol0003oooooooooo`24ooooo`005Oooool00ol0003oooooooooo`22ooooo`03o`000?oooooooooo
08?ooooo000Eooooo`;o0000Q?ooool00ol0003oooooooooo`22ooooo`005Oooool00ol0003ooooo
ooooo`23ooooo`03o`000?oooooooooo08;ooooo000Eooooo`03o`000?oooooooooo08Cooooo00?o
0000ooooooooool0POooool001Gooooo00?o0000ooooooooool0QOooool00ol0003oooooooooo`20
ooooo`005Oooool00ol0003oooooooooo`26ooooo`03o`000?oooooooooo07oooooo000Eooooo`03
o`000?oooooooooo08Oooooo00?o0000ooooooooool0O_ooool001Gooooo00?o0000ooooooooool0
R?ooool00ol0003oooooooooo`1mooooo`005Oooool00ol0003oooooooooo`29ooooo`03o`000?oo
oooooooo07cooooo000Eooooo`;o0000Roooool00ol0003oooooooooo`1kooooo`005Oooool00ol0
003oooooooooo`2;ooooo`03o`000?oooooooooo07[ooooo000Eooooo`03o`000?oooooooooo08co
oooo00?o0000ooooooooool0NOooool001Gooooo00?o0000ooooooooool0SOooool00ol0003ooooo
ooooo`1hooooo`005Oooool00ol0003oooooooooo`2>ooooo`03o`000?oooooooooo07Oooooo0002
ooooo`;o00001?ooool00ol0003oooooooooo`02ooooo`?o00001Oooool00ol0003oooooooooo`2?
ooooo`03o`000?oooooooooo07Kooooo00001Ooooooo0000oooooooooooo000000Oooooo00Go0000
ooooooooooooooooo`000004ooooo`03o`000?oooooooooo093ooooo0_l0001fooooo`0000Gooooo
o`000?ooooooooooo`000007ooooo`05o`000?ooooooooooooooool000001?ooool00ol0003ooooo
ooooo`2Booooo`03o`000?oooooooooo07?ooooo00001Ooooooo0000oooooooooooo000000Oooooo
1?l00005ooooo`?o0000Toooool00ol0003oooooooooo`1booooo`0000Goooooo`000?oooooooooo
o`000007ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0U?ooool00ol0003ooooo
ooooo`1aooooo`0000Goooooo`000?ooooooooooo`000008ooooo`03o`000?oooooooooo00Gooooo
00?o0000ooooooooool0UOooool00ol0003oooooooooo`1`ooooo`000_ooool2o`0000[ooooo0_l0
0005ooooo`03o`000?oooooooooo09Kooooo00?o0000ooooooooool0Koooool001Gooooo00?o0000
ooooooooool0Uoooool00ol0003oooooooooo`1^ooooo`005Oooool00ol0003oooooooooo`2Hoooo
o`03o`000?oooooooooo06gooooo000Eooooo`03o`000?oooooooooo09Wooooo0_l0001]ooooo`00
5Oooool00ol0003oooooooooo`2Kooooo`03o`000?oooooooooo06[ooooo000Eooooo`;o0000WOoo
ool00ol0003oooooooooo`1Yooooo`005Oooool00ol0003oooooooooo`2Mooooo`;o0000JOooool0
01Gooooo00?o0000ooooooooool0Woooool00ol0003oooooooooo`1Vooooo`005Oooool00ol0003o
ooooooooo`2Pooooo`03o`000?oooooooooo06Gooooo000Eooooo`03o`000?oooooooooo0:7ooooo
0_l0001Uooooo`005Oooool00ol0003oooooooooo`2Sooooo`03o`000?oooooooooo06;ooooo000E
ooooo`03o`000?oooooooooo0:Cooooo0_l0001Rooooo`005Oooool00ol0003oooooooooo`2Voooo
o`03o`000?oooooooooo05oooooo000Eooooo`;o0000Z?ooool2o`0005oooooo000Eooooo`03o`00
0?oooooooooo0:Wooooo00?o0000ooooooooool0G?ooool001Gooooo00?o0000ooooooooool0Z_oo
ool2o`0005cooooo000Eooooo`03o`000?oooooooooo0:cooooo00?o0000ooooooooool0FOooool0
01Gooooo00?o0000ooooooooool0[Oooool2o`0005Wooooo000Eooooo`03o`000?oooooooooo0:oo
oooo0_l0001Gooooo`005Oooool00ol0003oooooooooo`2aooooo`03o`000?oooooooooo05Cooooo
000Eooooo`03o`000?oooooooooo0;;ooooo0ol0001Cooooo`005Oooool2o`000;Kooooo0ol0001@
ooooo`005Oooool00ol0003oooooooooo`2hooooo`?o0000COooool001Gooooo00?o0000oooooooo
ool0^oooool2o`0004_ooooo000Eooooo`03o`000?oooooooooo0;gooooo0_l00019ooooo`005Ooo
ool00ol0003oooooooooo`2oooooo`?o0000A_ooool000;ooooo0_l00004ooooo`03o`000?oooooo
oooo00;ooooo0ol00005ooooo`03o`000?oooooooooo0<;ooooo0_l00014ooooo`0000Goooooo`00
0?ooooooooooo`000007ooooo`05o`000?ooooooooooooooool000001?ooool00ol0003ooooooooo
o`34ooooo`?o0000@Oooool00005ooooool0003oooooooooool000001oooool01Ol0003ooooooooo
oooooooo000000Cooooo00?o0000ooooooooool0aoooool4o`0003gooooo00001Ooooooo0000oooo
oooooooo000000Sooooo0ol00005ooooo`?o0000boooool4o`0003Wooooo00001Ooooooo0000oooo
oooooooo000000Oooooo00Go0000ooooooooooooooooo`000004ooooo`03o`000?oooooooooo0<oo
oooo0ol0000fooooo`0000Goooooo`000?ooooooooooo`000007ooooo`05o`000?oooooooooooooo
ool000001?ooool00ol0003oooooooooo`3Booooo`?o0000<oooool000;ooooo0_l00009ooooo`?o
00001Oooool00ol0003oooooooooo`3Eooooo`?o0000<?ooool001Gooooo00?o0000ooooooooool0
f?ooool5o`0002_ooooo000Eooooo`03o`000?oooooooooo0=gooooo1_l0000Uooooo`005Oooool0
0ol0003oooooooooo`3Sooooo`Ko00007oooool001Gooooo00?o0000ooooooooool0jOooool5o`00
01[ooooo000Eooooo`;o0000koooool4o`0001Kooooo000Eooooo`03o`000?oooooooooo0?;ooooo
1Ol0000Aooooo`005Oooool00ol0003oooooooooo`3gooooo`Co00003Oooool001Gooooo00?o0000
ooooooooool0noooool4o`0000Wooooo000Eooooo`03o`000?oooooooooo0?oooooo0_l00007oooo
o`005Oooool00ol0003oooooooooo`3oooooo`Wooooo000Eooooo`03o`000?oooooooooo0?oooooo
2Oooool001Gooooo00?o0000ooooooooool0ooooool9ooooo`005Oooool2o`000?oooooo2_ooool0
01Gooooo00?o0000ooooooooool0ooooool9ooooo`005Oooool00ol0003oooooooooo`3oooooo`Wo
oooo000Eooooo`03o`000?oooooooooo0?oooooo2Oooool001Gooooo00?o0000ooooooooool0oooo
ool9ooooo`005Oooool00ol0003oooooooooo`3oooooo`Wooooo000Eooooo`03o`000?oooooooooo
0?oooooo2Oooool001Gooooo00?o0000ooooooooool0ooooool9ooooo`005Oooool2o`000?oooooo
2_ooool001Gooooo00?o0000ooooooooool0ooooool9ooooo`005Oooool00ol0003oooooooooo`3o
ooooo`Wooooo000Eooooo`03o`000?oooooooooo0?oooooo2Oooool001Gooooo00?o0000oooooooo
ool0ooooool9ooooo`003Oooool3o`0000Gooooo00?o0000ooooooooool0ooooool9ooooo`003_oo
ool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo0?oooooo2Oooool000kooooo00?o0000
ooooooooool01?ooool00ol0003oooooooooo`3oooooo`Wooooo000>ooooo`03o`000?oooooooooo
00Cooooo0ol0003oooooo`Wooooo000>ooooo`03o`000?oooooooooo0?oooooo4?ooool000gooooo
0_l0003ooooooa;ooooo000>ooooo`03o`000?oooooooooo0?oooooo4?ooool00?oooooo8Oooool0
0001\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-2.49048, -0.0764114, \
0.115739, 0.00624232}}]
}, Closed]]
}, Open  ]],

Cell[TextData[{
  "Tip: ",
  StyleBox["Close the cells, and then double click on them: this animates the \
timecourse",
    FontWeight->"Plain"]
}], "Text",
  FontWeight->"Bold"],

Cell["\<\
Cline width reaches equilibrium at w=15.0 for all 3 loci within \
about 400 generations\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(Table[{t, ClineWidth[res[t]]} // Flatten, {t, 0, 500, 20}] // 
      TableForm\)], "Input",
  CellLabel->"In[7]:="],

Cell[BoxData[
    TagBox[GridBox[{
          {"0", "1", "1", "1"},
          {"20", "6.7762961456657145`", "6.776296145665712`", 
            "6.776296145665709`"},
          {"40", "8.682699921621472`", "8.682699921621463`", 
            "8.682699921621472`"},
          {"60", "9.891758861600024`", "9.891758861600024`", 
            "9.891758861600024`"},
          {"80", "10.849114894330178`", "10.849114894330178`", 
            "10.849114894330178`"},
          {"100", "11.652547822174217`", "11.652547822174224`", 
            "11.652547822174208`"},
          {"120", "12.327791851736501`", "12.327791851736494`", 
            "12.327791851736494`"},
          {"140", "12.889218820282824`", "12.889218820282842`", 
            "12.889218820282842`"},
          {"160", "13.350363064173846`", "13.350363064173836`", 
            "13.350363064173836`"},
          {"180", "13.724913803030262`", "13.724913803030251`", 
            "13.724913803030251`"},
          {"200", "14.026154149405448`", "14.026154149405459`", 
            "14.02615414940547`"},
          {"220", "14.266370388630865`", "14.266370388630842`", 
            "14.266370388630842`"},
          {"240", "14.456490948922456`", "14.456490948922456`", 
            "14.456490948922466`"},
          {"260", "14.605945912582293`", "14.605945912582293`", 
            "14.605945912582316`"},
          {"280", "14.722683987813284`", "14.722683987813273`", 
            "14.72268398781326`"},
          {"300", "14.813284522975852`", "14.813284522975852`", 
            "14.81328452297584`"},
          {"320", "14.883116646358488`", "14.8831166463585`", 
            "14.883116646358513`"},
          {"340", "14.936513220436943`", "14.936513220436943`", 
            "14.936513220436943`"},
          {"360", "14.97694002316221`", "14.976940023162236`", 
            "14.97694002316221`"},
          {"380", "15.007149689106289`", "15.007149689106289`", 
            "15.007149689106264`"},
          {"400", "15.02931592912226`", "15.0293159291223`", 
            "15.029315929122273`"},
          {"420", "15.045147176927838`", "15.045147176927838`", 
            "15.045147176927813`"},
          {"440", "15.055980818615655`", "15.055980818615655`", 
            "15.055980818615668`"},
          {"460", "15.062860123892849`", "15.062860123892861`", 
            "15.062860123892849`"},
          {"480", "15.066596328187739`", "15.066596328187714`", 
            "15.066596328187764`"},
          {"500", "15.067818288559337`", "15.06781828855935`", 
            "15.06781828855935`"}
          },
        RowSpacings->1,
        ColumnSpacings->3,
        RowAlignments->Baseline,
        ColumnAlignments->{Left}],
      Function[ BoxForm`e$, 
        TableForm[ BoxForm`e$]]]], "Output",
  CellLabel->"Out[7]//TableForm="]
}, Closed]],

Cell[TextData[{
  StyleBox["Q1: ",
    FontColor->RGBColor[0, 0, 1]],
  " Simulate clines with different selection coefficients.  How does cline \
width depend on selection strength?"
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Cline shape", "SubsubsectionIcon"],

Cell[TextData[{
  "Variations in cline shape can be seen most easily by plotting on a ",
  StyleBox["logit",
    FontSlant->"Italic"],
  " sclae, ",
  Cell[BoxData[
      \(TraditionalForm\`Log[p\/q]\  = \ Log[1/\((1\/p - 1)\)]\)]],
  ".  This plots a cline maintained by stepped selection across an \
\"ecotone\", generated in the last section:"
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(LinearLogListPlot[1/\((1\/AlleleFrequencyMean[res[500]] - 1)\), 
        PlotJoined \[Rule] True];\)\)], "Input",
  CellLabel->"In[11]:="],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.031746 0.309017 0.343763 [
[.02381 -0.0125 -3 -9 ]
[.02381 -0.0125 3 0 ]
[.18254 -0.0125 -3 -9 ]
[.18254 -0.0125 3 0 ]
[.34127 -0.0125 -6 -9 ]
[.34127 -0.0125 6 0 ]
[.5 -0.0125 -6 -9 ]
[.5 -0.0125 6 0 ]
[.65873 -0.0125 -6 -9 ]
[.65873 -0.0125 6 0 ]
[.81746 -0.0125 -6 -9 ]
[.81746 -0.0125 6 0 ]
[.97619 -0.0125 -6 -9 ]
[.97619 -0.0125 6 0 ]
[-0.0125 .06874 -22 -6 ]
[-0.0125 .06874 0 6 ]
[-0.0125 .20553 -22 -6 ]
[-0.0125 .20553 0 6 ]
[-0.0125 .30902 -10 -6 ]
[-0.0125 .30902 0 6 ]
[-0.0125 .4125 -10 -6 ]
[-0.0125 .4125 0 6 ]
[-0.0125 .5493 -10 -6 ]
[-0.0125 .5493 0 6 ]
[ -0.0005 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 0 m
.02381 .00625 L
s
[(0)] .02381 -0.0125 0 1 Mshowa
.18254 0 m
.18254 .00625 L
s
[(5)] .18254 -0.0125 0 1 Mshowa
.34127 0 m
.34127 .00625 L
s
[(10)] .34127 -0.0125 0 1 Mshowa
.5 0 m
.5 .00625 L
s
[(15)] .5 -0.0125 0 1 Mshowa
.65873 0 m
.65873 .00625 L
s
[(20)] .65873 -0.0125 0 1 Mshowa
.81746 0 m
.81746 .00625 L
s
[(25)] .81746 -0.0125 0 1 Mshowa
.97619 0 m
.97619 .00625 L
s
[(30)] .97619 -0.0125 0 1 Mshowa
.125 Mabswid
.05556 0 m
.05556 .00375 L
s
.0873 0 m
.0873 .00375 L
s
.11905 0 m
.11905 .00375 L
s
.15079 0 m
.15079 .00375 L
s
.21429 0 m
.21429 .00375 L
s
.24603 0 m
.24603 .00375 L
s
.27778 0 m
.27778 .00375 L
s
.30952 0 m
.30952 .00375 L
s
.37302 0 m
.37302 .00375 L
s
.40476 0 m
.40476 .00375 L
s
.43651 0 m
.43651 .00375 L
s
.46825 0 m
.46825 .00375 L
s
.53175 0 m
.53175 .00375 L
s
.56349 0 m
.56349 .00375 L
s
.59524 0 m
.59524 .00375 L
s
.62698 0 m
.62698 .00375 L
s
.69048 0 m
.69048 .00375 L
s
.72222 0 m
.72222 .00375 L
s
.75397 0 m
.75397 .00375 L
s
.78571 0 m
.78571 .00375 L
s
.84921 0 m
.84921 .00375 L
s
.88095 0 m
.88095 .00375 L
s
.9127 0 m
.9127 .00375 L
s
.94444 0 m
.94444 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .06874 m
.00625 .06874 L
s
gsave
-0.0125 .06874 -83 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.2) show
81.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 .20553 m
.00625 .20553 L
s
gsave
-0.0125 .20553 -83 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.5) show
81.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 .30902 m
.00625 .30902 L
s
gsave
-0.0125 .30902 -71 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 .4125 m
.00625 .4125 L
s
gsave
-0.0125 .4125 -71 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 .5493 m
.00625 .5493 L
s
gsave
-0.0125 .5493 -71 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(5) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.001 w
0 .12927 m
.00375 .12927 L
s
0 .17222 m
.00375 .17222 L
s
0 .23275 m
.00375 .23275 L
s
0 .25577 m
.00375 .25577 L
s
0 .2757 m
.00375 .2757 L
s
0 .29329 m
.00375 .29329 L
s
0 .47303 m
.00375 .47303 L
s
0 .51598 m
.00375 .51598 L
s
0 .57652 m
.00375 .57652 L
s
0 .59953 m
.00375 .59953 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.05556 .01472 m
.0873 .03791 L
.11905 .05032 L
.15079 .06116 L
.18254 .07249 L
.21429 .08502 L
.24603 .09907 L
.27778 .11484 L
.30952 .13245 L
.34127 .15204 L
.37302 .17378 L
.40476 .19792 L
.43651 .22479 L
.46825 .25493 L
.5 .28917 L
.53175 .32886 L
.56349 .3631 L
.59524 .39324 L
.62698 .42012 L
.65873 .44425 L
.69048 .466 L
.72222 .48559 L
.75397 .5032 L
.78571 .51896 L
.81746 .53302 L
.84921 .54554 L
.88095 .55687 L
.9127 .56771 L
.94444 .58012 L
.97619 .60332 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[11]:=",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/B000`400?l00000o`00003ooooooolQ
ooooo`00oooooolQooooo`007_ooool2o`0002Oooooo0ol0000Sooooo`?o00001?ooool2o`00027o
oooo0ol00003ooooo`?o00007oooool5o`0000?ooooo0_l0000Pooooo`Go00000_ooool3o`00023o
oooo0ol00004ooooo`;o00001?ooool001gooooo00Co0000oooooooooooo00009Oooool01Ol0003o
oooooooooooooooo000002?ooooo00?o0000ooooooooool00_ooool01?l0003oooooooooool0000Q
ooooo`05o`000?ooooooooooooooool000000oooool00ol0003oooooooooo`0Mooooo`04o`000?oo
ooooooooo`0000;ooooo00Co0000oooooooooooo00008?ooool01_l0003oooooooooool0003ooooo
o`0000?ooooo00?o0000ooooooooool07?ooool01Ol0003ooooooooooooooooo000000;ooooo00Co
0000oooooooooooo00000oooool001gooooo00Co0000oooooooooooo0000:Oooool00ol0003ooooo
ooooo`0Qooooo`03o`000?oooooooooo00;ooooo00Co0000oooooooooooo00008Oooool00ol0003o
ooooooooo`05ooooo`03o`000?oooooooooo01kooooo00?o0000ooooooooool00_ooool01?l0003o
ooooooooool0000Qooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool08?ooool01?l0
003oooooooooool00002ooooo`03o`000?oooooooooo007ooooo000Mooooo`04o`000?oooooooooo
o`0002Wooooo00?o0000ooooooooool08Oooool00ol0003oooooooooo`02ooooo`04o`000?oooooo
ooooo`00027ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`0Oooooo`05o`000?oo
ooooooooooooool000000_ooool00ol0003oooooooooo`0Pooooo`03o`000?oooooooooo00Cooooo
00?o0000ooooooooool07_ooool2o`0000?ooooo00Co0000oooooooooooo00000oooool001gooooo
00Co0000oooooooooooo00009Oooool4o`0002Cooooo00?o0000ooooooooool00_ooool01?l0003o
ooooooooool0000Qooooo`04o`000?ooooooooooooooo`Co00007oooool01Ol0003ooooooooooooo
oooo000000;ooooo00Co0000oooooooooooo00007oooool01_l0003ooooooooooooooooo0000oooo
o`Co00008oooool01?l0003oooooooooool00002ooooo`03o`000?oooooooooo007ooooo000Moooo
o`04o`000?ooooooooooo`0002Gooooo00?o0000ooooooooool09?ooool2o`0000Cooooo00Co0000
oooooooooooo00008?ooool2o`0000?ooooo00?o0000ooooooooool08?ooool01Ol0003ooooooooo
oooooooo000000;ooooo00Co0000oooooooooooo00007oooool01ol0003ooooooooooooooooo0000
ooooool000008_ooool01Ol0003ooooooooooooooooo000000;ooooo00Co0000oooooooooooo0000
0oooool001kooooo0_l0000Vooooo`Go00008oooool00ol0003oooooooooo`03ooooo`;o00008_oo
ool01?l0003oooooooooooooool5o`0001oooooo0ol00004ooooo`;o00008Oooool3o`0000;ooooo
1Ol0000Oooooo`?o00001?ooool2o`0000Cooooo003oooooob7ooooo003oooooob7ooooo003ooooo
ob7ooooo003oooooob7ooooo000Iooooo`0300000?l0003o00000?oo00001Ol0000001Wooooo00<0
0000ooooooooool00oooool00`00003oooooooooo`05ooooo`03o`000?oooooooooo00Kooooo00?o
0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Kooooo00?o
0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o
0000ooooooooool01_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o
0000ooooooooool01_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o
0000ooooooooool01_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o
0000ooooooooool01_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o
0000ooooooooool01Oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Gooooo00?o
0000ooooooooool01Oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Gooooo00?o
0000ooooooooool01Oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Gooooo00?o
0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`006Oooool00`00003oooooooooo`03
ooooo`0300000?oooooooooo02Oooooo00?o0000ooooooooool09_ooool00ol0003oooooooooo`0W
ooooo`03o`000?oooooooooo02Kooooo00?o0000ooooooooool09oooool00ol0003oooooooooo`0V
ooooo`03o`000?oooooooooo00Gooooo000Iooooo`0300000?oooooooooo0?oooooo1Oooool001Wo
oooo00<00000ooooooooool02oooool200000?Oooooo000Iooooo`0300000?oooooooooo00gooooo
00<00000ooooooooool0m?ooool001Wooooo00<00000ooooooooool03_ooool200000?Cooooo000I
ooooo`0300000?oooooooooo013ooooo00<00000ooooooooool0lOooool001Wooooo00<00000oooo
ooooool04Oooool200000?7ooooo000Iooooo`0300000?oooooooooo01?ooooo00<00000oooooooo
ool0k_ooool001Wooooo00<00000ooooooooool05?ooool200000>kooooo000Iooooo`0300000?oo
oooooooo01Kooooo0`00003[ooooo`006Oooool00`00003oooooooooo`0Iooooo`<00000j?ooool0
01Wooooo00<00000ooooooooool07?ooool200000>Kooooo000Iooooo`0300000?oooooooooo01ko
oooo0`00003Sooooo`006Oooool00`00003oooooooooo`0Qooooo`<00000h?ooool000Cooooo0_l0
0004ooooo`04o`000?ooooooooooooooo`Go00001_ooool00`00003oooooooooo`0Tooooo`<00000
gOooool000?ooooo00Co0000oooooooooooo00002?ooool01?l0003oooooooooool00006ooooo`03
00000?oooooooooo02Oooooo0`00003Jooooo`000oooool01?l0003oooooooooool00009ooooo`03
o`000?oooooooooo00Kooooo00<00000o`000?ooool0:_ooool300000=Oooooo0003ooooo`04o`00
0?ooooooooooo`0000[ooooo00?o0000ooooooooool01Oooool00`00003oooooooooo`0]ooooo`80
0000eOooool000?ooooo00Co0000oooooooooooo00001oooool01Ol0003ooooooooooooooooo0000
00Kooooo00<00000ooooooooool0;oooool200000=?ooooo0003ooooo`04o`000?ooooooooooo`00
00Oooooo00Go0000ooooooooooooooooo`000006ooooo`0300000?oooooooooo037ooooo0P00003A
ooooo`001?ooool2o`0000Wooooo0ol00007ooooo`0300000?oooooooooo03?ooooo0P00003?oooo
o`006Oooool00`00003oooooooooo`0eooooo`800000cOooool001Wooooo00<00000ooooooooool0
=oooool300000<[ooooo000Iooooo`0300000?oooooooooo03[ooooo0`000037ooooo`006Oooool0
0`00003oooooooooo`0mooooo`800000aOooool001Wooooo00<00000ooooooooool0?oooool20000
0<?ooooo000Iooooo`0300000?oooooooooo047ooooo0P000031ooooo`006Oooool00`00003ooooo
ooooo`13ooooo`800000_oooool001Wooooo00<00000ooooooooool0AOooool200000;gooooo000I
ooooo`0300000?oooooooooo04Oooooo0P00002kooooo`006Oooool00`00003oooooooooo`19oooo
o`800000^Oooool001Wooooo00<00000ooooooooool0Boooool00`00003oooooooooo`2fooooo`00
6Oooool00`00003o0000ooooo`1<ooooo`800000]_ooool001Wooooo00<00000ooooooooool0C_oo
ool200000;Cooooo000Iooooo`0300000?oooooooooo053ooooo00<00000ooooooooool0/Oooool0
01Wooooo00<00000ooooooooool0DOooool200000;7ooooo000Iooooo`0300000?oooooooooo05?o
oooo0P00002_ooooo`006Oooool00`00003oooooooooo`1Eooooo`0300000?oooooooooo0:cooooo
000Iooooo`0300000?oooooooooo05Kooooo0P00002/ooooo`006Oooool00`00003oooooooooo`1H
ooooo`0300000?oooooooooo0:Wooooo000Iooooo`0300000?oooooooooo05Wooooo00<00000oooo
ooooool0Z?ooool001Wooooo00<00000ooooooooool0F_ooool200000:Sooooo000Iooooo`030000
0?oooooooooo05cooooo00<00000ooooooooool0YOooool001Wooooo00<00000o`000?ooool0GOoo
ool00`00003oooooooooo`2Tooooo`006Oooool00`00003oooooooooo`1Nooooo`800000Y?ooool0
01Wooooo00<00000ooooooooool0H?ooool00`00003oooooooooo`2Qooooo`006Oooool00`00003o
ooooooooo`1Qooooo`800000XOooool001Wooooo00<00000ooooooooool0Hoooool00`00003ooooo
ooooo`2Nooooo`006Oooool00`00003oooooooooo`1Tooooo`800000W_ooool001Wooooo00<00000
ooooooooool0I_ooool00`00003oooooooooo`2Kooooo`001?ooool2o`0000Cooooo00?o0000oooo
ooooool00_ooool3o`0000Oooooo00<00000ooooooooool0Ioooool2000009_ooooo0003ooooo`04
o`000?ooooooooooo`0000Oooooo00Go0000ooooooooooooooooo`000006ooooo`0300000?oooooo
oooo06Wooooo00<00000ooooooooool0V?ooool000?ooooo00Co0000oooooooooooo00002oooool0
0ol0003oooooooooo`04ooooo`0300000?l0003ooooo06[ooooo00<00000ooooooooool0Uoooool0
00?ooooo00Co0000oooooooooooo00002oooool00ol0003oooooooooo`04ooooo`0300000?oooooo
oooo06_ooooo00<00000ooooooooool0U_ooool000?ooooo00Co0000oooooooooooo00001oooool4
o`0000Oooooo00<00000ooooooooool0K?ooool00`00003oooooooooo`2Eooooo`000oooool01?l0
003oooooooooool00007ooooo`03o`000?oooooooooo00Sooooo00<00000ooooooooool0KOooool0
0`00003oooooooooo`2Dooooo`001?ooool2o`0000Sooooo1Ol00006ooooo`0300000?oooooooooo
06kooooo00<00000ooooooooool0Toooool001Wooooo00<00000ooooooooool0Koooool00`00003o
ooooooooo`2Booooo`006Oooool00`00003oooooooooo`1`ooooo`0300000?oooooooooo097ooooo
000Iooooo`0300000?l0003ooooo077ooooo00<00000ooooooooool0T?ooool001Wooooo00<00000
ooooooooool0L_ooool00`00003oooooooooo`2?ooooo`006Oooool00`00003oooooooooo`1coooo
o`0300000?oooooooooo08kooooo000Iooooo`0300000?oooooooooo07Cooooo00<00000oooooooo
ool0SOooool001Wooooo00<00000ooooooooool0MOooool00`00003oooooooooo`2<ooooo`006Ooo
ool00`00003oooooooooo`1fooooo`0300000?oooooooooo08_ooooo000Iooooo`0300000?l0003o
oooo07Oooooo00<00000ooooooooool0R_ooool001Wooooo00<00000ooooooooool0N?ooool00`00
003oooooooooo`29ooooo`006Oooool00`00003oooooooooo`1iooooo`0300000?oooooooooo08So
oooo000Iooooo`0300000?oooooooooo07[ooooo00<00000ooooooooool0Qoooool001Wooooo00<0
0000ooooooooool0Noooool00`00003oooooooooo`26ooooo`006Oooool00`00003o0000ooooo`1l
ooooo`0300000?oooooooooo08Gooooo000Iooooo`0300000?oooooooooo07gooooo00<00000oooo
ooooool0Q?ooool001Wooooo00<00000ooooooooool0O_ooool00`00003oooooooooo`23ooooo`00
6Oooool00`00003oooooooooo`1oooooo`0300000?oooooooooo08;ooooo000Iooooo`0300000?oo
oooooooo083ooooo00<00000ooooooooool0POooool001Wooooo00<00000o`000?ooool0P?ooool0
0`00003oooooooooo`21ooooo`006Oooool00`00003oooooooooo`21ooooo`0300000?oooooooooo
083ooooo000?ooooo`?o00001oooool00`00003oooooooooo`22ooooo`0300000?oooooooooo07oo
oooo000@ooooo`03o`000?oooooooooo00Kooooo00<00000ooooooooool0Poooool00`00003ooooo
ooooo`1nooooo`004?ooool00ol0003oooooooooo`06ooooo`0300000?l0003ooooo08Cooooo00<0
0000ooooooooool0OOooool0013ooooo00?o0000ooooooooool01_ooool00`00003oooooooooo`24
ooooo`0300000?oooooooooo07gooooo000@ooooo`03o`000?oooooooooo00Kooooo00<00000oooo
ooooool0QOooool00`00003oooooooooo`1looooo`003oooool2o`0000Sooooo00<00000oooooooo
ool0Q_ooool00`00003oooooooooo`1kooooo`004?ooool00ol0003oooooooooo`06ooooo`030000
0?oooooooooo08Oooooo00<00000ooooooooool0N_ooool001Wooooo00<00000ooooooooool0R?oo
ool00`00003oooooooooo`1iooooo`006Oooool00`00003oooooooooo`28ooooo`0300000?oooooo
oooo07Wooooo000Iooooo`0300000?oooooooooo08Wooooo00<00000ooooooooool0N?ooool001Wo
oooo00<00000ooooooooool0R_ooool00`00003oooooooooo`1gooooo`006Oooool00`00003ooooo
ooooo`2;ooooo`0300000?oooooooooo07Kooooo000Iooooo`0300000?oooooooooo08cooooo00<0
0000ooooooooool0MOooool001Wooooo00<00000ooooooooool0SOooool00`00003oooooooooo`1d
ooooo`006Oooool00`00003oooooooooo`2>ooooo`0300000?oooooooooo07?ooooo000Iooooo`03
00000?oooooooooo08oooooo00<00000ooooooooool0L_ooool001Wooooo00<00000ooooooooool0
T?ooool2000007;ooooo000Iooooo`0300000?oooooooooo09;ooooo00<00000ooooooooool0Kooo
ool001Wooooo00<00000ooooooooool0Toooool00`00003oooooooooo`1^ooooo`006Oooool00`00
003oooooooooo`2Dooooo`0300000?oooooooooo06gooooo000Iooooo`0300000?oooooooooo09Go
oooo00<00000ooooooooool0K?ooool001Wooooo00<00000ooooooooool0U_ooool00`00003ooooo
ooooo`1[ooooo`006Oooool00`00003oooooooooo`2Gooooo`0300000?oooooooooo06[ooooo000I
ooooo`0300000?oooooooooo09Sooooo00<00000ooooooooool0JOooool001Wooooo00<00000oooo
ooooool0VOooool2000006Wooooo000Iooooo`0300000?oooooooooo09_ooooo00<00000oooooooo
ool0I_ooool001Wooooo00<00000ooooooooool0W?ooool00`00003oooooooooo`1Uooooo`003_oo
ool5o`0000Kooooo00<00000ooooooooool0WOooool00`00003oooooooooo`1Tooooo`003oooool0
1?l0003oooooooooool00006ooooo`0300000?oooooooooo09kooooo00<00000ooooooooool0Hooo
ool0013ooooo00?o0000ooooooooool01_ooool00`00003o0000ooooo`2Oooooo`0300000?oooooo
oooo06;ooooo000Aooooo`03o`000?oooooooooo00Gooooo00<00000ooooooooool0X?ooool00`00
003oooooooooo`1Qooooo`003_ooool01Ol0003ooooooooooooooooo000000Kooooo00<00000oooo
ooooool0XOooool20000067ooooo000>ooooo`05o`000?ooooooooooooooool000001_ooool00`00
003oooooooooo`2Sooooo`0300000?oooooooooo05kooooo000?ooooo`?o00001oooool00`00003o
ooooooooo`2Tooooo`0300000?oooooooooo05gooooo000Iooooo`0300000?oooooooooo0:Gooooo
00<00000ooooooooool0G?ooool001Wooooo00<00000ooooooooool0Y_ooool00`00003ooooooooo
o`1Kooooo`006Oooool00`00003oooooooooo`2Wooooo`0300000?oooooooooo05[ooooo000Ioooo
o`0300000?oooooooooo0:Sooooo00<00000ooooooooool0FOooool001Wooooo00<00000oooooooo
ool0ZOooool2000005Wooooo000Iooooo`0300000?oooooooooo0:_ooooo00<00000ooooooooool0
E_ooool001Wooooo00<00000ooooooooool0[?ooool2000005Kooooo000Iooooo`0300000?oooooo
oooo0:kooooo0P00001Dooooo`006Oooool00`00003oooooooooo`2`ooooo`0300000?oooooooooo
057ooooo000Iooooo`0300000?oooooooooo0;7ooooo0P00001Aooooo`006Oooool00`00003ooooo
ooooo`2cooooo`800000Coooool001Wooooo00<00000o`000?ooool0]Oooool2000004gooooo000I
ooooo`0300000?oooooooooo0;Oooooo00<00000ooooooooool0B_ooool001Wooooo00<00000oooo
ooooool0^?ooool2000004[ooooo000Iooooo`0300000?oooooooooo0;[ooooo0P000018ooooo`00
6Oooool00`00003oooooooooo`2looooo`0300000?oooooooooo04Gooooo000Iooooo`0300000?oo
oooooooo0;gooooo0P000015ooooo`006Oooool00`00003oooooooooo`2oooooo`800000@oooool0
01Wooooo00<00000ooooooooool0`Oooool00`00003oooooooooo`10ooooo`006Oooool00`00003o
ooooooooo`32ooooo`800000@?ooool001Wooooo00<00000ooooooooool0a?ooool2000003kooooo
000Iooooo`0300000?oooooooooo0<Kooooo0P00000looooo`006Oooool00`00003o0000ooooo`38
ooooo`800000>_ooool001Wooooo00<00000ooooooooool0b_ooool2000003Sooooo000Iooooo`03
00000?oooooooooo0<cooooo0P00000fooooo`006Oooool00`00003oooooooooo`3>ooooo`<00000
<oooool001Wooooo00<00000ooooooooool0dOooool20000037ooooo000Iooooo`0300000?oooooo
oooo0=?ooooo0P00000_ooooo`006Oooool00`00003oooooooooo`3Eooooo`<00000;?ooool000oo
oooo0ol00007ooooo`0300000?oooooooooo0=Sooooo0`00000Yooooo`003_ooool01Ol0003ooooo
oooooooooooo000000Kooooo00<00000ooooooooool0foooool2000002Oooooo000Booooo`03o`00
0?oooooooooo00Cooooo00<00000o`000?ooool0gOooool3000002Cooooo000Booooo`03o`000?oo
oooooooo00Cooooo00<00000ooooooooool0h?ooool30000027ooooo000>ooooo`Co00001oooool0
0`00003oooooooooo`3Sooooo`<000007_ooool000kooooo00?o0000ooooooooool02?ooool00`00
003oooooooooo`3Vooooo`<000006oooool000kooooo1Ol00006ooooo`0300000?oooooooooo0>Wo
oooo0`00000Hooooo`006Oooool00`00003oooooooooo`3/ooooo`8000005_ooool001Wooooo00<0
0000ooooooooool0k_ooool3000001?ooooo000Iooooo`0300000?l0003ooooo0?7ooooo0`00000@
ooooo`006Oooool00`00003oooooooooo`3dooooo`8000003_ooool001Wooooo00<00000oooooooo
ool0m_ooool00`00003oooooooooo`0;ooooo`006Oooool00`00003oooooooooo`3gooooo`030000
0?oooooooooo00[ooooo000Iooooo`0300000?oooooooooo0?Sooooo0P00000:ooooo`006Oooool0
0`00003oooooooooo`3jooooo`0300000?oooooooooo00Oooooo000Iooooo`0300000?l0003ooooo
0?_ooooo00<00000ooooooooool01_ooool001Wooooo00<00000ooooooooool0o?ooool00`00003o
ooooooooo`05ooooo`006Oooool00`00003oooooooooo`3oooooo`Gooooo000Iooooo`0300000?oo
oooooooo0?oooooo1Oooool001Wooooo00<00000ooooooooool0ooooool5ooooo`006Oooool00`00
003oooooooooo`3oooooo`Gooooo003oooooob7ooooo0000\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-3.79172, -1.0515, 0.120355, \
0.0111146}}]
}, Open  ]],

Cell[TextData[{
  StyleBox["Q2: ",
    FontColor->RGBColor[0, 0, 1]],
  "A cline maintained by selection against heterozygotes ",
  Cell[BoxData[
      \(TraditionalForm\`\((\[PartialD]\_t p\  = \ 
          s\[VeryThinSpace]p\[VeryThinSpace]\(q(p - q)\)\)\)]],
  ") gives a straight line on a logit scale",
  ", ",
  "For the plot above, what might explain deviations from a straight line on \
a logit scale??"
}], "Text"]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Linkage disequilibrium",
  FontColor->RGBColor[0, 0, 1]]], "SubsubsectionIcon"],

Cell["\<\
This shows the pattern of linkage disequilibrium between the three \
loci.:\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(ListPlot[DisequilibriumMean[res[500]], 
        PlotJoined \[Rule] True];\)\), "\[IndentingNewLine]", 
    \(\(DisequilibriumMean[
        res[500]]\)\[LeftDoubleBracket]15\[RightDoubleBracket]\)}], "Input",
  CellLabel->"In[12]:="],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.031746 0.0147151 165.549 [
[.18254 .00222 -3 -9 ]
[.18254 .00222 3 0 ]
[.34127 .00222 -6 -9 ]
[.34127 .00222 6 0 ]
[.5 .00222 -6 -9 ]
[.5 .00222 6 0 ]
[.65873 .00222 -6 -9 ]
[.65873 .00222 6 0 ]
[.81746 .00222 -6 -9 ]
[.81746 .00222 6 0 ]
[.97619 .00222 -6 -9 ]
[.97619 .00222 6 0 ]
[.01131 .09749 -36 -4.5 ]
[.01131 .09749 0 4.5 ]
[.01131 .18026 -30 -4.5 ]
[.01131 .18026 0 4.5 ]
[.01131 .26304 -36 -4.5 ]
[.01131 .26304 0 4.5 ]
[.01131 .34581 -30 -4.5 ]
[.01131 .34581 0 4.5 ]
[.01131 .42859 -36 -4.5 ]
[.01131 .42859 0 4.5 ]
[.01131 .51136 -30 -4.5 ]
[.01131 .51136 0 4.5 ]
[.01131 .59414 -36 -4.5 ]
[.01131 .59414 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.18254 .01472 m
.18254 .02097 L
s
[(5)] .18254 .00222 0 1 Mshowa
.34127 .01472 m
.34127 .02097 L
s
[(10)] .34127 .00222 0 1 Mshowa
.5 .01472 m
.5 .02097 L
s
[(15)] .5 .00222 0 1 Mshowa
.65873 .01472 m
.65873 .02097 L
s
[(20)] .65873 .00222 0 1 Mshowa
.81746 .01472 m
.81746 .02097 L
s
[(25)] .81746 .00222 0 1 Mshowa
.97619 .01472 m
.97619 .02097 L
s
[(30)] .97619 .00222 0 1 Mshowa
.125 Mabswid
.05556 .01472 m
.05556 .01847 L
s
.0873 .01472 m
.0873 .01847 L
s
.11905 .01472 m
.11905 .01847 L
s
.15079 .01472 m
.15079 .01847 L
s
.21429 .01472 m
.21429 .01847 L
s
.24603 .01472 m
.24603 .01847 L
s
.27778 .01472 m
.27778 .01847 L
s
.30952 .01472 m
.30952 .01847 L
s
.37302 .01472 m
.37302 .01847 L
s
.40476 .01472 m
.40476 .01847 L
s
.43651 .01472 m
.43651 .01847 L
s
.46825 .01472 m
.46825 .01847 L
s
.53175 .01472 m
.53175 .01847 L
s
.56349 .01472 m
.56349 .01847 L
s
.59524 .01472 m
.59524 .01847 L
s
.62698 .01472 m
.62698 .01847 L
s
.69048 .01472 m
.69048 .01847 L
s
.72222 .01472 m
.72222 .01847 L
s
.75397 .01472 m
.75397 .01847 L
s
.78571 .01472 m
.78571 .01847 L
s
.84921 .01472 m
.84921 .01847 L
s
.88095 .01472 m
.88095 .01847 L
s
.9127 .01472 m
.9127 .01847 L
s
.94444 .01472 m
.94444 .01847 L
s
.25 Mabswid
0 .01472 m
1 .01472 L
s
.02381 .09749 m
.03006 .09749 L
s
[(0.0005)] .01131 .09749 1 0 Mshowa
.02381 .18026 m
.03006 .18026 L
s
[(0.001)] .01131 .18026 1 0 Mshowa
.02381 .26304 m
.03006 .26304 L
s
[(0.0015)] .01131 .26304 1 0 Mshowa
.02381 .34581 m
.03006 .34581 L
s
[(0.002)] .01131 .34581 1 0 Mshowa
.02381 .42859 m
.03006 .42859 L
s
[(0.0025)] .01131 .42859 1 0 Mshowa
.02381 .51136 m
.03006 .51136 L
s
[(0.003)] .01131 .51136 1 0 Mshowa
.02381 .59414 m
.03006 .59414 L
s
[(0.0035)] .01131 .59414 1 0 Mshowa
.125 Mabswid
.02381 .03127 m
.02756 .03127 L
s
.02381 .04782 m
.02756 .04782 L
s
.02381 .06438 m
.02756 .06438 L
s
.02381 .08093 m
.02756 .08093 L
s
.02381 .11404 m
.02756 .11404 L
s
.02381 .1306 m
.02756 .1306 L
s
.02381 .14715 m
.02756 .14715 L
s
.02381 .16371 m
.02756 .16371 L
s
.02381 .19682 m
.02756 .19682 L
s
.02381 .21337 m
.02756 .21337 L
s
.02381 .22993 m
.02756 .22993 L
s
.02381 .24648 m
.02756 .24648 L
s
.02381 .27959 m
.02756 .27959 L
s
.02381 .29615 m
.02756 .29615 L
s
.02381 .3127 m
.02756 .3127 L
s
.02381 .32926 m
.02756 .32926 L
s
.02381 .36237 m
.02756 .36237 L
s
.02381 .37892 m
.02756 .37892 L
s
.02381 .39548 m
.02756 .39548 L
s
.02381 .41203 m
.02756 .41203 L
s
.02381 .44514 m
.02756 .44514 L
s
.02381 .4617 m
.02756 .4617 L
s
.02381 .47825 m
.02756 .47825 L
s
.02381 .49481 m
.02756 .49481 L
s
.02381 .52792 m
.02756 .52792 L
s
.02381 .54447 m
.02756 .54447 L
s
.02381 .56103 m
.02756 .56103 L
s
.02381 .57758 m
.02756 .57758 L
s
.02381 .61069 m
.02756 .61069 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.05556 .23632 m
.0873 .05702 L
.11905 .03326 L
.15079 .03209 L
.18254 .03676 L
.21429 .04513 L
.24603 .05758 L
.27778 .07531 L
.30952 .10023 L
.34127 .13504 L
.37302 .18353 L
.40476 .25084 L
.43651 .34341 L
.46825 .46614 L
.5 .60332 L
.53175 .60332 L
.56349 .46614 L
.59524 .34341 L
.62698 .25084 L
.65873 .18353 L
.69048 .13504 L
.72222 .10023 L
.75397 .07531 L
.78571 .05758 L
.81746 .04513 L
.84921 .03676 L
.88095 .03209 L
.9127 .03326 L
.94444 .05702 L
.97619 .23632 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[12]:=",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/B000`400?l00000o`00003ooooooolQ
ooooo`00oooooolQooooo`00oooooolQooooo`00oooooolQooooo`00oooooolQooooo`00oooooolQ
ooooo`00COooool3o`0002;ooooo0ol00004ooooo`;o00008?ooool3o`0000?ooooo0ol0000Noooo
o`Go00000oooool2o`0001kooooo1Ol00002ooooo`?o00007oooool3o`0000Cooooo0_l00004oooo
o`00C?ooool01Ol0003ooooooooooooooooo000002;ooooo00?o0000ooooooooool00_ooool01?l0
003oooooooooool0000Pooooo`05o`000?ooooooooooooooool000000oooool00ol0003ooooooooo
o`0Looooo`04o`000?ooooooooooo`0000;ooooo00Co0000oooooooooooo00007_ooool01_l0003o
ooooooooool0003oooooo`0000?ooooo00?o0000ooooooooool06oooool01Ol0003ooooooooooooo
oooo000000;ooooo00Co0000oooooooooooo00000oooool0053ooooo00?o0000ooooooooool08?oo
ool00ol0003oooooooooo`02ooooo`04o`000?ooooooooooo`00023ooooo00?o0000ooooooooool0
1Oooool00ol0003oooooooooo`0Mooooo`03o`000?oooooooooo00;ooooo00Co0000oooooooooooo
00007oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo01oooooo00Co0000oooooooo
oooo00000_ooool00ol0003oooooooooo`01ooooo`00D?ooool00ol0003oooooooooo`0Pooooo`03
o`000?oooooooooo00;ooooo00Co0000oooooooooooo00008?ooool00ol0003oooooooooo`05oooo
o`03o`000?oooooooooo01kooooo00Go0000ooooooooooooooooo`000002ooooo`03o`000?oooooo
oooo01kooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`0Mooooo`;o00000oooool0
1?l0003oooooooooool00003ooooo`00C?ooool4o`0002?ooooo00?o0000ooooooooool00_ooool0
1?l0003oooooooooool0000Pooooo`04o`000?ooooooooooooooo`Co00007_ooool01Ol0003ooooo
oooooooooooo000000;ooooo00Co0000oooooooooooo00007Oooool01_l0003ooooooooooooooooo
0000ooooo`Co00008_ooool01?l0003oooooooooool00002ooooo`03o`000?oooooooooo007ooooo
001<ooooo`03o`000?oooooooooo02?ooooo0_l00004ooooo`04o`000?ooooooooooo`0001oooooo
0_l00003ooooo`03o`000?oooooooooo01oooooo00Go0000ooooooooooooooooo`000002ooooo`04
o`000?ooooooooooo`0001gooooo00Oo0000ooooooooooooooooo`000?oooooo0000027ooooo00Go
0000ooooooooooooooooo`000002ooooo`04o`000?ooooooooooo`0000?ooooo001<ooooo`Go0000
8_ooool00ol0003oooooooooo`03ooooo`;o00008Oooool01?l0003oooooooooooooool5o`0001ko
oooo0ol00004ooooo`;o00007oooool3o`0000;ooooo1Ol0000Nooooo`?o00001?ooool2o`0000Co
oooo003oooooob7ooooo000Wooooo`03o`000?oooooooooo0?Kooooo000Wooooo`03o`000?oooooo
oooo0?Kooooo000Wooooo`03o`000?oooooooooo0?Kooooo000Wooooo`03o`000?oooooooooo0?Ko
oooo000Qoooooooo0000000Wooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool09Ooo
ool00ol0003oooooooooo`0Vooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool09Ooo
ool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo00Gooooo000Wooooo`03o`000?oooooo
oooo0?Kooooo000Wooooo`03o`000?oooooooooo0?Kooooo000Wooooo`;o00005Oooool>o`000;3o
oooo3_l0000Fooooo`009oooool00ol0003oooooooooo`0Cooooo`03o`000?oooooooooo00cooooo
1_l0002Tooooo`Ko00003_ooool00ol0003oooooooooo`0Cooooo`009oooool00ol0003ooooooooo
o`0Booooo`03o`000?oooooooooo01?ooooo1?l0002Looooo`Co00005Oooool00ol0003ooooooooo
o`0Booooo`009oooool00ol0003oooooooooo`0@ooooo`;o00006_ooool3o`0009Kooooo0ol0000J
ooooo`;o00004_ooool002Oooooo0_l0000@ooooo`03o`000?oooooooooo01gooooo0ol0002@oooo
o`?o00007oooool00ol0003oooooooooo`0?ooooo`009oooool00ol0003oooooooooo`0>ooooo`03
o`000?oooooooooo027ooooo0ol0002:ooooo`?o00008oooool00ol0003oooooooooo`0>ooooo`00
9oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo02Gooooo0_l00026ooooo`;o0000
9oooool00ol0003oooooooooo`0=ooooo`009oooool00ol0003oooooooooo`0=ooooo`03o`000?oo
oooooooo02Oooooo00?o0000ooooooooool0P_ooool00ol0003oooooooooo`0Wooooo`03o`000?oo
oooooooo00gooooo000Wooooo`;o00003_ooool00ol0003oooooooooo`0Xooooo`;o0000P?ooool2
o`0002[ooooo00?o0000ooooooooool03Oooool002Oooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0Zooooo`;o0000O?ooool2o`0002cooooo00?o0000ooooooooool03Oooool002Oo
oooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0]ooooo`03o`000?oooooooooo07So
oooo00?o0000ooooooooool0;Oooool00ol0003oooooooooo`0<ooooo`009oooool00ol0003ooooo
ooooo`0<ooooo`03o`000?oooooooooo02kooooo0_l0001fooooo`;o0000<?ooool00ol0003ooooo
ooooo`0<ooooo`009oooool2o`0000gooooo00?o0000ooooooooool0<?ooool00ol0003ooooooooo
o`1booooo`03o`000?oooooooooo033ooooo00?o0000ooooooooool03?ooool002Oooooo00?o0000
ooooooooool03?ooool00ol0003oooooooooo`0aooooo`03o`000?oooooooooo073ooooo00?o0000
ooooooooool0<Oooool00ol0003oooooooooo`0<ooooo`000_ooool2o`0000Cooooo00?o0000oooo
ooooool00oooool2o`0000Cooooo0_l00004ooooo`;o00000oooool3o`0000Gooooo00?o0000oooo
ooooool03?ooool00ol0003oooooooooo`0booooo`;o0000K_ooool2o`0003Cooooo00?o0000oooo
ooooool03?ooool00005ooooool0003oooooooooool000002?ooool01?l0003oooooooooool00002
ooooo`04o`000?ooooooooooo`0000;ooooo00Ko0000oooooooooooo0000ooooool00003ooooo`03
o`000?oooooooooo00;ooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0dooooo`03
o`000?oooooooooo06[ooooo00?o0000ooooooooool0=?ooool00ol0003oooooooooo`0<ooooo`00
00Goooooo`000?ooooooooooo`000008ooooo`04o`000?ooooooooooo`0000;ooooo00Co0000oooo
oooooooo00000_ooool01?l0003oooooooooool00005ooooo`03o`000?oooooooooo00;ooooo00?o
0000ooooooooool02oooool00ol0003oooooooooo`0fooooo`03o`000?oooooooooo06Sooooo00?o
0000ooooooooool0=_ooool00ol0003oooooooooo`0;ooooo`0000Goooooo`000?ooooooooooo`00
0008ooooo`04o`000?ooooooooooo`0000;ooooo00Co0000oooooooooooo00000_ooool01?l0003o
ooooooooool00005ooooo`03o`000?oooooooooo00;ooooo0_l0000<ooooo`03o`000?oooooooooo
03Oooooo00?o0000ooooooooool0I_ooool00ol0003oooooooooo`0gooooo`03o`000?oooooooooo
00_ooooo00001Ooooooo0000oooooooooooo000000Sooooo00Co0000oooooooooooo00000_ooool0
1?l0003oooooooooool00002ooooo`05o`000?ooooooooooo`000?ooool01?l00005ooooo`03o`00
0?oooooooooo00_ooooo00?o0000ooooooooool0=oooool00ol0003oooooooooo`1Vooooo`03o`00
0?oooooooooo03Oooooo00?o0000ooooooooool02oooool00005ooooool0003oooooooooool00000
2?ooool01?l0003oooooooooool00002ooooo`04o`000?ooooooooooo`0000;ooooo00Ko0000oooo
oooooooo0000ooooool00008ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool0>?oo
ool00ol0003oooooooooo`1Tooooo`03o`000?oooooooooo03Sooooo00?o0000ooooooooool02ooo
ool000;ooooo0_l0000:ooooo`;o00001?ooool2o`0000Cooooo0_l00002ooooo`Go00001?ooool0
0ol0003oooooooooo`0;ooooo`03o`000?oooooooooo03Wooooo00?o0000ooooooooool0H_ooool0
0ol0003oooooooooo`0iooooo`03o`000?oooooooooo00_ooooo000Wooooo`;o00002oooool00ol0
003oooooooooo`0kooooo`03o`000?oooooooooo063ooooo00?o0000ooooooooool0>oooool00ol0
003oooooooooo`0:ooooo`009oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo03co
oooo00?o0000ooooooooool0G_ooool00ol0003oooooooooo`0looooo`03o`000?oooooooooo00[o
oooo000Wooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool0?Oooool00ol0003ooooo
ooooo`1Looooo`03o`000?oooooooooo03gooooo00?o0000ooooooooool02_ooool002Oooooo00?o
0000ooooooooool02_ooool00ol0003oooooooooo`0nooooo`03o`000?oooooooooo05[ooooo00?o
0000ooooooooool0?_ooool00ol0003oooooooooo`0:ooooo`009oooool2o`0000_ooooo00?o0000
ooooooooool0?oooool00ol0003oooooooooo`1Hooooo`03o`000?oooooooooo03oooooo00?o0000
ooooooooool02_ooool002Oooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`10oooo
o`03o`000?oooooooooo05Kooooo00?o0000ooooooooool0@?ooool00ol0003oooooooooo`0:oooo
o`009oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo047ooooo00?o0000oooooooo
ool0E_ooool00ol0003oooooooooo`11ooooo`03o`000?oooooooooo00Wooooo000Wooooo`03o`00
0?oooooooooo00Wooooo00?o0000ooooooooool0@_ooool00ol0003oooooooooo`1Dooooo`03o`00
0?oooooooooo04;ooooo00?o0000ooooooooool02Oooool002Oooooo0_l0000:ooooo`03o`000?oo
oooooooo04?ooooo00?o0000ooooooooool0D_ooool00ol0003oooooooooo`13ooooo`03o`000?oo
oooooooo00Wooooo000Wooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool0@oooool0
0ol0003oooooooooo`1Booooo`03o`000?oooooooooo04?ooooo00?o0000ooooooooool02Oooool0
02Oooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`14ooooo`03o`000?oooooooooo
053ooooo00?o0000ooooooooool0A?ooool00ol0003oooooooooo`09ooooo`009oooool00ol0003o
ooooooooo`09ooooo`03o`000?oooooooooo04Gooooo00?o0000ooooooooool0C_ooool00ol0003o
ooooooooo`15ooooo`03o`000?oooooooooo00Wooooo000Wooooo`;o00002Oooool00ol0003ooooo
ooooo`16ooooo`03o`000?oooooooooo04kooooo00?o0000ooooooooool0A_ooool00ol0003ooooo
ooooo`08ooooo`009oooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo04Oooooo00?o
0000ooooooooool0C?ooool00ol0003oooooooooo`17ooooo`03o`000?oooooooooo00Sooooo0008
ooooo`;o00001?ooool00ol0003oooooooooo`03ooooo`;o00001?ooool2o`0000?ooooo0ol00005
ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool0B?ooool00ol0003oooooooooo`1:
ooooo`03o`000?oooooooooo04Sooooo00?o0000ooooooooool02?ooool000Oooooo00Co0000oooo
oooooooo00002?ooool01?l0003oooooooooool00002ooooo`04o`000?ooooooooooo`0000?ooooo
00?o0000ooooooooool01?ooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo04Sooooo
00?o0000ooooooooool0B_ooool00ol0003oooooooooo`18ooooo`03o`000?oooooooooo00Sooooo
0007ooooo`04o`000?ooooooooooo`0000Sooooo00Co0000oooooooooooo00000_ooool01?l0003o
ooooooooool00003ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool02?ooool00ol0
003oooooooooo`19ooooo`03o`000?oooooooooo04Sooooo00?o0000ooooooooool0BOooool00ol0
003oooooooooo`08ooooo`001oooool01?l0003oooooooooool00008ooooo`04o`000?oooooooooo
o`0000;ooooo00Co0000oooooooooooo00000oooool00ol0003oooooooooo`04ooooo`;o00002Ooo
ool00ol0003oooooooooo`1:ooooo`03o`000?oooooooooo04Kooooo00?o0000ooooooooool0B_oo
ool00ol0003oooooooooo`08ooooo`001oooool01?l0003oooooooooool00008ooooo`04o`000?oo
ooooooooo`0000;ooooo00Co0000oooooooooooo00000oooool00ol0003oooooooooo`04ooooo`03
o`000?oooooooooo00Oooooo00?o0000ooooooooool0Boooool00ol0003oooooooooo`16ooooo`03
o`000?oooooooooo04_ooooo00?o0000ooooooooool01oooool000Oooooo00Co0000oooooooooooo
00002?ooool01?l0003oooooooooool00002ooooo`04o`000?ooooooooooo`0000;ooooo0_l00006
ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0C?ooool00ol0003oooooooooo`14
ooooo`03o`000?oooooooooo04cooooo00?o0000ooooooooool01oooool000Sooooo0_l0000:oooo
o`;o00001?ooool2o`0000Cooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`07oooo
o`03o`000?oooooooooo04cooooo00?o0000ooooooooool0A?ooool00ol0003oooooooooo`1<oooo
o`03o`000?oooooooooo00Oooooo000Wooooo`;o00002?ooool00ol0003oooooooooo`1=ooooo`03
o`000?oooooooooo04;ooooo00?o0000ooooooooool0COooool00ol0003oooooooooo`07ooooo`00
9oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo04gooooo00?o0000ooooooooool0
@_ooool00ol0003oooooooooo`1=ooooo`03o`000?oooooooooo00Oooooo000Wooooo`03o`000?oo
oooooooo00Kooooo00?o0000ooooooooool0Coooool00ol0003oooooooooo`10ooooo`03o`000?oo
oooooooo04oooooo00?o0000ooooooooool01_ooool002Oooooo00?o0000ooooooooool01_ooool0
0ol0003oooooooooo`1?ooooo`03o`000?oooooooooo043ooooo00?o0000ooooooooool0Coooool0
0ol0003oooooooooo`06ooooo`009oooool2o`0000Oooooo00?o0000ooooooooool0D?ooool00ol0
003oooooooooo`0nooooo`03o`000?oooooooooo053ooooo00?o0000ooooooooool01_ooool002Oo
oooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`1@ooooo`03o`000?oooooooooo03ko
oooo00?o0000ooooooooool0D?ooool00ol0003oooooooooo`06ooooo`009oooool00ol0003ooooo
ooooo`06ooooo`03o`000?oooooooooo053ooooo00?o0000ooooooooool0?_ooool00ol0003ooooo
ooooo`1@ooooo`03o`000?oooooooooo00Kooooo000Wooooo`03o`000?oooooooooo00Kooooo00?o
0000ooooooooool0DOooool00ol0003oooooooooo`0looooo`03o`000?oooooooooo057ooooo00?o
0000ooooooooool01_ooool002Oooooo0_l00006ooooo`03o`000?oooooooooo05;ooooo00?o0000
ooooooooool0??ooool00ol0003oooooooooo`1Booooo`03o`000?oooooooooo00Gooooo000Woooo
o`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0Doooool00ol0003oooooooooo`0joooo
o`03o`000?oooooooooo05?ooooo00?o0000ooooooooool01Oooool002Oooooo00?o0000oooooooo
ool01Oooool00ol0003oooooooooo`1Cooooo`03o`000?oooooooooo03[ooooo00?o0000oooooooo
ool0Doooool00ol0003oooooooooo`05ooooo`009oooool00ol0003oooooooooo`1Looooo`03o`00
0?oooooooooo03Sooooo00?o0000ooooooooool0G?ooool002Oooooo0_l0001Mooooo`03o`000?oo
oooooooo03Sooooo00?o0000ooooooooool0G?ooool002Oooooo00?o0000ooooooooool0GOooool0
0ol0003oooooooooo`0fooooo`03o`000?oooooooooo05gooooo0002ooooo`;o00001?ooool00ol0
003oooooooooo`03ooooo`;o00001?ooool2o`0000?ooooo0ol00003ooooo`?o00001Oooool00ol0
003oooooooooo`1Mooooo`03o`000?oooooooooo03Kooooo00?o0000ooooooooool0GOooool00005
ooooool0003oooooooooool000002?ooool01?l0003oooooooooool00002ooooo`04o`000?oooooo
ooooo`0000?ooooo00Go0000ooooooooooooooooo`000003ooooo`03o`000?oooooooooo00;ooooo
00?o0000ooooooooool0G_ooool00ol0003oooooooooo`0dooooo`03o`000?oooooooooo05kooooo
00001Ooooooo0000oooooooooooo000000Sooooo00Co0000oooooooooooo00000_ooool01?l0003o
ooooooooool00003ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool00_ooool00ol0
003oooooooooo`1Nooooo`03o`000?oooooooooo03Cooooo00?o0000ooooooooool0G_ooool00005
ooooool0003oooooooooool000002?ooool01?l0003oooooooooool00002ooooo`04o`000?oooooo
ooooo`0000?ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`02ooooo`;o0000Gooo
ool00ol0003oooooooooo`0dooooo`03o`000?oooooooooo05kooooo00001Ooooooo0000oooooooo
oooo000000Sooooo00Co0000oooooooooooo00000_ooool01?l0003oooooooooool00003ooooo`04
o`000?ooooooooooooooo`Co00001Oooool00ol0003oooooooooo`1Oooooo`03o`000?oooooooooo
03;ooooo00?o0000ooooooooool0Goooool00005ooooool0003oooooooooool000002?ooool01?l0
003oooooooooool00002ooooo`04o`000?ooooooooooo`0000;ooooo0_l00003ooooo`03o`000?oo
oooooooo00Kooooo00?o0000ooooooooool0Goooool00ol0003oooooooooo`0booooo`03o`000?oo
oooooooo05oooooo0002ooooo`;o00002_ooool2o`0000Cooooo0_l00004ooooo`04o`000?oooooo
ooooooooo`Go00001?ooool00ol0003oooooooooo`1Oooooo`03o`000?oooooooooo03;ooooo00?o
0000ooooooooool0Goooool002Oooooo0_l0001Qooooo`03o`000?oooooooooo033ooooo00?o0000
ooooooooool0H?ooool002Oooooo00?o0000ooooooooool0H?ooool00ol0003oooooooooo`0`oooo
o`03o`000?oooooooooo063ooooo000Wooooo`03o`000?oooooooooo063ooooo00?o0000oooooooo
ool0<?ooool00ol0003oooooooooo`1Pooooo`009oooool00ol0003oooooooooo`1Qooooo`03o`00
0?oooooooooo02kooooo00?o0000ooooooooool0HOooool002Oooooo0_l0001Rooooo`03o`000?oo
oooooooo02kooooo00?o0000ooooooooool0HOooool002Oooooo00?o0000ooooooooool0HOooool0
0ol0003oooooooooo`0^ooooo`03o`000?oooooooooo067ooooo000Wooooo`03o`000?oooooooooo
06;ooooo00?o0000ooooooooool0;?ooool00ol0003oooooooooo`1Rooooo`009oooool00ol0003o
ooooooooo`1Rooooo`03o`000?oooooooooo02cooooo00?o0000ooooooooool0H_ooool002Oooooo
0_l0001Sooooo`03o`000?oooooooooo02cooooo00?o0000ooooooooool0H_ooool002Oooooo00?o
0000ooooooooool0Hoooool00ol0003oooooooooo`0Zooooo`03o`000?oooooooooo06?ooooo000W
ooooo`03o`000?oooooooooo06?ooooo00?o0000ooooooooool0:_ooool00ol0003oooooooooo`1S
ooooo`009oooool00ol0003oooooooooo`1Sooooo`03o`000?oooooooooo02[ooooo00?o0000oooo
ooooool0Hoooool002Oooooo0_l0001Uooooo`03o`000?oooooooooo02Sooooo00?o0000oooooooo
ool0I?ooool002Oooooo00?o0000ooooooooool0I?ooool00ol0003oooooooooo`0Xooooo`03o`00
0?oooooooooo06Cooooo0008ooooo`;o00001?ooool00ol0003oooooooooo`03ooooo`;o00001?oo
ool2o`0000;ooooo1Ol00004ooooo`03o`000?oooooooooo06Cooooo00?o0000ooooooooool0:?oo
ool00ol0003oooooooooo`1Tooooo`001oooool01?l0003oooooooooool00008ooooo`04o`000?oo
ooooooooo`0000;ooooo00Co0000oooooooooooo00000_ooool01?l0003oooooooooool00004oooo
o`03o`000?oooooooooo06Gooooo00?o0000ooooooooool09_ooool00ol0003oooooooooo`1Uoooo
o`001oooool01?l0003oooooooooool00008ooooo`04o`000?ooooooooooo`0000;ooooo00Co0000
oooooooooooo00000oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo06Gooooo00?o
0000ooooooooool09_ooool00ol0003oooooooooo`1Uooooo`001oooool01?l0003oooooooooool0
0008ooooo`04o`000?ooooooooooo`0000;ooooo00Co0000oooooooooooo00001?ooool00ol0003o
ooooooooo`03ooooo`;o0000I_ooool00ol0003oooooooooo`0Vooooo`03o`000?oooooooooo06Go
oooo0007ooooo`04o`000?ooooooooooo`0000Sooooo00Co0000oooooooooooo00000_ooool01_l0
003oooooooooool0003oooooo`0000?ooooo00?o0000ooooooooool00_ooool00ol0003ooooooooo
o`1Uooooo`03o`000?oooooooooo02Kooooo00?o0000ooooooooool0IOooool000Oooooo00Co0000
oooooooooooo00002?ooool01?l0003oooooooooool00002ooooo`06o`000?ooooooooooo`000?oo
oooo00000oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo06Kooooo00?o0000oooo
ooooool09?ooool00ol0003oooooooooo`1Vooooo`002?ooool2o`0000[ooooo0_l00004ooooo`;o
00000oooool3o`0000Gooooo00?o0000ooooooooool0I_ooool00ol0003oooooooooo`0Tooooo`03
o`000?oooooooooo06Kooooo000Wooooo`;o0000Ioooool00ol0003oooooooooo`0Tooooo`03o`00
0?oooooooooo06Kooooo000Wooooo`03o`000?oooooooooo06Oooooo00?o0000ooooooooool08ooo
ool00ol0003oooooooooo`1Vooooo`009oooool00ol0003oooooooooo`1Wooooo`03o`000?oooooo
oooo02;ooooo00?o0000ooooooooool0Ioooool002Oooooo00?o0000ooooooooool0Ioooool00ol0
003oooooooooo`0Rooooo`03o`000?oooooooooo06Oooooo000Wooooo`;o0000J?ooool00ol0003o
ooooooooo`0Rooooo`03o`000?oooooooooo06Oooooo000Wooooo`03o`000?oooooooooo06Sooooo
00?o0000ooooooooool08Oooool00ol0003oooooooooo`1Wooooo`009oooool00ol0003ooooooooo
o`1Xooooo`03o`000?oooooooooo023ooooo00?o0000ooooooooool0J?ooool002Oooooo00?o0000
ooooooooool0J?ooool00ol0003oooooooooo`0Pooooo`03o`000?oooooooooo06Sooooo000Woooo
o`;o0000J_ooool00ol0003oooooooooo`0Oooooo`03o`000?oooooooooo06Sooooo000Wooooo`03
o`000?oooooooooo06Wooooo00?o0000ooooooooool07oooool00ol0003oooooooooo`1Xooooo`00
9oooool00ol0003oooooooooo`1Yooooo`03o`000?oooooooooo01kooooo00?o0000ooooooooool0
JOooool002Oooooo00?o0000ooooooooool0J_ooool00ol0003oooooooooo`0Mooooo`03o`000?oo
oooooooo06Wooooo000Wooooo`;o0000Joooool00ol0003oooooooooo`0Mooooo`03o`000?oooooo
oooo06Wooooo000Wooooo`03o`000?oooooooooo06[ooooo00?o0000ooooooooool07?ooool00ol0
003oooooooooo`1Zooooo`000_ooool2o`0000Cooooo00?o0000ooooooooool00oooool2o`0000Co
oooo0_l00002ooooo`Go00000_ooool3o`0000Gooooo00?o0000ooooooooool0J_ooool00ol0003o
ooooooooo`0Looooo`03o`000?oooooooooo06[ooooo00001Ooooooo0000oooooooooooo000000So
oooo00Co0000oooooooooooo00000_ooool01?l0003oooooooooool00002ooooo`06o`000?oooooo
ooooo`000?oooooo00000oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo06_ooooo
00?o0000ooooooooool06oooool00ol0003oooooooooo`1Zooooo`0000Goooooo`000?oooooooooo
o`000008ooooo`04o`000?ooooooooooo`0000;ooooo00Co0000oooooooooooo00000oooool00ol0
003oooooooooo`05ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0Joooool00ol0
003oooooooooo`0Kooooo`03o`000?oooooooooo06[ooooo00001Ooooooo0000oooooooooooo0000
00Sooooo00Co0000oooooooooooo00000_ooool01?l0003oooooooooool00004ooooo`03o`000?oo
oooooooo00Cooooo00?o0000ooooooooool00_ooool2o`0006cooooo00?o0000ooooooooool06_oo
ool00ol0003oooooooooo`1[ooooo`0000Goooooo`000?ooooooooooo`000008ooooo`04o`000?oo
ooooooooo`0000;ooooo00Ko0000oooooooooooo0000ooooool00003ooooo`03o`000?oooooo0000
00?o00001Oooool00ol0003oooooooooo`1/ooooo`03o`000?oooooooooo01Wooooo00?o0000oooo
ooooool0Joooool00005ooooool0003oooooooooool000002?ooool01?l0003oooooooooool00002
ooooo`06o`000?ooooooooooo`000?oooooo00000oooool00ol0003oooooo`000008ooooo`03o`00
0?oooooooooo06cooooo00?o0000ooooooooool06Oooool00ol0003oooooooooo`1[ooooo`000_oo
ool2o`0000[ooooo0_l00004ooooo`;o00000oooool3o`0000;ooooo1Ol00004ooooo`03o`000?oo
oooooooo06cooooo00?o0000ooooooooool06Oooool00ol0003oooooooooo`1[ooooo`009oooool2
o`0006gooooo00?o0000ooooooooool06?ooool00ol0003oooooooooo`1/ooooo`009oooool00ol0
003oooooooooo`1]ooooo`03o`000?oooooooooo01Oooooo00?o0000ooooooooool0K?ooool002Oo
oooo00?o0000ooooooooool0KOooool00ol0003oooooooooo`0Gooooo`03o`000?oooooooooo06co
oooo000Wooooo`03o`000?oooooooooo06gooooo00?o0000ooooooooool05oooool00ol0003ooooo
ooooo`1/ooooo`009oooool2o`0006oooooo00?o0000ooooooooool05Oooool00ol0003ooooooooo
o`1]ooooo`009oooool00ol0003oooooooooo`1^ooooo`03o`000?oooooooooo01Gooooo00?o0000
ooooooooool0KOooool002Oooooo00?o0000ooooooooool0K_ooool00ol0003oooooooooo`0Eoooo
o`03o`000?oooooooooo06gooooo000Wooooo`03o`000?oooooooooo06kooooo00?o0000oooooooo
ool05Oooool00ol0003oooooooooo`1]ooooo`009oooool2o`00073ooooo00?o0000ooooooooool0
4oooool00ol0003oooooooooo`1^ooooo`009oooool00ol0003oooooooooo`1_ooooo`03o`000?oo
oooooooo01?ooooo00?o0000ooooooooool0K_ooool002Oooooo00?o0000ooooooooool0Koooool0
0ol0003oooooooooo`0Cooooo`03o`000?oooooooooo06kooooo000Wooooo`03o`000?oooooooooo
06oooooo00?o0000ooooooooool04oooool00ol0003oooooooooo`1^ooooo`009oooool2o`00073o
oooo00?o0000ooooooooool04oooool00ol0003oooooooooo`1^ooooo`009oooool00ol0003ooooo
ooooo`1`ooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool0Koooool000Sooooo0_l0
0004ooooo`03o`000?oooooooooo00?ooooo0_l00004ooooo`;o00000oooool3o`0000Gooooo00?o
0000ooooooooool0L?ooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo06oooooo0007
ooooo`04o`000?ooooooooooo`0000Sooooo00Co0000oooooooooooo00000_ooool01_l0003ooooo
ooooool0003oooooo`0000?ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`1`oooo
o`03o`000?oooooooooo017ooooo00?o0000ooooooooool0Koooool000Oooooo00Co0000oooooooo
oooo00002?ooool01?l0003oooooooooool00002ooooo`04o`000?ooooooooooo`0000Gooooo00?o
0000ooooooooool00_ooool00ol0003oooooooooo`1`ooooo`03o`000?oooooooooo017ooooo00?o
0000ooooooooool0Koooool000Oooooo00Co0000oooooooooooo00002?ooool01?l0003ooooooooo
ool00002ooooo`04o`000?ooooooooooo`0000?ooooo0_l00005ooooo`;o0000L_ooool00ol0003o
ooooooooo`0?ooooo`03o`000?oooooooooo073ooooo0007ooooo`04o`000?ooooooooooo`0000So
oooo00Co0000oooooooooooo00000_ooool01?l0003oooooooooool00005ooooo`03o`000?oooooo
oooo00;ooooo00?o0000ooooooooool0LOooool00ol0003oooooooooo`0?ooooo`03o`000?oooooo
oooo073ooooo0007ooooo`04o`000?ooooooooooo`0000Sooooo00Co0000oooooooooooo00000_oo
ool01_l0003oooooooooool0003oooooo`0000?ooooo00?o0000ooooooooool00_ooool00ol0003o
ooooooooo`1aooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool0L?ooool000Sooooo
0_l0000:ooooo`;o00001?ooool2o`0000?ooooo0ol00005ooooo`03o`000?oooooooooo077ooooo
00?o0000ooooooooool03oooool00ol0003oooooooooo`1`ooooo`009oooool2o`0007?ooooo00?o
0000ooooooooool03Oooool00ol0003oooooooooo`1aooooo`009oooool00ol0003oooooooooo`1b
ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool0LOooool002Oooooo00?o0000oooo
ooooool0L_ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo077ooooo000Wooooo`03
o`000?oooooooooo07;ooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`1aooooo`00
9oooool2o`0007?ooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`1aooooo`009ooo
ool00ol0003oooooooooo`1cooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool0L_oo
ool002Oooooo00?o0000ooooooooool0Loooool00ol0003oooooooooo`0;ooooo`03o`000?oooooo
oooo07;ooooo000Wooooo`03o`000?oooooooooo07?ooooo00?o0000ooooooooool02oooool00ol0
003oooooooooo`1booooo`009oooool2o`0007Cooooo00?o0000ooooooooool02oooool00ol0003o
ooooooooo`1booooo`009oooool00ol0003oooooooooo`1dooooo`03o`000?oooooooooo00Wooooo
00?o0000ooooooooool0Loooool002Oooooo00?o0000ooooooooool0M?ooool00ol0003ooooooooo
o`09ooooo`03o`000?oooooooooo07?ooooo000Wooooo`03o`000?oooooooooo07Cooooo00?o0000
ooooooooool02Oooool00ol0003oooooooooo`1cooooo`009oooool2o`0007Gooooo00?o0000oooo
ooooool02Oooool00ol0003oooooooooo`1cooooo`009oooool00ol0003oooooooooo`1eooooo`03
o`000?oooooooooo00Oooooo00?o0000ooooooooool0M?ooool000;ooooo0_l00004ooooo`03o`00
0?oooooooooo00?ooooo0_l00004ooooo`;o00000oooool3o`0000?ooooo0ol00005ooooo`03o`00
0?oooooooooo07Gooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`1dooooo`0000Go
ooooo`000?ooooooooooo`000008ooooo`04o`000?ooooooooooo`0000;ooooo00Ko0000oooooooo
oooo0000ooooool00003ooooo`03o`000?oooooo000000?ooooo00?o0000ooooooooool00_ooool0
0ol0003oooooooooo`1eooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0M?ooool0
0005ooooool0003oooooooooool000002?ooool01?l0003oooooooooool00002ooooo`04o`000?oo
ooooooooo`0000Gooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`02ooooo`03o`00
0?oooooooooo07Gooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`1dooooo`0000Go
ooooo`000?ooooooooooo`000008ooooo`04o`000?ooooooooooo`0000;ooooo00Co0000oooooooo
oooo00000oooool2o`0000Kooooo00?o0000ooooooooool00_ooool2o`0007Kooooo00?o0000oooo
ooooool01oooool00ol0003oooooooooo`1dooooo`0000Goooooo`000?ooooooooooo`000008oooo
o`04o`000?ooooooooooo`0000;ooooo00Co0000oooooooooooo00001Oooool00ol0003oooooo`00
0003o`0000Gooooo00?o0000ooooooooool0M_ooool00ol0003oooooooooo`05ooooo`03o`000?oo
oooooooo07Gooooo00001Ooooooo0000oooooooooooo000000Sooooo00Co0000oooooooooooo0000
0_ooool01_l0003oooooooooool0003oooooo`0000?ooooo00?o0000ooooool000002?ooool00ol0
003oooooooooo`1fooooo`Wo0000Moooool000;ooooo0_l0000:ooooo`;o00001?ooool2o`0000?o
oooo0ol00002ooooo`Go00001?ooool00ol0003oooooooooo`3fooooo`009oooool2o`000?Oooooo
000Wooooo`03o`000?oooooooooo0?Kooooo000Wooooo`03o`000?oooooooooo0?Kooooo003ooooo
ob7ooooo003oooooob7ooooo003oooooob7ooooo003oooooob7ooooo003oooooob7ooooo0000\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-4.86077, -0.000427656, \
0.12408, 2.37938*^-5}}],

Cell[BoxData[
    \(0.003555467951702121`\)], "Output",
  CellLabel->"Out[13]="]
}, Open  ]],

Cell[TextData[{
  "The strength of the disequilibrium in the centre is 1.4% of the maximum \
possible disequilibrium, ",
  Cell[BoxData[
      \(TraditionalForm\`p\[VeryThinSpace]q\)]],
  ":"
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(pp = \(AlleleFrequencyMean[
            res[500]]\)\[LeftDoubleBracket]15\[RightDoubleBracket];\)\), "\
\[IndentingNewLine]", 
    \(\(DisequilibriumMean[res[500]]\)\[LeftDoubleBracket]15\
\[RightDoubleBracket]\/\(pp \((1 - pp)\)\)\)}], "Input",
  CellLabel->"In[14]:="],

Cell[BoxData[
    \(0.014284789544439722`\)], "Output",
  CellLabel->"Out[15]="]
}, Open  ]],

Cell[TextData[{
  StyleBox["Q3: ",
    FontColor->RGBColor[0, 0, 1]],
  "How does the strength of linkage disequilibrium comparfe with the simple \
prediction obtained by assuming a balance between gene flow and recombation?  \
 How good is this approximation for other selection strengths?"
}], "Text"],

Cell["\<\
So far, all the loci have been unlinked (r=50%).  This simulates \
linkage of 10% between each of teh loci:\
\>", "Text"],

Cell[BoxData[
    \(\(StoreExact[res[3, 0.01, 0.1], MakeCline[30, 3, 100], 
        fitness[0.01, 15, ecotone], 0.5, {500, 20}, 
        Linkage \[Rule] {0.1, 0.1}, Compiled \[Rule] True, 
        FixedEnds \[Rule] {MakePopulation[3, 0], 
            MakePopulation[3, 1]}];\)\)], "Input",
  CellLabel->"In[18]:="],

Cell["Results are stored in res[0.01, 0.1][t]", "Text"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(ListPlot[DisequilibriumMean[\(res[3, 0.01, 0.1]\)[500]], 
        PlotJoined \[Rule] True];\)\), "\[IndentingNewLine]", 
    \(\(DisequilibriumMean[\(res[3, 0.01, 0.1]\)[
          500]]\)\[LeftDoubleBracket]15\[RightDoubleBracket]\)}], "Input",
  CellLabel->"In[19]:="],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.031746 0.0147151 44.6767 [
[.18254 .00222 -3 -9 ]
[.18254 .00222 3 0 ]
[.34127 .00222 -6 -9 ]
[.34127 .00222 6 0 ]
[.5 .00222 -6 -9 ]
[.5 .00222 6 0 ]
[.65873 .00222 -6 -9 ]
[.65873 .00222 6 0 ]
[.81746 .00222 -6 -9 ]
[.81746 .00222 6 0 ]
[.97619 .00222 -6 -9 ]
[.97619 .00222 6 0 ]
[.01131 .10407 -30 -4.5 ]
[.01131 .10407 0 4.5 ]
[.01131 .19342 -30 -4.5 ]
[.01131 .19342 0 4.5 ]
[.01131 .28278 -30 -4.5 ]
[.01131 .28278 0 4.5 ]
[.01131 .37213 -30 -4.5 ]
[.01131 .37213 0 4.5 ]
[.01131 .46148 -24 -4.5 ]
[.01131 .46148 0 4.5 ]
[.01131 .55084 -30 -4.5 ]
[.01131 .55084 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.18254 .01472 m
.18254 .02097 L
s
[(5)] .18254 .00222 0 1 Mshowa
.34127 .01472 m
.34127 .02097 L
s
[(10)] .34127 .00222 0 1 Mshowa
.5 .01472 m
.5 .02097 L
s
[(15)] .5 .00222 0 1 Mshowa
.65873 .01472 m
.65873 .02097 L
s
[(20)] .65873 .00222 0 1 Mshowa
.81746 .01472 m
.81746 .02097 L
s
[(25)] .81746 .00222 0 1 Mshowa
.97619 .01472 m
.97619 .02097 L
s
[(30)] .97619 .00222 0 1 Mshowa
.125 Mabswid
.05556 .01472 m
.05556 .01847 L
s
.0873 .01472 m
.0873 .01847 L
s
.11905 .01472 m
.11905 .01847 L
s
.15079 .01472 m
.15079 .01847 L
s
.21429 .01472 m
.21429 .01847 L
s
.24603 .01472 m
.24603 .01847 L
s
.27778 .01472 m
.27778 .01847 L
s
.30952 .01472 m
.30952 .01847 L
s
.37302 .01472 m
.37302 .01847 L
s
.40476 .01472 m
.40476 .01847 L
s
.43651 .01472 m
.43651 .01847 L
s
.46825 .01472 m
.46825 .01847 L
s
.53175 .01472 m
.53175 .01847 L
s
.56349 .01472 m
.56349 .01847 L
s
.59524 .01472 m
.59524 .01847 L
s
.62698 .01472 m
.62698 .01847 L
s
.69048 .01472 m
.69048 .01847 L
s
.72222 .01472 m
.72222 .01847 L
s
.75397 .01472 m
.75397 .01847 L
s
.78571 .01472 m
.78571 .01847 L
s
.84921 .01472 m
.84921 .01847 L
s
.88095 .01472 m
.88095 .01847 L
s
.9127 .01472 m
.9127 .01847 L
s
.94444 .01472 m
.94444 .01847 L
s
.25 Mabswid
0 .01472 m
1 .01472 L
s
.02381 .10407 m
.03006 .10407 L
s
[(0.002)] .01131 .10407 1 0 Mshowa
.02381 .19342 m
.03006 .19342 L
s
[(0.004)] .01131 .19342 1 0 Mshowa
.02381 .28278 m
.03006 .28278 L
s
[(0.006)] .01131 .28278 1 0 Mshowa
.02381 .37213 m
.03006 .37213 L
s
[(0.008)] .01131 .37213 1 0 Mshowa
.02381 .46148 m
.03006 .46148 L
s
[(0.01)] .01131 .46148 1 0 Mshowa
.02381 .55084 m
.03006 .55084 L
s
[(0.012)] .01131 .55084 1 0 Mshowa
.125 Mabswid
.02381 .03705 m
.02756 .03705 L
s
.02381 .05939 m
.02756 .05939 L
s
.02381 .08173 m
.02756 .08173 L
s
.02381 .12641 m
.02756 .12641 L
s
.02381 .14875 m
.02756 .14875 L
s
.02381 .17108 m
.02756 .17108 L
s
.02381 .21576 m
.02756 .21576 L
s
.02381 .2381 m
.02756 .2381 L
s
.02381 .26044 m
.02756 .26044 L
s
.02381 .30511 m
.02756 .30511 L
s
.02381 .32745 m
.02756 .32745 L
s
.02381 .34979 m
.02756 .34979 L
s
.02381 .39447 m
.02756 .39447 L
s
.02381 .41681 m
.02756 .41681 L
s
.02381 .43914 m
.02756 .43914 L
s
.02381 .48382 m
.02756 .48382 L
s
.02381 .50616 m
.02756 .50616 L
s
.02381 .5285 m
.02756 .5285 L
s
.02381 .57317 m
.02756 .57317 L
s
.02381 .59551 m
.02756 .59551 L
s
.02381 .61785 m
.02756 .61785 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.05556 .11561 m
.0873 .05918 L
.11905 .04495 L
.15079 .04416 L
.18254 .04995 L
.21429 .06089 L
.24603 .07737 L
.27778 .10077 L
.30952 .13322 L
.34127 .17748 L
.37302 .23673 L
.40476 .31374 L
.43651 .40876 L
.46825 .5143 L
.5 .60332 L
.53175 .60332 L
.56349 .5143 L
.59524 .40876 L
.62698 .31374 L
.65873 .23673 L
.69048 .17748 L
.72222 .13322 L
.75397 .10077 L
.78571 .07737 L
.81746 .06089 L
.84921 .04995 L
.88095 .04416 L
.9127 .04495 L
.94444 .05918 L
.97619 .11561 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[19]:=",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/B000`400?l00000o`00003ooooooolQ
ooooo`00oooooolQooooo`00oooooolQooooo`00oooooolQooooo`00B?ooool3o`0002?ooooo0ol0
0004ooooo`;o00008Oooool3o`0000?ooooo0ol0000Oooooo`Go00000oooool2o`0001oooooo1Ol0
0002ooooo`?o00008?ooool3o`0000Cooooo0_l00004ooooo`00Aoooool01Ol0003ooooooooooooo
oooo000002?ooooo00?o0000ooooooooool00_ooool01?l0003oooooooooool0000Qooooo`05o`00
0?ooooooooooooooool000000oooool00ol0003oooooooooo`0Mooooo`04o`000?ooooooooooo`00
00;ooooo00Co0000oooooooooooo00007oooool01_l0003oooooooooool0003oooooo`0000?ooooo
00?o0000ooooooooool07?ooool01Ol0003ooooooooooooooooo000000;ooooo00Co0000oooooooo
oooo00000oooool004_ooooo00?o0000ooooooooool08Oooool00ol0003oooooooooo`02ooooo`04
o`000?ooooooooooo`00027ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`0Noooo
o`03o`000?oooooooooo00;ooooo00Co0000oooooooooooo00008?ooool00ol0003oooooooooo`05
ooooo`03o`000?oooooooooo023ooooo00Co0000oooooooooooo00000_ooool00ol0003ooooooooo
o`01ooooo`00Boooool00ol0003oooooooooo`0Qooooo`03o`000?oooooooooo00;ooooo00Co0000
oooooooooooo00008Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo01oooooo00Go
0000ooooooooooooooooo`000002ooooo`03o`000?oooooooooo01oooooo00?o0000ooooooooool0
1?ooool00ol0003oooooooooo`0Nooooo`;o00000oooool01?l0003oooooooooool00003ooooo`00
Aoooool4o`0002Cooooo00?o0000ooooooooool00_ooool01?l0003oooooooooool0000Qooooo`04
o`000?ooooooooooooooo`Co00007oooool01Ol0003ooooooooooooooooo000000;ooooo00Co0000
oooooooooooo00007_ooool01_l0003ooooooooooooooooo0000ooooo`Co00008oooool01?l0003o
ooooooooool00002ooooo`03o`000?oooooooooo007ooooo0017ooooo`03o`000?oooooooooo02Co
oooo0_l00004ooooo`04o`000?ooooooooooo`00023ooooo0_l00003ooooo`03o`000?oooooooooo
023ooooo00Go0000ooooooooooooooooo`000002ooooo`04o`000?ooooooooooo`0001kooooo00Oo
0000ooooooooooooooooo`000?oooooo000002;ooooo00Go0000ooooooooooooooooo`000002oooo
o`04o`000?ooooooooooo`0000?ooooo0017ooooo`Go00008oooool00ol0003oooooooooo`03oooo
o`;o00008_ooool01?l0003oooooooooooooool5o`0001oooooo0ol00004ooooo`;o00008?ooool3
o`0000;ooooo1Ol0000Oooooo`?o00001?ooool2o`0000Cooooo003oooooob7ooooo000Qooooo`03
o`000?oooooooooo0?cooooo000Qooooo`03o`000?oooooooooo0?cooooo000Qooooo`03o`000?oo
oooooooo0?cooooo000Qooooo`03o`000?oooooooooo0?cooooo000Koooooooo00001_l00000027o
oooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Ko
oooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Go
oooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Go
oooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Go
oooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Ko
oooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Go
oooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Go
oooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Go
oooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Ko
oooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Go
oooo00?o0000ooooooooool01Oooool0027ooooo00?o0000ooooooooool0o?ooool0027ooooo00?o
0000ooooooooool0o?ooool0027ooooo00?o0000ooooooooool0o?ooool0027ooooo00?o0000oooo
ooooool0o?ooool0027ooooo0_l0003mooooo`008Oooool00ol0003oooooooooo`0Jooooo`Oo0000
^Oooool7o`0001_ooooo000Qooooo`03o`000?oooooooooo01Gooooo1Ol00007ooooo`Co0000/?oo
ool5o`0000Oooooo1Ol0000Fooooo`008Oooool00ol0003oooooooooo`0Booooo`?o00004?ooool3
o`000:[ooooo0ol0000Aooooo`?o00004oooool0027ooooo00?o0000ooooooooool03oooool3o`00
01Kooooo0ol0002Tooooo`?o00005oooool3o`00013ooooo000Qooooo`;o00003_ooool2o`0001co
oooo0ol0002Nooooo`?o00007Oooool00ol0003oooooooooo`0=ooooo`008Oooool00ol0003ooooo
ooooo`0=ooooo`03o`000?oooooooooo01kooooo0_l0002Jooooo`;o00008?ooool00ol0003ooooo
ooooo`0=ooooo`008Oooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo027ooooo0_l0
002Fooooo`;o00008oooool00ol0003oooooooooo`0<ooooo`008Oooool00ol0003oooooooooo`0<
ooooo`03o`000?oooooooooo02?ooooo0ol0002Aooooo`;o00009Oooool00ol0003oooooooooo`0<
ooooo`008Oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo02Oooooo0_l0002=oooo
o`;o0000:?ooool00ol0003oooooooooo`0;ooooo`008Oooool00ol0003oooooooooo`0;ooooo`03
o`000?oooooooooo02Wooooo0_l00029ooooo`;o0000:_ooool00ol0003oooooooooo`0;ooooo`00
8Oooool2o`0000_ooooo00?o0000ooooooooool0;?ooool00ol0003oooooooooo`25ooooo`03o`00
0?oooooooooo02_ooooo00?o0000ooooooooool02_ooool0027ooooo00?o0000ooooooooool02_oo
ool00ol0003oooooooooo`0]ooooo`03o`000?oooooooooo08?ooooo00?o0000ooooooooool0;?oo
ool00ol0003oooooooooo`0:ooooo`008Oooool00ol0003oooooooooo`09ooooo`03o`000?oooooo
oooo02oooooo0_l00021ooooo`;o0000<?ooool00ol0003oooooooooo`09ooooo`000_ooool2o`00
00Cooooo00?o0000ooooooooool00oooool2o`0000Cooooo0_l00002ooooo`Go00001?ooool00ol0
003oooooooooo`08ooooo`03o`000?oooooooooo03;ooooo00?o0000ooooooooool0OOooool00ol0
003oooooooooo`0aooooo`03o`000?oooooooooo00Sooooo00001Ooooooo0000oooooooooooo0000
00Sooooo00Co0000oooooooooooo00000_ooool01?l0003oooooooooool00002ooooo`04o`000?oo
ooooooooo`0000Cooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`0cooooo`03o`00
0?oooooooooo07_ooooo00?o0000ooooooooool0<_ooool00ol0003oooooooooo`08ooooo`0000Go
ooooo`000?ooooooooooo`000008ooooo`04o`000?ooooooooooo`0000;ooooo00Co0000oooooooo
oooo00000oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Oooooo00?o0000oooo
ooooool0=Oooool00ol0003oooooooooo`1iooooo`03o`000?oooooooooo03Cooooo00?o0000oooo
ooooool01oooool00005ooooool0003oooooooooool000002?ooool01?l0003oooooooooool00002
ooooo`04o`000?ooooooooooo`0000Cooooo00?o0000ooooooooool00oooool2o`0000Sooooo00?o
0000ooooooooool0=Oooool00ol0003oooooooooo`1hooooo`03o`000?oooooooooo03Gooooo00?o
0000ooooooooool01oooool00005ooooool0003oooooooooool000002?ooool01?l0003ooooooooo
ool00002ooooo`06o`000?ooooooooooo`000?oooooo00000oooool00ol0003oooooooooo`02oooo
o`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0=oooool00ol0003oooooooooo`1foooo
o`03o`000?oooooooooo03Oooooo00?o0000ooooooooool01_ooool00005ooooool0003ooooooooo
ool000002?ooool01?l0003oooooooooool00002ooooo`06o`000?ooooooooooo`000?oooooo0000
0oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0
>?ooool00ol0003oooooooooo`1dooooo`03o`000?oooooooooo03Sooooo00?o0000ooooooooool0
1_ooool000;ooooo0_l0000:ooooo`;o00001?ooool2o`0000?ooooo0ol00005ooooo`03o`000?oo
oooooooo00Gooooo00?o0000ooooooooool0>_ooool00ol0003oooooooooo`1booooo`03o`000?oo
oooooooo03[ooooo00?o0000ooooooooool01Oooool0027ooooo00?o0000ooooooooool0@oooool0
0ol0003oooooooooo`1`ooooo`03o`000?oooooooooo04?ooooo000Qooooo`03o`000?oooooooooo
04Cooooo00?o0000ooooooooool0K_ooool00ol0003oooooooooo`14ooooo`008Oooool2o`0004Ko
oooo00?o0000ooooooooool0K?ooool00ol0003oooooooooo`15ooooo`008Oooool00ol0003ooooo
ooooo`16ooooo`03o`000?oooooooooo06[ooooo00?o0000ooooooooool0A_ooool0027ooooo00?o
0000ooooooooool0Aoooool00ol0003oooooooooo`1Xooooo`03o`000?oooooooooo04Oooooo000Q
ooooo`03o`000?oooooooooo04Oooooo00?o0000ooooooooool0J?ooool00ol0003oooooooooo`17
ooooo`008Oooool00ol0003oooooooooo`18ooooo`03o`000?oooooooooo06Kooooo00?o0000oooo
ooooool0B?ooool0027ooooo00?o0000ooooooooool0BOooool00ol0003oooooooooo`1Tooooo`03
o`000?oooooooooo04Wooooo000Qooooo`;o0000Boooool00ol0003oooooooooo`1Rooooo`03o`00
0?oooooooooo04[ooooo000Qooooo`03o`000?oooooooooo04[ooooo00?o0000ooooooooool0H_oo
ool00ol0003oooooooooo`1:ooooo`008Oooool00ol0003oooooooooo`1;ooooo`03o`000?oooooo
oooo063ooooo00?o0000ooooooooool0Boooool0027ooooo00?o0000ooooooooool0C?ooool00ol0
003oooooooooo`1Nooooo`03o`000?oooooooooo04cooooo000Qooooo`03o`000?oooooooooo04co
oooo00?o0000ooooooooool0G_ooool00ol0003oooooooooo`1<ooooo`008Oooool2o`0004kooooo
00?o0000ooooooooool0G?ooool00ol0003oooooooooo`1=ooooo`008Oooool00ol0003ooooooooo
o`1>ooooo`03o`000?oooooooooo05[ooooo00?o0000ooooooooool0C_ooool0027ooooo00?o0000
ooooooooool0Coooool00ol0003oooooooooo`1Hooooo`03o`000?oooooooooo04oooooo000Qoooo
o`03o`000?oooooooooo04oooooo00?o0000ooooooooool0F?ooool00ol0003oooooooooo`1?oooo
o`000_ooool2o`0000Cooooo00?o0000ooooooooool00oooool2o`0000Cooooo0_l00004ooooo`?o
00001?ooool00ol0003oooooooooo`1@ooooo`03o`000?oooooooooo05Kooooo00?o0000oooooooo
ool0D?ooool00005ooooool0003oooooooooool000002?ooool01?l0003oooooooooool00002oooo
o`04o`000?ooooooooooo`0000Cooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`1A
ooooo`03o`000?oooooooooo05Gooooo00?o0000ooooooooool0D?ooool00005ooooool0003ooooo
ooooool000002?ooool01?l0003oooooooooool00002ooooo`05o`000?ooooooooooo`000?ooool0
1Ol00004ooooo`;o0000D_ooool00ol0003oooooooooo`1Dooooo`03o`000?oooooooooo057ooooo
00001Ooooooo0000oooooooooooo000000Sooooo00Co0000oooooooooooo00000_ooool01_l0003o
ooooooooool0003oooooo`0000;ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`1B
ooooo`03o`000?oooooooooo05?ooooo00?o0000ooooooooool0DOooool00005ooooool0003ooooo
ooooool000002?ooool01?l0003oooooooooool00002ooooo`04o`000?ooooooooooo`0000;ooooo
00?o0000ooooool000001Oooool00ol0003oooooooooo`1Booooo`03o`000?oooooooooo05;ooooo
00?o0000ooooooooool0D_ooool00005ooooool0003oooooooooool000002?ooool01?l0003ooooo
ooooool00002ooooo`04o`000?ooooooooooo`0000?ooooo0_l00005ooooo`03o`000?oooooooooo
05?ooooo00?o0000ooooooooool0DOooool00ol0003oooooooooo`1Booooo`000_ooool2o`0000[o
oooo0_l00004ooooo`;o00001Oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo05Co
oooo00?o0000ooooooooool0Coooool00ol0003oooooooooo`1Cooooo`008Oooool00ol0003ooooo
ooooo`1Dooooo`03o`000?oooooooooo04kooooo00?o0000ooooooooool0E?ooool0027ooooo0_l0
001Fooooo`03o`000?oooooooooo04gooooo00?o0000ooooooooool0E?ooool0027ooooo00?o0000
ooooooooool0EOooool00ol0003oooooooooo`1<ooooo`03o`000?oooooooooo05Gooooo000Qoooo
o`03o`000?oooooooooo05Kooooo00?o0000ooooooooool0Boooool00ol0003oooooooooo`1Eoooo
o`008Oooool00ol0003oooooooooo`1Gooooo`03o`000?oooooooooo04Wooooo00?o0000oooooooo
ool0E_ooool0027ooooo00?o0000ooooooooool0Eoooool00ol0003oooooooooo`19ooooo`03o`00
0?oooooooooo05Kooooo000Qooooo`03o`000?oooooooooo05Sooooo00?o0000ooooooooool0Aooo
ool00ol0003oooooooooo`1Gooooo`008Oooool2o`0005Wooooo00?o0000ooooooooool0Aoooool0
0ol0003oooooooooo`1Gooooo`008Oooool00ol0003oooooooooo`1Iooooo`03o`000?oooooooooo
04Gooooo00?o0000ooooooooool0F?ooool0027ooooo00?o0000ooooooooool0FOooool00ol0003o
ooooooooo`15ooooo`03o`000?oooooooooo05Sooooo000Qooooo`03o`000?oooooooooo05Wooooo
00?o0000ooooooooool0AOooool00ol0003oooooooooo`1Hooooo`008Oooool00ol0003ooooooooo
o`1Jooooo`03o`000?oooooooooo04?ooooo00?o0000ooooooooool0FOooool0027ooooo00?o0000
ooooooooool0F_ooool00ol0003oooooooooo`13ooooo`03o`000?oooooooooo05Wooooo000Qoooo
o`;o0000G?ooool00ol0003oooooooooo`11ooooo`03o`000?oooooooooo05[ooooo000Qooooo`03
o`000?oooooooooo05_ooooo00?o0000ooooooooool0@Oooool00ol0003oooooooooo`1Jooooo`00
8Oooool00ol0003oooooooooo`1Kooooo`03o`000?oooooooooo047ooooo00?o0000ooooooooool0
F_ooool000;ooooo0_l00004ooooo`03o`000?oooooooooo00?ooooo0_l00004ooooo`;o00000ooo
ool3o`0000Gooooo00?o0000ooooooooool0G?ooool00ol0003oooooooooo`0oooooo`03o`000?oo
oooooooo05_ooooo00001Ooooooo0000oooooooooooo000000Sooooo00Co0000oooooooooooo0000
0_ooool01_l0003oooooooooool0003oooooo`0000?ooooo00?o0000ooooooooool00_ooool00ol0
003oooooooooo`1Looooo`03o`000?oooooooooo03oooooo00?o0000ooooooooool0Foooool00005
ooooool0003oooooooooool000002?ooool01?l0003oooooooooool00002ooooo`06o`000?oooooo
ooooo`000?oooooo00000oooool00ol0003oooooooooo`02ooooo`;o0000G_ooool00ol0003ooooo
ooooo`0mooooo`03o`000?oooooooooo05cooooo00001Ooooooo0000oooooooooooo000000Sooooo
00Co0000oooooooooooo00000_ooool01Ol0003oooooooooool0003ooooo00Co00001Oooool00ol0
003oooooooooo`1Mooooo`03o`000?oooooooooo03gooooo00?o0000ooooooooool0G?ooool00005
ooooool0003oooooooooool000002?ooool01?l0003oooooooooool00002ooooo`06o`000?oooooo
ooooo`000?oooooo00002?ooool00ol0003oooooooooo`1Mooooo`03o`000?oooooooooo03gooooo
00?o0000ooooooooool0G?ooool00005ooooool0003oooooooooool000002?ooool01?l0003ooooo
ooooool00002ooooo`04o`000?ooooooooooo`0000;ooooo00?o0000ooooooooool01Oooool00ol0
003oooooooooo`1Nooooo`03o`000?oooooooooo03_ooooo00?o0000ooooooooool0GOooool000;o
oooo0_l0000:ooooo`;o00001?ooool2o`0000Cooooo0_l00005ooooo`03o`000?oooooooooo05ko
oooo00?o0000ooooooooool0>oooool00ol0003oooooooooo`1Mooooo`008Oooool00ol0003ooooo
ooooo`1Oooooo`03o`000?oooooooooo03Wooooo00?o0000ooooooooool0G_ooool0027ooooo0_l0
001Pooooo`03o`000?oooooooooo03Wooooo00?o0000ooooooooool0G_ooool0027ooooo00?o0000
ooooooooool0Goooool00ol0003oooooooooo`0iooooo`03o`000?oooooooooo05kooooo000Qoooo
o`03o`000?oooooooooo063ooooo00?o0000ooooooooool0=oooool00ol0003oooooooooo`1Ooooo
o`008Oooool00ol0003oooooooooo`1Pooooo`03o`000?oooooooooo03Oooooo00?o0000oooooooo
ool0Goooool0027ooooo00?o0000ooooooooool0H?ooool00ol0003oooooooooo`0fooooo`03o`00
0?oooooooooo063ooooo000Qooooo`03o`000?oooooooooo067ooooo00?o0000ooooooooool0=Ooo
ool00ol0003oooooooooo`1Pooooo`008Oooool2o`0006;ooooo00?o0000ooooooooool0=Oooool0
0ol0003oooooooooo`1Pooooo`008Oooool00ol0003oooooooooo`1Qooooo`03o`000?oooooooooo
03Cooooo00?o0000ooooooooool0HOooool0027ooooo00?o0000ooooooooool0H_ooool00ol0003o
ooooooooo`0cooooo`03o`000?oooooooooo067ooooo000Qooooo`03o`000?oooooooooo06;ooooo
00?o0000ooooooooool0<oooool00ol0003oooooooooo`1Qooooo`008Oooool00ol0003ooooooooo
o`1Rooooo`03o`000?oooooooooo03;ooooo00?o0000ooooooooool0H_ooool0027ooooo00?o0000
ooooooooool0Hoooool00ol0003oooooooooo`0aooooo`03o`000?oooooooooo06;ooooo000Qoooo
o`;o0000I?ooool00ol0003oooooooooo`0aooooo`03o`000?oooooooooo06;ooooo000Qooooo`03
o`000?oooooooooo06?ooooo00?o0000ooooooooool0<?ooool00ol0003oooooooooo`1Sooooo`00
8Oooool00ol0003oooooooooo`1Tooooo`03o`000?oooooooooo02oooooo00?o0000ooooooooool0
Hoooool000;ooooo0_l00004ooooo`03o`000?oooooooooo00?ooooo0_l00004ooooo`;o00000ooo
ool3o`0000Gooooo00?o0000ooooooooool0I?ooool00ol0003oooooooooo`0^ooooo`03o`000?oo
oooooooo06Cooooo00001Ooooooo0000oooooooooooo000000Sooooo00Co0000oooooooooooo0000
0_ooool01_l0003oooooooooool0003oooooo`0000?ooooo00?o0000ooooooooool00_ooool00ol0
003oooooooooo`1Tooooo`03o`000?oooooooooo02kooooo00?o0000ooooooooool0I?ooool00005
ooooool0003oooooooooool000002?ooool01?l0003oooooooooool00002ooooo`06o`000?oooooo
ooooo`000?oooooo00000oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo06Gooooo
00?o0000ooooooooool0;Oooool00ol0003oooooooooo`1Tooooo`0000Goooooo`000?oooooooooo
o`000008ooooo`04o`000?ooooooooooo`0000;ooooo00Co0000oooooooooooo00000_ooool3o`00
00Gooooo0_l0001Vooooo`03o`000?oooooooooo02cooooo00?o0000ooooooooool0IOooool00005
ooooool0003oooooooooool000002?ooool01?l0003oooooooooool00002ooooo`06o`000?oooooo
ooooo`000?oooooo00000oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo06Gooooo
00?o0000ooooooooool0;?ooool00ol0003oooooooooo`1Uooooo`0000Goooooo`000?oooooooooo
o`000008ooooo`04o`000?ooooooooooo`0000;ooooo00Ko0000oooooooooooo0000ooooool00003
ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0I_ooool00ol0003oooooooooo`0[
ooooo`03o`000?oooooooooo06Gooooo0002ooooo`;o00002_ooool2o`0000Cooooo0_l00003oooo
o`?o00001Oooool00ol0003oooooooooo`1Vooooo`03o`000?oooooooooo02[ooooo00?o0000oooo
ooooool0I_ooool0027ooooo00?o0000ooooooooool0I_ooool00ol0003oooooooooo`0Zooooo`03
o`000?oooooooooo06Kooooo000Qooooo`;o0000J?ooool00ol0003oooooooooo`0Yooooo`03o`00
0?oooooooooo06Kooooo000Qooooo`03o`000?oooooooooo06Oooooo00?o0000ooooooooool0:?oo
ool00ol0003oooooooooo`1Wooooo`008Oooool00ol0003oooooooooo`1Wooooo`03o`000?oooooo
oooo02Sooooo00?o0000ooooooooool0Ioooool0027ooooo00?o0000ooooooooool0J?ooool00ol0
003oooooooooo`0Wooooo`03o`000?oooooooooo06Oooooo000Qooooo`03o`000?oooooooooo06So
oooo00?o0000ooooooooool09_ooool00ol0003oooooooooo`1Xooooo`008Oooool00ol0003ooooo
ooooo`1Xooooo`03o`000?oooooooooo02Kooooo00?o0000ooooooooool0J?ooool0027ooooo0_l0
001Yooooo`03o`000?oooooooooo02Kooooo00?o0000ooooooooool0J?ooool0027ooooo00?o0000
ooooooooool0JOooool00ol0003oooooooooo`0Tooooo`03o`000?oooooooooo06Wooooo000Qoooo
o`03o`000?oooooooooo06Wooooo00?o0000ooooooooool09?ooool00ol0003oooooooooo`1Yoooo
o`008Oooool00ol0003oooooooooo`1Yooooo`03o`000?oooooooooo02Cooooo00?o0000oooooooo
ool0JOooool0027ooooo00?o0000ooooooooool0J_ooool00ol0003oooooooooo`0Rooooo`03o`00
0?oooooooooo06[ooooo000Qooooo`03o`000?oooooooooo06[ooooo00?o0000ooooooooool08_oo
ool00ol0003oooooooooo`1Zooooo`008Oooool2o`0006_ooooo00?o0000ooooooooool08_ooool0
0ol0003oooooooooo`1Zooooo`008Oooool00ol0003oooooooooo`1Zooooo`03o`000?oooooooooo
02;ooooo00?o0000ooooooooool0J_ooool0027ooooo00?o0000ooooooooool0Joooool00ol0003o
ooooooooo`0Pooooo`03o`000?oooooooooo06_ooooo0008ooooo`;o00001?ooool00ol0003ooooo
ooooo`03ooooo`;o00000oooool3o`0000Gooooo00?o0000ooooooooool0Joooool00ol0003ooooo
ooooo`0Pooooo`03o`000?oooooooooo06_ooooo0007ooooo`04o`000?ooooooooooo`0000Sooooo
00Co0000oooooooooooo00000oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo06_o
oooo00?o0000ooooooooool08?ooool00ol0003oooooooooo`1[ooooo`001oooool01?l0003ooooo
ooooool00008ooooo`04o`000?ooooooooooo`0000?ooooo00?o0000ooooooooool01?ooool00ol0
003oooooooooo`1/ooooo`03o`000?oooooooooo01kooooo00?o0000ooooooooool0K?ooool000Oo
oooo00Co0000oooooooooooo00002?ooool01?l0003oooooooooool00003ooooo`03o`000?oooooo
oooo00Cooooo0_l0001]ooooo`03o`000?oooooooooo01kooooo00?o0000ooooooooool0K?ooool0
00Oooooo00Co0000oooooooooooo00002?ooool01?l0003oooooooooool00003ooooo`03o`000?oo
oooooooo00Cooooo00?o0000ooooooooool0K?ooool00ol0003oooooooooo`0Nooooo`03o`000?oo
oooooooo06cooooo0007ooooo`04o`000?ooooooooooo`0000Sooooo00Co0000oooooooooooo0000
0_ooool2o`0000Kooooo00?o0000ooooooooool0K?ooool00ol0003oooooooooo`0Nooooo`03o`00
0?oooooooooo06cooooo0008ooooo`;o00002_ooool2o`0000Cooooo00?o0000ooooooooool01?oo
ool00ol0003oooooooooo`1]ooooo`03o`000?oooooooooo01cooooo00?o0000ooooooooool0KOoo
ool0027ooooo00?o0000ooooooooool0KOooool00ol0003oooooooooo`0Looooo`03o`000?oooooo
oooo06gooooo000Qooooo`03o`000?oooooooooo06gooooo00?o0000ooooooooool07?ooool00ol0
003oooooooooo`1]ooooo`008Oooool2o`0006oooooo00?o0000ooooooooool06_ooool00ol0003o
ooooooooo`1^ooooo`008Oooool00ol0003oooooooooo`1^ooooo`03o`000?oooooooooo01[ooooo
00?o0000ooooooooool0K_ooool0027ooooo00?o0000ooooooooool0K_ooool00ol0003ooooooooo
o`0Jooooo`03o`000?oooooooooo06kooooo000Qooooo`03o`000?oooooooooo06kooooo00?o0000
ooooooooool06_ooool00ol0003oooooooooo`1^ooooo`008Oooool00ol0003oooooooooo`1_oooo
o`03o`000?oooooooooo01Sooooo00?o0000ooooooooool0Koooool0027ooooo0_l0001`ooooo`03
o`000?oooooooooo01Sooooo00?o0000ooooooooool0Koooool0027ooooo00?o0000ooooooooool0
Koooool00ol0003oooooooooo`0Hooooo`03o`000?oooooooooo06oooooo000Qooooo`03o`000?oo
oooooooo073ooooo00?o0000ooooooooool05_ooool00ol0003oooooooooo`1`ooooo`008Oooool0
0ol0003oooooooooo`1`ooooo`03o`000?oooooooooo01Kooooo00?o0000ooooooooool0L?ooool0
027ooooo00?o0000ooooooooool0L?ooool00ol0003oooooooooo`0Fooooo`03o`000?oooooooooo
073ooooo000Qooooo`03o`000?oooooooooo077ooooo00?o0000ooooooooool05?ooool00ol0003o
ooooooooo`1aooooo`008Oooool2o`0007;ooooo00?o0000ooooooooool05?ooool00ol0003ooooo
ooooo`1aooooo`008Oooool00ol0003oooooooooo`1aooooo`03o`000?oooooooooo01Cooooo00?o
0000ooooooooool0LOooool0027ooooo00?o0000ooooooooool0L_ooool00ol0003oooooooooo`0B
ooooo`03o`000?oooooooooo07;ooooo000Qooooo`03o`000?oooooooooo07;ooooo00?o0000oooo
ooooool04_ooool00ol0003oooooooooo`1booooo`000_ooool2o`0000Cooooo00?o0000oooooooo
ool00oooool2o`0000?ooooo0ol00002ooooo`Go00001?ooool00ol0003oooooooooo`1cooooo`03
o`000?oooooooooo017ooooo00?o0000ooooooooool0L_ooool00005ooooool0003oooooooooool0
00002?ooool01?l0003oooooooooool00003ooooo`03o`000?oooooooooo00;ooooo00Co0000oooo
oooooooo00001?ooool00ol0003oooooooooo`1cooooo`03o`000?oooooooooo013ooooo00?o0000
ooooooooool0Loooool00005ooooool0003oooooooooool000002?ooool01?l0003oooooooooool0
0003ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool01?ooool2o`0007Cooooo00?o
0000ooooooooool04?ooool00ol0003oooooooooo`1cooooo`0000Goooooo`000?ooooooooooo`00
0008ooooo`04o`000?ooooooooooo`0000?ooooo00?o0000ooooooooool01?ooool00ol0003ooooo
ooooo`03ooooo`03o`000?oooooooooo07Cooooo00?o0000ooooooooool03oooool00ol0003ooooo
ooooo`1cooooo`0000Goooooo`000?ooooooooooo`000008ooooo`04o`000?ooooooooooo`0000?o
oooo00Go0000ooooooooooooooooo`000003ooooo`03o`000?oooooooooo00;ooooo00?o0000oooo
ooooool0M?ooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo07Cooooo00001Ooooooo
0000oooooooooooo000000Sooooo00Co0000oooooooooooo00000_ooool2o`0000?ooooo00Go0000
ooooooooooooooooo`000004ooooo`03o`000?oooooooooo07Gooooo00?o0000ooooooooool03Ooo
ool00ol0003oooooooooo`1dooooo`000_ooool2o`0000[ooooo0_l00004ooooo`03o`000?oooooo
oooo00;ooooo0ol00005ooooo`03o`000?oooooooooo07Gooooo00?o0000ooooooooool03Oooool0
0ol0003oooooooooo`1dooooo`008Oooool00ol0003oooooooooo`1eooooo`03o`000?oooooooooo
00cooooo00?o0000ooooooooool0MOooool0027ooooo0_l0001gooooo`03o`000?oooooooooo00_o
oooo00?o0000ooooooooool0MOooool0027ooooo00?o0000ooooooooool0M_ooool00ol0003ooooo
ooooo`0;ooooo`03o`000?oooooooooo07Gooooo000Qooooo`03o`000?oooooooooo07Kooooo00?o
0000ooooooooool02_ooool00ol0003oooooooooo`1fooooo`008Oooool00ol0003oooooooooo`1g
ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool0M_ooool0027ooooo00?o0000oooo
ooooool0Moooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo07Kooooo000Qooooo`03
o`000?oooooooooo07Sooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`1gooooo`00
8Oooool2o`0007Wooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`1gooooo`008Ooo
ool00ol0003oooooooooo`1hooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0Mooo
ool0027ooooo00?o0000ooooooooool0NOooool9o`0007[ooooo000Qooooo`03o`000?oooooooooo
0?cooooo000Qooooo`03o`000?oooooooooo0?cooooo000Qooooo`03o`000?oooooooooo0?cooooo
000Qooooo`;o0000oOooool00?oooooo8Oooool00?oooooo8Oooool00?oooooo8Oooool00001\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-4.02939, -0.00139331, \
0.121183, 8.61093*^-5}}],

Cell[BoxData[
    \(0.013174729680370279`\)], "Output",
  CellLabel->"Out[20]="]
}, Open  ]],

Cell[TextData[{
  StyleBox["Q4: ",
    FontColor->RGBColor[0, 1, 1]],
  "What effect does tighter linkage have on the cline?  What would happen \
with more loci than three?"
}], "Text"]
}, Closed]],

Cell[CellGroupData[{

Cell["Further questions", "SubsubsectionIcon"],

Cell["\<\
These simulations can be used to ask many other questions.  For \
example: 
What are the effects of different kinds of selection?  What can we infer \
about selection from observations of clines?  
Can an allele be established if  selection favours it only in a limited \
region?  How large must the region be?
Does linkage help or hinder local adaptation?
If selection maintains a cline in a quantitative trait, what will the \
underlying gene frequency clines look like?\
\>", "Text"]
}, Closed]]
},
FrontEndVersion->"4.2 for Macintosh",
ScreenRectangle->{{0, 1276}, {0, 832}},
WindowSize->{1254, 782},
WindowMargins->{{4, Automatic}, {Automatic, 1}},
Visible->True,
InputAliases->{"notation"->RowBox[ {"Notation", "[", 
        RowBox[ {
          TagBox[ 
          "\[Placeholder]", NotationBoxTag, TagStyle -> 
            "NotationTemplateStyle"], " ", "\[DoubleLongLeftRightArrow]", " ",
           
          TagBox[ 
          "\[Placeholder]", NotationBoxTag, TagStyle -> 
            "NotationTemplateStyle"]}], "]"}], 
    "notation>"->RowBox[ {"Notation", "[", 
        RowBox[ {
          TagBox[ 
          "\[Placeholder]", NotationBoxTag, TagStyle -> 
            "NotationTemplateStyle"], " ", "\[DoubleLongRightArrow]", " ", 
          TagBox[ 
          "\[Placeholder]", NotationBoxTag, TagStyle -> 
            "NotationTemplateStyle"]}], "]"}], 
    "notation<"->RowBox[ {"Notation", "[", 
        RowBox[ {
          TagBox[ 
          "\[Placeholder]", NotationBoxTag, TagStyle -> 
            "NotationTemplateStyle"], " ", "\[DoubleLongLeftArrow]", " ", 
          TagBox[ 
          "\[Placeholder]", NotationBoxTag, TagStyle -> 
            "NotationTemplateStyle"]}], "]"}], 
    "symb"->RowBox[ {"Symbolize", "[", 
        TagBox[ 
        "\[Placeholder]", NotationBoxTag, TagStyle -> 
          "NotationTemplateStyle"], "]"}], 
    "infixnotation"->RowBox[ {"InfixNotation", "[", 
        RowBox[ {
          TagBox[ 
          "\[Placeholder]", NotationBoxTag, TagStyle -> 
            "NotationTemplateStyle"], ",", "\[Placeholder]"}], "]"}], 
    "addia"->RowBox[ {"AddInputAlias", "[", 
        RowBox[ {"\"\[Placeholder]\"", "\[Rule]", 
          TagBox[ 
          "\[Placeholder]", NotationBoxTag, TagStyle -> 
            "NotationTemplateStyle"]}], "]"}], 
    "pattwraper"->TagBox[ 
      "\[Placeholder]", NotationPatternTag, TagStyle -> 
        "NotationPatternWrapperStyle"], 
    "madeboxeswraper"->TagBox[ 
      "\[Placeholder]", NotationMadeBoxesTag, TagStyle -> 
        "NotationMadeBoxesWrapperStyle"]},
StyleDefinitions -> Notebook[{
  
  Cell[CellGroupData[{
  Cell["Style Definitions for On-line Help", "Subtitle"],
  
  Cell["\<\
These styles are carefully tuned for all aspects of the online \
help. It's recommended that they remain unchanged.\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell["Style Environment Names", "Section"],
  
  Cell[StyleData[All, "Working"],
    PageWidth->WindowWidth,
    ShowCellBracket->False,
    ShowAutoStyles->False,
    ScriptMinSize->9],
  
  Cell[StyleData[All, "Brackets"],
    PageWidth->WindowWidth,
    ShowCellBracket->True,
    ShowAutoStyles->False,
    ScriptMinSize->9],
  
  Cell[StyleData[All, "SlideShow"],
    PageWidth->WindowWidth,
    ScrollingOptions->{"PagewiseDisplay"->True},
    ScriptMinSize->9],
  
  Cell[StyleData[All, "Printout"],
    PageWidth->PaperWidth,
    ShowCellBracket->False,
    ShowAutoStyles->False,
    ScriptMinSize->5,
    PrivateFontOptions->{"FontType"->"Outline"}],
  
  Cell[StyleData[All, "EnhancedPrintout"],
    PageWidth->PaperWidth,
    ShowCellBracket->False,
    ScriptMinSize->5,
    FontFamily->"Palatino",
    PrivateFontOptions->{"FontType"->"Outline"}],
  
  Cell[StyleData[All, "EnhancedPrintoutNonGray"],
    PageWidth->PaperWidth,
    ShowCellBracket->False,
    ScriptMinSize->5,
    FontFamily->"Palatino",
    PrivateFontOptions->{"FontType"->"Outline"}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Notebook Options", "Section"],
  
  Cell["\<\
  The options defined for the style below will be used at the \
Notebook level.  \
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Notebook"],
    PageHeaders->{{Cell[ 
            TextData[ {
              CounterBox[ "Page"]}], "PageNumber"], None, Cell[ 
            TextData[ {"Printed from the ", 
              StyleBox[ "Mathematica", FontSlant -> "Italic"], 
              " Help Browser"}], "PageHeader"]}, {Cell[ 
            TextData[ {"Printed from the ", 
              StyleBox[ "Mathematica", FontSlant -> "Italic"], 
              " Help Browser"}], "PageHeader"], None, Cell[ 
            TextData[ {
              CounterBox[ "Page"]}], "PageNumber"]}},
    PageFooters->{{None, Cell[ 
            
            TextData[ {
              "\[Copyright]1988-2002 Wolfram Research, Inc. All rights \
reserved."}], "PageFooter"], None}, {None, Cell[ 
            
            TextData[ {
              "\[Copyright]1988-2002 Wolfram Research, Inc. All rights \
reserved."}], "PageFooter"], None}},
    PageHeaderLines->{True, True},
    PageFooterLines->{True, True},
    PrintingOptions->{"FacingPages"->True},
    CellLabelAutoDelete->False,
    CellFrameLabelMargins->6,
    StyleMenuListing->None],
  
  Cell[StyleData["Notebook", "Printout"],
    PageHeaders->{{Cell[ 
            TextData[ {
              CounterBox[ "Page"]}], "PageNumber"], None, Cell[ 
            TextData[ {"Printed from the ", 
              StyleBox[ "Mathematica", FontSlant -> "Italic"], 
              " Help Browser"}], "PageHeader"]}, {Cell[ 
            TextData[ {"Printed from the ", 
              StyleBox[ "Mathematica", FontSlant -> "Italic"], 
              " Help Browser"}], "PageHeader"], None, Cell[ 
            TextData[ {
              CounterBox[ "Page"]}], "PageNumber"]}},
    PageFooters->{{None, Cell[ 
            
            TextData[ {
              "\[Copyright]1988-2002 Wolfram Research, Inc. All rights \
reserved."}], "PageFooter"], None}, {None, Cell[ 
            
            TextData[ {
              "\[Copyright]1988-2002 Wolfram Research, Inc. All rights \
reserved."}], "PageFooter"], None}},
    PageHeaderLines->{True, True},
    PageFooterLines->{True, True},
    PrintingOptions->{"FacingPages"->True}],
  
  Cell[StyleData["Notebook", "EnhancedPrintout"],
    PageFooters->{{None, None, None}, {None, None, None}},
    PageHeaderLines->{True, True},
    PrintingOptions->{"PrintingMargins"->{{62, 62}, {62, 72}},
    "PageSize"->{602, 672},
    "PrintRegistrationMarks"->True,
    "FirstPageHeader"->False,
    "FacingPages"->True}]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Headings", "Section"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Chapter"],
    CellFrame->{{0, 0}, {0.5, 0}},
    CellMargins->{{12, Inherited}, {10, 40}},
    CellGroupingRules->{"TitleGrouping", 0},
    PageBreakBelow->False,
    DefaultNewInlineCellStyle->"None",
    InputAutoReplacements->{"TeX"->StyleBox[ 
            RowBox[ {"T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.074999999999999997, \
-0.085000000000000006}, {0, 0}}, BoxBaselineShift -> 0.5], "X"}]], 
        "LaTeX"->StyleBox[ 
            RowBox[ {"L", 
              StyleBox[ 
                AdjustmentBox[ 
                "A", BoxMargins -> {{-0.35999999999999999, \
-0.10000000000000001}, {0, 0}}, BoxBaselineShift -> -0.20000000000000001], 
                FontSize -> Smaller], "T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.074999999999999997, \
-0.085000000000000006}, {0, 0}}, BoxBaselineShift -> 0.5], "X"}]], 
        "mma"->"Mathematica", "Mma"->"Mathematica", "MMA"->"Mathematica", 
        "webMathematica"->FormBox[ 
            RowBox[ {"web", 
              AdjustmentBox[ 
                StyleBox[ "Mathematica", FontSlant -> "Italic"], 
                BoxMargins -> {{-0.17499999999999999, 0}, {0, 0}}]}], 
            TextForm]},
    LanguageCategory->"NaturalLanguage",
    CounterIncrements->"Title",
    CounterAssignments->{{"Section", 0}, {"Equation", 0}, {"Figure", 0}, {
        "Subtitle", 0}, {"Subsubtitle", 0}},
    FontFamily->"Helvetica",
    FontSize->18,
    FontWeight->"Plain"],
  
  Cell[StyleData["Chapter", "Printout"],
    CellMargins->{{2, 10}, {6, 30}},
    FontSize->14],
  
  Cell[StyleData["Chapter", "EnhancedPrintout"],
    CellMargins->{{2, 10}, {6, 30}},
    FontFamily->"Futura",
    FontSize->14],
  
  Cell[StyleData["Chapter", "EnhancedPrintoutNonGray"],
    CellMargins->{{2, 10}, {6, 30}},
    FontFamily->"Futura",
    FontSize->14]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Section"],
    CellMargins->{{10, 4}, {12, 18}},
    CellGroupingRules->{"SectionGrouping", 30},
    ConversionRules:>{"HTML" -> {
      "<font size=\"+2\" face=\"Helvetica, Arial\"><p><b>", 
      "</b></p></font>\n"}},
    InputAutoReplacements->{"TeX"->StyleBox[ 
            RowBox[ {"T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.074999999999999997, \
-0.085000000000000006}, {0, 0}}, BoxBaselineShift -> 0.5], "X"}]], 
        "LaTeX"->StyleBox[ 
            RowBox[ {"L", 
              StyleBox[ 
                AdjustmentBox[ 
                "A", BoxMargins -> {{-0.35999999999999999, \
-0.10000000000000001}, {0, 0}}, BoxBaselineShift -> -0.20000000000000001], 
                FontSize -> Smaller], "T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.074999999999999997, \
-0.085000000000000006}, {0, 0}}, BoxBaselineShift -> 0.5], "X"}]], 
        "mma"->"Mathematica", "Mma"->"Mathematica", "MMA"->"Mathematica", 
        "webMathematica"->FormBox[ 
            RowBox[ {"web", 
              AdjustmentBox[ 
                StyleBox[ "Mathematica", FontSlant -> "Italic"], 
                BoxMargins -> {{-0.17499999999999999, 0}, {0, 0}}]}], 
            TextForm]},
    CounterIncrements->"Section",
    FontFamily->"Helvetica",
    FontSize->20,
    FontWeight->"Bold"],
  
  Cell[StyleData["Section", "SlideShow"],
    CellFrame->{{0, 0}, {0, 0.5}},
    ShowCellBracket->False,
    CellMargins->{{0, 0}, {5, 0}},
    PageBreakBelow->False,
    CellFrameMargins->{{36, 36}, {Inherited, 15}},
    FontFamily->"Helvetica",
    FontSize->18,
    FontWeight->"Bold",
    FontColor->GrayLevel[1],
    Background->RGBColor[0.408011, 0.440726, 0.8]],
  
  Cell[StyleData["Section", "Printout"],
    CellMargins->{{2, 0}, {0, 18}},
    PageBreakBelow->False,
    FontSize->18],
  
  Cell[StyleData["Section", "EnhancedPrintout"],
    CellFrame->{{0, 0}, {0.5, 0}},
    CellMargins->{{2, Inherited}, {5, 30}},
    CellGroupingRules->{"SectionGrouping", 30},
    PageBreakBelow->False,
    CellFrameMargins->8,
    CounterIncrements->"Section",
    CounterAssignments->{{"Subsection", 0}, {"Subsubsection", 0}},
    FontFamily->"Futura",
    FontSize->16],
  
  Cell[StyleData["Section", "EnhancedPrintoutNonGray"],
    CellFrame->{{0, 0}, {0.5, 0}},
    CellMargins->{{2, Inherited}, {5, 30}},
    CellGroupingRules->{"SectionGrouping", 30},
    PageBreakBelow->False,
    CellFrameMargins->8,
    CounterIncrements->"Section",
    CounterAssignments->{{"Subsection", 0}, {"Subsubsection", 0}},
    FontFamily->"Futura",
    FontSize->16]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Subsection"],
    CellDingbat->"\[FilledSquare]",
    CellMargins->{{24, 4}, {0, 18}},
    CellElementSpacings->{"ClosedGroupTopMargin"->18},
    CellGroupingRules->{"SectionGrouping", 40},
    ConversionRules:>{"HTML" -> {
      "<li type=\"square\"><font size=\"+1\" face=\"Helvetica, \
Arial\"><p><b>", "</b></p></font></li>\n"}},
    CellFrameLabelMargins->6,
    InputAutoReplacements->{"TeX"->StyleBox[ 
            RowBox[ {"T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.074999999999999997, \
-0.085000000000000006}, {0, 0}}, BoxBaselineShift -> 0.5], "X"}]], 
        "LaTeX"->StyleBox[ 
            RowBox[ {"L", 
              StyleBox[ 
                AdjustmentBox[ 
                "A", BoxMargins -> {{-0.35999999999999999, \
-0.10000000000000001}, {0, 0}}, BoxBaselineShift -> -0.20000000000000001], 
                FontSize -> Smaller], "T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.074999999999999997, \
-0.085000000000000006}, {0, 0}}, BoxBaselineShift -> 0.5], "X"}]], 
        "mma"->"Mathematica", "Mma"->"Mathematica", "MMA"->"Mathematica", 
        "webMathematica"->FormBox[ 
            RowBox[ {"web", 
              AdjustmentBox[ 
                StyleBox[ "Mathematica", FontSlant -> "Italic"], 
                BoxMargins -> {{-0.17499999999999999, 0}, {0, 0}}]}], 
            TextForm]},
    FontFamily->"Helvetica",
    FontSize->16,
    FontWeight->"Bold"],
  
  Cell[StyleData["Subsection", "SlideShow"],
    CellDingbat->None,
    CellMargins->{{70, 0}, {4, 12}},
    FontSize->12],
  
  Cell[StyleData["Subsection", "Printout"],
    CellMargins->{{9, 0}, {5, 24}},
    FontSize->12],
  
  Cell[StyleData["Subsection", "EnhancedPrintout"],
    CellMargins->{{9, 0}, {5, 20}},
    FontFamily->"Futura",
    FontSize->12],
  
  Cell[StyleData["Subsection", "EnhancedPrintoutNonGray"],
    CellMargins->{{9, 0}, {5, 20}},
    FontFamily->"Futura",
    FontSize->12]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Subsubsection"],
    CellMargins->{{10, 4}, {0, 18}},
    CellElementSpacings->{"ClosedGroupTopMargin"->18},
    CellGroupingRules->{"SectionGrouping", 50},
    ConversionRules:>{"HTML" -> {"<font face=\"Helvetica, Arial\"><p><b>", 
      "</b></p></font>\n"}},
    InputAutoReplacements->{"TeX"->StyleBox[ 
            RowBox[ {"T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.074999999999999997, \
-0.085000000000000006}, {0, 0}}, BoxBaselineShift -> 0.5], "X"}]], 
        "LaTeX"->StyleBox[ 
            RowBox[ {"L", 
              StyleBox[ 
                AdjustmentBox[ 
                "A", BoxMargins -> {{-0.35999999999999999, \
-0.10000000000000001}, {0, 0}}, BoxBaselineShift -> -0.20000000000000001], 
                FontSize -> Smaller], "T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.074999999999999997, \
-0.085000000000000006}, {0, 0}}, BoxBaselineShift -> 0.5], "X"}]], 
        "mma"->"Mathematica", "Mma"->"Mathematica", "MMA"->"Mathematica", 
        "webMathematica"->FormBox[ 
            RowBox[ {"web", 
              AdjustmentBox[ 
                StyleBox[ "Mathematica", FontSlant -> "Italic"], 
                BoxMargins -> {{-0.17499999999999999, 0}, {0, 0}}]}], 
            TextForm]},
    FontFamily->"Helvetica",
    FontSize->12,
    FontWeight->"Bold"],
  
  Cell[StyleData["Subsubsection", "Printout"],
    CellMargins->{{2, 0}, {3, 8}},
    FontSize->10],
  
  Cell[StyleData["Subsubsection", "EnhancedPrintout"],
    CellMargins->{{2, 0}, {3, 8}},
    FontFamily->"Futura",
    FontSize->10],
  
  Cell[StyleData["Subsubsection", "EnhancedPrintoutNonGray"],
    CellMargins->{{2, 0}, {3, 8}},
    FontFamily->"Futura",
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["SubsubsectionColor"],
    CellMargins->{{10, 4}, {0, 18}},
    CellElementSpacings->{"ClosedGroupTopMargin"->18},
    CellGroupingRules->{"SectionGrouping", 50},
    ConversionRules:>{"HTML" -> {
      "<font face=\"Helvetica, Arial\" color=\"660099\"><p><b>", 
      "</b></p></font>\n"}},
    InputAutoReplacements->{"TeX"->StyleBox[ 
            RowBox[ {"T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.074999999999999997, \
-0.085000000000000006}, {0, 0}}, BoxBaselineShift -> 0.5], "X"}]], 
        "LaTeX"->StyleBox[ 
            RowBox[ {"L", 
              StyleBox[ 
                AdjustmentBox[ 
                "A", BoxMargins -> {{-0.35999999999999999, \
-0.10000000000000001}, {0, 0}}, BoxBaselineShift -> -0.20000000000000001], 
                FontSize -> Smaller], "T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.074999999999999997, \
-0.085000000000000006}, {0, 0}}, BoxBaselineShift -> 0.5], "X"}]], 
        "mma"->"Mathematica", "Mma"->"Mathematica", "MMA"->"Mathematica", 
        "webMathematica"->FormBox[ 
            RowBox[ {"web", 
              AdjustmentBox[ 
                StyleBox[ "Mathematica", FontSlant -> "Italic"], 
                BoxMargins -> {{-0.17499999999999999, 0}, {0, 0}}]}], 
            TextForm]},
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->12,
    FontWeight->"Bold",
    FontColor->RGBColor[0.297993, 0, 0.454994]],
  
  Cell[StyleData["SubsubsectionColor", "Printout"],
    CellMargins->{{2, 0}, {0, 18}},
    PageBreakBelow->False,
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["SubsectionIcon"],
    ShowGroupOpenCloseIcon->True,
    CellMargins->{{24, 4}, {0, 18}},
    CellElementSpacings->{"ClosedGroupTopMargin"->8},
    CellGroupingRules->{"SectionGrouping", 40},
    ConversionRules:>{"HTML" -> {
      "<li type=\"square\"><font face=\"Helvetica, Arial\"><p><b>", 
      "</b></p></font>\n"}},
    InputAutoReplacements->{"TeX"->StyleBox[ 
            RowBox[ {"T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.074999999999999997, \
-0.085000000000000006}, {0, 0}}, BoxBaselineShift -> 0.5], "X"}]], 
        "LaTeX"->StyleBox[ 
            RowBox[ {"L", 
              StyleBox[ 
                AdjustmentBox[ 
                "A", BoxMargins -> {{-0.35999999999999999, \
-0.10000000000000001}, {0, 0}}, BoxBaselineShift -> -0.20000000000000001], 
                FontSize -> Smaller], "T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.074999999999999997, \
-0.085000000000000006}, {0, 0}}, BoxBaselineShift -> 0.5], "X"}]], 
        "mma"->"Mathematica", "Mma"->"Mathematica", "MMA"->"Mathematica", 
        "webMathematica"->FormBox[ 
            RowBox[ {"web", 
              AdjustmentBox[ 
                StyleBox[ "Mathematica", FontSlant -> "Italic"], 
                BoxMargins -> {{-0.17499999999999999, 0}, {0, 0}}]}], 
            TextForm]},
    CounterIncrements->"Section",
    FontFamily->"Helvetica",
    FontSize->16,
    FontWeight->"Bold"],
  
  Cell[StyleData["SubsectionIcon", "Printout"],
    CellDingbat->"\[FilledSquare]",
    ShowGroupOpenCloseIcon->False,
    CellMargins->{{16, 0}, {0, 18}},
    PageBreakBelow->False,
    FontSize->14]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["SubsubsectionIcon"],
    ShowGroupOpenCloseIcon->True,
    CellMargins->{{24, 4}, {0, 8}},
    CellElementSpacings->{"ClosedGroupTopMargin"->4},
    CellGroupingRules->{"SectionGrouping", 50},
    ConversionRules:>{"HTML" -> {
      "<li type=\"square\"><font face=\"Helvetica, Arial\"><p><b>", 
      "</b></p></font>\n"}},
    InputAutoReplacements->{"TeX"->StyleBox[ 
            RowBox[ {"T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.074999999999999997, \
-0.085000000000000006}, {0, 0}}, BoxBaselineShift -> 0.5], "X"}]], 
        "LaTeX"->StyleBox[ 
            RowBox[ {"L", 
              StyleBox[ 
                AdjustmentBox[ 
                "A", BoxMargins -> {{-0.35999999999999999, \
-0.10000000000000001}, {0, 0}}, BoxBaselineShift -> -0.20000000000000001], 
                FontSize -> Smaller], "T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.074999999999999997, \
-0.085000000000000006}, {0, 0}}, BoxBaselineShift -> 0.5], "X"}]], 
        "mma"->"Mathematica", "Mma"->"Mathematica", "MMA"->"Mathematica", 
        "webMathematica"->FormBox[ 
            RowBox[ {"web", 
              AdjustmentBox[ 
                StyleBox[ "Mathematica", FontSlant -> "Italic"], 
                BoxMargins -> {{-0.17499999999999999, 0}, {0, 0}}]}], 
            TextForm]},
    CounterIncrements->"Subsection",
    CounterAssignments->{{"Subsubsection", 0}},
    FontFamily->"Helvetica",
    FontSize->12,
    FontWeight->"Bold"],
  
  Cell[StyleData["SubsubsectionIcon", "Printout"],
    ShowGroupOpenCloseIcon->False,
    CellMargins->{{2, 0}, {0, 18}},
    PageBreakBelow->False,
    FontSize->10]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Text", "Section"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Text"],
    CellMargins->{{10, 4}, {0, 8}},
    ConversionRules:>{"HTML" -> {"<p>", "</p>"}},
    InputAutoReplacements->{"TeX"->StyleBox[ 
            RowBox[ {"T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.074999999999999997, \
-0.085000000000000006}, {0, 0}}, BoxBaselineShift -> 0.5], "X"}]], 
        "LaTeX"->StyleBox[ 
            RowBox[ {"L", 
              StyleBox[ 
                AdjustmentBox[ 
                "A", BoxMargins -> {{-0.35999999999999999, \
-0.10000000000000001}, {0, 0}}, BoxBaselineShift -> -0.20000000000000001], 
                FontSize -> Smaller], "T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.074999999999999997, \
-0.085000000000000006}, {0, 0}}, BoxBaselineShift -> 0.5], "X"}]], 
        "mma"->"Mathematica", "Mma"->"Mathematica", "MMA"->"Mathematica", 
        "webMathematica"->FormBox[ 
            RowBox[ {"web", 
              AdjustmentBox[ 
                StyleBox[ "Mathematica", FontSlant -> "Italic"], 
                BoxMargins -> {{-0.17499999999999999, 0}, {0, 0}}]}], 
            TextForm]},
    Hyphenation->True,
    ParagraphSpacing->{0, 8},
    FontSize->12],
  
  Cell[StyleData["Text", "SlideShow"],
    CellMargins->{{36, 24}, {4, 4}},
    Hyphenation->False,
    FontSize->14],
  
  Cell[StyleData["Text", "Printout"],
    CellMargins->{{2, 2}, {6, 6}},
    TextJustification->1,
    FontSize->10],
  
  Cell[StyleData["Text", "EnhancedPrintout"],
    CellMargins->{{2, 2}, {6, 6}},
    TextJustification->1,
    FontFamily->"Palatino",
    FontSize->10],
  
  Cell[StyleData["Text", "EnhancedPrintoutNonGray"],
    CellMargins->{{2, 2}, {6, 6}},
    TextJustification->1,
    FontFamily->"Palatino",
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["CompactText"],
    CellMargins->{{10, 4}, {0, 8}},
    ConversionRules:>{"HTML" -> {"<font size=\"-1\">", "</font>\n"}},
    Hyphenation->True,
    ParagraphSpacing->{0, 0},
    StyleMenuListing->None,
    FontSize->10],
  
  Cell[StyleData["CompactText", "Printout"],
    CellMargins->{{2, 0}, {0, 8}},
    FontSize->8],
  
  Cell[StyleData["CompactText", "EnhancedPrintout"],
    CellMargins->{{2, 0}, {0, 8}},
    FontSize->8],
  
  Cell[StyleData["CompactText", "EnhancedPrintoutNonGray"],
    CellMargins->{{2, 0}, {0, 8}},
    FontSize->8]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Compact12Text"],
    CellMargins->{{10, 4}, {0, 8}},
    ConversionRules:>{"HTML" -> {"<p>", "</p>"}},
    Hyphenation->True,
    ParagraphSpacing->{0, 0},
    StyleMenuListing->None],
  
  Cell[StyleData["Compact12Text", "Printout"],
    CellMargins->{{2, 0}, {0, 8}},
    FontSize->10],
  
  Cell[StyleData["Compact12Text", "EnhancedPrintout"],
    CellMargins->{{2, 0}, {0, 8}},
    FontSize->10],
  
  Cell[StyleData["Compact12Text", "EnhancedPrintoutNonGray"],
    CellMargins->{{2, 0}, {0, 8}},
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["TextSans"],
    CellMargins->{{10, 4}, {0, 8}},
    ConversionRules:>{"HTML" -> {
      "<font size=\"-1\" face=\"Helvetica, Arial\">", "</font>\n"}},
    CellHorizontalScrolling->True,
    Hyphenation->True,
    ParagraphSpacing->{0, 8},
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->10],
  
  Cell[StyleData["TextSans", "Printout"],
    CellMargins->{{2, 0}, {0, 8}},
    FontSize->8],
  
  Cell[StyleData["TextSans", "EnhancedPrintout"],
    CellMargins->{{2, 0}, {0, 8}},
    FontSize->8],
  
  Cell[StyleData["TextSans", "EnhancedPrintoutNonGray"],
    CellMargins->{{2, 0}, {0, 8}},
    FontSize->8]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["ItemizedText"],
    CellMargins->{{19, 4}, {4, 4}},
    ConversionRules:>{"HTML" -> {"<blockquote>", "</blockquote>"}},
    Hyphenation->True,
    LineSpacing->{1, 3},
    ParagraphIndent->-22,
    CounterIncrements->"ItemizedText",
    StyleMenuListing->None],
  
  Cell[StyleData["ItemizedText", "Printout"],
    FontSize->10],
  
  Cell[StyleData["ItemizedText", "EnhancedPrintout"],
    CellMargins->{{16, 4}, {2, 4}},
    FontFamily->"Palatino",
    FontSize->10],
  
  Cell[StyleData["ItemizedText", "EnhancedPrintoutNonGray"],
    ParagraphIndent->-18,
    FontFamily->"Palatino",
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["ItemizedTextNote"],
    CellMargins->{{41, 4}, {4, 0}},
    ConversionRules:>{"HTML" -> {"<blockquote>", "</blockquote>"}},
    Hyphenation->True,
    LineSpacing->{1, 2},
    CounterIncrements->"Text",
    StyleMenuListing->None],
  
  Cell[StyleData["ItemizedTextNote", "Printout"],
    CellMargins->{{34, 4}, {4, 1}},
    FontSize->10],
  
  Cell[StyleData["ItemizedTextNote", "EnhancedPrintout"],
    CellMargins->{{39, 4}, {4, 1}},
    FontFamily->"Palatino",
    FontSize->10],
  
  Cell[StyleData["ItemizedTextNote", "EnhancedPrintoutNonGray"],
    CellMargins->{{39, 4}, {4, 1}},
    FontFamily->"Palatino",
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["IndentedText"],
    CellMargins->{{20, 4}, {0, 6}},
    ConversionRules:>{"HTML" -> {"<blockquote>", "</blockquote>"}},
    LineSpacing->{1, 3},
    CounterIncrements->"Text",
    StyleMenuListing->None],
  
  Cell[StyleData["IndentedText", "SlideShow"],
    CellMargins->{{80, 24}, {5, 5}},
    Hyphenation->False,
    FontSize->13],
  
  Cell[StyleData["IndentedText", "Printout"],
    FontSize->11],
  
  Cell[StyleData["IndentedText", "EnhancedPrintout"],
    FontFamily->"Palatino",
    FontSize->10],
  
  Cell[StyleData["IndentedText", "EnhancedPrintoutNonGray"],
    FontFamily->"Palatino",
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["MathCaption"],
    CellDingbat->"\[FilledSmallSquare]",
    CellMargins->{{19, 62}, {0, 14}},
    ConversionRules:>{"HTML" -> {
      "<li type=\"square\"><p><font color=\"000066\">", "</font></p></li>"}},
    PageBreakBelow->False,
    CellFrameLabelMargins->4,
    Hyphenation->True,
    LineSpacing->{1, 1},
    ParagraphSpacing->{0, 8},
    FontColor->RGBColor[0, 0, 0.4]],
  
  Cell[StyleData["MathCaption", "SlideShow"],
    ShowCellBracket->False,
    CellMargins->{{36, 36}, {6, 6}}],
  
  Cell[StyleData["MathCaption", "Printout"],
    CellMargins->{{9, 0}, {0, 14}},
    FontSize->9,
    FontColor->GrayLevel[0]],
  
  Cell[StyleData["MathCaption", "EnhancedPrintout"],
    CellMargins->{{9, 0}, {0, 14}},
    FontSize->9,
    FontColor->GrayLevel[0]],
  
  Cell[StyleData["MathCaption", "EnhancedPrintoutNonGray"],
    CellMargins->{{9, 0}, {0, 14}},
    FontSize->9,
    FontColor->GrayLevel[0]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["SmallText"],
    CellMargins->{{10, 4}, {0, 8}},
    ConversionRules:>{"HTML" -> {"<FONT SIZE=\"1\"><P>", "</P></FONT>"}},
    Hyphenation->True,
    LineSpacing->{1, 3},
    ParagraphSpacing->{0.7, 0},
    CounterIncrements->"SmallText",
    FontSize->9],
  
  Cell[StyleData["SmallText", "Printout"],
    CellMargins->{{2, 2}, {5, 5}},
    TextJustification->1,
    FontSize->7],
  
  Cell[StyleData["SmallText", "EnhancedPrintout"],
    CellMargins->{{2, 2}, {5, 5}},
    TextJustification->1,
    FontFamily->"Palatino",
    FontSize->7],
  
  Cell[StyleData["SmallText", "EnhancedPrintoutNonGray"],
    CellMargins->{{2, 2}, {5, 5}},
    TextJustification->1,
    FontFamily->"Palatino",
    FontSize->7]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Input/Output", "Section"],
  
  Cell["\<\
The cells in this section define styles used for input and output \
to the kernel.  Be careful when modifying, renaming, or removing these \
styles, because the front end associates special meanings with these style \
names.    \
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Input"],
    ShowCellBracket->True,
    CellMargins->{{46, 4}, {3, 8}},
    Evaluatable->True,
    CellGroupingRules->"InputGrouping",
    PageBreakWithin->False,
    GroupPageBreakWithin->False,
    CellLabelAutoDelete->False,
    CellLabelMargins->{{14, Inherited}, {Inherited, Inherited}},
    DefaultFormatType->DefaultInputFormatType,
    ShowSpecialCharacters->Automatic,
    "TwoByteSyntaxCharacterAutoReplacement"->True,
    HyphenationOptions->{"HyphenationCharacter"->"\[Continuation]"},
    LanguageCategory->"Mathematica",
    FormatType->StandardForm,
    ShowStringCharacters->True,
    NumberMarks->True,
    FontWeight->"Bold"],
  
  Cell[StyleData["Input", "SlideShow"],
    ShowCellBracket->True,
    CellMargins->{{100, 50}, {0, 6}},
    PageBreakWithin->False,
    GroupPageBreakWithin->False,
    CellFrameMargins->{{8, 8}, {4, 8}},
    Background->RGBColor[1, 1, 0.8]],
  
  Cell[StyleData["Input", "Printout"],
    ShowCellBracket->False,
    CellMargins->{{39, 0}, {4, 6}},
    FontSize->9],
  
  Cell[StyleData["Input", "EnhancedPrintout"],
    ShowCellBracket->False,
    CellMargins->{{39, 0}, {4, 6}},
    FontSize->9],
  
  Cell[StyleData["Input", "EnhancedPrintoutNonGray"],
    ShowCellBracket->False,
    CellMargins->{{39, 0}, {4, 6}},
    FontSize->9]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Output"],
    ShowCellBracket->True,
    CellMargins->{{47, 4}, {4, 2}},
    CellEditDuplicate->True,
    CellGroupingRules->"OutputGrouping",
    CellHorizontalScrolling->True,
    PageBreakWithin->False,
    GroupPageBreakWithin->False,
    GeneratedCell->True,
    CellAutoOverwrite->True,
    CellLabelAutoDelete->False,
    CellLabelMargins->{{14, Inherited}, {Inherited, Inherited}},
    DefaultFormatType->DefaultOutputFormatType,
    "TwoByteSyntaxCharacterAutoReplacement"->True,
    HyphenationOptions->{"HyphenationCharacter"->"\[Continuation]"},
    AutoItalicWords->{},
    LanguageCategory->None,
    FormatType->StandardForm],
  
  Cell[StyleData["Output", "SlideShow"],
    ShowCellBracket->True,
    CellMargins->{{100, 50}, {6, 0}},
    PageBreakWithin->False,
    GroupPageBreakWithin->False,
    CellFrameMargins->{{8, 8}, {8, 4}},
    Background->RGBColor[1, 1, 0.8]],
  
  Cell[StyleData["Output", "Printout"],
    ShowCellBracket->False,
    CellMargins->{{39, 0}, {6, 4}},
    FontSize->9],
  
  Cell[StyleData["Output", "EnhancedPrintout"],
    ShowCellBracket->False,
    CellMargins->{{39, 0}, {6, 4}},
    FontSize->9],
  
  Cell[StyleData["Output", "EnhancedPrintoutNonGray"],
    ShowCellBracket->False,
    CellMargins->{{39, 0}, {6, 4}},
    FontSize->9]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["InputOnly"],
    ShowCellBracket->True,
    CellMargins->{{46, 4}, {8, 8}},
    Evaluatable->True,
    CellGroupingRules->"InputGrouping",
    PageBreakWithin->False,
    GroupPageBreakWithin->False,
    CellLabelAutoDelete->False,
    CellLabelMargins->{{14, Inherited}, {Inherited, Inherited}},
    DefaultFormatType->DefaultInputFormatType,
    ShowSpecialCharacters->Automatic,
    "TwoByteSyntaxCharacterAutoReplacement"->True,
    HyphenationOptions->{"HyphenationCharacter"->"\[Continuation]"},
    LanguageCategory->"Mathematica",
    FormatType->StandardForm,
    ShowStringCharacters->True,
    NumberMarks->True,
    StyleMenuListing->None,
    FontWeight->"Bold"],
  
  Cell[StyleData["InputOnly", "SlideShow"],
    ShowCellBracket->True,
    CellMargins->{{100, 50}, {6, 6}},
    PageBreakWithin->False,
    GroupPageBreakWithin->False,
    Background->RGBColor[1, 1, 0.8]],
  
  Cell[StyleData["InputOnly", "Printout"],
    ShowCellBracket->False,
    CellMargins->{{39, 0}, {6, 6}},
    FontSize->9],
  
  Cell[StyleData["InputOnly", "EnhancedPrintout"],
    ShowCellBracket->False,
    CellMargins->{{39, 0}, {6, 6}},
    FontSize->9],
  
  Cell[StyleData["InputOnly", "EnhancedPrintoutNonGray"],
    ShowCellBracket->False,
    CellMargins->{{39, 0}, {6, 6}},
    FontSize->9]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Message"],
    ShowCellBracket->True,
    CellMargins->{{47, 4}, {4, 2}},
    CellGroupingRules->"OutputGrouping",
    PageBreakWithin->False,
    GroupPageBreakWithin->False,
    GeneratedCell->True,
    CellAutoOverwrite->True,
    ShowCellLabel->False,
    CellLabelMargins->{{14, Inherited}, {Inherited, Inherited}},
    DefaultFormatType->DefaultOutputFormatType,
    "TwoByteSyntaxCharacterAutoReplacement"->True,
    HyphenationOptions->{"HyphenationCharacter"->"\[Continuation]"},
    LanguageCategory->None,
    FormatType->InputForm,
    StyleMenuListing->None,
    FontColor->RGBColor[0, 0, 1]],
  
  Cell[StyleData["Message", "SlideShow"],
    CellMargins->{{100, 50}, {6, 6}},
    FontSize->10,
    FontColor->RGBColor[0.699992, 0.4, 0]],
  
  Cell[StyleData["Message", "Printout"],
    ShowCellBracket->False,
    CellMargins->{{39, Inherited}, {Inherited, Inherited}},
    FontSize->9,
    FontColor->GrayLevel[0]],
  
  Cell[StyleData["Message", "EnhancedPrintout"],
    ShowCellBracket->False,
    CellMargins->{{39, Inherited}, {Inherited, Inherited}},
    FontFamily->"Courier",
    FontSize->9,
    FontColor->GrayLevel[0]],
  
  Cell[StyleData["Message", "EnhancedPrintoutNonGray"],
    ShowCellBracket->False,
    CellMargins->{{39, Inherited}, {Inherited, Inherited}},
    FontFamily->"Courier",
    FontSize->9,
    FontColor->GrayLevel[0]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Print"],
    ShowCellBracket->True,
    CellMargins->{{47, 4}, {4, 2}},
    CellGroupingRules->"OutputGrouping",
    PageBreakWithin->False,
    GroupPageBreakWithin->False,
    GeneratedCell->True,
    CellAutoOverwrite->True,
    ShowCellLabel->False,
    CellLabelMargins->{{14, Inherited}, {Inherited, Inherited}},
    DefaultFormatType->DefaultOutputFormatType,
    "TwoByteSyntaxCharacterAutoReplacement"->True,
    HyphenationOptions->{"HyphenationCharacter"->"\[Continuation]"},
    AutoItalicWords->{},
    LanguageCategory->None,
    FormatType->InputForm,
    StyleMenuListing->None],
  
  Cell[StyleData["Print", "SlideShow"],
    CellMargins->{{100, 50}, {6, 6}}],
  
  Cell[StyleData["Print", "Printout"],
    ShowCellBracket->False,
    CellMargins->{{57, Inherited}, {Inherited, Inherited}},
    FontSize->9],
  
  Cell[StyleData["Print", "EnhancedPrintout"],
    ShowCellBracket->False,
    CellMargins->{{57, Inherited}, {Inherited, Inherited}},
    FontFamily->"Courier",
    FontSize->9],
  
  Cell[StyleData["Print", "EnhancedPrintoutNonGray"],
    ShowCellBracket->False,
    CellMargins->{{57, Inherited}, {Inherited, Inherited}},
    FontFamily->"Courier",
    FontSize->9]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Graphics"],
    ShowCellBracket->True,
    CellMargins->{{47, 4}, {4, 2}},
    CellGroupingRules->"GraphicsGrouping",
    PageBreakWithin->False,
    GeneratedCell->True,
    CellAutoOverwrite->True,
    ShowCellLabel->False,
    DefaultFormatType->Utilities`Notation`Private`DefaultFormatTypeForOutput,
    LanguageCategory->None,
    FormatType->InputForm,
    StyleMenuListing->None,
    FontWeight->"Plain"],
  
  Cell[StyleData["Graphics", "SlideShow"],
    ShowCellBracket->True,
    CellMargins->{{100, 50}, {6, 0}},
    PageBreakWithin->False,
    GroupPageBreakWithin->False,
    CellFrameMargins->{{8, 8}, {4, 4}},
    Background->RGBColor[1, 1, 0.8]],
  
  Cell[StyleData["Graphics", "Printout"],
    ShowCellBracket->False,
    CellMargins->{{39, Inherited}, {Inherited, Inherited}},
    ImageSize->{250, 250},
    FontSize->9],
  
  Cell[StyleData["Graphics", "EnhancedPrintout"],
    ShowCellBracket->False,
    CellMargins->{{32, Inherited}, {Inherited, Inherited}},
    ImageSize->{250, 250},
    FontFamily->"Courier",
    FontSize->9],
  
  Cell[StyleData["Graphics", "EnhancedPrintoutNonGray"],
    ShowCellBracket->False,
    CellMargins->{{32, Inherited}, {Inherited, Inherited}},
    ImageSize->{250, 250},
    FontFamily->"Courier",
    FontSize->9]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["CellLabel"],
    LanguageCategory->None,
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->9,
    FontWeight->"Plain",
    FontColor->RGBColor[0, 0, 1]],
  
  Cell[StyleData["CellLabel", "SlideShow"],
    FontColor->RGBColor[0.699992, 0.4, 0]],
  
  Cell[StyleData["CellLabel", "Printout"],
    FontFamily->"Courier",
    FontSize->8,
    FontSlant->"Italic",
    FontColor->GrayLevel[0]],
  
  Cell[StyleData["CellLabel", "EnhancedPrintout"],
    FontFamily->"Courier",
    FontSize->8,
    FontSlant->"Italic",
    FontColor->GrayLevel[0]],
  
  Cell[StyleData["CellLabel", "EnhancedPrintoutNonGray"],
    FontFamily->"Courier",
    FontSize->8,
    FontSlant->"Italic",
    FontColor->GrayLevel[0]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Name"],
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->9,
    FontWeight->"Plain",
    FontSlant->"Italic",
    FontColor->RGBColor[0, 0, 1]],
  
  Cell[StyleData["Name", "Printout"],
    FontSize->7,
    FontColor->GrayLevel[0]],
  
  Cell[StyleData["Name", "EnhancedPrintout"],
    FontSize->7,
    FontColor->GrayLevel[0]],
  
  Cell[StyleData["Name", "EnhancedPrintoutNonGray"],
    FontSize->7,
    FontColor->GrayLevel[0]]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Hyperlinks", "Section"],
  
  Cell["\<\
The cells below define styles useful for making hypertext \
ButtonBoxes.  The \"Hyperlink\" style is for links within the same Notebook, \
or between Notebooks. The others point to the various sections of the help \
browser. These styles will modify individual words or letters in a cell \
exclusive of the cell tag.\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Hyperlink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontColor->RGBColor[0, 0, 1],
    FontVariations->{"Underline"->True},
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`NotebookLocate[ #2]}]&),
    Active->True,
    ButtonNote->ButtonData}],
  
  Cell[StyleData["Hyperlink", "Printout"],
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}],
  
  Cell[StyleData["Hyperlink", "EnhancedPrintout"],
    FontFamily->"Palatino",
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}],
  
  Cell[StyleData["Hyperlink", "EnhancedPrintoutNonGray"],
    FontFamily->"Palatino",
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["MainBookLink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontColor->RGBColor[0, 0, 1],
    FontVariations->{"Underline"->True},
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`HelpBrowserLookup[ "MainBook", #]}]&),
    Active->True,
    ButtonFrame->"None"}],
  
  Cell[StyleData["MainBookLink", "Printout"],
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}],
  
  Cell[StyleData["MainBookLink", "EnhancedPrintout"],
    FontFamily->"Palatino",
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}],
  
  Cell[StyleData["MainBookLink", "EnhancedPrintoutNonGray"],
    FontFamily->"Palatino",
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["MainBookLinkMR"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontFamily->"Courier",
    FontColor->RGBColor[0, 0, 1],
    FontVariations->{"Underline"->True},
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`HelpBrowserLookup[ "MainBook", #]}]&),
    Active->True,
    ButtonFrame->"None"}],
  
  Cell[StyleData["MainBookLinkMR", "Printout"],
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}],
  
  Cell[StyleData["MainBookLinkMR", "EnhancedPrintout"],
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}],
  
  Cell[StyleData["MainBookLinkMR", "EnhancedPrintoutNonGray"],
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["AddOnsLink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontFamily->"Courier",
    FontColor->RGBColor[0, 0, 1],
    FontVariations->{"Underline"->True},
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`HelpBrowserLookup[ "AddOns", #]}]&),
    Active->True,
    ButtonFrame->"None"}],
  
  Cell[StyleData["AddOnsLink", "Printout"],
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}],
  
  Cell[StyleData["AddOnsLink", "EnhancedPrintout"],
    FontFamily->"WRICourier",
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}],
  
  Cell[StyleData["AddOnsLink", "EnhancedPrintoutNonGray"],
    FontFamily->"WRICourier",
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["AddOnsLinkText"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontFamily->"Times",
    FontColor->RGBColor[0, 0, 1],
    FontVariations->{"Underline"->True},
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`HelpBrowserLookup[ "AddOns", #]}]&),
    Active->True,
    ButtonFrame->"None"}],
  
  Cell[StyleData["AddOnsLinkText", "Printout"],
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}],
  
  Cell[StyleData["AddOnsLinkText", "EnhancedPrintout"],
    FontFamily->"Palatino",
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}],
  
  Cell[StyleData["AddOnsLinkText", "EnhancedPrintoutNonGray"],
    FontFamily->"Palatino",
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["RefGuideLink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontFamily->"Courier",
    FontColor->RGBColor[0, 0, 1],
    FontVariations->{"Underline"->True},
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`HelpBrowserLookup[ "RefGuide", #]}]&),
    Active->True,
    ButtonFrame->"None"}],
  
  Cell[StyleData["RefGuideLink", "Printout"],
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}],
  
  Cell[StyleData["RefGuideLink", "EnhancedPrintout"],
    FontFamily->"WRICourier",
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}],
  
  Cell[StyleData["RefGuideLink", "EnhancedPrintoutNonGray"],
    FontFamily->"WRICourier",
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["GettingStartedLink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontColor->RGBColor[0, 0, 1],
    FontVariations->{"Underline"->True},
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`HelpBrowserLookup[ "GettingStarted", #]}]&),
    Active->True,
    ButtonFrame->"None"}],
  
  Cell[StyleData["GettingStartedLink", "Printout"],
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}],
  
  Cell[StyleData["GettingStartedLink", "EnhancedPrintout"],
    FontFamily->"Palatino",
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}],
  
  Cell[StyleData["GettingStartedLink", "EnhancedPrintoutNonGray"],
    FontFamily->"Palatino",
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["OtherInformationLink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontColor->RGBColor[0, 0, 1],
    FontVariations->{"Underline"->True},
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`HelpBrowserLookup[ "OtherInformation", #]}]&),
    Active->True,
    ButtonFrame->"None"}],
  
  Cell[StyleData["OtherInformationLink", "Printout"],
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}],
  
  Cell[StyleData["OtherInformationLink", "EnhancedPrintout"],
    FontFamily->"Palatino",
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}],
  
  Cell[StyleData["OtherInformationLink", "EnhancedPrintoutNonGray"],
    FontFamily->"Palatino",
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["OtherInformationLinkMR"],
    StyleMenuListing->None,
    FontFamily->"Courier",
    FontColor->RGBColor[0, 0, 1],
    FontVariations->{"Underline"->True},
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`HelpBrowserLookup[ "OtherInformation", #]}]&),
    Active->True,
    ButtonFrame->"None"}],
  
  Cell[StyleData["OtherInformationLinkMR", "Printout"],
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}],
  
  Cell[StyleData["OtherInformationLinkMR", "EnhancedPrintout"],
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}],
  
  Cell[StyleData["OtherInformationLinkMR", "EnhancedPrintoutNonGray"],
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Palette Styles", "Section"],
  
  Cell["\<\
The cells below define styles that define standard \
ButtonFunctions, for use in palette buttons.\
\>", "Text"],
  
  Cell[StyleData["Paste"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`NotebookApply[ 
          FrontEnd`InputNotebook[ ], #, After]}]&)}],
  
  Cell[StyleData["Evaluate"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`NotebookApply[ 
          FrontEnd`InputNotebook[ ], #, All], 
        SelectionEvaluate[ 
          FrontEnd`InputNotebook[ ], All]}]&)}],
  
  Cell[StyleData["EvaluateCell"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`NotebookApply[ 
          FrontEnd`InputNotebook[ ], #, All], 
        FrontEnd`SelectionMove[ 
          FrontEnd`InputNotebook[ ], All, Cell, 1], 
        FrontEnd`SelectionEvaluateCreateCell[ 
          FrontEnd`InputNotebook[ ], All]}]&)}],
  
  Cell[StyleData["CopyEvaluate"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`SelectionCreateCell[ 
          FrontEnd`InputNotebook[ ], All], 
        FrontEnd`NotebookApply[ 
          FrontEnd`InputNotebook[ ], #, All], 
        FrontEnd`SelectionEvaluate[ 
          FrontEnd`InputNotebook[ ], All]}]&)}],
  
  Cell[StyleData["CopyEvaluateCell"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`SelectionCreateCell[ 
          FrontEnd`InputNotebook[ ], All], 
        FrontEnd`NotebookApply[ 
          FrontEnd`InputNotebook[ ], #, All], 
        FrontEnd`SelectionEvaluateCreateCell[ 
          FrontEnd`InputNotebook[ ], All]}]&)}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Inline Formatting", "Section"],
  
  Cell["\<\
These styles are for modifying individual words or letters in a \
cell exclusive of the cell tag.\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["JT"],
    StyleMenuListing->None,
    FontFamily->"JFontText"],
  
  Cell[StyleData["JT", "Printout"]],
  
  Cell[StyleData["JT", "EnhancedPrintout"]],
  
  Cell[StyleData["JT", "EnhancedPrintoutNonGray"]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["JS"],
    StyleMenuListing->None,
    FontFamily->"JFontSans"],
  
  Cell[StyleData["JS", "Printout"]],
  
  Cell[StyleData["JS", "EnhancedPrintout"]],
  
  Cell[StyleData["JS", "EnhancedPrintoutNonGray"]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["JSB"],
    StyleMenuListing->None,
    FontFamily->"JFontSansBold"],
  
  Cell[StyleData["JSB", "Printout"]],
  
  Cell[StyleData["JSB", "EnhancedPrintout"]],
  
  Cell[StyleData["JSB", "EnhancedPrintoutNonGray"]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["RM"],
    StyleMenuListing->None,
    FontWeight->"Plain",
    FontSlant->"Plain"],
  
  Cell[StyleData["RM", "Printout"]],
  
  Cell[StyleData["RM", "EnhancedPrintout"]],
  
  Cell[StyleData["RM", "EnhancedPrintoutNonGray"]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["BF"],
    ConversionRules:>{"HTML" -> {"<b>", "</b>"}},
    StyleMenuListing->None,
    FontWeight->"Bold"],
  
  Cell[StyleData["BF", "Printout"]],
  
  Cell[StyleData["BF", "EnhancedPrintout"]],
  
  Cell[StyleData["BF", "EnhancedPrintoutNonGray"]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["IT"],
    ConversionRules:>{"HTML" -> {"<i>", "</i>"}},
    StyleMenuListing->None,
    FontSlant->"Italic"],
  
  Cell[StyleData["IT", "Printout"]],
  
  Cell[StyleData["IT", "EnhancedPrintout"]],
  
  Cell[StyleData["IT", "EnhancedPrintoutNonGray"]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["TR"],
    StyleMenuListing->None,
    FontFamily->"Times",
    FontWeight->"Plain",
    FontSlant->"Plain"],
  
  Cell[StyleData["TR", "Printout"]],
  
  Cell[StyleData["TR", "EnhancedPrintout"]],
  
  Cell[StyleData["TR", "EnhancedPrintoutNonGray"]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["TI"],
    ConversionRules:>{"HTML" -> {"<i>", "</i>"}},
    StyleMenuListing->None,
    FontFamily->"Times",
    FontSlant->"Italic"],
  
  Cell[StyleData["TI", "Printout"]],
  
  Cell[StyleData["TI", "EnhancedPrintout"]],
  
  Cell[StyleData["TI", "EnhancedPrintoutNonGray"]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["TB"],
    ConversionRules:>{"HTML" -> {"<b>", "</b>"}},
    StyleMenuListing->None,
    FontFamily->"Times",
    FontWeight->"Bold",
    FontSlant->"Plain"],
  
  Cell[StyleData["TB", "Printout"]],
  
  Cell[StyleData["TB", "EnhancedPrintout"],
    FontFamily->"Palatino"],
  
  Cell[StyleData["TB", "EnhancedPrintoutNonGray"],
    FontFamily->"Palatino"]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["TBI"],
    ConversionRules:>{"HTML" -> {"<b><i>", "</i></b>"}},
    StyleMenuListing->None,
    FontFamily->"Times",
    FontWeight->"Bold",
    FontSlant->"Italic"],
  
  Cell[StyleData["TBI", "Printout"]],
  
  Cell[StyleData["TBI", "EnhancedPrintout"],
    FontFamily->"Palatino"],
  
  Cell[StyleData["TBI", "EnhancedPrintoutNonGray"],
    FontFamily->"Palatino"]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["MR"],
    ConversionRules:>{"HTML" -> {"<tt>", "</tt>"}},
    Hyphenation->True,
    HyphenationOptions->{"HyphenationCharacter"->"\[Continuation]"},
    StyleMenuListing->None,
    FontFamily->"Courier",
    FontWeight->"Plain",
    FontSlant->"Plain"],
  
  Cell[StyleData["MR", "Printout"]],
  
  Cell[StyleData["MR", "EnhancedPrintout"],
    FontFamily->"WriCourier"],
  
  Cell[StyleData["MR", "EnhancedPrintoutNonGray"],
    FontFamily->"WriCourier"]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["MO"],
    ConversionRules:>{"HTML" -> {"<tt><i>", "</i></tt>"}},
    HyphenationOptions->{"HyphenationCharacter"->"\[Continuation]"},
    StyleMenuListing->None,
    FontFamily->"Courier",
    FontWeight->"Plain",
    FontSlant->"Italic"],
  
  Cell[StyleData["MO", "Printout"]],
  
  Cell[StyleData["MO", "EnhancedPrintout"],
    FontFamily->"WriCourier"],
  
  Cell[StyleData["MO", "EnhancedPrintoutNonGray"],
    FontFamily->"WriCourier"]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["MB"],
    ConversionRules:>{"HTML" -> {"<tt><b>", "</b></tt>"}},
    HyphenationOptions->{"HyphenationCharacter"->"\[Continuation]"},
    StyleMenuListing->None,
    FontFamily->"Courier",
    FontWeight->"Bold",
    FontSlant->"Plain"],
  
  Cell[StyleData["MB", "Printout"]],
  
  Cell[StyleData["MB", "EnhancedPrintout"],
    FontFamily->"WriCourier"],
  
  Cell[StyleData["MB", "EnhancedPrintoutNonGray"],
    FontFamily->"WriCourier"]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["MBO"],
    ConversionRules:>{"HTML" -> {"<tt><i><b>", "</b></i></tt>"}},
    HyphenationOptions->{"HyphenationCharacter"->"\[Continuation]"},
    StyleMenuListing->None,
    FontFamily->"Courier",
    FontWeight->"Bold",
    FontSlant->"Italic"],
  
  Cell[StyleData["MBO", "Printout"]],
  
  Cell[StyleData["MBO", "EnhancedPrintout"],
    FontFamily->"WriCourier"],
  
  Cell[StyleData["MBO", "EnhancedPrintoutNonGray"],
    FontFamily->"WriCourier"]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["SR"],
    ConversionRules:>{"HTML" -> {"<font=\"Helvetica, Arial\">", "</font>"}},
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontWeight->"Plain",
    FontSlant->"Plain"],
  
  Cell[StyleData["SR", "Printout"]],
  
  Cell[StyleData["SR", "EnhancedPrintout"],
    FontFamily->"Futura"],
  
  Cell[StyleData["SR", "EnhancedPrintoutNonGray"],
    FontFamily->"Futura"]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["SO"],
    ConversionRules:>{"HTML" -> {"<font=\"Futura\"><i>", "</i></font>"}},
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontWeight->"Plain",
    FontSlant->"Italic"],
  
  Cell[StyleData["SO", "Printout"],
    ConversionRules:>{"HTML" -> {"<I><Font=Futura>", "</I></Font>"}},
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontWeight->"Plain",
    FontSlant->"Italic"],
  
  Cell[StyleData["SO", "EnhancedPrintout"],
    FontFamily->"Futura"],
  
  Cell[StyleData["SO", "EnhancedPrintoutNonGray"],
    FontFamily->"Futura"]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["SB"],
    ConversionRules:>{"HTML" -> {"<font=\"Futura\"><b>", "</b></font>"}},
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontWeight->"Bold",
    FontSlant->"Plain"],
  
  Cell[StyleData["SB", "Printout"],
    ConversionRules:>{"HTML" -> {"<B><Font=Futura>", "</B></Font>"}},
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontWeight->"Bold",
    FontSlant->"Plain"],
  
  Cell[StyleData["SB", "EnhancedPrintout"],
    FontFamily->"Futura"],
  
  Cell[StyleData["SB", "EnhancedPrintoutNonGray"],
    FontFamily->"Futura"]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["SBO"],
    ConversionRules:>{"HTML" -> {"<font=\"Futura\"><b><i>", 
      "</i></b></font>"}},
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontWeight->"Bold",
    FontSlant->"Italic"],
  
  Cell[StyleData["SBO", "Printout"],
    ConversionRules:>{"HTML" -> {"<B><I><Font=Futura>", "</B></I></Font>"}},
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontWeight->"Bold",
    FontSlant->"Italic"],
  
  Cell[StyleData["SBO", "EnhancedPrintout"],
    FontFamily->"Futura"],
  
  Cell[StyleData["SBO", "EnhancedPrintoutNonGray"],
    FontFamily->"Futura"]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["M4"],
    ShowCellBracket->True,
    StyleMenuListing->None,
    FontFamily->"Math4",
    CharacterEncoding->"Math4"],
  
  Cell[StyleData["M4", "Printout"],
    ShowCellBracket->True,
    StyleMenuListing->None,
    FontFamily->"Math4",
    CharacterEncoding->"Math4"],
  
  Cell[StyleData["M4", "EnhancedPrintout"],
    ShowCellBracket->True,
    StyleMenuListing->None,
    FontFamily->"Math4",
    CharacterEncoding->"Math4"],
  
  Cell[StyleData["M4", "EnhancedPrintoutNonGray"],
    ShowCellBracket->True,
    StyleMenuListing->None,
    FontFamily->"Math4",
    CharacterEncoding->"Math4"]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["SO10"],
    ConversionRules:>{"HTML" -> {"<font=\"Helvetica, Arial\"><i>", 
      "</i></font>"}},
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->10,
    FontWeight->"Plain",
    FontSlant->"Italic"],
  
  Cell[StyleData["SO10", "Printout"],
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->8,
    FontWeight->"Plain",
    FontSlant->"Italic"],
  
  Cell[StyleData["SO10", "EnhancedPrintout"],
    StyleMenuListing->None,
    FontFamily->"Futura",
    FontSize->8,
    FontWeight->"Plain",
    FontSlant->"Italic"],
  
  Cell[StyleData["SO10", "EnhancedPrintoutNonGray"],
    StyleMenuListing->None,
    FontFamily->"Futura",
    FontSize->8,
    FontWeight->"Plain",
    FontSlant->"Italic"]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["C1"],
    StyleMenuListing->None,
    FontColor->RGBColor[0.4, 0, 1]],
  
  Cell[StyleData["C1", "Printout"],
    FontColor->GrayLevel[0]],
  
  Cell[StyleData["C1", "EnhancedPrintout"],
    FontColor->GrayLevel[0]],
  
  Cell[StyleData["C1", "EnhancedPrintoutNonGray"],
    FontColor->GrayLevel[0]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["C1MR"],
    StyleMenuListing->None,
    FontFamily->"Courier",
    FontColor->RGBColor[0.4, 0, 1]],
  
  Cell[StyleData["C1MR", "Printout"],
    FontColor->GrayLevel[0]],
  
  Cell[StyleData["C1MR", "EnhancedPrintout"],
    FontColor->GrayLevel[0]],
  
  Cell[StyleData["C1MR", "EnhancedPrintoutNonGray"],
    FontColor->GrayLevel[0]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["CapSmallCaps"],
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontWeight->"Plain",
    FontSlant->"Plain"],
  
  Cell[StyleData["CapSmallCaps", "Printout"]],
  
  Cell[StyleData["CapSmallCaps", "EnhancedPrintout"],
    FontFamily->"Futura"],
  
  Cell[StyleData["CapSmallCaps", "EnhancedPrintoutNonGray"],
    FontFamily->"Futura"]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["KeyboardChars"],
    StyleMenuListing->None,
    FontSize->12],
  
  Cell[StyleData["KeyboardChars", "Printout"],
    FontSize->10],
  
  Cell[StyleData["KeyboardChars", "EnhancedPrintout"],
    FontSize->10],
  
  Cell[StyleData["KeyboardChars", "EnhancedPrintoutNonGray"],
    FontSize->10]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Emphasis Boxes and Pictures", "Section"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Box"],
    CellMargins->{{10, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    StyleMenuListing->None,
    Background->RGBColor[1, 0.6, 0.6],
    FrameBoxOptions->{BoxFrame->0.5,
    BoxMargins->True},
    GridBoxOptions->{ColumnSpacings->1}],
  
  Cell[StyleData["Box", "Printout"],
    CellMargins->{{2, 0}, {0, 8}},
    FontSize->10,
    Background->GrayLevel[0.900008]],
  
  Cell[StyleData["Box", "EnhancedPrintout"],
    CellMargins->{{2, 0}, {0, 8}},
    FontSize->10,
    Background->GrayLevel[0.900008]],
  
  Cell[StyleData["Box", "EnhancedPrintoutNonGray"],
    CellMargins->{{2, 0}, {0, 8}},
    FontSize->10,
    Background->GrayLevel[1]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["DoubleBox"],
    CellMargins->{{10, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    StyleMenuListing->None,
    Background->RGBColor[1, 0.6, 0.6],
    FrameBoxOptions->{BoxFrame->0.5,
    BoxMargins->True},
    GridBoxOptions->{ColumnSpacings->2,
    RowAlignments->Top}],
  
  Cell[StyleData["DoubleBox", "Printout"],
    CellMargins->{{2, 0}, {0, 8}},
    FontSize->10,
    Background->GrayLevel[0.900008]],
  
  Cell[StyleData["DoubleBox", "EnhancedPrintout"],
    CellMargins->{{2, 0}, {0, 8}},
    FontSize->10,
    Background->GrayLevel[0.900008]],
  
  Cell[StyleData["DoubleBox", "EnhancedPrintoutNonGray"],
    CellMargins->{{2, 0}, {0, 8}},
    FontSize->10,
    Background->GrayLevel[1]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["1ColumnBox"],
    CellMargins->{{10, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    LineIndent->0,
    StyleMenuListing->None,
    Background->RGBColor[1, 0.6, 0.6],
    FrameBoxOptions->{BoxFrame->0.5,
    BoxMargins->True},
    GridBoxOptions->{ColumnSpacings->1}],
  
  Cell[StyleData["1ColumnBox", "Printout"],
    CellMargins->{{2, 0}, {0, 8}},
    FontSize->10,
    Background->GrayLevel[0.900008]],
  
  Cell[StyleData["1ColumnBox", "EnhancedPrintout"],
    CellMargins->{{2, 0}, {0, 8}},
    FontSize->10,
    Background->GrayLevel[0.900008]],
  
  Cell[StyleData["1ColumnBox", "EnhancedPrintoutNonGray"],
    CellMargins->{{2, 0}, {0, 8}},
    FontSize->10,
    Background->GrayLevel[1]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["2ColumnBox"],
    CellMargins->{{10, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    LineIndent->0,
    StyleMenuListing->None,
    Background->RGBColor[1, 0.6, 0.6],
    FrameBoxOptions->{BoxFrame->0.5,
    BoxMargins->True},
    GridBoxOptions->{ColumnWidths->{0.31, 0.67}}],
  
  Cell[StyleData["2ColumnBox", "Printout"],
    CellMargins->{{2, 0}, {0, 8}},
    FontSize->9,
    Background->GrayLevel[0.900008]],
  
  Cell[StyleData["2ColumnBox", "EnhancedPrintout"],
    CellMargins->{{2, 0}, {0, 8}},
    FontSize->9,
    Background->GrayLevel[0.900008]],
  
  Cell[StyleData["2ColumnBox", "EnhancedPrintoutNonGray"],
    CellMargins->{{2, 0}, {0, 8}},
    FontSize->9,
    Background->GrayLevel[1]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["2ColumnEvenBox"],
    CellMargins->{{10, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    LineIndent->0,
    StyleMenuListing->None,
    Background->RGBColor[1, 0.6, 0.6],
    FrameBoxOptions->{BoxFrame->0.5,
    BoxMargins->True},
    GridBoxOptions->{ColumnWidths->0.46}],
  
  Cell[StyleData["2ColumnEvenBox", "Printout"],
    CellMargins->{{2, 0}, {0, 8}},
    FontSize->10,
    Background->GrayLevel[0.900008]],
  
  Cell[StyleData["2ColumnEvenBox", "EnhancedPrintout"],
    CellMargins->{{2, 0}, {0, 8}},
    FontSize->10,
    Background->GrayLevel[0.900008]],
  
  Cell[StyleData["2ColumnEvenBox", "EnhancedPrintoutNonGray"],
    CellMargins->{{2, 0}, {0, 8}},
    FontSize->10,
    Background->GrayLevel[1]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["2ColumnSmallBox"],
    CellMargins->{{10, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    LineIndent->0,
    StyleMenuListing->None,
    Background->RGBColor[1, 0.6, 0.6],
    FrameBoxOptions->{BoxFrame->0.5,
    BoxMargins->True},
    GridBoxOptions->{ColumnSpacings->1.5,
    ColumnWidths->0.35,
    ColumnAlignments->{Right, Left}}],
  
  Cell[StyleData["2ColumnSmallBox", "Printout"],
    CellMargins->{{2, 0}, {0, 8}},
    FontSize->10,
    Background->GrayLevel[0.900008]],
  
  Cell[StyleData["2ColumnSmallBox", "EnhancedPrintout"],
    CellMargins->{{2, 0}, {0, 8}},
    FontSize->10,
    Background->GrayLevel[0.900008]],
  
  Cell[StyleData["2ColumnSmallBox", "EnhancedPrintoutNonGray"],
    CellMargins->{{2, 0}, {0, 8}},
    FontSize->10,
    Background->GrayLevel[1]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["3ColumnBox"],
    CellMargins->{{10, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    LineIndent->0,
    StyleMenuListing->None,
    Background->RGBColor[1, 0.6, 0.6],
    FrameBoxOptions->{BoxFrame->0.5,
    BoxMargins->True},
    GridBoxOptions->{ColumnWidths->0.32}],
  
  Cell[StyleData["3ColumnBox", "Printout"],
    CellMargins->{{2, 0}, {0, 8}},
    FontSize->10,
    Background->GrayLevel[0.900008]],
  
  Cell[StyleData["3ColumnBox", "EnhancedPrintout"],
    CellMargins->{{2, 0}, {0, 8}},
    FontSize->10,
    Background->GrayLevel[0.900008]],
  
  Cell[StyleData["3ColumnBox", "EnhancedPrintoutNonGray"],
    CellMargins->{{2, 0}, {0, 8}},
    FontSize->10,
    Background->GrayLevel[1]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["3ColumnSmallBox"],
    CellMargins->{{10, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    LineIndent->0,
    StyleMenuListing->None,
    Background->RGBColor[1, 0.6, 0.6],
    FrameBoxOptions->{BoxFrame->0.5,
    BoxMargins->True},
    GridBoxOptions->{ColumnSpacings->1.5,
    ColumnWidths->0.24,
    ColumnAlignments->{Right, Center, Left}}],
  
  Cell[StyleData["3ColumnSmallBox", "Printout"],
    CellMargins->{{2, 0}, {0, 8}},
    FontSize->10,
    Background->GrayLevel[0.900008]],
  
  Cell[StyleData["3ColumnSmallBox", "EnhancedPrintout"],
    CellMargins->{{2, 0}, {0, 8}},
    FontSize->10,
    Background->GrayLevel[0.900008]],
  
  Cell[StyleData["3ColumnSmallBox", "EnhancedPrintoutNonGray"],
    CellMargins->{{2, 0}, {0, 8}},
    FontSize->10,
    Background->GrayLevel[1]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["4ColumnBox"],
    CellMargins->{{10, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    LineIndent->0,
    StyleMenuListing->None,
    Background->RGBColor[1, 0.6, 0.6],
    FrameBoxOptions->{BoxFrame->0.5,
    BoxMargins->True},
    GridBoxOptions->{ColumnWidths->{0.13, 0.35, 0.13, 0.35}}],
  
  Cell[StyleData["4ColumnBox", "Printout"],
    CellMargins->{{2, 0}, {0, 8}},
    FontSize->10,
    Background->GrayLevel[0.900008]],
  
  Cell[StyleData["4ColumnBox", "EnhancedPrintout"],
    CellMargins->{{2, 0}, {0, 8}},
    FontSize->10,
    Background->GrayLevel[0.900008]],
  
  Cell[StyleData["4ColumnBox", "EnhancedPrintoutNonGray"],
    CellMargins->{{2, 0}, {0, 8}},
    FontSize->10,
    Background->GrayLevel[1]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["5ColumnBox"],
    CellMargins->{{10, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    LineIndent->0,
    StyleMenuListing->None,
    Background->RGBColor[1, 0.6, 0.6],
    FrameBoxOptions->{BoxFrame->0.5,
    BoxMargins->True},
    GridBoxOptions->{ColumnWidths->0.202}],
  
  Cell[StyleData["5ColumnBox", "Printout"],
    CellMargins->{{2, 0}, {0, 8}},
    FontSize->9,
    Background->GrayLevel[0.900008]],
  
  Cell[StyleData["5ColumnBox", "EnhancedPrintout"],
    CellMargins->{{2, 0}, {0, 8}},
    FontSize->9,
    Background->GrayLevel[0.900008]],
  
  Cell[StyleData["5ColumnBox", "EnhancedPrintoutNonGray"],
    CellMargins->{{2, 0}, {0, 8}},
    FontSize->9,
    Background->GrayLevel[1]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["6ColumnBox"],
    CellMargins->{{10, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    LineIndent->0,
    StyleMenuListing->None,
    Background->RGBColor[1, 0.6, 0.6],
    FrameBoxOptions->{BoxFrame->0.5,
    BoxMargins->True},
    GridBoxOptions->{ColumnWidths->{0.12, 0.22, 0.12, 0.12, 0.22, 0.12}}],
  
  Cell[StyleData["6ColumnBox", "Printout"],
    CellMargins->{{2, 0}, {0, 8}},
    FontSize->10,
    Background->GrayLevel[0.900008]],
  
  Cell[StyleData["6ColumnBox", "EnhancedPrintout"],
    CellMargins->{{2, 0}, {0, 8}},
    FontSize->10,
    Background->GrayLevel[0.900008]],
  
  Cell[StyleData["6ColumnBox", "EnhancedPrintoutNonGray"],
    CellMargins->{{2, 0}, {0, 8}},
    FontSize->10,
    Background->GrayLevel[1]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["FramedBox"],
    CellFrame->0.5,
    CellMargins->{{10, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    PageBreakWithin->False,
    AutoIndent->False,
    AutoSpacing->False,
    LineIndent->0,
    FontWeight->"Plain",
    Background->RGBColor[1, 0.6, 0.6],
    GridBoxOptions->{RowSpacings->1.5,
    ColumnAlignments->{Left}}],
  
  Cell[StyleData["FramedBox", "Printout"],
    CellMargins->{{2, 4}, {0, 8}},
    FontSize->10,
    Background->GrayLevel[1]],
  
  Cell[StyleData["FramedBox", "EnhancedPrintout"],
    CellMargins->{{2, 4}, {0, 8}},
    FontFamily->"Palatino",
    FontSize->10,
    Background->GrayLevel[1]],
  
  Cell[StyleData["FramedBox", "EnhancedPrintoutNonGray"],
    CellMargins->{{2, 4}, {0, 8}},
    FontFamily->"Palatino",
    FontSize->10,
    Background->GrayLevel[1]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["DefinitionBox"],
    CellFrame->0.5,
    CellMargins->{{10, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    PageBreakWithin->False,
    AutoIndent->False,
    AutoSpacing->False,
    LineIndent->0,
    FontWeight->"Plain",
    Background->RGBColor[1, 0.6, 0.6],
    GridBoxOptions->{RowSpacings->1.5,
    ColumnSpacings->1,
    ColumnWidths->{0.4, 0.6},
    ColumnAlignments->{Left}}],
  
  Cell[StyleData["DefinitionBox", "Printout"],
    CellMargins->{{2, 4}, {0, 8}},
    FontSize->10,
    Background->GrayLevel[1]],
  
  Cell[StyleData["DefinitionBox", "EnhancedPrintout"],
    CellMargins->{{2, 4}, {0, 8}},
    FontFamily->"Palatino",
    FontSize->10,
    Background->GrayLevel[1]],
  
  Cell[StyleData["DefinitionBox", "EnhancedPrintoutNonGray"],
    CellMargins->{{2, 4}, {0, 8}},
    FontFamily->"Palatino",
    FontSize->10,
    Background->GrayLevel[1]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["DefinitionBox3Col"],
    CellFrame->0.5,
    CellMargins->{{10, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    PageBreakWithin->False,
    AutoIndent->False,
    AutoSpacing->False,
    LineIndent->0,
    FontWeight->"Plain",
    Background->RGBColor[1, 0.6, 0.6],
    GridBoxOptions->{RowSpacings->1.5,
    ColumnSpacings->1,
    ColumnWidths->{0.35, 0.2, 0.45},
    ColumnAlignments->{Left}}],
  
  Cell[StyleData["DefinitionBox3Col", "Printout"],
    CellMargins->{{2, 4}, {0, 8}},
    FontSize->10,
    Background->GrayLevel[1]],
  
  Cell[StyleData["DefinitionBox3Col", "EnhancedPrintout"],
    CellMargins->{{2, 4}, {0, 8}},
    FontFamily->"Palatino",
    FontSize->10,
    Background->GrayLevel[1]],
  
  Cell[StyleData["DefinitionBox3Col", "EnhancedPrintoutNonGray"],
    CellMargins->{{2, 4}, {0, 8}},
    FontFamily->"Palatino",
    FontSize->10,
    Background->GrayLevel[1]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["DefinitionBox4Col"],
    CellFrame->0.5,
    CellMargins->{{10, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    PageBreakWithin->False,
    AutoIndent->False,
    AutoSpacing->False,
    LineIndent->0,
    FontWeight->"Plain",
    Background->RGBColor[1, 0.6, 0.6],
    GridBoxOptions->{RowSpacings->1.5,
    ColumnSpacings->1,
    ColumnWidths->{0.15, 0.35, 0.15, 0.35},
    ColumnAlignments->{Left}}],
  
  Cell[StyleData["DefinitionBox4Col", "Printout"],
    CellMargins->{{2, 4}, {0, 8}},
    FontSize->10,
    Background->GrayLevel[1]],
  
  Cell[StyleData["DefinitionBox4Col", "EnhancedPrintout"],
    CellMargins->{{2, 4}, {0, 8}},
    FontFamily->"Palatino",
    FontSize->10,
    Background->GrayLevel[1]],
  
  Cell[StyleData["DefinitionBox4Col", "EnhancedPrintoutNonGray"],
    CellMargins->{{2, 4}, {0, 8}},
    FontFamily->"Palatino",
    FontSize->10,
    Background->GrayLevel[1]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["DefinitionBox5Col"],
    CellFrame->0.5,
    CellMargins->{{10, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    PageBreakWithin->False,
    AutoIndent->False,
    AutoSpacing->False,
    LineIndent->0,
    FontWeight->"Plain",
    Background->RGBColor[1, 0.6, 0.6],
    GridBoxOptions->{RowSpacings->1.5,
    ColumnSpacings->1,
    ColumnWidths->0.2,
    ColumnAlignments->{Left}}],
  
  Cell[StyleData["DefinitionBox5Col", "Printout"],
    CellMargins->{{2, 4}, {0, 8}},
    FontSize->10,
    Background->GrayLevel[1]],
  
  Cell[StyleData["DefinitionBox5Col", "EnhancedPrintout"],
    CellMargins->{{2, 4}, {0, 8}},
    FontFamily->"Palatino",
    FontSize->10,
    Background->GrayLevel[1]],
  
  Cell[StyleData["DefinitionBox5Col", "EnhancedPrintoutNonGray"],
    CellMargins->{{2, 4}, {0, 8}},
    FontFamily->"Palatino",
    FontSize->10,
    Background->GrayLevel[1]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["DefinitionBox6Col"],
    CellFrame->0.5,
    CellMargins->{{10, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    PageBreakWithin->False,
    AutoIndent->False,
    AutoSpacing->False,
    LineIndent->0,
    FontWeight->"Plain",
    Background->RGBColor[1, 0.6, 0.6],
    GridBoxOptions->{RowSpacings->1.5,
    ColumnSpacings->1,
    ColumnWidths->{0.13, 0.24, 0.13, 0.13, 0.24, 0.13},
    ColumnAlignments->{Left}}],
  
  Cell[StyleData["DefinitionBox6Col", "Printout"],
    CellMargins->{{2, 4}, {0, 8}},
    FontSize->10,
    Background->GrayLevel[1]],
  
  Cell[StyleData["DefinitionBox6Col", "EnhancedPrintout"],
    CellMargins->{{2, 4}, {0, 8}},
    FontFamily->"Palatino",
    FontSize->10,
    Background->GrayLevel[1]],
  
  Cell[StyleData["DefinitionBox6Col", "EnhancedPrintoutNonGray"],
    CellMargins->{{2, 4}, {0, 8}},
    FontFamily->"Palatino",
    FontSize->10,
    Background->GrayLevel[1]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["TopBox"],
    CellFrame->{{0.5, 0.5}, {0, 0.5}},
    CellMargins->{{11, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    PageBreakBelow->False,
    AutoIndent->False,
    AutoSpacing->False,
    LineIndent->0,
    StyleMenuListing->None,
    FontWeight->"Plain",
    Background->RGBColor[1, 0.6, 0.6],
    GridBoxOptions->{RowSpacings->1.5,
    ColumnSpacings->1,
    ColumnWidths->{0.31, 0.62},
    ColumnAlignments->{Left}}],
  
  Cell[StyleData["TopBox", "Printout"],
    CellMargins->{{2, 0}, {0, 8}},
    Background->GrayLevel[1]],
  
  Cell[StyleData["TopBox", "EnhancedPrintout"],
    CellMargins->{{2, 0}, {0, 8}},
    FontFamily->"Palatino",
    Background->GrayLevel[1]],
  
  Cell[StyleData["TopBox", "EnhancedPrintoutNonGray"],
    CellMargins->{{2, 0}, {0, 8}},
    FontFamily->"Palatino",
    Background->GrayLevel[1]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["MiddleBox"],
    CellFrame->{{0.5, 0.5}, {0, 0}},
    CellMargins->{{11, 4}, {0, -7}},
    CellHorizontalScrolling->True,
    PageBreakAbove->False,
    PageBreakBelow->False,
    AutoIndent->False,
    AutoSpacing->False,
    LineIndent->0,
    StyleMenuListing->None,
    FontWeight->"Plain",
    Background->RGBColor[1, 0.6, 0.6],
    GridBoxOptions->{RowSpacings->1.5,
    ColumnSpacings->1,
    ColumnWidths->{0.31, 0.62},
    ColumnAlignments->{Left}}],
  
  Cell[StyleData["MiddleBox", "Printout"],
    CellMargins->{{2, 0}, {0, 2}},
    Background->GrayLevel[1]],
  
  Cell[StyleData["MiddleBox", "EnhancedPrintout"],
    CellMargins->{{2, 0}, {0, 4}},
    FontFamily->"Palatino",
    Background->GrayLevel[1]],
  
  Cell[StyleData["MiddleBox", "EnhancedPrintoutNonGray"],
    CellMargins->{{2, 0}, {0, 4}},
    FontFamily->"Palatino",
    Background->GrayLevel[1]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["BottomBox"],
    CellFrame->{{0.5, 0.5}, {0.5, 0}},
    CellMargins->{{11, 4}, {0, -7}},
    CellHorizontalScrolling->True,
    PageBreakAbove->False,
    PageBreakBelow->False,
    AutoIndent->False,
    AutoSpacing->False,
    LineIndent->0,
    StyleMenuListing->None,
    FontWeight->"Plain",
    Background->RGBColor[1, 0.6, 0.6],
    GridBoxOptions->{RowSpacings->1.5,
    ColumnSpacings->1,
    ColumnWidths->{0.31, 0.62},
    ColumnAlignments->{Left}}],
  
  Cell[StyleData["BottomBox", "Printout"],
    CellMargins->{{2, 0}, {0, -5}},
    FontSize->10,
    Background->GrayLevel[1],
    GridBoxOptions->{RowMinHeight->2.2}],
  
  Cell[StyleData["BottomBox", "EnhancedPrintout"],
    CellMargins->{{2, 0}, {0, -5}},
    FontFamily->"Palatino",
    FontSize->10,
    Background->GrayLevel[1],
    GridBoxOptions->{RowMinHeight->2.2}],
  
  Cell[StyleData["BottomBox", "EnhancedPrintoutNonGray"],
    CellMargins->{{2, 0}, {0, -5}},
    FontFamily->"Palatino",
    FontSize->10,
    Background->GrayLevel[1],
    GridBoxOptions->{RowMinHeight->2.2}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["TopSpanBox"],
    CellFrame->{{0.5, 0.5}, {0, 0.5}},
    CellMargins->{{11, 4}, {-2, 8}},
    CellHorizontalScrolling->True,
    PageBreakBelow->False,
    AutoIndent->False,
    AutoSpacing->False,
    LineIndent->0,
    StyleMenuListing->None,
    FontWeight->"Plain",
    Background->RGBColor[1, 0.6, 0.6],
    GridBoxOptions->{RowSpacings->1.5,
    ColumnSpacings->1,
    ColumnWidths->{0.9, 0.03},
    ColumnAlignments->{Left}}],
  
  Cell[StyleData["TopSpanBox", "Printout"],
    CellMargins->{{2, 0}, {-2, 8}},
    FontSize->10,
    Background->GrayLevel[1]],
  
  Cell[StyleData["TopSpanBox", "EnhancedPrintout"],
    CellMargins->{{2, 0}, {-4, 8}},
    FontFamily->"Palatino",
    FontSize->10,
    Background->GrayLevel[1]],
  
  Cell[StyleData["TopSpanBox", "EnhancedPrintoutNonGray"],
    CellMargins->{{2, 0}, {-4, 8}},
    FontFamily->"Palatino",
    FontSize->10,
    Background->GrayLevel[1]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["MiddleSpanBox"],
    CellFrame->{{0.5, 0.5}, {0, 0}},
    CellMargins->{{11, 4}, {0, 0}},
    CellHorizontalScrolling->True,
    PageBreakAbove->False,
    PageBreakBelow->False,
    AutoIndent->False,
    AutoSpacing->False,
    LineIndent->0,
    StyleMenuListing->None,
    FontWeight->"Plain",
    Background->RGBColor[1, 0.6, 0.6],
    GridBoxOptions->{RowSpacings->1.5,
    ColumnSpacings->1,
    ColumnWidths->{0.9, 0.03},
    ColumnAlignments->{Left}}],
  
  Cell[StyleData["MiddleSpanBox", "Printout"],
    CellMargins->{{2, 0}, {-5, 0}},
    FontSize->10,
    Background->GrayLevel[1],
    GridBoxOptions->{RowMinHeight->1.8}],
  
  Cell[StyleData["MiddleSpanBox", "EnhancedPrintout"],
    CellMargins->{{2, 0}, {-7, 0}},
    FontFamily->"Palatino",
    FontSize->10,
    Background->GrayLevel[1],
    GridBoxOptions->{RowMinHeight->1.8}],
  
  Cell[StyleData["MiddleSpanBox", "EnhancedPrintoutNonGray"],
    CellMargins->{{2, 0}, {-7, 0}},
    FontFamily->"Palatino",
    FontSize->10,
    Background->GrayLevel[1],
    GridBoxOptions->{RowMinHeight->1.8}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Picture"],
    CellMargins->{{10, Inherited}, {4, 4}},
    CellGroupingRules->"GraphicsGrouping",
    CellHorizontalScrolling->True,
    StyleMenuListing->None],
  
  Cell[StyleData["Picture", "Printout"],
    CellMargins->{{2, Inherited}, {4, 4}},
    Magnification->0.65],
  
  Cell[StyleData["Picture", "EnhancedPrintout"],
    CellMargins->{{2, Inherited}, {4, 2}},
    Magnification->0.65],
  
  Cell[StyleData["Picture", "EnhancedPrintoutNonGray"],
    CellMargins->{{2, Inherited}, {4, 2}},
    Magnification->0.65]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["OpenCloseItemizedPicture"],
    CellMargins->{{41, 4}, {4, 4}},
    PrivateCellOptions->{"DefaultCellGroupOpen"->False},
    CellGroupingRules->"GraphicsGrouping",
    CellHorizontalScrolling->True,
    StyleMenuListing->None],
  
  Cell[StyleData["OpenCloseItemizedPicture", "Printout"],
    CellMargins->{{76, 2}, {0, 0}},
    CellElementSpacings->{"CellMinHeight"->1,
    "ClosedCellHeight"->0},
    CellOpen->False],
  
  Cell[StyleData["OpenCloseItemizedPicture", "EnhancedPrintout"],
    CellMargins->{{76, 2}, {0, 0}},
    CellElementSpacings->{"CellMinHeight"->1,
    "ClosedCellHeight"->0},
    CellOpen->False],
  
  Cell[StyleData["OpenCloseItemizedPicture", "EnhancedPrintoutNonGray"],
    CellMargins->{{76, 2}, {0, 0}},
    CellElementSpacings->{"CellMinHeight"->1,
    "ClosedCellHeight"->0},
    CellOpen->False]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["ItemizedPicture"],
    CellMargins->{{41, 4}, {4, 4}},
    CellGroupingRules->"GraphicsGrouping",
    CellHorizontalScrolling->True,
    StyleMenuListing->None],
  
  Cell[StyleData["ItemizedPicture", "Printout"],
    CellMargins->{{77, 2}, {4, -4}},
    Magnification->0.5],
  
  Cell[StyleData["ItemizedPicture", "EnhancedPrintout"],
    CellMargins->{{78, 2}, {12, -6}},
    Magnification->0.5],
  
  Cell[StyleData["ItemizedPicture", "EnhancedPrintoutNonGray"],
    CellMargins->{{75, 2}, {4, -6}},
    Magnification->0.5]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["PictureGroup"],
    CellMargins->{{41, 4}, {0, 4}},
    CellGroupingRules->"GraphicsGrouping",
    CellHorizontalScrolling->True,
    StyleMenuListing->None],
  
  Cell[StyleData["PictureGroup", "Printout"],
    CellMargins->{{76, 2}, {0, 0}},
    CellElementSpacings->{"CellMinHeight"->1,
    "ClosedCellHeight"->0},
    CellOpen->False],
  
  Cell[StyleData["PictureGroup", "EnhancedPrintout"],
    CellMargins->{{76, 2}, {0, 0}},
    CellElementSpacings->{"CellMinHeight"->1,
    "ClosedCellHeight"->0},
    CellOpen->False],
  
  Cell[StyleData["PictureGroup", "EnhancedPrintoutNonGray"],
    CellMargins->{{76, 2}, {0, 0}},
    CellElementSpacings->{"CellMinHeight"->1,
    "ClosedCellHeight"->0},
    CellOpen->False]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Sound"],
    ShowCellBracket->True,
    CellMargins->{{10, Inherited}, {0, 8}},
    StyleMenuListing->None],
  
  Cell[StyleData["Sound", "Printout"],
    CellMargins->{{2, 0}, {0, 8}},
    FontSize->10],
  
  Cell[StyleData["Sound", "EnhancedPrintout"],
    CellMargins->{{2, 0}, {0, 8}},
    FontSize->10],
  
  Cell[StyleData["Sound", "EnhancedPrintoutNonGray"],
    CellMargins->{{2, 0}, {0, 8}},
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Caption"],
    CellMargins->{{10, 4}, {0, 3}},
    PageBreakAbove->False,
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->9],
  
  Cell[StyleData["Caption", "Printout"],
    CellMargins->{{2, 4}, {2, 0}},
    FontSize->7],
  
  Cell[StyleData["Caption", "EnhancedPrintout"],
    CellMargins->{{5, 4}, {2, -2}},
    FontFamily->"Futura",
    FontSize->7],
  
  Cell[StyleData["Caption", "EnhancedPrintoutNonGray"],
    CellMargins->{{5, 4}, {2, -2}},
    FontFamily->"Futura",
    FontSize->7]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Tables", "Section"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["2ColumnTable"],
    CellMargins->{{10, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    LineIndent->0,
    StyleMenuListing->None,
    GridBoxOptions->{ColumnWidths->{0.34, 0.64},
    ColumnAlignments->{Left}}],
  
  Cell[StyleData["2ColumnTable", "Printout"],
    CellMargins->{{2, 0}, {0, 8}},
    FontSize->9],
  
  Cell[StyleData["2ColumnTable", "EnhancedPrintout"],
    CellMargins->{{2, 0}, {0, 8}},
    FontSize->9],
  
  Cell[StyleData["2ColumnTable", "EnhancedPrintoutNonGray"],
    CellMargins->{{2, 0}, {0, 8}},
    FontSize->9]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["2ColumnEvenTable"],
    CellMargins->{{10, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    LineIndent->0,
    StyleMenuListing->None,
    GridBoxOptions->{ColumnWidths->0.49,
    ColumnAlignments->{Left}}],
  
  Cell[StyleData["2ColumnEvenTable", "Printout"],
    CellMargins->{{2, 0}, {0, 8}},
    FontSize->9],
  
  Cell[StyleData["2ColumnEvenTable", "EnhancedPrintout"],
    CellMargins->{{2, 0}, {0, 8}},
    FontSize->9],
  
  Cell[StyleData["2ColumnEvenTable", "EnhancedPrintoutNonGray"],
    CellMargins->{{2, 0}, {0, 8}},
    FontSize->9]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["3ColumnTable"],
    CellMargins->{{10, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    LineIndent->0,
    StyleMenuListing->None,
    GridBoxOptions->{ColumnWidths->{0.28, 0.28, 0.43},
    ColumnAlignments->{Left}}],
  
  Cell[StyleData["3ColumnTable", "Printout"],
    CellMargins->{{2, 0}, {0, 8}},
    FontSize->9],
  
  Cell[StyleData["3ColumnTable", "EnhancedPrintout"],
    CellMargins->{{2, 0}, {0, 8}},
    FontSize->9],
  
  Cell[StyleData["3ColumnTable", "EnhancedPrintoutNonGray"],
    CellMargins->{{2, 0}, {0, 8}},
    FontSize->9]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Formulas and Programming", "Section"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["InlineFormula"],
    CellMargins->{{10, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    "TwoByteSyntaxCharacterAutoReplacement"->True,
    HyphenationOptions->{"HyphenationCharacter"->"\[Continuation]"},
    LanguageCategory->"Formula",
    ScriptLevel->1,
    SingleLetterItalics->True,
    SpanMaxSize->Infinity,
    StyleMenuListing->None,
    GridBoxOptions->{ColumnWidths->Automatic}],
  
  Cell[StyleData["InlineFormula", "Printout"],
    CellMargins->{{2, 0}, {0, 8}},
    FontSize->10],
  
  Cell[StyleData["InlineFormula", "EnhancedPrintout"],
    CellMargins->{{2, 0}, {0, 8}},
    FontSize->10],
  
  Cell[StyleData["InlineFormula", "EnhancedPrintoutNonGray"],
    CellMargins->{{2, 0}, {0, 8}},
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["InlineOutput"],
    CellMargins->{{10, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    "TwoByteSyntaxCharacterAutoReplacement"->True,
    HyphenationOptions->{"HyphenationCharacter"->"\[Continuation]"},
    LanguageCategory->None,
    StyleMenuListing->None,
    FontFamily->"Courier"],
  
  Cell[StyleData["InlineOutput", "Printout"],
    CellMargins->{{2, 0}, {0, 8}},
    FontSize->9.5],
  
  Cell[StyleData["InlineOutput", "EnhancedPrintout"],
    CellMargins->{{2, 0}, {0, 8}},
    FontSize->9.5],
  
  Cell[StyleData["InlineOutput", "EnhancedPrintoutNonGray"],
    CellMargins->{{2, 0}, {0, 8}},
    FontSize->9.5]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["DisplayFormula"],
    CellMargins->{{42, Inherited}, {Inherited, 10}},
    CellHorizontalScrolling->True,
    "TwoByteSyntaxCharacterAutoReplacement"->True,
    HyphenationOptions->{"HyphenationCharacter"->"\[Continuation]"},
    LanguageCategory->"Formula",
    ScriptLevel->0,
    SingleLetterItalics->True,
    SpanMaxSize->Infinity,
    StyleMenuListing->None,
    UnderoverscriptBoxOptions->{LimitsPositioning->True},
    GridBoxOptions->{ColumnWidths->Automatic}],
  
  Cell[StyleData["DisplayFormula", "Printout"]],
  
  Cell[StyleData["DisplayFormula", "EnhancedPrintout"],
    FontFamily->"Palatino"],
  
  Cell[StyleData["DisplayFormula", "EnhancedPrintoutNonGray"],
    FontFamily->"Palatino"]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["DisplayMath"],
    CellMargins->{{42, 10}, {7, 7}},
    Evaluatable->False,
    CellGroupingRules->"InputGrouping",
    CellHorizontalScrolling->True,
    PageBreakWithin->False,
    GroupPageBreakWithin->False,
    DefaultFormatType->DefaultInputFormatType,
    "TwoByteSyntaxCharacterAutoReplacement"->True,
    HyphenationOptions->{"HyphenationCharacter"->"\[Continuation]"},
    AutoItalicWords->{},
    LanguageCategory->"Formula",
    FormatType->InputForm,
    ShowStringCharacters->True,
    NumberMarks->True,
    CounterIncrements->"Input"],
  
  Cell[StyleData["DisplayMath", "Printout"],
    CellMargins->{{39, 0}, {6, 6}},
    FontSize->9],
  
  Cell[StyleData["DisplayMath", "EnhancedPrintout"],
    CellMargins->{{39, 0}, {4, 6}},
    FontFamily->"WRICourier",
    FontSize->9],
  
  Cell[StyleData["DisplayMath", "EnhancedPrintoutNonGray"],
    CellMargins->{{39, 0}, {4, 6}},
    FontFamily->"WRICourier",
    FontSize->9]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["NumberedEquation"],
    CellMargins->{{45, 10}, {7, 7}},
    CellFrameLabels->{{None, Cell[ 
            TextData[ {"(", 
              CounterBox[ "NumberedEquation"], ")"}]]}, {None, None}},
    DefaultFormatType->DefaultInputFormatType,
    "TwoByteSyntaxCharacterAutoReplacement"->True,
    LanguageCategory->"Formula",
    CounterIncrements->"NumberedEquation",
    FormatTypeAutoConvert->False],
  
  Cell[StyleData["NumberedEquation", "Printout"],
    CellMargins->{{39, 55}, {0, 10}},
    FontSize->10],
  
  Cell[StyleData["NumberedEquation", "EnhancedPrintout"],
    CellMargins->{{39, 55}, {0, 10}},
    FontFamily->"Palatino",
    FontSize->10],
  
  Cell[StyleData["NumberedEquation", "EnhancedPrintoutNonGray"],
    CellMargins->{{39, 55}, {0, 10}},
    FontFamily->"Palatino",
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["EquationNumber"],
    LineSpacing->{1.83, 0},
    LanguageCategory->"Formula"],
  
  Cell[StyleData["EquationNumber", "Printout"],
    LineSpacing->{1.7, 0}],
  
  Cell[StyleData["EquationNumber", "EnhancedPrintout"],
    LineSpacing->{1.7, 0},
    FontFamily->"Palatino"],
  
  Cell[StyleData["EquationNumber", "EnhancedPrintoutNonGray"],
    LineSpacing->{1.7, 0},
    FontFamily->"Palatino"]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Program"],
    CellMargins->{{16, Inherited}, {Inherited, 10}},
    CellHorizontalScrolling->True,
    ShowSpecialCharacters->Automatic,
    LanguageCategory->"Formula",
    FontFamily->"Courier"],
  
  Cell[StyleData["Program", "Printout"],
    CellMargins->{{42, 30}, {Inherited, 4}},
    FontSize->9.5],
  
  Cell[StyleData["Program", "EnhancedPrintout"],
    CellMargins->{{42, 30}, {Inherited, 4}},
    FontFamily->"WRICourier",
    FontSize->9.5],
  
  Cell[StyleData["Program", "EnhancedPrintoutNonGray"],
    CellMargins->{{42, 30}, {Inherited, 4}},
    FontFamily->"WRICourier",
    FontSize->9.5]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Unique Help Browser Styles", "Section"],
  
  Cell[CellGroupData[{
  
  Cell["\<\
Standard Styles
\
\>", "Subsection"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["InspectorLevel1"],
    ShowGroupOpenCloseIcon->True,
    CellMargins->{{12, 10}, {2, 7}},
    CellGroupingRules->{"SectionGrouping", 60},
    HyphenationOptions->{"HyphenationCharacter"->"-"},
    ParagraphIndent->-38,
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->16,
    FontWeight->"Bold"],
  
  Cell[StyleData["InspectorLevel1", "Brackets"],
    HyphenationOptions->{"HyphenationCharacter"->"-"}],
  
  Cell[StyleData["InspectorLevel1", "SlideShow"],
    HyphenationOptions->{"HyphenationCharacter"->"-"}],
  
  Cell[StyleData["InspectorLevel1", "Printout"],
    HyphenationOptions->{"HyphenationCharacter"->"-"},
    FontSize->14]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["InspectorLevel2"],
    ShowGroupOpenCloseIcon->True,
    CellMargins->{{10, 4}, {0, 14}},
    HyphenationOptions->{"HyphenationCharacter"->"-"},
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->14,
    FontWeight->"Bold"],
  
  Cell[StyleData["InspectorLevel2", "Brackets"],
    ShowGroupOpenCloseIcon->True,
    CellMargins->{{48, 10}, {2, 12}},
    CellGroupingRules->{"SectionGrouping", 70},
    HyphenationOptions->{"HyphenationCharacter"->"-"},
    ParagraphIndent->-27,
    FontFamily->"Helvetica",
    FontSize->14,
    FontWeight->"Bold"],
  
  Cell[StyleData["InspectorLevel2", "SlideShow"],
    ShowGroupOpenCloseIcon->True,
    CellMargins->{{48, 10}, {2, 12}},
    CellGroupingRules->{"SectionGrouping", 70},
    HyphenationOptions->{"HyphenationCharacter"->"-"},
    ParagraphIndent->-27,
    FontFamily->"Helvetica",
    FontSize->14,
    FontWeight->"Bold"],
  
  Cell[StyleData["InspectorLevel2", "Printout"],
    HyphenationOptions->{"HyphenationCharacter"->"-"},
    FontSize->12]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["ObjectName"],
    CellMargins->{{10, 4}, {1, 10}},
    CellGroupingRules->{"SectionGrouping", 50},
    HyphenationOptions->{"HyphenationCharacter"->"-"},
    StyleMenuListing->None,
    FontFamily->"Courier",
    FontSize->16,
    FontWeight->"Bold"],
  
  Cell[StyleData["ObjectName", "Brackets"],
    CellMargins->{{72, 4}, {1, 14}},
    HyphenationOptions->{"HyphenationCharacter"->"-"},
    StyleMenuListing->None,
    FontFamily->"Courier",
    FontSize->12,
    FontWeight->"Bold"],
  
  Cell[StyleData["ObjectName", "SlideShow"],
    CellMargins->{{72, 4}, {1, 14}},
    CellGroupingRules->{"SectionGrouping", 90},
    HyphenationOptions->{"HyphenationCharacter"->"-"},
    StyleMenuListing->None,
    FontFamily->"Courier",
    FontSize->12,
    FontWeight->"Bold"],
  
  Cell[StyleData["ObjectName", "Printout"],
    CellMargins->{{2, 0}, {1, 10}},
    HyphenationOptions->{"HyphenationCharacter"->"-"},
    FontSize->12]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["SubObjectNameClosed"],
    ShowGroupOpenCloseIcon->True,
    CellMargins->{{10, 4}, {1, 10}},
    PrivateCellOptions->{"DefaultCellGroupOpen"->False},
    CellGroupingRules->{"SectionGrouping", 90},
    HyphenationOptions->{"HyphenationCharacter"->"-"},
    StyleMenuListing->None,
    FontFamily->"Courier",
    FontSize->14,
    FontWeight->"Bold"],
  
  Cell[StyleData["SubObjectNameClosed", "Brackets"],
    CellMargins->{{72, 4}, {1, 14}},
    HyphenationOptions->{"HyphenationCharacter"->"-"},
    StyleMenuListing->None,
    FontFamily->"Courier",
    FontSize->12,
    FontWeight->"Bold"],
  
  Cell[StyleData["SubObjectNameClosed", "SlideShow"],
    CellMargins->{{72, 4}, {1, 14}},
    HyphenationOptions->{"HyphenationCharacter"->"-"},
    StyleMenuListing->None,
    FontFamily->"Courier",
    FontSize->12,
    FontWeight->"Bold"],
  
  Cell[StyleData["SubObjectNameClosed", "Printout"],
    CellMargins->{{2, 0}, {1, 10}},
    HyphenationOptions->{"HyphenationCharacter"->"-"},
    FontSize->12]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["SubObjectName"],
    ShowGroupOpenCloseIcon->True,
    CellMargins->{{24, 4}, {1, 10}},
    HyphenationOptions->{"HyphenationCharacter"->"-"},
    StyleMenuListing->None,
    FontFamily->"Courier",
    FontSize->16,
    FontWeight->"Bold"],
  
  Cell[StyleData["SubObjectName", "Brackets"],
    ShowGroupOpenCloseIcon->True,
    CellMargins->{{90, 4}, {1, 14}},
    HyphenationOptions->{"HyphenationCharacter"->"-"},
    FontFamily->"Courier",
    FontSize->12],
  
  Cell[StyleData["SubObjectName", "SlideShow"],
    ShowGroupOpenCloseIcon->True,
    CellMargins->{{90, 4}, {1, 14}},
    HyphenationOptions->{"HyphenationCharacter"->"-"},
    FontFamily->"Courier",
    FontSize->12],
  
  Cell[StyleData["SubObjectName", "Printout"],
    CellMargins->{{2, 0}, {1, 10}},
    HyphenationOptions->{"HyphenationCharacter"->"-"},
    FontFamily->"Courier",
    FontSize->12]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["GroupObjectName"],
    ShowGroupOpenCloseIcon->True,
    CellMargins->{{10, 4}, {0, 14}},
    HyphenationOptions->{"HyphenationCharacter"->"-"},
    StyleMenuListing->None,
    FontFamily->"Courier",
    FontSize->16,
    FontWeight->"Bold"],
  
  Cell[StyleData["GroupObjectName", "Brackets"],
    ShowGroupOpenCloseIcon->True,
    CellMargins->{{72, 10}, {2, 12}},
    CellGroupingRules->{"SectionGrouping", 70},
    HyphenationOptions->{"HyphenationCharacter"->"-"},
    ParagraphIndent->-27,
    CounterIncrements->"Outline2",
    FontFamily->"Courier",
    FontSize->12,
    FontWeight->"Bold"],
  
  Cell[StyleData["GroupObjectName", "SlideShow"],
    ShowGroupOpenCloseIcon->True,
    CellMargins->{{72, 10}, {2, 12}},
    CellGroupingRules->{"SectionGrouping", 70},
    HyphenationOptions->{"HyphenationCharacter"->"-"},
    ParagraphIndent->-27,
    CounterIncrements->"Outline2",
    FontFamily->"Courier",
    FontSize->12,
    FontWeight->"Bold"],
  
  Cell[StyleData["GroupObjectName", "Printout"],
    HyphenationOptions->{"HyphenationCharacter"->"-"},
    FontSize->14]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["GroupObjectNameClosed"],
    ShowGroupOpenCloseIcon->True,
    CellMargins->{{10, 4}, {0, 14}},
    PrivateCellOptions->{"DefaultCellGroupOpen"->False},
    CellGroupingRules->{"SectionGrouping", 80},
    HyphenationOptions->{"HyphenationCharacter"->"-"},
    StyleMenuListing->None,
    FontFamily->"Courier",
    FontSize->16,
    FontWeight->"Bold"],
  
  Cell[StyleData["GroupObjectNameClosed", "Brackets"],
    ShowGroupOpenCloseIcon->True,
    CellMargins->{{72, 10}, {2, 12}},
    CellGroupingRules->{"SectionGrouping", 70},
    HyphenationOptions->{"HyphenationCharacter"->"-"},
    ParagraphIndent->-27,
    CounterIncrements->"Outline2",
    FontFamily->"Courier",
    FontSize->12,
    FontWeight->"Bold"],
  
  Cell[StyleData["GroupObjectNameClosed", "SlideShow"],
    ShowGroupOpenCloseIcon->True,
    CellMargins->{{72, 10}, {2, 12}},
    CellGroupingRules->{"SectionGrouping", 70},
    HyphenationOptions->{"HyphenationCharacter"->"-"},
    ParagraphIndent->-27,
    CounterIncrements->"Outline2",
    FontFamily->"Courier",
    FontSize->12,
    FontWeight->"Bold"],
  
  Cell[StyleData["GroupObjectNameClosed", "Printout"],
    HyphenationOptions->{"HyphenationCharacter"->"-"},
    FontSize->14]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["ObjectNameWarningMessages"],
    CellMargins->{{10, 4}, {1, 10}},
    CellGroupingRules->{"SectionGrouping", 65},
    HyphenationOptions->{"HyphenationCharacter"->"-"},
    StyleMenuListing->None,
    FontFamily->"Courier",
    FontSize->16,
    FontWeight->"Bold"],
  
  Cell[StyleData["ObjectNameWarningMessages", "Brackets"],
    CellMargins->{{10, 4}, {1, 10}},
    CellGroupingRules->{"SectionGrouping", 65},
    HyphenationOptions->{"HyphenationCharacter"->"-"},
    FontFamily->"Courier",
    FontSize->16,
    FontWeight->"Bold"],
  
  Cell[StyleData["ObjectNameWarningMessages", "SlideShow"],
    CellMargins->{{10, 4}, {1, 10}},
    CellGroupingRules->{"SectionGrouping", 65},
    HyphenationOptions->{"HyphenationCharacter"->"-"},
    FontFamily->"Courier",
    FontSize->16,
    FontWeight->"Bold"],
  
  Cell[StyleData["ObjectNameWarningMessages", "Printout"],
    CellMargins->{{2, 0}, {1, 10}},
    HyphenationOptions->{"HyphenationCharacter"->"-"},
    FontSize->12]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Command"],
    CellMargins->{{10, 4}, {0, 14}},
    HyphenationOptions->{"HyphenationCharacter"->"-"},
    CounterIncrements->"Section",
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->16,
    FontWeight->"Bold"],
  
  Cell[StyleData["Command", "Printout"],
    CellMargins->{{2, 0}, {0, 14}},
    PageBreakBelow->False,
    HyphenationOptions->{"HyphenationCharacter"->"-"},
    FontSize->14]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["CharacterName"],
    CellFrame->{{0, 0}, {0.5, 0.5}},
    CellMargins->{{10, 4}, {0, 4}},
    CellFrameMargins->4,
    HyphenationOptions->{"HyphenationCharacter"->"-"},
    StyleMenuListing->None],
  
  Cell[StyleData["CharacterName", "Brackets"],
    CellMargins->{{72, 4}, {1, 14}},
    CellGroupingRules->{"SectionGrouping", 90},
    HyphenationOptions->{"HyphenationCharacter"->"-"},
    StyleMenuListing->None,
    FontFamily->"Courier",
    FontSize->12,
    FontWeight->"Bold"],
  
  Cell[StyleData["CharacterName", "SlideShow"],
    CellMargins->{{72, 4}, {1, 14}},
    CellGroupingRules->{"SectionGrouping", 90},
    HyphenationOptions->{"HyphenationCharacter"->"-"},
    StyleMenuListing->None,
    FontFamily->"Courier",
    FontSize->12,
    FontWeight->"Bold"],
  
  Cell[StyleData["CharacterName", "Printout"],
    CellMargins->{{2, 0}, {0, 4}},
    HyphenationOptions->{"HyphenationCharacter"->"-"},
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Usage"],
    CellFrame->{{0, 0}, {0.5, 0.5}},
    CellMargins->{{10, 4}, {0, 4}},
    CellFrameMargins->5,
    Hyphenation->True,
    HyphenationOptions->{"HyphenationCharacter"->"-"},
    ParagraphSpacing->{0, 6},
    ParagraphIndent->-10,
    StyleMenuListing->None],
  
  Cell[StyleData["Usage", "Brackets"],
    CellFrame->{{0, 0}, {0.5, 0.5}},
    CellMargins->{{72, 4}, {0, 4}},
    CellFrameMargins->5,
    HyphenationOptions->{"HyphenationCharacter"->"-"},
    ParagraphSpacing->{0, 6},
    ParagraphIndent->-10,
    StyleMenuListing->None],
  
  Cell[StyleData["Usage", "SlideShow"],
    CellFrame->{{0, 0}, {0.5, 0.5}},
    CellMargins->{{72, 4}, {0, 4}},
    CellFrameMargins->5,
    HyphenationOptions->{"HyphenationCharacter"->"-"},
    ParagraphSpacing->{0, 6},
    ParagraphIndent->-10,
    StyleMenuListing->None],
  
  Cell[StyleData["Usage", "Printout"],
    CellMargins->{{2, 0}, {0, 4}},
    HyphenationOptions->{"HyphenationCharacter"->"-"},
    StyleMenuListing->None,
    FontSize->10,
    FontWeight->"Plain"]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["ErrorMessage"],
    CellFrame->{{0, 0}, {0.5, 0.5}},
    ShowCellBracket->True,
    CellMargins->{{10, 4}, {0, 4}},
    CellGroupingRules->"OutputGrouping",
    PageBreakWithin->False,
    GroupPageBreakWithin->False,
    GeneratedCell->True,
    CellAutoOverwrite->True,
    ShowCellLabel->False,
    CellLabelMargins->{{14, Inherited}, {Inherited, Inherited}},
    CellFrameMargins->5,
    DefaultFormatType->DefaultOutputFormatType,
    HyphenationOptions->{"HyphenationCharacter"->"-"},
    FormatType->InputForm,
    StyleMenuListing->None,
    FontColor->RGBColor[0, 0, 1]],
  
  Cell[StyleData["ErrorMessage", "Brackets"],
    CellMargins->{{72, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    HyphenationOptions->{"HyphenationCharacter"->"-"},
    StyleMenuListing->None],
  
  Cell[StyleData["ErrorMessage", "SlideShow"],
    CellMargins->{{72, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    HyphenationOptions->{"HyphenationCharacter"->"-"},
    StyleMenuListing->None],
  
  Cell[StyleData["ErrorMessage", "Printout"],
    HyphenationOptions->{"HyphenationCharacter"->"-"},
    FontSize->9,
    FontColor->GrayLevel[0]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Notes"],
    CellMargins->{{10, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    Hyphenation->True,
    HyphenationOptions->{"HyphenationCharacter"->"-"},
    ParagraphSpacing->{0, 6},
    ParagraphIndent->-10,
    StyleMenuListing->None,
    FontFamily->"Times"],
  
  Cell[StyleData["Notes", "Brackets"],
    CellMargins->{{72, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    HyphenationOptions->{"HyphenationCharacter"->"-"},
    ParagraphSpacing->{0, 6},
    ParagraphIndent->-10,
    StyleMenuListing->None,
    FontFamily->"Times"],
  
  Cell[StyleData["Notes", "SlideShow"],
    CellMargins->{{72, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    HyphenationOptions->{"HyphenationCharacter"->"-"},
    ParagraphSpacing->{0, 6},
    ParagraphIndent->-10,
    StyleMenuListing->None,
    FontFamily->"Times"],
  
  Cell[StyleData["Notes", "Printout"],
    CellMargins->{{2, 0}, {0, 8}},
    HyphenationOptions->{"HyphenationCharacter"->"-"},
    FontSize->9]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["NotesList"],
    CellMargins->{{20, 4}, {2, 8}},
    CellHorizontalScrolling->True,
    Hyphenation->True,
    HyphenationOptions->{"HyphenationCharacter"->"-"},
    ScriptLevel->1,
    SingleLetterItalics->True,
    StyleMenuListing->None,
    FontFamily->"Times"],
  
  Cell[StyleData["NotesList", "Brackets"],
    CellMargins->{{82, 4}, {2, 8}},
    CellHorizontalScrolling->True,
    HyphenationOptions->{"HyphenationCharacter"->"-"},
    ScriptLevel->1,
    SingleLetterItalics->True,
    StyleMenuListing->None,
    FontFamily->"Times"],
  
  Cell[StyleData["NotesList", "SlideShow"],
    CellMargins->{{82, 4}, {2, 8}},
    CellHorizontalScrolling->True,
    HyphenationOptions->{"HyphenationCharacter"->"-"},
    ScriptLevel->1,
    SingleLetterItalics->True,
    StyleMenuListing->None,
    FontFamily->"Times"],
  
  Cell[StyleData["NotesList", "Printout"],
    CellMargins->{{12, 0}, {2, 8}},
    HyphenationOptions->{"HyphenationCharacter"->"-"},
    FontSize->9]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["ExampleSection"],
    CellFrame->{{0, 0}, {0, 0.5}},
    ShowGroupOpenCloseIcon->True,
    CellMargins->{{11, 4}, {0, 10}},
    CellGroupingRules->{"SectionGrouping", 70},
    CellFrameMargins->12,
    HyphenationOptions->{"HyphenationCharacter"->"-"},
    StyleMenuListing->None,
    FontSize->13,
    FontWeight->"Bold",
    FontSlant->"Italic",
    FontColor->RGBColor[0, 0, 0.4]],
  
  Cell[StyleData["ExampleSection", "Printout"],
    CellMargins->{{3, 0}, {0, 10}},
    PageBreakBelow->False,
    HyphenationOptions->{"HyphenationCharacter"->"-"},
    FontSize->9,
    FontColor->GrayLevel[0]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["ExampleText"],
    CellMargins->{{20, 40}, {0, 18}},
    Hyphenation->True,
    HyphenationOptions->{"HyphenationCharacter"->"-"},
    ParagraphSpacing->{0, 6},
    StyleMenuListing->None,
    FontColor->RGBColor[0, 0, 0.4]],
  
  Cell[StyleData["ExampleText", "Printout"],
    CellMargins->{{2, 80}, {0, 8}},
    PageBreakBelow->False,
    HyphenationOptions->{"HyphenationCharacter"->"-"},
    FontSize->8,
    FontColor->GrayLevel[0]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["ExampleSubsection"],
    ShowCellBracket->True,
    CellMargins->{{20, 4}, {0, 16}},
    CellGroupingRules->{"SectionGrouping", 80},
    HyphenationOptions->{"HyphenationCharacter"->"-"},
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->10,
    FontWeight->"Bold"],
  
  Cell[StyleData["ExampleSubsection", "Printout"],
    CellMargins->{{12, 0}, {0, 16}},
    PageBreakBelow->False,
    HyphenationOptions->{"HyphenationCharacter"->"-"},
    FontSize->7]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["LineHead"],
    CellFrame->{{0, 0}, {0.5, 0}},
    CellMargins->{{10, 4}, {8, 18}},
    HyphenationOptions->{"HyphenationCharacter"->"-"},
    CounterIncrements->"Subsection",
    CounterAssignments->{{"Subsubsection", 0}},
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->12,
    FontWeight->"Bold"],
  
  Cell[StyleData["LineHead", "Printout"],
    CellMargins->{{2, 0}, {8, 18}},
    PageBreakBelow->False,
    HyphenationOptions->{"HyphenationCharacter"->"-"},
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["FlushInput"],
    CellMargins->{{10, 4}, {1, 4}},
    Evaluatable->True,
    CellGroupingRules->"InputGrouping",
    CellHorizontalScrolling->True,
    PageBreakWithin->False,
    GroupPageBreakWithin->False,
    CellLabelAutoDelete->False,
    CellLabelMargins->{{23, Inherited}, {Inherited, Inherited}},
    DefaultFormatType->DefaultInputFormatType,
    ShowSpecialCharacters->Automatic,
    HyphenationOptions->{"HyphenationCharacter"->"-"},
    FormatType->StandardForm,
    ShowStringCharacters->True,
    NumberMarks->True,
    StyleMenuListing->None,
    FontWeight->"Bold"],
  
  Cell[StyleData["FlushInput", "Printout"],
    CellMargins->{{2, 0}, {1, 4}},
    HyphenationOptions->{"HyphenationCharacter"->"-"},
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["FlushOutput"],
    CellMargins->{{10, Inherited}, {Inherited, Inherited}},
    CellEditDuplicate->True,
    CellGroupingRules->"OutputGrouping",
    CellHorizontalScrolling->True,
    PageBreakWithin->False,
    GroupPageBreakWithin->False,
    GeneratedCell->True,
    CellAutoOverwrite->True,
    CellLabelAutoDelete->False,
    CellLabelMargins->{{23, Inherited}, {Inherited, Inherited}},
    DefaultFormatType->DefaultOutputFormatType,
    HyphenationOptions->{"HyphenationCharacter"->"-"},
    FormatType->StandardForm,
    StyleMenuListing->None],
  
  Cell[StyleData["FlushOutput", "Printout"],
    CellMargins->{{2, Inherited}, {Inherited, Inherited}},
    HyphenationOptions->{"HyphenationCharacter"->"-"},
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["DialogItem"],
    CellDingbat->"\[EmptyDiamond]",
    CellMargins->{{20, 4}, {0, 12}},
    CellGroupingRules->{"SectionGrouping", 70},
    HyphenationOptions->{"HyphenationCharacter"->"-"},
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->10,
    FontWeight->"Bold"],
  
  Cell[StyleData["DialogItem", "Printout"],
    CellMargins->{{12, 0}, {0, 12}},
    PageBreakBelow->False,
    HyphenationOptions->{"HyphenationCharacter"->"-"},
    FontSize->8]
  }, Closed]],
  
  Cell[StyleData["GroupDivider"],
    CellMargins->{{10, Inherited}, {Inherited, Inherited}},
    CellEditDuplicate->True,
    CellGroupingRules->{"TitleGrouping", 0},
    HyphenationOptions->{"HyphenationCharacter"->"-"},
    StyleMenuListing->None],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Highlight"],
    CellMargins->{{10, 4}, {0, 18}},
    HyphenationOptions->{"HyphenationCharacter"->"-"},
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->12,
    Background->GrayLevel[0.900008]],
  
  Cell[StyleData["Highlight", "Printout"],
    CellMargins->{{2, 0}, {0, 18}},
    HyphenationOptions->{"HyphenationCharacter"->"-"},
    LineSpacing->{1, 3}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["UserNotes"],
    CellFrame->{{2, 0}, {0, 0.25}},
    CellMargins->{{10, 4}, {0, 8}},
    Hyphenation->True,
    HyphenationOptions->{"HyphenationCharacter"->"-"},
    ParagraphIndent->-7,
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->10],
  
  Cell[StyleData["UserNotes", "Printout"],
    CellMargins->{{2, 0}, {0, 4}},
    HyphenationOptions->{"HyphenationCharacter"->"-"},
    LineSpacing->{1, 3},
    FontSize->8]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["MoreInfo"],
    CellFrame->{{2, 0}, {0, 0.25}},
    CellMargins->{{10, 4}, {0, 8}},
    Hyphenation->True,
    HyphenationOptions->{"HyphenationCharacter"->"-"},
    ParagraphIndent->-7,
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->10,
    FontColor->GrayLevel[1],
    Background->RGBColor[0.4, 0.6, 0.550011]],
  
  Cell[StyleData["MoreInfo", "Printout"],
    CellMargins->{{2, 0}, {0, 4}},
    HyphenationOptions->{"HyphenationCharacter"->"-"},
    LineSpacing->{1, 3},
    FontSize->8]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["UserTips"],
    CellFrame->{{2, 0}, {0, 0.25}},
    CellMargins->{{10, 4}, {0, 8}},
    Hyphenation->True,
    HyphenationOptions->{"HyphenationCharacter"->"-"},
    ParagraphIndent->-7,
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->10,
    FontColor->GrayLevel[1],
    Background->RGBColor[0.300008, 0.600015, 0.700008]],
  
  Cell[StyleData["UserTips", "Printout"],
    CellMargins->{{2, 0}, {0, 4}},
    HyphenationOptions->{"HyphenationCharacter"->"-"},
    LineSpacing->{1, 3},
    FontSize->8,
    Background->GrayLevel[0.700008]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Theorem"],
    CellFrame->{{4, 0}, {0, 0}},
    CellMargins->{{12, 62}, {0, 14}},
    CellFrameMargins->4,
    CellFrameColor->RGBColor[0, 0, 0.8],
    HyphenationOptions->{"HyphenationCharacter"->"-"},
    LineSpacing->{1, 1},
    ParagraphSpacing->{0, 8}],
  
  Cell[StyleData["Theorem", "Printout"],
    CellMargins->{{2, 0}, {0, 14}},
    CellFrameMargins->3,
    CellFrameColor->GrayLevel[0.8],
    HyphenationOptions->{"HyphenationCharacter"->"-"},
    FontSize->9,
    FontColor->GrayLevel[0]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Commentary"],
    CellFrame->{{2, 0}, {0, 0}},
    CellMargins->{{36, 10}, {7, 7}},
    PageBreakBelow->False,
    CellFrameMargins->8,
    CellFrameColor->RGBColor[0, 0.2, 1],
    LineSpacing->{1, 3},
    FontSlant->"Italic"],
  
  Cell[StyleData["Commentary", "Printout"],
    CellMargins->{{36, 0}, {6, 6}},
    CellFrameColor->GrayLevel[0.8],
    FontSize->10],
  
  Cell[StyleData["Commentary", "EnhancedPrintout"],
    CellMargins->{{36, 0}, {6, 6}},
    CellFrameColor->GrayLevel[0.8],
    FontFamily->"Palatino",
    FontSize->10],
  
  Cell[StyleData["Commentary", "EnhancedPrintoutNonGray"],
    CellMargins->{{36, 0}, {6, 6}},
    CellFrameColor->GrayLevel[0.8],
    FontFamily->"Palatino",
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Level1Icon"],
    ShowGroupOpenCloseIcon->True,
    CellMargins->{{10, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    HyphenationOptions->{"HyphenationCharacter"->"-"},
    ParagraphSpacing->{0, 8},
    StyleMenuListing->None],
  
  Cell[StyleData["Level1Icon", "Printout"],
    CellMargins->{{2, 0}, {0, 8}},
    HyphenationOptions->{"HyphenationCharacter"->"-"},
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Level2Icon"],
    ShowGroupOpenCloseIcon->True,
    CellMargins->{{10, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    HyphenationOptions->{"HyphenationCharacter"->"-"},
    ParagraphSpacing->{0, 8},
    StyleMenuListing->None],
  
  Cell[StyleData["Level2Icon", "Printout"],
    CellMargins->{{2, 0}, {0, 8}},
    HyphenationOptions->{"HyphenationCharacter"->"-"},
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["CopyrightHead"],
    CellMargins->{{10, 4}, {0, 8}},
    PageBreakAbove->False,
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->12,
    FontWeight->"Bold"],
  
  Cell[StyleData["CopyrightHead", "Printout"],
    CellMargins->{{2, 2}, {6, 6}},
    TextJustification->1,
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Copyright"],
    CellMargins->{{10, 4}, {0, 8}},
    PageBreakAbove->False,
    StyleMenuListing->None],
  
  Cell[StyleData["Copyright", "Printout"],
    CellMargins->{{2, 2}, {6, 6}},
    TextJustification->1,
    FontSize->10]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Manual.nb Merge", "Subsection"],
  
  Cell[CellGroupData[{
  
  Cell["Function List", "Subsubsection"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["FunctionName"],
    CellDingbat->"\[FilledSquare]",
    CellMargins->{{24, 10}, {10, 12}},
    CellGroupingRules->{"SectionGrouping", 40},
    PageBreakBelow->False,
    StyleMenuListing->None,
    FontFamily->"Courier",
    FontSize->14,
    FontWeight->"Bold",
    CellTags->"FunctionName"],
  
  Cell[StyleData["FunctionName", "Printout"],
    CellMargins->{{9, 0}, {10, 10}},
    FontSize->12],
  
  Cell[StyleData["FunctionName", "EnhancedPrintout"],
    CellMargins->{{9, 0}, {10, 10}},
    FontFamily->"Courier",
    FontSize->12],
  
  Cell[StyleData["FunctionName", "EnhancedPrintoutNonGray"],
    CellMargins->{{9, 0}, {10, 10}},
    FontFamily->"Courier",
    FontSize->12]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["SubsectionIcon"],
    ShowGroupOpenCloseIcon->True,
    CellMargins->{{24, 10}, {0, 30}},
    CellGroupingRules->{"SectionGrouping", 50},
    PageBreakBelow->False,
    StyleMenuListing->None,
    FontSize->14,
    FontWeight->"Bold",
    CellTags->"FunctionSection"],
  
  Cell[StyleData["SubsectionIcon", "Printout"],
    CellMargins->{{20, 0}, {0, 20}},
    FontSize->13],
  
  Cell[StyleData["SubsectionIcon", "EnhancedPrintout"],
    CellMargins->{{20, 0}, {0, 20}},
    FontFamily->"Palatino",
    FontSize->10],
  
  Cell[StyleData["SubsectionIcon", "EnhancedPrintoutNonGray"],
    CellMargins->{{20, 0}, {0, 20}},
    FontFamily->"Palatino",
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["FunctionSubsection"],
    CellDingbat->"\[FilledSquare]",
    CellMargins->{{36, 10}, {0, 6}},
    CellGroupingRules->{"SectionGrouping", 60},
    PageBreakBelow->False,
    StyleMenuListing->None,
    FontWeight->"Bold",
    CellTags->"FunctionSubsection"],
  
  Cell[StyleData["FunctionSubsection", "Printout"],
    CellMargins->{{30, 0}, {0, 6}}],
  
  Cell[StyleData["FunctionSubsection", "EnhancedPrintout"],
    CellMargins->{{30, 0}, {0, 6}},
    FontFamily->"Palatino",
    FontSize->11],
  
  Cell[StyleData["FunctionSubsection", "EnhancedPrintoutNonGray"],
    CellMargins->{{30, 0}, {0, 6}},
    FontFamily->"Palatino",
    FontSize->11]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["SubsubsectionIcon"],
    ShowGroupOpenCloseIcon->True,
    CellMargins->{{36, 10}, {0, 6}},
    CellGroupingRules->{"SectionGrouping", 60},
    PageBreakBelow->False,
    StyleMenuListing->None,
    FontWeight->"Bold",
    CellTags->"SubsubsectionIcon"],
  
  Cell[StyleData["SubsubsectionIcon", "Printout"],
    CellMargins->{{30, 0}, {0, 6}},
    FontSize->11],
  
  Cell[StyleData["SubsubsectionIcon", "EnhancedPrintout"],
    CellMargins->{{30, 0}, {0, 6}},
    FontFamily->"Palatino",
    FontSize->9],
  
  Cell[StyleData["SubsubsectionIcon", "EnhancedPrintoutNonGray"],
    CellMargins->{{30, 0}, {0, 6}},
    FontFamily->"Palatino",
    FontSize->9]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["FunctionDescription"],
    CellMargins->{{36, 10}, {4, 0}},
    LineSpacing->{1, 3},
    ParagraphSpacing->{0.7, 0},
    CounterIncrements->"Text",
    StyleMenuListing->None,
    FontWeight->"Plain"],
  
  Cell[StyleData["FunctionDescription", "Printout"],
    CellMargins->{{30, 0}, {4, 0}},
    FontSize->11],
  
  Cell[StyleData["FunctionDescription", "EnhancedPrintout"],
    CellMargins->{{30, 0}, {4, 0}},
    TextJustification->0,
    FontFamily->"Palatino",
    FontSize->10],
  
  Cell[StyleData["FunctionDescription", "EnhancedPrintoutNonGray"],
    CellMargins->{{30, 0}, {4, 0}},
    TextJustification->0,
    FontFamily->"Palatino",
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["FunctionDescriptionRuled"],
    CellFrame->{{0, 0}, {0.25, 0.25}},
    CellMargins->{{36, 10}, {4, 0}},
    LineSpacing->{1, 3},
    ParagraphSpacing->{0.7, 0},
    CounterIncrements->"Text",
    StyleMenuListing->None],
  
  Cell[StyleData["FunctionDescriptionRuled", "Printout"],
    CellMargins->{{30, 0}, {4, 0}},
    FontSize->11],
  
  Cell[StyleData["FunctionDescriptionRuled", "EnhancedPrintout"],
    CellMargins->{{30, 0}, {4, 0}},
    TextJustification->0,
    FontFamily->"Palatino",
    FontSize->10],
  
  Cell[StyleData["FunctionDescriptionRuled", "EnhancedPrintoutNonGray"],
    CellMargins->{{30, 0}, {4, 0}},
    TextJustification->0,
    FontFamily->"Palatino",
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["FunctionDescriptionRuleTop"],
    CellFrame->{{0, 0}, {0, 0.25}},
    CellMargins->{{36, 10}, {4, 0}},
    LineSpacing->{1, 3},
    ParagraphSpacing->{0.7, 0},
    CounterIncrements->"Text",
    StyleMenuListing->None],
  
  Cell[StyleData["FunctionDescriptionRuleTop", "Printout"],
    CellMargins->{{30, 0}, {4, 0}},
    FontSize->11],
  
  Cell[StyleData["FunctionDescriptionRuleTop", "EnhancedPrintout"],
    CellMargins->{{30, 0}, {4, 0}},
    TextJustification->0,
    FontFamily->"Palatino",
    FontSize->10],
  
  Cell[StyleData["FunctionDescriptionRuleTop", "EnhancedPrintoutNonGray"],
    CellMargins->{{30, 0}, {4, 0}},
    TextJustification->0,
    FontFamily->"Palatino",
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["FunctionDescriptionRuleBottom"],
    CellFrame->{{0, 0}, {0.25, 0}},
    CellMargins->{{36, 10}, {4, 0}},
    LineSpacing->{1, 3},
    ParagraphSpacing->{0.7, 0},
    CounterIncrements->"Text",
    StyleMenuListing->None],
  
  Cell[StyleData["FunctionDescriptionRuleBottom", "Printout"],
    CellMargins->{{30, 0}, {4, 0}},
    FontSize->11],
  
  Cell[StyleData["FunctionDescriptionRuleBottom", "EnhancedPrintout"],
    CellMargins->{{30, 0}, {4, 0}},
    TextJustification->0,
    FontFamily->"Palatino",
    FontSize->10],
  
  Cell[StyleData["FunctionDescriptionRuleBottom", "EnhancedPrintoutNonGray"],
    CellMargins->{{30, 0}, {4, 0}},
    TextJustification->0,
    FontFamily->"Palatino",
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["FunctionExample"],
    CellMargins->{{36, 10}, {4, 0}},
    StyleMenuListing->None,
    FontSize->10],
  
  Cell[StyleData["FunctionExample", "Printout"],
    CellMargins->{{30, 0}, {4, 0}},
    FontSize->9],
  
  Cell[StyleData["FunctionExample", "EnhancedPrintout"],
    CellMargins->{{30, 0}, {4, 0}},
    FontFamily->"Palatino",
    FontSize->9],
  
  Cell[StyleData["FunctionExample", "EnhancedPrintoutNonGray"],
    CellMargins->{{30, 0}, {4, 0}},
    FontFamily->"Palatino",
    FontSize->9]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["FunctionTextNote"],
    CellMargins->{{36, 4}, {0, 4}},
    LineSpacing->{1, 3},
    ParagraphSpacing->{0, 4},
    LineIndent->0,
    StyleMenuListing->None],
  
  Cell[StyleData["FunctionTextNote", "Printout"],
    CellMargins->{{36, 4}, {0, 4}},
    FontSize->9],
  
  Cell[StyleData["FunctionTextNote", "EnhancedPrintout"],
    CellMargins->{{36, 4}, {0, 4}},
    FontFamily->"Palatino",
    FontSize->8],
  
  Cell[StyleData["FunctionTextNote", "EnhancedPrintoutNonGray"],
    CellMargins->{{36, 4}, {0, 4}},
    FontFamily->"Palatino",
    FontSize->8]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["3ColumnFunctionTable"],
    CellMargins->{{36, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    PageBreakWithin->False,
    AutoIndent->False,
    AutoSpacing->False,
    LineIndent->0,
    StyleMenuListing->None,
    GridBoxOptions->{RowSpacings->1.5,
    ColumnSpacings->2,
    ColumnWidths->{0.28, 0.28, 0.43},
    ColumnAlignments->{Left}}],
  
  Cell[StyleData["3ColumnFunctionTable", "Printout"],
    CellMargins->{{30, 0}, {0, 8}},
    FontSize->10],
  
  Cell[StyleData["3ColumnFunctionTable", "EnhancedPrintout"],
    CellMargins->{{30, 0}, {0, 8}},
    FontSize->10],
  
  Cell[StyleData["3ColumnFunctionTable", "EnhancedPrintoutNonGray"],
    CellMargins->{{30, 0}, {0, 8}},
    FontSize->10]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Browser Emulation", "Subsubsection"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["TextNormal"],
    CellMargins->{{12, 10}, {7, 7}},
    LineSpacing->{1, 3},
    CounterIncrements->"Text",
    StyleMenuListing->None,
    FontFamily->"Times",
    FontSize->12],
  
  Cell[StyleData["TextNormal", "Printout"],
    CellMargins->{{2, 2}, {6, 6}},
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["BrowserEmulation"],
    CellMargins->{{12, 1}, {7, 24}},
    CellGroupingRules->{"SectionGrouping", 70},
    LineSpacing->{1, 3},
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    GridBoxOptions->{ColumnWidths->0.25,
    ColumnAlignments->{Left},
    GridFrame->True,
    GridFrameMargins->0.5,
    ColumnLines->True}],
  
  Cell[StyleData["BrowserEmulation", "Printout"],
    CellMargins->{{2, 2}, {6, 6}},
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["CategoryDefs"],
    CellMargins->{{300, 10}, {7, 7}},
    LineSpacing->{1, 3},
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    Background->RGBColor[1, 0.8, 0.6],
    GridBoxOptions->{ColumnAlignments->{Left},
    GridFrame->False,
    RowLines->True,
    ColumnLines->True}],
  
  Cell[StyleData["CategoryDefs", "Printout"],
    CellMargins->{{2, 2}, {6, 6}},
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Category1"],
    ShowCellBracket->False,
    ShowGroupOpenCloseIcon->True,
    CellMargins->{{12, 10}, {7, 7}},
    CellGroupingRules->{"SectionGrouping", 50},
    StyleMenuListing->None,
    FontSize->16,
    FontWeight->"Bold"],
  
  Cell[StyleData["Category1", "Printout"],
    CellMargins->{{2, 2}, {6, 6}}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Category2"],
    ShowCellBracket->False,
    ShowGroupOpenCloseIcon->True,
    CellMargins->{{85, 10}, {7, 7}},
    CellGroupingRules->{"SectionGrouping", 60},
    StyleMenuListing->None,
    FontSize->14,
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0, 0.500008]],
  
  Cell[StyleData["Category2", "Printout"],
    CellMargins->{{2, 2}, {6, 6}}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Category3"],
    ShowCellBracket->False,
    ShowGroupOpenCloseIcon->True,
    CellMargins->{{157, 10}, {7, 7}},
    CellGroupingRules->{"SectionGrouping", 70},
    StyleMenuListing->None,
    FontSize->12,
    FontWeight->"Bold",
    FontColor->RGBColor[0.2, 0, 0.4]],
  
  Cell[StyleData["Category3", "Printout"],
    CellMargins->{{2, 2}, {6, 6}}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Category4"],
    ShowCellBracket->False,
    ShowGroupOpenCloseIcon->True,
    CellMargins->{{230, 10}, {7, 7}},
    CellGroupingRules->{"SectionGrouping", 80},
    StyleMenuListing->None,
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0.300008, 0.4]],
  
  Cell[StyleData["Category4", "Printout"],
    CellMargins->{{2, 2}, {6, 6}}]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Misc", "Subsubsection"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["4ColumnTable"],
    CellMargins->{{10, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    PageBreakWithin->False,
    AutoIndent->False,
    AutoSpacing->False,
    LineIndent->0,
    StyleMenuListing->None,
    GridBoxOptions->{RowSpacings->1.5,
    ColumnSpacings->2,
    ColumnWidths->0.25,
    ColumnAlignments->{Left, Center}}],
  
  Cell[StyleData["4ColumnTable", "Printout"],
    CellMargins->{{2, 0}, {0, 8}}],
  
  Cell[StyleData["4ColumnTable", "EnhancedPrintout"],
    CellMargins->{{2, 0}, {0, 8}}],
  
  Cell[StyleData["4ColumnTable", "EnhancedPrintoutNonGray"],
    CellMargins->{{2, 0}, {0, 8}}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["5ColumnTable"],
    CellMargins->{{10, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    PageBreakWithin->False,
    AutoIndent->False,
    AutoSpacing->False,
    LineIndent->0,
    StyleMenuListing->None,
    GridBoxOptions->{RowSpacings->1.5,
    ColumnSpacings->2,
    ColumnWidths->0.2,
    ColumnAlignments->{Left, Center}}],
  
  Cell[StyleData["5ColumnTable", "Printout"],
    CellMargins->{{2, 0}, {0, 8}}],
  
  Cell[StyleData["5ColumnTable", "EnhancedPrintout"],
    CellMargins->{{2, 0}, {0, 8}}],
  
  Cell[StyleData["5ColumnTable", "EnhancedPrintoutNonGray"],
    CellMargins->{{2, 0}, {0, 8}}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["6ColumnTable"],
    CellMargins->{{10, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    PageBreakWithin->False,
    AutoIndent->False,
    AutoSpacing->False,
    LineIndent->0,
    StyleMenuListing->None,
    GridBoxOptions->{RowSpacings->1.5,
    ColumnSpacings->2,
    ColumnWidths->0.16,
    ColumnAlignments->{Left, Center}}],
  
  Cell[StyleData["6ColumnTable", "Printout"],
    CellMargins->{{2, 0}, {0, 8}}],
  
  Cell[StyleData["6ColumnTable", "EnhancedPrintout"],
    CellMargins->{{2, 0}, {0, 8}}],
  
  Cell[StyleData["6ColumnTable", "EnhancedPrintoutNonGray"],
    CellMargins->{{2, 0}, {0, 8}}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["7ColumnTable"],
    CellMargins->{{10, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    PageBreakWithin->False,
    AutoIndent->False,
    AutoSpacing->False,
    LineIndent->0,
    StyleMenuListing->None,
    GridBoxOptions->{RowSpacings->1.5,
    ColumnSpacings->2,
    ColumnWidths->0.14,
    ColumnAlignments->{Left, Center}}],
  
  Cell[StyleData["7ColumnTable", "Printout"],
    CellMargins->{{2, 0}, {0, 8}}],
  
  Cell[StyleData["7ColumnTable", "EnhancedPrintout"],
    CellMargins->{{2, 0}, {0, 8}}],
  
  Cell[StyleData["7ColumnTable", "EnhancedPrintoutNonGray"],
    CellMargins->{{2, 0}, {0, 8}}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["8ColumnTable"],
    CellMargins->{{10, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    PageBreakWithin->False,
    AutoIndent->False,
    AutoSpacing->False,
    LineIndent->0,
    StyleMenuListing->None,
    GridBoxOptions->{RowSpacings->1.5,
    ColumnSpacings->2,
    ColumnWidths->0.12,
    ColumnAlignments->{Left, Center}}],
  
  Cell[StyleData["8ColumnTable", "Printout"],
    CellMargins->{{2, 0}, {0, 8}}],
  
  Cell[StyleData["8ColumnTable", "EnhancedPrintout"],
    CellMargins->{{2, 0}, {0, 8}}],
  
  Cell[StyleData["8ColumnTable", "EnhancedPrintoutNonGray"],
    CellMargins->{{2, 0}, {0, 8}}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["ABItemizedText"],
    CellMargins->{{20, 4}, {0, 5}},
    Hyphenation->True,
    LineSpacing->{1, 3},
    ParagraphIndent->-21,
    CounterIncrements->"ItemizedText",
    StyleMenuListing->None],
  
  Cell[StyleData["ABItemizedText", "Printout"],
    ParagraphIndent->-21,
    FontSize->11],
  
  Cell[StyleData["ABItemizedText", "EnhancedPrintout"],
    ParagraphIndent->-21,
    FontFamily->"Palatino",
    FontSize->10],
  
  Cell[StyleData["ABItemizedText", "EnhancedPrintoutNonGray"],
    ParagraphIndent->-21,
    FontFamily->"Palatino",
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["ChapNumber"],
    CellMargins->{{12, Inherited}, {20, 40}},
    CellGroupingRules->{"TitleGrouping", 0},
    PageBreakBelow->False,
    DefaultNewInlineCellStyle->"None",
    InputAutoReplacements->{"TeX"->StyleBox[ 
            RowBox[ {"T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.074999999999999997, \
-0.085000000000000006}, {0, 0}}, BoxBaselineShift -> 0.5], "X"}]], 
        "LaTeX"->StyleBox[ 
            RowBox[ {"L", 
              StyleBox[ 
                AdjustmentBox[ 
                "A", BoxMargins -> {{-0.35999999999999999, \
-0.10000000000000001}, {0, 0}}, BoxBaselineShift -> -0.20000000000000001], 
                FontSize -> Smaller], "T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.074999999999999997, \
-0.085000000000000006}, {0, 0}}, BoxBaselineShift -> 0.5], "X"}]], 
        "mma"->"Mathematica", "Mma"->"Mathematica", "MMA"->"Mathematica", 
        "webMathematica"->FormBox[ 
            RowBox[ {"web", 
              AdjustmentBox[ 
                StyleBox[ "Mathematica", FontSlant -> "Italic"], 
                BoxMargins -> {{-0.17499999999999999, 0}, {0, 0}}]}], 
            TextForm]},
    LanguageCategory->"NaturalLanguage",
    CounterIncrements->"Title",
    CounterAssignments->{{"Section", 0}, {"Equation", 0}, {"Figure", 0}, {
        "Subtitle", 0}, {"Subsubtitle", 0}},
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->42,
    FontWeight->"Plain"],
  
  Cell[StyleData["ChapNumber", "Printout"],
    CellMargins->{{2, 10}, {15, 30}},
    FontSize->36],
  
  Cell[StyleData["ChapNumber", "EnhancedPrintout"],
    CellMargins->{{2, 10}, {15, 30}},
    FontFamily->"Futura",
    FontSize->36],
  
  Cell[StyleData["ChapNumber", "EnhancedPrintoutNonGray"],
    CellMargins->{{2, 10}, {15, 30}},
    FontFamily->"Futura",
    FontSize->36]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["ChapTitle"],
    CellMargins->{{12, Inherited}, {80, 10}},
    CellGroupingRules->{"TitleGrouping", 0},
    PageBreakBelow->False,
    DefaultNewInlineCellStyle->"None",
    InputAutoReplacements->{"TeX"->StyleBox[ 
            RowBox[ {"T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.074999999999999997, \
-0.085000000000000006}, {0, 0}}, BoxBaselineShift -> 0.5], "X"}]], 
        "LaTeX"->StyleBox[ 
            RowBox[ {"L", 
              StyleBox[ 
                AdjustmentBox[ 
                "A", BoxMargins -> {{-0.35999999999999999, \
-0.10000000000000001}, {0, 0}}, BoxBaselineShift -> -0.20000000000000001], 
                FontSize -> Smaller], "T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.074999999999999997, \
-0.085000000000000006}, {0, 0}}, BoxBaselineShift -> 0.5], "X"}]], 
        "mma"->"Mathematica", "Mma"->"Mathematica", "MMA"->"Mathematica", 
        "webMathematica"->FormBox[ 
            RowBox[ {"web", 
              AdjustmentBox[ 
                StyleBox[ "Mathematica", FontSlant -> "Italic"], 
                BoxMargins -> {{-0.17499999999999999, 0}, {0, 0}}]}], 
            TextForm]},
    LanguageCategory->"NaturalLanguage",
    CounterIncrements->"Title",
    CounterAssignments->{{"Section", 0}, {"Equation", 0}, {"Figure", 0}, {
        "Subtitle", 0}, {"Subsubtitle", 0}},
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->36,
    FontWeight->"Bold"],
  
  Cell[StyleData["ChapTitle", "Printout"],
    CellMargins->{{2, 10}, {80, 6}},
    FontSize->30],
  
  Cell[StyleData["ChapTitle", "EnhancedPrintout"],
    CellMargins->{{2, 10}, {80, 6}},
    FontFamily->"Futura",
    FontSize->30],
  
  Cell[StyleData["ChapTitle", "EnhancedPrintoutNonGray"],
    CellMargins->{{2, 10}, {80, 6}},
    FontFamily->"Futura",
    FontSize->30]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["ItemDingbat"],
    CellSize->{22, 14},
    TextAlignment->Right,
    StyleMenuListing->None,
    FontWeight->"Bold"],
  
  Cell[StyleData["ItemDingbat", "Printout"],
    CellSize->{22, 13.125}],
  
  Cell[StyleData["ItemDingbat", "EnhancedPrintout"],
    CellSize->{22, 11}],
  
  Cell[StyleData["ItemDingbat", "EnhancedPrintoutNonGray"],
    CellSize->{22, 11}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Item1"],
    CellMargins->{{19, 4}, {4, 4}},
    ParagraphIndent->-22,
    CounterIncrements->"Item1",
    StyleMenuListing->None],
  
  Cell[StyleData["Item1", "Printout"],
    CellMargins->{{12, 0}, {2, 4}},
    FontSize->10],
  
  Cell[StyleData["Item1", "EnhancedPrintout"],
    CellMargins->{{16, 0}, {2, 4}},
    FontSize->10],
  
  Cell[StyleData["Item1", "EnhancedPrintoutNonGray"],
    CellMargins->{{16, 0}, {2, 4}},
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Item1Continued"],
    CellMargins->{{41, 4}, {4, 1}},
    CounterIncrements->"Item1Continued",
    StyleMenuListing->None],
  
  Cell[StyleData["Item1Continued", "Printout"],
    CellMargins->{{34, 0}, {4, 1}},
    FontSize->10],
  
  Cell[StyleData["Item1Continued", "EnhancedPrintout"],
    CellMargins->{{39, 0}, {4, 1}},
    FontSize->10],
  
  Cell[StyleData["Item1Continued", "EnhancedPrintoutNonGray"],
    CellMargins->{{39, 0}, {4, 1}},
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Item2"],
    CellMargins->{{32, 4}, {4, 4}},
    ParagraphIndent->-22,
    CounterIncrements->"Item2",
    StyleMenuListing->None],
  
  Cell[StyleData["Item2", "Printout"],
    CellMargins->{{26, 0}, {4, 4}},
    ParagraphIndent->-22,
    FontSize->10],
  
  Cell[StyleData["Item2", "EnhancedPrintout"],
    CellMargins->{{29, 0}, {2, 4}},
    ParagraphIndent->-22,
    FontSize->10],
  
  Cell[StyleData["Item2", "EnhancedPrintoutNonGray"],
    CellMargins->{{29, 0}, {2, 4}},
    ParagraphIndent->-22,
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Item2Continued"],
    CellMargins->{{54, 4}, {4, 1}},
    CounterIncrements->"Item2Continued",
    StyleMenuListing->None],
  
  Cell[StyleData["Item2Continued", "Printout"],
    CellMargins->{{27, 0}, {4, 1}}],
  
  Cell[StyleData["Item2Continued", "EnhancedPrintout"],
    CellMargins->{{52, 0}, {4, 1}},
    FontSize->10],
  
  Cell[StyleData["Item2Continued", "EnhancedPrintoutNonGray"],
    CellMargins->{{52, 0}, {4, 1}}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Item3"],
    CellMargins->{{45, 4}, {4, 4}},
    ParagraphIndent->-23,
    CounterIncrements->"Item3",
    StyleMenuListing->None],
  
  Cell[StyleData["Item3", "Printout"],
    CellMargins->{{27, 0}, {2, 4}}],
  
  Cell[StyleData["Item3", "EnhancedPrintout"],
    CellMargins->{{42, 0}, {2, 4}},
    FontSize->10],
  
  Cell[StyleData["Item3", "EnhancedPrintoutNonGray"],
    CellMargins->{{42, 0}, {2, 4}},
    StyleMenuListing->None]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Item3Continued"],
    CellMargins->{{67, 4}, {4, 1}},
    CounterIncrements->"Item3Continued",
    StyleMenuListing->None],
  
  Cell[StyleData["Item3Continued", "Printout"],
    CellMargins->{{27, 0}, {4, 1}}],
  
  Cell[StyleData["Item3Continued", "EnhancedPrintout"],
    CellMargins->{{65, 0}, {4, 1}},
    FontSize->10],
  
  Cell[StyleData["Item3Continued", "EnhancedPrintoutNonGray"],
    CellMargins->{{65, 0}, {4, 1}}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["ItemizedBulletText"],
    CellMargins->{{19, 4}, {0, 5}},
    Hyphenation->True,
    LineSpacing->{1, 3},
    ParagraphIndent->-22,
    CounterIncrements->"ItemizedBulletText",
    StyleMenuListing->None],
  
  Cell[StyleData["ItemizedBulletText", "Printout"],
    ParagraphIndent->-20,
    FontSize->11],
  
  Cell[StyleData["ItemizedBulletText", "EnhancedPrintout"],
    ParagraphIndent->-19,
    FontFamily->"Palatino",
    FontSize->10],
  
  Cell[StyleData["ItemizedBulletText", "EnhancedPrintoutNonGray"],
    ParagraphIndent->-19,
    FontFamily->"Palatino",
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["NoteBox"],
    CellFrame->0.5,
    CellMargins->{{10, 4}, {8, 8}},
    CellHorizontalScrolling->True,
    LineIndent->0,
    StyleMenuListing->None,
    Background->RGBColor[1, 0.6, 0.6],
    FrameBoxOptions->{BoxMargins->{{1, 1}, {1.5, 1.5}}},
    GridBoxOptions->{ColumnSpacings->1}],
  
  Cell[StyleData["NoteBox", "Printout"],
    CellMargins->{{2, 4}, {6, 2}},
    FontSize->10,
    Background->GrayLevel[0.900008]],
  
  Cell[StyleData["NoteBox", "EnhancedPrintout"],
    CellMargins->{{2, 4}, {6, 2}},
    FontSize->10,
    Background->GrayLevel[0.900008]],
  
  Cell[StyleData["NoteBox", "EnhancedPrintoutNonGray"],
    CellMargins->{{2, 4}, {6, 2}},
    FontSize->10,
    Background->GrayLevel[1]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["ItemizedNoteBox"],
    CellFrame->0.5,
    CellMargins->{{41, 4}, {8, 2}},
    CellHorizontalScrolling->True,
    LineIndent->0,
    StyleMenuListing->None,
    Background->RGBColor[1, 0.6, 0.6],
    FrameBoxOptions->{BoxMargins->{{1, 1}, {1.5, 1.5}}},
    GridBoxOptions->{ColumnSpacings->1}],
  
  Cell[StyleData["ItemizedNoteBox", "Printout"],
    CellMargins->{{39, 4}, {6, 2}},
    FontSize->10,
    Background->GrayLevel[0.900008]],
  
  Cell[StyleData["ItemizedNoteBox", "EnhancedPrintout"],
    CellMargins->{{39, 4}, {6, 2}},
    FontSize->10,
    Background->GrayLevel[0.900008]],
  
  Cell[StyleData["ItemizedNoteBox", "EnhancedPrintoutNonGray"],
    CellMargins->{{39, 4}, {6, 2}},
    FontSize->10,
    Background->GrayLevel[1]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["ItemizedTopBox"],
    CellFrame->{{0.5, 0.5}, {0, 0.5}},
    CellMargins->{{37, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    CellFrameMargins->{{8, 8}, {0, 8}},
    LineIndent->0,
    StyleMenuListing->None,
    Background->RGBColor[1, 0.6, 0.6],
    GridBoxOptions->{RowSpacings->1.5,
    ColumnSpacings->1,
    ColumnWidths->{0.31, 0.62},
    ColumnAlignments->{Left}}],
  
  Cell[StyleData["ItemizedTopBox", "Printout"],
    FontSize->10,
    Background->GrayLevel[0.900008]],
  
  Cell[StyleData["ItemizedTopBox", "EnhancedPrintout"],
    CellMargins->{{39, 4}, {0, 6}},
    FontSize->10,
    Background->GrayLevel[0.900008]],
  
  Cell[StyleData["ItemizedTopBox", "EnhancedPrintoutNonGray"],
    CellMargins->{{39, 4}, {0, 6}},
    FontSize->10,
    Background->GrayLevel[1]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["ItemizedBottomBox"],
    CellFrame->{{0.5, 0.5}, {0.5, 0}},
    CellMargins->{{37, 4}, {4, 0}},
    CellHorizontalScrolling->True,
    CellFrameMargins->{{8, 8}, {8, 0}},
    LineIndent->0,
    StyleMenuListing->None,
    Background->RGBColor[1, 0.6, 0.6],
    GridBoxOptions->{RowSpacings->1.5,
    ColumnSpacings->1,
    ColumnWidths->{0.31, 0.62},
    ColumnAlignments->{Left}}],
  
  Cell[StyleData["ItemizedBottomBox", "Printout"],
    FontSize->10,
    Background->GrayLevel[0.900008]],
  
  Cell[StyleData["ItemizedBottomBox", "EnhancedPrintout"],
    CellMargins->{{39, 4}, {6, 0}},
    FontSize->10,
    Background->GrayLevel[0.900008]],
  
  Cell[StyleData["ItemizedBottomBox", "EnhancedPrintoutNonGray"],
    CellMargins->{{39, 4}, {6, 0}},
    FontSize->10,
    Background->GrayLevel[1]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["MiddleSpacedBox"],
    CellFrame->{{0.5, 0.5}, {0, 0}},
    CellMargins->{{11, 4}, {0, -7}},
    CellHorizontalScrolling->True,
    PageBreakAbove->False,
    PageBreakBelow->False,
    AutoIndent->False,
    AutoSpacing->False,
    LineIndent->0,
    StyleMenuListing->None,
    FontWeight->"Plain",
    Background->RGBColor[1, 0.6, 0.6],
    GridBoxOptions->{RowSpacings->1.5,
    ColumnSpacings->1,
    ColumnWidths->{0.31, 0.62},
    ColumnAlignments->{Left}}],
  
  Cell[StyleData["MiddleSpacedBox", "Printout"],
    CellMargins->{{2, 0}, {0, 0}},
    Background->GrayLevel[1],
    GridBoxOptions->{RowMinHeight->1.8}],
  
  Cell[StyleData["MiddleSpacedBox", "EnhancedPrintout"],
    CellMargins->{{2, 0}, {0, 0}},
    FontFamily->"Palatino",
    Background->GrayLevel[1],
    GridBoxOptions->{RowMinHeight->1.8}],
  
  Cell[StyleData["MiddleSpacedBox", "EnhancedPrintoutNonGray"],
    CellMargins->{{2, 0}, {0, 0}},
    FontFamily->"Palatino",
    Background->GrayLevel[1],
    GridBoxOptions->{RowMinHeight->1.8}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["ItemizedNote"],
    CellMargins->{{41, 4}, {0, 12}},
    Hyphenation->True,
    LineSpacing->{1, 2},
    CounterIncrements->"Text",
    StyleMenuListing->None],
  
  Cell[StyleData["ItemizedNote", "Printout"],
    CellMargins->{{38, 4}, {0, 9}},
    FontSize->11],
  
  Cell[StyleData["ItemizedNote", "EnhancedPrintout"],
    CellMargins->{{38, 4}, {0, 0}},
    TextJustification->1,
    FontFamily->"Palatino",
    FontSize->10],
  
  Cell[StyleData["ItemizedNote", "EnhancedPrintoutNonGray"],
    CellMargins->{{38, 4}, {0, 0}},
    TextJustification->1,
    FontFamily->"Palatino",
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["ItemizedNoteBelow"],
    CellMargins->{{41, 4}, {0, 8}},
    Hyphenation->True,
    LineSpacing->{1, 2},
    CounterIncrements->"Text",
    StyleMenuListing->None],
  
  Cell[StyleData["ItemizedNoteBelow", "Printout"],
    CellMargins->{{38, 4}, {0, 12}},
    FontSize->11],
  
  Cell[StyleData["ItemizedNoteBelow", "EnhancedPrintout"],
    CellMargins->{{38, 4}, {0, 8}},
    TextJustification->1,
    FontFamily->"Palatino",
    FontSize->10],
  
  Cell[StyleData["ItemizedNoteBelow", "EnhancedPrintoutNonGray"],
    CellMargins->{{38, 4}, {0, 8}},
    TextJustification->1,
    FontFamily->"Palatino",
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["ItemizedTextBelowPic"],
    CellMargins->{{19, 4}, {0, 8}},
    Hyphenation->True,
    LineSpacing->{1, 3},
    ParagraphIndent->-22,
    CounterIncrements->"ItemizedText",
    StyleMenuListing->None],
  
  Cell[StyleData["ItemizedTextBelowPic", "Printout"],
    CellMargins->{{20, 4}, {2, 12}},
    ParagraphIndent->-18,
    FontSize->11],
  
  Cell[StyleData["ItemizedTextBelowPic", "EnhancedPrintout"],
    CellMargins->{{20, 4}, {2, 12}},
    ParagraphIndent->-17,
    FontFamily->"Palatino",
    FontSize->10],
  
  Cell[StyleData["ItemizedTextBelowPic", "EnhancedPrintoutNonGray"],
    CellMargins->{{20, 4}, {2, 12}},
    ParagraphIndent->-17,
    FontFamily->"Palatino",
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["ItemizedTextNote2"],
    CellMargins->{{41, 4}, {0, 4}},
    Hyphenation->True,
    LineSpacing->{1, 2},
    CounterIncrements->"Text",
    StyleMenuListing->None],
  
  Cell[StyleData["ItemizedTextNote2", "Printout"],
    CellMargins->{{38, 4}, {0, 2}},
    FontSize->11],
  
  Cell[StyleData["ItemizedTextNote2", "EnhancedPrintout"],
    CellMargins->{{38, 4}, {0, 2}},
    FontFamily->"Palatino",
    FontSize->10],
  
  Cell[StyleData["ItemizedTextNote2", "EnhancedPrintoutNonGray"],
    CellMargins->{{38, 4}, {0, 2}},
    FontFamily->"Palatino",
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["NumberedItem1"],
    CellMargins->{{48, 4}, {4, 4}},
    CellGroupingRules->{"SectionGrouping", 15},
    ParagraphIndent->-23,
    CounterIncrements->"NumberedItem1",
    StyleMenuListing->None],
  
  Cell[StyleData["NumberedItem1", "Printout"],
    CellMargins->{{12, 0}, {0, 8}}],
  
  Cell[StyleData["NumberedItem1", "EnhancedPrintout"],
    CellMargins->{{12, 0}, {0, 8}}],
  
  Cell[StyleData["NumberedItem1", "EnhancedPrintoutNonGray"],
    CellMargins->{{12, 0}, {0, 8}}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["NumberedItem2"],
    CellMargins->{{71, 4}, {3, 3}},
    CellGroupingRules->{"SectionGrouping", 15},
    ParagraphIndent->-21,
    CounterIncrements->"NumberedItem2",
    StyleMenuListing->None],
  
  Cell[StyleData["NumberedItem2", "Printout"],
    CellMargins->{{27, 0}, {0, 4}}],
  
  Cell[StyleData["NumberedItem2", "EnhancedPrintout"],
    CellMargins->{{27, 0}, {0, 4}}],
  
  Cell[StyleData["NumberedItem2", "EnhancedPrintoutNonGray"],
    CellMargins->{{27, 0}, {0, 4}}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["NumberedItem3"],
    CellMargins->{{94, 4}, {2, 2}},
    CellGroupingRules->{"SectionGrouping", 15},
    ParagraphIndent->-23,
    CounterIncrements->"NumberedItem3",
    StyleMenuListing->None],
  
  Cell[StyleData["NumberedItem3", "Printout"],
    CellMargins->{{27, 0}, {0, 4}}],
  
  Cell[StyleData["NumberedItem3", "EnhancedPrintout"],
    CellMargins->{{27, 0}, {0, 4}}],
  
  Cell[StyleData["NumberedItem3", "EnhancedPrintoutNonGray"],
    CellMargins->{{27, 0}, {0, 4}},
    StyleMenuListing->None]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["PageHeaderBold"],
    CellMargins->{{0, 0}, {2, 0}},
    StyleMenuListing->None,
    FontSize->8,
    FontWeight->"Bold",
    FontSlant->"Italic"],
  
  Cell[StyleData["PageHeaderBold", "Printout"]],
  
  Cell[StyleData["PageHeaderBold", "EnhancedPrintout"],
    FontFamily->"Futura"],
  
  Cell[StyleData["PageHeaderBold", "EnhancedPrintoutNonGray"],
    FontFamily->"Futura"]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["S9"],
    ConversionRules:>{"HTML" -> {"<font=\"Helvetica, Arial\">", "</font>"}},
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->9,
    FontWeight->"Plain"],
  
  Cell[StyleData["S9", "Printout"],
    FontSize->9,
    FontWeight->"Plain"],
  
  Cell[StyleData["S9", "EnhancedPrintout"],
    FontFamily->"Futura",
    FontSize->9,
    FontWeight->"Plain"],
  
  Cell[StyleData["S9", "EnhancedPrintoutNonGray"],
    FontFamily->"Futura",
    FontSize->9,
    FontWeight->"Plain"]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["S10"],
    ConversionRules:>{"HTML" -> {"<font=\"Helvetica, Arial\">", "</font>"}},
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->10,
    FontWeight->"Plain"],
  
  Cell[StyleData["S10", "Printout"],
    FontSize->10,
    FontWeight->"Plain"],
  
  Cell[StyleData["S10", "EnhancedPrintout"],
    FontFamily->"Futura",
    FontSize->10,
    FontWeight->"Plain"],
  
  Cell[StyleData["S10", "EnhancedPrintoutNonGray"],
    FontFamily->"Futura",
    FontSize->10,
    FontWeight->"Plain"]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["SB9"],
    ConversionRules:>{"HTML" -> {"<font=\"Helvetica, Arial\">", "</font>"}},
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->9,
    FontWeight->"Bold",
    PrivateFontOptions->{"OperatorSubstitution"->False}],
  
  Cell[StyleData["SB9", "Printout"],
    FontSize->7],
  
  Cell[StyleData["SB9", "EnhancedPrintout"],
    FontFamily->"Futura",
    FontSize->7],
  
  Cell[StyleData["SB9", "EnhancedPrintoutNonGray"],
    FontFamily->"Futura",
    FontSize->7]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["SB10"],
    ConversionRules:>{"HTML" -> {"<font=\"Helvetica, Arial\">", "</font>"}},
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->10,
    FontWeight->"Bold"],
  
  Cell[StyleData["SB10", "Printout"],
    FontSize->7],
  
  Cell[StyleData["SB10", "EnhancedPrintout"],
    FontFamily->"Futura",
    FontSize->7],
  
  Cell[StyleData["SB10", "EnhancedPrintoutNonGray"],
    FontFamily->"Futura",
    FontSize->7]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["SingleRowTable"],
    CellMargins->{{10, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    PageBreakWithin->False,
    AutoIndent->False,
    AutoSpacing->False,
    LineIndent->0,
    StyleMenuListing->None,
    GridBoxOptions->{RowSpacings->1.5,
    ColumnSpacings->2,
    ColumnAlignments->{Left}}],
  
  Cell[StyleData["SingleRowTable", "Printout"],
    CellMargins->{{2, 0}, {0, 8}}],
  
  Cell[StyleData["SingleRowTable", "EnhancedPrintout"],
    CellMargins->{{2, 0}, {0, 8}}],
  
  Cell[StyleData["SingleRowTable", "EnhancedPrintoutNonGray"],
    CellMargins->{{2, 0}, {0, 8}}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Subsubsubsection"],
    CellMargins->{{10, 4}, {0, 18}},
    CellElementSpacings->{"ClosedGroupTopMargin"->18},
    StyleMenuListing->None,
    FontSize->12,
    FontWeight->"Bold"],
  
  Cell[StyleData["Subsubsubsection", "Printout"],
    CellMargins->{{2, 0}, {3, 8}},
    FontSize->10],
  
  Cell[StyleData["Subsubsubsection", "EnhancedPrintout"],
    CellMargins->{{2, 0}, {3, 8}},
    FontFamily->"Palatino",
    FontSize->10],
  
  Cell[StyleData["Subsubsubsection", "EnhancedPrintoutNonGray"],
    CellMargins->{{2, 0}, {3, 8}},
    FontFamily->"Palatino",
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Subsubtitle"],
    CellMargins->{{12, Inherited}, {20, 15}},
    CellGroupingRules->{"TitleGrouping", 20},
    PageBreakBelow->False,
    DefaultNewInlineCellStyle->"None",
    InputAutoReplacements->{"TeX"->StyleBox[ 
            RowBox[ {"T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.074999999999999997, \
-0.085000000000000006}, {0, 0}}, BoxBaselineShift -> 0.5], "X"}]], 
        "LaTeX"->StyleBox[ 
            RowBox[ {"L", 
              StyleBox[ 
                AdjustmentBox[ 
                "A", BoxMargins -> {{-0.35999999999999999, \
-0.10000000000000001}, {0, 0}}, BoxBaselineShift -> -0.20000000000000001], 
                FontSize -> Smaller], "T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.074999999999999997, \
-0.085000000000000006}, {0, 0}}, BoxBaselineShift -> 0.5], "X"}]], 
        "mma"->"Mathematica", "Mma"->"Mathematica", "MMA"->"Mathematica", 
        "webMathematica"->FormBox[ 
            RowBox[ {"web", 
              AdjustmentBox[ 
                StyleBox[ "Mathematica", FontSlant -> "Italic"], 
                BoxMargins -> {{-0.17499999999999999, 0}, {0, 0}}]}], 
            TextForm]},
    LanguageCategory->"NaturalLanguage",
    CounterIncrements->"Subsubtitle",
    CounterAssignments->{{"Section", 0}, {"Equation", 0}, {"Figure", 0}},
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->14,
    FontSlant->"Italic"],
  
  Cell[StyleData["Subsubtitle", "Printout"],
    CellMargins->{{2, 10}, {8, 10}},
    FontSize->12],
  
  Cell[StyleData["Subsubtitle", "EnhancedPrintout"],
    CellMargins->{{2, 10}, {8, 10}},
    FontFamily->"Futura",
    FontSize->12],
  
  Cell[StyleData["Subsubtitle", "EnhancedPrintoutNonGray"],
    CellMargins->{{2, 10}, {8, 10}},
    FontFamily->"Futura",
    FontSize->12]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Subtitle"],
    CellMargins->{{12, Inherited}, {20, 15}},
    CellGroupingRules->{"TitleGrouping", 10},
    PageBreakBelow->False,
    DefaultNewInlineCellStyle->"None",
    InputAutoReplacements->{"TeX"->StyleBox[ 
            RowBox[ {"T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.074999999999999997, \
-0.085000000000000006}, {0, 0}}, BoxBaselineShift -> 0.5], "X"}]], 
        "LaTeX"->StyleBox[ 
            RowBox[ {"L", 
              StyleBox[ 
                AdjustmentBox[ 
                "A", BoxMargins -> {{-0.35999999999999999, \
-0.10000000000000001}, {0, 0}}, BoxBaselineShift -> -0.20000000000000001], 
                FontSize -> Smaller], "T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.074999999999999997, \
-0.085000000000000006}, {0, 0}}, BoxBaselineShift -> 0.5], "X"}]], 
        "mma"->"Mathematica", "Mma"->"Mathematica", "MMA"->"Mathematica", 
        "webMathematica"->FormBox[ 
            RowBox[ {"web", 
              AdjustmentBox[ 
                StyleBox[ "Mathematica", FontSlant -> "Italic"], 
                BoxMargins -> {{-0.17499999999999999, 0}, {0, 0}}]}], 
            TextForm]},
    LanguageCategory->"NaturalLanguage",
    CounterIncrements->"Subtitle",
    CounterAssignments->{{"Section", 0}, {"Equation", 0}, {"Figure", 0}, {
        "Subsubtitle", 0}},
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->24],
  
  Cell[StyleData["Subtitle", "Printout"],
    CellMargins->{{2, 10}, {10, 15}},
    FontSize->24],
  
  Cell[StyleData["Subtitle", "EnhancedPrintout"],
    CellMargins->{{2, 10}, {10, 15}},
    FontFamily->"Futura",
    FontSize->24],
  
  Cell[StyleData["Subtitle", "EnhancedPrintoutNonGray"],
    CellMargins->{{2, 10}, {10, 15}},
    FontFamily->"Futura",
    FontSize->24]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["TextBelow"],
    CellMargins->{{10, 4}, {0, 14}},
    ConversionRules:>{"HTML" -> {"<p>", "</p>"}},
    InputAutoReplacements->{"TeX"->StyleBox[ 
            RowBox[ {"T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.074999999999999997, \
-0.085000000000000006}, {0, 0}}, BoxBaselineShift -> 0.5], "X"}]], 
        "LaTeX"->StyleBox[ 
            RowBox[ {"L", 
              StyleBox[ 
                AdjustmentBox[ 
                "A", BoxMargins -> {{-0.35999999999999999, \
-0.10000000000000001}, {0, 0}}, BoxBaselineShift -> -0.20000000000000001], 
                FontSize -> Smaller], "T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.074999999999999997, \
-0.085000000000000006}, {0, 0}}, BoxBaselineShift -> 0.5], "X"}]], 
        "mma"->"Mathematica", "Mma"->"Mathematica", "MMA"->"Mathematica", 
        "webMathematica"->FormBox[ 
            RowBox[ {"web", 
              AdjustmentBox[ 
                StyleBox[ "Mathematica", FontSlant -> "Italic"], 
                BoxMargins -> {{-0.17499999999999999, 0}, {0, 0}}]}], 
            TextForm]},
    Hyphenation->True,
    ParagraphSpacing->{0, 8},
    StyleMenuListing->None,
    FontSize->12],
  
  Cell[StyleData["TextBelow", "Printout"],
    CellMargins->{{2, 2}, {6, 12}},
    TextJustification->1,
    FontSize->10],
  
  Cell[StyleData["TextBelow", "EnhancedPrintout"],
    CellMargins->{{2, 2}, {6, 12}},
    TextJustification->1,
    FontFamily->"Palatino",
    FontSize->10],
  
  Cell[StyleData["TextBelow", "EnhancedPrintoutNonGray"],
    CellMargins->{{2, 2}, {6, 12}},
    TextJustification->1,
    FontFamily->"Palatino",
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Title"],
    CellMargins->{{12, Inherited}, {20, 40}},
    CellGroupingRules->{"TitleGrouping", 0},
    PageBreakBelow->False,
    DefaultNewInlineCellStyle->"None",
    InputAutoReplacements->{"TeX"->StyleBox[ 
            RowBox[ {"T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.074999999999999997, \
-0.085000000000000006}, {0, 0}}, BoxBaselineShift -> 0.5], "X"}]], 
        "LaTeX"->StyleBox[ 
            RowBox[ {"L", 
              StyleBox[ 
                AdjustmentBox[ 
                "A", BoxMargins -> {{-0.35999999999999999, \
-0.10000000000000001}, {0, 0}}, BoxBaselineShift -> -0.20000000000000001], 
                FontSize -> Smaller], "T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.074999999999999997, \
-0.085000000000000006}, {0, 0}}, BoxBaselineShift -> 0.5], "X"}]], 
        "mma"->"Mathematica", "Mma"->"Mathematica", "MMA"->"Mathematica", 
        "webMathematica"->FormBox[ 
            RowBox[ {"web", 
              AdjustmentBox[ 
                StyleBox[ "Mathematica", FontSlant -> "Italic"], 
                BoxMargins -> {{-0.17499999999999999, 0}, {0, 0}}]}], 
            TextForm]},
    LanguageCategory->"NaturalLanguage",
    CounterIncrements->"Title",
    CounterAssignments->{{"Section", 0}, {"Equation", 0}, {"Figure", 0}, {
        "Subtitle", 0}, {"Subsubtitle", 0}},
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->36,
    FontWeight->"Bold"],
  
  Cell[StyleData["Title", "Printout"],
    CellMargins->{{2, 10}, {15, 30}},
    FontSize->30],
  
  Cell[StyleData["Title", "EnhancedPrintout"],
    CellMargins->{{2, 10}, {15, 30}},
    FontFamily->"Futura",
    FontSize->30.5],
  
  Cell[StyleData["Title", "EnhancedPrintoutNonGray"],
    CellMargins->{{2, 10}, {15, 30}},
    FontFamily->"Futura",
    FontSize->30.5]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Undersubsection"],
    CellMargins->{{10, 4}, {0, 18}},
    CellElementSpacings->{"ClosedGroupTopMargin"->18},
    ConversionRules:>{"HTML" -> {"<p><font face=\"Helvetica, Arial\"><b>", 
      "</b></font></p>\n"}},
    InputAutoReplacements->{"TeX"->StyleBox[ 
            RowBox[ {"T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.074999999999999997, \
-0.085000000000000006}, {0, 0}}, BoxBaselineShift -> 0.5], "X"}]], 
        "LaTeX"->StyleBox[ 
            RowBox[ {"L", 
              StyleBox[ 
                AdjustmentBox[ 
                "A", BoxMargins -> {{-0.35999999999999999, \
-0.10000000000000001}, {0, 0}}, BoxBaselineShift -> -0.20000000000000001], 
                FontSize -> Smaller], "T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.074999999999999997, \
-0.085000000000000006}, {0, 0}}, BoxBaselineShift -> 0.5], "X"}]], 
        "mma"->"Mathematica", "Mma"->"Mathematica", "MMA"->"Mathematica", 
        "webMathematica"->FormBox[ 
            RowBox[ {"web", 
              AdjustmentBox[ 
                StyleBox[ "Mathematica", FontSlant -> "Italic"], 
                BoxMargins -> {{-0.17499999999999999, 0}, {0, 0}}]}], 
            TextForm]},
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->12,
    FontWeight->"Bold"],
  
  Cell[StyleData["Undersubsection", "Printout"],
    CellMargins->{{2, 0}, {7, 10}},
    FontSize->10],
  
  Cell[StyleData["Undersubsection", "EnhancedPrintout"],
    CellMargins->{{2, 0}, {7, 8}},
    FontFamily->"Futura",
    FontSize->10],
  
  Cell[StyleData["Undersubsection", "EnhancedPrintoutNonGray"],
    CellMargins->{{2, 0}, {7, 8}},
    FontFamily->"Futura",
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["SectionFirst"],
    CellMargins->{{10, 4}, {12, 18}},
    CellGroupingRules->{"SectionGrouping", 30},
    CounterIncrements->"Section",
    FontFamily->"Helvetica",
    FontSize->20,
    FontWeight->"Bold"],
  
  Cell[StyleData["SectionFirst", "Printout"],
    CellMargins->{{2, 0}, {0, 6}},
    PageBreakBelow->False,
    FontSize->18],
  
  Cell[StyleData["SectionFirst", "EnhancedPrintout"],
    CellFrame->{{0, 0}, {0.5, 0}},
    CellMargins->{{2, Inherited}, {5, 6}},
    CellGroupingRules->{"SectionGrouping", 30},
    PageBreakBelow->False,
    CellFrameMargins->8,
    CounterIncrements->"Section",
    CounterAssignments->{{"Subsection", 0}, {"Subsubsection", 0}},
    FontFamily->"Futura",
    FontSize->16],
  
  Cell[StyleData["SectionFirst", "EnhancedPrintoutNonGray"],
    CellFrame->{{0, 0}, {0.5, 0}},
    CellMargins->{{2, Inherited}, {5, 6}},
    CellGroupingRules->{"SectionGrouping", 30},
    PageBreakBelow->False,
    CellFrameMargins->8,
    CounterIncrements->"Section",
    CounterAssignments->{{"Subsection", 0}, {"Subsubsection", 0}},
    FontFamily->"Futura",
    FontSize->16]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["SubsectionFirst"],
    CellDingbat->"\[FilledSquare]",
    CellMargins->{{24, 4}, {0, 18}},
    CellElementSpacings->{"ClosedGroupTopMargin"->18},
    CellGroupingRules->{"SectionGrouping", 40},
    FontFamily->"Helvetica",
    FontSize->16,
    FontWeight->"Bold"],
  
  Cell[StyleData["SubsectionFirst", "SlideShow"],
    CellDingbat->None,
    CellMargins->{{70, 0}, {4, 6}},
    FontSize->12],
  
  Cell[StyleData["SubsectionFirst", "Printout"],
    CellMargins->{{9, 0}, {5, 6}},
    CellBracketOptions->{"Color"->RGBColor[1, 0, 0]},
    FontSize->12],
  
  Cell[StyleData["SubsectionFirst", "EnhancedPrintout"],
    CellMargins->{{9, 0}, {5, 6}},
    CellBracketOptions->{"Color"->RGBColor[1, 0, 0]},
    FontFamily->"Futura",
    FontSize->12],
  
  Cell[StyleData["SubsectionFirst", "EnhancedPrintoutNonGray"],
    CellMargins->{{9, 0}, {5, 6}},
    CellBracketOptions->{"Color"->RGBColor[1, 0, 0]},
    FontFamily->"Futura",
    FontSize->12]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["SubsubsectionFirst"],
    CellMargins->{{10, 4}, {0, 18}},
    CellElementSpacings->{"ClosedGroupTopMargin"->18},
    CellGroupingRules->{"SectionGrouping", 50},
    FontFamily->"Helvetica",
    FontSize->12,
    FontWeight->"Bold"],
  
  Cell[StyleData["SubsubsectionFirst", "Printout"],
    CellMargins->{{2, 0}, {3, 3}},
    CellBracketOptions->{"Color"->RGBColor[1, 0, 0]},
    FontSize->10],
  
  Cell[StyleData["SubsubsectionFirst", "EnhancedPrintout"],
    CellMargins->{{2, 0}, {3, 3}},
    CellBracketOptions->{"Color"->RGBColor[1, 0, 0]},
    FontFamily->"Futura",
    FontSize->10],
  
  Cell[StyleData["SubsubsectionFirst", "EnhancedPrintoutNonGray"],
    CellMargins->{{2, 0}, {3, 3}},
    CellBracketOptions->{"Color"->RGBColor[1, 0, 0]},
    FontFamily->"Futura",
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["SubsubsubsectionFirst"],
    CellMargins->{{10, 4}, {0, 12}},
    CellElementSpacings->{"ClosedGroupTopMargin"->18},
    StyleMenuListing->None,
    FontSize->12,
    FontWeight->"Bold"],
  
  Cell[StyleData["SubsubsubsectionFirst", "Printout"],
    CellMargins->{{2, 0}, {3, 3}},
    FontSize->10],
  
  Cell[StyleData["SubsubsubsectionFirst", "EnhancedPrintout"],
    CellMargins->{{2, 0}, {3, 3}},
    FontFamily->"Palatino",
    FontSize->10],
  
  Cell[StyleData["SubsubsubsectionFirst", "EnhancedPrintoutNonGray"],
    CellMargins->{{2, 0}, {3, 3}},
    FontFamily->"Palatino",
    FontSize->10]
  }, Closed]],
  
  Cell["Spacer Cell", "Text"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Spacer"],
    CellMargins->{{10, 10}, {0, 0}},
    CellElementSpacings->{"CellMinHeight"->2,
    "ClosedCellHeight"->1},
    CellOpen->False,
    StyleMenuListing->None],
  
  Cell[StyleData["Spacer", "Printout"],
    CellOpen->True,
    FontSize->3]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["DiscretionaryHyphen"],
    StyleMenuListing->None,
    FontSize->0.0625,
    FontColor->GrayLevel[1]],
  
  Cell[StyleData["DiscretionaryHyphen", "Printout"],
    FontSize->10,
    FontColor->GrayLevel[0]],
  
  Cell[StyleData["DiscretionaryHyphen", "EnhancedPrintout"],
    FontSize->10,
    FontColor->GrayLevel[0]],
  
  Cell[StyleData["DiscretionaryHyphen", "EnhancedPrintoutNonGray"],
    FontSize->10,
    FontColor->GrayLevel[0]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["PictureSmaller1"],
    CellMargins->{{10, Inherited}, {4, 4}},
    CellGroupingRules->"GraphicsGrouping",
    CellHorizontalScrolling->True,
    StyleMenuListing->None],
  
  Cell[StyleData["PictureSmaller1", "Printout"],
    CellMargins->{{2, Inherited}, {4, 4}},
    Magnification->0.63],
  
  Cell[StyleData["PictureSmaller1", "EnhancedPrintout"],
    CellMargins->{{2, Inherited}, {4, 2}},
    Magnification->0.63],
  
  Cell[StyleData["PictureSmaller1", "EnhancedPrintoutNonGray"],
    CellMargins->{{2, Inherited}, {4, 2}},
    Magnification->0.63]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["PictureSmaller2"],
    CellMargins->{{10, Inherited}, {4, 4}},
    CellGroupingRules->"GraphicsGrouping",
    CellHorizontalScrolling->True,
    StyleMenuListing->None],
  
  Cell[StyleData["PictureSmaller2", "Printout"],
    CellMargins->{{2, Inherited}, {4, 4}},
    Magnification->0.61],
  
  Cell[StyleData["PictureSmaller2", "EnhancedPrintout"],
    CellMargins->{{2, Inherited}, {4, 2}},
    Magnification->0.61],
  
  Cell[StyleData["PictureSmaller2", "EnhancedPrintoutNonGray"],
    CellMargins->{{2, Inherited}, {4, 2}},
    Magnification->0.61]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["PictureSmaller3"],
    CellMargins->{{10, Inherited}, {4, 4}},
    CellGroupingRules->"GraphicsGrouping",
    CellHorizontalScrolling->True,
    StyleMenuListing->None],
  
  Cell[StyleData["PictureSmaller3", "Printout"],
    CellMargins->{{2, Inherited}, {4, 4}},
    Magnification->0.59],
  
  Cell[StyleData["PictureSmaller3", "EnhancedPrintout"],
    CellMargins->{{2, Inherited}, {4, 2}},
    Magnification->0.59],
  
  Cell[StyleData["PictureSmaller3", "EnhancedPrintoutNonGray"],
    CellMargins->{{2, Inherited}, {4, 2}},
    Magnification->0.59]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["PictureSmaller4"],
    CellMargins->{{10, Inherited}, {4, 4}},
    CellGroupingRules->"GraphicsGrouping",
    CellHorizontalScrolling->True,
    StyleMenuListing->None],
  
  Cell[StyleData["PictureSmaller4", "Printout"],
    CellMargins->{{2, Inherited}, {4, 4}},
    Magnification->0.57],
  
  Cell[StyleData["PictureSmaller4", "EnhancedPrintout"],
    CellMargins->{{2, Inherited}, {4, 2}},
    Magnification->0.57],
  
  Cell[StyleData["PictureSmaller4", "EnhancedPrintoutNonGray"],
    CellMargins->{{2, Inherited}, {4, 2}},
    Magnification->0.57]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["PictureSmaller5"],
    CellMargins->{{10, Inherited}, {4, 4}},
    CellGroupingRules->"GraphicsGrouping",
    CellHorizontalScrolling->True,
    StyleMenuListing->None],
  
  Cell[StyleData["PictureSmaller5", "Printout"],
    CellMargins->{{2, Inherited}, {4, 4}},
    Magnification->0.55],
  
  Cell[StyleData["PictureSmaller5", "EnhancedPrintout"],
    CellMargins->{{2, Inherited}, {4, 2}},
    Magnification->0.55],
  
  Cell[StyleData["PictureSmaller5", "EnhancedPrintoutNonGray"],
    CellMargins->{{2, Inherited}, {4, 2}},
    Magnification->0.55]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["PictureSmaller6"],
    CellMargins->{{10, Inherited}, {4, 4}},
    CellGroupingRules->"GraphicsGrouping",
    CellHorizontalScrolling->True,
    StyleMenuListing->None],
  
  Cell[StyleData["PictureSmaller6", "Printout"],
    CellMargins->{{2, Inherited}, {4, 4}},
    Magnification->0.53],
  
  Cell[StyleData["PictureSmaller6", "EnhancedPrintout"],
    CellMargins->{{2, Inherited}, {4, 2}},
    Magnification->0.53],
  
  Cell[StyleData["PictureSmaller6", "EnhancedPrintoutNonGray"],
    CellMargins->{{2, Inherited}, {4, 2}},
    Magnification->0.53]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["ItemPicture"],
    CellMargins->{{41, Inherited}, {4, 2}},
    CellGroupingRules->"GraphicsGrouping",
    CellHorizontalScrolling->True,
    StyleMenuListing->None],
  
  Cell[StyleData["ItemPicture", "Printout"],
    CellMargins->{{55, Inherited}, {8, -4}},
    Magnification->0.65],
  
  Cell[StyleData["ItemPicture", "EnhancedPrintout"],
    CellMargins->{{60, Inherited}, {10, -3}},
    Magnification->0.65],
  
  Cell[StyleData["ItemPicture", "EnhancedPrintoutNonGray"],
    CellMargins->{{60, Inherited}, {10, -3}},
    Magnification->0.65]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["ItemPictureSmaller1"],
    CellMargins->{{41, Inherited}, {4, 2}},
    CellGroupingRules->"GraphicsGrouping",
    CellHorizontalScrolling->True,
    StyleMenuListing->None],
  
  Cell[StyleData["ItemPictureSmaller1", "Printout"],
    CellMargins->{{56, Inherited}, {9, -3}},
    Magnification->0.63],
  
  Cell[StyleData["ItemPictureSmaller1", "EnhancedPrintout"],
    CellMargins->{{63, Inherited}, {10, -3}},
    Magnification->0.63],
  
  Cell[StyleData["ItemPictureSmaller1", "EnhancedPrintoutNonGray"],
    CellMargins->{{63, Inherited}, {10, -3}},
    Magnification->0.63]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["ItemPictureSmaller2"],
    CellMargins->{{41, Inherited}, {4, 2}},
    CellGroupingRules->"GraphicsGrouping",
    CellHorizontalScrolling->True,
    StyleMenuListing->None],
  
  Cell[StyleData["ItemPictureSmaller2", "Printout"],
    CellMargins->{{58, Inherited}, {8, -4}},
    Magnification->0.61],
  
  Cell[StyleData["ItemPictureSmaller2", "EnhancedPrintout"],
    CellMargins->{{65, Inherited}, {11, -3}},
    Magnification->0.61],
  
  Cell[StyleData["ItemPictureSmaller2", "EnhancedPrintoutNonGray"],
    CellMargins->{{65, Inherited}, {11, -3}},
    Magnification->0.61]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["ItemPictureSmaller3"],
    CellMargins->{{41, Inherited}, {4, 2}},
    CellGroupingRules->"GraphicsGrouping",
    CellHorizontalScrolling->True,
    StyleMenuListing->None],
  
  Cell[StyleData["ItemPictureSmaller3", "Printout"],
    CellMargins->{{61, Inherited}, {10, -2}},
    Magnification->0.59],
  
  Cell[StyleData["ItemPictureSmaller3", "EnhancedPrintout"],
    CellMargins->{{67, Inherited}, {11, -3}},
    Magnification->0.59],
  
  Cell[StyleData["ItemPictureSmaller3", "EnhancedPrintoutNonGray"],
    CellMargins->{{67, Inherited}, {11, -3}},
    Magnification->0.59]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["ItemPictureSmaller4"],
    CellMargins->{{41, Inherited}, {4, 2}},
    CellGroupingRules->"GraphicsGrouping",
    CellHorizontalScrolling->True,
    StyleMenuListing->None],
  
  Cell[StyleData["ItemPictureSmaller4", "Printout"],
    CellMargins->{{63, Inherited}, {10, -2}},
    Magnification->0.57],
  
  Cell[StyleData["ItemPictureSmaller4", "EnhancedPrintout"],
    CellMargins->{{69, Inherited}, {12, -4}},
    Magnification->0.57],
  
  Cell[StyleData["ItemPictureSmaller4", "EnhancedPrintoutNonGray"],
    CellMargins->{{69, Inherited}, {12, -4}},
    Magnification->0.57]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["ItemPictureSmaller5"],
    CellMargins->{{41, Inherited}, {4, 2}},
    CellGroupingRules->"GraphicsGrouping",
    CellHorizontalScrolling->True,
    StyleMenuListing->None],
  
  Cell[StyleData["ItemPictureSmaller5", "Printout"],
    CellMargins->{{65, Inherited}, {11, -2}},
    Magnification->0.55],
  
  Cell[StyleData["ItemPictureSmaller5", "EnhancedPrintout"],
    CellMargins->{{71, Inherited}, {13, -2}},
    Magnification->0.55],
  
  Cell[StyleData["ItemPictureSmaller5", "EnhancedPrintoutNonGray"],
    CellMargins->{{71, Inherited}, {13, -2}},
    Magnification->0.55]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["ItemPictureSmaller6"],
    CellMargins->{{41, Inherited}, {4, 2}},
    CellGroupingRules->"GraphicsGrouping",
    CellHorizontalScrolling->True,
    StyleMenuListing->None],
  
  Cell[StyleData["ItemPictureSmaller6", "Printout"],
    CellMargins->{{67, Inherited}, {12, -2}},
    Magnification->0.53],
  
  Cell[StyleData["ItemPictureSmaller6", "EnhancedPrintout"],
    CellMargins->{{74, Inherited}, {13, -3}},
    Magnification->0.53],
  
  Cell[StyleData["ItemPictureSmaller6", "EnhancedPrintoutNonGray"],
    CellMargins->{{74, Inherited}, {13, -3}},
    Magnification->0.53]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["PictureBigger1"],
    CellMargins->{{10, Inherited}, {4, 4}},
    CellGroupingRules->"GraphicsGrouping",
    CellHorizontalScrolling->True,
    StyleMenuListing->None],
  
  Cell[StyleData["PictureBigger1", "Printout"],
    CellMargins->{{2, Inherited}, {4, 4}},
    Magnification->0.68],
  
  Cell[StyleData["PictureBigger1", "EnhancedPrintout"],
    CellMargins->{{2, Inherited}, {4, 2}},
    Magnification->0.68],
  
  Cell[StyleData["PictureBigger1", "EnhancedPrintoutNonGray"],
    CellMargins->{{2, Inherited}, {4, 2}},
    Magnification->0.68]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["PictureBigger2"],
    CellMargins->{{10, Inherited}, {4, 4}},
    CellGroupingRules->"GraphicsGrouping",
    CellHorizontalScrolling->True,
    StyleMenuListing->None],
  
  Cell[StyleData["PictureBigger2", "Printout"],
    CellMargins->{{2, Inherited}, {4, 4}},
    Magnification->0.71],
  
  Cell[StyleData["PictureBigger2", "EnhancedPrintout"],
    CellMargins->{{2, Inherited}, {4, 2}},
    Magnification->0.71],
  
  Cell[StyleData["PictureBigger2", "EnhancedPrintoutNonGray"],
    CellMargins->{{2, Inherited}, {4, 2}},
    Magnification->0.71]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["PictureBigger3"],
    CellMargins->{{10, Inherited}, {4, 4}},
    CellGroupingRules->"GraphicsGrouping",
    CellHorizontalScrolling->True,
    StyleMenuListing->None],
  
  Cell[StyleData["PictureBigger3", "Printout"],
    CellMargins->{{2, Inherited}, {4, 4}},
    Magnification->0.74],
  
  Cell[StyleData["PictureBigger3", "EnhancedPrintout"],
    CellMargins->{{2, Inherited}, {4, 2}},
    Magnification->0.74],
  
  Cell[StyleData["PictureBigger3", "EnhancedPrintoutNonGray"],
    CellMargins->{{2, Inherited}, {4, 2}},
    Magnification->0.74]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["PictureBigger4"],
    CellMargins->{{10, Inherited}, {4, 4}},
    CellGroupingRules->"GraphicsGrouping",
    CellHorizontalScrolling->True,
    StyleMenuListing->None],
  
  Cell[StyleData["PictureBigger4", "Printout"],
    CellMargins->{{2, Inherited}, {4, 4}},
    Magnification->0.77],
  
  Cell[StyleData["PictureBigger4", "EnhancedPrintout"],
    CellMargins->{{2, Inherited}, {4, 2}},
    Magnification->0.77],
  
  Cell[StyleData["PictureBigger4", "EnhancedPrintoutNonGray"],
    CellMargins->{{2, Inherited}, {4, 2}},
    Magnification->0.77]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["PictureBigger5"],
    CellMargins->{{10, Inherited}, {4, 4}},
    CellGroupingRules->"GraphicsGrouping",
    CellHorizontalScrolling->True,
    StyleMenuListing->None],
  
  Cell[StyleData["PictureBigger5", "Printout"],
    CellMargins->{{2, Inherited}, {4, 4}},
    Magnification->0.8],
  
  Cell[StyleData["PictureBigger5", "EnhancedPrintout"],
    CellMargins->{{2, Inherited}, {4, 2}},
    Magnification->0.8],
  
  Cell[StyleData["PictureBigger5", "EnhancedPrintoutNonGray"],
    CellMargins->{{2, Inherited}, {4, 2}},
    Magnification->0.8]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["PictureBigger6"],
    CellMargins->{{10, Inherited}, {4, 4}},
    CellGroupingRules->"GraphicsGrouping",
    CellHorizontalScrolling->True,
    StyleMenuListing->None],
  
  Cell[StyleData["PictureBigger6", "Printout"],
    CellMargins->{{2, Inherited}, {4, 4}},
    Magnification->0.83],
  
  Cell[StyleData["PictureBigger6", "EnhancedPrintout"],
    CellMargins->{{2, Inherited}, {4, 2}},
    Magnification->0.83],
  
  Cell[StyleData["PictureBigger6", "EnhancedPrintoutNonGray"],
    CellMargins->{{2, Inherited}, {4, 2}},
    Magnification->0.83]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["ItemPictureBigger1"],
    CellMargins->{{41, Inherited}, {4, 2}},
    CellGroupingRules->"GraphicsGrouping",
    CellHorizontalScrolling->True,
    StyleMenuListing->None],
  
  Cell[StyleData["ItemPictureBigger1", "Printout"],
    CellMargins->{{50, Inherited}, {9, -3}},
    Magnification->0.68],
  
  Cell[StyleData["ItemPictureBigger1", "EnhancedPrintout"],
    CellMargins->{{57, Inherited}, {10, -3}},
    Magnification->0.68],
  
  Cell[StyleData["ItemPictureBigger1", "EnhancedPrintoutNonGray"],
    CellMargins->{{57, Inherited}, {10, -3}},
    Magnification->0.68]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["ItemPictureBigger2"],
    CellMargins->{{41, Inherited}, {4, 2}},
    CellGroupingRules->"GraphicsGrouping",
    CellHorizontalScrolling->True,
    StyleMenuListing->None],
  
  Cell[StyleData["ItemPictureBigger2", "Printout"],
    CellMargins->{{48, Inherited}, {8, -4}},
    Magnification->0.71],
  
  Cell[StyleData["ItemPictureBigger2", "EnhancedPrintout"],
    CellMargins->{{54, Inherited}, {10, -3}},
    Magnification->0.71],
  
  Cell[StyleData["ItemPictureBigger2", "EnhancedPrintoutNonGray"],
    CellMargins->{{54, Inherited}, {10, -3}},
    Magnification->0.71]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["ItemPictureBigger3"],
    CellMargins->{{41, Inherited}, {4, 2}},
    CellGroupingRules->"GraphicsGrouping",
    CellHorizontalScrolling->True,
    StyleMenuListing->None],
  
  Cell[StyleData["ItemPictureBigger3", "Printout"],
    CellMargins->{{46, Inherited}, {10, -2}},
    Magnification->0.74],
  
  Cell[StyleData["ItemPictureBigger3", "EnhancedPrintout"],
    CellMargins->{{52, Inherited}, {10, -3}},
    Magnification->0.74],
  
  Cell[StyleData["ItemPictureBigger3", "EnhancedPrintoutNonGray"],
    CellMargins->{{52, Inherited}, {10, -3}},
    Magnification->0.74]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["ItemPictureBigger4"],
    CellMargins->{{41, Inherited}, {4, 2}},
    CellGroupingRules->"GraphicsGrouping",
    CellHorizontalScrolling->True,
    StyleMenuListing->None],
  
  Cell[StyleData["ItemPictureBigger4", "Printout"],
    CellMargins->{{45, Inherited}, {10, -2}},
    Magnification->0.77],
  
  Cell[StyleData["ItemPictureBigger4", "EnhancedPrintout"],
    CellMargins->{{50, Inherited}, {10, -3}},
    Magnification->0.77],
  
  Cell[StyleData["ItemPictureBigger4", "EnhancedPrintoutNonGray"],
    CellMargins->{{50, Inherited}, {10, -3}},
    Magnification->0.77]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["ItemPictureBigger5"],
    CellMargins->{{41, Inherited}, {4, 2}},
    CellGroupingRules->"GraphicsGrouping",
    CellHorizontalScrolling->True,
    StyleMenuListing->None],
  
  Cell[StyleData["ItemPictureBigger5", "Printout"],
    CellMargins->{{43, Inherited}, {11, -2}},
    Magnification->0.8],
  
  Cell[StyleData["ItemPictureBigger5", "EnhancedPrintout"],
    CellMargins->{{49, Inherited}, {10, -3}},
    Magnification->0.8],
  
  Cell[StyleData["ItemPictureBigger5", "EnhancedPrintoutNonGray"],
    CellMargins->{{49, Inherited}, {10, -3}},
    Magnification->0.8]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["ItemPictureBigger6"],
    CellMargins->{{41, Inherited}, {4, 2}},
    CellGroupingRules->"GraphicsGrouping",
    CellHorizontalScrolling->True,
    StyleMenuListing->None],
  
  Cell[StyleData["ItemPictureBigger6", "Printout"],
    CellMargins->{{43, Inherited}, {12, -2}},
    Magnification->0.83],
  
  Cell[StyleData["ItemPictureBigger6", "EnhancedPrintout"],
    CellMargins->{{46, Inherited}, {8, -2}},
    Magnification->0.83],
  
  Cell[StyleData["ItemPictureBigger6", "EnhancedPrintoutNonGray"],
    CellMargins->{{46, Inherited}, {8, -2}},
    Magnification->0.83]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["ScreenGraphic"],
    CellMargins->{{12, Inherited}, {0, 8}},
    CellHorizontalScrolling->True,
    StyleMenuListing->None],
  
  Cell[StyleData["ScreenGraphic", "Printout"],
    CellMargins->{{2, Inherited}, {0, 8}}],
  
  Cell[StyleData["ScreenGraphic", "EnhancedPrintout"],
    CellMargins->{{2, Inherited}, {0, 8}},
    CellElementSpacings->{"CellMinHeight"->2,
    "ClosedCellHeight"->2},
    CellOpen->False],
  
  Cell[StyleData["ScreenGraphic", "EnhancedPrintoutNonGray"],
    CellMargins->{{2, Inherited}, {0, 8}},
    CellElementSpacings->{"CellMinHeight"->2,
    "ClosedCellHeight"->2},
    CellOpen->False]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["PrintGraphic"],
    CellMargins->{{12, Inherited}, {0, 8}},
    CellElementSpacings->{"CellMinHeight"->2,
    "ClosedCellHeight"->2},
    CellOpen->False,
    CellHorizontalScrolling->True,
    StyleMenuListing->None],
  
  Cell[StyleData["PrintGraphic", "Printout"],
    CellMargins->{{2, Inherited}, {0, 8}},
    CellElementSpacings->{"CellMinHeight"->2,
    "ClosedCellHeight"->2},
    CellOpen->False],
  
  Cell[StyleData["PrintGraphic", "EnhancedPrintout"],
    CellMargins->{{2, Inherited}, {0, 8}},
    CellElementSpacings->{"CellMinHeight"->12},
    CellOpen->True],
  
  Cell[StyleData["PrintGraphic", "EnhancedPrintoutNonGray"],
    CellMargins->{{2, Inherited}, {0, 8}},
    CellElementSpacings->{"CellMinHeight"->12},
    CellOpen->True]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["SmallTextSans"],
    CellMargins->{{10, 4}, {8, 8}},
    ConversionRules:>{"HTML" -> {
      "<FONT SIZE=\"-1\" FACE=\"Helvetica, Arial\">", "</FONT>\n"}},
    TextJustification->1,
    Hyphenation->True,
    LineSpacing->{1, 2},
    FontFamily->"Helvetica",
    FontSize->9],
  
  Cell[StyleData["SmallTextSans", "Printout"],
    CellMargins->{{2, 0}, {0, 8}},
    FontSize->7],
  
  Cell[StyleData["SmallTextSans", "EnhancedPrintout"],
    CellMargins->{{2, 0}, {0, 8}},
    LineSpacing->{1, 1},
    ParagraphSpacing->{0, -2},
    FontFamily->"Futura",
    FontSize->7]
  }, Closed]]
  }, Closed]]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["AuthorTools", "Section"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["BilateralCell"],
    CellMargins->{{10, 4}, {0, 8}},
    StyleMenuListing->None,
    FontSize->12,
    GridBoxOptions->{ColumnWidths->{0.33, 0.6},
    RowAlignments->Top,
    ColumnAlignments->{Left}}],
  
  Cell[StyleData["BilateralCell", "SlideShow"],
    CellMargins->{{36, 24}, {4, 4}},
    Background->GrayLevel[0.900008]],
  
  Cell[StyleData["BilateralCell", "Printout"],
    CellMargins->{{2, 2}, {6, 6}},
    TextJustification->1,
    FontSize->10],
  
  Cell[StyleData["BilateralCell", "EnhancedPrintout"],
    CellMargins->{{2, 2}, {6, 6}},
    TextJustification->1,
    FontFamily->"Palatino",
    FontSize->10],
  
  Cell[StyleData["BilateralCell", "EnhancedPrintoutNonGray"],
    CellMargins->{{2, 2}, {6, 6}},
    TextJustification->1,
    FontFamily->"Palatino",
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["RuledPageBreak"],
    CellFrame->{{0, 0}, {0.25, 0}},
    CellMargins->{{10, 4}, {12, 0}},
    CellFrameMargins->{{0, 0}, {1, 0}},
    FontSize->8],
  
  Cell[StyleData["RuledPageBreak", "SlideShow"],
    CellMargins->{{36, 24}, {4, 4}}],
  
  Cell[StyleData["RuledPageBreak", "Printout"],
    CellMargins->{{2, 2}, {6, 6}},
    PageBreakBelow->True,
    FontSize->1],
  
  Cell[StyleData["RuledPageBreak", "EnhancedPrintout"],
    CellMargins->{{2, 2}, {6, 6}},
    PageBreakBelow->True],
  
  Cell[StyleData["RuledPageBreak", "EnhancedPrintoutNonGray"],
    CellMargins->{{2, 2}, {6, 6}},
    PageBreakBelow->True]
  }, Closed]],
  
  Cell[StyleData["PaletteTitle"],
    CellFrame->{{0, 0}, {1, 0}},
    CellMargins->{{4, 20}, {Inherited, 0}},
    StyleMenuListing->None,
    ButtonStyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->14,
    FontWeight->"Bold",
    FontColor->GrayLevel[1],
    Background->RGBColor[0, 0.32549, 0.537255],
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`HelpBrowserLookup[ "AddOns", #2]}]&),
    ButtonEvaluator->None,
    ButtonStyle->"PaletteButton",
    ButtonMargins->3}],
  
  Cell[StyleData["PaletteButton"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->12,
    FontWeight->"Bold",
    FontColor->GrayLevel[1],
    ButtonBoxOptions->{ButtonEvaluator->"Local",
    Active->True,
    ButtonMargins->6,
    Background->RGBColor[0.329412, 0.584314, 0.694118]}],
  
  Cell[StyleData["PaletteButton2"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->12,
    FontWeight->"Bold",
    FontColor->GrayLevel[1],
    ButtonBoxOptions->{ButtonEvaluator->"Local",
    Active->True,
    ButtonMargins->4,
    Background->RGBColor[0.537255, 0.72549, 0.843137]}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Outline Styles", "Section"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Outline1"],
    CellMargins->{{12, 10}, {7, 7}},
    CellGroupingRules->{"SectionGrouping", 50},
    ParagraphIndent->-38,
    CounterIncrements->"Outline1",
    FontSize->18,
    FontWeight->"Bold",
    CounterBoxOptions->{
    CounterFunction:>Utilities`Notation`Private`CapitalRomanNumeral}],
  
  Cell[StyleData["Outline1", "Printout"],
    CounterBoxOptions->{
    CounterFunction:>Utilities`Notation`Private`CapitalRomanNumeral}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Outline2"],
    CellMargins->{{48, 10}, {6, 6}},
    CellGroupingRules->{"SectionGrouping", 60},
    ParagraphIndent->-27,
    CounterIncrements->"Outline2",
    FontSize->15,
    FontWeight->"Bold",
    CounterBoxOptions->{CounterFunction:>(Part[ 
        CharacterRange[ "A", "Z"], #]&)}],
  
  Cell[StyleData["Outline2", "Printout"],
    CounterBoxOptions->{CounterFunction:>(Part[ 
        CharacterRange[ "A", "Z"], #]&)}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Outline3"],
    CellMargins->{{84, 10}, {5, 5}},
    CellGroupingRules->{"SectionGrouping", 70},
    ParagraphIndent->-21,
    CounterIncrements->"Outline3",
    FontSize->12,
    CounterBoxOptions->{CounterFunction:>Identity}],
  
  Cell[StyleData["Outline3", "Printout"],
    CounterBoxOptions->{CounterFunction:>Identity}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Outline4"],
    CellMargins->{{120, 10}, {4, 4}},
    CellGroupingRules->{"SectionGrouping", 80},
    ParagraphIndent->-18,
    CounterIncrements->"Outline4",
    FontSize->10,
    CounterBoxOptions->{CounterFunction:>(Part[ 
        CharacterRange[ "a", "z"], #]&)}],
  
  Cell[StyleData["Outline4", "Printout"]]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Slide Show Styles", "Section"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["SlideShowNavigationBar"],
    Editable->False,
    CellFrame->True,
    CellMargins->{{0, 0}, {3, 3}},
    CellElementSpacings->{"CellMinHeight"->0.8125},
    CellGroupingRules->{"SectionGrouping", 30},
    CellFrameMargins->False,
    CellFrameColor->GrayLevel[1],
    CellFrameLabelMargins->False,
    TextAlignment->Center,
    CounterIncrements->"SlideShowNavigationBar",
    StyleMenuListing->None,
    FontSize->10,
    Background->GrayLevel[0.8],
    Magnification->1,
    GridBoxOptions->{GridBaseline->Center,
    RowSpacings->0,
    ColumnSpacings->0,
    ColumnWidths->{3.5, 3.5, 3.5, 3.5, 13, 5, 4},
    RowAlignments->Baseline,
    ColumnAlignments->{
      Center, Center, Center, Center, Center, Center, Right, Center}}],
  
  Cell[StyleData["SlideShowNavigationBar", "SlideShow"],
    Deletable->False,
    ShowCellBracket->False,
    CellMargins->{{-1, -1}, {-1, -1}},
    PageBreakAbove->True,
    CellFrameMargins->{{1, 1}, {0, 0}}],
  
  Cell[StyleData["SlideShowNavigationBar", "Printout"],
    CellMargins->{{18, 4}, {4, 4}},
    LineSpacing->{1, 3},
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["SlideShowSection"],
    CellFrame->{{0, 0}, {0, 0.5}},
    CellMargins->{{0, 0}, {10, 0}},
    CellGroupingRules->{"SectionGrouping", 40},
    PageBreakBelow->False,
    CellFrameMargins->{{12, 4}, {6, 12}},
    InputAutoReplacements->{"TeX"->StyleBox[ 
            RowBox[ {"T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.074999999999999997, \
-0.085000000000000006}, {0, 0}}, BoxBaselineShift -> 0.5], "X"}]], 
        "LaTeX"->StyleBox[ 
            RowBox[ {"L", 
              StyleBox[ 
                AdjustmentBox[ 
                "A", BoxMargins -> {{-0.35999999999999999, \
-0.10000000000000001}, {0, 0}}, BoxBaselineShift -> -0.20000000000000001], 
                FontSize -> Smaller], "T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.074999999999999997, \
-0.085000000000000006}, {0, 0}}, BoxBaselineShift -> 0.5], "X"}]], 
        "mma"->"Mathematica", "Mma"->"Mathematica", "MMA"->"Mathematica", 
        "webMathematica"->FormBox[ 
            RowBox[ {"web", 
              AdjustmentBox[ 
                StyleBox[ "Mathematica", FontSlant -> "Italic"], 
                BoxMargins -> {{-0.17499999999999999, 0}, {0, 0}}]}], 
            TextForm], Inherited},
    CounterIncrements->"Section",
    CounterAssignments->{{"Subsection", 0}, {"Subsubsection", 0}},
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->18,
    FontWeight->"Plain",
    FontColor->GrayLevel[1],
    Background->RGBColor[0.408011, 0.440726, 0.8]],
  
  Cell[StyleData["SlideShowSection", "SlideShow"],
    ShowCellBracket->False,
    PageBreakAbove->True],
  
  Cell[StyleData["SlideShowSection", "Printout"],
    CellMargins->{{18, 30}, {0, 30}},
    CellFrameMargins->5,
    FontSize->14]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["SlideHyperlink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontSize->26,
    FontColor->GrayLevel[0.400015],
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`NotebookLocate[ #2]}]&),
    Active->True,
    ButtonMinHeight->0.85,
    ButtonMargins->0.5,
    ButtonNote->None}],
  
  Cell[StyleData["SlideHyperlink", "SlideShow"]],
  
  Cell[StyleData["SlideHyperlink", "Printout"],
    FontSize->10,
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["SlideTOCLink"],
    CellMargins->{{24, Inherited}, {Inherited, Inherited}},
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontFamily->"Helvetica",
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`NotebookLocate[ #2]}]&),
    Active->True,
    ButtonMargins->1.5,
    ButtonNote->ButtonData}],
  
  Cell[StyleData["SlideTOCLink", "SlideShow"]],
  
  Cell[StyleData["SlideTOCLink", "Printout"],
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["SlideTOC"],
    CellDingbat->"\[Bullet]",
    CellMargins->{{18, Inherited}, {Inherited, Inherited}},
    StyleMenuListing->None,
    FontFamily->"Helvetica"],
  
  Cell[StyleData["SlideTOC", "SlideShow"],
    FontSize->14],
  
  Cell[StyleData["SlideTOC", "Printout"],
    FontSize->10,
    FontColor->GrayLevel[0]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["1ColumnBox"],
    CellMargins->{{10, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    LineIndent->0,
    StyleMenuListing->None,
    Background->RGBColor[1, 0.6, 0.6],
    FrameBoxOptions->{BoxFrame->0.5,
    BoxMargins->True},
    GridBoxOptions->{ColumnSpacings->1}],
  
  Cell[StyleData["1ColumnBox", "Printout"],
    CellMargins->{{2, 0}, {0, 8}},
    FontSize->10,
    Background->GrayLevel[0.900008]],
  
  Cell[StyleData["1ColumnBox", "SlideShow"],
    CellMargins->{{36, 36}, {3, 6}},
    Background->RGBColor[0.700008, 0.849989, 0.949996]],
  
  Cell[StyleData["1ColumnBox", "EnhancedPrintout"],
    CellMargins->{{2, 0}, {0, 8}},
    FontSize->10,
    Background->GrayLevel[0.900008]],
  
  Cell[StyleData["1ColumnBox", "EnhancedPrintoutNonGray"],
    CellMargins->{{2, 0}, {3, 8}},
    FontSize->10,
    Background->GrayLevel[1]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["2ColumnBox"],
    CellMargins->{{10, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    LineIndent->0,
    StyleMenuListing->None,
    Background->RGBColor[1, 0.6, 0.6],
    FrameBoxOptions->{BoxFrame->0.5,
    BoxMargins->True},
    GridBoxOptions->{ColumnWidths->{0.31, 0.67}}],
  
  Cell[StyleData["2ColumnBox", "Printout"],
    CellMargins->{{2, 0}, {0, 8}},
    FontSize->9,
    Background->GrayLevel[0.900008]],
  
  Cell[StyleData["2ColumnBox", "SlideShow"],
    CellMargins->{{36, 36}, {6, 6}},
    Background->RGBColor[0.700008, 0.849989, 0.949996]],
  
  Cell[StyleData["2ColumnBox", "EnhancedPrintout"],
    CellMargins->{{2, 0}, {0, 8}},
    FontSize->9,
    Background->GrayLevel[0.900008]],
  
  Cell[StyleData["2ColumnBox", "EnhancedPrintoutNonGray"],
    CellMargins->{{2, 0}, {0, 8}},
    FontSize->9,
    Background->GrayLevel[1]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["DefinitionBox"],
    CellFrame->0.5,
    CellMargins->{{10, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    PageBreakWithin->False,
    AutoIndent->False,
    AutoSpacing->False,
    LineIndent->0,
    StyleMenuListing->None,
    FontWeight->"Plain",
    Background->RGBColor[1, 0.6, 0.6],
    GridBoxOptions->{RowSpacings->1.5,
    ColumnSpacings->1,
    ColumnWidths->{0.4, 0.6},
    ColumnAlignments->{Left}}],
  
  Cell[StyleData["DefinitionBox", "Printout"],
    CellMargins->{{2, 4}, {0, 8}},
    FontSize->10,
    Background->GrayLevel[1]],
  
  Cell[StyleData["DefinitionBox", "SlideShow"],
    CellMargins->{{36, 36}, {6, 6}},
    Background->RGBColor[0.700008, 0.849989, 0.949996]],
  
  Cell[StyleData["DefinitionBox", "EnhancedPrintout"],
    CellMargins->{{2, 4}, {0, 8}},
    FontFamily->"Palatino",
    FontSize->10,
    Background->GrayLevel[1]],
  
  Cell[StyleData["DefinitionBox", "EnhancedPrintoutNonGray"],
    CellMargins->{{2, 4}, {0, 8}},
    FontFamily->"Palatino",
    FontSize->10,
    Background->GrayLevel[1]]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Contents and Index", "Section"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["ContentsTitle"],
    CellMargins->{{21, 4}, {12, 24}},
    FontFamily->"Helvetica",
    FontSize->24,
    FontWeight->"Bold"],
  
  Cell[StyleData["ContentsTitle", "Printout"],
    CellMargins->{{12, 0}, {102, 89}},
    PageBreakBelow->False,
    FontSize->30.5],
  
  Cell[StyleData["ContentsTitle", "EnhancedPrintout"],
    CellMargins->{{24, 0}, {102, 89}},
    PageBreakBelow->False,
    FontFamily->"Futura",
    FontSize->30.5]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["ContentsSection"],
    ShowGroupOpenCloseIcon->True,
    CellMargins->{{35, 4}, {3, 18}},
    CellGroupingRules->{"SectionGrouping", 70},
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->12,
    FontWeight->"Bold"],
  
  Cell[StyleData["ContentsSection", "Printout"],
    CellMargins->{{20, 0}, {3, 18}},
    PageBreakBelow->False,
    FontSize->11],
  
  Cell[StyleData["ContentsSection", "EnhancedPrintout"],
    CellMargins->{{20, 0}, {3, 18}},
    PageBreakBelow->False,
    FontFamily->"Futura",
    FontSize->11],
  
  Cell[StyleData["ContentsSection", "EnhancedPrintoutNonGray"],
    CellMargins->{{20, 0}, {3, 18}},
    PageBreakBelow->False,
    FontFamily->"Futura",
    FontSize->11]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["IndexSection"],
    CellDingbat->"\[FilledSquare]",
    CellMargins->{{20, 4}, {5, 20}},
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->12,
    FontWeight->"Bold"],
  
  Cell[StyleData["IndexSection", "Printout"],
    CellMargins->{{12, 0}, {5, 20}},
    PageBreakBelow->False,
    FontSize->12]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Contents"],
    ShowGroupOpenCloseIcon->False,
    CellMargins->{{50, 4}, {0, 5}},
    CellGroupingRules->{"SectionGrouping", 90},
    StyleMenuListing->None],
  
  Cell[StyleData["Contents", "Printout"],
    CellMargins->{{40, 4}, {0, 5}},
    FontSize->11],
  
  Cell[StyleData["Contents", "EnhancedPrintout"],
    CellMargins->{{40, 5}, {0, 5}},
    FontFamily->"Palatino",
    FontSize->11],
  
  Cell[StyleData["Contents", "EnhancedPrintoutNonGray"],
    CellMargins->{{40, 5}, {0, 5}},
    FontFamily->"Palatino",
    FontSize->11]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Index"],
    CellMargins->{{21, 4}, {0, 0}},
    ParagraphIndent->-48,
    StyleMenuListing->None],
  
  Cell[StyleData["Index", "Printout"],
    CellMargins->{{13, 0}, {0, 0}},
    FontSize->9],
  
  Cell[StyleData["Index", "EnhancedPrintout"],
    CellMargins->{{13, 0}, {0, 0}},
    FontFamily->"Palatino",
    FontSize->9],
  
  Cell[StyleData["Index", "EnhancedPrintoutNonGray"],
    CellMargins->{{13, 0}, {0, 0}},
    FontFamily->"Palatino",
    FontSize->9]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["IndexSubentry"],
    CellMargins->{{36, 4}, {0, 0}},
    ParagraphIndent->-48],
  
  Cell[StyleData["IndexSubentry", "Printout"],
    CellMargins->{{24, 0}, {0, 0}},
    FontSize->9],
  
  Cell[StyleData["IndexSubentry", "EnhancedPrintout"],
    CellMargins->{{24, 0}, {0, 0}},
    FontFamily->"Palatino",
    FontSize->9]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Index2Column"],
    CellMargins->{{21, 4}, {0, 8}},
    ParagraphIndent->-20,
    TabSpacings->1,
    StyleMenuListing->None,
    FontSize->10,
    GridBoxOptions->{ColumnWidths->0.5,
    ColumnAlignments->{Left}}],
  
  Cell[StyleData["Index2Column", "Printout"],
    CellMargins->{{2, 2}, {6, 6}},
    FontSize->8],
  
  Cell[StyleData["Index2Column", "EnhancedPrintout"],
    CellMargins->{{2, 2}, {6, 6}},
    FontFamily->"Palatino",
    FontSize->8],
  
  Cell[StyleData["Index2Column", "EnhancedPrintoutNonGray"],
    CellMargins->{{2, 2}, {6, 6}},
    FontFamily->"Palatino",
    FontSize->8]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Leader"],
    TabFilling->".",
    StyleMenuListing->None,
    FontFamily->"Times",
    FontSize->12,
    FontWeight->"Plain"],
  
  Cell[StyleData["Leader", "Printout"],
    FontSize->10],
  
  Cell[StyleData["Leader", "EnhancedPrintout"],
    FontFamily->"Palatino",
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["LeaderNoDots"],
    TabFilling->" ",
    StyleMenuListing->None,
    FontFamily->"Times",
    FontSize->12,
    FontWeight->"Plain"],
  
  Cell[StyleData["LeaderNoDots", "Printout"],
    FontSize->10],
  
  Cell[StyleData["LeaderNoDots", "EnhancedPrintout"],
    FontFamily->"Palatino",
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["PageLink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontColor->RGBColor[0, 0, 1],
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`NotebookLocate[ #2]}]&),
    Active->True,
    ButtonFrame->"None"}],
  
  Cell[StyleData["PageLink", "Printout"],
    FontColor->GrayLevel[0]],
  
  Cell[StyleData["PageLink", "EnhancedPrintout"],
    FontColor->GrayLevel[0]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["TOCPage"],
    CellSize->{22, Inherited},
    TextAlignment->Right,
    StyleMenuListing->None,
    FontSize->12,
    FontWeight->"Plain"],
  
  Cell[StyleData["TOCPage", "Printout"],
    FontSize->10],
  
  Cell[StyleData["TOCPage", "EnhancedPrintout"],
    FontFamily->"Palatino",
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["TOCTitle"],
    CellMargins->{{20, 0}, {1, 8}},
    CellGroupingRules->{"SectionGrouping", 70},
    TabSpacings->46,
    CounterIncrements->"TOCTitle",
    CounterAssignments->{{"TOCSection", 0}},
    FontFamily->"Helvetica",
    FontSize->12,
    FontWeight->"Bold"],
  
  Cell[StyleData["TOCTitle", "Printout"],
    CellMargins->{{12, 0}, {1, 8}},
    PageBreakBelow->False,
    TabSpacings->47.4,
    FontSize->11],
  
  Cell[StyleData["TOCTitle", "EnhancedPrintout"],
    CellMargins->{{2, 0}, {2, 10}},
    PageBreakBelow->False,
    TabSpacings->49.3,
    FontFamily->"Futura",
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["TOCSection"],
    CellMargins->{{48, 0}, {1, 1}},
    CellGroupingRules->{"SectionGrouping", 75},
    TabSpacings->42.9,
    CounterIncrements->"TOCSection",
    CounterAssignments->{{"TOCSubsection", 0}},
    FontFamily->"Helvetica",
    FontSize->12],
  
  Cell[StyleData["TOCSection", "Printout"],
    CellMargins->{{30, 0}, {1, 1}},
    PageBreakBelow->False,
    FontSize->12],
  
  Cell[StyleData["TOCSection", "EnhancedPrintout"],
    CellMargins->{{26, 0}, {1, 3}},
    PageBreakBelow->False,
    TabSpacings->46.45,
    FontFamily->"Futura",
    FontSize->9]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["TOCSubsection"],
    CellMargins->{{76, 0}, {1, 1}},
    CellGroupingRules->{"SectionGrouping", 80},
    TabSpacings->39.8,
    CounterIncrements->"TOCSubsection",
    CounterAssignments->{{"TOCSubsubsection", 0}},
    FontSize->12],
  
  Cell[StyleData["TOCSubsection", "Printout"],
    CellMargins->{{70, 0}, {1, 1}},
    PageBreakBelow->False,
    FontSize->10],
  
  Cell[StyleData["TOCSubsection", "EnhancedPrintout"],
    CellMargins->{{38, 0}, {1, 1}},
    PageBreakBelow->False,
    TabSpacings->45.15,
    FontFamily->"Palatino",
    FontSize->9]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["TOCSubsubsection"],
    CellMargins->{{104, 0}, {1, 1}},
    CellGroupingRules->{"SectionGrouping", 85},
    TabSpacings->36.7,
    CounterIncrements->"TOCSubsubsection",
    FontSize->12],
  
  Cell[StyleData["TOCSubsubsection", "Printout"],
    CellMargins->{{96, 0}, {1, 1}},
    PageBreakBelow->False,
    FontSize->9],
  
  Cell[StyleData["TOCSubsubsection", "EnhancedPrintout"],
    CellMargins->{{96, 0}, {1, 1}},
    PageBreakBelow->False,
    FontFamily->"Palatino",
    FontSize->9]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["TOCTitleDingbat"],
    CellSize->{34, Inherited},
    TextAlignment->Right],
  
  Cell[StyleData["TOCTitleDingbat", "EnhancedPrintout"],
    FontFamily->"Futura",
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["TOCSectionDingbat"],
    CellSize->{38, Inherited},
    TextAlignment->Right],
  
  Cell[StyleData["TOCSectionDingbat", "EnhancedPrintout"],
    FontFamily->"Futura",
    FontSize->9]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["TOCSubsectionDingbat"],
    CellSize->{54, Inherited},
    TextAlignment->Right],
  
  Cell[StyleData["TOCSubsectionDingbat", "EnhancedPrintout"],
    FontSize->9]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["TOCTitleCondensed"],
    CellMargins->{{20, 0}, {1, 8}},
    CellGroupingRules->{"SectionGrouping", 70},
    TabSpacings->50.4,
    CounterIncrements->"TOCTitleCondensed",
    CounterAssignments->{{"TOCSectionCondensed", 0}, {
        "TOCSubsectionCondensed", 0}},
    FontFamily->"Helvetica",
    FontSize->12,
    FontWeight->"Bold"],
  
  Cell[StyleData["TOCTitleCondensed", "Printout"],
    CellMargins->{{12, 0}, {1, 8}},
    PageBreakBelow->False,
    FontSize->11],
  
  Cell[StyleData["TOCTitleCondensed", "EnhancedPrintout"],
    CellMargins->{{12, 0}, {1, 8}},
    PageBreakBelow->False,
    FontFamily->"Futura",
    FontSize->11]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["TOCSectionCondensed"],
    CellMargins->{{48, 0}, {1, 1}},
    CellGroupingRules->{"SectionGrouping", 75},
    TabSpacings->47.4,
    CounterIncrements->"TOCSectionCondensed",
    CounterAssignments->{{"TOCSubsection", 0}},
    FontFamily->"Helvetica",
    FontSize->10,
    FontWeight->"Bold",
    FontColor->GrayLevel[0.2]],
  
  Cell[StyleData["TOCSectionCondensed", "Printout"],
    CellMargins->{{36, 0}, {1, 1}},
    PageBreakBelow->False,
    FontSize->11],
  
  Cell[StyleData["TOCSectionCondensed", "EnhancedPrintout"],
    CellMargins->{{36, 0}, {1, 1}},
    PageBreakBelow->False,
    FontFamily->"Palatino",
    FontSize->11]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["TOCSubsectionCondensed"],
    PageWidth->470,
    CellMargins->{{76, 0}, {1, 1}},
    CellGroupingRules->{"SectionGrouping", 80},
    TextJustification->1,
    Hyphenation->True,
    FontSize->12],
  
  Cell[StyleData["TOCSubsectionCondensed", "Printout"],
    CellMargins->{{72, 0}, {1, 1}},
    PageBreakBelow->False,
    FontSize->10],
  
  Cell[StyleData["TOCSubsectionCondensed", "EnhancedPrintout"],
    CellMargins->{{72, 0}, {1, 1}},
    PageBreakBelow->False,
    FontFamily->"Palatino",
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["TOCSubsubsectionCondensed"],
    CellMargins->{{104, 0}, {1, 1}},
    CellGroupingRules->{"SectionGrouping", 85},
    TabSpacings->39.3,
    CounterIncrements->"TOCSubsubsectionCondensed",
    FontSize->12],
  
  Cell[StyleData["TOCSubsubsectionCondensed", "Printout"],
    CellMargins->{{96, 0}, {1, 1}},
    PageBreakBelow->False,
    FontSize->9],
  
  Cell[StyleData["TOCSubsubsectionCondensed", "EnhancedPrintout"],
    CellMargins->{{96, 0}, {1, 1}},
    PageBreakBelow->False,
    FontFamily->"Palatino",
    FontSize->9]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Horizontal Lines", "Section"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Line1"],
    CellFrame->{{0, 0}, {0, 0.5}},
    CellMargins->{{10, 4}, {-16, 9}},
    StyleMenuListing->None,
    FontSize->2],
  
  Cell[StyleData["Line1", "Printout"],
    CellMargins->{{2, 0}, {-16, 9}}]
  }, Closed]],
  
  Cell["\<\

The item above is horizontal 0.5 pt line\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["ProgramTop"],
    CellFrame->{{0.5, 0.5}, {0, 0.5}},
    CellMargins->{{10, 4}, {-18, 18}},
    LineSpacing->{1, -4},
    StyleMenuListing->None,
    FontSize->4],
  
  Cell[StyleData["ProgramTop", "Printout"],
    CellMargins->{{2, 0}, {-18, 18}}]
  }, Closed]],
  
  Cell["\<\

The item above is a ProgramTop line
\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["ProgramBottom"],
    CellFrame->{{0.5, 0.5}, {0.5, 0}},
    CellMargins->{{10, 4}, {-10, -2}},
    LineSpacing->{1, -4},
    StyleMenuListing->None,
    FontSize->4],
  
  Cell[StyleData["ProgramBottom", "Printout"],
    CellMargins->{{2, 0}, {-10, -2}}]
  }, Closed]],
  
  Cell["\<\

The item above is a ProgramBottom line
\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["SessionLabel"],
    CellFrame->{{0.5, 0}, {0, 0.5}},
    CellMargins->{{10, 4}, {-4, 18}},
    LineSpacing->{1, 0},
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->9],
  
  Cell[StyleData["SessionLabel", "Printout"],
    CellMargins->{{2, 0}, {-4, 18}},
    FontSize->7]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Page Headers and Footers", "Section"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["PageHeader"],
    CellMargins->{{0, 0}, {2, 0}},
    StyleMenuListing->None,
    FontSize->8,
    FontSlant->"Italic"],
  
  Cell[StyleData["PageHeader", "Printout"]],
  
  Cell[StyleData["PageHeader", "EnhancedPrintout"],
    FontFamily->"Futura"],
  
  Cell[StyleData["PageHeader", "EnhancedPrintoutNonGray"],
    FontFamily->"Futura"]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["PageNumber"],
    CellMargins->{{0, 0}, {2, 0}},
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->8,
    FontWeight->"Bold"],
  
  Cell[StyleData["PageNumber", "Printout"]],
  
  Cell[StyleData["PageNumber", "EnhancedPrintout"],
    FontFamily->"Futura"],
  
  Cell[StyleData["PageNumber", "EnhancedPrintoutNonGray"],
    FontFamily->"Futura"]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["PageFooter"],
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->6],
  
  Cell[StyleData["PageFooter", "Printout"]],
  
  Cell[StyleData["PageFooter", "EnhancedPrintout"],
    FontFamily->"Futura"],
  
  Cell[StyleData["PageFooter", "EnhancedPrintoutNonGray"],
    FontFamily->"Futura"]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["For compatibility", "Subsection"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Header"],
    CellMargins->{{0, 0}, {2, 0}},
    StyleMenuListing->None,
    FontSize->8,
    FontSlant->"Italic"],
  
  Cell[StyleData["Header", "Printout"]],
  
  Cell[StyleData["Header", "EnhancedPrintout"],
    FontFamily->"Futura"],
  
  Cell[StyleData["Header", "EnhancedPrintoutNonGray"],
    FontFamily->"Futura"]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Footer"],
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->6],
  
  Cell[StyleData["Footer", "Printout"]],
  
  Cell[StyleData["Footer", "EnhancedPrintout"],
    FontFamily->"Futura"],
  
  Cell[StyleData["Footer", "EnhancedPrintoutNonGray"],
    FontFamily->"Futura"]
  }, Closed]]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Automatic Styles", "Section"],
  
  Cell["\<\
The cells below define styles that are used to affect the display \
of certain types of objects in typeset expressions.  For example, \
\"UnmatchedBracket\" style defines how unmatched bracket, curly bracket, and \
parenthesis characters are displayed (typically by coloring them to make them \
stand out).\
\>", "Text"],
  
  Cell[StyleData["UnmatchedBracket"],
    StyleMenuListing->None]
  }, Closed]]
  }, Open  ]],
  
  Cell[CellGroupData[{
  
  Cell["Notation Package Styles", "Section",
    CellTags->"NotationPackage"],
  
  Cell["\<\
The cells below define certain styles needed by the Notation \
package. These styles serve to make visible otherwise invisible \
tagboxes.\
\>", "Text",
    CellTags->"NotationPackage"],
  
  Cell[StyleData["NotationTemplateStyle"],
    StyleMenuListing->None,
    Background->RGBColor[1, 1, 0.850004],
    TagBoxOptions->{SyntaxForm->"symbol"},
    CellTags->"NotationPackage"],
  
  Cell[StyleData["NotationPatternWrapperStyle"],
    StyleMenuListing->None,
    Background->RGBColor[1, 0.900008, 0.979995],
    TagBoxOptions->{SyntaxForm->"symbol"},
    CellTags->"NotationPackage"],
  
  Cell[StyleData["NotationMadeBoxesWrapperStyle"],
    StyleMenuListing->None,
    Background->RGBColor[0.900008, 0.889998, 1],
    TagBoxOptions->{SyntaxForm->"symbol"},
    CellTags->"NotationPackage"]
  }, Closed]]
  }]
]

(*******************************************************************
Cached data follows.  If you edit this Notebook file directly, not
using Mathematica, you must remove the line containing CacheID at
the top of  the file.  The cache data will then be recreated when
you save this file from within Mathematica.
*******************************************************************)

(*CellTagsOutline
CellTagsIndex->{}
*)

(*CellTagsIndex
CellTagsIndex->{}
*)

(*NotebookFileOutline
Notebook[{
Cell[1754, 51, 31, 0, 34, "Subsubsection"],

Cell[CellGroupData[{
Cell[1810, 55, 34, 0, 24, "SubsubsectionIcon"],
Cell[1847, 57, 571, 13, 40, "Text"],
Cell[2421, 72, 199, 6, 72, "Text"],
Cell[2623, 80, 264, 6, 24, "Text"]
}, Closed]],

Cell[CellGroupData[{
Cell[2924, 91, 94, 1, 20, "SubsubsectionIcon"],
Cell[3021, 94, 66, 0, 30, "MathCaption"],
Cell[3090, 96, 125, 3, 26, "Input"],
Cell[3218, 101, 45, 0, 24, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[3300, 106, 101, 1, 24, "SubsubsectionIcon"],
Cell[3404, 109, 99, 3, 30, "MathCaption"],

Cell[CellGroupData[{
Cell[3528, 116, 78, 2, 26, "Input"],
Cell[3609, 120, 1211, 21, 117, "Output"]
}, Closed]],
Cell[4835, 144, 238, 6, 20, "Text"],
Cell[5076, 152, 197, 4, 24, "Text"],
Cell[5276, 158, 128, 3, 24, "Text"],
Cell[5407, 163, 242, 4, 30, "Input"],
Cell[5652, 169, 148, 3, 24, "Text"],

Cell[CellGroupData[{
Cell[5825, 176, 141, 3, 26, "Input"],
Cell[5969, 181, 521, 8, 21, "Output"]
}, Open  ]],
Cell[6505, 192, 189, 7, 24, "Text"],
Cell[6697, 201, 196, 6, 24, "Text"],
Cell[6896, 209, 336, 7, 30, "Input"],
Cell[7235, 218, 135, 5, 24, "Text"],
Cell[7373, 225, 157, 3, 28, "Input"],
Cell[7533, 230, 263, 6, 24, "Text"]
}, Closed]],

Cell[CellGroupData[{
Cell[7833, 241, 99, 1, 20, "SubsubsectionIcon"],
Cell[7935, 244, 276, 6, 24, "Text"],
Cell[8214, 252, 516, 10, 63, "Input"],
Cell[8733, 264, 422, 8, 64, "Text"],
Cell[9158, 274, 321, 10, 24, "Text"],
Cell[9482, 286, 56, 0, 24, "Text"],

Cell[CellGroupData[{
Cell[9563, 290, 65, 2, 26, "Input"],
Cell[9631, 294, 7769, 121, 485, "Output"]
}, Closed]],
Cell[17415, 418, 110, 3, 20, "Text"],

Cell[CellGroupData[{
Cell[17550, 425, 87, 2, 26, "Input"],
Cell[17640, 429, 2302, 32, 101, "Output"]
}, Closed]],
Cell[19957, 464, 39, 0, 20, "Text"],

Cell[CellGroupData[{
Cell[20021, 468, 86, 2, 26, "Input"],
Cell[20110, 472, 761, 12, 37, "Output"]
}, Closed]],
Cell[20886, 487, 59, 0, 20, "Text"],

Cell[CellGroupData[{
Cell[20970, 491, 216, 5, 26, "Input"],

Cell[CellGroupData[{
Cell[21211, 500, 18120, 452, 184, 3305, 264, "GraphicsData", "PostScript", \
"Graphics"],
Cell[39334, 954, 17962, 449, 184, 3366, 264, "GraphicsData", "PostScript", \
"Graphics"],
Cell[57299, 1405, 17788, 447, 184, 3378, 264, "GraphicsData", "PostScript", \
"Graphics"],
Cell[75090, 1854, 17639, 445, 184, 3379, 264, "GraphicsData", "PostScript", \
"Graphics"],
Cell[92732, 2301, 17460, 443, 184, 3374, 264, "GraphicsData", "PostScript", \
"Graphics"],
Cell[110195, 2746, 17314, 441, 184, 3378, 264, "GraphicsData", "PostScript", \
"Graphics"],
Cell[127512, 3189, 17170, 439, 184, 3376, 264, "GraphicsData", "PostScript", \
"Graphics"],
Cell[144685, 3630, 17041, 438, 184, 3376, 264, "GraphicsData", "PostScript", \
"Graphics"],
Cell[161729, 4070, 16948, 437, 184, 3376, 264, "GraphicsData", "PostScript", \
"Graphics"],
Cell[178680, 4509, 16860, 436, 184, 3377, 264, "GraphicsData", "PostScript", \
"Graphics"],
Cell[195543, 4947, 16789, 435, 184, 3379, 264, "GraphicsData", "PostScript", \
"Graphics"],
Cell[212335, 5384, 16735, 434, 184, 3378, 264, "GraphicsData", "PostScript", \
"Graphics"],
Cell[229073, 5820, 16700, 434, 184, 3379, 264, "GraphicsData", "PostScript", \
"Graphics"],
Cell[245776, 6256, 16636, 433, 184, 3376, 264, "GraphicsData", "PostScript", \
"Graphics"],
Cell[262415, 6691, 16635, 433, 184, 3379, 264, "GraphicsData", "PostScript", \
"Graphics"],
Cell[279053, 7126, 16594, 432, 184, 3375, 264, "GraphicsData", "PostScript", \
"Graphics"],
Cell[295650, 7560, 16595, 432, 184, 3376, 264, "GraphicsData", "PostScript", \
"Graphics"],
Cell[312248, 7994, 16584, 432, 184, 3377, 264, "GraphicsData", "PostScript", \
"Graphics"],
Cell[328835, 8428, 16599, 432, 184, 3372, 264, "GraphicsData", "PostScript", \
"Graphics"],
Cell[345437, 8862, 16602, 432, 184, 3375, 264, "GraphicsData", "PostScript", \
"Graphics"],
Cell[362042, 9296, 16617, 433, 184, 3377, 264, "GraphicsData", "PostScript", \
"Graphics"],
Cell[378662, 9731, 16617, 433, 184, 3377, 264, "GraphicsData", "PostScript", \
"Graphics"],
Cell[395282, 10166, 16617, 433, 184, 3377, 264, "GraphicsData", "PostScript", \
"Graphics"],
Cell[411902, 10601, 16613, 433, 184, 3373, 264, "GraphicsData", "PostScript", \
"Graphics"],
Cell[428518, 11036, 16618, 433, 184, 3378, 264, "GraphicsData", "PostScript", \
"Graphics"],
Cell[445139, 11471, 16613, 433, 184, 3377, 264, "GraphicsData", "PostScript", \
"Graphics"]
}, Closed]]
}, Open  ]],
Cell[461779, 11908, 178, 6, 24, "Text"],
Cell[461960, 11916, 111, 3, 24, "Text"],

Cell[CellGroupData[{
Cell[462096, 11923, 135, 3, 26, "Input"],
Cell[462234, 11928, 2807, 60, 431, "Output"]
}, Closed]],
Cell[465056, 11991, 195, 5, 20, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[465288, 12001, 40, 0, 24, "SubsubsectionIcon"],
Cell[465331, 12003, 358, 9, 30, "Text"],

Cell[CellGroupData[{
Cell[465714, 12016, 160, 3, 43, "Input"],
Cell[465877, 12021, 23838, 669, 184, 9751, 490, "GraphicsData", "PostScript", \
"Graphics"]
}, Open  ]],
Cell[489730, 12693, 423, 11, 24, "Text"]
}, Closed]],

Cell[CellGroupData[{
Cell[490190, 12709, 103, 1, 20, "SubsubsectionIcon"],
Cell[490296, 12712, 99, 3, 24, "Text"],

Cell[CellGroupData[{
Cell[490420, 12719, 255, 5, 42, "Input"],
Cell[490678, 12726, 28481, 619, 184, 4478, 318, "GraphicsData", "PostScript", \
"Graphics"],
Cell[519162, 13347, 80, 2, 21, "Output"]
}, Open  ]],
Cell[519257, 13352, 203, 6, 24, "Text"],

Cell[CellGroupData[{
Cell[519485, 13362, 293, 6, 61, "Input"],
Cell[519781, 13370, 80, 2, 21, "Output"]
}, Open  ]],
Cell[519876, 13375, 303, 6, 24, "Text"],
Cell[520182, 13383, 131, 3, 24, "Text"],
Cell[520316, 13388, 314, 6, 42, "Input"],
Cell[520633, 13396, 55, 0, 24, "Text"],

Cell[CellGroupData[{
Cell[520713, 13400, 293, 5, 42, "Input"],
Cell[521009, 13407, 25656, 559, 184, 4083, 288, "GraphicsData", "PostScript", \
"Graphics"],
Cell[546668, 13968, 80, 2, 21, "Output"]
}, Open  ]],
Cell[546763, 13973, 185, 5, 24, "Text"]
}, Closed]],

Cell[CellGroupData[{
Cell[546985, 13983, 46, 0, 20, "SubsubsectionIcon"],
Cell[547034, 13985, 496, 10, 120, "Text"]
}, Closed]]
}
]
*)



(*******************************************************************
End of Mathematica Notebook file.
*******************************************************************)

