(***********************************************************************

                    Mathematica-Compatible Notebook

This notebook can be used on any computer system with Mathematica 4.0,
MathReader 4.0, or any compatible application. The data for the notebook 
starts with the line containing stars above.

To get the notebook into a Mathematica-compatible application, do one of 
the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing the 
word CacheID, otherwise Mathematica-compatible applications may try to 
use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
***********************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[     13004,        335]*)
(*NotebookOutlinePosition[     14333,        377]*)
(*  CellTagsIndexPosition[     14190,        369]*)
(*WindowFrame->Normal*)



Notebook[{

Cell[CellGroupData[{
Cell["Converting between representations", "SubsectionIcon"],

Cell[TextData[Cell[BoxData[
    FormBox[GridBox[{
          {\(MakeDiploid[
              HaploidIndividuals[\[Psi], 
                n]]\), \(gives\ a\ diploid\ population, \ 
            formed\ by\ combining\ neighbouring\ pairs\ of\ \(\(haploids\)\(.\
\)\)\)},
          {\(MakeHaploid[
              DiploidFrequencies[\[Psi], 
                n]]\), \(gives\ the\ haploid\ frequencies, \ 
            averaged\ over\ the\ maternal\ and\ paternal\ genomes\)}
          }], TraditionalForm]]]], "DefinitionBox",
  CellTags->{"MakeDiploid", "MakeHaploid"}],

Cell["\<\
This is a haploid population, with three loci and deme size \
10:\
\>", "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[
    \(hp = 
      MakePopulation[3, {0.1, 0.2, 0.3}, 10, 
        NumericalModel \[Rule] HaploidIndividuals]\)], "Input",
  CellLabel->"In[10]:="],

Cell[BoxData[
    \(HaploidIndividuals[{{0, 0, 0}, {0, 0, 0}, {0, 0, 0}, {0, 0, 0}, {0, 0, 
          0}, {0, 0, 1}, {0, 0, 0}, {1, 0, 0}, {0, 0, 1}, {0, 0, 1}}, 
      10]\)], "Output",
  CellLabel->"Out[10]="]
}, Open  ]],

Cell["This is the diploid population after random union:", "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[
    \(dp = MakeDiploid[hp]\)], "Input",
  CellLabel->"In[11]:="],

Cell[BoxData[
    \(DiploidIndividuals[{{{0, 0, 0}, {0, 0, 0}}, {{0, 0, 0}, {0, 0, 
            0}}, {{0, 0, 0}, {0, 0, 1}}, {{0, 0, 0}, {1, 0, 0}}, {{0, 0, 
            1}, {0, 0, 1}}}, 5]\)], "Output",
  CellLabel->"Out[11]="]
}, Open  ]],

Cell["\<\
Note that neighbouring pairs are combined, and so their order must \
be random to ensure random union.\
\>", "Text"],

Cell["This generates a haploid population:", "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[
    \(MakeHaploid[dp]\)], "Input",
  CellLabel->"In[15]:="],

Cell[BoxData[
    \(HaploidIndividuals[{{0, 0, 0}, {0, 0, 0}, {0, 0, 0}, {0, 0, 0}, {0, 0, 
          0}, {0, 0, 1}, {0, 0, 0}, {1, 0, 0}, {0, 0, 1}, {0, 0, 1}}, 
      10]\)], "Output",
  CellLabel->"Out[15]="]
}, Open  ]],

Cell[TextData[{
  "This just flattens out the list of haplotypes, doubling the deme size.  \
This does ",
  StyleBox["not",
    FontWeight->"Bold"],
  " represent the formation of new gametes by meiosis: for that, use ",
  ButtonBox["NewGametes",
    ButtonData:>{"Simulating individuals: reproduction", "NewGametes"},
    ButtonStyle->"AddOnsLink"],
  "."
}], "Text"],

Cell["Deme size is halved, and so must initially be even:", "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(hp2 = 
        MakePopulation[3, {0.1, 0.2, 0.3}, 11, 
          NumericalModel \[Rule] 
            HaploidIndividuals];\)\), "\[IndentingNewLine]", 
    \(dp2 = MakeDiploid[hp2]\)}], "Input",
  CellLabel->"In[13]:="],

Cell[BoxData[
    \(MakeDiploid::"odd" \(\(:\)\(\ \)\) 
      "MakeDiploid[HaploidIndividuals[\[Psi],n] only applies when n is \
even"\)], "Message",
  CellLabel->"From In[13]:="],

Cell[BoxData[
    \(HaploidIndividuals[{{0, 0, 1}, {0, 0, 1}, {0, 0, 0}, {0, 0, 1}, {0, 0, 
          1}, {0, 1, 1}, {1, 1, 1}, {0, 0, 1}, {0, 0, 0}, {0, 0, 0}, {0, 0, 
          0}}, 11]\)], "Output",
  CellLabel->"Out[14]="]
}, Open  ]],

Cell[TextData[Cell[BoxData[
    FormBox[GridBox[{
          {\(MakeIndividuals[HaploidFrequencies[\[Psi], n\_0], 
              n]\), \(gives\ n\ haploid\ individuals, \ 
            sampled\ from\ the\ population\ \[Psi]\)},
          {\(MakeIndividuals[
              DiploidFrequencies[\[Psi], 
                n]]\), \(gives\ n\ diploid\ frequencies, \ 
            sampled\ from\ the\ population\ \[Psi]\)}
          }], TraditionalForm]]]], "DefinitionBox",
  CellTags->"MakeIndividuals"],

Cell["This generates a sample of 100 haploid individuals:", "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[
    \(hi = MakeIndividuals[hp, 100]\)], "Input",
  CellLabel->"In[218]:=  (9:11:43 on 4/22/01)"],

Cell[BoxData[
    \(HaploidIndividuals[{{0, 0, 1}, {0, 0, 1}, {0, 0, 1}, {0, 1, 0}, {1, 0, 
          0}, {0, 0, 0}, {0, 0, 1}, {0, 0, 0}, {0, 0, 0}, {0, 0, 0}, {0, 0, 
          0}, {0, 0, 1}, {0, 0, 1}, {0, 0, 0}, {0, 0, 0}, {0, 1, 0}, {0, 0, 
          0}, {0, 0, 0}, {0, 0, 0}, {0, 1, 1}, {0, 1, 0}, {1, 0, 0}, {0, 0, 
          0}, {0, 0, 0}, {0, 0, 0}, {0, 0, 0}, {0, 0, 1}, {0, 0, 1}, {0, 0, 
          0}, {0, 0, 0}, {1, 0, 0}, {0, 0, 1}, {0, 0, 0}, {0, 0, 1}, {0, 0, 
          1}, {0, 1, 1}, {0, 0, 1}, {0, 0, 0}, {0, 0, 0}, {0, 0, 0}, {0, 0, 
          0}, {1, 1, 0}, {0, 0, 0}, {0, 0, 0}, {0, 0, 0}, {0, 0, 0}, {0, 1, 
          0}, {0, 1, 0}, {0, 0, 0}, {0, 0, 1}, {0, 0, 0}, {0, 0, 0}, {0, 1, 
          1}, {0, 0, 1}, {0, 0, 0}, {0, 0, 1}, {0, 0, 1}, {1, 0, 0}, {0, 0, 
          1}, {0, 0, 1}, {0, 0, 0}, {0, 0, 1}, {0, 0, 0}, {0, 0, 1}, {0, 1, 
          0}, {0, 0, 1}, {0, 0, 0}, {0, 0, 0}, {0, 0, 0}, {0, 0, 1}, {0, 0, 
          1}, {0, 0, 0}, {0, 0, 0}, {0, 0, 0}, {0, 0, 0}, {0, 0, 0}, {0, 0, 
          0}, {0, 0, 0}, {0, 0, 0}, {0, 1, 1}, {0, 0, 1}, {0, 0, 1}, {0, 0, 
          0}, {0, 0, 0}, {0, 0, 1}, {0, 1, 1}, {0, 0, 0}, {0, 1, 0}, {0, 0, 
          1}, {0, 0, 0}, {0, 1, 0}, {0, 0, 0}, {0, 0, 0}, {0, 0, 1}, {0, 0, 
          0}, {1, 0, 0}, {0, 0, 0}, {0, 0, 1}, {0, 1, 0}, {0, 0, 1}}, 
      100]\)], "Output",
  CellLabel->"Out[218]=  (9:11:43 on 4/22/01)"]
}, Closed]],

Cell["\<\
These are close to the allele frequencies {0.1, 0.2, 0.3} in the \
base population, and to linkage equilibrium:\
\>", "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[
    \({AlleleFrequencyTable[hi] // MatrixForm, 
        DisequilibriumTable[hi] // MatrixForm} // N\)], "Input",
  CellLabel->"In[226]:=  (9:12:59 on 4/22/01)"],

Cell[BoxData[
    RowBox[{"{", 
      RowBox[{
        InterpretationBox[
          RowBox[{"(", "\[NoBreak]", GridBox[{
                {"0.06`"},
                {"0.15`"},
                {"0.35`"}
                }], "\[NoBreak]", ")"}],
          
          MatrixForm[ {0.059999999999999998, 0.14999999999999999, 
            0.34999999999999998}]], ",", 
        TagBox[
          RowBox[{"(", "\[NoBreak]", GridBox[{
                {"0.05696969696969697`", 
                  "0.00101010101010101`", \(-0.021212121212121213`\)},
                {"0.00101010101010101`", 
                  "0.12878787878787878`", \(-0.0025252525252525255`\)},
                {\(-0.021212121212121213`\), \(-0.0025252525252525255`\), 
                  "0.2297979797979798`"}
                }], "\[NoBreak]", ")"}],
          (MatrixForm[ #]&)]}], "}"}]], "Output",
  CellLabel->"Out[226]=  (9:12:59 on 4/22/01)"]
}, Open  ]],

Cell["This does the same for a diploid population:", "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[
    \(di = MakeIndividuals[dp, 100]\)], "Input",
  CellLabel->"In[227]:=  (9:15:15 on 4/22/01)"],

Cell[BoxData[
    \(DiploidIndividuals[{{{1, 0, 0}, {0, 0, 1}}, {{0, 0, 0}, {0, 0, 
            0}}, {{0, 1, 0}, {0, 0, 0}}, {{0, 0, 1}, {0, 0, 1}}, {{0, 0, 
            0}, {0, 0, 1}}, {{0, 0, 0}, {1, 0, 0}}, {{0, 0, 0}, {0, 0, 
            1}}, {{0, 0, 0}, {0, 1, 0}}, {{0, 1, 0}, {0, 0, 1}}, {{0, 0, 
            1}, {0, 0, 0}}, {{0, 0, 0}, {0, 0, 0}}, {{0, 0, 1}, {0, 1, 
            0}}, {{0, 0, 0}, {0, 0, 0}}, {{0, 0, 0}, {0, 1, 0}}, {{0, 0, 
            0}, {0, 1, 0}}, {{0, 0, 0}, {0, 0, 0}}, {{0, 1, 0}, {0, 0, 
            0}}, {{0, 1, 0}, {0, 1, 0}}, {{0, 0, 0}, {0, 0, 0}}, {{0, 0, 
            0}, {0, 0, 1}}, {{0, 0, 1}, {0, 0, 0}}, {{0, 0, 0}, {0, 0, 
            1}}, {{0, 0, 0}, {0, 1, 0}}, {{0, 1, 0}, {0, 0, 0}}, {{0, 0, 
            1}, {0, 0, 1}}, {{0, 0, 0}, {0, 0, 0}}, {{0, 0, 1}, {0, 1, 
            0}}, {{0, 0, 0}, {0, 0, 0}}, {{0, 0, 0}, {0, 0, 1}}, {{0, 1, 
            0}, {0, 0, 0}}, {{0, 0, 0}, {0, 1, 0}}, {{0, 0, 1}, {1, 1, 
            0}}, {{0, 0, 0}, {1, 1, 0}}, {{0, 0, 0}, {0, 0, 0}}, {{0, 0, 
            0}, {0, 0, 1}}, {{0, 0, 0}, {0, 0, 0}}, {{0, 0, 0}, {0, 1, 
            0}}, {{0, 1, 0}, {0, 1, 0}}, {{0, 1, 1}, {0, 0, 1}}, {{0, 1, 
            0}, {0, 1, 0}}, {{0, 0, 1}, {0, 0, 1}}, {{1, 1, 1}, {1, 1, 
            1}}, {{0, 0, 1}, {0, 1, 0}}, {{0, 0, 1}, {0, 0, 0}}, {{0, 0, 
            0}, {0, 0, 0}}, {{0, 1, 0}, {0, 0, 0}}, {{0, 0, 0}, {0, 0, 
            1}}, {{0, 1, 0}, {0, 0, 1}}, {{0, 0, 0}, {0, 1, 1}}, {{0, 0, 
            0}, {1, 0, 1}}, {{0, 0, 1}, {0, 0, 1}}, {{0, 0, 1}, {0, 1, 
            1}}, {{0, 0, 0}, {0, 0, 0}}, {{0, 1, 0}, {0, 0, 0}}, {{0, 0, 
            0}, {0, 0, 0}}, {{1, 0, 1}, {0, 1, 1}}, {{0, 0, 1}, {0, 0, 
            1}}, {{0, 0, 1}, {0, 0, 0}}, {{1, 0, 0}, {1, 0, 0}}, {{1, 0, 
            0}, {0, 0, 1}}, {{0, 0, 0}, {0, 0, 1}}, {{0, 1, 0}, {0, 0, 
            0}}, {{0, 0, 0}, {0, 0, 0}}, {{0, 0, 0}, {0, 0, 0}}, {{0, 0, 
            1}, {0, 0, 1}}, {{0, 1, 0}, {0, 0, 0}}, {{0, 0, 0}, {0, 1, 
            0}}, {{0, 0, 1}, {0, 0, 0}}, {{0, 0, 1}, {0, 0, 0}}, {{0, 0, 
            0}, {0, 0, 0}}, {{0, 0, 0}, {0, 0, 0}}, {{0, 1, 0}, {0, 0, 
            0}}, {{0, 0, 0}, {0, 0, 0}}, {{0, 0, 1}, {0, 0, 0}}, {{0, 0, 
            0}, {1, 0, 0}}, {{0, 0, 0}, {0, 0, 0}}, {{1, 1, 1}, {0, 0, 
            1}}, {{0, 1, 0}, {0, 0, 1}}, {{0, 0, 0}, {0, 0, 1}}, {{0, 0, 
            0}, {0, 0, 0}}, {{0, 0, 0}, {0, 0, 1}}, {{0, 0, 0}, {0, 0, 
            0}}, {{0, 0, 0}, {0, 0, 1}}, {{0, 0, 0}, {0, 0, 0}}, {{0, 0, 
            0}, {0, 0, 0}}, {{0, 0, 0}, {1, 1, 0}}, {{0, 0, 0}, {0, 0, 
            0}}, {{0, 0, 0}, {0, 0, 0}}, {{0, 0, 0}, {1, 0, 0}}, {{0, 1, 
            0}, {0, 0, 0}}, {{0, 1, 1}, {0, 0, 0}}, {{0, 0, 0}, {1, 0, 
            1}}, {{0, 1, 1}, {0, 0, 1}}, {{0, 1, 0}, {0, 0, 0}}, {{0, 1, 
            0}, {0, 0, 0}}, {{0, 1, 0}, {0, 0, 0}}, {{0, 1, 0}, {0, 0, 
            0}}, {{0, 0, 0}, {0, 0, 0}}, {{0, 0, 0}, {0, 0, 1}}, {{0, 0, 
            1}, {0, 1, 0}}}, 100]\)], "Output",
  CellLabel->"Out[227]=  (9:15:15 on 4/22/01)"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    \({AlleleFrequencyTable[di] // MatrixForm, 
        DisequilibriumTable[di] // MatrixForm} // N\)], "Input",
  CellLabel->"In[232]:=  (9:18:30 on 4/22/01)"],

Cell[BoxData[
    RowBox[{"{", 
      RowBox[{
        InterpretationBox[
          RowBox[{"(", "\[NoBreak]", GridBox[{
                {"0.08`"},
                {"0.23`"},
                {"0.285`"}
                }], "\[NoBreak]", ")"}],
          
          MatrixForm[ {0.080000000000000002, 0.23000000000000001, 
            0.28499999999999998}]], ",", 
        TagBox[
          RowBox[{"(", "\[NoBreak]", GridBox[{
                {"0.07396984924623115`", "0.011658291457286432`", 
                  "0.007236180904522613`"},
                {"0.011658291457286432`", 
                  "0.17798994974874371`", \(-0.02065326633165829`\)},
                {"0.007236180904522613`", \(-0.02065326633165829`\), 
                  "0.20479899497487436`"}
                }], "\[NoBreak]", ")"}],
          (MatrixForm[ #]&)]}], "}"}]], "Output",
  CellLabel->"Out[232]=  (9:18:30 on 4/22/01)"]
}, Open  ]],

Cell[TextData[{
  StyleBox["Related functions:",
    FontWeight->"Bold"],
  "  ",
  ButtonBox["RandomFamily",
    ButtonData:>{"Generating families", "RandomFamily"},
    ButtonStyle->"AddOnsLink"],
  " generates families of individuals from a cross, for arbitrary numbers of \
alleles. "
}], "Text"]
}, Open  ]]
},
FrontEndVersion->"4.0 for Macintosh",
ScreenRectangle->{{0, 1152}, {0, 748}},
WindowSize->{911, 638},
WindowMargins->{{Automatic, 31}, {Automatic, 3}},
StyleDefinitions -> "HelpBrowser.nb",
MacintoshSystemPageSetup->"\<\
00h0001804P000000b02<?oaonl3>@91H`85N0?N0@00005X0FP000003j0:l001
0@00I00100000@0200000BL?00400000000000000000010000000000000@0?ne
oj/@7@]500P1000000000000000001T1\>"
]


(***********************************************************************
Cached data follows.  If you edit this Notebook file directly, not using
Mathematica, you must remove the line containing CacheID at the top of 
the file.  The cache data will then be recreated when you save this file 
from within Mathematica.
***********************************************************************)

(*CellTagsOutline
CellTagsIndex->{
  "MakeDiploid"->{
    Cell[1802, 53, 559, 12, 56, "DefinitionBox",
      CellTags->{"MakeDiploid", "MakeHaploid"}]},
  "MakeHaploid"->{
    Cell[1802, 53, 559, 12, 56, "DefinitionBox",
      CellTags->{"MakeDiploid", "MakeHaploid"}]},
  "MakeIndividuals"->{
    Cell[4948, 159, 494, 10, 56, "DefinitionBox",
      CellTags->"MakeIndividuals"]}
  }
*)

(*CellTagsIndex
CellTagsIndex->{
  {"MakeDiploid", 13838, 356},
  {"MakeHaploid", 13956, 359},
  {"MakeIndividuals", 14078, 362}
  }
*)

(*NotebookFileOutline
Notebook[{

Cell[CellGroupData[{
Cell[1739, 51, 60, 0, 36, "SubsectionIcon"],
Cell[1802, 53, 559, 12, 56, "DefinitionBox",
  CellTags->{"MakeDiploid", "MakeHaploid"}],
Cell[2364, 67, 96, 3, 28, "MathCaption"],

Cell[CellGroupData[{
Cell[2485, 74, 160, 4, 26, "Input"],
Cell[2648, 80, 211, 4, 35, "Output"]
}, Open  ]],
Cell[2874, 87, 73, 0, 28, "MathCaption"],

Cell[CellGroupData[{
Cell[2972, 91, 78, 2, 26, "Input"],
Cell[3053, 95, 228, 4, 35, "Output"]
}, Open  ]],
Cell[3296, 102, 126, 3, 22, "Text"],
Cell[3425, 107, 59, 0, 28, "MathCaption"],

Cell[CellGroupData[{
Cell[3509, 111, 73, 2, 26, "Input"],
Cell[3585, 115, 211, 4, 35, "Output"]
}, Open  ]],
Cell[3811, 122, 368, 10, 24, "Text"],
Cell[4182, 134, 74, 0, 28, "MathCaption"],

Cell[CellGroupData[{
Cell[4281, 138, 241, 6, 42, "Input"],
Cell[4525, 146, 179, 4, 20, "Message"],
Cell[4707, 152, 226, 4, 35, "Output"]
}, Open  ]],
Cell[4948, 159, 494, 10, 56, "DefinitionBox",
  CellTags->"MakeIndividuals"],
Cell[5445, 171, 74, 0, 28, "MathCaption"],

Cell[CellGroupData[{
Cell[5544, 175, 110, 2, 38, "Input"],
Cell[5657, 179, 1390, 19, 98, "Output"]
}, Closed]],
Cell[7062, 201, 142, 3, 18, "MathCaption"],

Cell[CellGroupData[{
Cell[7229, 208, 174, 3, 38, "Input"],
Cell[7406, 213, 906, 22, 63, "Output"]
}, Open  ]],
Cell[8327, 238, 67, 0, 28, "MathCaption"],

Cell[CellGroupData[{
Cell[8419, 242, 110, 2, 38, "Input"],
Cell[8532, 246, 3027, 42, 202, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[11596, 293, 174, 3, 34, "Input"],
Cell[11773, 298, 900, 22, 63, "Output"]
}, Open  ]],
Cell[12688, 323, 300, 9, 24, "Text"]
}, Open  ]]
}
]
*)




(***********************************************************************
End of Mathematica Notebook file.
***********************************************************************)

